/********************************************************************************
** Form generated from reading UI file 'opsdslrsettings.ui'
**
** Created by: Qt User Interface Compiler version 6.11.1
**
** WARNING! All changes made in this file will be lost when recompiling UI file!
********************************************************************************/

#ifndef UI_OPSDSLRSETTINGS_H
#define UI_OPSDSLRSETTINGS_H

#include <QtCore/QVariant>
#include <QtGui/QIcon>
#include <QtWidgets/QApplication>
#include <QtWidgets/QCheckBox>
#include <QtWidgets/QHBoxLayout>
#include <QtWidgets/QPushButton>
#include <QtWidgets/QSpacerItem>
#include <QtWidgets/QVBoxLayout>
#include <QtWidgets/QWidget>
#include <klocalizedstring.h>

QT_BEGIN_NAMESPACE

class Ui_OpsDslrSettings
{
public:
    QVBoxLayout *verticalLayout;
    QHBoxLayout *horizontalLayout;
    QCheckBox *kcfg_ForceDSLRPresets;
    QCheckBox *kcfg_useDSLRImageViewer;
    QPushButton *clearDSLRInfoB;
    QSpacerItem *verticalSpacer;

    void setupUi(QWidget *OpsDslrSettings)
    {
        if (OpsDslrSettings->objectName().isEmpty())
            OpsDslrSettings->setObjectName("OpsDslrSettings");
        OpsDslrSettings->resize(410, 41);
        OpsDslrSettings->setProperty("currentIndex", QVariant(2));
        verticalLayout = new QVBoxLayout(OpsDslrSettings);
        verticalLayout->setSpacing(3);
        verticalLayout->setObjectName("verticalLayout");
        verticalLayout->setContentsMargins(3, 3, 3, 3);
        horizontalLayout = new QHBoxLayout();
        horizontalLayout->setObjectName("horizontalLayout");
        kcfg_ForceDSLRPresets = new QCheckBox(OpsDslrSettings);
        kcfg_ForceDSLRPresets->setObjectName("kcfg_ForceDSLRPresets");

        horizontalLayout->addWidget(kcfg_ForceDSLRPresets);

        kcfg_useDSLRImageViewer = new QCheckBox(OpsDslrSettings);
        kcfg_useDSLRImageViewer->setObjectName("kcfg_useDSLRImageViewer");

        horizontalLayout->addWidget(kcfg_useDSLRImageViewer);

        clearDSLRInfoB = new QPushButton(OpsDslrSettings);
        clearDSLRInfoB->setObjectName("clearDSLRInfoB");
        QIcon icon(QIcon::fromTheme(QString::fromUtf8("edit-clear")));
        clearDSLRInfoB->setIcon(icon);
        clearDSLRInfoB->setIconSize(QSize(24, 24));

        horizontalLayout->addWidget(clearDSLRInfoB);


        verticalLayout->addLayout(horizontalLayout);

        verticalSpacer = new QSpacerItem(20, 328, QSizePolicy::Policy::Minimum, QSizePolicy::Policy::Expanding);

        verticalLayout->addItem(verticalSpacer);


        retranslateUi(OpsDslrSettings);

        QMetaObject::connectSlotsByName(OpsDslrSettings);
    } // setupUi

    void retranslateUi(QWidget *OpsDslrSettings)
    {
        OpsDslrSettings->setWindowTitle(tr2i18n("TabWidget", nullptr));
#if QT_CONFIG(tooltip)
        kcfg_ForceDSLRPresets->setToolTip(tr2i18n("<html><head/><body><p>Force exposure times to align with DSLR exposure presets. This insures accurate exposure times for sub-second exposures.</p></body></html>", nullptr));
#endif // QT_CONFIG(tooltip)
        kcfg_ForceDSLRPresets->setText(tr2i18n("Force DSLR presets", nullptr));
#if QT_CONFIG(tooltip)
        kcfg_useDSLRImageViewer->setToolTip(tr2i18n("Display received DSLR images in the Image Viewer", nullptr));
#endif // QT_CONFIG(tooltip)
        kcfg_useDSLRImageViewer->setText(tr2i18n("DSLR image viewer", nullptr));
#if QT_CONFIG(tooltip)
        clearDSLRInfoB->setToolTip(tr2i18n("Clear saved DSLR sizes", nullptr));
#endif // QT_CONFIG(tooltip)
        clearDSLRInfoB->setText(tr2i18n("Clear DSLR Info", nullptr));
    } // retranslateUi

};

namespace Ui {
    class OpsDslrSettings: public Ui_OpsDslrSettings {};
} // namespace Ui

QT_END_NAMESPACE

#endif // OPSDSLRSETTINGS_H

