/*
 * This file was generated by qdbusxml2cpp version 0.8
 * Source file was org.kde.kstars.INDI.LightBox.xml
 *
 * qdbusxml2cpp is Copyright (C) The Qt Company Ltd. and other contributors.
 *
 * This is an auto-generated file.
 * This file may have been hand-edited. Look for HAND-EDIT comments
 * before re-generating it.
 */

#ifndef LIGHTBOXADAPTOR_H
#define LIGHTBOXADAPTOR_H

#include <QtCore/QObject>
#include <QtDBus/QtDBus>
#include "indi/indilightbox.h"
#include <QtCore/qcontainerfwd.h>

/*
 * Adaptor class for interface org.kde.kstars.INDI.LightBox
 */
class LightBoxAdaptor: public QDBusAbstractAdaptor
{
    Q_OBJECT
    Q_CLASSINFO("D-Bus Interface", "org.kde.kstars.INDI.LightBox")
    Q_CLASSINFO("D-Bus Introspection", ""
"  <interface name=\"org.kde.kstars.INDI.LightBox\">\n"
"    <property access=\"read\" type=\"s\" name=\"name\"/>\n"
"    <property access=\"read\" type=\"b\" name=\"connected\"/>\n"
"    <property access=\"read\" type=\"i\" name=\"status\">\n"
"      <annotation value=\"ISD::LightBox::LightStatus\" name=\"org.qtproject.QtDBus.QtTypeName\"/>\n"
"    </property>\n"
"    <property access=\"read\" type=\"q\" name=\"brightness\"/>\n"
"    <method name=\"isLightOn\">\n"
"      <arg direction=\"out\" type=\"b\"/>\n"
"    </method>\n"
"    <method name=\"setLightEnabled\">\n"
"      <arg direction=\"out\" type=\"b\"/>\n"
"      <arg direction=\"in\" type=\"b\" name=\"enable\"/>\n"
"    </method>\n"
"    <method name=\"setBrightness\">\n"
"      <arg direction=\"out\" type=\"b\"/>\n"
"      <arg direction=\"in\" type=\"q\" name=\"val\"/>\n"
"    </method>\n"
"    <signal name=\"Connected\"/>\n"
"    <signal name=\"Disconnected\"/>\n"
"    <signal name=\"ready\"/>\n"
"    <signal name=\"newStatus\">\n"
"      <arg direction=\"out\" type=\"(i)\" name=\"status\"/>\n"
"      <annotation value=\"ISD::LightBox::LightStatus\" name=\"org.qtproject.QtDBus.QtTypeName.In0\"/>\n"
"      <annotation value=\"ISD::LightBox::LightStatus\" name=\"org.qtproject.QtDBus.QtTypeName.Out0\"/>\n"
"    </signal>\n"
"  </interface>\n"
        "")
public:
    LightBoxAdaptor(ISD::LightBox *parent);
    ~LightBoxAdaptor() override;

    inline ISD::LightBox *parent() const
    { return static_cast<ISD::LightBox *>(QObject::parent()); }

public: // PROPERTIES
    Q_PROPERTY(ushort brightness READ brightness)
    ushort brightness() const;

    Q_PROPERTY(bool connected READ connected)
    bool connected() const;

    Q_PROPERTY(QString name READ name)
    QString name() const;

    Q_PROPERTY(int status READ status)
    int status() const;

public Q_SLOTS: // METHODS
    bool isLightOn();
    bool setBrightness(ushort val);
    bool setLightEnabled(bool enable);
Q_SIGNALS: // SIGNALS
    void Connected();
    void Disconnected();
    void newStatus(ISD::LightBox::LightStatus status);
    void ready();
};

#endif
