/********************************************************************************
** Form generated from reading UI file 'mountmodel.ui'
**
** Created by: Qt User Interface Compiler version 6.11.1
**
** WARNING! All changes made in this file will be lost when recompiling UI file!
********************************************************************************/

#ifndef UI_MOUNTMODEL_H
#define UI_MOUNTMODEL_H

#include <QtCore/QVariant>
#include <QtWidgets/QApplication>
#include <QtWidgets/QCheckBox>
#include <QtWidgets/QComboBox>
#include <QtWidgets/QDialog>
#include <QtWidgets/QGridLayout>
#include <QtWidgets/QGroupBox>
#include <QtWidgets/QHBoxLayout>
#include <QtWidgets/QHeaderView>
#include <QtWidgets/QLabel>
#include <QtWidgets/QPushButton>
#include <QtWidgets/QSpacerItem>
#include <QtWidgets/QSpinBox>
#include <QtWidgets/QTableWidget>
#include <QtWidgets/QVBoxLayout>
#include <klocalizedstring.h>

QT_BEGIN_NAMESPACE

class Ui_mountModel
{
public:
    QVBoxLayout *verticalLayout_3;
    QLabel *label;
    QGroupBox *groupBox_2;
    QGridLayout *gridLayout_2;
    QLabel *label_7;
    QComboBox *alignTypeBox;
    QPushButton *wizardAlignB;
    QSpinBox *alignDec;
    QLabel *label_6;
    QSpinBox *minAltBox;
    QLabel *label_3;
    QSpacerItem *horizontalSpacer_6;
    QLabel *label_8;
    QSpacerItem *horizontalSpacer_5;
    QSpinBox *alignPtNum;
    QSpacerItem *horizontalSpacer_3;
    QCheckBox *artificialHorizonCheck;
    QGroupBox *groupBox_3;
    QGridLayout *gridLayout;
    QLabel *label_4;
    QComboBox *starListBox;
    QSpacerItem *horizontalSpacer_4;
    QLabel *label_5;
    QComboBox *greekStarListBox;
    QGroupBox *groupBox;
    QVBoxLayout *verticalLayout_2;
    QHBoxLayout *horizontalLayout_2;
    QPushButton *clearAllAlignB;
    QPushButton *removeAlignB;
    QPushButton *addAlignB;
    QPushButton *findAlignB;
    QPushButton *sortAlignB;
    QSpacerItem *horizontalSpacer_2;
    QTableWidget *alignTable;
    QHBoxLayout *horizontalLayout;
    QPushButton *loadAlignB;
    QPushButton *saveAlignB;
    QPushButton *previewB;
    QSpacerItem *horizontalSpacer;
    QPushButton *startAlignB;
    QPushButton *stopAlignB;

    void setupUi(QDialog *mountModel)
    {
        if (mountModel->objectName().isEmpty())
            mountModel->setObjectName("mountModel");
        mountModel->resize(441, 535);
        verticalLayout_3 = new QVBoxLayout(mountModel);
        verticalLayout_3->setSpacing(3);
        verticalLayout_3->setObjectName("verticalLayout_3");
        verticalLayout_3->setContentsMargins(3, 3, 3, 3);
        label = new QLabel(mountModel);
        label->setObjectName("label");
        label->setAlignment(Qt::AlignJustify|Qt::AlignVCenter);
        label->setWordWrap(true);

        verticalLayout_3->addWidget(label);

        groupBox_2 = new QGroupBox(mountModel);
        groupBox_2->setObjectName("groupBox_2");
        gridLayout_2 = new QGridLayout(groupBox_2);
        gridLayout_2->setObjectName("gridLayout_2");
        label_7 = new QLabel(groupBox_2);
        label_7->setObjectName("label_7");

        gridLayout_2->addWidget(label_7, 2, 0, 1, 1);

        alignTypeBox = new QComboBox(groupBox_2);
        alignTypeBox->addItem(QString());
        alignTypeBox->addItem(QString());
        alignTypeBox->addItem(QString());
        alignTypeBox->addItem(QString());
        alignTypeBox->addItem(QString());
        alignTypeBox->addItem(QString());
        alignTypeBox->setObjectName("alignTypeBox");

        gridLayout_2->addWidget(alignTypeBox, 2, 1, 1, 4);

        wizardAlignB = new QPushButton(groupBox_2);
        wizardAlignB->setObjectName("wizardAlignB");
        QSizePolicy sizePolicy(QSizePolicy::Policy::Preferred, QSizePolicy::Policy::Fixed);
        sizePolicy.setHorizontalStretch(0);
        sizePolicy.setVerticalStretch(0);
        sizePolicy.setHeightForWidth(wizardAlignB->sizePolicy().hasHeightForWidth());
        wizardAlignB->setSizePolicy(sizePolicy);

        gridLayout_2->addWidget(wizardAlignB, 0, 5, 1, 1);

        alignDec = new QSpinBox(groupBox_2);
        alignDec->setObjectName("alignDec");
        alignDec->setEnabled(false);
        alignDec->setMinimum(-89);
        alignDec->setMaximum(89);

        gridLayout_2->addWidget(alignDec, 1, 4, 1, 1);

        label_6 = new QLabel(groupBox_2);
        label_6->setObjectName("label_6");

        gridLayout_2->addWidget(label_6, 1, 0, 1, 1);

        minAltBox = new QSpinBox(groupBox_2);
        minAltBox->setObjectName("minAltBox");
        minAltBox->setMaximum(80);
        minAltBox->setValue(30);

        gridLayout_2->addWidget(minAltBox, 1, 2, 1, 1);

        label_3 = new QLabel(groupBox_2);
        label_3->setObjectName("label_3");

        gridLayout_2->addWidget(label_3, 0, 0, 1, 2);

        horizontalSpacer_6 = new QSpacerItem(77, 20, QSizePolicy::Policy::Expanding, QSizePolicy::Policy::Minimum);

        gridLayout_2->addItem(horizontalSpacer_6, 2, 5, 1, 1);

        label_8 = new QLabel(groupBox_2);
        label_8->setObjectName("label_8");

        gridLayout_2->addWidget(label_8, 1, 3, 1, 1);

        horizontalSpacer_5 = new QSpacerItem(77, 20, QSizePolicy::Policy::Expanding, QSizePolicy::Policy::Minimum);

        gridLayout_2->addItem(horizontalSpacer_5, 1, 5, 1, 1);

        alignPtNum = new QSpinBox(groupBox_2);
        alignPtNum->setObjectName("alignPtNum");
        alignPtNum->setMinimum(2);

        gridLayout_2->addWidget(alignPtNum, 0, 2, 1, 1);

        horizontalSpacer_3 = new QSpacerItem(171, 20, QSizePolicy::Policy::Expanding, QSizePolicy::Policy::Minimum);

        gridLayout_2->addItem(horizontalSpacer_3, 0, 3, 1, 2);

        artificialHorizonCheck = new QCheckBox(groupBox_2);
        artificialHorizonCheck->setObjectName("artificialHorizonCheck");
        artificialHorizonCheck->setChecked(true);

        gridLayout_2->addWidget(artificialHorizonCheck, 3, 0, 1, 5);


        verticalLayout_3->addWidget(groupBox_2);

        groupBox_3 = new QGroupBox(mountModel);
        groupBox_3->setObjectName("groupBox_3");
        gridLayout = new QGridLayout(groupBox_3);
        gridLayout->setObjectName("gridLayout");
        gridLayout->setContentsMargins(3, 3, 3, 3);
        label_4 = new QLabel(groupBox_3);
        label_4->setObjectName("label_4");

        gridLayout->addWidget(label_4, 0, 0, 1, 1);

        starListBox = new QComboBox(groupBox_3);
        starListBox->setObjectName("starListBox");
        QSizePolicy sizePolicy1(QSizePolicy::Policy::MinimumExpanding, QSizePolicy::Policy::Fixed);
        sizePolicy1.setHorizontalStretch(0);
        sizePolicy1.setVerticalStretch(0);
        sizePolicy1.setHeightForWidth(starListBox->sizePolicy().hasHeightForWidth());
        starListBox->setSizePolicy(sizePolicy1);

        gridLayout->addWidget(starListBox, 0, 1, 1, 1);

        horizontalSpacer_4 = new QSpacerItem(125, 20, QSizePolicy::Policy::Expanding, QSizePolicy::Policy::Minimum);

        gridLayout->addItem(horizontalSpacer_4, 0, 2, 2, 1);

        label_5 = new QLabel(groupBox_3);
        label_5->setObjectName("label_5");

        gridLayout->addWidget(label_5, 1, 0, 1, 1);

        greekStarListBox = new QComboBox(groupBox_3);
        greekStarListBox->setObjectName("greekStarListBox");
        sizePolicy1.setHeightForWidth(greekStarListBox->sizePolicy().hasHeightForWidth());
        greekStarListBox->setSizePolicy(sizePolicy1);

        gridLayout->addWidget(greekStarListBox, 1, 1, 1, 1);


        verticalLayout_3->addWidget(groupBox_3);

        groupBox = new QGroupBox(mountModel);
        groupBox->setObjectName("groupBox");
        verticalLayout_2 = new QVBoxLayout(groupBox);
        verticalLayout_2->setObjectName("verticalLayout_2");
        verticalLayout_2->setContentsMargins(3, 3, 3, 3);
        horizontalLayout_2 = new QHBoxLayout();
        horizontalLayout_2->setSpacing(0);
        horizontalLayout_2->setObjectName("horizontalLayout_2");
        horizontalLayout_2->setContentsMargins(-1, 0, -1, -1);
        clearAllAlignB = new QPushButton(groupBox);
        clearAllAlignB->setObjectName("clearAllAlignB");
        clearAllAlignB->setMinimumSize(QSize(32, 32));
        clearAllAlignB->setMaximumSize(QSize(32, 32));

        horizontalLayout_2->addWidget(clearAllAlignB);

        removeAlignB = new QPushButton(groupBox);
        removeAlignB->setObjectName("removeAlignB");
        removeAlignB->setMinimumSize(QSize(32, 32));
        removeAlignB->setMaximumSize(QSize(32, 32));

        horizontalLayout_2->addWidget(removeAlignB);

        addAlignB = new QPushButton(groupBox);
        addAlignB->setObjectName("addAlignB");
        addAlignB->setMinimumSize(QSize(32, 32));
        addAlignB->setMaximumSize(QSize(32, 32));

        horizontalLayout_2->addWidget(addAlignB);

        findAlignB = new QPushButton(groupBox);
        findAlignB->setObjectName("findAlignB");
        findAlignB->setMinimumSize(QSize(32, 32));
        findAlignB->setMaximumSize(QSize(32, 32));

        horizontalLayout_2->addWidget(findAlignB);

        sortAlignB = new QPushButton(groupBox);
        sortAlignB->setObjectName("sortAlignB");
        sortAlignB->setMinimumSize(QSize(32, 32));
        sortAlignB->setMaximumSize(QSize(32, 32));

        horizontalLayout_2->addWidget(sortAlignB);

        horizontalSpacer_2 = new QSpacerItem(40, 20, QSizePolicy::Policy::Expanding, QSizePolicy::Policy::Minimum);

        horizontalLayout_2->addItem(horizontalSpacer_2);


        verticalLayout_2->addLayout(horizontalLayout_2);

        alignTable = new QTableWidget(groupBox);
        if (alignTable->columnCount() < 4)
            alignTable->setColumnCount(4);
        QTableWidgetItem *__qtablewidgetitem = new QTableWidgetItem();
        alignTable->setHorizontalHeaderItem(0, __qtablewidgetitem);
        QTableWidgetItem *__qtablewidgetitem1 = new QTableWidgetItem();
        alignTable->setHorizontalHeaderItem(1, __qtablewidgetitem1);
        QTableWidgetItem *__qtablewidgetitem2 = new QTableWidgetItem();
        alignTable->setHorizontalHeaderItem(2, __qtablewidgetitem2);
        QTableWidgetItem *__qtablewidgetitem3 = new QTableWidgetItem();
        alignTable->setHorizontalHeaderItem(3, __qtablewidgetitem3);
        alignTable->setObjectName("alignTable");

        verticalLayout_2->addWidget(alignTable);


        verticalLayout_3->addWidget(groupBox);

        horizontalLayout = new QHBoxLayout();
        horizontalLayout->setSpacing(0);
        horizontalLayout->setObjectName("horizontalLayout");
        loadAlignB = new QPushButton(mountModel);
        loadAlignB->setObjectName("loadAlignB");
        loadAlignB->setMinimumSize(QSize(32, 32));
        loadAlignB->setMaximumSize(QSize(32, 32));

        horizontalLayout->addWidget(loadAlignB);

        saveAlignB = new QPushButton(mountModel);
        saveAlignB->setObjectName("saveAlignB");
        saveAlignB->setMinimumSize(QSize(32, 32));
        saveAlignB->setMaximumSize(QSize(32, 32));

        horizontalLayout->addWidget(saveAlignB);

        previewB = new QPushButton(mountModel);
        previewB->setObjectName("previewB");
        previewB->setMinimumSize(QSize(32, 32));
        previewB->setMaximumSize(QSize(32, 32));

        horizontalLayout->addWidget(previewB);

        horizontalSpacer = new QSpacerItem(40, 20, QSizePolicy::Policy::Expanding, QSizePolicy::Policy::Minimum);

        horizontalLayout->addItem(horizontalSpacer);

        startAlignB = new QPushButton(mountModel);
        startAlignB->setObjectName("startAlignB");
        startAlignB->setMinimumSize(QSize(32, 32));
        startAlignB->setMaximumSize(QSize(32, 32));

        horizontalLayout->addWidget(startAlignB);

        stopAlignB = new QPushButton(mountModel);
        stopAlignB->setObjectName("stopAlignB");
        stopAlignB->setMinimumSize(QSize(32, 32));
        stopAlignB->setMaximumSize(QSize(32, 32));

        horizontalLayout->addWidget(stopAlignB);


        verticalLayout_3->addLayout(horizontalLayout);


        retranslateUi(mountModel);

        QMetaObject::connectSlotsByName(mountModel);
    } // setupUi

    void retranslateUi(QDialog *mountModel)
    {
        mountModel->setWindowTitle(tr2i18n("Dialog", nullptr));
        label->setText(tr2i18n("<p>This tool can help your mount build a better pointing model by moving the mount to different points in the sky and solving captured images. This can increase the accuracy of your GOTOs. To qualify, your mount must be capable of improving its internal pointing model after each <b>Sync</b>  commanded by Ekos. If this is not the case, then this tool is not suitable for your mount.</p>", nullptr));
        groupBox_2->setTitle(tr2i18n("Mount Model Wizard", nullptr));
        label_7->setText(tr2i18n("Object Type:", nullptr));
        alignTypeBox->setItemText(0, tr2i18n("Any Stars", nullptr));
        alignTypeBox->setItemText(1, tr2i18n("Named Stars", nullptr));
        alignTypeBox->setItemText(2, tr2i18n("Any Object", nullptr));
        alignTypeBox->setItemText(3, tr2i18n("Uniform Distribution", nullptr));
        alignTypeBox->setItemText(4, tr2i18n("Fixed DEC", nullptr));
        alignTypeBox->setItemText(5, tr2i18n("Fixed Grid", nullptr));

#if QT_CONFIG(tooltip)
        alignTypeBox->setToolTip(tr2i18n("<html><head/><body><p>Select how the wizard chooses alignment points.</p>\n"
"<p>All modes except Fixed DEC and Fixed Grid spread points evenly across the sky using uniform distribution. The modes differ in what each point snaps to:</p>\n"
"<ul>\n"
"<li><b>Any Stars:</b> Snaps to the nearest visible star.</li>\n"
"<li><b>Named Stars:</b> Snaps to a well-known named star (e.g. Vega, Arcturus).</li>\n"
"<li><b>Any Object:</b> Snaps to the nearest visible object of any type.</li>\n"
"<li><b>Uniform Distribution:</b> Points are spread evenly across the visible sky.</li>\n"
"<li><b>Fixed DEC:</b> All points share the same declination (set below).</li>\n"
"<li><b>Fixed Grid:</b> Points arranged in a regular RA/DEC grid, evenly spaced in RA and DEC.</li>\n"
"</ul>\n"
"</body></html>", nullptr));
#endif // QT_CONFIG(tooltip)
#if QT_CONFIG(tooltip)
        wizardAlignB->setToolTip(tr2i18n("Automatically generate the specified number of alignment points in the table below. They will be generated based on the options selected in this wizard.", nullptr));
#endif // QT_CONFIG(tooltip)
        wizardAlignB->setText(tr2i18n("Generate", nullptr));
#if QT_CONFIG(tooltip)
        alignDec->setToolTip(tr2i18n("The Declination of the points that will be generated.  This option only applies to the Fixed DEC Option.", nullptr));
#endif // QT_CONFIG(tooltip)
        label_6->setText(tr2i18n("Minimum Alt:", nullptr));
#if QT_CONFIG(tooltip)
        minAltBox->setToolTip(tr2i18n("This is the minimum altitude above the horizon to use in generating points with the wizard.", nullptr));
#endif // QT_CONFIG(tooltip)
        label_3->setText(tr2i18n("Alignment Points:", nullptr));
        label_8->setText(tr2i18n("Declination:", nullptr));
#if QT_CONFIG(tooltip)
        alignPtNum->setToolTip(tr2i18n("The Number of points the wizard should generate. If this number is less than 5, it will generate them at the same DEC. After that they will be evenly distributed over RA and DEC. Note, if Fixed DEC is selected, all of the points will be at the same DEC.", nullptr));
#endif // QT_CONFIG(tooltip)
#if QT_CONFIG(tooltip)
        artificialHorizonCheck->setToolTip(tr2i18n("Skip generated points that are below the artificial horizon, if any are defined and enabled. See the artificial horizon item in the KStars Settings menu.", nullptr));
#endif // QT_CONFIG(tooltip)
        artificialHorizonCheck->setText(tr2i18n("Artificial Horizon", nullptr));
        groupBox_3->setTitle(tr2i18n("Add Currently Visible Stars", nullptr));
        label_4->setText(tr2i18n("Common Names:", nullptr));
#if QT_CONFIG(tooltip)
        starListBox->setToolTip(tr2i18n("These are the common names for the named stars that are currently up at your location.  If you select a star, it will be added to the table below.", nullptr));
#endif // QT_CONFIG(tooltip)
        label_5->setText(tr2i18n("Greek:", nullptr));
#if QT_CONFIG(tooltip)
        greekStarListBox->setToolTip(tr2i18n("These are the Greek names for the brighter stars that are currently up at your location.  If you select a star, it will be added to the table below.", nullptr));
#endif // QT_CONFIG(tooltip)
        groupBox->setTitle(tr2i18n("Mount Model Alignment Points", nullptr));
#if QT_CONFIG(tooltip)
        clearAllAlignB->setToolTip(tr2i18n("Clear the entire table of alignment points below.  Note that this will not affect your mount in any way.  It will not clear your pointing model.  It just clears the list of points so that if you run the mount model routine again, these points will not be included.", nullptr));
#endif // QT_CONFIG(tooltip)
        clearAllAlignB->setText(QString());
#if QT_CONFIG(tooltip)
        removeAlignB->setToolTip(tr2i18n("<p>Remove the selected row from the alignment point table below. Note that it does <b>not</b> command your mount to clear that point from the model, it just means that if you run the mount model routine, that point will not be included in the list.</p>", nullptr));
#endif // QT_CONFIG(tooltip)
        removeAlignB->setText(QString());
#if QT_CONFIG(tooltip)
        addAlignB->setToolTip(tr2i18n("Add an empty row to the alignment list so that you can manually add an RA and DE for a position you would like the telescope to slew to when doing the mount model routine.", nullptr));
#endif // QT_CONFIG(tooltip)
        addAlignB->setText(QString());
#if QT_CONFIG(tooltip)
        findAlignB->setToolTip(tr2i18n("Open the Find Object dialog so that you can select an object to get an RA and DEC automatically that you would like the telescope to slew to when doing the mount model routine.", nullptr));
#endif // QT_CONFIG(tooltip)
        findAlignB->setText(QString());
#if QT_CONFIG(tooltip)
        sortAlignB->setToolTip(tr2i18n("Sort the alignment points, starting with the point closest to the current telescope position, to try to minimize the distance between each slew.", nullptr));
#endif // QT_CONFIG(tooltip)
        sortAlignB->setText(QString());
        QTableWidgetItem *___qtablewidgetitem = alignTable->horizontalHeaderItem(0);
        ___qtablewidgetitem->setText(tr2i18n("RA (J2000)", nullptr));
        QTableWidgetItem *___qtablewidgetitem1 = alignTable->horizontalHeaderItem(1);
        ___qtablewidgetitem1->setText(tr2i18n("DEC (J2000)", nullptr));
        QTableWidgetItem *___qtablewidgetitem2 = alignTable->horizontalHeaderItem(2);
        ___qtablewidgetitem2->setText(tr2i18n("Object", nullptr));
        QTableWidgetItem *___qtablewidgetitem3 = alignTable->horizontalHeaderItem(3);
        ___qtablewidgetitem3->setText(tr2i18n("~~", nullptr));
#if QT_CONFIG(tooltip)
        alignTable->setToolTip(tr2i18n("This is a table of alignment points that you would like the mount model routine to use in aligning your telescope.  If you would like to add or remove points, you may use the buttons above.  If you would like to run, pause, or stop the mount model routine, you may use the buttons below.  You can directly edit an RA or DE for a particular point directly in the cells.  Just be sure to follow the format hh:mm:ss. The object name is just provided for convenience and is not used.  If you want to change the order of the alignment points, you can drag the row up or down using the vertical header for that row on the left.", nullptr));
#endif // QT_CONFIG(tooltip)
#if QT_CONFIG(tooltip)
        loadAlignB->setToolTip(tr2i18n("Load a saved alignment point list so that you can run the same alignment you ran on a previous occasion.", nullptr));
#endif // QT_CONFIG(tooltip)
        loadAlignB->setText(QString());
#if QT_CONFIG(tooltip)
        saveAlignB->setToolTip(tr2i18n("Save the alignment list so that you can run this alignment again in the future.", nullptr));
#endif // QT_CONFIG(tooltip)
        saveAlignB->setText(QString());
#if QT_CONFIG(tooltip)
        previewB->setToolTip(tr2i18n("Display the alignment points on the skymap as flags.  Clicking it again will remove the flags.  The flags will not be saved.", nullptr));
#endif // QT_CONFIG(tooltip)
        previewB->setText(QString());
#if QT_CONFIG(tooltip)
        startAlignB->setToolTip(tr2i18n("Start or pause the mount model routine.  It will slew to and astrometrically solve the list of points in the table above using the settings in the align module.  If the routine was previously paused, it will pick up where it left off.  If it was stopped or it had finished it will start the routine over again.", nullptr));
#endif // QT_CONFIG(tooltip)
        startAlignB->setText(QString());
#if QT_CONFIG(tooltip)
        stopAlignB->setToolTip(tr2i18n("<p>Stop the mount model routine.  It will <b>not</b> clear any points from your telescope's pointing model.  It will stop the routine and any points currently being solved. If you run the mount model again after hitting stop, it will start the routine over again with the first point.</p>", nullptr));
#endif // QT_CONFIG(tooltip)
        stopAlignB->setText(QString());
    } // retranslateUi

};

namespace Ui {
    class mountModel: public Ui_mountModel {};
} // namespace Ui

QT_END_NAMESPACE

#endif // MOUNTMODEL_H

