/********************************************************************************
** Form generated from reading UI file 'addlinkdialog.ui'
**
** Created by: Qt User Interface Compiler version 6.11.1
**
** WARNING! All changes made in this file will be lost when recompiling UI file!
********************************************************************************/

#ifndef UI_ADDLINKDIALOG_H
#define UI_ADDLINKDIALOG_H

#include <QtCore/QVariant>
#include <QtWidgets/QApplication>
#include <QtWidgets/QGridLayout>
#include <QtWidgets/QGroupBox>
#include <QtWidgets/QHBoxLayout>
#include <QtWidgets/QLabel>
#include <QtWidgets/QLineEdit>
#include <QtWidgets/QPushButton>
#include <QtWidgets/QRadioButton>
#include <QtWidgets/QSpacerItem>
#include <QtWidgets/QVBoxLayout>
#include <QtWidgets/QWidget>
#include <klocalizedstring.h>

QT_BEGIN_NAMESPACE

class Ui_AddLinkDialog
{
public:
    QVBoxLayout *vboxLayout;
    QGroupBox *TypeBox;
    QHBoxLayout *hboxLayout;
    QRadioButton *ImageRadio;
    QRadioButton *InfoRadio;
    QGridLayout *gridLayout;
    QLineEdit *DescBox;
    QLabel *DescLabel;
    QLabel *URLLabel;
    QLineEdit *URLBox;
    QHBoxLayout *hboxLayout1;
    QSpacerItem *spacerItem;
    QPushButton *URLButton;
    QSpacerItem *spacerItem1;

    void setupUi(QWidget *AddLinkDialog)
    {
        if (AddLinkDialog->objectName().isEmpty())
            AddLinkDialog->setObjectName("AddLinkDialog");
        AddLinkDialog->resize(556, 201);
        vboxLayout = new QVBoxLayout(AddLinkDialog);
#ifndef UI_Q_OS_MAC
        vboxLayout->setSpacing(6);
#endif
        vboxLayout->setContentsMargins(10, 10, 10, 10);
        vboxLayout->setObjectName("vboxLayout");
        TypeBox = new QGroupBox(AddLinkDialog);
        TypeBox->setObjectName("TypeBox");
        hboxLayout = new QHBoxLayout(TypeBox);
#ifndef UI_Q_OS_MAC
        hboxLayout->setSpacing(6);
#endif
        hboxLayout->setContentsMargins(10, 10, 10, 10);
        hboxLayout->setObjectName("hboxLayout");
        ImageRadio = new QRadioButton(TypeBox);
        ImageRadio->setObjectName("ImageRadio");

        hboxLayout->addWidget(ImageRadio);

        InfoRadio = new QRadioButton(TypeBox);
        InfoRadio->setObjectName("InfoRadio");

        hboxLayout->addWidget(InfoRadio);


        vboxLayout->addWidget(TypeBox);

        gridLayout = new QGridLayout();
#ifndef UI_Q_OS_MAC
        gridLayout->setSpacing(6);
#endif
        gridLayout->setContentsMargins(0, 0, 0, 0);
        gridLayout->setObjectName("gridLayout");
        DescBox = new QLineEdit(AddLinkDialog);
        DescBox->setObjectName("DescBox");

        gridLayout->addWidget(DescBox, 0, 1, 1, 1);

        DescLabel = new QLabel(AddLinkDialog);
        DescLabel->setObjectName("DescLabel");

        gridLayout->addWidget(DescLabel, 0, 0, 1, 1);

        URLLabel = new QLabel(AddLinkDialog);
        URLLabel->setObjectName("URLLabel");

        gridLayout->addWidget(URLLabel, 1, 0, 1, 1);

        URLBox = new QLineEdit(AddLinkDialog);
        URLBox->setObjectName("URLBox");
        QSizePolicy sizePolicy(QSizePolicy::Policy::Preferred, QSizePolicy::Policy::Fixed);
        sizePolicy.setHorizontalStretch(0);
        sizePolicy.setVerticalStretch(0);
        sizePolicy.setHeightForWidth(URLBox->sizePolicy().hasHeightForWidth());
        URLBox->setSizePolicy(sizePolicy);
        URLBox->setMinimumSize(QSize(450, 0));

        gridLayout->addWidget(URLBox, 1, 1, 1, 1);


        vboxLayout->addLayout(gridLayout);

        hboxLayout1 = new QHBoxLayout();
#ifndef UI_Q_OS_MAC
        hboxLayout1->setSpacing(6);
#endif
        hboxLayout1->setContentsMargins(0, 0, 0, 0);
        hboxLayout1->setObjectName("hboxLayout1");
        spacerItem = new QSpacerItem(40, 20, QSizePolicy::Policy::Expanding, QSizePolicy::Policy::Minimum);

        hboxLayout1->addItem(spacerItem);

        URLButton = new QPushButton(AddLinkDialog);
        URLButton->setObjectName("URLButton");

        hboxLayout1->addWidget(URLButton);


        vboxLayout->addLayout(hboxLayout1);

        spacerItem1 = new QSpacerItem(20, 40, QSizePolicy::Policy::Minimum, QSizePolicy::Policy::Expanding);

        vboxLayout->addItem(spacerItem1);


        retranslateUi(AddLinkDialog);

        QMetaObject::connectSlotsByName(AddLinkDialog);
    } // setupUi

    void retranslateUi(QWidget *AddLinkDialog)
    {
        TypeBox->setTitle(tr2i18n("Resource Type", nullptr));
        ImageRadio->setText(tr2i18n("Image", nullptr));
        InfoRadio->setText(tr2i18n("Information", nullptr));
#if QT_CONFIG(tooltip)
        DescBox->setToolTip(tr2i18n("Text describing the linked resource", nullptr));
#endif // QT_CONFIG(tooltip)
        DescLabel->setText(tr2i18n("Description:", nullptr));
        URLLabel->setText(tr2i18n("URL:", nullptr));
#if QT_CONFIG(tooltip)
        URLBox->setToolTip(tr2i18n("The URL which will be displayed by this item", nullptr));
#endif // QT_CONFIG(tooltip)
#if QT_CONFIG(tooltip)
        URLButton->setToolTip(tr2i18n("Open URL in a browser window", nullptr));
#endif // QT_CONFIG(tooltip)
#if QT_CONFIG(whatsthis)
        URLButton->setWhatsThis(tr2i18n("You can verify the entered URL by opening it in a browser window with this button", nullptr));
#endif // QT_CONFIG(whatsthis)
        URLButton->setText(tr2i18n("Check URL", nullptr));
        (void)AddLinkDialog;
    } // retranslateUi

};

namespace Ui {
    class AddLinkDialog: public Ui_AddLinkDialog {};
} // namespace Ui

QT_END_NAMESPACE

#endif // ADDLINKDIALOG_H

