/********************************************************************************
** Form generated from reading UI file 'modcalcaltaz.ui'
**
** Created by: Qt User Interface Compiler version 6.11.1
**
** WARNING! All changes made in this file will be lost when recompiling UI file!
********************************************************************************/

#ifndef UI_MODCALCALTAZ_H
#define UI_MODCALCALTAZ_H

#include <QtCore/QVariant>
#include <QtWidgets/QApplication>
#include <QtWidgets/QDateTimeEdit>
#include <QtWidgets/QGridLayout>
#include <QtWidgets/QGroupBox>
#include <QtWidgets/QHBoxLayout>
#include <QtWidgets/QLabel>
#include <QtWidgets/QLineEdit>
#include <QtWidgets/QPushButton>
#include <QtWidgets/QSpacerItem>
#include <QtWidgets/QTabWidget>
#include <QtWidgets/QVBoxLayout>
#include <QtWidgets/QWidget>
#include <klocalizedstring.h>
#include "widgets/dmsbox.h"

QT_BEGIN_NAMESPACE

class Ui_modCalcAltAz
{
public:
    QVBoxLayout *vboxLayout;
    QTabWidget *tabWidget3;
    QWidget *interact;
    QVBoxLayout *vboxLayout1;
    QGridLayout *gridLayout;
    QHBoxLayout *hboxLayout;
    QDateTimeEdit *DateTime;
    QPushButton *NowButton;
    QLabel *LocationLabel;
    QPushButton *LocationButton;
    QLabel *DateLabel;
    QSpacerItem *spacerItem;
    QHBoxLayout *hboxLayout1;
    QGroupBox *groupBox_3;
    QGridLayout *gridLayout1;
    QSpacerItem *spacerItem1;
    QPushButton *ObjectButton;
    dmsBox *Dec;
    dmsBox *RA;
    QLabel *decLabel;
    QLabel *raLabel;
    QGroupBox *groupBox_4;
    QVBoxLayout *vboxLayout2;
    QGridLayout *gridLayout2;
    dmsBox *Alt;
    dmsBox *Az;
    QLabel *azLabel;
    QLabel *elLabel;
    QSpacerItem *spacerItem2;
    QSpacerItem *spacerItem3;

    void setupUi(QWidget *modCalcAltAz)
    {
        if (modCalcAltAz->objectName().isEmpty())
            modCalcAltAz->setObjectName("modCalcAltAz");
        modCalcAltAz->setEnabled(true);
        modCalcAltAz->resize(528, 544);
        vboxLayout = new QVBoxLayout(modCalcAltAz);
        vboxLayout->setSpacing(6);
        vboxLayout->setObjectName("vboxLayout");
        vboxLayout->setContentsMargins(9, 9, 9, 9);
        tabWidget3 = new QTabWidget(modCalcAltAz);
        tabWidget3->setObjectName("tabWidget3");
        interact = new QWidget();
        interact->setObjectName("interact");
        vboxLayout1 = new QVBoxLayout(interact);
        vboxLayout1->setSpacing(6);
        vboxLayout1->setObjectName("vboxLayout1");
        vboxLayout1->setContentsMargins(9, 9, 9, 9);
        gridLayout = new QGridLayout();
        gridLayout->setSpacing(6);
        gridLayout->setObjectName("gridLayout");
        gridLayout->setContentsMargins(0, 0, 0, 0);
        hboxLayout = new QHBoxLayout();
        hboxLayout->setSpacing(6);
        hboxLayout->setObjectName("hboxLayout");
        hboxLayout->setContentsMargins(0, 0, 0, 0);
        DateTime = new QDateTimeEdit(interact);
        DateTime->setObjectName("DateTime");

        hboxLayout->addWidget(DateTime);

        NowButton = new QPushButton(interact);
        NowButton->setObjectName("NowButton");

        hboxLayout->addWidget(NowButton);


        gridLayout->addLayout(hboxLayout, 0, 1, 1, 1);

        LocationLabel = new QLabel(interact);
        LocationLabel->setObjectName("LocationLabel");

        gridLayout->addWidget(LocationLabel, 1, 0, 1, 1);

        LocationButton = new QPushButton(interact);
        LocationButton->setObjectName("LocationButton");

        gridLayout->addWidget(LocationButton, 1, 1, 1, 1);

        DateLabel = new QLabel(interact);
        DateLabel->setObjectName("DateLabel");

        gridLayout->addWidget(DateLabel, 0, 0, 1, 1);


        vboxLayout1->addLayout(gridLayout);

        spacerItem = new QSpacerItem(411, 20, QSizePolicy::Policy::Expanding, QSizePolicy::Policy::Minimum);

        vboxLayout1->addItem(spacerItem);

        hboxLayout1 = new QHBoxLayout();
        hboxLayout1->setSpacing(6);
        hboxLayout1->setObjectName("hboxLayout1");
        hboxLayout1->setContentsMargins(0, 0, 0, 0);
        groupBox_3 = new QGroupBox(interact);
        groupBox_3->setObjectName("groupBox_3");
        gridLayout1 = new QGridLayout(groupBox_3);
        gridLayout1->setSpacing(6);
        gridLayout1->setObjectName("gridLayout1");
        gridLayout1->setContentsMargins(9, 9, 9, 9);
        spacerItem1 = new QSpacerItem(40, 20, QSizePolicy::Policy::Expanding, QSizePolicy::Policy::Minimum);

        gridLayout1->addItem(spacerItem1, 2, 0, 1, 1);

        ObjectButton = new QPushButton(groupBox_3);
        ObjectButton->setObjectName("ObjectButton");

        gridLayout1->addWidget(ObjectButton, 2, 1, 1, 1);

        Dec = new dmsBox(groupBox_3);
        Dec->setObjectName("Dec");
        Dec->setMinimumSize(QSize(100, 0));
        Dec->setFocusPolicy(Qt::StrongFocus);

        gridLayout1->addWidget(Dec, 1, 1, 1, 1);

        RA = new dmsBox(groupBox_3);
        RA->setObjectName("RA");
        RA->setEnabled(true);
        RA->setMinimumSize(QSize(100, 0));
        RA->setFocusPolicy(Qt::StrongFocus);

        gridLayout1->addWidget(RA, 0, 1, 1, 1);

        decLabel = new QLabel(groupBox_3);
        decLabel->setObjectName("decLabel");

        gridLayout1->addWidget(decLabel, 1, 0, 1, 1);

        raLabel = new QLabel(groupBox_3);
        raLabel->setObjectName("raLabel");

        gridLayout1->addWidget(raLabel, 0, 0, 1, 1);


        hboxLayout1->addWidget(groupBox_3);

        groupBox_4 = new QGroupBox(interact);
        groupBox_4->setObjectName("groupBox_4");
        vboxLayout2 = new QVBoxLayout(groupBox_4);
        vboxLayout2->setSpacing(6);
        vboxLayout2->setObjectName("vboxLayout2");
        vboxLayout2->setContentsMargins(8, 8, 8, 8);
        gridLayout2 = new QGridLayout();
        gridLayout2->setSpacing(6);
        gridLayout2->setObjectName("gridLayout2");
        gridLayout2->setContentsMargins(0, 0, 0, 0);
        Alt = new dmsBox(groupBox_4);
        Alt->setObjectName("Alt");
        Alt->setMinimumSize(QSize(100, 0));
        Alt->setFocusPolicy(Qt::StrongFocus);

        gridLayout2->addWidget(Alt, 1, 1, 1, 1);

        Az = new dmsBox(groupBox_4);
        Az->setObjectName("Az");
        Az->setMinimumSize(QSize(100, 0));
        Az->setFocusPolicy(Qt::StrongFocus);

        gridLayout2->addWidget(Az, 0, 1, 1, 1);

        azLabel = new QLabel(groupBox_4);
        azLabel->setObjectName("azLabel");

        gridLayout2->addWidget(azLabel, 0, 0, 1, 1);

        elLabel = new QLabel(groupBox_4);
        elLabel->setObjectName("elLabel");

        gridLayout2->addWidget(elLabel, 1, 0, 1, 1);


        vboxLayout2->addLayout(gridLayout2);

        spacerItem2 = new QSpacerItem(20, 20, QSizePolicy::Policy::Minimum, QSizePolicy::Policy::Fixed);

        vboxLayout2->addItem(spacerItem2);


        hboxLayout1->addWidget(groupBox_4);


        vboxLayout1->addLayout(hboxLayout1);

        spacerItem3 = new QSpacerItem(20, 37, QSizePolicy::Policy::Minimum, QSizePolicy::Policy::Expanding);

        vboxLayout1->addItem(spacerItem3);

        tabWidget3->addTab(interact, QString());

        vboxLayout->addWidget(tabWidget3);

        QWidget::setTabOrder(tabWidget3, NowButton);
        QWidget::setTabOrder(NowButton, LocationButton);
        QWidget::setTabOrder(LocationButton, RA);
        QWidget::setTabOrder(RA, Dec);
        QWidget::setTabOrder(Dec, ObjectButton);
        QWidget::setTabOrder(ObjectButton, Az);
        QWidget::setTabOrder(Az, Alt);

        retranslateUi(modCalcAltAz);

        tabWidget3->setCurrentIndex(0);


        QMetaObject::connectSlotsByName(modCalcAltAz);
    } // setupUi

    void retranslateUi(QWidget *modCalcAltAz)
    {
        modCalcAltAz->setWindowTitle(tr2i18n("Horizontal Coordinates", nullptr));
        NowButton->setText(tr2i18n("Now", nullptr));
        LocationLabel->setText(tr2i18n("Location:", nullptr));
        LocationButton->setText(tr2i18n("Greenwich, United Kingdom", nullptr));
        DateLabel->setText(tr2i18n("Date and time:", nullptr));
        groupBox_3->setTitle(tr2i18n("Equatorial Coordinates (J2000)", nullptr));
        ObjectButton->setText(tr2i18n("Select Object...", nullptr));
        decLabel->setText(tr2i18n("Declination:", nullptr));
        raLabel->setText(tr2i18n("Right ascension:", nullptr));
        groupBox_4->setTitle(tr2i18n("Horizontal Coordinates", nullptr));
        azLabel->setText(tr2i18n("Azimuth:", nullptr));
        elLabel->setText(tr2i18n("Altitude:", nullptr));
        tabWidget3->setTabText(tabWidget3->indexOf(interact), tr2i18n("Interactive Mode", nullptr));
    } // retranslateUi

};

namespace Ui {
    class modCalcAltAz: public Ui_modCalcAltAz {};
} // namespace Ui

QT_END_NAMESPACE

#endif // MODCALCALTAZ_H

