/****************************************************************************
** Meta object code from reading C++ file 'media.h'
**
** Created by: The Qt Meta Object Compiler version 69 (Qt 6.11.1)
**
** WARNING! All changes made in this file will be lost!
*****************************************************************************/

#include "../../../../kstars-3.8.4.1/kstars/ekos/ekoslive/media.h"
#include <QtNetwork/QSslError>
#include <QtDataVisualization/qbar3dseries.h>
#include <QtDataVisualization/q3dscene.h>
#include <QtGui/qtextcursor.h>
#include <QtCore/qmetatype.h>
#include <QtCore/QSharedPointer>

#include <QtCore/qtmochelpers.h>

#include <memory>


#include <QtCore/qxptype_traits.h>
#if !defined(Q_MOC_OUTPUT_REVISION)
#error "The header file 'media.h' doesn't include <QObject>."
#elif Q_MOC_OUTPUT_REVISION != 69
#error "This file was generated using the moc from 6.11.1. It"
#error "cannot be used with the include files from this version of Qt."
#error "(The moc has changed too much.)"
#endif

#ifndef Q_CONSTINIT
#define Q_CONSTINIT
#endif

QT_WARNING_PUSH
QT_WARNING_DISABLE_DEPRECATED
QT_WARNING_DISABLE_GCC("-Wuseless-cast")
namespace {
struct qt_meta_tag_ZN8EkosLive5MediaE_t {};
} // unnamed namespace

template <> constexpr inline auto EkosLive::Media::qt_create_metaobjectdata<qt_meta_tag_ZN8EkosLive5MediaE_t>()
{
    namespace QMC = QtMocConstants;
    QtMocHelpers::StringRefStorage qt_stringData {
        "EkosLive::Media",
        "connected",
        "",
        "disconnected",
        "globalLogoutTriggered",
        "QUrl",
        "url",
        "newBoundingRect",
        "QRect",
        "rect",
        "QSize",
        "view",
        "currentZoom",
        "newImage",
        "image",
        "uuid",
        "sendVideoFrame",
        "QSharedPointer<QImage>",
        "frame",
        "setLiveStackingActive",
        "active",
        "setCorrectionVector",
        "QLineF",
        "correctionVector",
        "resetPolarView",
        "processNewBLOB",
        "IBLOB*",
        "bp",
        "onConnected",
        "onDisconnected",
        "onTextReceived",
        "message",
        "onBinaryReceived",
        "uploadImage"
    };

    QtMocHelpers::UintData qt_methods {
        // Signal 'connected'
        QtMocHelpers::SignalData<void()>(1, 2, QMC::AccessPublic, QMetaType::Void),
        // Signal 'disconnected'
        QtMocHelpers::SignalData<void()>(3, 2, QMC::AccessPublic, QMetaType::Void),
        // Signal 'globalLogoutTriggered'
        QtMocHelpers::SignalData<void(const QUrl &)>(4, 2, QMC::AccessPublic, QMetaType::Void, {{
            { 0x80000000 | 5, 6 },
        }}),
        // Signal 'newBoundingRect'
        QtMocHelpers::SignalData<void(QRect, QSize, double)>(7, 2, QMC::AccessPublic, QMetaType::Void, {{
            { 0x80000000 | 8, 9 }, { 0x80000000 | 10, 11 }, { QMetaType::Double, 12 },
        }}),
        // Signal 'newImage'
        QtMocHelpers::SignalData<void(const QByteArray &, const QString &)>(13, 2, QMC::AccessPublic, QMetaType::Void, {{
            { QMetaType::QByteArray, 14 }, { QMetaType::QString, 15 },
        }}),
        // Slot 'sendVideoFrame'
        QtMocHelpers::SlotData<void(const QSharedPointer<QImage> &)>(16, 2, QMC::AccessPublic, QMetaType::Void, {{
            { 0x80000000 | 17, 18 },
        }}),
        // Slot 'setLiveStackingActive'
        QtMocHelpers::SlotData<void(bool)>(19, 2, QMC::AccessPublic, QMetaType::Void, {{
            { QMetaType::Bool, 20 },
        }}),
        // Slot 'setCorrectionVector'
        QtMocHelpers::SlotData<void(QLineF)>(21, 2, QMC::AccessPublic, QMetaType::Void, {{
            { 0x80000000 | 22, 23 },
        }}),
        // Slot 'resetPolarView'
        QtMocHelpers::SlotData<void()>(24, 2, QMC::AccessPublic, QMetaType::Void),
        // Slot 'processNewBLOB'
        QtMocHelpers::SlotData<void(IBLOB *)>(25, 2, QMC::AccessPublic, QMetaType::Void, {{
            { 0x80000000 | 26, 27 },
        }}),
        // Slot 'onConnected'
        QtMocHelpers::SlotData<void()>(28, 2, QMC::AccessPrivate, QMetaType::Void),
        // Slot 'onDisconnected'
        QtMocHelpers::SlotData<void()>(29, 2, QMC::AccessPrivate, QMetaType::Void),
        // Slot 'onTextReceived'
        QtMocHelpers::SlotData<void(const QString &)>(30, 2, QMC::AccessPrivate, QMetaType::Void, {{
            { QMetaType::QString, 31 },
        }}),
        // Slot 'onBinaryReceived'
        QtMocHelpers::SlotData<void(const QByteArray &)>(32, 2, QMC::AccessPrivate, QMetaType::Void, {{
            { QMetaType::QByteArray, 31 },
        }}),
        // Slot 'uploadImage'
        QtMocHelpers::SlotData<void(const QByteArray &, const QString &)>(33, 2, QMC::AccessPrivate, QMetaType::Void, {{
            { QMetaType::QByteArray, 14 }, { QMetaType::QString, 15 },
        }}),
    };
    QtMocHelpers::UintData qt_properties {
    };
    QtMocHelpers::UintData qt_enums {
    };
    return QtMocHelpers::metaObjectData<Media, qt_meta_tag_ZN8EkosLive5MediaE_t>(QMC::MetaObjectFlag{}, qt_stringData,
            qt_methods, qt_properties, qt_enums);
}
Q_CONSTINIT const QMetaObject EkosLive::Media::staticMetaObject = { {
    QMetaObject::SuperData::link<QObject::staticMetaObject>(),
    qt_staticMetaObjectStaticContent<qt_meta_tag_ZN8EkosLive5MediaE_t>.stringdata,
    qt_staticMetaObjectStaticContent<qt_meta_tag_ZN8EkosLive5MediaE_t>.data,
    qt_static_metacall,
    nullptr,
    qt_staticMetaObjectRelocatingContent<qt_meta_tag_ZN8EkosLive5MediaE_t>.metaTypes,
    nullptr
} };

void EkosLive::Media::qt_static_metacall(QObject *_o, QMetaObject::Call _c, int _id, void **_a)
{
    auto *_t = static_cast<Media *>(_o);
    if (_c == QMetaObject::InvokeMetaMethod) {
        switch (_id) {
        case 0: _t->connected(); break;
        case 1: _t->disconnected(); break;
        case 2: _t->globalLogoutTriggered((*reinterpret_cast<std::add_pointer_t<QUrl>>(_a[1]))); break;
        case 3: _t->newBoundingRect((*reinterpret_cast<std::add_pointer_t<QRect>>(_a[1])),(*reinterpret_cast<std::add_pointer_t<QSize>>(_a[2])),(*reinterpret_cast<std::add_pointer_t<double>>(_a[3]))); break;
        case 4: _t->newImage((*reinterpret_cast<std::add_pointer_t<QByteArray>>(_a[1])),(*reinterpret_cast<std::add_pointer_t<QString>>(_a[2]))); break;
        case 5: _t->sendVideoFrame((*reinterpret_cast<std::add_pointer_t<QSharedPointer<QImage>>>(_a[1]))); break;
        case 6: _t->setLiveStackingActive((*reinterpret_cast<std::add_pointer_t<bool>>(_a[1]))); break;
        case 7: _t->setCorrectionVector((*reinterpret_cast<std::add_pointer_t<QLineF>>(_a[1]))); break;
        case 8: _t->resetPolarView(); break;
        case 9: _t->processNewBLOB((*reinterpret_cast<std::add_pointer_t<IBLOB*>>(_a[1]))); break;
        case 10: _t->onConnected(); break;
        case 11: _t->onDisconnected(); break;
        case 12: _t->onTextReceived((*reinterpret_cast<std::add_pointer_t<QString>>(_a[1]))); break;
        case 13: _t->onBinaryReceived((*reinterpret_cast<std::add_pointer_t<QByteArray>>(_a[1]))); break;
        case 14: _t->uploadImage((*reinterpret_cast<std::add_pointer_t<QByteArray>>(_a[1])),(*reinterpret_cast<std::add_pointer_t<QString>>(_a[2]))); break;
        default: ;
        }
    }
    if (_c == QMetaObject::IndexOfMethod) {
        if (QtMocHelpers::indexOfMethod<void (Media::*)()>(_a, &Media::connected, 0))
            return;
        if (QtMocHelpers::indexOfMethod<void (Media::*)()>(_a, &Media::disconnected, 1))
            return;
        if (QtMocHelpers::indexOfMethod<void (Media::*)(const QUrl & )>(_a, &Media::globalLogoutTriggered, 2))
            return;
        if (QtMocHelpers::indexOfMethod<void (Media::*)(QRect , QSize , double )>(_a, &Media::newBoundingRect, 3))
            return;
        if (QtMocHelpers::indexOfMethod<void (Media::*)(const QByteArray & , const QString & )>(_a, &Media::newImage, 4))
            return;
    }
}

const QMetaObject *EkosLive::Media::metaObject() const
{
    return QObject::d_ptr->metaObject ? QObject::d_ptr->dynamicMetaObject() : &staticMetaObject;
}

void *EkosLive::Media::qt_metacast(const char *_clname)
{
    if (!_clname) return nullptr;
    if (!strcmp(_clname, qt_staticMetaObjectStaticContent<qt_meta_tag_ZN8EkosLive5MediaE_t>.strings))
        return static_cast<void*>(this);
    return QObject::qt_metacast(_clname);
}

int EkosLive::Media::qt_metacall(QMetaObject::Call _c, int _id, void **_a)
{
    _id = QObject::qt_metacall(_c, _id, _a);
    if (_id < 0)
        return _id;
    if (_c == QMetaObject::InvokeMetaMethod) {
        if (_id < 15)
            qt_static_metacall(this, _c, _id, _a);
        _id -= 15;
    }
    if (_c == QMetaObject::RegisterMethodArgumentMetaType) {
        if (_id < 15)
            *reinterpret_cast<QMetaType *>(_a[0]) = QMetaType();
        _id -= 15;
    }
    return _id;
}

// SIGNAL 0
void EkosLive::Media::connected()
{
    QMetaObject::activate(this, &staticMetaObject, 0, nullptr);
}

// SIGNAL 1
void EkosLive::Media::disconnected()
{
    QMetaObject::activate(this, &staticMetaObject, 1, nullptr);
}

// SIGNAL 2
void EkosLive::Media::globalLogoutTriggered(const QUrl & _t1)
{
    QMetaObject::activate<void>(this, &staticMetaObject, 2, nullptr, _t1);
}

// SIGNAL 3
void EkosLive::Media::newBoundingRect(QRect _t1, QSize _t2, double _t3)
{
    QMetaObject::activate<void>(this, &staticMetaObject, 3, nullptr, _t1, _t2, _t3);
}

// SIGNAL 4
void EkosLive::Media::newImage(const QByteArray & _t1, const QString & _t2)
{
    QMetaObject::activate<void>(this, &staticMetaObject, 4, nullptr, _t1, _t2);
}
QT_WARNING_POP
