/********************************************************************************
** Form generated from reading UI file 'addcatalogobject.ui'
**
** Created by: Qt User Interface Compiler version 6.11.1
**
** WARNING! All changes made in this file will be lost when recompiling UI file!
********************************************************************************/

#ifndef UI_ADDCATALOGOBJECT_H
#define UI_ADDCATALOGOBJECT_H

#include <QtCore/QVariant>
#include <QtWidgets/QAbstractButton>
#include <QtWidgets/QApplication>
#include <QtWidgets/QCheckBox>
#include <QtWidgets/QComboBox>
#include <QtWidgets/QDialog>
#include <QtWidgets/QDialogButtonBox>
#include <QtWidgets/QDoubleSpinBox>
#include <QtWidgets/QFormLayout>
#include <QtWidgets/QGroupBox>
#include <QtWidgets/QHBoxLayout>
#include <QtWidgets/QLabel>
#include <QtWidgets/QLineEdit>
#include <QtWidgets/QPushButton>
#include <QtWidgets/QSpacerItem>
#include <QtWidgets/QVBoxLayout>
#include <klocalizedstring.h>
#include "widgets/dmsbox.h"

QT_BEGIN_NAMESPACE

class Ui_AddCatalogObject
{
public:
    QVBoxLayout *verticalLayout;
    QGroupBox *groupBox;
    QFormLayout *formLayout;
    QLabel *label;
    QLineEdit *name;
    QLabel *label_4;
    QComboBox *type;
    QLabel *label_5;
    QHBoxLayout *horizontalLayout;
    dmsBox *ra;
    QLabel *label_6;
    dmsBox *dec;
    QLabel *label_11;
    QHBoxLayout *horizontalLayout_2;
    QDoubleSpinBox *mag;
    QCheckBox *magUnknown;
    QGroupBox *groupBox_2;
    QVBoxLayout *verticalLayout_2;
    QGroupBox *groupBox_3;
    QHBoxLayout *horizontalLayout_3;
    QFormLayout *formLayout_2;
    QDoubleSpinBox *maj;
    QLabel *label_8;
    QFormLayout *formLayout_4;
    QLabel *label_7;
    QDoubleSpinBox *min;
    QGroupBox *groupBox_4;
    QFormLayout *formLayout_3;
    QLabel *label_3;
    QLineEdit *catalog_identifier;
    QLabel *label_9;
    QDoubleSpinBox *flux;
    QLabel *label_10;
    QDoubleSpinBox *position_angle;
    QLabel *label_2;
    QLineEdit *long_name;
    QHBoxLayout *horizontalLayout_4;
    QPushButton *guessFromTextButton;
    QSpacerItem *horizontalSpacer;
    QDialogButtonBox *buttonBox;

    void setupUi(QDialog *AddCatalogObject)
    {
        if (AddCatalogObject->objectName().isEmpty())
            AddCatalogObject->setObjectName("AddCatalogObject");
        AddCatalogObject->resize(457, 580);
        verticalLayout = new QVBoxLayout(AddCatalogObject);
        verticalLayout->setObjectName("verticalLayout");
        groupBox = new QGroupBox(AddCatalogObject);
        groupBox->setObjectName("groupBox");
        formLayout = new QFormLayout(groupBox);
        formLayout->setObjectName("formLayout");
        label = new QLabel(groupBox);
        label->setObjectName("label");

        formLayout->setWidget(0, QFormLayout::ItemRole::LabelRole, label);

        name = new QLineEdit(groupBox);
        name->setObjectName("name");

        formLayout->setWidget(0, QFormLayout::ItemRole::FieldRole, name);

        label_4 = new QLabel(groupBox);
        label_4->setObjectName("label_4");

        formLayout->setWidget(1, QFormLayout::ItemRole::LabelRole, label_4);

        type = new QComboBox(groupBox);
        type->setObjectName("type");

        formLayout->setWidget(1, QFormLayout::ItemRole::FieldRole, type);

        label_5 = new QLabel(groupBox);
        label_5->setObjectName("label_5");

        formLayout->setWidget(2, QFormLayout::ItemRole::LabelRole, label_5);

        horizontalLayout = new QHBoxLayout();
        horizontalLayout->setObjectName("horizontalLayout");
        ra = new dmsBox(groupBox);
        ra->setObjectName("ra");
        ra->setClearButtonEnabled(true);

        horizontalLayout->addWidget(ra);

        label_6 = new QLabel(groupBox);
        label_6->setObjectName("label_6");
        QSizePolicy sizePolicy(QSizePolicy::Policy::Fixed, QSizePolicy::Policy::Minimum);
        sizePolicy.setHorizontalStretch(0);
        sizePolicy.setVerticalStretch(0);
        sizePolicy.setHeightForWidth(label_6->sizePolicy().hasHeightForWidth());
        label_6->setSizePolicy(sizePolicy);
        label_6->setAlignment(Qt::AlignCenter);

        horizontalLayout->addWidget(label_6);

        dec = new dmsBox(groupBox);
        dec->setObjectName("dec");
        dec->setClearButtonEnabled(true);

        horizontalLayout->addWidget(dec);


        formLayout->setLayout(2, QFormLayout::ItemRole::FieldRole, horizontalLayout);

        label_11 = new QLabel(groupBox);
        label_11->setObjectName("label_11");

        formLayout->setWidget(5, QFormLayout::ItemRole::LabelRole, label_11);

        horizontalLayout_2 = new QHBoxLayout();
        horizontalLayout_2->setObjectName("horizontalLayout_2");
        mag = new QDoubleSpinBox(groupBox);
        mag->setObjectName("mag");
        mag->setMinimum(-1.000000000000000);
        mag->setMaximum(30.000000000000000);

        horizontalLayout_2->addWidget(mag);

        magUnknown = new QCheckBox(groupBox);
        magUnknown->setObjectName("magUnknown");

        horizontalLayout_2->addWidget(magUnknown);


        formLayout->setLayout(5, QFormLayout::ItemRole::FieldRole, horizontalLayout_2);


        verticalLayout->addWidget(groupBox);

        groupBox_2 = new QGroupBox(AddCatalogObject);
        groupBox_2->setObjectName("groupBox_2");
        verticalLayout_2 = new QVBoxLayout(groupBox_2);
        verticalLayout_2->setObjectName("verticalLayout_2");
        groupBox_3 = new QGroupBox(groupBox_2);
        groupBox_3->setObjectName("groupBox_3");
        horizontalLayout_3 = new QHBoxLayout(groupBox_3);
        horizontalLayout_3->setObjectName("horizontalLayout_3");
        formLayout_2 = new QFormLayout();
        formLayout_2->setObjectName("formLayout_2");
        maj = new QDoubleSpinBox(groupBox_3);
        maj->setObjectName("maj");
        maj->setMaximum(600.000000000000000);

        formLayout_2->setWidget(0, QFormLayout::ItemRole::FieldRole, maj);

        label_8 = new QLabel(groupBox_3);
        label_8->setObjectName("label_8");

        formLayout_2->setWidget(0, QFormLayout::ItemRole::LabelRole, label_8);


        horizontalLayout_3->addLayout(formLayout_2);

        formLayout_4 = new QFormLayout();
        formLayout_4->setObjectName("formLayout_4");
        label_7 = new QLabel(groupBox_3);
        label_7->setObjectName("label_7");

        formLayout_4->setWidget(0, QFormLayout::ItemRole::LabelRole, label_7);

        min = new QDoubleSpinBox(groupBox_3);
        min->setObjectName("min");
        min->setMaximum(600.000000000000000);

        formLayout_4->setWidget(0, QFormLayout::ItemRole::FieldRole, min);


        horizontalLayout_3->addLayout(formLayout_4);


        verticalLayout_2->addWidget(groupBox_3);

        groupBox_4 = new QGroupBox(groupBox_2);
        groupBox_4->setObjectName("groupBox_4");
        formLayout_3 = new QFormLayout(groupBox_4);
        formLayout_3->setObjectName("formLayout_3");
        label_3 = new QLabel(groupBox_4);
        label_3->setObjectName("label_3");

        formLayout_3->setWidget(1, QFormLayout::ItemRole::LabelRole, label_3);

        catalog_identifier = new QLineEdit(groupBox_4);
        catalog_identifier->setObjectName("catalog_identifier");

        formLayout_3->setWidget(1, QFormLayout::ItemRole::FieldRole, catalog_identifier);

        label_9 = new QLabel(groupBox_4);
        label_9->setObjectName("label_9");

        formLayout_3->setWidget(3, QFormLayout::ItemRole::LabelRole, label_9);

        flux = new QDoubleSpinBox(groupBox_4);
        flux->setObjectName("flux");

        formLayout_3->setWidget(3, QFormLayout::ItemRole::FieldRole, flux);

        label_10 = new QLabel(groupBox_4);
        label_10->setObjectName("label_10");

        formLayout_3->setWidget(4, QFormLayout::ItemRole::LabelRole, label_10);

        position_angle = new QDoubleSpinBox(groupBox_4);
        position_angle->setObjectName("position_angle");
        position_angle->setDecimals(6);
        position_angle->setMaximum(180.000000000000000);

        formLayout_3->setWidget(4, QFormLayout::ItemRole::FieldRole, position_angle);

        label_2 = new QLabel(groupBox_4);
        label_2->setObjectName("label_2");

        formLayout_3->setWidget(0, QFormLayout::ItemRole::LabelRole, label_2);

        long_name = new QLineEdit(groupBox_4);
        long_name->setObjectName("long_name");

        formLayout_3->setWidget(0, QFormLayout::ItemRole::FieldRole, long_name);


        verticalLayout_2->addWidget(groupBox_4);


        verticalLayout->addWidget(groupBox_2);

        horizontalLayout_4 = new QHBoxLayout();
        horizontalLayout_4->setObjectName("horizontalLayout_4");
        guessFromTextButton = new QPushButton(AddCatalogObject);
        guessFromTextButton->setObjectName("guessFromTextButton");

        horizontalLayout_4->addWidget(guessFromTextButton);

        horizontalSpacer = new QSpacerItem(40, 20, QSizePolicy::Policy::Expanding, QSizePolicy::Policy::Minimum);

        horizontalLayout_4->addItem(horizontalSpacer);

        buttonBox = new QDialogButtonBox(AddCatalogObject);
        buttonBox->setObjectName("buttonBox");
        buttonBox->setOrientation(Qt::Horizontal);
        buttonBox->setStandardButtons(QDialogButtonBox::Cancel|QDialogButtonBox::Ok);

        horizontalLayout_4->addWidget(buttonBox);


        verticalLayout->addLayout(horizontalLayout_4);

        QWidget::setTabOrder(name, type);
        QWidget::setTabOrder(type, ra);
        QWidget::setTabOrder(ra, dec);
        QWidget::setTabOrder(dec, mag);
        QWidget::setTabOrder(mag, magUnknown);
        QWidget::setTabOrder(magUnknown, maj);
        QWidget::setTabOrder(maj, min);
        QWidget::setTabOrder(min, long_name);
        QWidget::setTabOrder(long_name, catalog_identifier);
        QWidget::setTabOrder(catalog_identifier, flux);
        QWidget::setTabOrder(flux, position_angle);

        retranslateUi(AddCatalogObject);
        QObject::connect(buttonBox, &QDialogButtonBox::accepted, AddCatalogObject, qOverload<>(&QDialog::accept));
        QObject::connect(buttonBox, &QDialogButtonBox::rejected, AddCatalogObject, qOverload<>(&QDialog::reject));
        QObject::connect(magUnknown, &QCheckBox::toggled, mag, &QDoubleSpinBox::setDisabled);

        QMetaObject::connectSlotsByName(AddCatalogObject);
    } // setupUi

    void retranslateUi(QDialog *AddCatalogObject)
    {
        AddCatalogObject->setWindowTitle(tr2i18n("Add/Edit DSO", nullptr));
        groupBox->setTitle(tr2i18n("Basics", nullptr));
        label->setText(tr2i18n("Name:", nullptr));
        name->setPlaceholderText(tr2i18n("e.g. PGC 54559", nullptr));
        label_4->setText(tr2i18n("Type:", nullptr));
        label_5->setText(tr2i18n("RA / Dec (J2000):", nullptr));
        label_6->setText(tr2i18n("/", nullptr));
        label_11->setText(tr2i18n("Apparent magnitude:", nullptr));
#if QT_CONFIG(tooltip)
        magUnknown->setToolTip(tr2i18n("Check if magnitude is unknown", nullptr));
#endif // QT_CONFIG(tooltip)
        magUnknown->setText(tr2i18n("Unknown", nullptr));
        groupBox_2->setTitle(tr2i18n("Optional", nullptr));
        groupBox_3->setTitle(tr2i18n("Size Info in Arcminutes", nullptr));
        label_8->setText(tr2i18n("Major axis:", nullptr));
        label_7->setText(tr2i18n("Minor axis:", nullptr));
        groupBox_4->setTitle(tr2i18n("Misc", nullptr));
#if QT_CONFIG(tooltip)
        label_3->setToolTip(tr2i18n("Some catalog specific identifier, like the NGC number.", nullptr));
#endif // QT_CONFIG(tooltip)
#if QT_CONFIG(whatsthis)
        label_3->setWhatsThis(tr2i18n("Some catalog specific identifier, like the NGC number.", nullptr));
#endif // QT_CONFIG(whatsthis)
        label_3->setText(tr2i18n("Catalog identifier:", nullptr));
        catalog_identifier->setPlaceholderText(tr2i18n("e.g. 54559", nullptr));
        label_9->setText(tr2i18n("Flux:", nullptr));
        label_10->setText(tr2i18n("Position angle (\302\260):", nullptr));
        label_2->setText(tr2i18n("Long name:", nullptr));
        long_name->setPlaceholderText(tr2i18n("e.g. Hoag's Object", nullptr));
#if QT_CONFIG(tooltip)
        guessFromTextButton->setToolTip(tr2i18n("This feature allows you to copy-paste a piece of text from e.g. a website or another app and magically try to infer the contents of this form from it.", nullptr));
#endif // QT_CONFIG(tooltip)
        guessFromTextButton->setText(tr2i18n("Guess from &Text", nullptr));
    } // retranslateUi

};

namespace Ui {
    class AddCatalogObject: public Ui_AddCatalogObject {};
} // namespace Ui

QT_END_NAMESPACE

#endif // ADDCATALOGOBJECT_H

