// This file was generated by ecm_qt_declare_logging_category(): DO NOT EDIT!

#include "ekos_observatory_debug.h"


Q_LOGGING_CATEGORY(KSTARS_EKOS_OBSERVATORY, "org.kde.kstars.ekos.observatory", QtInfoMsg)

