/****************************************************************************
** Meta object code from reading C++ file 'indidbus.h'
**
** Created by: The Qt Meta Object Compiler version 69 (Qt 6.11.1)
**
** WARNING! All changes made in this file will be lost!
*****************************************************************************/

#include "../../../../kstars-3.8.4.1/kstars/indi/indidbus.h"
#include <QtCore/qmetatype.h>

#include <QtCore/qtmochelpers.h>

#include <memory>


#include <QtCore/qxptype_traits.h>
#if !defined(Q_MOC_OUTPUT_REVISION)
#error "The header file 'indidbus.h' doesn't include <QObject>."
#elif Q_MOC_OUTPUT_REVISION != 69
#error "This file was generated using the moc from 6.11.1. It"
#error "cannot be used with the include files from this version of Qt."
#error "(The moc has changed too much.)"
#endif

#ifndef Q_CONSTINIT
#define Q_CONSTINIT
#endif

QT_WARNING_PUSH
QT_WARNING_DISABLE_DEPRECATED
QT_WARNING_DISABLE_GCC("-Wuseless-cast")
namespace {
struct qt_meta_tag_ZN8INDIDBusE_t {};
} // unnamed namespace

template <> constexpr inline auto INDIDBus::qt_create_metaobjectdata<qt_meta_tag_ZN8INDIDBusE_t>()
{
    namespace QMC = QtMocConstants;
    QtMocHelpers::StringRefStorage qt_stringData {
        "INDIDBus",
        "D-Bus Interface",
        "org.kde.kstars.INDI",
        "start",
        "",
        "port",
        "drivers",
        "stop",
        "connect",
        "host",
        "disconnect",
        "getDevicesPaths",
        "uint32_t",
        "interface",
        "getDevices",
        "getProperties",
        "device",
        "getPropertyState",
        "property",
        "sendProperty",
        "setSwitch",
        "switchName",
        "status",
        "getSwitch",
        "setText",
        "textName",
        "text",
        "getText",
        "setNumber",
        "numberName",
        "value",
        "getNumber",
        "getLight",
        "lightName",
        "getBLOBData",
        "blobName",
        "QString&",
        "blobFormat",
        "int&",
        "size",
        "getBLOBFile"
    };

    QtMocHelpers::UintData qt_methods {
        // Method 'start'
        QtMocHelpers::MethodData<bool(int, const QStringList &)>(3, 4, QMC::AccessPublic | QMC::MethodScriptable, QMetaType::Bool, {{
            { QMetaType::Int, 5 }, { QMetaType::QStringList, 6 },
        }}),
        // Method 'stop'
        QtMocHelpers::MethodData<bool(const QString &)>(7, 4, QMC::AccessPublic | QMC::MethodScriptable, QMetaType::Bool, {{
            { QMetaType::QString, 5 },
        }}),
        // Method 'connect'
        QtMocHelpers::MethodData<bool(const QString &, int)>(8, 4, QMC::AccessPublic | QMC::MethodScriptable, QMetaType::Bool, {{
            { QMetaType::QString, 9 }, { QMetaType::Int, 5 },
        }}),
        // Method 'disconnect'
        QtMocHelpers::MethodData<bool(const QString &, int)>(10, 4, QMC::AccessPublic | QMC::MethodScriptable, QMetaType::Bool, {{
            { QMetaType::QString, 9 }, { QMetaType::Int, 5 },
        }}),
        // Method 'getDevicesPaths'
        QtMocHelpers::MethodData<QStringList(uint32_t)>(11, 4, QMC::AccessPublic | QMC::MethodScriptable, QMetaType::QStringList, {{
            { 0x80000000 | 12, 13 },
        }}),
        // Method 'getDevices'
        QtMocHelpers::MethodData<QStringList()>(14, 4, QMC::AccessPublic | QMC::MethodScriptable, QMetaType::QStringList),
        // Method 'getProperties'
        QtMocHelpers::MethodData<QStringList(const QString &)>(15, 4, QMC::AccessPublic | QMC::MethodScriptable, QMetaType::QStringList, {{
            { QMetaType::QString, 16 },
        }}),
        // Method 'getPropertyState'
        QtMocHelpers::MethodData<QString(const QString &, const QString &)>(17, 4, QMC::AccessPublic | QMC::MethodScriptable, QMetaType::QString, {{
            { QMetaType::QString, 16 }, { QMetaType::QString, 18 },
        }}),
        // Method 'sendProperty'
        QtMocHelpers::MethodData<bool(const QString &, const QString &)>(19, 4, QMC::AccessPublic | QMC::MethodScriptable, QMetaType::Bool, {{
            { QMetaType::QString, 16 }, { QMetaType::QString, 18 },
        }}),
        // Method 'setSwitch'
        QtMocHelpers::MethodData<bool(const QString &, const QString &, const QString &, const QString &)>(20, 4, QMC::AccessPublic | QMC::MethodScriptable, QMetaType::Bool, {{
            { QMetaType::QString, 16 }, { QMetaType::QString, 18 }, { QMetaType::QString, 21 }, { QMetaType::QString, 22 },
        }}),
        // Method 'getSwitch'
        QtMocHelpers::MethodData<QString(const QString &, const QString &, const QString &)>(23, 4, QMC::AccessPublic | QMC::MethodScriptable, QMetaType::QString, {{
            { QMetaType::QString, 16 }, { QMetaType::QString, 18 }, { QMetaType::QString, 21 },
        }}),
        // Method 'setText'
        QtMocHelpers::MethodData<bool(const QString &, const QString &, const QString &, const QString &)>(24, 4, QMC::AccessPublic | QMC::MethodScriptable, QMetaType::Bool, {{
            { QMetaType::QString, 16 }, { QMetaType::QString, 18 }, { QMetaType::QString, 25 }, { QMetaType::QString, 26 },
        }}),
        // Method 'getText'
        QtMocHelpers::MethodData<QString(const QString &, const QString &, const QString &)>(27, 4, QMC::AccessPublic | QMC::MethodScriptable, QMetaType::QString, {{
            { QMetaType::QString, 16 }, { QMetaType::QString, 18 }, { QMetaType::QString, 25 },
        }}),
        // Method 'setNumber'
        QtMocHelpers::MethodData<bool(const QString &, const QString &, const QString &, double)>(28, 4, QMC::AccessPublic | QMC::MethodScriptable, QMetaType::Bool, {{
            { QMetaType::QString, 16 }, { QMetaType::QString, 18 }, { QMetaType::QString, 29 }, { QMetaType::Double, 30 },
        }}),
        // Method 'getNumber'
        QtMocHelpers::MethodData<double(const QString &, const QString &, const QString &)>(31, 4, QMC::AccessPublic | QMC::MethodScriptable, QMetaType::Double, {{
            { QMetaType::QString, 16 }, { QMetaType::QString, 18 }, { QMetaType::QString, 29 },
        }}),
        // Method 'getLight'
        QtMocHelpers::MethodData<QString(const QString &, const QString &, const QString &)>(32, 4, QMC::AccessPublic | QMC::MethodScriptable, QMetaType::QString, {{
            { QMetaType::QString, 16 }, { QMetaType::QString, 18 }, { QMetaType::QString, 33 },
        }}),
        // Method 'getBLOBData'
        QtMocHelpers::MethodData<QByteArray(const QString &, const QString &, const QString &, QString &, int &)>(34, 4, QMC::AccessPublic | QMC::MethodScriptable, QMetaType::QByteArray, {{
            { QMetaType::QString, 16 }, { QMetaType::QString, 18 }, { QMetaType::QString, 35 }, { 0x80000000 | 36, 37 },
            { 0x80000000 | 38, 39 },
        }}),
        // Method 'getBLOBFile'
        QtMocHelpers::MethodData<QString(const QString &, const QString &, const QString &, QString &, int &)>(40, 4, QMC::AccessPublic | QMC::MethodScriptable, QMetaType::QString, {{
            { QMetaType::QString, 16 }, { QMetaType::QString, 18 }, { QMetaType::QString, 35 }, { 0x80000000 | 36, 37 },
            { 0x80000000 | 38, 39 },
        }}),
    };
    QtMocHelpers::UintData qt_properties {
    };
    QtMocHelpers::UintData qt_enums {
    };
    QtMocHelpers::UintData qt_constructors {};
    QtMocHelpers::ClassInfos qt_classinfo({
            {    1,    2 },
    });
    return QtMocHelpers::metaObjectData<INDIDBus, qt_meta_tag_ZN8INDIDBusE_t>(QMC::MetaObjectFlag{}, qt_stringData,
            qt_methods, qt_properties, qt_enums, qt_constructors, qt_classinfo);
}
Q_CONSTINIT const QMetaObject INDIDBus::staticMetaObject = { {
    QMetaObject::SuperData::link<QObject::staticMetaObject>(),
    qt_staticMetaObjectStaticContent<qt_meta_tag_ZN8INDIDBusE_t>.stringdata,
    qt_staticMetaObjectStaticContent<qt_meta_tag_ZN8INDIDBusE_t>.data,
    qt_static_metacall,
    nullptr,
    qt_staticMetaObjectRelocatingContent<qt_meta_tag_ZN8INDIDBusE_t>.metaTypes,
    nullptr
} };

void INDIDBus::qt_static_metacall(QObject *_o, QMetaObject::Call _c, int _id, void **_a)
{
    auto *_t = static_cast<INDIDBus *>(_o);
    if (_c == QMetaObject::InvokeMetaMethod) {
        switch (_id) {
        case 0: { bool _r = _t->start((*reinterpret_cast<std::add_pointer_t<int>>(_a[1])),(*reinterpret_cast<std::add_pointer_t<QStringList>>(_a[2])));
            if (_a[0]) *reinterpret_cast<bool*>(_a[0]) = std::move(_r); }  break;
        case 1: { bool _r = _t->stop((*reinterpret_cast<std::add_pointer_t<QString>>(_a[1])));
            if (_a[0]) *reinterpret_cast<bool*>(_a[0]) = std::move(_r); }  break;
        case 2: { bool _r = _t->connect((*reinterpret_cast<std::add_pointer_t<QString>>(_a[1])),(*reinterpret_cast<std::add_pointer_t<int>>(_a[2])));
            if (_a[0]) *reinterpret_cast<bool*>(_a[0]) = std::move(_r); }  break;
        case 3: { bool _r = _t->disconnect((*reinterpret_cast<std::add_pointer_t<QString>>(_a[1])),(*reinterpret_cast<std::add_pointer_t<int>>(_a[2])));
            if (_a[0]) *reinterpret_cast<bool*>(_a[0]) = std::move(_r); }  break;
        case 4: { QStringList _r = _t->getDevicesPaths((*reinterpret_cast<std::add_pointer_t<uint32_t>>(_a[1])));
            if (_a[0]) *reinterpret_cast<QStringList*>(_a[0]) = std::move(_r); }  break;
        case 5: { QStringList _r = _t->getDevices();
            if (_a[0]) *reinterpret_cast<QStringList*>(_a[0]) = std::move(_r); }  break;
        case 6: { QStringList _r = _t->getProperties((*reinterpret_cast<std::add_pointer_t<QString>>(_a[1])));
            if (_a[0]) *reinterpret_cast<QStringList*>(_a[0]) = std::move(_r); }  break;
        case 7: { QString _r = _t->getPropertyState((*reinterpret_cast<std::add_pointer_t<QString>>(_a[1])),(*reinterpret_cast<std::add_pointer_t<QString>>(_a[2])));
            if (_a[0]) *reinterpret_cast<QString*>(_a[0]) = std::move(_r); }  break;
        case 8: { bool _r = _t->sendProperty((*reinterpret_cast<std::add_pointer_t<QString>>(_a[1])),(*reinterpret_cast<std::add_pointer_t<QString>>(_a[2])));
            if (_a[0]) *reinterpret_cast<bool*>(_a[0]) = std::move(_r); }  break;
        case 9: { bool _r = _t->setSwitch((*reinterpret_cast<std::add_pointer_t<QString>>(_a[1])),(*reinterpret_cast<std::add_pointer_t<QString>>(_a[2])),(*reinterpret_cast<std::add_pointer_t<QString>>(_a[3])),(*reinterpret_cast<std::add_pointer_t<QString>>(_a[4])));
            if (_a[0]) *reinterpret_cast<bool*>(_a[0]) = std::move(_r); }  break;
        case 10: { QString _r = _t->getSwitch((*reinterpret_cast<std::add_pointer_t<QString>>(_a[1])),(*reinterpret_cast<std::add_pointer_t<QString>>(_a[2])),(*reinterpret_cast<std::add_pointer_t<QString>>(_a[3])));
            if (_a[0]) *reinterpret_cast<QString*>(_a[0]) = std::move(_r); }  break;
        case 11: { bool _r = _t->setText((*reinterpret_cast<std::add_pointer_t<QString>>(_a[1])),(*reinterpret_cast<std::add_pointer_t<QString>>(_a[2])),(*reinterpret_cast<std::add_pointer_t<QString>>(_a[3])),(*reinterpret_cast<std::add_pointer_t<QString>>(_a[4])));
            if (_a[0]) *reinterpret_cast<bool*>(_a[0]) = std::move(_r); }  break;
        case 12: { QString _r = _t->getText((*reinterpret_cast<std::add_pointer_t<QString>>(_a[1])),(*reinterpret_cast<std::add_pointer_t<QString>>(_a[2])),(*reinterpret_cast<std::add_pointer_t<QString>>(_a[3])));
            if (_a[0]) *reinterpret_cast<QString*>(_a[0]) = std::move(_r); }  break;
        case 13: { bool _r = _t->setNumber((*reinterpret_cast<std::add_pointer_t<QString>>(_a[1])),(*reinterpret_cast<std::add_pointer_t<QString>>(_a[2])),(*reinterpret_cast<std::add_pointer_t<QString>>(_a[3])),(*reinterpret_cast<std::add_pointer_t<double>>(_a[4])));
            if (_a[0]) *reinterpret_cast<bool*>(_a[0]) = std::move(_r); }  break;
        case 14: { double _r = _t->getNumber((*reinterpret_cast<std::add_pointer_t<QString>>(_a[1])),(*reinterpret_cast<std::add_pointer_t<QString>>(_a[2])),(*reinterpret_cast<std::add_pointer_t<QString>>(_a[3])));
            if (_a[0]) *reinterpret_cast<double*>(_a[0]) = std::move(_r); }  break;
        case 15: { QString _r = _t->getLight((*reinterpret_cast<std::add_pointer_t<QString>>(_a[1])),(*reinterpret_cast<std::add_pointer_t<QString>>(_a[2])),(*reinterpret_cast<std::add_pointer_t<QString>>(_a[3])));
            if (_a[0]) *reinterpret_cast<QString*>(_a[0]) = std::move(_r); }  break;
        case 16: { QByteArray _r = _t->getBLOBData((*reinterpret_cast<std::add_pointer_t<QString>>(_a[1])),(*reinterpret_cast<std::add_pointer_t<QString>>(_a[2])),(*reinterpret_cast<std::add_pointer_t<QString>>(_a[3])),(*reinterpret_cast<std::add_pointer_t<QString&>>(_a[4])),(*reinterpret_cast<std::add_pointer_t<int&>>(_a[5])));
            if (_a[0]) *reinterpret_cast<QByteArray*>(_a[0]) = std::move(_r); }  break;
        case 17: { QString _r = _t->getBLOBFile((*reinterpret_cast<std::add_pointer_t<QString>>(_a[1])),(*reinterpret_cast<std::add_pointer_t<QString>>(_a[2])),(*reinterpret_cast<std::add_pointer_t<QString>>(_a[3])),(*reinterpret_cast<std::add_pointer_t<QString&>>(_a[4])),(*reinterpret_cast<std::add_pointer_t<int&>>(_a[5])));
            if (_a[0]) *reinterpret_cast<QString*>(_a[0]) = std::move(_r); }  break;
        default: ;
        }
    }
}

const QMetaObject *INDIDBus::metaObject() const
{
    return QObject::d_ptr->metaObject ? QObject::d_ptr->dynamicMetaObject() : &staticMetaObject;
}

void *INDIDBus::qt_metacast(const char *_clname)
{
    if (!_clname) return nullptr;
    if (!strcmp(_clname, qt_staticMetaObjectStaticContent<qt_meta_tag_ZN8INDIDBusE_t>.strings))
        return static_cast<void*>(this);
    return QObject::qt_metacast(_clname);
}

int INDIDBus::qt_metacall(QMetaObject::Call _c, int _id, void **_a)
{
    _id = QObject::qt_metacall(_c, _id, _a);
    if (_id < 0)
        return _id;
    if (_c == QMetaObject::InvokeMetaMethod) {
        if (_id < 18)
            qt_static_metacall(this, _c, _id, _a);
        _id -= 18;
    }
    if (_c == QMetaObject::RegisterMethodArgumentMetaType) {
        if (_id < 18)
            *reinterpret_cast<QMetaType *>(_a[0]) = QMetaType();
        _id -= 18;
    }
    return _id;
}
QT_WARNING_POP
