/********************************************************************************
** Form generated from reading UI file 'wizwelcome.ui'
**
** Created by: Qt User Interface Compiler version 6.11.1
**
** WARNING! All changes made in this file will be lost when recompiling UI file!
********************************************************************************/

#ifndef UI_WIZWELCOME_H
#define UI_WIZWELCOME_H

#include <QtCore/QVariant>
#include <QtWidgets/QApplication>
#include <QtWidgets/QHBoxLayout>
#include <QtWidgets/QLabel>
#include <QtWidgets/QSpacerItem>
#include <QtWidgets/QVBoxLayout>
#include <QtWidgets/QWidget>
#include <klocalizedstring.h>

QT_BEGIN_NAMESPACE

class Ui_WizWelcome
{
public:
    QHBoxLayout *hboxLayout;
    QLabel *Banner;
    QVBoxLayout *vboxLayout;
    QLabel *WelcomeTitle;
    QSpacerItem *spacerItem;
    QLabel *WelcomeText;
    QSpacerItem *spacerItem1;

    void setupUi(QWidget *WizWelcome)
    {
        if (WizWelcome->objectName().isEmpty())
            WizWelcome->setObjectName("WizWelcome");
        WizWelcome->resize(586, 395);
        hboxLayout = new QHBoxLayout(WizWelcome);
#ifndef UI_Q_OS_MAC
        hboxLayout->setSpacing(6);
#endif
        hboxLayout->setContentsMargins(8, 8, 8, 8);
        hboxLayout->setObjectName("hboxLayout");
        Banner = new QLabel(WizWelcome);
        Banner->setObjectName("Banner");
        QSizePolicy sizePolicy(QSizePolicy::Policy::Fixed, QSizePolicy::Policy::Fixed);
        sizePolicy.setHorizontalStretch(0);
        sizePolicy.setVerticalStretch(0);
        sizePolicy.setHeightForWidth(Banner->sizePolicy().hasHeightForWidth());
        Banner->setSizePolicy(sizePolicy);
        Banner->setMinimumSize(QSize(120, 360));

        hboxLayout->addWidget(Banner);

        vboxLayout = new QVBoxLayout();
#ifndef UI_Q_OS_MAC
        vboxLayout->setSpacing(6);
#endif
        vboxLayout->setContentsMargins(0, 0, 0, 0);
        vboxLayout->setObjectName("vboxLayout");
        WelcomeTitle = new QLabel(WizWelcome);
        WelcomeTitle->setObjectName("WelcomeTitle");
        QFont font;
        font.setFamilies({QString::fromUtf8("Sans Serif")});
        font.setPointSize(11);
        font.setBold(true);
        font.setItalic(false);
        font.setUnderline(false);
        font.setStrikeOut(false);
        WelcomeTitle->setFont(font);

        vboxLayout->addWidget(WelcomeTitle);

        spacerItem = new QSpacerItem(20, 12, QSizePolicy::Policy::Minimum, QSizePolicy::Policy::Fixed);

        vboxLayout->addItem(spacerItem);

        WelcomeText = new QLabel(WizWelcome);
        WelcomeText->setObjectName("WelcomeText");
        WelcomeText->setWordWrap(true);

        vboxLayout->addWidget(WelcomeText);

        spacerItem1 = new QSpacerItem(20, 191, QSizePolicy::Policy::Minimum, QSizePolicy::Policy::Expanding);

        vboxLayout->addItem(spacerItem1);


        hboxLayout->addLayout(vboxLayout);


        retranslateUi(WizWelcome);

        QMetaObject::connectSlotsByName(WizWelcome);
    } // setupUi

    void retranslateUi(QWidget *WizWelcome)
    {
        Banner->setText(QString());
        WelcomeTitle->setText(tr2i18n("Welcome to the KStars Startup Wizard", nullptr));
        WelcomeText->setText(tr2i18n("<p>This wizard will help you set up some basic options, such as your location on Earth.</p><p>To get started, press the <b>Next</b> button.</p>", nullptr));
        (void)WizWelcome;
    } // retranslateUi

};

namespace Ui {
    class WizWelcome: public Ui_WizWelcome {};
} // namespace Ui

QT_END_NAMESPACE

#endif // WIZWELCOME_H

