/********************************************************************************
** Form generated from reading UI file 'opsoffsetsettings.ui'
**
** Created by: Qt User Interface Compiler version 6.11.1
**
** WARNING! All changes made in this file will be lost when recompiling UI file!
********************************************************************************/

#ifndef UI_OPSOFFSETSETTINGS_H
#define UI_OPSOFFSETSETTINGS_H

#include <QtCore/QVariant>
#include <QtWidgets/QApplication>
#include <QtWidgets/QCheckBox>
#include <QtWidgets/QDoubleSpinBox>
#include <QtWidgets/QGridLayout>
#include <QtWidgets/QLabel>
#include <QtWidgets/QSpacerItem>
#include <QtWidgets/QWidget>
#include <klocalizedstring.h>

QT_BEGIN_NAMESPACE

class Ui_OpsOffsetSettings
{
public:
    QGridLayout *gridLayout;
    QLabel *dawnOffsetLabel;
    QDoubleSpinBox *kcfg_DuskOffset;
    QLabel *leadTimeLabel;
    QCheckBox *kcfg_PreemptiveShutdown;
    QDoubleSpinBox *kcfg_LeadTime;
    QDoubleSpinBox *kcfg_PreemptiveShutdownTime;
    QLabel *preDawnLabel;
    QDoubleSpinBox *kcfg_PreDawnTime;
    QSpacerItem *verticalSpacer;
    QDoubleSpinBox *kcfg_DawnOffset;
    QLabel *duskOffsetLabel;

    void setupUi(QWidget *OpsOffsetSettings)
    {
        if (OpsOffsetSettings->objectName().isEmpty())
            OpsOffsetSettings->setObjectName("OpsOffsetSettings");
        OpsOffsetSettings->resize(248, 168);
        gridLayout = new QGridLayout(OpsOffsetSettings);
        gridLayout->setSpacing(3);
        gridLayout->setObjectName("gridLayout");
        gridLayout->setContentsMargins(3, 3, 3, 3);
        dawnOffsetLabel = new QLabel(OpsOffsetSettings);
        dawnOffsetLabel->setObjectName("dawnOffsetLabel");

        gridLayout->addWidget(dawnOffsetLabel, 4, 0, 1, 1);

        kcfg_DuskOffset = new QDoubleSpinBox(OpsOffsetSettings);
        kcfg_DuskOffset->setObjectName("kcfg_DuskOffset");
        kcfg_DuskOffset->setMinimum(-24.000000000000000);
        kcfg_DuskOffset->setMaximum(24.000000000000000);
        kcfg_DuskOffset->setSingleStep(0.500000000000000);

        gridLayout->addWidget(kcfg_DuskOffset, 3, 1, 1, 1);

        leadTimeLabel = new QLabel(OpsOffsetSettings);
        leadTimeLabel->setObjectName("leadTimeLabel");

        gridLayout->addWidget(leadTimeLabel, 0, 0, 1, 1);

        kcfg_PreemptiveShutdown = new QCheckBox(OpsOffsetSettings);
        kcfg_PreemptiveShutdown->setObjectName("kcfg_PreemptiveShutdown");

        gridLayout->addWidget(kcfg_PreemptiveShutdown, 2, 0, 1, 1);

        kcfg_LeadTime = new QDoubleSpinBox(OpsOffsetSettings);
        kcfg_LeadTime->setObjectName("kcfg_LeadTime");

        gridLayout->addWidget(kcfg_LeadTime, 0, 1, 1, 1);

        kcfg_PreemptiveShutdownTime = new QDoubleSpinBox(OpsOffsetSettings);
        kcfg_PreemptiveShutdownTime->setObjectName("kcfg_PreemptiveShutdownTime");

        gridLayout->addWidget(kcfg_PreemptiveShutdownTime, 2, 1, 1, 1);

        preDawnLabel = new QLabel(OpsOffsetSettings);
        preDawnLabel->setObjectName("preDawnLabel");

        gridLayout->addWidget(preDawnLabel, 1, 0, 1, 1);

        kcfg_PreDawnTime = new QDoubleSpinBox(OpsOffsetSettings);
        kcfg_PreDawnTime->setObjectName("kcfg_PreDawnTime");

        gridLayout->addWidget(kcfg_PreDawnTime, 1, 1, 1, 1);

        verticalSpacer = new QSpacerItem(20, 40, QSizePolicy::Policy::Minimum, QSizePolicy::Policy::Expanding);

        gridLayout->addItem(verticalSpacer, 5, 0, 1, 1);

        kcfg_DawnOffset = new QDoubleSpinBox(OpsOffsetSettings);
        kcfg_DawnOffset->setObjectName("kcfg_DawnOffset");
        kcfg_DawnOffset->setMinimum(-24.000000000000000);
        kcfg_DawnOffset->setMaximum(24.000000000000000);
        kcfg_DawnOffset->setSingleStep(0.500000000000000);

        gridLayout->addWidget(kcfg_DawnOffset, 4, 1, 1, 1);

        duskOffsetLabel = new QLabel(OpsOffsetSettings);
        duskOffsetLabel->setObjectName("duskOffsetLabel");

        gridLayout->addWidget(duskOffsetLabel, 3, 0, 1, 1);


        retranslateUi(OpsOffsetSettings);

        QMetaObject::connectSlotsByName(OpsOffsetSettings);
    } // setupUi

    void retranslateUi(QWidget *OpsOffsetSettings)
    {
        OpsOffsetSettings->setWindowTitle(tr2i18n("TabWidget", nullptr));
#if QT_CONFIG(tooltip)
        dawnOffsetLabel->setToolTip(tr2i18n("<html><body><p>Offset astronomical dawn by this many hours. This positive or negative value adjusts the twilight restriction.</p></body></html>", nullptr));
#endif // QT_CONFIG(tooltip)
        dawnOffsetLabel->setText(tr2i18n("Dawn offset:", nullptr));
#if QT_CONFIG(tooltip)
        leadTimeLabel->setToolTip(tr2i18n("<html><head/><body><p>Lead time is the minimum time in minutes between jobs. The scheduler starts execution of a job before its scheduled startup time by this lead time. Early execution is useful as focusing, alignment, and guiding procedures may take prolonged periods to time to complete.</p></body></html>", nullptr));
#endif // QT_CONFIG(tooltip)
        leadTimeLabel->setText(tr2i18n("Lead time:", nullptr));
#if QT_CONFIG(tooltip)
        kcfg_PreemptiveShutdown->setToolTip(tr2i18n("<html><head/><body><p>In case no scheduler job is scheduled for this many hours, perform a complete shutdown procedure and restart observatory operations once the next job is ready.</p></body></html>", nullptr));
#endif // QT_CONFIG(tooltip)
        kcfg_PreemptiveShutdown->setText(tr2i18n("Pre-emptive shutdown:", nullptr));
#if QT_CONFIG(tooltip)
        kcfg_PreemptiveShutdownTime->setToolTip(tr2i18n("<html><head/><body><p>Pre-emptive shutdown hours</p></body></html>", nullptr));
#endif // QT_CONFIG(tooltip)
#if QT_CONFIG(tooltip)
        preDawnLabel->setToolTip(tr2i18n("<html><head/><body><p>Do not permit jobs to be scheduled or executed past this many minutes before dawn.</p></body></html>", nullptr));
#endif // QT_CONFIG(tooltip)
        preDawnLabel->setText(tr2i18n("Pre-dawn:", nullptr));
#if QT_CONFIG(tooltip)
        duskOffsetLabel->setToolTip(tr2i18n("<html><body><p>Offset astronomical dusk by this many hours. This positive or negative value adjusts the twilight restriction.</p></body></html>", nullptr));
#endif // QT_CONFIG(tooltip)
        duskOffsetLabel->setText(tr2i18n("Dusk offset:", nullptr));
    } // retranslateUi

};

namespace Ui {
    class OpsOffsetSettings: public Ui_OpsOffsetSettings {};
} // namespace Ui

QT_END_NAMESPACE

#endif // OPSOFFSETSETTINGS_H

