/*
 * This file was generated by qdbusxml2cpp version 0.8
 * Source file was org.kde.kstars.SimClock.xml
 *
 * qdbusxml2cpp is Copyright (C) The Qt Company Ltd. and other contributors.
 *
 * This is an auto-generated file.
 * Do not edit! All changes made to it will be lost.
 */

#include "simclockadaptor.h"
#include <QtCore/QMetaObject>
#include <QtCore/QByteArray>
#include <QtCore/QList>
#include <QtCore/QMap>
#include <QtCore/QString>
#include <QtCore/QStringList>
#include <QtCore/QVariant>

/*
 * Implementation of adaptor class SimClockAdaptor
 */

SimClockAdaptor::SimClockAdaptor(SimClock *parent)
    : QDBusAbstractAdaptor(parent)
{
    // constructor
    setAutoRelaySignals(true);
}

SimClockAdaptor::~SimClockAdaptor()
{
    // destructor
}

void SimClockAdaptor::setClockScale(double scale)
{
    // handle method call org.kde.kstars.SimClock.setClockScale
    parent()->setClockScale(scale);
}

void SimClockAdaptor::setNow()
{
    // handle method call org.kde.kstars.SimClock.setNow
    parent()->setNow();
}

void SimClockAdaptor::start()
{
    // handle method call org.kde.kstars.SimClock.start
    parent()->start();
}

void SimClockAdaptor::stop()
{
    // handle method call org.kde.kstars.SimClock.stop
    parent()->stop();
}


#include "moc_simclockadaptor.cpp"
