/********************************************************************************
** Form generated from reading UI file 'pwizfovsh.ui'
**
** Created by: Qt User Interface Compiler version 6.11.1
**
** WARNING! All changes made in this file will be lost when recompiling UI file!
********************************************************************************/

#ifndef UI_PWIZFOVSH_H
#define UI_PWIZFOVSH_H

#include <QtCore/QVariant>
#include <QtWidgets/QApplication>
#include <QtWidgets/QComboBox>
#include <QtWidgets/QDoubleSpinBox>
#include <QtWidgets/QGridLayout>
#include <QtWidgets/QHBoxLayout>
#include <QtWidgets/QLabel>
#include <QtWidgets/QPushButton>
#include <QtWidgets/QSpacerItem>
#include <QtWidgets/QVBoxLayout>
#include <QtWidgets/QWidget>
#include <klocalizedstring.h>

QT_BEGIN_NAMESPACE

class Ui_PWizFovSh
{
public:
    QHBoxLayout *horizontalLayout_4;
    QLabel *banner;
    QSpacerItem *horSpacer8;
    QVBoxLayout *fovShLayout;
    QLabel *stepTitle;
    QSpacerItem *vertSpacer1;
    QLabel *stepText;
    QLabel *label1;
    QHBoxLayout *horizontalLayout_3;
    QSpacerItem *horSpacer1;
    QPushButton *selectFromListButton;
    QSpacerItem *horSpacer2;
    QPushButton *pointButton;
    QSpacerItem *horSpacer3;
    QLabel *objInfoLabel;
    QHBoxLayout *horizontalLayout_2;
    QSpacerItem *horSpacer4;
    QPushButton *detailsButton;
    QSpacerItem *horSpacer5;
    QSpacerItem *vertSpacer2;
    QGridLayout *gridLayout;
    QLabel *label2;
    QComboBox *fovCombo;
    QLabel *label3;
    QDoubleSpinBox *maglimSpinBox;
    QSpacerItem *vertSpacer3;
    QHBoxLayout *horizontalLayout;
    QSpacerItem *horSpacer6;
    QPushButton *captureButton;
    QSpacerItem *horSpacer7;
    QSpacerItem *vertSpacer4;

    void setupUi(QWidget *PWizFovSh)
    {
        if (PWizFovSh->objectName().isEmpty())
            PWizFovSh->setObjectName("PWizFovSh");
        PWizFovSh->resize(586, 395);
        PWizFovSh->setMinimumSize(QSize(586, 395));
        horizontalLayout_4 = new QHBoxLayout(PWizFovSh);
        horizontalLayout_4->setObjectName("horizontalLayout_4");
        banner = new QLabel(PWizFovSh);
        banner->setObjectName("banner");
        QSizePolicy sizePolicy(QSizePolicy::Policy::Fixed, QSizePolicy::Policy::Fixed);
        sizePolicy.setHorizontalStretch(0);
        sizePolicy.setVerticalStretch(0);
        sizePolicy.setHeightForWidth(banner->sizePolicy().hasHeightForWidth());
        banner->setSizePolicy(sizePolicy);
        banner->setMinimumSize(QSize(120, 360));

        horizontalLayout_4->addWidget(banner);

        horSpacer8 = new QSpacerItem(5, 20, QSizePolicy::Policy::Fixed, QSizePolicy::Policy::Minimum);

        horizontalLayout_4->addItem(horSpacer8);

        fovShLayout = new QVBoxLayout();
#ifndef UI_Q_OS_MAC
        fovShLayout->setSpacing(6);
#endif
        fovShLayout->setContentsMargins(0, 0, 0, 0);
        fovShLayout->setObjectName("fovShLayout");
        stepTitle = new QLabel(PWizFovSh);
        stepTitle->setObjectName("stepTitle");
        QFont font;
        font.setFamilies({QString::fromUtf8("Sans Serif")});
        font.setPointSize(11);
        font.setBold(true);
        font.setItalic(false);
        font.setUnderline(false);
        font.setStrikeOut(false);
        stepTitle->setFont(font);

        fovShLayout->addWidget(stepTitle);

        vertSpacer1 = new QSpacerItem(20, 13, QSizePolicy::Policy::Minimum, QSizePolicy::Policy::Fixed);

        fovShLayout->addItem(vertSpacer1);

        stepText = new QLabel(PWizFovSh);
        stepText->setObjectName("stepText");
        stepText->setWordWrap(true);

        fovShLayout->addWidget(stepText);

        label1 = new QLabel(PWizFovSh);
        label1->setObjectName("label1");
        QFont font1;
        font1.setBold(true);
        label1->setFont(font1);

        fovShLayout->addWidget(label1);

        horizontalLayout_3 = new QHBoxLayout();
        horizontalLayout_3->setObjectName("horizontalLayout_3");
        horSpacer1 = new QSpacerItem(40, 20, QSizePolicy::Policy::Expanding, QSizePolicy::Policy::Minimum);

        horizontalLayout_3->addItem(horSpacer1);

        selectFromListButton = new QPushButton(PWizFovSh);
        selectFromListButton->setObjectName("selectFromListButton");

        horizontalLayout_3->addWidget(selectFromListButton);

        horSpacer2 = new QSpacerItem(40, 20, QSizePolicy::Policy::Expanding, QSizePolicy::Policy::Minimum);

        horizontalLayout_3->addItem(horSpacer2);

        pointButton = new QPushButton(PWizFovSh);
        pointButton->setObjectName("pointButton");

        horizontalLayout_3->addWidget(pointButton);

        horSpacer3 = new QSpacerItem(40, 20, QSizePolicy::Policy::Expanding, QSizePolicy::Policy::Minimum);

        horizontalLayout_3->addItem(horSpacer3);


        fovShLayout->addLayout(horizontalLayout_3);

        objInfoLabel = new QLabel(PWizFovSh);
        objInfoLabel->setObjectName("objInfoLabel");
        objInfoLabel->setAlignment(Qt::AlignCenter);

        fovShLayout->addWidget(objInfoLabel);

        horizontalLayout_2 = new QHBoxLayout();
        horizontalLayout_2->setObjectName("horizontalLayout_2");
        horSpacer4 = new QSpacerItem(40, 20, QSizePolicy::Policy::Expanding, QSizePolicy::Policy::Minimum);

        horizontalLayout_2->addItem(horSpacer4);

        detailsButton = new QPushButton(PWizFovSh);
        detailsButton->setObjectName("detailsButton");

        horizontalLayout_2->addWidget(detailsButton);

        horSpacer5 = new QSpacerItem(40, 20, QSizePolicy::Policy::Expanding, QSizePolicy::Policy::Minimum);

        horizontalLayout_2->addItem(horSpacer5);


        fovShLayout->addLayout(horizontalLayout_2);

        vertSpacer2 = new QSpacerItem(20, 40, QSizePolicy::Policy::Minimum, QSizePolicy::Policy::Expanding);

        fovShLayout->addItem(vertSpacer2);

        gridLayout = new QGridLayout();
        gridLayout->setObjectName("gridLayout");
        label2 = new QLabel(PWizFovSh);
        label2->setObjectName("label2");

        gridLayout->addWidget(label2, 0, 0, 1, 1);

        fovCombo = new QComboBox(PWizFovSh);
        fovCombo->setObjectName("fovCombo");

        gridLayout->addWidget(fovCombo, 0, 1, 1, 1);

        label3 = new QLabel(PWizFovSh);
        label3->setObjectName("label3");

        gridLayout->addWidget(label3, 1, 0, 1, 1);

        maglimSpinBox = new QDoubleSpinBox(PWizFovSh);
        maglimSpinBox->setObjectName("maglimSpinBox");
        maglimSpinBox->setDecimals(1);
        maglimSpinBox->setMaximum(15.000000000000000);
        maglimSpinBox->setSingleStep(0.100000000000000);
        maglimSpinBox->setValue(7.000000000000000);

        gridLayout->addWidget(maglimSpinBox, 1, 1, 1, 1);


        fovShLayout->addLayout(gridLayout);

        vertSpacer3 = new QSpacerItem(20, 40, QSizePolicy::Policy::Minimum, QSizePolicy::Policy::Expanding);

        fovShLayout->addItem(vertSpacer3);

        horizontalLayout = new QHBoxLayout();
        horizontalLayout->setObjectName("horizontalLayout");
        horSpacer6 = new QSpacerItem(40, 20, QSizePolicy::Policy::Expanding, QSizePolicy::Policy::Minimum);

        horizontalLayout->addItem(horSpacer6);

        captureButton = new QPushButton(PWizFovSh);
        captureButton->setObjectName("captureButton");

        horizontalLayout->addWidget(captureButton);

        horSpacer7 = new QSpacerItem(40, 20, QSizePolicy::Policy::Expanding, QSizePolicy::Policy::Minimum);

        horizontalLayout->addItem(horSpacer7);


        fovShLayout->addLayout(horizontalLayout);

        vertSpacer4 = new QSpacerItem(20, 40, QSizePolicy::Policy::Minimum, QSizePolicy::Policy::Expanding);

        fovShLayout->addItem(vertSpacer4);


        horizontalLayout_4->addLayout(fovShLayout);


        retranslateUi(PWizFovSh);

        QMetaObject::connectSlotsByName(PWizFovSh);
    } // setupUi

    void retranslateUi(QWidget *PWizFovSh)
    {
        banner->setText(QString());
        stepTitle->setText(tr2i18n("Set Star Hopper FOV Capture Options", nullptr));
        stepText->setText(tr2i18n("Configure star hopper FOV capture: select object at which star hopping will begin, select FOV symbol and magnitude limit.", nullptr));
        label1->setText(tr2i18n("Select begin star:", nullptr));
        selectFromListButton->setText(tr2i18n("Select object from list", nullptr));
        pointButton->setText(tr2i18n("Point object on sky map", nullptr));
        objInfoLabel->setText(QString());
        detailsButton->setText(tr2i18n("Show details...", nullptr));
        label2->setText(tr2i18n("Hopping FOV:", nullptr));
        label3->setText(tr2i18n("Hop magnitude limit:", nullptr));
        captureButton->setText(tr2i18n("Begin capture", nullptr));
        (void)PWizFovSh;
    } // retranslateUi

};

namespace Ui {
    class PWizFovSh: public Ui_PWizFovSh {};
} // namespace Ui

QT_END_NAMESPACE

#endif // PWIZFOVSH_H

