/********************************************************************************
** Form generated from reading UI file 'details_log.ui'
**
** Created by: Qt User Interface Compiler version 6.11.1
**
** WARNING! All changes made in this file will be lost when recompiling UI file!
********************************************************************************/

#ifndef UI_DETAILS_LOG_H
#define UI_DETAILS_LOG_H

#include <QtCore/QVariant>
#include <QtWidgets/QApplication>
#include <QtWidgets/QLabel>
#include <QtWidgets/QVBoxLayout>
#include <QtWidgets/QWidget>
#include <klocalizedstring.h>
#include "widgets/logedit.h"

QT_BEGIN_NAMESPACE

class Ui_DetailsLog
{
public:
    QVBoxLayout *vboxLayout;
    QLabel *LogTitle;
    LogEdit *UserLog;

    void setupUi(QWidget *DetailsLog)
    {
        if (DetailsLog->objectName().isEmpty())
            DetailsLog->setObjectName("DetailsLog");
        DetailsLog->resize(400, 300);
        vboxLayout = new QVBoxLayout(DetailsLog);
        vboxLayout->setSpacing(0);
        vboxLayout->setContentsMargins(8, 8, 8, 8);
        vboxLayout->setObjectName("vboxLayout");
        LogTitle = new QLabel(DetailsLog);
        LogTitle->setObjectName("LogTitle");
        QFont font;
        font.setFamilies({QString::fromUtf8("Sans Serif")});
        font.setPointSize(10);
        font.setBold(true);
        font.setItalic(false);
        font.setUnderline(false);
        font.setStrikeOut(false);
        LogTitle->setFont(font);
        LogTitle->setAutoFillBackground(true);
        LogTitle->setAlignment(Qt::AlignCenter);

        vboxLayout->addWidget(LogTitle);

        UserLog = new LogEdit(DetailsLog);
        UserLog->setObjectName("UserLog");
        UserLog->setFrameShape(QFrame::Box);
        UserLog->setFrameShadow(QFrame::Plain);
        UserLog->setLineWidth(4);

        vboxLayout->addWidget(UserLog);


        retranslateUi(DetailsLog);

        QMetaObject::connectSlotsByName(DetailsLog);
    } // setupUi

    void retranslateUi(QWidget *DetailsLog)
    {
        LogTitle->setText(tr2i18n("User Log", nullptr));
        (void)DetailsLog;
    } // retranslateUi

};

namespace Ui {
    class DetailsLog: public Ui_DetailsLog {};
} // namespace Ui

QT_END_NAMESPACE

#endif // DETAILS_LOG_H

