/********************************************************************************
** Form generated from reading UI file 'argtimescale.ui'
**
** Created by: Qt User Interface Compiler version 6.11.1
**
** WARNING! All changes made in this file will be lost when recompiling UI file!
********************************************************************************/

#ifndef UI_ARGTIMESCALE_H
#define UI_ARGTIMESCALE_H

#include <QtCore/QVariant>
#include <QtWidgets/QApplication>
#include <QtWidgets/QHBoxLayout>
#include <QtWidgets/QSpacerItem>
#include <QtWidgets/QVBoxLayout>
#include <QtWidgets/QWidget>
#include <klocalizedstring.h>
#include "widgets/timestepbox.h"

QT_BEGIN_NAMESPACE

class Ui_ArgTimeScale
{
public:
    QVBoxLayout *vboxLayout;
    QHBoxLayout *hboxLayout;
    TimeStepBox *TimeScale;
    QSpacerItem *spacerItem;
    QSpacerItem *spacerItem1;

    void setupUi(QWidget *ArgTimeScale)
    {
        if (ArgTimeScale->objectName().isEmpty())
            ArgTimeScale->setObjectName("ArgTimeScale");
        ArgTimeScale->resize(283, 64);
        vboxLayout = new QVBoxLayout(ArgTimeScale);
#ifndef UI_Q_OS_MAC
        vboxLayout->setSpacing(6);
#endif
        vboxLayout->setContentsMargins(8, 8, 8, 8);
        vboxLayout->setObjectName("vboxLayout");
        hboxLayout = new QHBoxLayout();
#ifndef UI_Q_OS_MAC
        hboxLayout->setSpacing(6);
#endif
#ifndef UI_Q_OS_MAC
        hboxLayout->setContentsMargins(0, 0, 0, 0);
#endif
        hboxLayout->setObjectName("hboxLayout");
        TimeScale = new TimeStepBox(ArgTimeScale);
        TimeScale->setObjectName("TimeScale");

        hboxLayout->addWidget(TimeScale);

        spacerItem = new QSpacerItem(91, 20, QSizePolicy::Policy::Expanding, QSizePolicy::Policy::Minimum);

        hboxLayout->addItem(spacerItem);


        vboxLayout->addLayout(hboxLayout);

        spacerItem1 = new QSpacerItem(261, 16, QSizePolicy::Policy::Minimum, QSizePolicy::Policy::Expanding);

        vboxLayout->addItem(spacerItem1);


        retranslateUi(ArgTimeScale);

        QMetaObject::connectSlotsByName(ArgTimeScale);
    } // setupUi

    void retranslateUi(QWidget *ArgTimeScale)
    {
        (void)ArgTimeScale;
    } // retranslateUi

};

namespace Ui {
    class ArgTimeScale: public Ui_ArgTimeScale {};
} // namespace Ui

QT_END_NAMESPACE

#endif // ARGTIMESCALE_H

