/********************************************************************************
** Form generated from reading UI file 'opsastrometryindexfiles.ui'
**
** Created by: Qt User Interface Compiler version 6.11.1
**
** WARNING! All changes made in this file will be lost when recompiling UI file!
********************************************************************************/

#ifndef UI_OPSASTROMETRYINDEXFILES_H
#define UI_OPSASTROMETRYINDEXFILES_H

#include <QtCore/QVariant>
#include <QtWidgets/QApplication>
#include <QtWidgets/QCheckBox>
#include <QtWidgets/QComboBox>
#include <QtWidgets/QDialog>
#include <QtWidgets/QGridLayout>
#include <QtWidgets/QGroupBox>
#include <QtWidgets/QHBoxLayout>
#include <QtWidgets/QLabel>
#include <QtWidgets/QLineEdit>
#include <QtWidgets/QProgressBar>
#include <QtWidgets/QPushButton>
#include <QtWidgets/QSpacerItem>
#include <QtWidgets/QVBoxLayout>
#include <klocalizedstring.h>

QT_BEGIN_NAMESPACE

class Ui_OpsAstrometryIndexFiles
{
public:
    QVBoxLayout *verticalLayout;
    QLabel *label_30;
    QHBoxLayout *horizontalLayout_4;
    QLabel *required_legend;
    QLabel *label_32;
    QSpacerItem *horizontalSpacer_2;
    QLabel *recommended_legend;
    QLabel *label_33;
    QSpacerItem *horizontalSpacer_3;
    QLabel *optional_legend;
    QLabel *label_35;
    QGridLayout *gridLayout_2;
    QComboBox *indexLocations;
    QLineEdit *FOVOut;
    QLabel *label_27;
    QLabel *label_31;
    QHBoxLayout *horizontalLayout_16;
    QPushButton *addIndexFileDirectory;
    QPushButton *removeIndexFileDirectory;
    QPushButton *openIndexFileDirectory;
    QLineEdit *folderDetails;
    QLabel *label_28;
    QLabel *label_24;
    QLineEdit *indexURL;
    QHBoxLayout *horizontalLayout;
    QGroupBox *groupBox;
    QGridLayout *gridLayout;
    QCheckBox *index_5200;
    QLabel *label_14;
    QPushButton *index_4209_cancel;
    QCheckBox *index_4210;
    QHBoxLayout *horizontalLayout_13;
    QLabel *label_11;
    QProgressBar *index_4210_progress;
    QLabel *index_4210_perc;
    QLabel *label_73;
    QLabel *label_65;
    QHBoxLayout *horizontalLayout_15;
    QLabel *label_13;
    QProgressBar *index_4212_progress;
    QLabel *index_4212_perc;
    QPushButton *index_4107_cancel;
    QLabel *label_22;
    QPushButton *index_4217_cancel;
    QLabel *label_52;
    QCheckBox *index_4112;
    QPushButton *index_4211_cancel;
    QCheckBox *index_5203;
    QPushButton *index_4219_cancel;
    QCheckBox *index_4213;
    QCheckBox *index_4219;
    QCheckBox *index_4200;
    QLabel *label_76;
    QLabel *label_58;
    QProgressBar *index_4109_progress;
    QPushButton *index_4212_cancel;
    QCheckBox *index_4217;
    QLabel *label_63;
    QLabel *label_45;
    QPushButton *index_4111_cancel;
    QLabel *label_67;
    QCheckBox *index_4215;
    QPushButton *index_4218_cancel;
    QHBoxLayout *horizontalLayout_12;
    QLabel *label_10;
    QProgressBar *index_4209_progress;
    QLabel *index_4209_perc;
    QHBoxLayout *horizontalLayout_3;
    QLabel *label_7;
    QProgressBar *index_4206_progress;
    QLabel *index_4206_info;
    QLabel *label_68;
    QHBoxLayout *horizontalLayout_8;
    QLabel *label_3;
    QProgressBar *index_4202_progress;
    QLabel *index_4202_info;
    QLabel *label_38;
    QLabel *label_55;
    QLabel *label_74;
    QCheckBox *index_4115;
    QLabel *label_23;
    QCheckBox *index_4206;
    QCheckBox *index_4218;
    QLabel *label_50;
    QLabel *index_4107_perc;
    QPushButton *index_4202_cancel;
    QPushButton *index_4114_cancel;
    QCheckBox *index_4201;
    QLabel *label_53;
    QCheckBox *index_4108;
    QCheckBox *index_4208;
    QCheckBox *index_4207;
    QPushButton *index_4115_cancel;
    QPushButton *index_4204_cancel;
    QPushButton *index_4213_cancel;
    QLabel *label_40;
    QProgressBar *index_4111_progress;
    QPushButton *index_4112_cancel;
    QCheckBox *index_4110;
    QCheckBox *index_4109;
    QCheckBox *index_4212;
    QLabel *label_60;
    QCheckBox *index_4203;
    QPushButton *index_4216_cancel;
    QPushButton *index_4113_cancel;
    QPushButton *index_4214_cancel;
    QLabel *label_37;
    QHBoxLayout *horizontalLayout_10;
    QLabel *label;
    QProgressBar *index_4200_progress;
    QLabel *index_4200_info;
    QCheckBox *index_4209;
    QLabel *index_4110_perc;
    QCheckBox *index_4205;
    QLabel *label_39;
    QPushButton *index_4116_cancel;
    QCheckBox *index_4214;
    QCheckBox *index_4107;
    QPushButton *index_4118_cancel;
    QCheckBox *index_4114;
    QLabel *label_44;
    QHBoxLayout *horizontalLayout_7;
    QLabel *label_4;
    QProgressBar *index_4203_progress;
    QLabel *index_4203_info;
    QLabel *label_43;
    QLabel *label_78;
    QPushButton *index_4108_cancel;
    QProgressBar *index_4108_progress;
    QCheckBox *index_5206;
    QLabel *label_15;
    QPushButton *index_4207_cancel;
    QPushButton *index_4117_cancel;
    QCheckBox *index_4117;
    QLabel *index_4112_perc;
    QPushButton *index_4205_cancel;
    QHBoxLayout *horizontalLayout_5;
    QLabel *label_6;
    QProgressBar *index_4205_progress;
    QLabel *index_4205_info;
    QLabel *label_54;
    QHBoxLayout *horizontalLayout_11;
    QLabel *label_9;
    QProgressBar *index_4208_progress;
    QLabel *index_4208_perc;
    QCheckBox *index_4119;
    QHBoxLayout *horizontalLayout_9;
    QLabel *label_2;
    QProgressBar *index_4201_progress;
    QLabel *index_4201_info;
    QLabel *label_61;
    QProgressBar *index_4110_progress;
    QLabel *index_4109_perc;
    QLabel *label_49;
    QLabel *label_69;
    QLabel *label_48;
    QLabel *label_26;
    QLabel *label_47;
    QCheckBox *index_4211;
    QPushButton *index_4210_cancel;
    QCheckBox *index_4216;
    QPushButton *index_4208_cancel;
    QPushButton *index_4110_cancel;
    QPushButton *index_4201_cancel;
    QLabel *label_16;
    QLabel *label_134;
    QCheckBox *index_4202;
    QCheckBox *index_4111;
    QLabel *label_19;
    QLabel *index_4111_perc;
    QLabel *index_4108_perc;
    QCheckBox *index_4113;
    QLabel *label_20;
    QLabel *label_18;
    QLabel *label_29;
    QPushButton *index_4119_cancel;
    QLabel *label_135;
    QLabel *label_46;
    QPushButton *index_4200_cancel;
    QLabel *label_57;
    QLabel *label_51;
    QHBoxLayout *horizontalLayout_6;
    QLabel *label_5;
    QProgressBar *index_4204_progress;
    QLabel *index_4204_info;
    QLabel *label_21;
    QCheckBox *index_5205;
    QLabel *label_59;
    QProgressBar *index_4107_progress;
    QLabel *label_17;
    QPushButton *index_4109_cancel;
    QCheckBox *index_4116;
    QPushButton *index_4206_cancel;
    QLabel *label_75;
    QCheckBox *index_4118;
    QCheckBox *index_5204;
    QCheckBox *index_5201;
    QLabel *label_64;
    QLabel *label_41;
    QLabel *label_72;
    QLabel *label_77;
    QCheckBox *index_4204;
    QHBoxLayout *horizontalLayout_14;
    QLabel *label_12;
    QProgressBar *index_4211_progress;
    QLabel *index_4211_perc;
    QProgressBar *index_4112_progress;
    QPushButton *index_4215_cancel;
    QLabel *label_42;
    QLabel *label_66;
    QPushButton *index_4203_cancel;
    QLabel *label_62;
    QLabel *label_56;
    QCheckBox *index_5202;
    QHBoxLayout *horizontalLayout_2;
    QLabel *label_8;
    QProgressBar *index_4207_progress;
    QLabel *index_4207_info;
    QPushButton *index_5206_cancel;
    QPushButton *index_5205_cancel;
    QPushButton *index_5204_cancel;
    QPushButton *index_5203_cancel;
    QPushButton *index_5202_cancel;
    QPushButton *index_5201_cancel;
    QPushButton *index_5200_cancel;
    QLabel *index_5206_info;
    QLabel *index_5205_info;
    QLabel *index_5204_info;
    QLabel *index_5203_info;
    QLabel *index_5202_info;
    QLabel *index_5201_info;
    QLabel *index_5200_info;
    QProgressBar *index_5206_progress;
    QProgressBar *index_5205_progress;
    QProgressBar *index_5204_progress;
    QProgressBar *index_5203_progress;
    QProgressBar *index_5202_progress;
    QProgressBar *index_5201_progress;
    QProgressBar *index_5200_progress;

    void setupUi(QDialog *OpsAstrometryIndexFiles)
    {
        if (OpsAstrometryIndexFiles->objectName().isEmpty())
            OpsAstrometryIndexFiles->setObjectName("OpsAstrometryIndexFiles");
        OpsAstrometryIndexFiles->resize(717, 761);
        verticalLayout = new QVBoxLayout(OpsAstrometryIndexFiles);
        verticalLayout->setSpacing(3);
        verticalLayout->setObjectName("verticalLayout");
        verticalLayout->setContentsMargins(3, 3, 3, 3);
        label_30 = new QLabel(OpsAstrometryIndexFiles);
        label_30->setObjectName("label_30");
        label_30->setStyleSheet(QString::fromUtf8("li\n"
"{\n"
"background:  url(:/icons/astrometry-required.svg) no-repeat left top;\n"
"}"));
        label_30->setWordWrap(true);
        label_30->setOpenExternalLinks(true);

        verticalLayout->addWidget(label_30);

        horizontalLayout_4 = new QHBoxLayout();
        horizontalLayout_4->setSpacing(3);
        horizontalLayout_4->setObjectName("horizontalLayout_4");
        required_legend = new QLabel(OpsAstrometryIndexFiles);
        required_legend->setObjectName("required_legend");
        required_legend->setEnabled(false);
        required_legend->setMinimumSize(QSize(32, 32));
        required_legend->setMaximumSize(QSize(32, 32));
        required_legend->setPixmap(QPixmap(QString::fromUtf8(":/icons/astrometry-required.svg")));
        required_legend->setScaledContents(true);

        horizontalLayout_4->addWidget(required_legend);

        label_32 = new QLabel(OpsAstrometryIndexFiles);
        label_32->setObjectName("label_32");

        horizontalLayout_4->addWidget(label_32);

        horizontalSpacer_2 = new QSpacerItem(13, 20, QSizePolicy::Policy::Expanding, QSizePolicy::Policy::Minimum);

        horizontalLayout_4->addItem(horizontalSpacer_2);

        recommended_legend = new QLabel(OpsAstrometryIndexFiles);
        recommended_legend->setObjectName("recommended_legend");
        recommended_legend->setEnabled(false);
        recommended_legend->setMinimumSize(QSize(32, 32));
        recommended_legend->setMaximumSize(QSize(32, 32));
        recommended_legend->setPixmap(QPixmap(QString::fromUtf8(":/icons/astrometry-recommended.svg")));
        recommended_legend->setScaledContents(true);

        horizontalLayout_4->addWidget(recommended_legend);

        label_33 = new QLabel(OpsAstrometryIndexFiles);
        label_33->setObjectName("label_33");

        horizontalLayout_4->addWidget(label_33);

        horizontalSpacer_3 = new QSpacerItem(13, 20, QSizePolicy::Policy::Expanding, QSizePolicy::Policy::Minimum);

        horizontalLayout_4->addItem(horizontalSpacer_3);

        optional_legend = new QLabel(OpsAstrometryIndexFiles);
        optional_legend->setObjectName("optional_legend");
        optional_legend->setEnabled(false);
        optional_legend->setMinimumSize(QSize(32, 32));
        optional_legend->setMaximumSize(QSize(32, 32));
        optional_legend->setPixmap(QPixmap(QString::fromUtf8(":/icons/astrometry-optional.svg")));
        optional_legend->setScaledContents(true);

        horizontalLayout_4->addWidget(optional_legend);

        label_35 = new QLabel(OpsAstrometryIndexFiles);
        label_35->setObjectName("label_35");

        horizontalLayout_4->addWidget(label_35);


        verticalLayout->addLayout(horizontalLayout_4);

        gridLayout_2 = new QGridLayout();
        gridLayout_2->setObjectName("gridLayout_2");
        gridLayout_2->setHorizontalSpacing(4);
        gridLayout_2->setVerticalSpacing(3);
        indexLocations = new QComboBox(OpsAstrometryIndexFiles);
        indexLocations->setObjectName("indexLocations");

        gridLayout_2->addWidget(indexLocations, 0, 1, 1, 1);

        FOVOut = new QLineEdit(OpsAstrometryIndexFiles);
        FOVOut->setObjectName("FOVOut");
        FOVOut->setReadOnly(true);

        gridLayout_2->addWidget(FOVOut, 3, 1, 1, 2);

        label_27 = new QLabel(OpsAstrometryIndexFiles);
        label_27->setObjectName("label_27");

        gridLayout_2->addWidget(label_27, 0, 0, 1, 1);

        label_31 = new QLabel(OpsAstrometryIndexFiles);
        label_31->setObjectName("label_31");

        gridLayout_2->addWidget(label_31, 2, 0, 1, 1);

        horizontalLayout_16 = new QHBoxLayout();
        horizontalLayout_16->setSpacing(3);
        horizontalLayout_16->setObjectName("horizontalLayout_16");
        addIndexFileDirectory = new QPushButton(OpsAstrometryIndexFiles);
        addIndexFileDirectory->setObjectName("addIndexFileDirectory");

        horizontalLayout_16->addWidget(addIndexFileDirectory);

        removeIndexFileDirectory = new QPushButton(OpsAstrometryIndexFiles);
        removeIndexFileDirectory->setObjectName("removeIndexFileDirectory");

        horizontalLayout_16->addWidget(removeIndexFileDirectory);

        openIndexFileDirectory = new QPushButton(OpsAstrometryIndexFiles);
        openIndexFileDirectory->setObjectName("openIndexFileDirectory");

        horizontalLayout_16->addWidget(openIndexFileDirectory);


        gridLayout_2->addLayout(horizontalLayout_16, 0, 2, 1, 1);

        folderDetails = new QLineEdit(OpsAstrometryIndexFiles);
        folderDetails->setObjectName("folderDetails");
        folderDetails->setEnabled(false);

        gridLayout_2->addWidget(folderDetails, 2, 1, 1, 2);

        label_28 = new QLabel(OpsAstrometryIndexFiles);
        label_28->setObjectName("label_28");

        gridLayout_2->addWidget(label_28, 3, 0, 1, 1);

        label_24 = new QLabel(OpsAstrometryIndexFiles);
        label_24->setObjectName("label_24");

        gridLayout_2->addWidget(label_24, 4, 0, 1, 1);

        indexURL = new QLineEdit(OpsAstrometryIndexFiles);
        indexURL->setObjectName("indexURL");

        gridLayout_2->addWidget(indexURL, 4, 1, 1, 2);


        verticalLayout->addLayout(gridLayout_2);

        horizontalLayout = new QHBoxLayout();
        horizontalLayout->setObjectName("horizontalLayout");
        groupBox = new QGroupBox(OpsAstrometryIndexFiles);
        groupBox->setObjectName("groupBox");
        gridLayout = new QGridLayout(groupBox);
        gridLayout->setSpacing(3);
        gridLayout->setObjectName("gridLayout");
        gridLayout->setContentsMargins(3, 3, 3, 3);
        index_5200 = new QCheckBox(groupBox);
        index_5200->setObjectName("index_5200");

        gridLayout->addWidget(index_5200, 31, 10, 1, 1);

        label_14 = new QLabel(groupBox);
        label_14->setObjectName("label_14");

        gridLayout->addWidget(label_14, 11, 0, 1, 1);

        index_4209_cancel = new QPushButton(groupBox);
        index_4209_cancel->setObjectName("index_4209_cancel");
        QSizePolicy sizePolicy(QSizePolicy::Policy::Fixed, QSizePolicy::Policy::Fixed);
        sizePolicy.setHorizontalStretch(0);
        sizePolicy.setVerticalStretch(0);
        sizePolicy.setHeightForWidth(index_4209_cancel->sizePolicy().hasHeightForWidth());
        index_4209_cancel->setSizePolicy(sizePolicy);
        index_4209_cancel->setMinimumSize(QSize(15, 15));
        index_4209_cancel->setMaximumSize(QSize(15, 15));
        QPalette palette;
        QBrush brush(QColor(255, 0, 0, 255));
        brush.setStyle(Qt::BrushStyle::SolidPattern);
        palette.setBrush(QPalette::ColorGroup::Active, QPalette::ColorRole::ButtonText, brush);
        palette.setBrush(QPalette::ColorGroup::Inactive, QPalette::ColorRole::ButtonText, brush);
        QBrush brush1(QColor(148, 148, 148, 255));
        brush1.setStyle(Qt::BrushStyle::SolidPattern);
        palette.setBrush(QPalette::ColorGroup::Disabled, QPalette::ColorRole::ButtonText, brush1);
        index_4209_cancel->setPalette(palette);

        gridLayout->addWidget(index_4209_cancel, 19, 1, 1, 1);

        index_4210 = new QCheckBox(groupBox);
        index_4210->setObjectName("index_4210");

        gridLayout->addWidget(index_4210, 17, 3, 1, 1);

        horizontalLayout_13 = new QHBoxLayout();
        horizontalLayout_13->setObjectName("horizontalLayout_13");
        horizontalLayout_13->setContentsMargins(-1, 0, -1, -1);
        label_11 = new QLabel(groupBox);
        label_11->setObjectName("label_11");

        horizontalLayout_13->addWidget(label_11);

        index_4210_progress = new QProgressBar(groupBox);
        index_4210_progress->setObjectName("index_4210_progress");
        QSizePolicy sizePolicy1(QSizePolicy::Policy::MinimumExpanding, QSizePolicy::Policy::Fixed);
        sizePolicy1.setHorizontalStretch(0);
        sizePolicy1.setVerticalStretch(0);
        sizePolicy1.setHeightForWidth(index_4210_progress->sizePolicy().hasHeightForWidth());
        index_4210_progress->setSizePolicy(sizePolicy1);
        index_4210_progress->setMinimumSize(QSize(0, 0));
        index_4210_progress->setMaximumSize(QSize(75, 20));
        index_4210_progress->setMinimum(0);
        index_4210_progress->setMaximum(100);
        index_4210_progress->setValue(0);

        horizontalLayout_13->addWidget(index_4210_progress);

        index_4210_perc = new QLabel(groupBox);
        index_4210_perc->setObjectName("index_4210_perc");

        horizontalLayout_13->addWidget(index_4210_perc);


        gridLayout->addLayout(horizontalLayout_13, 17, 0, 1, 1);

        label_73 = new QLabel(groupBox);
        label_73->setObjectName("label_73");

        gridLayout->addWidget(label_73, 26, 11, 1, 1);

        label_65 = new QLabel(groupBox);
        label_65->setObjectName("label_65");

        gridLayout->addWidget(label_65, 17, 11, 1, 1);

        horizontalLayout_15 = new QHBoxLayout();
        horizontalLayout_15->setObjectName("horizontalLayout_15");
        horizontalLayout_15->setContentsMargins(-1, 0, -1, -1);
        label_13 = new QLabel(groupBox);
        label_13->setObjectName("label_13");

        horizontalLayout_15->addWidget(label_13);

        index_4212_progress = new QProgressBar(groupBox);
        index_4212_progress->setObjectName("index_4212_progress");
        sizePolicy1.setHeightForWidth(index_4212_progress->sizePolicy().hasHeightForWidth());
        index_4212_progress->setSizePolicy(sizePolicy1);
        index_4212_progress->setMinimumSize(QSize(0, 0));
        index_4212_progress->setMaximumSize(QSize(75, 20));
        index_4212_progress->setMinimum(0);
        index_4212_progress->setMaximum(100);
        index_4212_progress->setValue(0);

        horizontalLayout_15->addWidget(index_4212_progress);

        index_4212_perc = new QLabel(groupBox);
        index_4212_perc->setObjectName("index_4212_perc");

        horizontalLayout_15->addWidget(index_4212_perc);


        gridLayout->addLayout(horizontalLayout_15, 13, 0, 1, 1);

        index_4107_cancel = new QPushButton(groupBox);
        index_4107_cancel->setObjectName("index_4107_cancel");
        sizePolicy.setHeightForWidth(index_4107_cancel->sizePolicy().hasHeightForWidth());
        index_4107_cancel->setSizePolicy(sizePolicy);
        index_4107_cancel->setMinimumSize(QSize(15, 15));
        index_4107_cancel->setMaximumSize(QSize(15, 15));
        QPalette palette1;
        palette1.setBrush(QPalette::ColorGroup::Active, QPalette::ColorRole::ButtonText, brush);
        palette1.setBrush(QPalette::ColorGroup::Inactive, QPalette::ColorRole::ButtonText, brush);
        palette1.setBrush(QPalette::ColorGroup::Disabled, QPalette::ColorRole::ButtonText, brush1);
        index_4107_cancel->setPalette(palette1);

        gridLayout->addWidget(index_4107_cancel, 24, 7, 1, 1);

        label_22 = new QLabel(groupBox);
        label_22->setObjectName("label_22");
        label_22->setAlignment(Qt::AlignCenter);

        gridLayout->addWidget(label_22, 0, 10, 1, 1);

        index_4217_cancel = new QPushButton(groupBox);
        index_4217_cancel->setObjectName("index_4217_cancel");
        sizePolicy.setHeightForWidth(index_4217_cancel->sizePolicy().hasHeightForWidth());
        index_4217_cancel->setSizePolicy(sizePolicy);
        index_4217_cancel->setMinimumSize(QSize(15, 15));
        index_4217_cancel->setMaximumSize(QSize(15, 15));
        QPalette palette2;
        palette2.setBrush(QPalette::ColorGroup::Active, QPalette::ColorRole::ButtonText, brush);
        palette2.setBrush(QPalette::ColorGroup::Inactive, QPalette::ColorRole::ButtonText, brush);
        palette2.setBrush(QPalette::ColorGroup::Disabled, QPalette::ColorRole::ButtonText, brush1);
        index_4217_cancel->setPalette(palette2);

        gridLayout->addWidget(index_4217_cancel, 6, 1, 1, 1);

        label_52 = new QLabel(groupBox);
        label_52->setObjectName("label_52");

        gridLayout->addWidget(label_52, 28, 4, 1, 1);

        index_4112 = new QCheckBox(groupBox);
        index_4112->setObjectName("index_4112");

        gridLayout->addWidget(index_4112, 13, 10, 1, 1);

        index_4211_cancel = new QPushButton(groupBox);
        index_4211_cancel->setObjectName("index_4211_cancel");
        sizePolicy.setHeightForWidth(index_4211_cancel->sizePolicy().hasHeightForWidth());
        index_4211_cancel->setSizePolicy(sizePolicy);
        index_4211_cancel->setMinimumSize(QSize(15, 15));
        index_4211_cancel->setMaximumSize(QSize(15, 15));
        QPalette palette3;
        palette3.setBrush(QPalette::ColorGroup::Active, QPalette::ColorRole::ButtonText, brush);
        palette3.setBrush(QPalette::ColorGroup::Inactive, QPalette::ColorRole::ButtonText, brush);
        palette3.setBrush(QPalette::ColorGroup::Disabled, QPalette::ColorRole::ButtonText, brush1);
        index_4211_cancel->setPalette(palette3);

        gridLayout->addWidget(index_4211_cancel, 15, 1, 1, 1);

        index_5203 = new QCheckBox(groupBox);
        index_5203->setObjectName("index_5203");

        gridLayout->addWidget(index_5203, 28, 10, 1, 1);

        index_4219_cancel = new QPushButton(groupBox);
        index_4219_cancel->setObjectName("index_4219_cancel");
        sizePolicy.setHeightForWidth(index_4219_cancel->sizePolicy().hasHeightForWidth());
        index_4219_cancel->setSizePolicy(sizePolicy);
        index_4219_cancel->setMinimumSize(QSize(15, 15));
        index_4219_cancel->setMaximumSize(QSize(15, 15));
        QPalette palette4;
        palette4.setBrush(QPalette::ColorGroup::Active, QPalette::ColorRole::ButtonText, brush);
        palette4.setBrush(QPalette::ColorGroup::Inactive, QPalette::ColorRole::ButtonText, brush);
        palette4.setBrush(QPalette::ColorGroup::Disabled, QPalette::ColorRole::ButtonText, brush1);
        index_4219_cancel->setPalette(palette4);

        gridLayout->addWidget(index_4219_cancel, 3, 1, 1, 1);

        index_4213 = new QCheckBox(groupBox);
        index_4213->setObjectName("index_4213");

        gridLayout->addWidget(index_4213, 11, 3, 1, 1);

        index_4219 = new QCheckBox(groupBox);
        index_4219->setObjectName("index_4219");

        gridLayout->addWidget(index_4219, 3, 3, 1, 1);

        index_4200 = new QCheckBox(groupBox);
        index_4200->setObjectName("index_4200");

        gridLayout->addWidget(index_4200, 31, 3, 1, 1);

        label_76 = new QLabel(groupBox);
        label_76->setObjectName("label_76");

        gridLayout->addWidget(label_76, 30, 11, 1, 1);

        label_58 = new QLabel(groupBox);
        label_58->setObjectName("label_58");

        gridLayout->addWidget(label_58, 6, 11, 1, 1);

        index_4109_progress = new QProgressBar(groupBox);
        index_4109_progress->setObjectName("index_4109_progress");
        sizePolicy1.setHeightForWidth(index_4109_progress->sizePolicy().hasHeightForWidth());
        index_4109_progress->setSizePolicy(sizePolicy1);
        index_4109_progress->setMinimumSize(QSize(0, 0));
        index_4109_progress->setMaximumSize(QSize(75, 20));
        index_4109_progress->setMinimum(0);
        index_4109_progress->setMaximum(100);
        index_4109_progress->setValue(0);

        gridLayout->addWidget(index_4109_progress, 19, 5, 1, 1);

        index_4212_cancel = new QPushButton(groupBox);
        index_4212_cancel->setObjectName("index_4212_cancel");
        sizePolicy.setHeightForWidth(index_4212_cancel->sizePolicy().hasHeightForWidth());
        index_4212_cancel->setSizePolicy(sizePolicy);
        index_4212_cancel->setMinimumSize(QSize(15, 15));
        index_4212_cancel->setMaximumSize(QSize(15, 15));
        QPalette palette5;
        palette5.setBrush(QPalette::ColorGroup::Active, QPalette::ColorRole::ButtonText, brush);
        palette5.setBrush(QPalette::ColorGroup::Inactive, QPalette::ColorRole::ButtonText, brush);
        palette5.setBrush(QPalette::ColorGroup::Disabled, QPalette::ColorRole::ButtonText, brush1);
        index_4212_cancel->setPalette(palette5);

        gridLayout->addWidget(index_4212_cancel, 13, 1, 1, 1);

        index_4217 = new QCheckBox(groupBox);
        index_4217->setObjectName("index_4217");

        gridLayout->addWidget(index_4217, 6, 3, 1, 1);

        label_63 = new QLabel(groupBox);
        label_63->setObjectName("label_63");

        gridLayout->addWidget(label_63, 13, 11, 1, 1);

        label_45 = new QLabel(groupBox);
        label_45->setObjectName("label_45");

        gridLayout->addWidget(label_45, 17, 4, 1, 1);

        index_4111_cancel = new QPushButton(groupBox);
        index_4111_cancel->setObjectName("index_4111_cancel");
        sizePolicy.setHeightForWidth(index_4111_cancel->sizePolicy().hasHeightForWidth());
        index_4111_cancel->setSizePolicy(sizePolicy);
        index_4111_cancel->setMinimumSize(QSize(15, 15));
        index_4111_cancel->setMaximumSize(QSize(15, 15));
        QPalette palette6;
        palette6.setBrush(QPalette::ColorGroup::Active, QPalette::ColorRole::ButtonText, brush);
        palette6.setBrush(QPalette::ColorGroup::Inactive, QPalette::ColorRole::ButtonText, brush);
        palette6.setBrush(QPalette::ColorGroup::Disabled, QPalette::ColorRole::ButtonText, brush1);
        index_4111_cancel->setPalette(palette6);

        gridLayout->addWidget(index_4111_cancel, 15, 7, 1, 1);

        label_67 = new QLabel(groupBox);
        label_67->setObjectName("label_67");

        gridLayout->addWidget(label_67, 22, 11, 1, 1);

        index_4215 = new QCheckBox(groupBox);
        index_4215->setObjectName("index_4215");

        gridLayout->addWidget(index_4215, 9, 3, 1, 1);

        index_4218_cancel = new QPushButton(groupBox);
        index_4218_cancel->setObjectName("index_4218_cancel");
        sizePolicy.setHeightForWidth(index_4218_cancel->sizePolicy().hasHeightForWidth());
        index_4218_cancel->setSizePolicy(sizePolicy);
        index_4218_cancel->setMinimumSize(QSize(15, 15));
        index_4218_cancel->setMaximumSize(QSize(15, 15));
        QPalette palette7;
        palette7.setBrush(QPalette::ColorGroup::Active, QPalette::ColorRole::ButtonText, brush);
        palette7.setBrush(QPalette::ColorGroup::Inactive, QPalette::ColorRole::ButtonText, brush);
        palette7.setBrush(QPalette::ColorGroup::Disabled, QPalette::ColorRole::ButtonText, brush1);
        index_4218_cancel->setPalette(palette7);

        gridLayout->addWidget(index_4218_cancel, 5, 1, 1, 1);

        horizontalLayout_12 = new QHBoxLayout();
        horizontalLayout_12->setObjectName("horizontalLayout_12");
        horizontalLayout_12->setContentsMargins(-1, 0, -1, -1);
        label_10 = new QLabel(groupBox);
        label_10->setObjectName("label_10");

        horizontalLayout_12->addWidget(label_10);

        index_4209_progress = new QProgressBar(groupBox);
        index_4209_progress->setObjectName("index_4209_progress");
        sizePolicy1.setHeightForWidth(index_4209_progress->sizePolicy().hasHeightForWidth());
        index_4209_progress->setSizePolicy(sizePolicy1);
        index_4209_progress->setMinimumSize(QSize(0, 0));
        index_4209_progress->setMaximumSize(QSize(75, 20));
        index_4209_progress->setMinimum(0);
        index_4209_progress->setMaximum(100);
        index_4209_progress->setValue(0);

        horizontalLayout_12->addWidget(index_4209_progress);

        index_4209_perc = new QLabel(groupBox);
        index_4209_perc->setObjectName("index_4209_perc");

        horizontalLayout_12->addWidget(index_4209_perc);


        gridLayout->addLayout(horizontalLayout_12, 19, 0, 1, 1);

        horizontalLayout_3 = new QHBoxLayout();
        horizontalLayout_3->setObjectName("horizontalLayout_3");
        horizontalLayout_3->setContentsMargins(0, -1, -1, -1);
        label_7 = new QLabel(groupBox);
        label_7->setObjectName("label_7");

        horizontalLayout_3->addWidget(label_7);

        index_4206_progress = new QProgressBar(groupBox);
        index_4206_progress->setObjectName("index_4206_progress");
        sizePolicy1.setHeightForWidth(index_4206_progress->sizePolicy().hasHeightForWidth());
        index_4206_progress->setSizePolicy(sizePolicy1);
        index_4206_progress->setMinimumSize(QSize(0, 0));
        index_4206_progress->setMaximumSize(QSize(75, 20));
        index_4206_progress->setMinimum(0);
        index_4206_progress->setMaximum(100);
        index_4206_progress->setValue(0);

        horizontalLayout_3->addWidget(index_4206_progress);

        index_4206_info = new QLabel(groupBox);
        index_4206_info->setObjectName("index_4206_info");

        horizontalLayout_3->addWidget(index_4206_info);


        gridLayout->addLayout(horizontalLayout_3, 25, 0, 1, 1);

        label_68 = new QLabel(groupBox);
        label_68->setObjectName("label_68");

        gridLayout->addWidget(label_68, 24, 11, 1, 1);

        horizontalLayout_8 = new QHBoxLayout();
        horizontalLayout_8->setObjectName("horizontalLayout_8");
        horizontalLayout_8->setContentsMargins(0, -1, -1, -1);
        label_3 = new QLabel(groupBox);
        label_3->setObjectName("label_3");

        horizontalLayout_8->addWidget(label_3);

        index_4202_progress = new QProgressBar(groupBox);
        index_4202_progress->setObjectName("index_4202_progress");
        sizePolicy1.setHeightForWidth(index_4202_progress->sizePolicy().hasHeightForWidth());
        index_4202_progress->setSizePolicy(sizePolicy1);
        index_4202_progress->setMinimumSize(QSize(0, 0));
        index_4202_progress->setMaximumSize(QSize(75, 20));
        index_4202_progress->setMinimum(0);
        index_4202_progress->setMaximum(100);
        index_4202_progress->setValue(0);

        horizontalLayout_8->addWidget(index_4202_progress);

        index_4202_info = new QLabel(groupBox);
        index_4202_info->setObjectName("index_4202_info");

        horizontalLayout_8->addWidget(index_4202_info);


        gridLayout->addLayout(horizontalLayout_8, 29, 0, 1, 1);

        label_38 = new QLabel(groupBox);
        label_38->setObjectName("label_38");

        gridLayout->addWidget(label_38, 6, 4, 1, 1);

        label_55 = new QLabel(groupBox);
        label_55->setObjectName("label_55");

        gridLayout->addWidget(label_55, 31, 4, 1, 1);

        label_74 = new QLabel(groupBox);
        label_74->setObjectName("label_74");

        gridLayout->addWidget(label_74, 27, 11, 1, 1);

        index_4115 = new QCheckBox(groupBox);
        index_4115->setObjectName("index_4115");

        gridLayout->addWidget(index_4115, 9, 10, 1, 1);

        label_23 = new QLabel(groupBox);
        label_23->setObjectName("label_23");

        gridLayout->addWidget(label_23, 0, 0, 1, 1);

        index_4206 = new QCheckBox(groupBox);
        index_4206->setObjectName("index_4206");

        gridLayout->addWidget(index_4206, 25, 3, 1, 1);

        index_4218 = new QCheckBox(groupBox);
        index_4218->setObjectName("index_4218");

        gridLayout->addWidget(index_4218, 5, 3, 1, 1);

        label_50 = new QLabel(groupBox);
        label_50->setObjectName("label_50");

        gridLayout->addWidget(label_50, 26, 4, 1, 1);

        index_4107_perc = new QLabel(groupBox);
        index_4107_perc->setObjectName("index_4107_perc");

        gridLayout->addWidget(index_4107_perc, 24, 6, 1, 1);

        index_4202_cancel = new QPushButton(groupBox);
        index_4202_cancel->setObjectName("index_4202_cancel");
        sizePolicy.setHeightForWidth(index_4202_cancel->sizePolicy().hasHeightForWidth());
        index_4202_cancel->setSizePolicy(sizePolicy);
        index_4202_cancel->setMinimumSize(QSize(15, 15));
        index_4202_cancel->setMaximumSize(QSize(15, 15));
        QPalette palette8;
        palette8.setBrush(QPalette::ColorGroup::Active, QPalette::ColorRole::ButtonText, brush);
        palette8.setBrush(QPalette::ColorGroup::Inactive, QPalette::ColorRole::ButtonText, brush);
        palette8.setBrush(QPalette::ColorGroup::Disabled, QPalette::ColorRole::ButtonText, brush1);
        index_4202_cancel->setPalette(palette8);

        gridLayout->addWidget(index_4202_cancel, 29, 1, 1, 1);

        index_4114_cancel = new QPushButton(groupBox);
        index_4114_cancel->setObjectName("index_4114_cancel");
        sizePolicy.setHeightForWidth(index_4114_cancel->sizePolicy().hasHeightForWidth());
        index_4114_cancel->setSizePolicy(sizePolicy);
        index_4114_cancel->setMinimumSize(QSize(15, 15));
        index_4114_cancel->setMaximumSize(QSize(15, 15));
        QPalette palette9;
        palette9.setBrush(QPalette::ColorGroup::Active, QPalette::ColorRole::ButtonText, brush);
        palette9.setBrush(QPalette::ColorGroup::Inactive, QPalette::ColorRole::ButtonText, brush);
        palette9.setBrush(QPalette::ColorGroup::Disabled, QPalette::ColorRole::ButtonText, brush1);
        index_4114_cancel->setPalette(palette9);

        gridLayout->addWidget(index_4114_cancel, 10, 7, 1, 1);

        index_4201 = new QCheckBox(groupBox);
        index_4201->setObjectName("index_4201");

        gridLayout->addWidget(index_4201, 30, 3, 1, 1);

        label_53 = new QLabel(groupBox);
        label_53->setObjectName("label_53");

        gridLayout->addWidget(label_53, 29, 4, 1, 1);

        index_4108 = new QCheckBox(groupBox);
        index_4108->setObjectName("index_4108");

        gridLayout->addWidget(index_4108, 22, 10, 1, 1);

        index_4208 = new QCheckBox(groupBox);
        index_4208->setObjectName("index_4208");

        gridLayout->addWidget(index_4208, 22, 3, 1, 1);

        index_4207 = new QCheckBox(groupBox);
        index_4207->setObjectName("index_4207");

        gridLayout->addWidget(index_4207, 24, 3, 1, 1);

        index_4115_cancel = new QPushButton(groupBox);
        index_4115_cancel->setObjectName("index_4115_cancel");
        sizePolicy.setHeightForWidth(index_4115_cancel->sizePolicy().hasHeightForWidth());
        index_4115_cancel->setSizePolicy(sizePolicy);
        index_4115_cancel->setMinimumSize(QSize(15, 15));
        index_4115_cancel->setMaximumSize(QSize(15, 15));
        QPalette palette10;
        palette10.setBrush(QPalette::ColorGroup::Active, QPalette::ColorRole::ButtonText, brush);
        palette10.setBrush(QPalette::ColorGroup::Inactive, QPalette::ColorRole::ButtonText, brush);
        palette10.setBrush(QPalette::ColorGroup::Disabled, QPalette::ColorRole::ButtonText, brush1);
        index_4115_cancel->setPalette(palette10);

        gridLayout->addWidget(index_4115_cancel, 9, 7, 1, 1);

        index_4204_cancel = new QPushButton(groupBox);
        index_4204_cancel->setObjectName("index_4204_cancel");
        sizePolicy.setHeightForWidth(index_4204_cancel->sizePolicy().hasHeightForWidth());
        index_4204_cancel->setSizePolicy(sizePolicy);
        index_4204_cancel->setMinimumSize(QSize(15, 15));
        index_4204_cancel->setMaximumSize(QSize(15, 15));
        QPalette palette11;
        palette11.setBrush(QPalette::ColorGroup::Active, QPalette::ColorRole::ButtonText, brush);
        palette11.setBrush(QPalette::ColorGroup::Inactive, QPalette::ColorRole::ButtonText, brush);
        palette11.setBrush(QPalette::ColorGroup::Disabled, QPalette::ColorRole::ButtonText, brush1);
        index_4204_cancel->setPalette(palette11);

        gridLayout->addWidget(index_4204_cancel, 27, 1, 1, 1);

        index_4213_cancel = new QPushButton(groupBox);
        index_4213_cancel->setObjectName("index_4213_cancel");
        sizePolicy.setHeightForWidth(index_4213_cancel->sizePolicy().hasHeightForWidth());
        index_4213_cancel->setSizePolicy(sizePolicy);
        index_4213_cancel->setMinimumSize(QSize(15, 15));
        index_4213_cancel->setMaximumSize(QSize(15, 15));
        QPalette palette12;
        palette12.setBrush(QPalette::ColorGroup::Active, QPalette::ColorRole::ButtonText, brush);
        palette12.setBrush(QPalette::ColorGroup::Inactive, QPalette::ColorRole::ButtonText, brush);
        palette12.setBrush(QPalette::ColorGroup::Disabled, QPalette::ColorRole::ButtonText, brush1);
        index_4213_cancel->setPalette(palette12);

        gridLayout->addWidget(index_4213_cancel, 11, 1, 1, 1);

        label_40 = new QLabel(groupBox);
        label_40->setObjectName("label_40");

        gridLayout->addWidget(label_40, 9, 4, 1, 1);

        index_4111_progress = new QProgressBar(groupBox);
        index_4111_progress->setObjectName("index_4111_progress");
        sizePolicy1.setHeightForWidth(index_4111_progress->sizePolicy().hasHeightForWidth());
        index_4111_progress->setSizePolicy(sizePolicy1);
        index_4111_progress->setMinimumSize(QSize(0, 0));
        index_4111_progress->setMaximumSize(QSize(75, 20));
        index_4111_progress->setMinimum(0);
        index_4111_progress->setMaximum(100);
        index_4111_progress->setValue(0);

        gridLayout->addWidget(index_4111_progress, 15, 5, 1, 1);

        index_4112_cancel = new QPushButton(groupBox);
        index_4112_cancel->setObjectName("index_4112_cancel");
        sizePolicy.setHeightForWidth(index_4112_cancel->sizePolicy().hasHeightForWidth());
        index_4112_cancel->setSizePolicy(sizePolicy);
        index_4112_cancel->setMinimumSize(QSize(15, 15));
        index_4112_cancel->setMaximumSize(QSize(15, 15));
        QPalette palette13;
        palette13.setBrush(QPalette::ColorGroup::Active, QPalette::ColorRole::ButtonText, brush);
        palette13.setBrush(QPalette::ColorGroup::Inactive, QPalette::ColorRole::ButtonText, brush);
        palette13.setBrush(QPalette::ColorGroup::Disabled, QPalette::ColorRole::ButtonText, brush1);
        index_4112_cancel->setPalette(palette13);

        gridLayout->addWidget(index_4112_cancel, 13, 7, 1, 1);

        index_4110 = new QCheckBox(groupBox);
        index_4110->setObjectName("index_4110");

        gridLayout->addWidget(index_4110, 17, 10, 1, 1);

        index_4109 = new QCheckBox(groupBox);
        index_4109->setObjectName("index_4109");

        gridLayout->addWidget(index_4109, 19, 10, 1, 1);

        index_4212 = new QCheckBox(groupBox);
        index_4212->setObjectName("index_4212");

        gridLayout->addWidget(index_4212, 13, 3, 1, 1);

        label_60 = new QLabel(groupBox);
        label_60->setObjectName("label_60");

        gridLayout->addWidget(label_60, 9, 11, 1, 1);

        index_4203 = new QCheckBox(groupBox);
        index_4203->setObjectName("index_4203");

        gridLayout->addWidget(index_4203, 28, 3, 1, 1);

        index_4216_cancel = new QPushButton(groupBox);
        index_4216_cancel->setObjectName("index_4216_cancel");
        sizePolicy.setHeightForWidth(index_4216_cancel->sizePolicy().hasHeightForWidth());
        index_4216_cancel->setSizePolicy(sizePolicy);
        index_4216_cancel->setMinimumSize(QSize(15, 15));
        index_4216_cancel->setMaximumSize(QSize(15, 15));
        QPalette palette14;
        palette14.setBrush(QPalette::ColorGroup::Active, QPalette::ColorRole::ButtonText, brush);
        palette14.setBrush(QPalette::ColorGroup::Inactive, QPalette::ColorRole::ButtonText, brush);
        palette14.setBrush(QPalette::ColorGroup::Disabled, QPalette::ColorRole::ButtonText, brush1);
        index_4216_cancel->setPalette(palette14);

        gridLayout->addWidget(index_4216_cancel, 8, 1, 1, 1);

        index_4113_cancel = new QPushButton(groupBox);
        index_4113_cancel->setObjectName("index_4113_cancel");
        sizePolicy.setHeightForWidth(index_4113_cancel->sizePolicy().hasHeightForWidth());
        index_4113_cancel->setSizePolicy(sizePolicy);
        index_4113_cancel->setMinimumSize(QSize(15, 15));
        index_4113_cancel->setMaximumSize(QSize(15, 15));
        QPalette palette15;
        palette15.setBrush(QPalette::ColorGroup::Active, QPalette::ColorRole::ButtonText, brush);
        palette15.setBrush(QPalette::ColorGroup::Inactive, QPalette::ColorRole::ButtonText, brush);
        palette15.setBrush(QPalette::ColorGroup::Disabled, QPalette::ColorRole::ButtonText, brush1);
        index_4113_cancel->setPalette(palette15);

        gridLayout->addWidget(index_4113_cancel, 11, 7, 1, 1);

        index_4214_cancel = new QPushButton(groupBox);
        index_4214_cancel->setObjectName("index_4214_cancel");
        sizePolicy.setHeightForWidth(index_4214_cancel->sizePolicy().hasHeightForWidth());
        index_4214_cancel->setSizePolicy(sizePolicy);
        index_4214_cancel->setMinimumSize(QSize(15, 15));
        index_4214_cancel->setMaximumSize(QSize(15, 15));
        QPalette palette16;
        palette16.setBrush(QPalette::ColorGroup::Active, QPalette::ColorRole::ButtonText, brush);
        palette16.setBrush(QPalette::ColorGroup::Inactive, QPalette::ColorRole::ButtonText, brush);
        palette16.setBrush(QPalette::ColorGroup::Disabled, QPalette::ColorRole::ButtonText, brush1);
        index_4214_cancel->setPalette(palette16);

        gridLayout->addWidget(index_4214_cancel, 10, 1, 1, 1);

        label_37 = new QLabel(groupBox);
        label_37->setObjectName("label_37");

        gridLayout->addWidget(label_37, 5, 4, 1, 1);

        horizontalLayout_10 = new QHBoxLayout();
        horizontalLayout_10->setObjectName("horizontalLayout_10");
        horizontalLayout_10->setContentsMargins(0, -1, -1, -1);
        label = new QLabel(groupBox);
        label->setObjectName("label");

        horizontalLayout_10->addWidget(label);

        index_4200_progress = new QProgressBar(groupBox);
        index_4200_progress->setObjectName("index_4200_progress");
        sizePolicy1.setHeightForWidth(index_4200_progress->sizePolicy().hasHeightForWidth());
        index_4200_progress->setSizePolicy(sizePolicy1);
        index_4200_progress->setMinimumSize(QSize(0, 0));
        index_4200_progress->setMaximumSize(QSize(75, 20));
        index_4200_progress->setMinimum(0);
        index_4200_progress->setMaximum(100);
        index_4200_progress->setValue(0);

        horizontalLayout_10->addWidget(index_4200_progress);

        index_4200_info = new QLabel(groupBox);
        index_4200_info->setObjectName("index_4200_info");

        horizontalLayout_10->addWidget(index_4200_info);


        gridLayout->addLayout(horizontalLayout_10, 31, 0, 1, 1);

        index_4209 = new QCheckBox(groupBox);
        index_4209->setObjectName("index_4209");

        gridLayout->addWidget(index_4209, 19, 3, 1, 1);

        index_4110_perc = new QLabel(groupBox);
        index_4110_perc->setObjectName("index_4110_perc");

        gridLayout->addWidget(index_4110_perc, 17, 6, 1, 1);

        index_4205 = new QCheckBox(groupBox);
        index_4205->setObjectName("index_4205");

        gridLayout->addWidget(index_4205, 26, 3, 1, 1);

        label_39 = new QLabel(groupBox);
        label_39->setObjectName("label_39");

        gridLayout->addWidget(label_39, 8, 4, 1, 1);

        index_4116_cancel = new QPushButton(groupBox);
        index_4116_cancel->setObjectName("index_4116_cancel");
        sizePolicy.setHeightForWidth(index_4116_cancel->sizePolicy().hasHeightForWidth());
        index_4116_cancel->setSizePolicy(sizePolicy);
        index_4116_cancel->setMinimumSize(QSize(15, 15));
        index_4116_cancel->setMaximumSize(QSize(15, 15));
        QPalette palette17;
        palette17.setBrush(QPalette::ColorGroup::Active, QPalette::ColorRole::ButtonText, brush);
        palette17.setBrush(QPalette::ColorGroup::Inactive, QPalette::ColorRole::ButtonText, brush);
        palette17.setBrush(QPalette::ColorGroup::Disabled, QPalette::ColorRole::ButtonText, brush1);
        index_4116_cancel->setPalette(palette17);

        gridLayout->addWidget(index_4116_cancel, 8, 7, 1, 1);

        index_4214 = new QCheckBox(groupBox);
        index_4214->setObjectName("index_4214");

        gridLayout->addWidget(index_4214, 10, 3, 1, 1);

        index_4107 = new QCheckBox(groupBox);
        index_4107->setObjectName("index_4107");

        gridLayout->addWidget(index_4107, 24, 10, 1, 1);

        index_4118_cancel = new QPushButton(groupBox);
        index_4118_cancel->setObjectName("index_4118_cancel");
        sizePolicy.setHeightForWidth(index_4118_cancel->sizePolicy().hasHeightForWidth());
        index_4118_cancel->setSizePolicy(sizePolicy);
        index_4118_cancel->setMinimumSize(QSize(15, 15));
        index_4118_cancel->setMaximumSize(QSize(15, 15));
        QPalette palette18;
        palette18.setBrush(QPalette::ColorGroup::Active, QPalette::ColorRole::ButtonText, brush);
        palette18.setBrush(QPalette::ColorGroup::Inactive, QPalette::ColorRole::ButtonText, brush);
        palette18.setBrush(QPalette::ColorGroup::Disabled, QPalette::ColorRole::ButtonText, brush1);
        index_4118_cancel->setPalette(palette18);

        gridLayout->addWidget(index_4118_cancel, 5, 7, 1, 1);

        index_4114 = new QCheckBox(groupBox);
        index_4114->setObjectName("index_4114");

        gridLayout->addWidget(index_4114, 10, 10, 1, 1);

        label_44 = new QLabel(groupBox);
        label_44->setObjectName("label_44");

        gridLayout->addWidget(label_44, 15, 4, 1, 1);

        horizontalLayout_7 = new QHBoxLayout();
        horizontalLayout_7->setObjectName("horizontalLayout_7");
        horizontalLayout_7->setContentsMargins(0, -1, -1, -1);
        label_4 = new QLabel(groupBox);
        label_4->setObjectName("label_4");

        horizontalLayout_7->addWidget(label_4);

        index_4203_progress = new QProgressBar(groupBox);
        index_4203_progress->setObjectName("index_4203_progress");
        sizePolicy1.setHeightForWidth(index_4203_progress->sizePolicy().hasHeightForWidth());
        index_4203_progress->setSizePolicy(sizePolicy1);
        index_4203_progress->setMinimumSize(QSize(0, 0));
        index_4203_progress->setMaximumSize(QSize(75, 20));
        index_4203_progress->setMinimum(0);
        index_4203_progress->setMaximum(100);
        index_4203_progress->setValue(0);

        horizontalLayout_7->addWidget(index_4203_progress);

        index_4203_info = new QLabel(groupBox);
        index_4203_info->setObjectName("index_4203_info");

        horizontalLayout_7->addWidget(index_4203_info);


        gridLayout->addLayout(horizontalLayout_7, 28, 0, 1, 1);

        label_43 = new QLabel(groupBox);
        label_43->setObjectName("label_43");

        gridLayout->addWidget(label_43, 13, 4, 1, 1);

        label_78 = new QLabel(groupBox);
        label_78->setObjectName("label_78");

        gridLayout->addWidget(label_78, 31, 11, 1, 1);

        index_4108_cancel = new QPushButton(groupBox);
        index_4108_cancel->setObjectName("index_4108_cancel");
        sizePolicy.setHeightForWidth(index_4108_cancel->sizePolicy().hasHeightForWidth());
        index_4108_cancel->setSizePolicy(sizePolicy);
        index_4108_cancel->setMinimumSize(QSize(15, 15));
        index_4108_cancel->setMaximumSize(QSize(15, 15));
        QPalette palette19;
        palette19.setBrush(QPalette::ColorGroup::Active, QPalette::ColorRole::ButtonText, brush);
        palette19.setBrush(QPalette::ColorGroup::Inactive, QPalette::ColorRole::ButtonText, brush);
        palette19.setBrush(QPalette::ColorGroup::Disabled, QPalette::ColorRole::ButtonText, brush1);
        index_4108_cancel->setPalette(palette19);

        gridLayout->addWidget(index_4108_cancel, 22, 7, 1, 1);

        index_4108_progress = new QProgressBar(groupBox);
        index_4108_progress->setObjectName("index_4108_progress");
        sizePolicy1.setHeightForWidth(index_4108_progress->sizePolicy().hasHeightForWidth());
        index_4108_progress->setSizePolicy(sizePolicy1);
        index_4108_progress->setMinimumSize(QSize(0, 0));
        index_4108_progress->setMaximumSize(QSize(75, 20));
        index_4108_progress->setMinimum(0);
        index_4108_progress->setMaximum(100);
        index_4108_progress->setValue(0);

        gridLayout->addWidget(index_4108_progress, 22, 5, 1, 1);

        index_5206 = new QCheckBox(groupBox);
        index_5206->setObjectName("index_5206");

        gridLayout->addWidget(index_5206, 25, 10, 1, 1);

        label_15 = new QLabel(groupBox);
        label_15->setObjectName("label_15");

        gridLayout->addWidget(label_15, 10, 0, 1, 1);

        index_4207_cancel = new QPushButton(groupBox);
        index_4207_cancel->setObjectName("index_4207_cancel");
        sizePolicy.setHeightForWidth(index_4207_cancel->sizePolicy().hasHeightForWidth());
        index_4207_cancel->setSizePolicy(sizePolicy);
        index_4207_cancel->setMinimumSize(QSize(15, 15));
        index_4207_cancel->setMaximumSize(QSize(15, 15));
        QPalette palette20;
        palette20.setBrush(QPalette::ColorGroup::Active, QPalette::ColorRole::ButtonText, brush);
        palette20.setBrush(QPalette::ColorGroup::Inactive, QPalette::ColorRole::ButtonText, brush);
        palette20.setBrush(QPalette::ColorGroup::Disabled, QPalette::ColorRole::ButtonText, brush1);
        index_4207_cancel->setPalette(palette20);

        gridLayout->addWidget(index_4207_cancel, 24, 1, 1, 1);

        index_4117_cancel = new QPushButton(groupBox);
        index_4117_cancel->setObjectName("index_4117_cancel");
        sizePolicy.setHeightForWidth(index_4117_cancel->sizePolicy().hasHeightForWidth());
        index_4117_cancel->setSizePolicy(sizePolicy);
        index_4117_cancel->setMinimumSize(QSize(15, 15));
        index_4117_cancel->setMaximumSize(QSize(15, 15));
        QPalette palette21;
        palette21.setBrush(QPalette::ColorGroup::Active, QPalette::ColorRole::ButtonText, brush);
        palette21.setBrush(QPalette::ColorGroup::Inactive, QPalette::ColorRole::ButtonText, brush);
        palette21.setBrush(QPalette::ColorGroup::Disabled, QPalette::ColorRole::ButtonText, brush1);
        index_4117_cancel->setPalette(palette21);

        gridLayout->addWidget(index_4117_cancel, 6, 7, 1, 1);

        index_4117 = new QCheckBox(groupBox);
        index_4117->setObjectName("index_4117");

        gridLayout->addWidget(index_4117, 6, 10, 1, 1);

        index_4112_perc = new QLabel(groupBox);
        index_4112_perc->setObjectName("index_4112_perc");

        gridLayout->addWidget(index_4112_perc, 13, 6, 1, 1);

        index_4205_cancel = new QPushButton(groupBox);
        index_4205_cancel->setObjectName("index_4205_cancel");
        sizePolicy.setHeightForWidth(index_4205_cancel->sizePolicy().hasHeightForWidth());
        index_4205_cancel->setSizePolicy(sizePolicy);
        index_4205_cancel->setMinimumSize(QSize(15, 15));
        index_4205_cancel->setMaximumSize(QSize(15, 15));
        QPalette palette22;
        palette22.setBrush(QPalette::ColorGroup::Active, QPalette::ColorRole::ButtonText, brush);
        palette22.setBrush(QPalette::ColorGroup::Inactive, QPalette::ColorRole::ButtonText, brush);
        palette22.setBrush(QPalette::ColorGroup::Disabled, QPalette::ColorRole::ButtonText, brush1);
        index_4205_cancel->setPalette(palette22);

        gridLayout->addWidget(index_4205_cancel, 26, 1, 1, 1);

        horizontalLayout_5 = new QHBoxLayout();
        horizontalLayout_5->setObjectName("horizontalLayout_5");
        horizontalLayout_5->setContentsMargins(0, -1, -1, -1);
        label_6 = new QLabel(groupBox);
        label_6->setObjectName("label_6");

        horizontalLayout_5->addWidget(label_6);

        index_4205_progress = new QProgressBar(groupBox);
        index_4205_progress->setObjectName("index_4205_progress");
        sizePolicy1.setHeightForWidth(index_4205_progress->sizePolicy().hasHeightForWidth());
        index_4205_progress->setSizePolicy(sizePolicy1);
        index_4205_progress->setMinimumSize(QSize(0, 0));
        index_4205_progress->setMaximumSize(QSize(75, 20));
        index_4205_progress->setMinimum(0);
        index_4205_progress->setMaximum(100);
        index_4205_progress->setValue(0);

        horizontalLayout_5->addWidget(index_4205_progress);

        index_4205_info = new QLabel(groupBox);
        index_4205_info->setObjectName("index_4205_info");

        horizontalLayout_5->addWidget(index_4205_info);


        gridLayout->addLayout(horizontalLayout_5, 26, 0, 1, 1);

        label_54 = new QLabel(groupBox);
        label_54->setObjectName("label_54");

        gridLayout->addWidget(label_54, 30, 4, 1, 1);

        horizontalLayout_11 = new QHBoxLayout();
        horizontalLayout_11->setObjectName("horizontalLayout_11");
        horizontalLayout_11->setContentsMargins(-1, 0, -1, -1);
        label_9 = new QLabel(groupBox);
        label_9->setObjectName("label_9");

        horizontalLayout_11->addWidget(label_9);

        index_4208_progress = new QProgressBar(groupBox);
        index_4208_progress->setObjectName("index_4208_progress");
        sizePolicy1.setHeightForWidth(index_4208_progress->sizePolicy().hasHeightForWidth());
        index_4208_progress->setSizePolicy(sizePolicy1);
        index_4208_progress->setMinimumSize(QSize(0, 0));
        index_4208_progress->setMaximumSize(QSize(75, 20));
        index_4208_progress->setMinimum(0);
        index_4208_progress->setMaximum(100);
        index_4208_progress->setValue(0);

        horizontalLayout_11->addWidget(index_4208_progress);

        index_4208_perc = new QLabel(groupBox);
        index_4208_perc->setObjectName("index_4208_perc");

        horizontalLayout_11->addWidget(index_4208_perc);


        gridLayout->addLayout(horizontalLayout_11, 22, 0, 1, 1);

        index_4119 = new QCheckBox(groupBox);
        index_4119->setObjectName("index_4119");

        gridLayout->addWidget(index_4119, 3, 10, 1, 1);

        horizontalLayout_9 = new QHBoxLayout();
        horizontalLayout_9->setObjectName("horizontalLayout_9");
        horizontalLayout_9->setContentsMargins(0, -1, -1, -1);
        label_2 = new QLabel(groupBox);
        label_2->setObjectName("label_2");

        horizontalLayout_9->addWidget(label_2);

        index_4201_progress = new QProgressBar(groupBox);
        index_4201_progress->setObjectName("index_4201_progress");
        sizePolicy1.setHeightForWidth(index_4201_progress->sizePolicy().hasHeightForWidth());
        index_4201_progress->setSizePolicy(sizePolicy1);
        index_4201_progress->setMinimumSize(QSize(0, 0));
        index_4201_progress->setMaximumSize(QSize(75, 20));
        index_4201_progress->setMinimum(0);
        index_4201_progress->setMaximum(100);
        index_4201_progress->setValue(0);

        horizontalLayout_9->addWidget(index_4201_progress);

        index_4201_info = new QLabel(groupBox);
        index_4201_info->setObjectName("index_4201_info");

        horizontalLayout_9->addWidget(index_4201_info);


        gridLayout->addLayout(horizontalLayout_9, 30, 0, 1, 1);

        label_61 = new QLabel(groupBox);
        label_61->setObjectName("label_61");

        gridLayout->addWidget(label_61, 10, 11, 1, 1);

        index_4110_progress = new QProgressBar(groupBox);
        index_4110_progress->setObjectName("index_4110_progress");
        sizePolicy1.setHeightForWidth(index_4110_progress->sizePolicy().hasHeightForWidth());
        index_4110_progress->setSizePolicy(sizePolicy1);
        index_4110_progress->setMinimumSize(QSize(0, 0));
        index_4110_progress->setMaximumSize(QSize(75, 20));
        index_4110_progress->setMinimum(0);
        index_4110_progress->setMaximum(100);
        index_4110_progress->setValue(0);

        gridLayout->addWidget(index_4110_progress, 17, 5, 1, 1);

        index_4109_perc = new QLabel(groupBox);
        index_4109_perc->setObjectName("index_4109_perc");

        gridLayout->addWidget(index_4109_perc, 19, 6, 1, 1);

        label_49 = new QLabel(groupBox);
        label_49->setObjectName("label_49");

        gridLayout->addWidget(label_49, 25, 4, 1, 1);

        label_69 = new QLabel(groupBox);
        label_69->setObjectName("label_69");

        gridLayout->addWidget(label_69, 1, 0, 1, 1);

        label_48 = new QLabel(groupBox);
        label_48->setObjectName("label_48");

        gridLayout->addWidget(label_48, 24, 4, 1, 1);

        label_26 = new QLabel(groupBox);
        label_26->setObjectName("label_26");

        gridLayout->addWidget(label_26, 2, 0, 1, 1);

        label_47 = new QLabel(groupBox);
        label_47->setObjectName("label_47");

        gridLayout->addWidget(label_47, 22, 4, 1, 1);

        index_4211 = new QCheckBox(groupBox);
        index_4211->setObjectName("index_4211");

        gridLayout->addWidget(index_4211, 15, 3, 1, 1);

        index_4210_cancel = new QPushButton(groupBox);
        index_4210_cancel->setObjectName("index_4210_cancel");
        sizePolicy.setHeightForWidth(index_4210_cancel->sizePolicy().hasHeightForWidth());
        index_4210_cancel->setSizePolicy(sizePolicy);
        index_4210_cancel->setMinimumSize(QSize(15, 15));
        index_4210_cancel->setMaximumSize(QSize(15, 15));
        QPalette palette23;
        palette23.setBrush(QPalette::ColorGroup::Active, QPalette::ColorRole::ButtonText, brush);
        palette23.setBrush(QPalette::ColorGroup::Inactive, QPalette::ColorRole::ButtonText, brush);
        palette23.setBrush(QPalette::ColorGroup::Disabled, QPalette::ColorRole::ButtonText, brush1);
        index_4210_cancel->setPalette(palette23);

        gridLayout->addWidget(index_4210_cancel, 17, 1, 1, 1);

        index_4216 = new QCheckBox(groupBox);
        index_4216->setObjectName("index_4216");

        gridLayout->addWidget(index_4216, 8, 3, 1, 1);

        index_4208_cancel = new QPushButton(groupBox);
        index_4208_cancel->setObjectName("index_4208_cancel");
        sizePolicy.setHeightForWidth(index_4208_cancel->sizePolicy().hasHeightForWidth());
        index_4208_cancel->setSizePolicy(sizePolicy);
        index_4208_cancel->setMinimumSize(QSize(15, 15));
        index_4208_cancel->setMaximumSize(QSize(15, 15));
        QPalette palette24;
        palette24.setBrush(QPalette::ColorGroup::Active, QPalette::ColorRole::ButtonText, brush);
        palette24.setBrush(QPalette::ColorGroup::Inactive, QPalette::ColorRole::ButtonText, brush);
        palette24.setBrush(QPalette::ColorGroup::Disabled, QPalette::ColorRole::ButtonText, brush1);
        index_4208_cancel->setPalette(palette24);

        gridLayout->addWidget(index_4208_cancel, 22, 1, 1, 1);

        index_4110_cancel = new QPushButton(groupBox);
        index_4110_cancel->setObjectName("index_4110_cancel");
        sizePolicy.setHeightForWidth(index_4110_cancel->sizePolicy().hasHeightForWidth());
        index_4110_cancel->setSizePolicy(sizePolicy);
        index_4110_cancel->setMinimumSize(QSize(15, 15));
        index_4110_cancel->setMaximumSize(QSize(15, 15));
        QPalette palette25;
        palette25.setBrush(QPalette::ColorGroup::Active, QPalette::ColorRole::ButtonText, brush);
        palette25.setBrush(QPalette::ColorGroup::Inactive, QPalette::ColorRole::ButtonText, brush);
        palette25.setBrush(QPalette::ColorGroup::Disabled, QPalette::ColorRole::ButtonText, brush1);
        index_4110_cancel->setPalette(palette25);

        gridLayout->addWidget(index_4110_cancel, 17, 7, 1, 1);

        index_4201_cancel = new QPushButton(groupBox);
        index_4201_cancel->setObjectName("index_4201_cancel");
        sizePolicy.setHeightForWidth(index_4201_cancel->sizePolicy().hasHeightForWidth());
        index_4201_cancel->setSizePolicy(sizePolicy);
        index_4201_cancel->setMinimumSize(QSize(15, 15));
        index_4201_cancel->setMaximumSize(QSize(15, 15));
        QPalette palette26;
        palette26.setBrush(QPalette::ColorGroup::Active, QPalette::ColorRole::ButtonText, brush);
        palette26.setBrush(QPalette::ColorGroup::Inactive, QPalette::ColorRole::ButtonText, brush);
        palette26.setBrush(QPalette::ColorGroup::Disabled, QPalette::ColorRole::ButtonText, brush1);
        index_4201_cancel->setPalette(palette26);

        gridLayout->addWidget(index_4201_cancel, 30, 1, 1, 1);

        label_16 = new QLabel(groupBox);
        label_16->setObjectName("label_16");

        gridLayout->addWidget(label_16, 9, 0, 1, 1);

        label_134 = new QLabel(groupBox);
        label_134->setObjectName("label_134");
        label_134->setAlignment(Qt::AlignCenter);

        gridLayout->addWidget(label_134, 2, 4, 1, 1);

        index_4202 = new QCheckBox(groupBox);
        index_4202->setObjectName("index_4202");

        gridLayout->addWidget(index_4202, 29, 3, 1, 1);

        index_4111 = new QCheckBox(groupBox);
        index_4111->setObjectName("index_4111");

        gridLayout->addWidget(index_4111, 15, 10, 1, 1);

        label_19 = new QLabel(groupBox);
        label_19->setObjectName("label_19");

        gridLayout->addWidget(label_19, 5, 0, 1, 1);

        index_4111_perc = new QLabel(groupBox);
        index_4111_perc->setObjectName("index_4111_perc");

        gridLayout->addWidget(index_4111_perc, 15, 6, 1, 1);

        index_4108_perc = new QLabel(groupBox);
        index_4108_perc->setObjectName("index_4108_perc");

        gridLayout->addWidget(index_4108_perc, 22, 6, 1, 1);

        index_4113 = new QCheckBox(groupBox);
        index_4113->setObjectName("index_4113");

        gridLayout->addWidget(index_4113, 11, 10, 1, 1);

        label_20 = new QLabel(groupBox);
        label_20->setObjectName("label_20");

        gridLayout->addWidget(label_20, 3, 0, 1, 1);

        label_18 = new QLabel(groupBox);
        label_18->setObjectName("label_18");

        gridLayout->addWidget(label_18, 6, 0, 1, 1);

        label_29 = new QLabel(groupBox);
        label_29->setObjectName("label_29");

        gridLayout->addWidget(label_29, 3, 4, 1, 1);

        index_4119_cancel = new QPushButton(groupBox);
        index_4119_cancel->setObjectName("index_4119_cancel");
        sizePolicy.setHeightForWidth(index_4119_cancel->sizePolicy().hasHeightForWidth());
        index_4119_cancel->setSizePolicy(sizePolicy);
        index_4119_cancel->setMinimumSize(QSize(15, 15));
        index_4119_cancel->setMaximumSize(QSize(15, 15));
        QPalette palette27;
        palette27.setBrush(QPalette::ColorGroup::Active, QPalette::ColorRole::ButtonText, brush);
        palette27.setBrush(QPalette::ColorGroup::Inactive, QPalette::ColorRole::ButtonText, brush);
        palette27.setBrush(QPalette::ColorGroup::Disabled, QPalette::ColorRole::ButtonText, brush1);
        index_4119_cancel->setPalette(palette27);

        gridLayout->addWidget(index_4119_cancel, 3, 7, 1, 1);

        label_135 = new QLabel(groupBox);
        label_135->setObjectName("label_135");

        gridLayout->addWidget(label_135, 2, 11, 1, 1);

        label_46 = new QLabel(groupBox);
        label_46->setObjectName("label_46");

        gridLayout->addWidget(label_46, 19, 4, 1, 1);

        index_4200_cancel = new QPushButton(groupBox);
        index_4200_cancel->setObjectName("index_4200_cancel");
        sizePolicy.setHeightForWidth(index_4200_cancel->sizePolicy().hasHeightForWidth());
        index_4200_cancel->setSizePolicy(sizePolicy);
        index_4200_cancel->setMinimumSize(QSize(15, 15));
        index_4200_cancel->setMaximumSize(QSize(15, 15));
        QPalette palette28;
        palette28.setBrush(QPalette::ColorGroup::Active, QPalette::ColorRole::ButtonText, brush);
        palette28.setBrush(QPalette::ColorGroup::Inactive, QPalette::ColorRole::ButtonText, brush);
        palette28.setBrush(QPalette::ColorGroup::Disabled, QPalette::ColorRole::ButtonText, brush1);
        index_4200_cancel->setPalette(palette28);

        gridLayout->addWidget(index_4200_cancel, 31, 1, 1, 1);

        label_57 = new QLabel(groupBox);
        label_57->setObjectName("label_57");

        gridLayout->addWidget(label_57, 5, 11, 1, 1);

        label_51 = new QLabel(groupBox);
        label_51->setObjectName("label_51");

        gridLayout->addWidget(label_51, 27, 4, 1, 1);

        horizontalLayout_6 = new QHBoxLayout();
        horizontalLayout_6->setObjectName("horizontalLayout_6");
        horizontalLayout_6->setContentsMargins(0, -1, -1, -1);
        label_5 = new QLabel(groupBox);
        label_5->setObjectName("label_5");

        horizontalLayout_6->addWidget(label_5);

        index_4204_progress = new QProgressBar(groupBox);
        index_4204_progress->setObjectName("index_4204_progress");
        sizePolicy1.setHeightForWidth(index_4204_progress->sizePolicy().hasHeightForWidth());
        index_4204_progress->setSizePolicy(sizePolicy1);
        index_4204_progress->setMinimumSize(QSize(0, 0));
        index_4204_progress->setMaximumSize(QSize(75, 20));
        index_4204_progress->setMinimum(0);
        index_4204_progress->setMaximum(100);
        index_4204_progress->setValue(0);

        horizontalLayout_6->addWidget(index_4204_progress);

        index_4204_info = new QLabel(groupBox);
        index_4204_info->setObjectName("index_4204_info");

        horizontalLayout_6->addWidget(index_4204_info);


        gridLayout->addLayout(horizontalLayout_6, 27, 0, 1, 1);

        label_21 = new QLabel(groupBox);
        label_21->setObjectName("label_21");
        label_21->setAlignment(Qt::AlignCenter);

        gridLayout->addWidget(label_21, 0, 3, 1, 1);

        index_5205 = new QCheckBox(groupBox);
        index_5205->setObjectName("index_5205");

        gridLayout->addWidget(index_5205, 26, 10, 1, 1);

        label_59 = new QLabel(groupBox);
        label_59->setObjectName("label_59");

        gridLayout->addWidget(label_59, 8, 11, 1, 1);

        index_4107_progress = new QProgressBar(groupBox);
        index_4107_progress->setObjectName("index_4107_progress");
        sizePolicy1.setHeightForWidth(index_4107_progress->sizePolicy().hasHeightForWidth());
        index_4107_progress->setSizePolicy(sizePolicy1);
        index_4107_progress->setMinimumSize(QSize(0, 0));
        index_4107_progress->setMaximumSize(QSize(75, 20));
        index_4107_progress->setMinimum(0);
        index_4107_progress->setMaximum(100);
        index_4107_progress->setValue(0);

        gridLayout->addWidget(index_4107_progress, 24, 5, 1, 1);

        label_17 = new QLabel(groupBox);
        label_17->setObjectName("label_17");

        gridLayout->addWidget(label_17, 8, 0, 1, 1);

        index_4109_cancel = new QPushButton(groupBox);
        index_4109_cancel->setObjectName("index_4109_cancel");
        sizePolicy.setHeightForWidth(index_4109_cancel->sizePolicy().hasHeightForWidth());
        index_4109_cancel->setSizePolicy(sizePolicy);
        index_4109_cancel->setMinimumSize(QSize(15, 15));
        index_4109_cancel->setMaximumSize(QSize(15, 15));
        QPalette palette29;
        palette29.setBrush(QPalette::ColorGroup::Active, QPalette::ColorRole::ButtonText, brush);
        palette29.setBrush(QPalette::ColorGroup::Inactive, QPalette::ColorRole::ButtonText, brush);
        palette29.setBrush(QPalette::ColorGroup::Disabled, QPalette::ColorRole::ButtonText, brush1);
        index_4109_cancel->setPalette(palette29);

        gridLayout->addWidget(index_4109_cancel, 19, 7, 1, 1);

        index_4116 = new QCheckBox(groupBox);
        index_4116->setObjectName("index_4116");

        gridLayout->addWidget(index_4116, 8, 10, 1, 1);

        index_4206_cancel = new QPushButton(groupBox);
        index_4206_cancel->setObjectName("index_4206_cancel");
        sizePolicy.setHeightForWidth(index_4206_cancel->sizePolicy().hasHeightForWidth());
        index_4206_cancel->setSizePolicy(sizePolicy);
        index_4206_cancel->setMinimumSize(QSize(15, 15));
        index_4206_cancel->setMaximumSize(QSize(15, 15));
        QPalette palette30;
        palette30.setBrush(QPalette::ColorGroup::Active, QPalette::ColorRole::ButtonText, brush);
        palette30.setBrush(QPalette::ColorGroup::Inactive, QPalette::ColorRole::ButtonText, brush);
        palette30.setBrush(QPalette::ColorGroup::Disabled, QPalette::ColorRole::ButtonText, brush1);
        index_4206_cancel->setPalette(palette30);

        gridLayout->addWidget(index_4206_cancel, 25, 1, 1, 1);

        label_75 = new QLabel(groupBox);
        label_75->setObjectName("label_75");

        gridLayout->addWidget(label_75, 28, 11, 1, 1);

        index_4118 = new QCheckBox(groupBox);
        index_4118->setObjectName("index_4118");

        gridLayout->addWidget(index_4118, 5, 10, 1, 1);

        index_5204 = new QCheckBox(groupBox);
        index_5204->setObjectName("index_5204");

        gridLayout->addWidget(index_5204, 27, 10, 1, 1);

        index_5201 = new QCheckBox(groupBox);
        index_5201->setObjectName("index_5201");

        gridLayout->addWidget(index_5201, 30, 10, 1, 1);

        label_64 = new QLabel(groupBox);
        label_64->setObjectName("label_64");

        gridLayout->addWidget(label_64, 15, 11, 1, 1);

        label_41 = new QLabel(groupBox);
        label_41->setObjectName("label_41");

        gridLayout->addWidget(label_41, 10, 4, 1, 1);

        label_72 = new QLabel(groupBox);
        label_72->setObjectName("label_72");

        gridLayout->addWidget(label_72, 25, 11, 1, 1);

        label_77 = new QLabel(groupBox);
        label_77->setObjectName("label_77");

        gridLayout->addWidget(label_77, 29, 11, 1, 1);

        index_4204 = new QCheckBox(groupBox);
        index_4204->setObjectName("index_4204");

        gridLayout->addWidget(index_4204, 27, 3, 1, 1);

        horizontalLayout_14 = new QHBoxLayout();
        horizontalLayout_14->setObjectName("horizontalLayout_14");
        horizontalLayout_14->setContentsMargins(-1, 0, -1, -1);
        label_12 = new QLabel(groupBox);
        label_12->setObjectName("label_12");

        horizontalLayout_14->addWidget(label_12);

        index_4211_progress = new QProgressBar(groupBox);
        index_4211_progress->setObjectName("index_4211_progress");
        sizePolicy1.setHeightForWidth(index_4211_progress->sizePolicy().hasHeightForWidth());
        index_4211_progress->setSizePolicy(sizePolicy1);
        index_4211_progress->setMinimumSize(QSize(0, 0));
        index_4211_progress->setMaximumSize(QSize(75, 20));
        index_4211_progress->setMinimum(0);
        index_4211_progress->setMaximum(100);
        index_4211_progress->setValue(0);

        horizontalLayout_14->addWidget(index_4211_progress);

        index_4211_perc = new QLabel(groupBox);
        index_4211_perc->setObjectName("index_4211_perc");

        horizontalLayout_14->addWidget(index_4211_perc);


        gridLayout->addLayout(horizontalLayout_14, 15, 0, 1, 1);

        index_4112_progress = new QProgressBar(groupBox);
        index_4112_progress->setObjectName("index_4112_progress");
        sizePolicy1.setHeightForWidth(index_4112_progress->sizePolicy().hasHeightForWidth());
        index_4112_progress->setSizePolicy(sizePolicy1);
        index_4112_progress->setMinimumSize(QSize(0, 0));
        index_4112_progress->setMaximumSize(QSize(75, 20));
        index_4112_progress->setMinimum(0);
        index_4112_progress->setMaximum(100);
        index_4112_progress->setValue(0);

        gridLayout->addWidget(index_4112_progress, 13, 5, 1, 1);

        index_4215_cancel = new QPushButton(groupBox);
        index_4215_cancel->setObjectName("index_4215_cancel");
        sizePolicy.setHeightForWidth(index_4215_cancel->sizePolicy().hasHeightForWidth());
        index_4215_cancel->setSizePolicy(sizePolicy);
        index_4215_cancel->setMinimumSize(QSize(15, 15));
        index_4215_cancel->setMaximumSize(QSize(15, 15));
        QPalette palette31;
        palette31.setBrush(QPalette::ColorGroup::Active, QPalette::ColorRole::ButtonText, brush);
        palette31.setBrush(QPalette::ColorGroup::Inactive, QPalette::ColorRole::ButtonText, brush);
        palette31.setBrush(QPalette::ColorGroup::Disabled, QPalette::ColorRole::ButtonText, brush1);
        index_4215_cancel->setPalette(palette31);

        gridLayout->addWidget(index_4215_cancel, 9, 1, 1, 1);

        label_42 = new QLabel(groupBox);
        label_42->setObjectName("label_42");

        gridLayout->addWidget(label_42, 11, 4, 1, 1);

        label_66 = new QLabel(groupBox);
        label_66->setObjectName("label_66");

        gridLayout->addWidget(label_66, 19, 11, 1, 1);

        index_4203_cancel = new QPushButton(groupBox);
        index_4203_cancel->setObjectName("index_4203_cancel");
        sizePolicy.setHeightForWidth(index_4203_cancel->sizePolicy().hasHeightForWidth());
        index_4203_cancel->setSizePolicy(sizePolicy);
        index_4203_cancel->setMinimumSize(QSize(15, 15));
        index_4203_cancel->setMaximumSize(QSize(15, 15));
        QPalette palette32;
        palette32.setBrush(QPalette::ColorGroup::Active, QPalette::ColorRole::ButtonText, brush);
        palette32.setBrush(QPalette::ColorGroup::Inactive, QPalette::ColorRole::ButtonText, brush);
        palette32.setBrush(QPalette::ColorGroup::Disabled, QPalette::ColorRole::ButtonText, brush1);
        index_4203_cancel->setPalette(palette32);

        gridLayout->addWidget(index_4203_cancel, 28, 1, 1, 1);

        label_62 = new QLabel(groupBox);
        label_62->setObjectName("label_62");

        gridLayout->addWidget(label_62, 11, 11, 1, 1);

        label_56 = new QLabel(groupBox);
        label_56->setObjectName("label_56");

        gridLayout->addWidget(label_56, 3, 11, 1, 1);

        index_5202 = new QCheckBox(groupBox);
        index_5202->setObjectName("index_5202");

        gridLayout->addWidget(index_5202, 29, 10, 1, 1);

        horizontalLayout_2 = new QHBoxLayout();
        horizontalLayout_2->setObjectName("horizontalLayout_2");
        horizontalLayout_2->setContentsMargins(0, -1, -1, -1);
        label_8 = new QLabel(groupBox);
        label_8->setObjectName("label_8");

        horizontalLayout_2->addWidget(label_8);

        index_4207_progress = new QProgressBar(groupBox);
        index_4207_progress->setObjectName("index_4207_progress");
        sizePolicy1.setHeightForWidth(index_4207_progress->sizePolicy().hasHeightForWidth());
        index_4207_progress->setSizePolicy(sizePolicy1);
        index_4207_progress->setMinimumSize(QSize(0, 0));
        index_4207_progress->setMaximumSize(QSize(75, 20));
        index_4207_progress->setMinimum(0);
        index_4207_progress->setMaximum(100);
        index_4207_progress->setValue(0);

        horizontalLayout_2->addWidget(index_4207_progress);

        index_4207_info = new QLabel(groupBox);
        index_4207_info->setObjectName("index_4207_info");

        horizontalLayout_2->addWidget(index_4207_info);


        gridLayout->addLayout(horizontalLayout_2, 24, 0, 1, 1);

        index_5206_cancel = new QPushButton(groupBox);
        index_5206_cancel->setObjectName("index_5206_cancel");
        sizePolicy.setHeightForWidth(index_5206_cancel->sizePolicy().hasHeightForWidth());
        index_5206_cancel->setSizePolicy(sizePolicy);
        index_5206_cancel->setMinimumSize(QSize(15, 15));
        index_5206_cancel->setMaximumSize(QSize(15, 15));
        QPalette palette33;
        palette33.setBrush(QPalette::ColorGroup::Active, QPalette::ColorRole::ButtonText, brush);
        palette33.setBrush(QPalette::ColorGroup::Inactive, QPalette::ColorRole::ButtonText, brush);
        palette33.setBrush(QPalette::ColorGroup::Disabled, QPalette::ColorRole::ButtonText, brush1);
        index_5206_cancel->setPalette(palette33);

        gridLayout->addWidget(index_5206_cancel, 25, 7, 1, 1);

        index_5205_cancel = new QPushButton(groupBox);
        index_5205_cancel->setObjectName("index_5205_cancel");
        sizePolicy.setHeightForWidth(index_5205_cancel->sizePolicy().hasHeightForWidth());
        index_5205_cancel->setSizePolicy(sizePolicy);
        index_5205_cancel->setMinimumSize(QSize(15, 15));
        index_5205_cancel->setMaximumSize(QSize(15, 15));
        QPalette palette34;
        palette34.setBrush(QPalette::ColorGroup::Active, QPalette::ColorRole::ButtonText, brush);
        palette34.setBrush(QPalette::ColorGroup::Inactive, QPalette::ColorRole::ButtonText, brush);
        palette34.setBrush(QPalette::ColorGroup::Disabled, QPalette::ColorRole::ButtonText, brush1);
        index_5205_cancel->setPalette(palette34);

        gridLayout->addWidget(index_5205_cancel, 26, 7, 1, 1);

        index_5204_cancel = new QPushButton(groupBox);
        index_5204_cancel->setObjectName("index_5204_cancel");
        sizePolicy.setHeightForWidth(index_5204_cancel->sizePolicy().hasHeightForWidth());
        index_5204_cancel->setSizePolicy(sizePolicy);
        index_5204_cancel->setMinimumSize(QSize(15, 15));
        index_5204_cancel->setMaximumSize(QSize(15, 15));
        QPalette palette35;
        palette35.setBrush(QPalette::ColorGroup::Active, QPalette::ColorRole::ButtonText, brush);
        palette35.setBrush(QPalette::ColorGroup::Inactive, QPalette::ColorRole::ButtonText, brush);
        palette35.setBrush(QPalette::ColorGroup::Disabled, QPalette::ColorRole::ButtonText, brush1);
        index_5204_cancel->setPalette(palette35);

        gridLayout->addWidget(index_5204_cancel, 27, 7, 1, 1);

        index_5203_cancel = new QPushButton(groupBox);
        index_5203_cancel->setObjectName("index_5203_cancel");
        sizePolicy.setHeightForWidth(index_5203_cancel->sizePolicy().hasHeightForWidth());
        index_5203_cancel->setSizePolicy(sizePolicy);
        index_5203_cancel->setMinimumSize(QSize(15, 15));
        index_5203_cancel->setMaximumSize(QSize(15, 15));
        QPalette palette36;
        palette36.setBrush(QPalette::ColorGroup::Active, QPalette::ColorRole::ButtonText, brush);
        palette36.setBrush(QPalette::ColorGroup::Inactive, QPalette::ColorRole::ButtonText, brush);
        palette36.setBrush(QPalette::ColorGroup::Disabled, QPalette::ColorRole::ButtonText, brush1);
        index_5203_cancel->setPalette(palette36);

        gridLayout->addWidget(index_5203_cancel, 28, 7, 1, 1);

        index_5202_cancel = new QPushButton(groupBox);
        index_5202_cancel->setObjectName("index_5202_cancel");
        sizePolicy.setHeightForWidth(index_5202_cancel->sizePolicy().hasHeightForWidth());
        index_5202_cancel->setSizePolicy(sizePolicy);
        index_5202_cancel->setMinimumSize(QSize(15, 15));
        index_5202_cancel->setMaximumSize(QSize(15, 15));
        QPalette palette37;
        palette37.setBrush(QPalette::ColorGroup::Active, QPalette::ColorRole::ButtonText, brush);
        palette37.setBrush(QPalette::ColorGroup::Inactive, QPalette::ColorRole::ButtonText, brush);
        palette37.setBrush(QPalette::ColorGroup::Disabled, QPalette::ColorRole::ButtonText, brush1);
        index_5202_cancel->setPalette(palette37);

        gridLayout->addWidget(index_5202_cancel, 29, 7, 1, 1);

        index_5201_cancel = new QPushButton(groupBox);
        index_5201_cancel->setObjectName("index_5201_cancel");
        sizePolicy.setHeightForWidth(index_5201_cancel->sizePolicy().hasHeightForWidth());
        index_5201_cancel->setSizePolicy(sizePolicy);
        index_5201_cancel->setMinimumSize(QSize(15, 15));
        index_5201_cancel->setMaximumSize(QSize(15, 15));
        QPalette palette38;
        palette38.setBrush(QPalette::ColorGroup::Active, QPalette::ColorRole::ButtonText, brush);
        palette38.setBrush(QPalette::ColorGroup::Inactive, QPalette::ColorRole::ButtonText, brush);
        palette38.setBrush(QPalette::ColorGroup::Disabled, QPalette::ColorRole::ButtonText, brush1);
        index_5201_cancel->setPalette(palette38);

        gridLayout->addWidget(index_5201_cancel, 30, 7, 1, 1);

        index_5200_cancel = new QPushButton(groupBox);
        index_5200_cancel->setObjectName("index_5200_cancel");
        sizePolicy.setHeightForWidth(index_5200_cancel->sizePolicy().hasHeightForWidth());
        index_5200_cancel->setSizePolicy(sizePolicy);
        index_5200_cancel->setMinimumSize(QSize(15, 15));
        index_5200_cancel->setMaximumSize(QSize(15, 15));
        QPalette palette39;
        palette39.setBrush(QPalette::ColorGroup::Active, QPalette::ColorRole::ButtonText, brush);
        palette39.setBrush(QPalette::ColorGroup::Inactive, QPalette::ColorRole::ButtonText, brush);
        palette39.setBrush(QPalette::ColorGroup::Disabled, QPalette::ColorRole::ButtonText, brush1);
        index_5200_cancel->setPalette(palette39);

        gridLayout->addWidget(index_5200_cancel, 31, 7, 1, 1);

        index_5206_info = new QLabel(groupBox);
        index_5206_info->setObjectName("index_5206_info");

        gridLayout->addWidget(index_5206_info, 25, 6, 1, 1);

        index_5205_info = new QLabel(groupBox);
        index_5205_info->setObjectName("index_5205_info");

        gridLayout->addWidget(index_5205_info, 26, 6, 1, 1);

        index_5204_info = new QLabel(groupBox);
        index_5204_info->setObjectName("index_5204_info");

        gridLayout->addWidget(index_5204_info, 27, 6, 1, 1);

        index_5203_info = new QLabel(groupBox);
        index_5203_info->setObjectName("index_5203_info");

        gridLayout->addWidget(index_5203_info, 28, 6, 1, 1);

        index_5202_info = new QLabel(groupBox);
        index_5202_info->setObjectName("index_5202_info");

        gridLayout->addWidget(index_5202_info, 29, 6, 1, 1);

        index_5201_info = new QLabel(groupBox);
        index_5201_info->setObjectName("index_5201_info");

        gridLayout->addWidget(index_5201_info, 30, 6, 1, 1);

        index_5200_info = new QLabel(groupBox);
        index_5200_info->setObjectName("index_5200_info");

        gridLayout->addWidget(index_5200_info, 31, 6, 1, 1);

        index_5206_progress = new QProgressBar(groupBox);
        index_5206_progress->setObjectName("index_5206_progress");
        sizePolicy1.setHeightForWidth(index_5206_progress->sizePolicy().hasHeightForWidth());
        index_5206_progress->setSizePolicy(sizePolicy1);
        index_5206_progress->setMinimumSize(QSize(0, 0));
        index_5206_progress->setMaximumSize(QSize(75, 20));
        index_5206_progress->setMinimum(0);
        index_5206_progress->setMaximum(100);
        index_5206_progress->setValue(0);

        gridLayout->addWidget(index_5206_progress, 25, 5, 1, 1);

        index_5205_progress = new QProgressBar(groupBox);
        index_5205_progress->setObjectName("index_5205_progress");
        sizePolicy1.setHeightForWidth(index_5205_progress->sizePolicy().hasHeightForWidth());
        index_5205_progress->setSizePolicy(sizePolicy1);
        index_5205_progress->setMinimumSize(QSize(0, 0));
        index_5205_progress->setMaximumSize(QSize(75, 20));
        index_5205_progress->setMinimum(0);
        index_5205_progress->setMaximum(100);
        index_5205_progress->setValue(0);

        gridLayout->addWidget(index_5205_progress, 26, 5, 1, 1);

        index_5204_progress = new QProgressBar(groupBox);
        index_5204_progress->setObjectName("index_5204_progress");
        sizePolicy1.setHeightForWidth(index_5204_progress->sizePolicy().hasHeightForWidth());
        index_5204_progress->setSizePolicy(sizePolicy1);
        index_5204_progress->setMinimumSize(QSize(0, 0));
        index_5204_progress->setMaximumSize(QSize(75, 20));
        index_5204_progress->setMinimum(0);
        index_5204_progress->setMaximum(100);
        index_5204_progress->setValue(0);

        gridLayout->addWidget(index_5204_progress, 27, 5, 1, 1);

        index_5203_progress = new QProgressBar(groupBox);
        index_5203_progress->setObjectName("index_5203_progress");
        sizePolicy1.setHeightForWidth(index_5203_progress->sizePolicy().hasHeightForWidth());
        index_5203_progress->setSizePolicy(sizePolicy1);
        index_5203_progress->setMinimumSize(QSize(0, 0));
        index_5203_progress->setMaximumSize(QSize(75, 20));
        index_5203_progress->setMinimum(0);
        index_5203_progress->setMaximum(100);
        index_5203_progress->setValue(0);

        gridLayout->addWidget(index_5203_progress, 28, 5, 1, 1);

        index_5202_progress = new QProgressBar(groupBox);
        index_5202_progress->setObjectName("index_5202_progress");
        sizePolicy1.setHeightForWidth(index_5202_progress->sizePolicy().hasHeightForWidth());
        index_5202_progress->setSizePolicy(sizePolicy1);
        index_5202_progress->setMinimumSize(QSize(0, 0));
        index_5202_progress->setMaximumSize(QSize(75, 20));
        index_5202_progress->setMinimum(0);
        index_5202_progress->setMaximum(100);
        index_5202_progress->setValue(0);

        gridLayout->addWidget(index_5202_progress, 29, 5, 1, 1);

        index_5201_progress = new QProgressBar(groupBox);
        index_5201_progress->setObjectName("index_5201_progress");
        sizePolicy1.setHeightForWidth(index_5201_progress->sizePolicy().hasHeightForWidth());
        index_5201_progress->setSizePolicy(sizePolicy1);
        index_5201_progress->setMinimumSize(QSize(0, 0));
        index_5201_progress->setMaximumSize(QSize(75, 20));
        index_5201_progress->setMinimum(0);
        index_5201_progress->setMaximum(100);
        index_5201_progress->setValue(0);

        gridLayout->addWidget(index_5201_progress, 30, 5, 1, 1);

        index_5200_progress = new QProgressBar(groupBox);
        index_5200_progress->setObjectName("index_5200_progress");
        sizePolicy1.setHeightForWidth(index_5200_progress->sizePolicy().hasHeightForWidth());
        index_5200_progress->setSizePolicy(sizePolicy1);
        index_5200_progress->setMinimumSize(QSize(0, 0));
        index_5200_progress->setMaximumSize(QSize(75, 20));
        index_5200_progress->setMinimum(0);
        index_5200_progress->setMaximum(100);
        index_5200_progress->setValue(0);

        gridLayout->addWidget(index_5200_progress, 31, 5, 1, 1);


        horizontalLayout->addWidget(groupBox);


        verticalLayout->addLayout(horizontalLayout);


        retranslateUi(OpsAstrometryIndexFiles);

        QMetaObject::connectSlotsByName(OpsAstrometryIndexFiles);
    } // setupUi

    void retranslateUi(QDialog *OpsAstrometryIndexFiles)
    {
        OpsAstrometryIndexFiles->setWindowTitle(tr2i18n("Dialog", nullptr));
        label_30->setText(tr2i18n("<html><head/><body><p><span style=\" font-weight:600;\">Offline</span> astrometry.net solver requires index files in order to solve an image.  Please see the Astrometry.net <a href=\"http://astrometry.net/doc/readme.html\"><span style=\" text-decoration: underline; color:#0000ff;\">README</span></a> for details. The following list provides a complete list of the index files, along with recommended index files to install given the current CCD Field of View. Installed index files are checked. Next to each index file is an icon that represents the following:</p></body></html>", nullptr));
#if QT_CONFIG(tooltip)
        required_legend->setToolTip(tr2i18n("<html><head/><body><p>This index file is required and must be installed for the solver to work correctly.</p></body></html>", nullptr));
#endif // QT_CONFIG(tooltip)
        required_legend->setText(QString());
#if QT_CONFIG(tooltip)
        label_32->setToolTip(tr2i18n("<html><head/><body><p>This index file is required and must be installed for the solver to work correctly.</p></body></html>", nullptr));
#endif // QT_CONFIG(tooltip)
        label_32->setText(tr2i18n("Required", nullptr));
#if QT_CONFIG(tooltip)
        recommended_legend->setToolTip(tr2i18n("<html><head/><body><p>This index file is recommended. Installing the index file might help in improving the solver.</p></body></html>", nullptr));
#endif // QT_CONFIG(tooltip)
        recommended_legend->setText(QString());
#if QT_CONFIG(tooltip)
        label_33->setToolTip(tr2i18n("<html><head/><body><p>This index file is recommended. Installing the index file might help in improving the solver.</p></body></html>", nullptr));
#endif // QT_CONFIG(tooltip)
        label_33->setText(tr2i18n("Recommended", nullptr));
#if QT_CONFIG(tooltip)
        optional_legend->setToolTip(tr2i18n("<html><head/><body><p>This index file is not required.</p></body></html>", nullptr));
#endif // QT_CONFIG(tooltip)
        optional_legend->setText(QString());
#if QT_CONFIG(tooltip)
        label_35->setToolTip(tr2i18n("<html><head/><body><p>This index file is not required.</p></body></html>", nullptr));
#endif // QT_CONFIG(tooltip)
        label_35->setText(tr2i18n("Optional", nullptr));
#if QT_CONFIG(tooltip)
        label_27->setToolTip(tr2i18n("<html><head/><body><p>This displays the path to the folder for the Astrometry Index Files on your computer.</p></body></html>", nullptr));
#endif // QT_CONFIG(tooltip)
        label_27->setText(tr2i18n("Index Files Location: ", nullptr));
#if QT_CONFIG(tooltip)
        label_31->setToolTip(tr2i18n("<html><head/><body><p>This displays the current CCD field of view that will be used to calculate which index files are needed.</p></body></html>", nullptr));
#endif // QT_CONFIG(tooltip)
        label_31->setText(tr2i18n("Folder Details:", nullptr));
#if QT_CONFIG(tooltip)
        addIndexFileDirectory->setToolTip(tr2i18n("Add a folder where index files are stored", nullptr));
#endif // QT_CONFIG(tooltip)
        addIndexFileDirectory->setText(tr2i18n("+", nullptr));
#if QT_CONFIG(tooltip)
        removeIndexFileDirectory->setToolTip(tr2i18n("Remove an index files location", nullptr));
#endif // QT_CONFIG(tooltip)
        removeIndexFileDirectory->setText(tr2i18n("-", nullptr));
#if QT_CONFIG(tooltip)
        openIndexFileDirectory->setToolTip(tr2i18n("<html><head/><body><p>This button will open the Astrometry Index File folder on your filesystem so that you can see where it is located and copy files into it if needed.</p></body></html>", nullptr));
#endif // QT_CONFIG(tooltip)
        openIndexFileDirectory->setText(tr2i18n("Open", "opens astrometry index file directory"));
#if QT_CONFIG(tooltip)
        label_28->setToolTip(tr2i18n("<html><head/><body><p>This displays the current CCD field of view that will be used to calculate which index files are needed.</p></body></html>", nullptr));
#endif // QT_CONFIG(tooltip)
        label_28->setText(tr2i18n("Current CCD FOV: ", nullptr));
#if QT_CONFIG(tooltip)
        label_24->setToolTip(tr2i18n("The URL of the server where index files live", nullptr));
#endif // QT_CONFIG(tooltip)
        label_24->setText(tr2i18n("Index Files URL:", nullptr));
        indexURL->setText(QString());
        indexURL->setPlaceholderText(tr2i18n("http://data.astrometry.net/", nullptr));
#if QT_CONFIG(tooltip)
        groupBox->setToolTip(QString());
#endif // QT_CONFIG(tooltip)
        groupBox->setTitle(tr2i18n("Index Files", nullptr));
        index_5200->setText(tr2i18n("index-5200-*.fits", nullptr));
        label_14->setText(tr2i18n("170' - 240'", nullptr));
        index_4209_cancel->setText(tr2i18n("X", nullptr));
        index_4210->setText(tr2i18n("index-4210.fits", nullptr));
        label_11->setText(tr2i18n("60' - 85'", nullptr));
        index_4210_progress->setFormat(tr2i18n("%p%", nullptr));
        index_4210_perc->setText(tr2i18n("perc", nullptr));
        label_73->setText(tr2i18n("(615 M)", nullptr));
        label_65->setText(tr2i18n("(24 M)", nullptr));
        label_13->setText(tr2i18n("120' - 170'", nullptr));
        index_4212_progress->setFormat(tr2i18n("%p%", nullptr));
        index_4212_perc->setText(tr2i18n("perc", nullptr));
        index_4107_cancel->setText(tr2i18n("X", nullptr));
        label_22->setText(tr2i18n("Tycho2/Gaia Catalog", nullptr));
        index_4217_cancel->setText(tr2i18n("X", nullptr));
        label_52->setText(tr2i18n("(2.5 G)", nullptr));
        index_4112->setText(tr2i18n("index-4112.fits", nullptr));
        index_4211_cancel->setText(tr2i18n("X", nullptr));
        index_5203->setText(tr2i18n("index-5203-*.fits", nullptr));
        index_4219_cancel->setText(tr2i18n("X", nullptr));
        index_4213->setText(tr2i18n("index-4213.fits", nullptr));
        index_4219->setText(tr2i18n("index-4219.fits", nullptr));
        index_4200->setText(tr2i18n("index-4200-*.fits", nullptr));
        label_76->setText(tr2i18n("(8.8 G)", nullptr));
        label_58->setText(tr2i18n("(242 K)", nullptr));
        index_4109_progress->setFormat(tr2i18n("%p%", nullptr));
        index_4212_cancel->setText(tr2i18n("X", nullptr));
        index_4217->setText(tr2i18n("index-4217.fits", nullptr));
        label_63->setText(tr2i18n("(5.1 M)", nullptr));
        label_45->setText(tr2i18n("(20 M)", nullptr));
        index_4111_cancel->setText(tr2i18n("X", nullptr));
        label_67->setText(tr2i18n("(90 M)", nullptr));
        index_4215->setText(tr2i18n("index-4215.fits", nullptr));
        index_4218_cancel->setText(tr2i18n("X", nullptr));
        label_10->setText(tr2i18n("42' - 60'", nullptr));
        index_4209_progress->setFormat(tr2i18n("%p%", nullptr));
        index_4209_perc->setText(tr2i18n("perc", nullptr));
        label_7->setText(tr2i18n("16' - 22'", nullptr));
        index_4206_progress->setFormat(tr2i18n("%p%", nullptr));
        index_4206_info->setText(tr2i18n("info", nullptr));
        label_68->setText(tr2i18n("(157 M)", nullptr));
        label_3->setText(tr2i18n("4.0' - 5.6'", nullptr));
        index_4202_progress->setFormat(tr2i18n("%p%", nullptr));
        index_4202_info->setText(tr2i18n("info", nullptr));
        label_38->setText(tr2i18n("(208 K)", nullptr));
        label_55->setText(tr2i18n("(13.6 G)", nullptr));
        label_74->setText(tr2i18n("(1.2 G)", nullptr));
        index_4115->setText(tr2i18n("index-4115.fits", nullptr));
        label_23->setText(tr2i18n("SkyMark", nullptr));
        index_4206->setText(tr2i18n("index-4206-*.fits", nullptr));
        index_4218->setText(tr2i18n("index-4218.fits", nullptr));
        label_50->setText(tr2i18n("(624 M)", nullptr));
        index_4107_perc->setText(tr2i18n("perc", nullptr));
        index_4202_cancel->setText(tr2i18n("X", nullptr));
        index_4114_cancel->setText(tr2i18n("X", nullptr));
        index_4201->setText(tr2i18n("index-4201-*.fits", nullptr));
        label_53->setText(tr2i18n("(4.8 G)", nullptr));
        index_4108->setText(tr2i18n("index-4108.fits", nullptr));
        index_4208->setText(tr2i18n("index-4208.fits", nullptr));
        index_4207->setText(tr2i18n("index-4207-*.fits", nullptr));
        index_4115_cancel->setText(tr2i18n("X", nullptr));
        index_4204_cancel->setText(tr2i18n("X", nullptr));
        index_4213_cancel->setText(tr2i18n("X", nullptr));
        label_40->setText(tr2i18n("(582 K)", nullptr));
        index_4111_progress->setFormat(tr2i18n("%p%", nullptr));
        index_4112_cancel->setText(tr2i18n("X", nullptr));
        index_4110->setText(tr2i18n("index-4110.fits", nullptr));
        index_4109->setText(tr2i18n("index-4109.fits", nullptr));
        index_4212->setText(tr2i18n("index-4212.fits", nullptr));
        label_60->setText(tr2i18n("(723 K)", nullptr));
        index_4203->setText(tr2i18n("index-4203-*.fits", nullptr));
        index_4216_cancel->setText(tr2i18n("X", nullptr));
        index_4113_cancel->setText(tr2i18n("X", nullptr));
        index_4214_cancel->setText(tr2i18n("X", nullptr));
        label_37->setText(tr2i18n("(160 K)", nullptr));
        label->setText(tr2i18n("2.0' - 2.8'", nullptr));
        index_4200_progress->setFormat(tr2i18n("%p%", nullptr));
        index_4200_info->setText(tr2i18n("info", nullptr));
        index_4209->setText(tr2i18n("index-4209.fits", nullptr));
        index_4110_perc->setText(tr2i18n("perc", nullptr));
        index_4205->setText(tr2i18n("index-4205-*.fits", nullptr));
        label_39->setText(tr2i18n("(332 K)", nullptr));
        index_4116_cancel->setText(tr2i18n("X", nullptr));
        index_4214->setText(tr2i18n("index-4214.fits", nullptr));
        index_4107->setText(tr2i18n("index-4107.fits", nullptr));
        index_4118_cancel->setText(tr2i18n("X", nullptr));
        index_4114->setText(tr2i18n("index-4114.fits", nullptr));
        label_44->setText(tr2i18n("(7.6 M)", nullptr));
        label_4->setText(tr2i18n("5.6' - 8.0'", nullptr));
        index_4203_progress->setFormat(tr2i18n("%p%", nullptr));
        index_4203_info->setText(tr2i18n("info", nullptr));
        label_43->setText(tr2i18n("(4 M)", nullptr));
        label_78->setText(tr2i18n("(13.6 G)", nullptr));
        index_4108_cancel->setText(tr2i18n("X", nullptr));
        index_4108_progress->setFormat(tr2i18n("%p%", nullptr));
        index_5206->setText(tr2i18n("index-5206-*.fits", nullptr));
        label_15->setText(tr2i18n("240' - 340'", nullptr));
        index_4207_cancel->setText(tr2i18n("X", nullptr));
        index_4117_cancel->setText(tr2i18n("X", nullptr));
        index_4117->setText(tr2i18n("index-4117.fits", nullptr));
        index_4112_perc->setText(tr2i18n("perc", nullptr));
        index_4205_cancel->setText(tr2i18n("X", nullptr));
        label_6->setText(tr2i18n("11' - 16'", nullptr));
        index_4205_progress->setFormat(tr2i18n("%p%", nullptr));
        index_4205_info->setText(tr2i18n("info", nullptr));
        label_54->setText(tr2i18n("(8.8 G)", nullptr));
        label_9->setText(tr2i18n("30' - 42'", nullptr));
        index_4208_progress->setFormat(tr2i18n("%p%", nullptr));
        index_4208_perc->setText(tr2i18n("perc", nullptr));
        index_4119->setText(tr2i18n("index-4119.fits", nullptr));
        label_2->setText(tr2i18n("2.8' - 4.0'", nullptr));
        index_4201_progress->setFormat(tr2i18n("%p%", nullptr));
        index_4201_info->setText(tr2i18n("info", nullptr));
        label_61->setText(tr2i18n("(1.3 M)", nullptr));
        index_4110_progress->setFormat(tr2i18n("%p%", nullptr));
        index_4109_perc->setText(tr2i18n("perc", nullptr));
        label_49->setText(tr2i18n("(312 M)", nullptr));
        label_69->setText(tr2i18n("Diameters", nullptr));
        label_48->setText(tr2i18n("(156 M)", nullptr));
        label_26->setText(tr2i18n("(arcminutes)", nullptr));
        label_47->setText(tr2i18n("(78 M)", nullptr));
        index_4211->setText(tr2i18n("index-4211.fits", nullptr));
        index_4210_cancel->setText(tr2i18n("X", nullptr));
        index_4216->setText(tr2i18n("index-4216.fits", nullptr));
        index_4208_cancel->setText(tr2i18n("X", nullptr));
        index_4110_cancel->setText(tr2i18n("X", nullptr));
        index_4201_cancel->setText(tr2i18n("X", nullptr));
        label_16->setText(tr2i18n("340' - 480'", nullptr));
        label_134->setText(tr2i18n("(filesize)", nullptr));
        index_4202->setText(tr2i18n("index-4202-*.fits", nullptr));
        index_4111->setText(tr2i18n("index-4111.fits", nullptr));
        label_19->setText(tr2i18n("1000' - 1400'", nullptr));
        index_4111_perc->setText(tr2i18n("perc", nullptr));
        index_4108_perc->setText(tr2i18n("perc", nullptr));
        index_4113->setText(tr2i18n("index-4113.fits", nullptr));
        label_20->setText(tr2i18n("1400' - 2000'", nullptr));
        label_18->setText(tr2i18n("680' - 1000'", nullptr));
        label_29->setText(tr2i18n("(129 K)", nullptr));
        index_4119_cancel->setText(tr2i18n("X", nullptr));
        label_135->setText(tr2i18n("(filesize)", nullptr));
        label_46->setText(tr2i18n("(39 M)", nullptr));
        index_4200_cancel->setText(tr2i18n("X", nullptr));
        label_57->setText(tr2i18n("(183 K)", nullptr));
        label_51->setText(tr2i18n("(1.2 G)", nullptr));
        label_5->setText(tr2i18n("8' - 11'", nullptr));
        index_4204_progress->setFormat(tr2i18n("%p%", nullptr));
        index_4204_info->setText(tr2i18n("info", nullptr));
        label_21->setText(tr2i18n("2Mass Catalog", nullptr));
        index_5205->setText(tr2i18n("index-5205-*.fits", nullptr));
        label_59->setText(tr2i18n("(399 K)", nullptr));
        index_4107_progress->setFormat(tr2i18n("%p%", nullptr));
        label_17->setText(tr2i18n("480' - 680'", nullptr));
        index_4109_cancel->setText(tr2i18n("X", nullptr));
        index_4116->setText(tr2i18n("index-4116.fits", nullptr));
        index_4206_cancel->setText(tr2i18n("X", nullptr));
        label_75->setText(tr2i18n("(2.5 G)", nullptr));
        index_4118->setText(tr2i18n("index-4118.fits", nullptr));
        index_5204->setText(tr2i18n("index-5204-*.fits", nullptr));
        index_5201->setText(tr2i18n("index-5201-*.fits", nullptr));
        label_64->setText(tr2i18n("(9.7 M)", nullptr));
        label_41->setText(tr2i18n("(1 M)", nullptr));
        label_72->setText(tr2i18n("(310 M)", nullptr));
        label_77->setText(tr2i18n("(4.8 G)", nullptr));
        index_4204->setText(tr2i18n("index-4204-*.fits", nullptr));
        label_12->setText(tr2i18n("85' - 120'", nullptr));
        index_4211_progress->setFormat(tr2i18n("%p%", nullptr));
        index_4211_perc->setText(tr2i18n("perc", nullptr));
        index_4112_progress->setFormat(tr2i18n("%p%", nullptr));
        index_4215_cancel->setText(tr2i18n("X", nullptr));
        label_42->setText(tr2i18n("(2.1 M)", nullptr));
        label_66->setText(tr2i18n("(47 M)", nullptr));
        index_4203_cancel->setText(tr2i18n("X", nullptr));
        label_62->setText(tr2i18n("(2.6 M)", nullptr));
        label_56->setText(tr2i18n("(141 K)", nullptr));
        index_5202->setText(tr2i18n("index-5202-*.fits", nullptr));
        label_8->setText(tr2i18n("22' - 30'", nullptr));
        index_4207_progress->setFormat(tr2i18n("%p%", nullptr));
        index_4207_info->setText(tr2i18n("info", nullptr));
        index_5206_cancel->setText(tr2i18n("X", nullptr));
        index_5205_cancel->setText(tr2i18n("X", nullptr));
        index_5204_cancel->setText(tr2i18n("X", nullptr));
        index_5203_cancel->setText(tr2i18n("X", nullptr));
        index_5202_cancel->setText(tr2i18n("X", nullptr));
        index_5201_cancel->setText(tr2i18n("X", nullptr));
        index_5200_cancel->setText(tr2i18n("X", nullptr));
        index_5206_info->setText(tr2i18n("info", nullptr));
        index_5205_info->setText(tr2i18n("info", nullptr));
        index_5204_info->setText(tr2i18n("info", nullptr));
        index_5203_info->setText(tr2i18n("info", nullptr));
        index_5202_info->setText(tr2i18n("info", nullptr));
        index_5201_info->setText(tr2i18n("info", nullptr));
        index_5200_info->setText(tr2i18n("info", nullptr));
        index_5206_progress->setFormat(tr2i18n("%p%", nullptr));
        index_5205_progress->setFormat(tr2i18n("%p%", nullptr));
        index_5204_progress->setFormat(tr2i18n("%p%", nullptr));
        index_5203_progress->setFormat(tr2i18n("%p%", nullptr));
        index_5202_progress->setFormat(tr2i18n("%p%", nullptr));
        index_5201_progress->setFormat(tr2i18n("%p%", nullptr));
        index_5200_progress->setFormat(tr2i18n("%p%", nullptr));
    } // retranslateUi

};

namespace Ui {
    class OpsAstrometryIndexFiles: public Ui_OpsAstrometryIndexFiles {};
} // namespace Ui

QT_END_NAMESPACE

#endif // OPSASTROMETRYINDEXFILES_H

