/********************************************************************************
** Form generated from reading UI file 'customdrivers.ui'
**
** Created by: Qt User Interface Compiler version 6.11.1
**
** WARNING! All changes made in this file will be lost when recompiling UI file!
********************************************************************************/

#ifndef UI_CUSTOMDRIVERS_H
#define UI_CUSTOMDRIVERS_H

#include <QtCore/QVariant>
#include <QtWidgets/QAbstractButton>
#include <QtWidgets/QApplication>
#include <QtWidgets/QComboBox>
#include <QtWidgets/QDialog>
#include <QtWidgets/QDialogButtonBox>
#include <QtWidgets/QFormLayout>
#include <QtWidgets/QHBoxLayout>
#include <QtWidgets/QHeaderView>
#include <QtWidgets/QLabel>
#include <QtWidgets/QLineEdit>
#include <QtWidgets/QPushButton>
#include <QtWidgets/QSpacerItem>
#include <QtWidgets/QTableView>
#include <QtWidgets/QVBoxLayout>
#include <klocalizedstring.h>

QT_BEGIN_NAMESPACE

class Ui_CustomDrivers
{
public:
    QVBoxLayout *verticalLayout;
    QHBoxLayout *mainLayout;
    QTableView *driversView;
    QFormLayout *formLayout;
    QLabel *label_8;
    QComboBox *driverCombo;
    QLabel *label_9;
    QComboBox *familyCombo;
    QLabel *label_7;
    QLineEdit *execIN;
    QLabel *label_10;
    QLineEdit *nameIN;
    QHBoxLayout *horizontalLayout_3;
    QLabel *label_6;
    QLabel *label_5;
    QLineEdit *labelIN;
    QLabel *label_3;
    QLineEdit *manufacturerIN;
    QHBoxLayout *horizontalLayout;
    QPushButton *removeDriverB;
    QSpacerItem *horizontalSpacer_2;
    QPushButton *addDriverB;
    QHBoxLayout *horizontalLayout_4;
    QLabel *tipLabel;
    QLabel *label;
    QHBoxLayout *horizontalLayout_2;
    QLabel *cautionLabel;
    QLabel *label_2;
    QDialogButtonBox *buttonBox;

    void setupUi(QDialog *CustomDrivers)
    {
        if (CustomDrivers->objectName().isEmpty())
            CustomDrivers->setObjectName("CustomDrivers");
        CustomDrivers->resize(553, 306);
        verticalLayout = new QVBoxLayout(CustomDrivers);
        verticalLayout->setSpacing(3);
        verticalLayout->setObjectName("verticalLayout");
        verticalLayout->setContentsMargins(3, 3, 3, 3);
        mainLayout = new QHBoxLayout();
        mainLayout->setObjectName("mainLayout");
        mainLayout->setContentsMargins(-1, -1, 0, -1);
        driversView = new QTableView(CustomDrivers);
        driversView->setObjectName("driversView");
        driversView->setSelectionBehavior(QAbstractItemView::SelectRows);

        mainLayout->addWidget(driversView);

        formLayout = new QFormLayout();
        formLayout->setObjectName("formLayout");
        formLayout->setHorizontalSpacing(3);
        formLayout->setVerticalSpacing(3);
        label_8 = new QLabel(CustomDrivers);
        label_8->setObjectName("label_8");

        formLayout->setWidget(0, QFormLayout::ItemRole::LabelRole, label_8);

        driverCombo = new QComboBox(CustomDrivers);
        driverCombo->setObjectName("driverCombo");
        QSizePolicy sizePolicy(QSizePolicy::Policy::MinimumExpanding, QSizePolicy::Policy::Fixed);
        sizePolicy.setHorizontalStretch(0);
        sizePolicy.setVerticalStretch(0);
        sizePolicy.setHeightForWidth(driverCombo->sizePolicy().hasHeightForWidth());
        driverCombo->setSizePolicy(sizePolicy);
        driverCombo->setEditable(true);

        formLayout->setWidget(0, QFormLayout::ItemRole::FieldRole, driverCombo);

        label_9 = new QLabel(CustomDrivers);
        label_9->setObjectName("label_9");

        formLayout->setWidget(1, QFormLayout::ItemRole::LabelRole, label_9);

        familyCombo = new QComboBox(CustomDrivers);
        familyCombo->setObjectName("familyCombo");

        formLayout->setWidget(1, QFormLayout::ItemRole::FieldRole, familyCombo);

        label_7 = new QLabel(CustomDrivers);
        label_7->setObjectName("label_7");

        formLayout->setWidget(3, QFormLayout::ItemRole::LabelRole, label_7);

        execIN = new QLineEdit(CustomDrivers);
        execIN->setObjectName("execIN");

        formLayout->setWidget(3, QFormLayout::ItemRole::FieldRole, execIN);

        label_10 = new QLabel(CustomDrivers);
        label_10->setObjectName("label_10");

        formLayout->setWidget(4, QFormLayout::ItemRole::LabelRole, label_10);

        nameIN = new QLineEdit(CustomDrivers);
        nameIN->setObjectName("nameIN");

        formLayout->setWidget(4, QFormLayout::ItemRole::FieldRole, nameIN);

        horizontalLayout_3 = new QHBoxLayout();
        horizontalLayout_3->setSpacing(3);
        horizontalLayout_3->setObjectName("horizontalLayout_3");
        label_6 = new QLabel(CustomDrivers);
        label_6->setObjectName("label_6");

        horizontalLayout_3->addWidget(label_6);

        label_5 = new QLabel(CustomDrivers);
        label_5->setObjectName("label_5");
        label_5->setStyleSheet(QString::fromUtf8("color:red"));

        horizontalLayout_3->addWidget(label_5);


        formLayout->setLayout(5, QFormLayout::ItemRole::LabelRole, horizontalLayout_3);

        labelIN = new QLineEdit(CustomDrivers);
        labelIN->setObjectName("labelIN");

        formLayout->setWidget(5, QFormLayout::ItemRole::FieldRole, labelIN);

        label_3 = new QLabel(CustomDrivers);
        label_3->setObjectName("label_3");

        formLayout->setWidget(2, QFormLayout::ItemRole::LabelRole, label_3);

        manufacturerIN = new QLineEdit(CustomDrivers);
        manufacturerIN->setObjectName("manufacturerIN");

        formLayout->setWidget(2, QFormLayout::ItemRole::FieldRole, manufacturerIN);


        mainLayout->addLayout(formLayout);

        mainLayout->setStretch(0, 3);
        mainLayout->setStretch(1, 1);

        verticalLayout->addLayout(mainLayout);

        horizontalLayout = new QHBoxLayout();
        horizontalLayout->setSpacing(3);
        horizontalLayout->setObjectName("horizontalLayout");
        removeDriverB = new QPushButton(CustomDrivers);
        removeDriverB->setObjectName("removeDriverB");
        removeDriverB->setEnabled(false);

        horizontalLayout->addWidget(removeDriverB);

        horizontalSpacer_2 = new QSpacerItem(40, 20, QSizePolicy::Policy::Expanding, QSizePolicy::Policy::Minimum);

        horizontalLayout->addItem(horizontalSpacer_2);

        addDriverB = new QPushButton(CustomDrivers);
        addDriverB->setObjectName("addDriverB");
        addDriverB->setEnabled(false);

        horizontalLayout->addWidget(addDriverB);


        verticalLayout->addLayout(horizontalLayout);

        horizontalLayout_4 = new QHBoxLayout();
        horizontalLayout_4->setSpacing(3);
        horizontalLayout_4->setObjectName("horizontalLayout_4");
        tipLabel = new QLabel(CustomDrivers);
        tipLabel->setObjectName("tipLabel");
        tipLabel->setMinimumSize(QSize(32, 32));
        tipLabel->setMaximumSize(QSize(32, 32));

        horizontalLayout_4->addWidget(tipLabel);

        label = new QLabel(CustomDrivers);
        label->setObjectName("label");
        label->setWordWrap(true);

        horizontalLayout_4->addWidget(label);


        verticalLayout->addLayout(horizontalLayout_4);

        horizontalLayout_2 = new QHBoxLayout();
        horizontalLayout_2->setSpacing(3);
        horizontalLayout_2->setObjectName("horizontalLayout_2");
        cautionLabel = new QLabel(CustomDrivers);
        cautionLabel->setObjectName("cautionLabel");
        cautionLabel->setMinimumSize(QSize(32, 32));
        cautionLabel->setMaximumSize(QSize(32, 32));

        horizontalLayout_2->addWidget(cautionLabel);

        label_2 = new QLabel(CustomDrivers);
        label_2->setObjectName("label_2");
        label_2->setWordWrap(true);

        horizontalLayout_2->addWidget(label_2);


        verticalLayout->addLayout(horizontalLayout_2);

        buttonBox = new QDialogButtonBox(CustomDrivers);
        buttonBox->setObjectName("buttonBox");
        buttonBox->setOrientation(Qt::Horizontal);
        buttonBox->setStandardButtons(QDialogButtonBox::Close);

        verticalLayout->addWidget(buttonBox);


        retranslateUi(CustomDrivers);
        QObject::connect(buttonBox, &QDialogButtonBox::accepted, CustomDrivers, qOverload<>(&QDialog::accept));
        QObject::connect(buttonBox, &QDialogButtonBox::rejected, CustomDrivers, qOverload<>(&QDialog::reject));

        QMetaObject::connectSlotsByName(CustomDrivers);
    } // setupUi

    void retranslateUi(QDialog *CustomDrivers)
    {
        CustomDrivers->setWindowTitle(tr2i18n("Custom Drivers", nullptr));
        label_8->setText(tr2i18n("Driver:", nullptr));
        label_9->setText(tr2i18n("Family:", nullptr));
        label_7->setText(tr2i18n("Executable:", nullptr));
        label_10->setText(tr2i18n("Name:", nullptr));
        label_6->setText(tr2i18n("Label:", nullptr));
        label_5->setText(tr2i18n("*", nullptr));
        label_3->setText(tr2i18n("Manufacturer:", nullptr));
        removeDriverB->setText(tr2i18n("Remove", nullptr));
        addDriverB->setText(tr2i18n("Add New", nullptr));
        tipLabel->setText(QString());
        label->setText(tr2i18n("<html><head/><body><p>To create an <span style=\" font-weight:600;\">Alias</span> from an existing driver, select an existing driver and then only change the <span style=\" font-weight:600;\">Label </span>then press<span style=\" font-weight:600;\"> Add.</span></p></body></html>", nullptr));
        cautionLabel->setText(QString());
        label_2->setText(tr2i18n("<html><head/><body><p>KStars must be restarted for new drivers to take effect.</p></body></html>", nullptr));
    } // retranslateUi

};

namespace Ui {
    class CustomDrivers: public Ui_CustomDrivers {};
} // namespace Ui

QT_END_NAMESPACE

#endif // CUSTOMDRIVERS_H

