/********************************************************************************
** Form generated from reading UI file 'opsscriptssettings.ui'
**
** Created by: Qt User Interface Compiler version 6.11.1
**
** WARNING! All changes made in this file will be lost when recompiling UI file!
********************************************************************************/

#ifndef UI_OPSSCRIPTSSETTINGS_H
#define UI_OPSSCRIPTSSETTINGS_H

#include <QtCore/QVariant>
#include <QtWidgets/QApplication>
#include <QtWidgets/QCheckBox>
#include <QtWidgets/QHBoxLayout>
#include <QtWidgets/QSpacerItem>
#include <QtWidgets/QSpinBox>
#include <QtWidgets/QVBoxLayout>
#include <QtWidgets/QWidget>
#include <klocalizedstring.h>

QT_BEGIN_NAMESPACE

class Ui_OpsScriptsSettings
{
public:
    QVBoxLayout *verticalLayout;
    QCheckBox *kcfg_StopEkosAfterShutdown;
    QCheckBox *kcfg_ShutdownScriptTerminatesINDI;
    QHBoxLayout *horizontalLayout;
    QCheckBox *kcfg_CameraWarmupEnabled;
    QSpinBox *kcfg_CameraWarmupRamp;
    QSpacerItem *horizontalSpacer;
    QSpacerItem *verticalSpacer;

    void setupUi(QWidget *OpsScriptsSettings)
    {
        if (OpsScriptsSettings->objectName().isEmpty())
            OpsScriptsSettings->setObjectName("OpsScriptsSettings");
        OpsScriptsSettings->resize(328, 90);
        verticalLayout = new QVBoxLayout(OpsScriptsSettings);
        verticalLayout->setSpacing(3);
        verticalLayout->setObjectName("verticalLayout");
        verticalLayout->setContentsMargins(3, 3, 3, 3);
        kcfg_StopEkosAfterShutdown = new QCheckBox(OpsScriptsSettings);
        kcfg_StopEkosAfterShutdown->setObjectName("kcfg_StopEkosAfterShutdown");

        verticalLayout->addWidget(kcfg_StopEkosAfterShutdown);

        kcfg_ShutdownScriptTerminatesINDI = new QCheckBox(OpsScriptsSettings);
        kcfg_ShutdownScriptTerminatesINDI->setObjectName("kcfg_ShutdownScriptTerminatesINDI");

        verticalLayout->addWidget(kcfg_ShutdownScriptTerminatesINDI);

        horizontalLayout = new QHBoxLayout();
        horizontalLayout->setObjectName("horizontalLayout");
        kcfg_CameraWarmupEnabled = new QCheckBox(OpsScriptsSettings);
        kcfg_CameraWarmupEnabled->setObjectName("kcfg_CameraWarmupEnabled");

        horizontalLayout->addWidget(kcfg_CameraWarmupEnabled);

        kcfg_CameraWarmupRamp = new QSpinBox(OpsScriptsSettings);
        kcfg_CameraWarmupRamp->setObjectName("kcfg_CameraWarmupRamp");
        kcfg_CameraWarmupRamp->setMinimum(1);
        kcfg_CameraWarmupRamp->setMaximum(30);
        kcfg_CameraWarmupRamp->setSingleStep(1);
        kcfg_CameraWarmupRamp->setValue(5);

        horizontalLayout->addWidget(kcfg_CameraWarmupRamp);

        horizontalSpacer = new QSpacerItem(40, 20, QSizePolicy::Policy::Expanding, QSizePolicy::Policy::Minimum);

        horizontalLayout->addItem(horizontalSpacer);


        verticalLayout->addLayout(horizontalLayout);

        verticalSpacer = new QSpacerItem(20, 40, QSizePolicy::Policy::Minimum, QSizePolicy::Policy::Expanding);

        verticalLayout->addItem(verticalSpacer);


        retranslateUi(OpsScriptsSettings);

        QMetaObject::connectSlotsByName(OpsScriptsSettings);
    } // setupUi

    void retranslateUi(QWidget *OpsScriptsSettings)
    {
        OpsScriptsSettings->setWindowTitle(tr2i18n("TabWidget", nullptr));
#if QT_CONFIG(tooltip)
        kcfg_StopEkosAfterShutdown->setToolTip(tr2i18n("After shutdown procedure is successfully executed, stop INDI and Ekos.", nullptr));
#endif // QT_CONFIG(tooltip)
        kcfg_StopEkosAfterShutdown->setText(tr2i18n("Stop Ekos after shutdown", nullptr));
#if QT_CONFIG(tooltip)
        kcfg_ShutdownScriptTerminatesINDI->setToolTip(tr2i18n("<html><head/><body><p>If the shutdown script terminates INDI server, enable this option so that no disconnection errors are generated.</p></body></html>", nullptr));
#endif // QT_CONFIG(tooltip)
        kcfg_ShutdownScriptTerminatesINDI->setText(tr2i18n("Shutdown script terminates INDI", nullptr));
#if QT_CONFIG(tooltip)
        kcfg_CameraWarmupEnabled->setToolTip(tr2i18n("Warm up the camera sensor before shutting down.", nullptr));
#endif // QT_CONFIG(tooltip)
        kcfg_CameraWarmupEnabled->setText(tr2i18n("Warm camera before shutdown", nullptr));
#if QT_CONFIG(tooltip)
        kcfg_CameraWarmupRamp->setToolTip(tr2i18n("Temperature ramp rate for camera warmup in \302\260C per minute.", nullptr));
#endif // QT_CONFIG(tooltip)
        kcfg_CameraWarmupRamp->setSuffix(tr2i18n(" \302\260C/min", nullptr));
    } // retranslateUi

};

namespace Ui {
    class OpsScriptsSettings: public Ui_OpsScriptsSettings {};
} // namespace Ui

QT_END_NAMESPACE

#endif // OPSSCRIPTSSETTINGS_H

