/********************************************************************************
** Form generated from reading UI file 'opsdeveloper.ui'
**
** Created by: Qt User Interface Compiler version 6.11.1
**
** WARNING! All changes made in this file will be lost when recompiling UI file!
********************************************************************************/

#ifndef UI_OPSDEVELOPER_H
#define UI_OPSDEVELOPER_H

#include <QtCore/QVariant>
#include <QtWidgets/QApplication>
#include <QtWidgets/QCheckBox>
#include <QtWidgets/QComboBox>
#include <QtWidgets/QGridLayout>
#include <QtWidgets/QGroupBox>
#include <QtWidgets/QLabel>
#include <QtWidgets/QSpacerItem>
#include <QtWidgets/QVBoxLayout>
#include <QtWidgets/QWidget>
#include <klocalizedstring.h>

QT_BEGIN_NAMESPACE

class Ui_OpsDeveloper
{
public:
    QGridLayout *gridLayout;
    QVBoxLayout *verticalLayout;
    QGroupBox *groupBox_2;
    QGridLayout *gridLayout_2;
    QCheckBox *kcfg_SaveAlignImages;
    QCheckBox *kcfg_SaveFailedAlignImages;
    QCheckBox *kcfg_SaveGuideImages;
    QCheckBox *kcfg_SaveFocusImages;
    QCheckBox *kcfg_DontSyncToRealTime;
    QGroupBox *gridGroupBox;
    QGridLayout *gridLayout_3;
    QComboBox *kcfg_ImageDebayerEngine;
    QLabel *label;
    QComboBox *kcfg_ImageDebayerAlgo;
    QLabel *label_2;
    QComboBox *kcfg_StackDebayerEngine;
    QComboBox *kcfg_StackDebayerAlgo;
    QSpacerItem *verticalSpacer;

    void setupUi(QWidget *OpsDeveloper)
    {
        if (OpsDeveloper->objectName().isEmpty())
            OpsDeveloper->setObjectName("OpsDeveloper");
        OpsDeveloper->resize(490, 370);
        gridLayout = new QGridLayout(OpsDeveloper);
        gridLayout->setSpacing(3);
        gridLayout->setObjectName("gridLayout");
        gridLayout->setContentsMargins(3, 3, 3, 3);
        verticalLayout = new QVBoxLayout();
        verticalLayout->setObjectName("verticalLayout");
        groupBox_2 = new QGroupBox(OpsDeveloper);
        groupBox_2->setObjectName("groupBox_2");
        gridLayout_2 = new QGridLayout(groupBox_2);
        gridLayout_2->setObjectName("gridLayout_2");
        kcfg_SaveAlignImages = new QCheckBox(groupBox_2);
        kcfg_SaveAlignImages->setObjectName("kcfg_SaveAlignImages");

        gridLayout_2->addWidget(kcfg_SaveAlignImages, 2, 0, 1, 1);

        kcfg_SaveFailedAlignImages = new QCheckBox(groupBox_2);
        kcfg_SaveFailedAlignImages->setObjectName("kcfg_SaveFailedAlignImages");

        gridLayout_2->addWidget(kcfg_SaveFailedAlignImages, 3, 0, 1, 1);

        kcfg_SaveGuideImages = new QCheckBox(groupBox_2);
        kcfg_SaveGuideImages->setObjectName("kcfg_SaveGuideImages");

        gridLayout_2->addWidget(kcfg_SaveGuideImages, 1, 0, 1, 1);

        kcfg_SaveFocusImages = new QCheckBox(groupBox_2);
        kcfg_SaveFocusImages->setObjectName("kcfg_SaveFocusImages");
        QFont font;
        font.setStrikeOut(true);
        kcfg_SaveFocusImages->setFont(font);

        gridLayout_2->addWidget(kcfg_SaveFocusImages, 0, 0, 1, 1);

        kcfg_DontSyncToRealTime = new QCheckBox(groupBox_2);
        kcfg_DontSyncToRealTime->setObjectName("kcfg_DontSyncToRealTime");

        gridLayout_2->addWidget(kcfg_DontSyncToRealTime, 4, 0, 1, 1);

        gridGroupBox = new QGroupBox(groupBox_2);
        gridGroupBox->setObjectName("gridGroupBox");
        gridGroupBox->setMinimumSize(QSize(0, 50));
        gridLayout_3 = new QGridLayout(gridGroupBox);
        gridLayout_3->setObjectName("gridLayout_3");
        kcfg_ImageDebayerEngine = new QComboBox(gridGroupBox);
        kcfg_ImageDebayerEngine->setObjectName("kcfg_ImageDebayerEngine");

        gridLayout_3->addWidget(kcfg_ImageDebayerEngine, 0, 1, 1, 1);

        label = new QLabel(gridGroupBox);
        label->setObjectName("label");

        gridLayout_3->addWidget(label, 0, 0, 1, 1);

        kcfg_ImageDebayerAlgo = new QComboBox(gridGroupBox);
        kcfg_ImageDebayerAlgo->setObjectName("kcfg_ImageDebayerAlgo");

        gridLayout_3->addWidget(kcfg_ImageDebayerAlgo, 0, 2, 1, 1);

        label_2 = new QLabel(gridGroupBox);
        label_2->setObjectName("label_2");

        gridLayout_3->addWidget(label_2, 1, 0, 1, 1);

        kcfg_StackDebayerEngine = new QComboBox(gridGroupBox);
        kcfg_StackDebayerEngine->setObjectName("kcfg_StackDebayerEngine");

        gridLayout_3->addWidget(kcfg_StackDebayerEngine, 1, 1, 1, 1);

        kcfg_StackDebayerAlgo = new QComboBox(gridGroupBox);
        kcfg_StackDebayerAlgo->setObjectName("kcfg_StackDebayerAlgo");

        gridLayout_3->addWidget(kcfg_StackDebayerAlgo, 1, 2, 1, 1);


        gridLayout_2->addWidget(gridGroupBox, 6, 0, 2, 1);


        verticalLayout->addWidget(groupBox_2);


        gridLayout->addLayout(verticalLayout, 1, 0, 1, 1);

        verticalSpacer = new QSpacerItem(20, 40, QSizePolicy::Policy::Minimum, QSizePolicy::Policy::Expanding);

        gridLayout->addItem(verticalSpacer, 2, 0, 1, 1);

        QWidget::setTabOrder(kcfg_SaveFocusImages, kcfg_SaveGuideImages);
        QWidget::setTabOrder(kcfg_SaveGuideImages, kcfg_SaveAlignImages);

        retranslateUi(OpsDeveloper);

        QMetaObject::connectSlotsByName(OpsDeveloper);
    } // setupUi

    void retranslateUi(QWidget *OpsDeveloper)
    {
        groupBox_2->setTitle(tr2i18n("Developer Options", nullptr));
#if QT_CONFIG(tooltip)
        kcfg_SaveAlignImages->setToolTip(tr2i18n("<html><head/><body><p>Save Internal Align frames. Only enable to troubleshoot align by examining frames. This can consume some extra storage space.</p></body></html>", nullptr));
#endif // QT_CONFIG(tooltip)
        kcfg_SaveAlignImages->setText(tr2i18n("Save Align Images", nullptr));
#if QT_CONFIG(tooltip)
        kcfg_SaveFailedAlignImages->setToolTip(tr2i18n("<html><head/><body><p>Save Align images where align failed. Only enable to troubleshoot align by examining frames. This can consume some extra storage space.</p></body></html>", nullptr));
#endif // QT_CONFIG(tooltip)
        kcfg_SaveFailedAlignImages->setText(tr2i18n("Save Failed Align Images", nullptr));
#if QT_CONFIG(tooltip)
        kcfg_SaveGuideImages->setToolTip(tr2i18n("<html><head/><body><p>Save Internal Guider frames. Only enable to troubleshoot guider by examining frames. This can consume a lot of storage space.</p></body></html>", nullptr));
#endif // QT_CONFIG(tooltip)
        kcfg_SaveGuideImages->setText(tr2i18n("Save Guider Images", nullptr));
#if QT_CONFIG(tooltip)
        kcfg_SaveFocusImages->setToolTip(tr2i18n("<html><head/><body><p>Option replaced by the <span style=\" font-weight:600;\">max. focus frame</span> option in the Focus options.</p></body></html>", nullptr));
#endif // QT_CONFIG(tooltip)
        kcfg_SaveFocusImages->setText(tr2i18n("Save Focus Images", nullptr));
#if QT_CONFIG(tooltip)
        kcfg_DontSyncToRealTime->setToolTip(tr2i18n("<html><head/><body><p>Do not sync to the system clock when Ekos is started. This could cause issues for real imaging runs, but can be useful in reproducing/debugging issues.</p></body></html>", nullptr));
#endif // QT_CONFIG(tooltip)
        kcfg_DontSyncToRealTime->setText(tr2i18n("Don't sync to Real Time on Ekos startup", nullptr));
        gridGroupBox->setTitle(tr2i18n("Debayer Options:", nullptr));
#if QT_CONFIG(tooltip)
        kcfg_ImageDebayerEngine->setToolTip(QString());
#endif // QT_CONFIG(tooltip)
#if QT_CONFIG(tooltip)
        label->setToolTip(tr2i18n("<html><head/><body><p>Debayer parameters to be applied to images.</p></body></html>", nullptr));
#endif // QT_CONFIG(tooltip)
        label->setText(tr2i18n("Image Debayer:", nullptr));
#if QT_CONFIG(tooltip)
        kcfg_ImageDebayerAlgo->setToolTip(QString());
#endif // QT_CONFIG(tooltip)
#if QT_CONFIG(tooltip)
        label_2->setToolTip(tr2i18n("<html><head/><body><p>Debayer parameters to be applied to Live Stacker subs.</p></body></html>", nullptr));
#endif // QT_CONFIG(tooltip)
        label_2->setText(tr2i18n("Stack Sub Debayer:", nullptr));
#if QT_CONFIG(tooltip)
        kcfg_StackDebayerEngine->setToolTip(QString());
#endif // QT_CONFIG(tooltip)
        kcfg_StackDebayerEngine->setCurrentText(QString());
#if QT_CONFIG(tooltip)
        kcfg_StackDebayerAlgo->setToolTip(QString());
#endif // QT_CONFIG(tooltip)
        (void)OpsDeveloper;
    } // retranslateUi

};

namespace Ui {
    class OpsDeveloper: public Ui_OpsDeveloper {};
} // namespace Ui

QT_END_NAMESPACE

#endif // OPSDEVELOPER_H

