/********************************************************************************
** Form generated from reading UI file 'imagingplanneroptions.ui'
**
** Created by: Qt User Interface Compiler version 6.11.1
**
** WARNING! All changes made in this file will be lost when recompiling UI file!
********************************************************************************/

#ifndef UI_IMAGINGPLANNEROPTIONS_H
#define UI_IMAGINGPLANNEROPTIONS_H

#include <QtCore/QVariant>
#include <QtWidgets/QApplication>
#include <QtWidgets/QCheckBox>
#include <QtWidgets/QVBoxLayout>
#include <QtWidgets/QWidget>
#include <klocalizedstring.h>

QT_BEGIN_NAMESPACE

class Ui_ImagingPlannerOptions
{
public:
    QVBoxLayout *vboxLayout;
    QCheckBox *CenterOnSkyMapCB;
    QCheckBox *IndependentWindowCB;
    QCheckBox *StartSolvingImmediatelyCB;

    void setupUi(QWidget *ImagingPlannerOptions)
    {
        if (ImagingPlannerOptions->objectName().isEmpty())
            ImagingPlannerOptions->setObjectName("ImagingPlannerOptions");
        ImagingPlannerOptions->resize(458, 200);
        vboxLayout = new QVBoxLayout(ImagingPlannerOptions);
        vboxLayout->setObjectName("vboxLayout");
        CenterOnSkyMapCB = new QCheckBox(ImagingPlannerOptions);
        CenterOnSkyMapCB->setObjectName("CenterOnSkyMapCB");

        vboxLayout->addWidget(CenterOnSkyMapCB);

        IndependentWindowCB = new QCheckBox(ImagingPlannerOptions);
        IndependentWindowCB->setObjectName("IndependentWindowCB");

        vboxLayout->addWidget(IndependentWindowCB);

        StartSolvingImmediatelyCB = new QCheckBox(ImagingPlannerOptions);
        StartSolvingImmediatelyCB->setObjectName("StartSolvingImmediatelyCB");

        vboxLayout->addWidget(StartSolvingImmediatelyCB);


        retranslateUi(ImagingPlannerOptions);

        QMetaObject::connectSlotsByName(ImagingPlannerOptions);
    } // setupUi

    void retranslateUi(QWidget *ImagingPlannerOptions)
    {
#if QT_CONFIG(tooltip)
        CenterOnSkyMapCB->setToolTip(tr2i18n("<html><head/><body><p>Slew to selected objects on the SkyMap.</p></body></html>", nullptr));
#endif // QT_CONFIG(tooltip)
        CenterOnSkyMapCB->setText(tr2i18n("Center selected object on SkyMap", nullptr));
#if QT_CONFIG(tooltip)
        IndependentWindowCB->setToolTip(tr2i18n("<html><head/><body><p>Make the ImagingPlannerTool an independent window. Would take effect next restart.</p></body></html>", nullptr));
#endif // QT_CONFIG(tooltip)
        IndependentWindowCB->setText(tr2i18n("Independent Window", nullptr));
#if QT_CONFIG(tooltip)
        StartSolvingImmediatelyCB->setToolTip(tr2i18n("<html><head/><body><p>Start solving immediately after taking a screenshot, instead of waiting for the Solve button to be pressed.</p></body></html>", nullptr));
#endif // QT_CONFIG(tooltip)
        StartSolvingImmediatelyCB->setText(tr2i18n("Start Solving Immediately", nullptr));
        (void)ImagingPlannerOptions;
    } // retranslateUi

};

namespace Ui {
    class ImagingPlannerOptions: public Ui_ImagingPlannerOptions {};
} // namespace Ui

QT_END_NAMESPACE

#endif // IMAGINGPLANNEROPTIONS_H

