/********************************************************************************
** Form generated from reading UI file 'imagingplanner.ui'
**
** Created by: Qt User Interface Compiler version 6.11.1
**
** WARNING! All changes made in this file will be lost when recompiling UI file!
********************************************************************************/

#ifndef UI_IMAGINGPLANNER_H
#define UI_IMAGINGPLANNER_H

#include <QtCore/QVariant>
#include <QtGui/QIcon>
#include <QtWidgets/QApplication>
#include <QtWidgets/QCheckBox>
#include <QtWidgets/QDateEdit>
#include <QtWidgets/QDoubleSpinBox>
#include <QtWidgets/QFrame>
#include <QtWidgets/QGridLayout>
#include <QtWidgets/QHBoxLayout>
#include <QtWidgets/QHeaderView>
#include <QtWidgets/QLabel>
#include <QtWidgets/QPushButton>
#include <QtWidgets/QSpacerItem>
#include <QtWidgets/QTableView>
#include <QtWidgets/QTextEdit>
#include <QtWidgets/QVBoxLayout>
#include <QtWidgets/QWidget>
#include <klocalizedstring.h>
#include "auxiliary/minimizewidget.h"
#include "kplotwidget.h"
#include "tools/avtplotwidget.h"

QT_BEGIN_NAMESPACE

class Ui_ImagingPlanner
{
public:
    QVBoxLayout *verticalLayout_2;
    QHBoxLayout *WholeLayout;
    QFrame *TargetCatalog;
    QVBoxLayout *verticalLayout_5;
    QVBoxLayout *tableCountLayout;
    QHBoxLayout *countSearchLayout;
    QPushButton *SearchB;
    QTextEdit *SearchText;
    QLabel *tableCount;
    QTableView *CatalogView;
    QVBoxLayout *RightSideLayoutWithSpacer;
    QFrame *RightPanel;
    QVBoxLayout *RightLayout;
    QHBoxLayout *statusLineLayout;
    QLabel *statusLabel;
    QSpacerItem *horizontalSpacer_1;
    QFrame *topLine;
    QHBoxLayout *LocationTimeLayout;
    QLabel *moonImage;
    QLabel *moonPercentLabel;
    QPushButton *backOneDay;
    QDateEdit *DateEdit;
    QPushButton *forwardOneDay;
    QSpacerItem *horizontalSpacer_2;
    QPushButton *optionsButton;
    QPushButton *helpButton;
    QFrame *DevelFrame;
    QHBoxLayout *DevelLayout;
    QLabel *DevelLabel;
    QPushButton *DevelDownsampleButton;
    QPushButton *DevelCheckTargetsButton;
    QPushButton *DevelCheckCatalogButton;
    QPushButton *DevelCheckTargetsPrevButton;
    QPushButton *DevelCheckTargetsNextButton;
    QFrame *ObjectInfoFrameH;
    QVBoxLayout *objectInfoLayoutV;
    QHBoxLayout *objectInfoLayoutH;
    QGridLayout *objectInfoLayoutGrid;
    QLabel *infoObjectName;
    QLabel *infoObjectType;
    QLabel *infoSize;
    QLabel *infoObjectFlags;
    QLabel *infoObjectLongName;
    QLabel *infoRiseSet;
    QSpacerItem *detailsspacer;
    QHBoxLayout *userNotesLayout;
    QPushButton *userNotesEditButton;
    QPushButton *userNotesDoneButton;
    QPushButton *userNotesOpenLink;
    QPushButton *userNotesOpenLink2;
    QPushButton *userNotesOpenLink3;
    QLabel *userNotesLabel;
    QLabel *userNotes;
    QTextEdit *userNotesEdit;
    QSpacerItem *imageHspacer_1;
    MinimizeWidget *altitudeGraphMinimizeWidget;
    QVBoxLayout *altitudeGraphMinWidgetLayout;
    QFrame *altMaxFrame;
    QHBoxLayout *AltitudeGraphH;
    QHBoxLayout *AltitudeGraphLayout;
    AVTPlotWidget *altitudeGraph;
    QFrame *AltMinFrame;
    QHBoxLayout *AltitudeGraphHiddenLayout;
    QLabel *HiddenAltitudeGraphLabel;
    QSpacerItem *hiddenAltitudeGraphSpacer;
    QFrame *MinControls;
    QHBoxLayout *minControlsLayoutV;
    QGridLayout *minControlsLayout;
    QCheckBox *useArtificialHorizon;
    QLabel *minAltitudeLabel;
    QDoubleSpinBox *minAltitude;
    QLabel *minMoonLabel;
    QDoubleSpinBox *minMoon;
    QDoubleSpinBox *maxMoonAltitude;
    QSpacerItem *minControlsspacer;
    MinimizeWidget *astrobinSearchMinimizeWidget;
    QVBoxLayout *astrobinSearchVerticalLayout;
    QFrame *SearchMaxFrame;
    QHBoxLayout *objectInfoLayoutH2;
    QVBoxLayout *searchLayout1;
    QHBoxLayout *searchLayout2;
    QLabel *SearchLabel;
    QPushButton *astrobinButton;
    QPushButton *searchWikipedia;
    QPushButton *searchSpecialWebPageImages;
    QPushButton *searchSimbad;
    QCheckBox *AstrobinAward;
    QHBoxLayout *searchLayout3;
    QLabel *radiusLabel;
    QLabel *minRadiusLabel;
    QDoubleSpinBox *AstrobinMinRadius;
    QHBoxLayout *layoutMaxRadius;
    QLabel *maxRadiusLabel;
    QDoubleSpinBox *AstrobinMaxRadius;
    QSpacerItem *radius_spacer;
    QSpacerItem *searchastrobinspacer;
    QFrame *SearchMinFrame;
    QHBoxLayout *objectInfoLayoutH2b;
    QGridLayout *objectInfoLayoutGrid2b;
    QLabel *SearchLabel2;
    QPushButton *astrobinButton2;
    QPushButton *searchWikipedia2;
    QPushButton *searchSpecialWebPageImages2;
    QPushButton *searchSimbad2;
    QSpacerItem *searchastrobinspacer2;
    MinimizeWidget *filtersMinimizeWidget;
    QVBoxLayout *filtersVerticalLayout;
    QFrame *FiltersMaxFrame;
    QHBoxLayout *filterTypesLayoutV;
    QGridLayout *filterTypesLayout;
    QLabel *FiltersLabel;
    QLabel *minHoursLabel;
    QDoubleSpinBox *minHours;
    QCheckBox *OpenClusterCB;
    QCheckBox *NebulaCB;
    QCheckBox *GlobularClusterCB;
    QCheckBox *PlanetaryCB;
    QCheckBox *SupernovaRemnantCB;
    QCheckBox *GalaxyCB;
    QCheckBox *GalaxyClusterCB;
    QCheckBox *DarkNebulaCB;
    QCheckBox *OtherCB;
    QFrame *line;
    QCheckBox *pickedCB;
    QCheckBox *notPickedCB;
    QCheckBox *dontCarePickedCB;
    QCheckBox *imagedCB;
    QCheckBox *notImagedCB;
    QCheckBox *dontCareImagedCB;
    QPushButton *loadImagedB;
    QCheckBox *ignoredCB;
    QCheckBox *notIgnoredCB;
    QCheckBox *dontCareIgnoredCB;
    QCheckBox *keywordCB;
    QCheckBox *notKeywordCB;
    QCheckBox *dontCareKeywordCB;
    QTextEdit *keywordEdit;
    QSpacerItem *filterTypesspacer;
    QFrame *FiltersMinFrame;
    QHBoxLayout *filterTypesLayoutV2;
    QGridLayout *filterTypesLayout2;
    QLabel *FiltersLabel2;
    QSpacerItem *filterTypesspacer2;
    MinimizeWidget *imageFrameMinimizeWidget;
    QVBoxLayout *imageFrameVerticalLayout;
    QFrame *imageMaxFrame;
    QVBoxLayout *imageFrameLayoutV;
    QHBoxLayout *imageFrameLayoutH;
    QLabel *ImageFrameLabel;
    QSpacerItem *imagetitlespacer;
    QPushButton *LoadCatalogButton;
    QHBoxLayout *ImageHLayout;
    QVBoxLayout *ImageVLayout;
    QLabel *ImagePreview;
    QLabel *ImagePreviewCredit;
    QLabel *ImagePreviewCreditLink;
    QSpacerItem *imageHspacer_2;
    QSpacerItem *imagespacer;
    QFrame *ImageMinFrame;
    QVBoxLayout *imageFrameLayoutV2;
    QHBoxLayout *imageFrameLayoutH2;
    QLabel *ImageFrameLabel2;
    QSpacerItem *imagetitlespacer2;
    QPushButton *LoadCatalogButton2;
    QSpacerItem *RightPanelSpacer;
    QSpacerItem *RightPanelOuterSpacer;

    void setupUi(QWidget *ImagingPlanner)
    {
        if (ImagingPlanner->objectName().isEmpty())
            ImagingPlanner->setObjectName("ImagingPlanner");
        ImagingPlanner->resize(1000, 800);
        verticalLayout_2 = new QVBoxLayout(ImagingPlanner);
        verticalLayout_2->setSpacing(3);
        verticalLayout_2->setObjectName("verticalLayout_2");
        verticalLayout_2->setContentsMargins(3, 3, 3, 3);
        WholeLayout = new QHBoxLayout();
        WholeLayout->setSpacing(3);
        WholeLayout->setObjectName("WholeLayout");
        TargetCatalog = new QFrame(ImagingPlanner);
        TargetCatalog->setObjectName("TargetCatalog");
        QSizePolicy sizePolicy(QSizePolicy::Policy::Preferred, QSizePolicy::Policy::Preferred);
        sizePolicy.setHorizontalStretch(0);
        sizePolicy.setVerticalStretch(0);
        sizePolicy.setHeightForWidth(TargetCatalog->sizePolicy().hasHeightForWidth());
        TargetCatalog->setSizePolicy(sizePolicy);
        verticalLayout_5 = new QVBoxLayout(TargetCatalog);
        verticalLayout_5->setSpacing(3);
        verticalLayout_5->setObjectName("verticalLayout_5");
        verticalLayout_5->setContentsMargins(3, 3, 3, 3);
        tableCountLayout = new QVBoxLayout();
        tableCountLayout->setObjectName("tableCountLayout");
        countSearchLayout = new QHBoxLayout();
        countSearchLayout->setObjectName("countSearchLayout");
        SearchB = new QPushButton(TargetCatalog);
        SearchB->setObjectName("SearchB");
        QSizePolicy sizePolicy1(QSizePolicy::Policy::Preferred, QSizePolicy::Policy::Fixed);
        sizePolicy1.setHorizontalStretch(0);
        sizePolicy1.setVerticalStretch(0);
        sizePolicy1.setHeightForWidth(SearchB->sizePolicy().hasHeightForWidth());
        SearchB->setSizePolicy(sizePolicy1);
        SearchB->setMaximumSize(QSize(32, 32));
        QIcon icon(QIcon::fromTheme(QString::fromUtf8("edit-find")));
        SearchB->setIcon(icon);

        countSearchLayout->addWidget(SearchB);

        SearchText = new QTextEdit(TargetCatalog);
        SearchText->setObjectName("SearchText");
        QSizePolicy sizePolicy2(QSizePolicy::Policy::Expanding, QSizePolicy::Policy::Fixed);
        sizePolicy2.setHorizontalStretch(0);
        sizePolicy2.setVerticalStretch(0);
        sizePolicy2.setHeightForWidth(SearchText->sizePolicy().hasHeightForWidth());
        SearchText->setSizePolicy(sizePolicy2);
        SearchText->setMaximumSize(QSize(100, 32));

        countSearchLayout->addWidget(SearchText);

        tableCount = new QLabel(TargetCatalog);
        tableCount->setObjectName("tableCount");
        sizePolicy1.setHeightForWidth(tableCount->sizePolicy().hasHeightForWidth());
        tableCount->setSizePolicy(sizePolicy1);
        tableCount->setMinimumSize(QSize(32, 32));
        tableCount->setMaximumSize(QSize(1000000, 32));
        QFont font;
        font.setBold(true);
        tableCount->setFont(font);
        tableCount->setAlignment(Qt::AlignmentFlag::AlignCenter);

        countSearchLayout->addWidget(tableCount);


        tableCountLayout->addLayout(countSearchLayout);

        CatalogView = new QTableView(TargetCatalog);
        CatalogView->setObjectName("CatalogView");
        QSizePolicy sizePolicy3(QSizePolicy::Policy::Expanding, QSizePolicy::Policy::Preferred);
        sizePolicy3.setHorizontalStretch(0);
        sizePolicy3.setVerticalStretch(0);
        sizePolicy3.setHeightForWidth(CatalogView->sizePolicy().hasHeightForWidth());
        CatalogView->setSizePolicy(sizePolicy3);
        CatalogView->setEditTriggers(QAbstractItemView::EditTrigger::NoEditTriggers);
        CatalogView->setAlternatingRowColors(true);
        CatalogView->setSelectionBehavior(QAbstractItemView::SelectionBehavior::SelectRows);
        CatalogView->setShowGrid(false);
        CatalogView->setSortingEnabled(true);

        tableCountLayout->addWidget(CatalogView);


        verticalLayout_5->addLayout(tableCountLayout);


        WholeLayout->addWidget(TargetCatalog);

        RightSideLayoutWithSpacer = new QVBoxLayout();
        RightSideLayoutWithSpacer->setObjectName("RightSideLayoutWithSpacer");
        RightPanel = new QFrame(ImagingPlanner);
        RightPanel->setObjectName("RightPanel");
        QSizePolicy sizePolicy4(QSizePolicy::Policy::Fixed, QSizePolicy::Policy::Fixed);
        sizePolicy4.setHorizontalStretch(0);
        sizePolicy4.setVerticalStretch(0);
        sizePolicy4.setHeightForWidth(RightPanel->sizePolicy().hasHeightForWidth());
        RightPanel->setSizePolicy(sizePolicy4);
        RightLayout = new QVBoxLayout(RightPanel);
        RightLayout->setSpacing(3);
        RightLayout->setObjectName("RightLayout");
        RightLayout->setSizeConstraint(QLayout::SizeConstraint::SetDefaultConstraint);
        statusLineLayout = new QHBoxLayout();
        statusLineLayout->setObjectName("statusLineLayout");
        statusLineLayout->setContentsMargins(-1, 3, -1, 3);
        statusLabel = new QLabel(RightPanel);
        statusLabel->setObjectName("statusLabel");
        statusLabel->setMinimumSize(QSize(130, 32));
        statusLabel->setMaximumSize(QSize(150, 32));

        statusLineLayout->addWidget(statusLabel);

        horizontalSpacer_1 = new QSpacerItem(10, 10, QSizePolicy::Policy::Expanding, QSizePolicy::Policy::Minimum);

        statusLineLayout->addItem(horizontalSpacer_1);

        topLine = new QFrame(RightPanel);
        topLine->setObjectName("topLine");
        topLine->setMaximumSize(QSize(1000000, 32));
        LocationTimeLayout = new QHBoxLayout(topLine);
        LocationTimeLayout->setSpacing(3);
        LocationTimeLayout->setObjectName("LocationTimeLayout");
        LocationTimeLayout->setContentsMargins(-1, 0, -1, -1);
        moonImage = new QLabel(topLine);
        moonImage->setObjectName("moonImage");
        moonImage->setMinimumSize(QSize(32, 32));

        LocationTimeLayout->addWidget(moonImage);

        moonPercentLabel = new QLabel(topLine);
        moonPercentLabel->setObjectName("moonPercentLabel");
        moonPercentLabel->setMinimumSize(QSize(32, 32));
        moonPercentLabel->setMaximumSize(QSize(32, 32));
        moonPercentLabel->setAlignment(Qt::AlignmentFlag::AlignCenter);

        LocationTimeLayout->addWidget(moonPercentLabel);

        backOneDay = new QPushButton(topLine);
        backOneDay->setObjectName("backOneDay");
        sizePolicy4.setHeightForWidth(backOneDay->sizePolicy().hasHeightForWidth());
        backOneDay->setSizePolicy(sizePolicy4);
        backOneDay->setMinimumSize(QSize(32, 32));
        backOneDay->setMaximumSize(QSize(32, 32));
        QIcon icon1(QIcon::fromTheme(QString::fromUtf8("arrow-left")));
        backOneDay->setIcon(icon1);

        LocationTimeLayout->addWidget(backOneDay);

        DateEdit = new QDateEdit(topLine);
        DateEdit->setObjectName("DateEdit");
        DateEdit->setProperty("showGroupSeparator", QVariant(false));
        DateEdit->setCalendarPopup(true);

        LocationTimeLayout->addWidget(DateEdit);

        forwardOneDay = new QPushButton(topLine);
        forwardOneDay->setObjectName("forwardOneDay");
        sizePolicy4.setHeightForWidth(forwardOneDay->sizePolicy().hasHeightForWidth());
        forwardOneDay->setSizePolicy(sizePolicy4);
        forwardOneDay->setMinimumSize(QSize(32, 32));
        forwardOneDay->setMaximumSize(QSize(32, 32));
        QIcon icon2(QIcon::fromTheme(QString::fromUtf8("arrow-right")));
        forwardOneDay->setIcon(icon2);

        LocationTimeLayout->addWidget(forwardOneDay);


        statusLineLayout->addWidget(topLine);

        horizontalSpacer_2 = new QSpacerItem(10, 10, QSizePolicy::Policy::Expanding, QSizePolicy::Policy::Minimum);

        statusLineLayout->addItem(horizontalSpacer_2);

        optionsButton = new QPushButton(RightPanel);
        optionsButton->setObjectName("optionsButton");
        sizePolicy.setHeightForWidth(optionsButton->sizePolicy().hasHeightForWidth());
        optionsButton->setSizePolicy(sizePolicy);
        optionsButton->setMaximumSize(QSize(32, 32));
        QIcon icon3(QIcon::fromTheme(QString::fromUtf8("open-menu-symbolic")));
        optionsButton->setIcon(icon3);

        statusLineLayout->addWidget(optionsButton);

        helpButton = new QPushButton(RightPanel);
        helpButton->setObjectName("helpButton");
        sizePolicy.setHeightForWidth(helpButton->sizePolicy().hasHeightForWidth());
        helpButton->setSizePolicy(sizePolicy);
        helpButton->setMaximumSize(QSize(32, 32));
        QIcon icon4(QIcon::fromTheme(QString::fromUtf8("help-about")));
        helpButton->setIcon(icon4);

        statusLineLayout->addWidget(helpButton);


        RightLayout->addLayout(statusLineLayout);

        DevelFrame = new QFrame(RightPanel);
        DevelFrame->setObjectName("DevelFrame");
        DevelFrame->setVisible(false);
        DevelLayout = new QHBoxLayout(DevelFrame);
        DevelLayout->setObjectName("DevelLayout");
        DevelLabel = new QLabel(DevelFrame);
        DevelLabel->setObjectName("DevelLabel");

        DevelLayout->addWidget(DevelLabel);

        DevelDownsampleButton = new QPushButton(DevelFrame);
        DevelDownsampleButton->setObjectName("DevelDownsampleButton");
        sizePolicy4.setHeightForWidth(DevelDownsampleButton->sizePolicy().hasHeightForWidth());
        DevelDownsampleButton->setSizePolicy(sizePolicy4);
        DevelDownsampleButton->setMinimumSize(QSize(24, 24));

        DevelLayout->addWidget(DevelDownsampleButton);

        DevelCheckTargetsButton = new QPushButton(DevelFrame);
        DevelCheckTargetsButton->setObjectName("DevelCheckTargetsButton");
        sizePolicy4.setHeightForWidth(DevelCheckTargetsButton->sizePolicy().hasHeightForWidth());
        DevelCheckTargetsButton->setSizePolicy(sizePolicy4);
        DevelCheckTargetsButton->setMinimumSize(QSize(24, 24));

        DevelLayout->addWidget(DevelCheckTargetsButton);

        DevelCheckCatalogButton = new QPushButton(DevelFrame);
        DevelCheckCatalogButton->setObjectName("DevelCheckCatalogButton");
        sizePolicy4.setHeightForWidth(DevelCheckCatalogButton->sizePolicy().hasHeightForWidth());
        DevelCheckCatalogButton->setSizePolicy(sizePolicy4);
        DevelCheckCatalogButton->setMinimumSize(QSize(24, 24));

        DevelLayout->addWidget(DevelCheckCatalogButton);

        DevelCheckTargetsPrevButton = new QPushButton(DevelFrame);
        DevelCheckTargetsPrevButton->setObjectName("DevelCheckTargetsPrevButton");
        sizePolicy4.setHeightForWidth(DevelCheckTargetsPrevButton->sizePolicy().hasHeightForWidth());
        DevelCheckTargetsPrevButton->setSizePolicy(sizePolicy4);
        DevelCheckTargetsPrevButton->setMinimumSize(QSize(24, 24));
        DevelCheckTargetsPrevButton->setMaximumSize(QSize(24, 24));
        DevelCheckTargetsPrevButton->setIcon(icon1);

        DevelLayout->addWidget(DevelCheckTargetsPrevButton);

        DevelCheckTargetsNextButton = new QPushButton(DevelFrame);
        DevelCheckTargetsNextButton->setObjectName("DevelCheckTargetsNextButton");
        sizePolicy4.setHeightForWidth(DevelCheckTargetsNextButton->sizePolicy().hasHeightForWidth());
        DevelCheckTargetsNextButton->setSizePolicy(sizePolicy4);
        DevelCheckTargetsNextButton->setMinimumSize(QSize(24, 24));
        DevelCheckTargetsNextButton->setMaximumSize(QSize(24, 24));
        DevelCheckTargetsNextButton->setIcon(icon2);

        DevelLayout->addWidget(DevelCheckTargetsNextButton);


        RightLayout->addWidget(DevelFrame);

        ObjectInfoFrameH = new QFrame(RightPanel);
        ObjectInfoFrameH->setObjectName("ObjectInfoFrameH");
        ObjectInfoFrameH->setFrameShape(QFrame::Shape::Box);
        ObjectInfoFrameH->setFrameShadow(QFrame::Shadow::Sunken);
        objectInfoLayoutV = new QVBoxLayout(ObjectInfoFrameH);
        objectInfoLayoutV->setObjectName("objectInfoLayoutV");
        objectInfoLayoutV->setContentsMargins(-1, 3, -1, 3);
        objectInfoLayoutH = new QHBoxLayout();
        objectInfoLayoutH->setObjectName("objectInfoLayoutH");
        objectInfoLayoutGrid = new QGridLayout();
        objectInfoLayoutGrid->setObjectName("objectInfoLayoutGrid");
        infoObjectName = new QLabel(ObjectInfoFrameH);
        infoObjectName->setObjectName("infoObjectName");
        infoObjectName->setMaximumSize(QSize(1000000, 32));

        objectInfoLayoutGrid->addWidget(infoObjectName, 0, 0, 1, 1);

        infoObjectType = new QLabel(ObjectInfoFrameH);
        infoObjectType->setObjectName("infoObjectType");
        infoObjectType->setMaximumSize(QSize(1000000, 32));

        objectInfoLayoutGrid->addWidget(infoObjectType, 0, 2, 1, 2);

        infoSize = new QLabel(ObjectInfoFrameH);
        infoSize->setObjectName("infoSize");
        infoSize->setMaximumSize(QSize(100, 32));

        objectInfoLayoutGrid->addWidget(infoSize, 0, 4, 1, 2);

        infoObjectFlags = new QLabel(ObjectInfoFrameH);
        infoObjectFlags->setObjectName("infoObjectFlags");
        infoObjectFlags->setMaximumSize(QSize(1000000, 32));

        objectInfoLayoutGrid->addWidget(infoObjectFlags, 0, 6, 1, 1);

        infoObjectLongName = new QLabel(ObjectInfoFrameH);
        infoObjectLongName->setObjectName("infoObjectLongName");
        infoObjectLongName->setMaximumSize(QSize(10000, 32));

        objectInfoLayoutGrid->addWidget(infoObjectLongName, 1, 0, 1, 7);

        infoRiseSet = new QLabel(ObjectInfoFrameH);
        infoRiseSet->setObjectName("infoRiseSet");

        objectInfoLayoutGrid->addWidget(infoRiseSet, 2, 0, 1, 7);


        objectInfoLayoutH->addLayout(objectInfoLayoutGrid);

        detailsspacer = new QSpacerItem(40, 20, QSizePolicy::Policy::Expanding, QSizePolicy::Policy::Minimum);

        objectInfoLayoutH->addItem(detailsspacer);


        objectInfoLayoutV->addLayout(objectInfoLayoutH);

        userNotesLayout = new QHBoxLayout();
        userNotesLayout->setObjectName("userNotesLayout");
        userNotesEditButton = new QPushButton(ObjectInfoFrameH);
        userNotesEditButton->setObjectName("userNotesEditButton");
        sizePolicy4.setHeightForWidth(userNotesEditButton->sizePolicy().hasHeightForWidth());
        userNotesEditButton->setSizePolicy(sizePolicy4);
        userNotesEditButton->setMinimumSize(QSize(24, 24));
        userNotesEditButton->setMaximumSize(QSize(24, 24));
        QIcon icon5(QIcon::fromTheme(QString::fromUtf8("document-edit")));
        userNotesEditButton->setIcon(icon5);

        userNotesLayout->addWidget(userNotesEditButton);

        userNotesDoneButton = new QPushButton(ObjectInfoFrameH);
        userNotesDoneButton->setObjectName("userNotesDoneButton");
        sizePolicy4.setHeightForWidth(userNotesDoneButton->sizePolicy().hasHeightForWidth());
        userNotesDoneButton->setSizePolicy(sizePolicy4);
        userNotesDoneButton->setMinimumSize(QSize(24, 24));
        userNotesDoneButton->setMaximumSize(QSize(24, 24));
        QIcon icon6(QIcon::fromTheme(QString::fromUtf8("checkmark")));
        userNotesDoneButton->setIcon(icon6);

        userNotesLayout->addWidget(userNotesDoneButton);

        userNotesOpenLink = new QPushButton(ObjectInfoFrameH);
        userNotesOpenLink->setObjectName("userNotesOpenLink");
        sizePolicy4.setHeightForWidth(userNotesOpenLink->sizePolicy().hasHeightForWidth());
        userNotesOpenLink->setSizePolicy(sizePolicy4);
        userNotesOpenLink->setMinimumSize(QSize(24, 24));
        userNotesOpenLink->setMaximumSize(QSize(24, 24));
        QIcon icon7(QIcon::fromTheme(QString::fromUtf8("link")));
        userNotesOpenLink->setIcon(icon7);

        userNotesLayout->addWidget(userNotesOpenLink);

        userNotesOpenLink2 = new QPushButton(ObjectInfoFrameH);
        userNotesOpenLink2->setObjectName("userNotesOpenLink2");
        sizePolicy4.setHeightForWidth(userNotesOpenLink2->sizePolicy().hasHeightForWidth());
        userNotesOpenLink2->setSizePolicy(sizePolicy4);
        userNotesOpenLink2->setMinimumSize(QSize(24, 24));
        userNotesOpenLink2->setMaximumSize(QSize(24, 24));
        userNotesOpenLink2->setIcon(icon7);

        userNotesLayout->addWidget(userNotesOpenLink2);

        userNotesOpenLink3 = new QPushButton(ObjectInfoFrameH);
        userNotesOpenLink3->setObjectName("userNotesOpenLink3");
        sizePolicy4.setHeightForWidth(userNotesOpenLink3->sizePolicy().hasHeightForWidth());
        userNotesOpenLink3->setSizePolicy(sizePolicy4);
        userNotesOpenLink3->setMinimumSize(QSize(24, 24));
        userNotesOpenLink3->setMaximumSize(QSize(24, 24));
        userNotesOpenLink3->setIcon(icon7);

        userNotesLayout->addWidget(userNotesOpenLink3);

        userNotesLabel = new QLabel(ObjectInfoFrameH);
        userNotesLabel->setObjectName("userNotesLabel");
        userNotesLabel->setMinimumSize(QSize(32, 32));
        userNotesLabel->setMaximumSize(QSize(40, 32));

        userNotesLayout->addWidget(userNotesLabel);

        userNotes = new QLabel(ObjectInfoFrameH);
        userNotes->setObjectName("userNotes");
        userNotes->setMinimumSize(QSize(32, 32));
        userNotes->setMaximumSize(QSize(1000000, 32));

        userNotesLayout->addWidget(userNotes);

        userNotesEdit = new QTextEdit(ObjectInfoFrameH);
        userNotesEdit->setObjectName("userNotesEdit");
        sizePolicy.setHeightForWidth(userNotesEdit->sizePolicy().hasHeightForWidth());
        userNotesEdit->setSizePolicy(sizePolicy);

        userNotesLayout->addWidget(userNotesEdit);

        imageHspacer_1 = new QSpacerItem(5, 20, QSizePolicy::Policy::Expanding, QSizePolicy::Policy::Minimum);

        userNotesLayout->addItem(imageHspacer_1);


        objectInfoLayoutV->addLayout(userNotesLayout);


        RightLayout->addWidget(ObjectInfoFrameH);

        altitudeGraphMinimizeWidget = new MinimizeWidget(RightPanel);
        altitudeGraphMinimizeWidget->setObjectName("altitudeGraphMinimizeWidget");
        altitudeGraphMinWidgetLayout = new QVBoxLayout(altitudeGraphMinimizeWidget);
        altitudeGraphMinWidgetLayout->setObjectName("altitudeGraphMinWidgetLayout");
        altMaxFrame = new QFrame(altitudeGraphMinimizeWidget);
        altMaxFrame->setObjectName("altMaxFrame");
        altMaxFrame->setFrameShape(QFrame::Shape::NoFrame);
        AltitudeGraphH = new QHBoxLayout(altMaxFrame);
        AltitudeGraphH->setSpacing(0);
        AltitudeGraphH->setObjectName("AltitudeGraphH");
        AltitudeGraphH->setContentsMargins(0, 0, 0, 0);
        AltitudeGraphLayout = new QHBoxLayout();
        AltitudeGraphLayout->setObjectName("AltitudeGraphLayout");
        altitudeGraph = new AVTPlotWidget(altMaxFrame);
        altitudeGraph->setObjectName("altitudeGraph");
        altitudeGraph->setEnabled(true);
        QSizePolicy sizePolicy5(QSizePolicy::Policy::Fixed, QSizePolicy::Policy::Preferred);
        sizePolicy5.setHorizontalStretch(0);
        sizePolicy5.setVerticalStretch(0);
        sizePolicy5.setHeightForWidth(altitudeGraph->sizePolicy().hasHeightForWidth());
        altitudeGraph->setSizePolicy(sizePolicy5);
        altitudeGraph->setMinimumSize(QSize(400, 150));
        altitudeGraph->setMaximumSize(QSize(100000, 200));
        altitudeGraph->setCursor(QCursor(Qt::CursorShape::CrossCursor));

        AltitudeGraphLayout->addWidget(altitudeGraph);


        AltitudeGraphH->addLayout(AltitudeGraphLayout);


        altitudeGraphMinWidgetLayout->addWidget(altMaxFrame);

        AltMinFrame = new QFrame(altitudeGraphMinimizeWidget);
        AltMinFrame->setObjectName("AltMinFrame");
        AltMinFrame->setFrameShape(QFrame::Shape::NoFrame);
        AltitudeGraphHiddenLayout = new QHBoxLayout(AltMinFrame);
        AltitudeGraphHiddenLayout->setSpacing(1);
        AltitudeGraphHiddenLayout->setObjectName("AltitudeGraphHiddenLayout");
        AltitudeGraphHiddenLayout->setContentsMargins(0, 0, 0, 0);
        HiddenAltitudeGraphLabel = new QLabel(AltMinFrame);
        HiddenAltitudeGraphLabel->setObjectName("HiddenAltitudeGraphLabel");
        HiddenAltitudeGraphLabel->setMinimumSize(QSize(100, 0));
        HiddenAltitudeGraphLabel->setMaximumSize(QSize(200, 32));
        HiddenAltitudeGraphLabel->setFont(font);

        AltitudeGraphHiddenLayout->addWidget(HiddenAltitudeGraphLabel);

        hiddenAltitudeGraphSpacer = new QSpacerItem(40, 20, QSizePolicy::Policy::Expanding, QSizePolicy::Policy::Minimum);

        AltitudeGraphHiddenLayout->addItem(hiddenAltitudeGraphSpacer);


        altitudeGraphMinWidgetLayout->addWidget(AltMinFrame);


        RightLayout->addWidget(altitudeGraphMinimizeWidget);

        MinControls = new QFrame(RightPanel);
        MinControls->setObjectName("MinControls");
        MinControls->setFrameShape(QFrame::Shape::NoFrame);
        minControlsLayoutV = new QHBoxLayout(MinControls);
        minControlsLayoutV->setObjectName("minControlsLayoutV");
        minControlsLayoutV->setContentsMargins(-1, 3, -1, 3);
        minControlsLayout = new QGridLayout();
        minControlsLayout->setObjectName("minControlsLayout");
        useArtificialHorizon = new QCheckBox(MinControls);
        useArtificialHorizon->setObjectName("useArtificialHorizon");

        minControlsLayout->addWidget(useArtificialHorizon, 0, 0, 1, 1);

        minAltitudeLabel = new QLabel(MinControls);
        minAltitudeLabel->setObjectName("minAltitudeLabel");
        minAltitudeLabel->setMaximumSize(QSize(200, 32));

        minControlsLayout->addWidget(minAltitudeLabel, 0, 1, 1, 1);

        minAltitude = new QDoubleSpinBox(MinControls);
        minAltitude->setObjectName("minAltitude");
        sizePolicy.setHeightForWidth(minAltitude->sizePolicy().hasHeightForWidth());
        minAltitude->setSizePolicy(sizePolicy);
        minAltitude->setMaximumSize(QSize(65, 16777215));
        minAltitude->setDecimals(1);
        minAltitude->setMinimum(0.000000000000000);
        minAltitude->setMaximum(90.000000000000000);

        minControlsLayout->addWidget(minAltitude, 0, 2, 1, 1);

        minMoonLabel = new QLabel(MinControls);
        minMoonLabel->setObjectName("minMoonLabel");
        minMoonLabel->setMaximumSize(QSize(200, 32));

        minControlsLayout->addWidget(minMoonLabel, 0, 3, 1, 1);

        minMoon = new QDoubleSpinBox(MinControls);
        minMoon->setObjectName("minMoon");
        sizePolicy.setHeightForWidth(minMoon->sizePolicy().hasHeightForWidth());
        minMoon->setSizePolicy(sizePolicy);
        minMoon->setMaximumSize(QSize(60, 16777215));
        minMoon->setDecimals(0);
        minMoon->setMinimum(0.000000000000000);
        minMoon->setMaximum(90.000000000000000);

        minControlsLayout->addWidget(minMoon, 0, 4, 1, 1);

        maxMoonAltitude = new QDoubleSpinBox(MinControls);
        maxMoonAltitude->setObjectName("maxMoonAltitude");
        maxMoonAltitude->setDecimals(0);
        maxMoonAltitude->setMaximum(90.000000000000000);
        maxMoonAltitude->setValue(90.000000000000000);

        minControlsLayout->addWidget(maxMoonAltitude, 0, 5, 1, 1);


        minControlsLayoutV->addLayout(minControlsLayout);

        minControlsspacer = new QSpacerItem(40, 20, QSizePolicy::Policy::Expanding, QSizePolicy::Policy::Minimum);

        minControlsLayoutV->addItem(minControlsspacer);


        RightLayout->addWidget(MinControls);

        astrobinSearchMinimizeWidget = new MinimizeWidget(RightPanel);
        astrobinSearchMinimizeWidget->setObjectName("astrobinSearchMinimizeWidget");
        astrobinSearchVerticalLayout = new QVBoxLayout(astrobinSearchMinimizeWidget);
        astrobinSearchVerticalLayout->setObjectName("astrobinSearchVerticalLayout");
        SearchMaxFrame = new QFrame(astrobinSearchMinimizeWidget);
        SearchMaxFrame->setObjectName("SearchMaxFrame");
        SearchMaxFrame->setFrameShape(QFrame::Shape::NoFrame);
        objectInfoLayoutH2 = new QHBoxLayout(SearchMaxFrame);
        objectInfoLayoutH2->setSpacing(0);
        objectInfoLayoutH2->setObjectName("objectInfoLayoutH2");
        objectInfoLayoutH2->setContentsMargins(0, 0, 0, 0);
        searchLayout1 = new QVBoxLayout();
        searchLayout1->setObjectName("searchLayout1");
        searchLayout2 = new QHBoxLayout();
        searchLayout2->setObjectName("searchLayout2");
        SearchLabel = new QLabel(SearchMaxFrame);
        SearchLabel->setObjectName("SearchLabel");
        SearchLabel->setMinimumSize(QSize(60, 0));
        SearchLabel->setMaximumSize(QSize(60, 32));
        SearchLabel->setFont(font);

        searchLayout2->addWidget(SearchLabel);

        astrobinButton = new QPushButton(SearchMaxFrame);
        astrobinButton->setObjectName("astrobinButton");
        sizePolicy4.setHeightForWidth(astrobinButton->sizePolicy().hasHeightForWidth());
        astrobinButton->setSizePolicy(sizePolicy4);
        astrobinButton->setMinimumSize(QSize(75, 24));
        astrobinButton->setMaximumSize(QSize(75, 24));
        QFont font1;
        font1.setPointSize(8);
        astrobinButton->setFont(font1);

        searchLayout2->addWidget(astrobinButton);

        searchWikipedia = new QPushButton(SearchMaxFrame);
        searchWikipedia->setObjectName("searchWikipedia");
        sizePolicy4.setHeightForWidth(searchWikipedia->sizePolicy().hasHeightForWidth());
        searchWikipedia->setSizePolicy(sizePolicy4);
        searchWikipedia->setMinimumSize(QSize(75, 24));
        searchWikipedia->setMaximumSize(QSize(75, 24));
        searchWikipedia->setFont(font1);

        searchLayout2->addWidget(searchWikipedia);

        searchSpecialWebPageImages = new QPushButton(SearchMaxFrame);
        searchSpecialWebPageImages->setObjectName("searchSpecialWebPageImages");
        sizePolicy4.setHeightForWidth(searchSpecialWebPageImages->sizePolicy().hasHeightForWidth());
        searchSpecialWebPageImages->setSizePolicy(sizePolicy4);
        searchSpecialWebPageImages->setMinimumSize(QSize(75, 24));
        searchSpecialWebPageImages->setMaximumSize(QSize(75, 24));
        searchSpecialWebPageImages->setFont(font1);

        searchLayout2->addWidget(searchSpecialWebPageImages);

        searchSimbad = new QPushButton(SearchMaxFrame);
        searchSimbad->setObjectName("searchSimbad");
        sizePolicy4.setHeightForWidth(searchSimbad->sizePolicy().hasHeightForWidth());
        searchSimbad->setSizePolicy(sizePolicy4);
        searchSimbad->setMinimumSize(QSize(75, 24));
        searchSimbad->setMaximumSize(QSize(75, 24));
        searchSimbad->setFont(font1);

        searchLayout2->addWidget(searchSimbad);


        searchLayout1->addLayout(searchLayout2);

        AstrobinAward = new QCheckBox(SearchMaxFrame);
        AstrobinAward->setObjectName("AstrobinAward");

        searchLayout1->addWidget(AstrobinAward);

        searchLayout3 = new QHBoxLayout();
        searchLayout3->setObjectName("searchLayout3");
        radiusLabel = new QLabel(SearchMaxFrame);
        radiusLabel->setObjectName("radiusLabel");
        radiusLabel->setMinimumSize(QSize(0, 0));
        radiusLabel->setMaximumSize(QSize(100, 32));

        searchLayout3->addWidget(radiusLabel);

        minRadiusLabel = new QLabel(SearchMaxFrame);
        minRadiusLabel->setObjectName("minRadiusLabel");
        minRadiusLabel->setMaximumSize(QSize(100, 32));
        minRadiusLabel->setAlignment(Qt::AlignmentFlag::AlignRight|Qt::AlignmentFlag::AlignTrailing|Qt::AlignmentFlag::AlignVCenter);

        searchLayout3->addWidget(minRadiusLabel);

        AstrobinMinRadius = new QDoubleSpinBox(SearchMaxFrame);
        AstrobinMinRadius->setObjectName("AstrobinMinRadius");
        sizePolicy.setHeightForWidth(AstrobinMinRadius->sizePolicy().hasHeightForWidth());
        AstrobinMinRadius->setSizePolicy(sizePolicy);
        AstrobinMinRadius->setMaximumSize(QSize(60, 16777215));
        AstrobinMinRadius->setDecimals(2);
        AstrobinMinRadius->setMinimum(0.010000000000000);
        AstrobinMinRadius->setMaximum(30.000000000000000);

        searchLayout3->addWidget(AstrobinMinRadius);

        layoutMaxRadius = new QHBoxLayout();
        layoutMaxRadius->setObjectName("layoutMaxRadius");
        maxRadiusLabel = new QLabel(SearchMaxFrame);
        maxRadiusLabel->setObjectName("maxRadiusLabel");
        maxRadiusLabel->setMaximumSize(QSize(100, 32));
        maxRadiusLabel->setAlignment(Qt::AlignmentFlag::AlignRight|Qt::AlignmentFlag::AlignTrailing|Qt::AlignmentFlag::AlignVCenter);

        layoutMaxRadius->addWidget(maxRadiusLabel);

        AstrobinMaxRadius = new QDoubleSpinBox(SearchMaxFrame);
        AstrobinMaxRadius->setObjectName("AstrobinMaxRadius");
        sizePolicy.setHeightForWidth(AstrobinMaxRadius->sizePolicy().hasHeightForWidth());
        AstrobinMaxRadius->setSizePolicy(sizePolicy);
        AstrobinMaxRadius->setMaximumSize(QSize(60, 16777215));
        AstrobinMaxRadius->setMinimum(0.010000000000000);
        AstrobinMaxRadius->setMaximum(30.000000000000000);

        layoutMaxRadius->addWidget(AstrobinMaxRadius);

        radius_spacer = new QSpacerItem(40, 20, QSizePolicy::Policy::Expanding, QSizePolicy::Policy::Minimum);

        layoutMaxRadius->addItem(radius_spacer);


        searchLayout3->addLayout(layoutMaxRadius);


        searchLayout1->addLayout(searchLayout3);


        objectInfoLayoutH2->addLayout(searchLayout1);

        searchastrobinspacer = new QSpacerItem(40, 20, QSizePolicy::Policy::Expanding, QSizePolicy::Policy::Minimum);

        objectInfoLayoutH2->addItem(searchastrobinspacer);


        astrobinSearchVerticalLayout->addWidget(SearchMaxFrame);

        SearchMinFrame = new QFrame(astrobinSearchMinimizeWidget);
        SearchMinFrame->setObjectName("SearchMinFrame");
        SearchMinFrame->setFrameShape(QFrame::Shape::NoFrame);
        objectInfoLayoutH2b = new QHBoxLayout(SearchMinFrame);
        objectInfoLayoutH2b->setSpacing(0);
        objectInfoLayoutH2b->setObjectName("objectInfoLayoutH2b");
        objectInfoLayoutH2b->setContentsMargins(0, 0, 0, 0);
        objectInfoLayoutGrid2b = new QGridLayout();
        objectInfoLayoutGrid2b->setObjectName("objectInfoLayoutGrid2b");
        SearchLabel2 = new QLabel(SearchMinFrame);
        SearchLabel2->setObjectName("SearchLabel2");
        SearchLabel2->setMinimumSize(QSize(60, 0));
        SearchLabel2->setMaximumSize(QSize(60, 32));
        SearchLabel2->setFont(font);

        objectInfoLayoutGrid2b->addWidget(SearchLabel2, 0, 1, 1, 1);

        astrobinButton2 = new QPushButton(SearchMinFrame);
        astrobinButton2->setObjectName("astrobinButton2");
        sizePolicy4.setHeightForWidth(astrobinButton2->sizePolicy().hasHeightForWidth());
        astrobinButton2->setSizePolicy(sizePolicy4);
        astrobinButton2->setMinimumSize(QSize(75, 24));
        astrobinButton2->setMaximumSize(QSize(75, 24));
        astrobinButton2->setFont(font1);

        objectInfoLayoutGrid2b->addWidget(astrobinButton2, 0, 2, 1, 1);

        searchWikipedia2 = new QPushButton(SearchMinFrame);
        searchWikipedia2->setObjectName("searchWikipedia2");
        sizePolicy4.setHeightForWidth(searchWikipedia2->sizePolicy().hasHeightForWidth());
        searchWikipedia2->setSizePolicy(sizePolicy4);
        searchWikipedia2->setMinimumSize(QSize(75, 24));
        searchWikipedia2->setMaximumSize(QSize(75, 24));
        searchWikipedia2->setFont(font1);

        objectInfoLayoutGrid2b->addWidget(searchWikipedia2, 0, 3, 1, 1);

        searchSpecialWebPageImages2 = new QPushButton(SearchMinFrame);
        searchSpecialWebPageImages2->setObjectName("searchSpecialWebPageImages2");
        sizePolicy4.setHeightForWidth(searchSpecialWebPageImages2->sizePolicy().hasHeightForWidth());
        searchSpecialWebPageImages2->setSizePolicy(sizePolicy4);
        searchSpecialWebPageImages2->setMinimumSize(QSize(75, 24));
        searchSpecialWebPageImages2->setMaximumSize(QSize(70, 32));
        searchSpecialWebPageImages2->setFont(font1);

        objectInfoLayoutGrid2b->addWidget(searchSpecialWebPageImages2, 0, 4, 1, 1);

        searchSimbad2 = new QPushButton(SearchMinFrame);
        searchSimbad2->setObjectName("searchSimbad2");
        sizePolicy4.setHeightForWidth(searchSimbad2->sizePolicy().hasHeightForWidth());
        searchSimbad2->setSizePolicy(sizePolicy4);
        searchSimbad2->setMinimumSize(QSize(75, 24));
        searchSimbad2->setMaximumSize(QSize(75, 24));
        searchSimbad2->setFont(font1);

        objectInfoLayoutGrid2b->addWidget(searchSimbad2, 0, 5, 1, 1);


        objectInfoLayoutH2b->addLayout(objectInfoLayoutGrid2b);

        searchastrobinspacer2 = new QSpacerItem(40, 20, QSizePolicy::Policy::Expanding, QSizePolicy::Policy::Minimum);

        objectInfoLayoutH2b->addItem(searchastrobinspacer2);


        astrobinSearchVerticalLayout->addWidget(SearchMinFrame);


        RightLayout->addWidget(astrobinSearchMinimizeWidget);

        filtersMinimizeWidget = new MinimizeWidget(RightPanel);
        filtersMinimizeWidget->setObjectName("filtersMinimizeWidget");
        filtersVerticalLayout = new QVBoxLayout(filtersMinimizeWidget);
        filtersVerticalLayout->setObjectName("filtersVerticalLayout");
        FiltersMaxFrame = new QFrame(filtersMinimizeWidget);
        FiltersMaxFrame->setObjectName("FiltersMaxFrame");
        sizePolicy4.setHeightForWidth(FiltersMaxFrame->sizePolicy().hasHeightForWidth());
        FiltersMaxFrame->setSizePolicy(sizePolicy4);
        FiltersMaxFrame->setFrameShape(QFrame::Shape::NoFrame);
        filterTypesLayoutV = new QHBoxLayout(FiltersMaxFrame);
        filterTypesLayoutV->setSpacing(0);
        filterTypesLayoutV->setObjectName("filterTypesLayoutV");
        filterTypesLayoutV->setContentsMargins(0, 0, 0, 0);
        filterTypesLayout = new QGridLayout();
        filterTypesLayout->setObjectName("filterTypesLayout");
        filterTypesLayout->setVerticalSpacing(1);
        FiltersLabel = new QLabel(FiltersMaxFrame);
        FiltersLabel->setObjectName("FiltersLabel");
        FiltersLabel->setMaximumSize(QSize(200, 32));
        FiltersLabel->setFont(font);

        filterTypesLayout->addWidget(FiltersLabel, 0, 1, 1, 1);

        minHoursLabel = new QLabel(FiltersMaxFrame);
        minHoursLabel->setObjectName("minHoursLabel");
        minHoursLabel->setMaximumSize(QSize(200, 32));
        minHoursLabel->setLineWidth(1);

        filterTypesLayout->addWidget(minHoursLabel, 0, 2, 1, 1);

        minHours = new QDoubleSpinBox(FiltersMaxFrame);
        minHours->setObjectName("minHours");
        sizePolicy.setHeightForWidth(minHours->sizePolicy().hasHeightForWidth());
        minHours->setSizePolicy(sizePolicy);
        minHours->setMinimum(0.000000000000000);
        minHours->setMaximum(24.000000000000000);

        filterTypesLayout->addWidget(minHours, 0, 3, 1, 1);

        OpenClusterCB = new QCheckBox(FiltersMaxFrame);
        OpenClusterCB->setObjectName("OpenClusterCB");

        filterTypesLayout->addWidget(OpenClusterCB, 1, 1, 1, 1);

        NebulaCB = new QCheckBox(FiltersMaxFrame);
        NebulaCB->setObjectName("NebulaCB");

        filterTypesLayout->addWidget(NebulaCB, 1, 2, 1, 1);

        GlobularClusterCB = new QCheckBox(FiltersMaxFrame);
        GlobularClusterCB->setObjectName("GlobularClusterCB");

        filterTypesLayout->addWidget(GlobularClusterCB, 1, 3, 1, 1);

        PlanetaryCB = new QCheckBox(FiltersMaxFrame);
        PlanetaryCB->setObjectName("PlanetaryCB");

        filterTypesLayout->addWidget(PlanetaryCB, 1, 4, 1, 1);

        SupernovaRemnantCB = new QCheckBox(FiltersMaxFrame);
        SupernovaRemnantCB->setObjectName("SupernovaRemnantCB");

        filterTypesLayout->addWidget(SupernovaRemnantCB, 2, 1, 1, 1);

        GalaxyCB = new QCheckBox(FiltersMaxFrame);
        GalaxyCB->setObjectName("GalaxyCB");

        filterTypesLayout->addWidget(GalaxyCB, 2, 2, 1, 1);

        GalaxyClusterCB = new QCheckBox(FiltersMaxFrame);
        GalaxyClusterCB->setObjectName("GalaxyClusterCB");

        filterTypesLayout->addWidget(GalaxyClusterCB, 2, 3, 1, 1);

        DarkNebulaCB = new QCheckBox(FiltersMaxFrame);
        DarkNebulaCB->setObjectName("DarkNebulaCB");
        QFont font2;
        font2.setPointSize(10);
        DarkNebulaCB->setFont(font2);

        filterTypesLayout->addWidget(DarkNebulaCB, 2, 4, 1, 1);

        OtherCB = new QCheckBox(FiltersMaxFrame);
        OtherCB->setObjectName("OtherCB");

        filterTypesLayout->addWidget(OtherCB, 0, 4, 1, 1);

        line = new QFrame(FiltersMaxFrame);
        line->setObjectName("line");
        line->setFrameShape(QFrame::Shape::HLine);
        line->setFrameShadow(QFrame::Shadow::Sunken);

        filterTypesLayout->addWidget(line, 3, 1, 1, 4);

        pickedCB = new QCheckBox(FiltersMaxFrame);
        pickedCB->setObjectName("pickedCB");

        filterTypesLayout->addWidget(pickedCB, 4, 1, 1, 1);

        notPickedCB = new QCheckBox(FiltersMaxFrame);
        notPickedCB->setObjectName("notPickedCB");

        filterTypesLayout->addWidget(notPickedCB, 4, 2, 1, 1);

        dontCarePickedCB = new QCheckBox(FiltersMaxFrame);
        dontCarePickedCB->setObjectName("dontCarePickedCB");

        filterTypesLayout->addWidget(dontCarePickedCB, 4, 3, 1, 1);

        imagedCB = new QCheckBox(FiltersMaxFrame);
        imagedCB->setObjectName("imagedCB");

        filterTypesLayout->addWidget(imagedCB, 5, 1, 1, 1);

        notImagedCB = new QCheckBox(FiltersMaxFrame);
        notImagedCB->setObjectName("notImagedCB");

        filterTypesLayout->addWidget(notImagedCB, 5, 2, 1, 1);

        dontCareImagedCB = new QCheckBox(FiltersMaxFrame);
        dontCareImagedCB->setObjectName("dontCareImagedCB");

        filterTypesLayout->addWidget(dontCareImagedCB, 5, 3, 1, 1);

        loadImagedB = new QPushButton(FiltersMaxFrame);
        loadImagedB->setObjectName("loadImagedB");
        sizePolicy.setHeightForWidth(loadImagedB->sizePolicy().hasHeightForWidth());
        loadImagedB->setSizePolicy(sizePolicy);
        loadImagedB->setMaximumSize(QSize(75, 16777215));
        loadImagedB->setFont(font1);

        filterTypesLayout->addWidget(loadImagedB, 5, 4, 1, 1);

        ignoredCB = new QCheckBox(FiltersMaxFrame);
        ignoredCB->setObjectName("ignoredCB");

        filterTypesLayout->addWidget(ignoredCB, 6, 1, 1, 1);

        notIgnoredCB = new QCheckBox(FiltersMaxFrame);
        notIgnoredCB->setObjectName("notIgnoredCB");

        filterTypesLayout->addWidget(notIgnoredCB, 6, 2, 1, 1);

        dontCareIgnoredCB = new QCheckBox(FiltersMaxFrame);
        dontCareIgnoredCB->setObjectName("dontCareIgnoredCB");

        filterTypesLayout->addWidget(dontCareIgnoredCB, 6, 3, 1, 1);

        keywordCB = new QCheckBox(FiltersMaxFrame);
        keywordCB->setObjectName("keywordCB");

        filterTypesLayout->addWidget(keywordCB, 7, 1, 1, 1);

        notKeywordCB = new QCheckBox(FiltersMaxFrame);
        notKeywordCB->setObjectName("notKeywordCB");

        filterTypesLayout->addWidget(notKeywordCB, 7, 2, 1, 1);

        dontCareKeywordCB = new QCheckBox(FiltersMaxFrame);
        dontCareKeywordCB->setObjectName("dontCareKeywordCB");

        filterTypesLayout->addWidget(dontCareKeywordCB, 7, 3, 1, 1);

        keywordEdit = new QTextEdit(FiltersMaxFrame);
        keywordEdit->setObjectName("keywordEdit");
        keywordEdit->setMaximumSize(QSize(75, 24));
        QFont font3;
        font3.setPointSize(9);
        keywordEdit->setFont(font3);

        filterTypesLayout->addWidget(keywordEdit, 7, 4, 1, 1);


        filterTypesLayoutV->addLayout(filterTypesLayout);

        filterTypesspacer = new QSpacerItem(40, 20, QSizePolicy::Policy::Expanding, QSizePolicy::Policy::Minimum);

        filterTypesLayoutV->addItem(filterTypesspacer);


        filtersVerticalLayout->addWidget(FiltersMaxFrame);

        FiltersMinFrame = new QFrame(filtersMinimizeWidget);
        FiltersMinFrame->setObjectName("FiltersMinFrame");
        sizePolicy4.setHeightForWidth(FiltersMinFrame->sizePolicy().hasHeightForWidth());
        FiltersMinFrame->setSizePolicy(sizePolicy4);
        FiltersMinFrame->setFrameShape(QFrame::Shape::NoFrame);
        filterTypesLayoutV2 = new QHBoxLayout(FiltersMinFrame);
        filterTypesLayoutV2->setSpacing(0);
        filterTypesLayoutV2->setObjectName("filterTypesLayoutV2");
        filterTypesLayoutV2->setContentsMargins(0, 0, 0, 0);
        filterTypesLayout2 = new QGridLayout();
        filterTypesLayout2->setObjectName("filterTypesLayout2");
        FiltersLabel2 = new QLabel(FiltersMinFrame);
        FiltersLabel2->setObjectName("FiltersLabel2");
        FiltersLabel2->setMinimumSize(QSize(100, 0));
        FiltersLabel2->setMaximumSize(QSize(200, 32));
        QFont font4;
        font4.setPointSize(11);
        font4.setBold(true);
        FiltersLabel2->setFont(font4);

        filterTypesLayout2->addWidget(FiltersLabel2, 0, 1, 1, 1);


        filterTypesLayoutV2->addLayout(filterTypesLayout2);

        filterTypesspacer2 = new QSpacerItem(40, 20, QSizePolicy::Policy::Expanding, QSizePolicy::Policy::Minimum);

        filterTypesLayoutV2->addItem(filterTypesspacer2);


        filtersVerticalLayout->addWidget(FiltersMinFrame);


        RightLayout->addWidget(filtersMinimizeWidget);

        imageFrameMinimizeWidget = new MinimizeWidget(RightPanel);
        imageFrameMinimizeWidget->setObjectName("imageFrameMinimizeWidget");
        imageFrameVerticalLayout = new QVBoxLayout(imageFrameMinimizeWidget);
        imageFrameVerticalLayout->setObjectName("imageFrameVerticalLayout");
        imageMaxFrame = new QFrame(imageFrameMinimizeWidget);
        imageMaxFrame->setObjectName("imageMaxFrame");
        imageMaxFrame->setFrameShape(QFrame::Shape::NoFrame);
        imageFrameLayoutV = new QVBoxLayout(imageMaxFrame);
        imageFrameLayoutV->setObjectName("imageFrameLayoutV");
        imageFrameLayoutV->setContentsMargins(-1, 3, -1, 3);
        imageFrameLayoutH = new QHBoxLayout();
        imageFrameLayoutH->setObjectName("imageFrameLayoutH");
        ImageFrameLabel = new QLabel(imageMaxFrame);
        ImageFrameLabel->setObjectName("ImageFrameLabel");
        ImageFrameLabel->setMaximumSize(QSize(110, 32));
        ImageFrameLabel->setFont(font);

        imageFrameLayoutH->addWidget(ImageFrameLabel);

        imagetitlespacer = new QSpacerItem(20, 20, QSizePolicy::Policy::Expanding, QSizePolicy::Policy::Minimum);

        imageFrameLayoutH->addItem(imagetitlespacer);

        LoadCatalogButton = new QPushButton(imageMaxFrame);
        LoadCatalogButton->setObjectName("LoadCatalogButton");
        sizePolicy4.setHeightForWidth(LoadCatalogButton->sizePolicy().hasHeightForWidth());
        LoadCatalogButton->setSizePolicy(sizePolicy4);
        LoadCatalogButton->setMinimumSize(QSize(100, 24));
        LoadCatalogButton->setMaximumSize(QSize(100, 24));

        imageFrameLayoutH->addWidget(LoadCatalogButton);


        imageFrameLayoutV->addLayout(imageFrameLayoutH);

        ImageHLayout = new QHBoxLayout();
        ImageHLayout->setObjectName("ImageHLayout");
        ImageVLayout = new QVBoxLayout();
        ImageVLayout->setObjectName("ImageVLayout");
        ImagePreview = new QLabel(imageMaxFrame);
        ImagePreview->setObjectName("ImagePreview");
        ImagePreview->setMaximumSize(QSize(100000, 300));

        ImageVLayout->addWidget(ImagePreview);

        ImagePreviewCredit = new QLabel(imageMaxFrame);
        ImagePreviewCredit->setObjectName("ImagePreviewCredit");
        ImagePreviewCredit->setMaximumSize(QSize(100000, 32));

        ImageVLayout->addWidget(ImagePreviewCredit);

        ImagePreviewCreditLink = new QLabel(imageMaxFrame);
        ImagePreviewCreditLink->setObjectName("ImagePreviewCreditLink");
        ImagePreviewCreditLink->setMaximumSize(QSize(100000, 32));

        ImageVLayout->addWidget(ImagePreviewCreditLink);


        ImageHLayout->addLayout(ImageVLayout);

        imageHspacer_2 = new QSpacerItem(40, 20, QSizePolicy::Policy::Expanding, QSizePolicy::Policy::Minimum);

        ImageHLayout->addItem(imageHspacer_2);


        imageFrameLayoutV->addLayout(ImageHLayout);

        imagespacer = new QSpacerItem(40, 20, QSizePolicy::Policy::Minimum, QSizePolicy::Policy::Expanding);

        imageFrameLayoutV->addItem(imagespacer);


        imageFrameVerticalLayout->addWidget(imageMaxFrame);

        ImageMinFrame = new QFrame(imageFrameMinimizeWidget);
        ImageMinFrame->setObjectName("ImageMinFrame");
        ImageMinFrame->setFrameShape(QFrame::Shape::NoFrame);
        imageFrameLayoutV2 = new QVBoxLayout(ImageMinFrame);
        imageFrameLayoutV2->setSpacing(0);
        imageFrameLayoutV2->setObjectName("imageFrameLayoutV2");
        imageFrameLayoutV2->setContentsMargins(0, 0, 0, 0);
        imageFrameLayoutH2 = new QHBoxLayout();
        imageFrameLayoutH2->setObjectName("imageFrameLayoutH2");
        ImageFrameLabel2 = new QLabel(ImageMinFrame);
        ImageFrameLabel2->setObjectName("ImageFrameLabel2");
        ImageFrameLabel2->setMaximumSize(QSize(1000000, 32));
        ImageFrameLabel2->setFont(font);

        imageFrameLayoutH2->addWidget(ImageFrameLabel2);

        imagetitlespacer2 = new QSpacerItem(20, 20, QSizePolicy::Policy::Expanding, QSizePolicy::Policy::Minimum);

        imageFrameLayoutH2->addItem(imagetitlespacer2);

        LoadCatalogButton2 = new QPushButton(ImageMinFrame);
        LoadCatalogButton2->setObjectName("LoadCatalogButton2");
        sizePolicy4.setHeightForWidth(LoadCatalogButton2->sizePolicy().hasHeightForWidth());
        LoadCatalogButton2->setSizePolicy(sizePolicy4);
        LoadCatalogButton2->setMinimumSize(QSize(100, 24));

        imageFrameLayoutH2->addWidget(LoadCatalogButton2);


        imageFrameLayoutV2->addLayout(imageFrameLayoutH2);


        imageFrameVerticalLayout->addWidget(ImageMinFrame);


        RightLayout->addWidget(imageFrameMinimizeWidget);

        RightPanelSpacer = new QSpacerItem(40, 20, QSizePolicy::Policy::Minimum, QSizePolicy::Policy::Expanding);

        RightLayout->addItem(RightPanelSpacer);


        RightSideLayoutWithSpacer->addWidget(RightPanel);

        RightPanelOuterSpacer = new QSpacerItem(20, 20, QSizePolicy::Policy::Minimum, QSizePolicy::Policy::Expanding);

        RightSideLayoutWithSpacer->addItem(RightPanelOuterSpacer);


        WholeLayout->addLayout(RightSideLayoutWithSpacer);


        verticalLayout_2->addLayout(WholeLayout);


        retranslateUi(ImagingPlanner);

        QMetaObject::connectSlotsByName(ImagingPlanner);
    } // setupUi

    void retranslateUi(QWidget *ImagingPlanner)
    {
#if QT_CONFIG(tooltip)
        SearchB->setToolTip(tr2i18n("Search for an object in the table.", nullptr));
#endif // QT_CONFIG(tooltip)
        SearchB->setText(QString());
        SearchText->setPlaceholderText(tr2i18n("Object Name", nullptr));
        SearchText->setProperty("text", QVariant(QString()));
        tableCount->setText(QString());
        statusLabel->setText(tr2i18n("Select an Object", nullptr));
        moonImage->setText(QString());
        moonPercentLabel->setText(QString());
#if QT_CONFIG(tooltip)
        backOneDay->setToolTip(tr2i18n("Back one day", nullptr));
#endif // QT_CONFIG(tooltip)
        backOneDay->setText(QString());
        DateEdit->setDisplayFormat(tr2i18n("dd/MM/yy", nullptr));
#if QT_CONFIG(tooltip)
        forwardOneDay->setToolTip(tr2i18n("Forward one day", nullptr));
#endif // QT_CONFIG(tooltip)
        forwardOneDay->setText(QString());
#if QT_CONFIG(tooltip)
        optionsButton->setToolTip(tr2i18n("Open options menu.", nullptr));
#endif // QT_CONFIG(tooltip)
        optionsButton->setText(QString());
#if QT_CONFIG(tooltip)
        helpButton->setToolTip(tr2i18n("Open web documentation.", nullptr));
#endif // QT_CONFIG(tooltip)
        helpButton->setText(QString());
        DevelLabel->setText(tr2i18n("\n"
"                 Catalog Development:\n"
"              ", nullptr));
#if QT_CONFIG(tooltip)
        DevelDownsampleButton->setToolTip(tr2i18n("For catalog development", nullptr));
#endif // QT_CONFIG(tooltip)
        DevelDownsampleButton->setText(tr2i18n("Downsample", nullptr));
#if QT_CONFIG(tooltip)
        DevelCheckTargetsButton->setToolTip(tr2i18n("For catalog development", nullptr));
#endif // QT_CONFIG(tooltip)
        DevelCheckTargetsButton->setText(tr2i18n("Check", nullptr));
#if QT_CONFIG(tooltip)
        DevelCheckCatalogButton->setToolTip(tr2i18n("For catalog development", nullptr));
#endif // QT_CONFIG(tooltip)
        DevelCheckCatalogButton->setText(tr2i18n("Catalog", nullptr));
#if QT_CONFIG(tooltip)
        DevelCheckTargetsPrevButton->setToolTip(tr2i18n("For catalog development", nullptr));
#endif // QT_CONFIG(tooltip)
        DevelCheckTargetsPrevButton->setText(QString());
#if QT_CONFIG(tooltip)
        DevelCheckTargetsNextButton->setToolTip(tr2i18n("For catalog development", nullptr));
#endif // QT_CONFIG(tooltip)
        DevelCheckTargetsNextButton->setText(QString());
        infoObjectName->setText(QString());
        infoObjectType->setText(QString());
        infoSize->setText(QString());
        infoObjectFlags->setText(QString());
        infoObjectLongName->setText(QString());
        infoRiseSet->setText(QString());
#if QT_CONFIG(tooltip)
        userNotesEditButton->setToolTip(tr2i18n("Create/Edit some user notes for this object", nullptr));
#endif // QT_CONFIG(tooltip)
        userNotesEditButton->setText(QString());
#if QT_CONFIG(tooltip)
        userNotesDoneButton->setToolTip(tr2i18n("Done creating/editing some user notes for this object", nullptr));
#endif // QT_CONFIG(tooltip)
        userNotesDoneButton->setText(QString());
#if QT_CONFIG(tooltip)
        userNotesOpenLink->setToolTip(tr2i18n("Open a browser with the 1st link in this note.", nullptr));
#endif // QT_CONFIG(tooltip)
        userNotesOpenLink->setText(QString());
#if QT_CONFIG(tooltip)
        userNotesOpenLink2->setToolTip(tr2i18n("Open a browser with the 2nd link in this note.", nullptr));
#endif // QT_CONFIG(tooltip)
        userNotesOpenLink2->setText(QString());
#if QT_CONFIG(tooltip)
        userNotesOpenLink3->setToolTip(tr2i18n("Open a browser with the 3rd link in this note.", nullptr));
#endif // QT_CONFIG(tooltip)
        userNotesOpenLink3->setText(QString());
        userNotesLabel->setText(tr2i18n("Note:", nullptr));
        userNotes->setText(QString());
        userNotesEdit->setPlaceholderText(tr2i18n("Enter notes here", nullptr));
        userNotesEdit->setProperty("text", QVariant(QString()));
#if QT_CONFIG(tooltip)
        HiddenAltitudeGraphLabel->setToolTip(tr2i18n("Altitude vs Time graph.", nullptr));
#endif // QT_CONFIG(tooltip)
        HiddenAltitudeGraphLabel->setText(tr2i18n("Altitude vs Time graph", nullptr));
#if QT_CONFIG(tooltip)
        useArtificialHorizon->setToolTip(tr2i18n("<html><head/><body><p>Use the system's artificial horizon for calculating imaging hours.</p></body></html>", nullptr));
#endif // QT_CONFIG(tooltip)
        useArtificialHorizon->setText(tr2i18n("Artificial horizon", nullptr));
#if QT_CONFIG(tooltip)
        minAltitudeLabel->setToolTip(tr2i18n("For imaging hours calculation, object must be at least at this altitude (and above any artificial horizon in use).", nullptr));
#endif // QT_CONFIG(tooltip)
        minAltitudeLabel->setText(tr2i18n("Min alt", nullptr));
#if QT_CONFIG(tooltip)
        minAltitude->setToolTip(tr2i18n("For imaging hours calculation, object must be at least at this altitude (and above any artificial horizon in use).", nullptr));
#endif // QT_CONFIG(tooltip)
        minAltitude->setSuffix(tr2i18n(" \302\260", nullptr));
#if QT_CONFIG(tooltip)
        minMoonLabel->setToolTip(tr2i18n("<html><head/><body><p>For imaging hours calculations, object must be at least the number of degrees in the 1st box away from the moon, and the moon must be below the altitude in the 2nd box.</p></body></html>", nullptr));
#endif // QT_CONFIG(tooltip)
        minMoonLabel->setText(tr2i18n("Moon:", nullptr));
#if QT_CONFIG(tooltip)
        minMoon->setToolTip(tr2i18n("<html><head/><body><p>For imaging hours calculations object must be at least this far from the moon.</p></body></html>", nullptr));
#endif // QT_CONFIG(tooltip)
        minMoon->setSuffix(tr2i18n("\302\260", nullptr));
#if QT_CONFIG(tooltip)
        maxMoonAltitude->setToolTip(tr2i18n("<html><head/><body><p>For imaging hours calculations the moon must be lower than this altitude.</p></body></html>", nullptr));
#endif // QT_CONFIG(tooltip)
        maxMoonAltitude->setSuffix(tr2i18n("\302\260", nullptr));
#if QT_CONFIG(tooltip)
        SearchLabel->setToolTip(tr2i18n("Select a button to search for the selected object on the internet.", nullptr));
#endif // QT_CONFIG(tooltip)
        SearchLabel->setText(tr2i18n("Search", nullptr));
#if QT_CONFIG(tooltip)
        astrobinButton->setToolTip(tr2i18n("Search Astrobin for the selected object using the search constraints in this section.", nullptr));
#endif // QT_CONFIG(tooltip)
        astrobinButton->setText(tr2i18n("Astrobin", nullptr));
#if QT_CONFIG(tooltip)
        searchWikipedia->setToolTip(tr2i18n("Search Wikipedia for the selected object.", nullptr));
#endif // QT_CONFIG(tooltip)
        searchWikipedia->setText(tr2i18n("Wikipedia", nullptr));
#if QT_CONFIG(tooltip)
        searchSpecialWebPageImages->setToolTip(tr2i18n("Search the Professor Seligman online site for NGC/IC images.", nullptr));
#endif // QT_CONFIG(tooltip)
        searchSpecialWebPageImages->setText(tr2i18n("NGC/IC", nullptr));
#if QT_CONFIG(tooltip)
        searchSimbad->setToolTip(tr2i18n("Search Simbad.", nullptr));
#endif // QT_CONFIG(tooltip)
        searchSimbad->setText(tr2i18n("Simbad", nullptr));
#if QT_CONFIG(tooltip)
        AstrobinAward->setToolTip(tr2i18n("<html><head/><body><p>Required one of the Astrobin awards when searching Astrobin images.</p></body></html>", nullptr));
#endif // QT_CONFIG(tooltip)
        AstrobinAward->setText(tr2i18n("Awards Required", nullptr));
        radiusLabel->setText(tr2i18n("Radius:", nullptr));
        minRadiusLabel->setText(tr2i18n("Min:", nullptr));
        AstrobinMinRadius->setSuffix(tr2i18n(" \302\260", nullptr));
        maxRadiusLabel->setText(tr2i18n("Max:", nullptr));
        AstrobinMaxRadius->setSuffix(tr2i18n(" \302\260", nullptr));
#if QT_CONFIG(tooltip)
        SearchLabel2->setToolTip(tr2i18n("Select a button to search for the selected object on the internet.", nullptr));
#endif // QT_CONFIG(tooltip)
        SearchLabel2->setText(tr2i18n("Search", nullptr));
#if QT_CONFIG(tooltip)
        astrobinButton2->setToolTip(tr2i18n("Search Astrobin for the selected object using the search constraints in this section.", nullptr));
#endif // QT_CONFIG(tooltip)
        astrobinButton2->setText(tr2i18n("Astrobin", nullptr));
#if QT_CONFIG(tooltip)
        searchWikipedia2->setToolTip(tr2i18n("Search Wikipedia for the selected object.", nullptr));
#endif // QT_CONFIG(tooltip)
        searchWikipedia2->setText(tr2i18n("Wikipedia", nullptr));
#if QT_CONFIG(tooltip)
        searchSpecialWebPageImages2->setToolTip(tr2i18n("Search the Professor Seligman online site for NGC/IC images.", nullptr));
#endif // QT_CONFIG(tooltip)
        searchSpecialWebPageImages2->setText(tr2i18n("NGC/IC", nullptr));
#if QT_CONFIG(tooltip)
        searchSimbad2->setToolTip(tr2i18n("Search Simbad.", nullptr));
#endif // QT_CONFIG(tooltip)
        searchSimbad2->setText(tr2i18n("Simbad", nullptr));
#if QT_CONFIG(tooltip)
        FiltersLabel->setToolTip(tr2i18n("Constrain the list of object on the left by the filters in this section.", nullptr));
#endif // QT_CONFIG(tooltip)
        FiltersLabel->setText(tr2i18n("Filters", nullptr));
#if QT_CONFIG(tooltip)
        minHoursLabel->setToolTip(tr2i18n("Objects are only shown if they can be imaged for at least this many hours.", nullptr));
#endif // QT_CONFIG(tooltip)
        minHoursLabel->setText(tr2i18n("Min Hours:", nullptr));
#if QT_CONFIG(tooltip)
        minHours->setToolTip(tr2i18n("Objects are only shown if they can be imaged for at least this many hours.", nullptr));
#endif // QT_CONFIG(tooltip)
        minHours->setSuffix(QString());
#if QT_CONFIG(tooltip)
        OpenClusterCB->setToolTip(tr2i18n("<html><head/><body><p>Hide open clusters if unchecked.</p></body></html>", nullptr));
#endif // QT_CONFIG(tooltip)
        OpenClusterCB->setText(tr2i18n("Open Cl", nullptr));
#if QT_CONFIG(tooltip)
        NebulaCB->setToolTip(tr2i18n("<html><head/><body><p>Hide nebulae if unchecked.</p></body></html>", nullptr));
#endif // QT_CONFIG(tooltip)
        NebulaCB->setText(tr2i18n("Nebula", nullptr));
#if QT_CONFIG(tooltip)
        GlobularClusterCB->setToolTip(tr2i18n("<html><head/><body><p>Hide globular clusters if unchecked.</p></body></html>", nullptr));
#endif // QT_CONFIG(tooltip)
        GlobularClusterCB->setText(tr2i18n("Globular", nullptr));
#if QT_CONFIG(tooltip)
        PlanetaryCB->setToolTip(tr2i18n("<html><head/><body><p>Hide planetary nebulae if unchecked.</p></body></html>", nullptr));
#endif // QT_CONFIG(tooltip)
        PlanetaryCB->setText(tr2i18n("PN", nullptr));
#if QT_CONFIG(tooltip)
        SupernovaRemnantCB->setToolTip(tr2i18n("<html><head/><body><p>Hide supernova remnants if unchecked.</p></body></html>", nullptr));
#endif // QT_CONFIG(tooltip)
        SupernovaRemnantCB->setText(tr2i18n("Remnant", nullptr));
#if QT_CONFIG(tooltip)
        GalaxyCB->setToolTip(tr2i18n("<html><head/><body><p>Hide galaxies if unchecked.</p></body></html>", nullptr));
#endif // QT_CONFIG(tooltip)
        GalaxyCB->setText(tr2i18n("Galaxy", nullptr));
#if QT_CONFIG(tooltip)
        GalaxyClusterCB->setToolTip(tr2i18n("<html><head/><body><p>Hide galaxy clusters if unchecked.</p></body></html>", nullptr));
#endif // QT_CONFIG(tooltip)
        GalaxyClusterCB->setText(tr2i18n("Galaxy Cl", nullptr));
#if QT_CONFIG(tooltip)
        DarkNebulaCB->setToolTip(tr2i18n("<html><head/><body><p>Hide dark nebulae if unchecked.</p></body></html>", nullptr));
#endif // QT_CONFIG(tooltip)
        DarkNebulaCB->setText(tr2i18n("DarkNeb", nullptr));
#if QT_CONFIG(tooltip)
        OtherCB->setToolTip(tr2i18n("<html><head/><body><p>Hide other object types if unchecked.</p></body></html>", nullptr));
#endif // QT_CONFIG(tooltip)
        OtherCB->setText(tr2i18n("Other", nullptr));
#if QT_CONFIG(tooltip)
        pickedCB->setToolTip(tr2i18n("<html><head/><body><p>Show the objects that are marked picked (don't show those that are not picked).</p></body></html>", nullptr));
#endif // QT_CONFIG(tooltip)
        pickedCB->setText(tr2i18n("Picked", nullptr));
#if QT_CONFIG(tooltip)
        notPickedCB->setToolTip(tr2i18n("<html><head/><body><p>Show the objects that are not marked picked (don't show those that are picked).</p></body></html>", nullptr));
#endif // QT_CONFIG(tooltip)
        notPickedCB->setText(tr2i18n("Not Picked", nullptr));
#if QT_CONFIG(tooltip)
        dontCarePickedCB->setToolTip(tr2i18n("<html><head/><body><p>Object display doesn't depend on whether objects are marked picked or not.</p></body></html>", nullptr));
#endif // QT_CONFIG(tooltip)
        dontCarePickedCB->setText(tr2i18n("Don't care", nullptr));
#if QT_CONFIG(tooltip)
        imagedCB->setToolTip(tr2i18n("<html><head/><body><p>Show the objects that are marked imaged (and don't show those that are not marked previously imaged).</p></body></html>", nullptr));
#endif // QT_CONFIG(tooltip)
        imagedCB->setText(tr2i18n("Imaged", nullptr));
#if QT_CONFIG(tooltip)
        notImagedCB->setToolTip(tr2i18n("<html><head/><body><p>Show the objects that are not marked imaged (and don't show those that are marked previously imaged).</p></body></html>", nullptr));
#endif // QT_CONFIG(tooltip)
        notImagedCB->setText(tr2i18n("Not imaged", nullptr));
#if QT_CONFIG(tooltip)
        dontCareImagedCB->setToolTip(tr2i18n("<html><head/><body><p>Object display doesn't depend on whether objects are marked previously imaged or not.</p></body></html>", nullptr));
#endif // QT_CONFIG(tooltip)
        dontCareImagedCB->setText(tr2i18n("Don't care", nullptr));
#if QT_CONFIG(tooltip)
        loadImagedB->setToolTip(tr2i18n("Load a file listing the names of already imaged objects--one name per line. This adds to the list of imaged object, it does not replace them.", nullptr));
#endif // QT_CONFIG(tooltip)
        loadImagedB->setText(tr2i18n("Load", nullptr));
#if QT_CONFIG(tooltip)
        ignoredCB->setToolTip(tr2i18n("<html><head/><body><p>Show the objects that have been ignored (and don't show those that have not been ignored).</p></body></html>", nullptr));
#endif // QT_CONFIG(tooltip)
        ignoredCB->setText(tr2i18n("Ignored", nullptr));
#if QT_CONFIG(tooltip)
        notIgnoredCB->setToolTip(tr2i18n("<html><head/><body><p>Show the objects that have not been ignored (and don't show those that have been ignored).</p></body></html>", nullptr));
#endif // QT_CONFIG(tooltip)
        notIgnoredCB->setText(tr2i18n("Not ignored", nullptr));
#if QT_CONFIG(tooltip)
        dontCareIgnoredCB->setToolTip(tr2i18n("<html><head/><body><p>Object display doesn't depend on whether objects have been ignored or not.</p></body></html>", nullptr));
#endif // QT_CONFIG(tooltip)
        dontCareIgnoredCB->setText(tr2i18n("Don't care", nullptr));
#if QT_CONFIG(tooltip)
        keywordCB->setToolTip(tr2i18n("<html><head/><body><p>Show the objects that have the (case-sensitive) keyword in their notes (and don't show those that don't).</p></body></html>", nullptr));
#endif // QT_CONFIG(tooltip)
        keywordCB->setText(tr2i18n("Keyword", nullptr));
#if QT_CONFIG(tooltip)
        notKeywordCB->setToolTip(tr2i18n("<html><head/><body><p>Show the objects that don't have the (case-sensitive) keyword in their notes (and don't show those that do).</p></body></html>", nullptr));
#endif // QT_CONFIG(tooltip)
        notKeywordCB->setText(tr2i18n("Not keyword", nullptr));
#if QT_CONFIG(tooltip)
        dontCareKeywordCB->setToolTip(tr2i18n("<html><head/><body><p>Object display doesn't depend on whether or not objects have the keyword in their notes.</p></body></html>", nullptr));
#endif // QT_CONFIG(tooltip)
        dontCareKeywordCB->setText(tr2i18n("Don't care", nullptr));
#if QT_CONFIG(tooltip)
        keywordEdit->setToolTip(tr2i18n("Enter the (case-sensitive) keyword to be used for the checkboxes to the left.", nullptr));
#endif // QT_CONFIG(tooltip)
        keywordEdit->setPlaceholderText(tr2i18n("keyword", nullptr));
        keywordEdit->setProperty("text", QVariant(QString()));
#if QT_CONFIG(tooltip)
        FiltersLabel2->setToolTip(tr2i18n("Constrain the list of object on the left by the filters in this section.", nullptr));
#endif // QT_CONFIG(tooltip)
        FiltersLabel2->setText(tr2i18n("Filters", nullptr));
        ImageFrameLabel->setText(tr2i18n("Catalog Image", nullptr));
#if QT_CONFIG(tooltip)
        LoadCatalogButton->setToolTip(tr2i18n("Load a new catalog", nullptr));
#endif // QT_CONFIG(tooltip)
        LoadCatalogButton->setText(tr2i18n("Load Catalog", nullptr));
        ImagePreview->setText(QString());
        ImagePreviewCredit->setText(QString());
        ImagePreviewCreditLink->setText(QString());
        ImageFrameLabel2->setText(tr2i18n("Catalog Image", nullptr));
#if QT_CONFIG(tooltip)
        LoadCatalogButton2->setToolTip(tr2i18n("Load a new catalog", nullptr));
#endif // QT_CONFIG(tooltip)
        LoadCatalogButton2->setText(tr2i18n("Load Catalog", nullptr));
        (void)ImagingPlanner;
    } // retranslateUi

};

namespace Ui {
    class ImagingPlanner: public Ui_ImagingPlanner {};
} // namespace Ui

QT_END_NAMESPACE

#endif // IMAGINGPLANNER_H

