/********************************************************************************
** Form generated from reading UI file 'horizonmanager.ui'
**
** Created by: Qt User Interface Compiler version 6.11.1
**
** WARNING! All changes made in this file will be lost when recompiling UI file!
********************************************************************************/

#ifndef UI_HORIZONMANAGER_H
#define UI_HORIZONMANAGER_H

#include <QtCore/QVariant>
#include <QtWidgets/QApplication>
#include <QtWidgets/QGroupBox>
#include <QtWidgets/QHBoxLayout>
#include <QtWidgets/QHeaderView>
#include <QtWidgets/QLabel>
#include <QtWidgets/QListView>
#include <QtWidgets/QPushButton>
#include <QtWidgets/QSpacerItem>
#include <QtWidgets/QTableView>
#include <QtWidgets/QVBoxLayout>
#include <QtWidgets/QWidget>
#include <klocalizedstring.h>

QT_BEGIN_NAMESPACE

class Ui_HorizonManager
{
public:
    QVBoxLayout *verticalLayout_3;
    QHBoxLayout *horizontalLayout_3;
    QGroupBox *groupBox;
    QVBoxLayout *verticalLayout;
    QHBoxLayout *horizontalLayout;
    QPushButton *addRegionB;
    QPushButton *removeRegionB;
    QPushButton *toggleCeilingB;
    QSpacerItem *horizontalSpacer_1;
    QPushButton *exportHorizonB;
    QPushButton *importHorizonB;
    QSpacerItem *horizontalSpacer;
    QPushButton *saveB;
    QListView *regionsList;
    QGroupBox *groupBox_2;
    QVBoxLayout *verticalLayout_2;
    QHBoxLayout *horizontalLayout_2;
    QPushButton *addPointB;
    QPushButton *removePointB;
    QPushButton *clearPointsB;
    QSpacerItem *horizontalSpacer_2;
    QLabel *regionValidation;
    QPushButton *selectPointsB;
    QTableView *pointsList;
    QHBoxLayout *horizontalLayout_4;
    QLabel *tipLabel;
    QLabel *label;

    void setupUi(QWidget *HorizonManager)
    {
        if (HorizonManager->objectName().isEmpty())
            HorizonManager->setObjectName("HorizonManager");
        HorizonManager->resize(609, 449);
        verticalLayout_3 = new QVBoxLayout(HorizonManager);
        verticalLayout_3->setObjectName("verticalLayout_3");
        horizontalLayout_3 = new QHBoxLayout();
        horizontalLayout_3->setObjectName("horizontalLayout_3");
        horizontalLayout_3->setSizeConstraint(QLayout::SetDefaultConstraint);
        groupBox = new QGroupBox(HorizonManager);
        groupBox->setObjectName("groupBox");
        verticalLayout = new QVBoxLayout(groupBox);
        verticalLayout->setObjectName("verticalLayout");
        horizontalLayout = new QHBoxLayout();
        horizontalLayout->setObjectName("horizontalLayout");
        addRegionB = new QPushButton(groupBox);
        addRegionB->setObjectName("addRegionB");
        addRegionB->setMinimumSize(QSize(32, 32));
        addRegionB->setMaximumSize(QSize(32, 32));

        horizontalLayout->addWidget(addRegionB);

        removeRegionB = new QPushButton(groupBox);
        removeRegionB->setObjectName("removeRegionB");
        removeRegionB->setEnabled(false);
        removeRegionB->setMinimumSize(QSize(32, 32));
        removeRegionB->setMaximumSize(QSize(32, 32));

        horizontalLayout->addWidget(removeRegionB);

        toggleCeilingB = new QPushButton(groupBox);
        toggleCeilingB->setObjectName("toggleCeilingB");
        toggleCeilingB->setEnabled(false);
        toggleCeilingB->setMinimumSize(QSize(32, 32));
        toggleCeilingB->setMaximumSize(QSize(32, 32));

        horizontalLayout->addWidget(toggleCeilingB);

        horizontalSpacer_1 = new QSpacerItem(20, 20, QSizePolicy::Policy::Expanding, QSizePolicy::Policy::Minimum);

        horizontalLayout->addItem(horizontalSpacer_1);

        exportHorizonB = new QPushButton(groupBox);
        exportHorizonB->setObjectName("exportHorizonB");
        exportHorizonB->setEnabled(false);
        exportHorizonB->setMinimumSize(QSize(32, 32));
        exportHorizonB->setMaximumSize(QSize(32, 32));

        horizontalLayout->addWidget(exportHorizonB);

        importHorizonB = new QPushButton(groupBox);
        importHorizonB->setObjectName("importHorizonB");
        importHorizonB->setEnabled(true);
        importHorizonB->setMinimumSize(QSize(32, 32));
        importHorizonB->setMaximumSize(QSize(32, 32));

        horizontalLayout->addWidget(importHorizonB);

        horizontalSpacer = new QSpacerItem(40, 20, QSizePolicy::Policy::Expanding, QSizePolicy::Policy::Minimum);

        horizontalLayout->addItem(horizontalSpacer);

        saveB = new QPushButton(groupBox);
        saveB->setObjectName("saveB");
        saveB->setEnabled(false);
        saveB->setMinimumSize(QSize(32, 32));
        saveB->setMaximumSize(QSize(32, 32));

        horizontalLayout->addWidget(saveB);


        verticalLayout->addLayout(horizontalLayout);

        regionsList = new QListView(groupBox);
        regionsList->setObjectName("regionsList");

        verticalLayout->addWidget(regionsList);


        horizontalLayout_3->addWidget(groupBox);

        groupBox_2 = new QGroupBox(HorizonManager);
        groupBox_2->setObjectName("groupBox_2");
        QSizePolicy sizePolicy(QSizePolicy::Policy::Preferred, QSizePolicy::Policy::Preferred);
        sizePolicy.setHorizontalStretch(0);
        sizePolicy.setVerticalStretch(0);
        sizePolicy.setHeightForWidth(groupBox_2->sizePolicy().hasHeightForWidth());
        groupBox_2->setSizePolicy(sizePolicy);
        verticalLayout_2 = new QVBoxLayout(groupBox_2);
        verticalLayout_2->setObjectName("verticalLayout_2");
        horizontalLayout_2 = new QHBoxLayout();
        horizontalLayout_2->setObjectName("horizontalLayout_2");
        addPointB = new QPushButton(groupBox_2);
        addPointB->setObjectName("addPointB");
        addPointB->setEnabled(false);
        addPointB->setMinimumSize(QSize(32, 32));
        addPointB->setMaximumSize(QSize(32, 32));

        horizontalLayout_2->addWidget(addPointB);

        removePointB = new QPushButton(groupBox_2);
        removePointB->setObjectName("removePointB");
        removePointB->setEnabled(false);
        removePointB->setMinimumSize(QSize(32, 32));
        removePointB->setMaximumSize(QSize(32, 32));

        horizontalLayout_2->addWidget(removePointB);

        clearPointsB = new QPushButton(groupBox_2);
        clearPointsB->setObjectName("clearPointsB");
        clearPointsB->setEnabled(false);
        clearPointsB->setMinimumSize(QSize(32, 32));
        clearPointsB->setMaximumSize(QSize(32, 32));

        horizontalLayout_2->addWidget(clearPointsB);

        horizontalSpacer_2 = new QSpacerItem(40, 20, QSizePolicy::Policy::Expanding, QSizePolicy::Policy::Minimum);

        horizontalLayout_2->addItem(horizontalSpacer_2);

        regionValidation = new QLabel(groupBox_2);
        regionValidation->setObjectName("regionValidation");
        regionValidation->setEnabled(false);
        regionValidation->setMinimumSize(QSize(32, 32));

        horizontalLayout_2->addWidget(regionValidation);

        selectPointsB = new QPushButton(groupBox_2);
        selectPointsB->setObjectName("selectPointsB");
        selectPointsB->setEnabled(false);
        selectPointsB->setMinimumSize(QSize(32, 32));
        selectPointsB->setMaximumSize(QSize(32, 32));
        selectPointsB->setCheckable(true);
        selectPointsB->setFlat(false);

        horizontalLayout_2->addWidget(selectPointsB);


        verticalLayout_2->addLayout(horizontalLayout_2);

        pointsList = new QTableView(groupBox_2);
        pointsList->setObjectName("pointsList");

        verticalLayout_2->addWidget(pointsList);


        horizontalLayout_3->addWidget(groupBox_2);


        verticalLayout_3->addLayout(horizontalLayout_3);

        horizontalLayout_4 = new QHBoxLayout();
        horizontalLayout_4->setObjectName("horizontalLayout_4");
        tipLabel = new QLabel(HorizonManager);
        tipLabel->setObjectName("tipLabel");
        tipLabel->setMinimumSize(QSize(64, 64));
        tipLabel->setMaximumSize(QSize(64, 64));

        horizontalLayout_4->addWidget(tipLabel);

        label = new QLabel(HorizonManager);
        label->setObjectName("label");
        label->setWordWrap(true);

        horizontalLayout_4->addWidget(label);

        horizontalLayout_4->setStretch(0, 1);
        horizontalLayout_4->setStretch(1, 5);

        verticalLayout_3->addLayout(horizontalLayout_4);


        retranslateUi(HorizonManager);

        QMetaObject::connectSlotsByName(HorizonManager);
    } // setupUi

    void retranslateUi(QWidget *HorizonManager)
    {
        groupBox->setTitle(tr2i18n("Regions", nullptr));
#if QT_CONFIG(tooltip)
        addRegionB->setToolTip(tr2i18n("Add Region", nullptr));
#endif // QT_CONFIG(tooltip)
        addRegionB->setText(QString());
#if QT_CONFIG(tooltip)
        removeRegionB->setToolTip(tr2i18n("Remove Region", nullptr));
#endif // QT_CONFIG(tooltip)
        removeRegionB->setText(QString());
#if QT_CONFIG(tooltip)
        toggleCeilingB->setToolTip(tr2i18n("Toggle Ceiling", nullptr));
#endif // QT_CONFIG(tooltip)
        toggleCeilingB->setText(QString());
#if QT_CONFIG(tooltip)
        exportHorizonB->setToolTip(tr2i18n("Export the selected horizon to a file", nullptr));
#endif // QT_CONFIG(tooltip)
        exportHorizonB->setText(QString());
#if QT_CONFIG(tooltip)
        importHorizonB->setToolTip(tr2i18n("Import a previously exported horizon file", nullptr));
#endif // QT_CONFIG(tooltip)
        importHorizonB->setText(QString());
#if QT_CONFIG(tooltip)
        saveB->setToolTip(tr2i18n("Save Regions", nullptr));
#endif // QT_CONFIG(tooltip)
        saveB->setText(QString());
        groupBox_2->setTitle(tr2i18n("Points", nullptr));
#if QT_CONFIG(tooltip)
        addPointB->setToolTip(tr2i18n("Add Point", nullptr));
#endif // QT_CONFIG(tooltip)
        addPointB->setText(QString());
#if QT_CONFIG(tooltip)
        removePointB->setToolTip(tr2i18n("Remove Point", nullptr));
#endif // QT_CONFIG(tooltip)
        removePointB->setText(QString());
#if QT_CONFIG(tooltip)
        clearPointsB->setToolTip(tr2i18n("Clear all points", nullptr));
#endif // QT_CONFIG(tooltip)
        clearPointsB->setText(QString());
#if QT_CONFIG(tooltip)
        regionValidation->setToolTip(QString());
#endif // QT_CONFIG(tooltip)
        regionValidation->setText(QString());
#if QT_CONFIG(tooltip)
        selectPointsB->setToolTip(tr2i18n("Select points from the sky map", nullptr));
#endif // QT_CONFIG(tooltip)
        selectPointsB->setText(QString());
        tipLabel->setText(QString());
        label->setText(tr2i18n("<html><head/><body><p>Artificial horizon is used to define <span style=\" font-weight:600;\">Regions</span> on the SkyMap that are <span style=\" font-style:italic;\">blocked</span> from view from your vantage point (e.g. by tall trees or buildings). Regions can be areas above or below line segments that you enter. </p><ul style=\"margin-top: 0px; margin-bottom: 0px; margin-left: 0px; margin-right: 0px; -qt-list-indent: 1;\"><li style=\" margin-top:12px; margin-bottom:0px; margin-left:0px; margin-right:0px; -qt-block-indent:0; text-indent:0px;\">To draw a <span style=\" font-weight:600;\">Region</span>, enter a list of <span style=\" font-weight:600;\">Points</span> (<span style=\" font-style:italic;\">minimum</span> 2) that outlines the top of a blocked area (the <span style=\" font-weight:600;\">blockage is below</span> the lines).</li><ul style=\"margin-top: 0px; margin-bottom: 0px; margin-left: 0px; margin-right: 0px; -qt-list-indent: 1;\"><li style=\" margin-top:0px; margin-bottom:0px; margin-left:0px; ma"
                        "rgin-right:0px; -qt-block-indent:0; text-indent:0px;\">Setting <span style=\" font-style:italic;\">ceiling/window mode</span> for a list of points instead sets the <span style=\" font-weight:600;\">blockage above</span> the lines.</li><li style=\" margin-top:0px; margin-bottom:0px; margin-left:0px; margin-right:0px; -qt-block-indent:0; text-indent:0px;\">Add the points manually, or preferably by selecting them from the Sky Map after clicking <span style=\" font-style:italic;\">Select Points</span> button. </li></ul><li style=\" margin-top:0px; margin-bottom:0px; margin-left:0px; margin-right:0px; -qt-block-indent:0; text-indent:0px;\">Enable a region by <span style=\" font-style:italic;\">checking its box</span>. </li><li style=\" margin-top:0px; margin-bottom:0px; margin-left:0px; margin-right:0px; -qt-block-indent:0; text-indent:0px;\">Selecting a region displays its points on the SkyMap. </li><li style=\" margin-top:0px; margin-bottom:0px; margin-left:0px; margin-right:0px; -qt-block-indent:0; text-indent:0"
                        "px;\">When done click <span style=\" font-style:italic;\">Apply</span>.</li><li style=\" margin-top:0px; margin-bottom:0px; margin-left:0px; margin-right:0px; -qt-block-indent:0; text-indent:0px;\">Defining regions is easier when used in conjunction with the Terrain background feature.</li><li style=\" margin-top:0px; margin-bottom:12px; margin-left:0px; margin-right:0px; -qt-block-indent:0; text-indent:0px;\">You can export (and later import) regions using the export/import region buttons.</li></ul></body></html>", nullptr));
        (void)HorizonManager;
    } // retranslateUi

};

namespace Ui {
    class HorizonManager: public Ui_HorizonManager {};
} // namespace Ui

QT_END_NAMESPACE

#endif // HORIZONMANAGER_H

