/****************************************************************************
** Meta object code from reading C++ file 'pacadaptor.h'
**
** Created by: The Qt Meta Object Compiler version 69 (Qt 6.11.1)
**
** WARNING! All changes made in this file will be lost!
*****************************************************************************/

#include "pacadaptor.h"
#include <QtCore/qmetatype.h>

#include <QtCore/qtmochelpers.h>

#include <memory>


#include <QtCore/qxptype_traits.h>
#if !defined(Q_MOC_OUTPUT_REVISION)
#error "The header file 'pacadaptor.h' doesn't include <QObject>."
#elif Q_MOC_OUTPUT_REVISION != 69
#error "This file was generated using the moc from 6.11.1. It"
#error "cannot be used with the include files from this version of Qt."
#error "(The moc has changed too much.)"
#endif

#ifndef Q_CONSTINIT
#define Q_CONSTINIT
#endif

QT_WARNING_PUSH
QT_WARNING_DISABLE_DEPRECATED
QT_WARNING_DISABLE_GCC("-Wuseless-cast")
namespace {
struct qt_meta_tag_ZN10PACAdaptorE_t {};
} // unnamed namespace

template <> constexpr inline auto PACAdaptor::qt_create_metaobjectdata<qt_meta_tag_ZN10PACAdaptorE_t>()
{
    namespace QMC = QtMocConstants;
    QtMocHelpers::StringRefStorage qt_stringData {
        "PACAdaptor",
        "D-Bus Interface",
        "org.kde.kstars.INDI.PAC",
        "D-Bus Introspection",
        "  <interface name=\"org.kde.kstars.INDI.PAC\">\n    <property acce"
        "ss=\"read\" type=\"s\" name=\"name\"/>\n    <property access=\"rea"
        "d\" type=\"b\" name=\"connected\"/>\n    <property access=\"read\""
        " type=\"i\" name=\"status\">\n      <annotation value=\"ISD::PAC::"
        "Status\" name=\"org.qtproject.QtDBus.QtTypeName\"/>\n    </propert"
        "y>\n    <method name=\"startCorrection\">\n      <arg direction=\""
        "in\" type=\"d\" name=\"azError\"/>\n      <arg direction=\"in\" ty"
        "pe=\"d\" name=\"altError\"/>\n      <arg direction=\"out\" type=\""
        "b\"/>\n    </method>\n    <method name=\"abortCorrection\">\n     "
        " <arg direction=\"out\" type=\"b\"/>\n    </method>\n    <method n"
        "ame=\"moveAZ\">\n      <arg direction=\"in\" type=\"d\" name=\"deg"
        "rees\"/>\n      <arg direction=\"out\" type=\"b\"/>\n    </method>"
        "\n    <method name=\"moveALT\">\n      <arg direction=\"in\" type="
        "\"d\" name=\"degrees\"/>\n      <arg direction=\"out\" type=\"b\"/"
        ">\n    </method>\n    <signal name=\"Connected\"/>\n    <signal na"
        "me=\"Disconnected\"/>\n    <signal name=\"ready\"/>\n    <signal n"
        "ame=\"newStatus\">\n      <arg direction=\"out\" type=\"(i)\" name"
        "=\"status\"/>\n      <annotation value=\"ISD::PAC::Status\" name=\""
        "org.qtproject.QtDBus.QtTypeName.In0\"/>\n      <annotation value=\""
        "ISD::PAC::Status\" name=\"org.qtproject.QtDBus.QtTypeName.Out0\"/>"
        "\n    </signal>\n  </interface>\n",
        "Connected",
        "",
        "Disconnected",
        "newStatus",
        "ISD::PAC::Status",
        "status",
        "ready",
        "abortCorrection",
        "moveALT",
        "degrees",
        "moveAZ",
        "startCorrection",
        "azError",
        "altError",
        "connected",
        "name"
    };

    QtMocHelpers::UintData qt_methods {
        // Signal 'Connected'
        QtMocHelpers::SignalData<void()>(5, 6, QMC::AccessPublic, QMetaType::Void),
        // Signal 'Disconnected'
        QtMocHelpers::SignalData<void()>(7, 6, QMC::AccessPublic, QMetaType::Void),
        // Signal 'newStatus'
        QtMocHelpers::SignalData<void(ISD::PAC::Status)>(8, 6, QMC::AccessPublic, QMetaType::Void, {{
            { 0x80000000 | 9, 10 },
        }}),
        // Signal 'ready'
        QtMocHelpers::SignalData<void()>(11, 6, QMC::AccessPublic, QMetaType::Void),
        // Slot 'abortCorrection'
        QtMocHelpers::SlotData<bool()>(12, 6, QMC::AccessPublic, QMetaType::Bool),
        // Slot 'moveALT'
        QtMocHelpers::SlotData<bool(double)>(13, 6, QMC::AccessPublic, QMetaType::Bool, {{
            { QMetaType::Double, 14 },
        }}),
        // Slot 'moveAZ'
        QtMocHelpers::SlotData<bool(double)>(15, 6, QMC::AccessPublic, QMetaType::Bool, {{
            { QMetaType::Double, 14 },
        }}),
        // Slot 'startCorrection'
        QtMocHelpers::SlotData<bool(double, double)>(16, 6, QMC::AccessPublic, QMetaType::Bool, {{
            { QMetaType::Double, 17 }, { QMetaType::Double, 18 },
        }}),
    };
    QtMocHelpers::UintData qt_properties {
        // property 'connected'
        QtMocHelpers::PropertyData<bool>(19, QMetaType::Bool, QMC::DefaultPropertyFlags),
        // property 'name'
        QtMocHelpers::PropertyData<QString>(20, QMetaType::QString, QMC::DefaultPropertyFlags),
        // property 'status'
        QtMocHelpers::PropertyData<int>(10, QMetaType::Int, QMC::DefaultPropertyFlags),
    };
    QtMocHelpers::UintData qt_enums {
    };
    QtMocHelpers::UintData qt_constructors {};
    QtMocHelpers::ClassInfos qt_classinfo({
            {    1,    2 },
            {    3,    4 },
    });
    return QtMocHelpers::metaObjectData<PACAdaptor, qt_meta_tag_ZN10PACAdaptorE_t>(QMC::MetaObjectFlag{}, qt_stringData,
            qt_methods, qt_properties, qt_enums, qt_constructors, qt_classinfo);
}
Q_CONSTINIT const QMetaObject PACAdaptor::staticMetaObject = { {
    QMetaObject::SuperData::link<QDBusAbstractAdaptor::staticMetaObject>(),
    qt_staticMetaObjectStaticContent<qt_meta_tag_ZN10PACAdaptorE_t>.stringdata,
    qt_staticMetaObjectStaticContent<qt_meta_tag_ZN10PACAdaptorE_t>.data,
    qt_static_metacall,
    nullptr,
    qt_staticMetaObjectRelocatingContent<qt_meta_tag_ZN10PACAdaptorE_t>.metaTypes,
    nullptr
} };

void PACAdaptor::qt_static_metacall(QObject *_o, QMetaObject::Call _c, int _id, void **_a)
{
    auto *_t = static_cast<PACAdaptor *>(_o);
    if (_c == QMetaObject::InvokeMetaMethod) {
        switch (_id) {
        case 0: _t->Connected(); break;
        case 1: _t->Disconnected(); break;
        case 2: _t->newStatus((*reinterpret_cast<std::add_pointer_t<ISD::PAC::Status>>(_a[1]))); break;
        case 3: _t->ready(); break;
        case 4: { bool _r = _t->abortCorrection();
            if (_a[0]) *reinterpret_cast<bool*>(_a[0]) = std::move(_r); }  break;
        case 5: { bool _r = _t->moveALT((*reinterpret_cast<std::add_pointer_t<double>>(_a[1])));
            if (_a[0]) *reinterpret_cast<bool*>(_a[0]) = std::move(_r); }  break;
        case 6: { bool _r = _t->moveAZ((*reinterpret_cast<std::add_pointer_t<double>>(_a[1])));
            if (_a[0]) *reinterpret_cast<bool*>(_a[0]) = std::move(_r); }  break;
        case 7: { bool _r = _t->startCorrection((*reinterpret_cast<std::add_pointer_t<double>>(_a[1])),(*reinterpret_cast<std::add_pointer_t<double>>(_a[2])));
            if (_a[0]) *reinterpret_cast<bool*>(_a[0]) = std::move(_r); }  break;
        default: ;
        }
    }
    if (_c == QMetaObject::RegisterMethodArgumentMetaType) {
        switch (_id) {
        default: *reinterpret_cast<QMetaType *>(_a[0]) = QMetaType(); break;
        case 2:
            switch (*reinterpret_cast<int*>(_a[1])) {
            default: *reinterpret_cast<QMetaType *>(_a[0]) = QMetaType(); break;
            case 0:
                *reinterpret_cast<QMetaType *>(_a[0]) = QMetaType::fromType< ISD::PAC::Status >(); break;
            }
            break;
        }
    }
    if (_c == QMetaObject::IndexOfMethod) {
        if (QtMocHelpers::indexOfMethod<void (PACAdaptor::*)()>(_a, &PACAdaptor::Connected, 0))
            return;
        if (QtMocHelpers::indexOfMethod<void (PACAdaptor::*)()>(_a, &PACAdaptor::Disconnected, 1))
            return;
        if (QtMocHelpers::indexOfMethod<void (PACAdaptor::*)(ISD::PAC::Status )>(_a, &PACAdaptor::newStatus, 2))
            return;
        if (QtMocHelpers::indexOfMethod<void (PACAdaptor::*)()>(_a, &PACAdaptor::ready, 3))
            return;
    }
    if (_c == QMetaObject::ReadProperty) {
        void *_v = _a[0];
        switch (_id) {
        case 0: *reinterpret_cast<bool*>(_v) = _t->connected(); break;
        case 1: *reinterpret_cast<QString*>(_v) = _t->name(); break;
        case 2: *reinterpret_cast<int*>(_v) = _t->status(); break;
        default: break;
        }
    }
}

const QMetaObject *PACAdaptor::metaObject() const
{
    return QObject::d_ptr->metaObject ? QObject::d_ptr->dynamicMetaObject() : &staticMetaObject;
}

void *PACAdaptor::qt_metacast(const char *_clname)
{
    if (!_clname) return nullptr;
    if (!strcmp(_clname, qt_staticMetaObjectStaticContent<qt_meta_tag_ZN10PACAdaptorE_t>.strings))
        return static_cast<void*>(this);
    return QDBusAbstractAdaptor::qt_metacast(_clname);
}

int PACAdaptor::qt_metacall(QMetaObject::Call _c, int _id, void **_a)
{
    _id = QDBusAbstractAdaptor::qt_metacall(_c, _id, _a);
    if (_id < 0)
        return _id;
    if (_c == QMetaObject::InvokeMetaMethod) {
        if (_id < 8)
            qt_static_metacall(this, _c, _id, _a);
        _id -= 8;
    }
    if (_c == QMetaObject::RegisterMethodArgumentMetaType) {
        if (_id < 8)
            qt_static_metacall(this, _c, _id, _a);
        _id -= 8;
    }
    if (_c == QMetaObject::ReadProperty || _c == QMetaObject::WriteProperty
            || _c == QMetaObject::ResetProperty || _c == QMetaObject::BindableProperty
            || _c == QMetaObject::RegisterPropertyMetaType) {
        qt_static_metacall(this, _c, _id, _a);
        _id -= 3;
    }
    return _id;
}

// SIGNAL 0
void PACAdaptor::Connected()
{
    QMetaObject::activate(this, &staticMetaObject, 0, nullptr);
}

// SIGNAL 1
void PACAdaptor::Disconnected()
{
    QMetaObject::activate(this, &staticMetaObject, 1, nullptr);
}

// SIGNAL 2
void PACAdaptor::newStatus(ISD::PAC::Status _t1)
{
    QMetaObject::activate<void>(this, &staticMetaObject, 2, nullptr, _t1);
}

// SIGNAL 3
void PACAdaptor::ready()
{
    QMetaObject::activate(this, &staticMetaObject, 3, nullptr);
}
QT_WARNING_POP
