/****************************************************************************
** Meta object code from reading C++ file 'imageexporter.h'
**
** Created by: The Qt Meta Object Compiler version 69 (Qt 6.11.1)
**
** WARNING! All changes made in this file will be lost!
*****************************************************************************/

#include "../../../../kstars-3.8.4.1/kstars/auxiliary/imageexporter.h"
#include <QtCore/qmetatype.h>

#include <QtCore/qtmochelpers.h>

#include <memory>


#include <QtCore/qxptype_traits.h>
#if !defined(Q_MOC_OUTPUT_REVISION)
#error "The header file 'imageexporter.h' doesn't include <QObject>."
#elif Q_MOC_OUTPUT_REVISION != 69
#error "This file was generated using the moc from 6.11.1. It"
#error "cannot be used with the include files from this version of Qt."
#error "(The moc has changed too much.)"
#endif

#ifndef Q_CONSTINIT
#define Q_CONSTINIT
#endif

QT_WARNING_PUSH
QT_WARNING_DISABLE_DEPRECATED
QT_WARNING_DISABLE_GCC("-Wuseless-cast")
namespace {
struct qt_meta_tag_ZN13ImageExporterE_t {};
} // unnamed namespace

template <> constexpr inline auto ImageExporter::qt_create_metaobjectdata<qt_meta_tag_ZN13ImageExporterE_t>()
{
    namespace QMC = QtMocConstants;
    QtMocHelpers::StringRefStorage qt_stringData {
        "ImageExporter",
        "exportImage",
        "",
        "url",
        "setLegendProperties",
        "Legend::LEGEND_TYPE",
        "type",
        "Legend::LEGEND_ORIENTATION",
        "orientation",
        "Legend::LEGEND_POSITION",
        "position",
        "alpha",
        "include",
        "includeLegend",
        "setLegendAlpha",
        "setRasterOutputSize",
        "const QSize*",
        "size",
        "getLegend",
        "Legend*"
    };

    QtMocHelpers::UintData qt_methods {
        // Slot 'exportImage'
        QtMocHelpers::SlotData<bool(QString)>(1, 2, QMC::AccessPublic, QMetaType::Bool, {{
            { QMetaType::QString, 3 },
        }}),
        // Slot 'setLegendProperties'
        QtMocHelpers::SlotData<void(Legend::LEGEND_TYPE, Legend::LEGEND_ORIENTATION, Legend::LEGEND_POSITION, int, bool)>(4, 2, QMC::AccessPublic, QMetaType::Void, {{
            { 0x80000000 | 5, 6 }, { 0x80000000 | 7, 8 }, { 0x80000000 | 9, 10 }, { QMetaType::Int, 11 },
            { QMetaType::Bool, 12 },
        }}),
        // Slot 'setLegendProperties'
        QtMocHelpers::SlotData<void(Legend::LEGEND_TYPE, Legend::LEGEND_ORIENTATION, Legend::LEGEND_POSITION, int)>(4, 2, QMC::AccessPublic | QMC::MethodCloned, QMetaType::Void, {{
            { 0x80000000 | 5, 6 }, { 0x80000000 | 7, 8 }, { 0x80000000 | 9, 10 }, { QMetaType::Int, 11 },
        }}),
        // Slot 'setLegendProperties'
        QtMocHelpers::SlotData<void(Legend::LEGEND_TYPE, Legend::LEGEND_ORIENTATION, Legend::LEGEND_POSITION)>(4, 2, QMC::AccessPublic | QMC::MethodCloned, QMetaType::Void, {{
            { 0x80000000 | 5, 6 }, { 0x80000000 | 7, 8 }, { 0x80000000 | 9, 10 },
        }}),
        // Slot 'includeLegend'
        QtMocHelpers::SlotData<void(bool)>(13, 2, QMC::AccessPublic, QMetaType::Void, {{
            { QMetaType::Bool, 12 },
        }}),
        // Slot 'setLegendAlpha'
        QtMocHelpers::SlotData<void(int)>(14, 2, QMC::AccessPublic, QMetaType::Void, {{
            { QMetaType::Int, 11 },
        }}),
        // Slot 'setRasterOutputSize'
        QtMocHelpers::SlotData<void(const QSize *)>(15, 2, QMC::AccessPublic, QMetaType::Void, {{
            { 0x80000000 | 16, 17 },
        }}),
        // Slot 'getLegend'
        QtMocHelpers::SlotData<Legend *()>(18, 2, QMC::AccessPublic, 0x80000000 | 19),
    };
    QtMocHelpers::UintData qt_properties {
    };
    QtMocHelpers::UintData qt_enums {
    };
    return QtMocHelpers::metaObjectData<ImageExporter, qt_meta_tag_ZN13ImageExporterE_t>(QMC::MetaObjectFlag{}, qt_stringData,
            qt_methods, qt_properties, qt_enums);
}
Q_CONSTINIT const QMetaObject ImageExporter::staticMetaObject = { {
    QMetaObject::SuperData::link<QObject::staticMetaObject>(),
    qt_staticMetaObjectStaticContent<qt_meta_tag_ZN13ImageExporterE_t>.stringdata,
    qt_staticMetaObjectStaticContent<qt_meta_tag_ZN13ImageExporterE_t>.data,
    qt_static_metacall,
    nullptr,
    qt_staticMetaObjectRelocatingContent<qt_meta_tag_ZN13ImageExporterE_t>.metaTypes,
    nullptr
} };

void ImageExporter::qt_static_metacall(QObject *_o, QMetaObject::Call _c, int _id, void **_a)
{
    auto *_t = static_cast<ImageExporter *>(_o);
    if (_c == QMetaObject::InvokeMetaMethod) {
        switch (_id) {
        case 0: { bool _r = _t->exportImage((*reinterpret_cast<std::add_pointer_t<QString>>(_a[1])));
            if (_a[0]) *reinterpret_cast<bool*>(_a[0]) = std::move(_r); }  break;
        case 1: _t->setLegendProperties((*reinterpret_cast<std::add_pointer_t<Legend::LEGEND_TYPE>>(_a[1])),(*reinterpret_cast<std::add_pointer_t<Legend::LEGEND_ORIENTATION>>(_a[2])),(*reinterpret_cast<std::add_pointer_t<Legend::LEGEND_POSITION>>(_a[3])),(*reinterpret_cast<std::add_pointer_t<int>>(_a[4])),(*reinterpret_cast<std::add_pointer_t<bool>>(_a[5]))); break;
        case 2: _t->setLegendProperties((*reinterpret_cast<std::add_pointer_t<Legend::LEGEND_TYPE>>(_a[1])),(*reinterpret_cast<std::add_pointer_t<Legend::LEGEND_ORIENTATION>>(_a[2])),(*reinterpret_cast<std::add_pointer_t<Legend::LEGEND_POSITION>>(_a[3])),(*reinterpret_cast<std::add_pointer_t<int>>(_a[4]))); break;
        case 3: _t->setLegendProperties((*reinterpret_cast<std::add_pointer_t<Legend::LEGEND_TYPE>>(_a[1])),(*reinterpret_cast<std::add_pointer_t<Legend::LEGEND_ORIENTATION>>(_a[2])),(*reinterpret_cast<std::add_pointer_t<Legend::LEGEND_POSITION>>(_a[3]))); break;
        case 4: _t->includeLegend((*reinterpret_cast<std::add_pointer_t<bool>>(_a[1]))); break;
        case 5: _t->setLegendAlpha((*reinterpret_cast<std::add_pointer_t<int>>(_a[1]))); break;
        case 6: _t->setRasterOutputSize((*reinterpret_cast<std::add_pointer_t<const QSize*>>(_a[1]))); break;
        case 7: { Legend* _r = _t->getLegend();
            if (_a[0]) *reinterpret_cast<Legend**>(_a[0]) = std::move(_r); }  break;
        default: ;
        }
    }
}

const QMetaObject *ImageExporter::metaObject() const
{
    return QObject::d_ptr->metaObject ? QObject::d_ptr->dynamicMetaObject() : &staticMetaObject;
}

void *ImageExporter::qt_metacast(const char *_clname)
{
    if (!_clname) return nullptr;
    if (!strcmp(_clname, qt_staticMetaObjectStaticContent<qt_meta_tag_ZN13ImageExporterE_t>.strings))
        return static_cast<void*>(this);
    return QObject::qt_metacast(_clname);
}

int ImageExporter::qt_metacall(QMetaObject::Call _c, int _id, void **_a)
{
    _id = QObject::qt_metacall(_c, _id, _a);
    if (_id < 0)
        return _id;
    if (_c == QMetaObject::InvokeMetaMethod) {
        if (_id < 8)
            qt_static_metacall(this, _c, _id, _a);
        _id -= 8;
    }
    if (_c == QMetaObject::RegisterMethodArgumentMetaType) {
        if (_id < 8)
            *reinterpret_cast<QMetaType *>(_a[0]) = QMetaType();
        _id -= 8;
    }
    return _id;
}
QT_WARNING_POP
