/********************************************************************************
** Form generated from reading UI file 'exportimagedialog.ui'
**
** Created by: Qt User Interface Compiler version 6.11.1
**
** WARNING! All changes made in this file will be lost when recompiling UI file!
********************************************************************************/

#ifndef UI_EXPORTIMAGEDIALOG_H
#define UI_EXPORTIMAGEDIALOG_H

#include <QtCore/QVariant>
#include <QtWidgets/QApplication>
#include <QtWidgets/QCheckBox>
#include <QtWidgets/QComboBox>
#include <QtWidgets/QFormLayout>
#include <QtWidgets/QGroupBox>
#include <QtWidgets/QLabel>
#include <QtWidgets/QSpacerItem>
#include <QtWidgets/QVBoxLayout>
#include <QtWidgets/QWidget>
#include <klocalizedstring.h>

QT_BEGIN_NAMESPACE

class Ui_ExportImageDialog
{
public:
    QVBoxLayout *verticalLayout;
    QGroupBox *legendGroupBox;
    QVBoxLayout *verticalLayout_2;
    QCheckBox *addLegendCheckBox;
    QFormLayout *formLayout;
    QLabel *legendOrientationLabel;
    QComboBox *legendOrientationComboBox;
    QLabel *legendTypeLabel;
    QComboBox *legendTypeComboBox;
    QLabel *legendPositionLabel;
    QComboBox *legendPositionComboBox;
    QSpacerItem *horizontalSpacer;

    void setupUi(QWidget *ExportImageDialog)
    {
        if (ExportImageDialog->objectName().isEmpty())
            ExportImageDialog->setObjectName("ExportImageDialog");
        ExportImageDialog->resize(365, 170);
        verticalLayout = new QVBoxLayout(ExportImageDialog);
        verticalLayout->setSpacing(3);
        verticalLayout->setObjectName("verticalLayout");
        verticalLayout->setContentsMargins(3, 3, 3, 3);
        legendGroupBox = new QGroupBox(ExportImageDialog);
        legendGroupBox->setObjectName("legendGroupBox");
        verticalLayout_2 = new QVBoxLayout(legendGroupBox);
        verticalLayout_2->setSpacing(3);
        verticalLayout_2->setObjectName("verticalLayout_2");
        verticalLayout_2->setContentsMargins(3, 3, 3, 3);
        addLegendCheckBox = new QCheckBox(legendGroupBox);
        addLegendCheckBox->setObjectName("addLegendCheckBox");

        verticalLayout_2->addWidget(addLegendCheckBox);

        formLayout = new QFormLayout();
        formLayout->setObjectName("formLayout");
        formLayout->setFieldGrowthPolicy(QFormLayout::AllNonFixedFieldsGrow);
        formLayout->setHorizontalSpacing(3);
        formLayout->setVerticalSpacing(3);
        legendOrientationLabel = new QLabel(legendGroupBox);
        legendOrientationLabel->setObjectName("legendOrientationLabel");

        formLayout->setWidget(0, QFormLayout::ItemRole::LabelRole, legendOrientationLabel);

        legendOrientationComboBox = new QComboBox(legendGroupBox);
        legendOrientationComboBox->setObjectName("legendOrientationComboBox");

        formLayout->setWidget(0, QFormLayout::ItemRole::FieldRole, legendOrientationComboBox);

        legendTypeLabel = new QLabel(legendGroupBox);
        legendTypeLabel->setObjectName("legendTypeLabel");

        formLayout->setWidget(1, QFormLayout::ItemRole::LabelRole, legendTypeLabel);

        legendTypeComboBox = new QComboBox(legendGroupBox);
        legendTypeComboBox->setObjectName("legendTypeComboBox");

        formLayout->setWidget(1, QFormLayout::ItemRole::FieldRole, legendTypeComboBox);

        legendPositionLabel = new QLabel(legendGroupBox);
        legendPositionLabel->setObjectName("legendPositionLabel");

        formLayout->setWidget(2, QFormLayout::ItemRole::LabelRole, legendPositionLabel);

        legendPositionComboBox = new QComboBox(legendGroupBox);
        legendPositionComboBox->setObjectName("legendPositionComboBox");

        formLayout->setWidget(2, QFormLayout::ItemRole::FieldRole, legendPositionComboBox);


        verticalLayout_2->addLayout(formLayout);

        horizontalSpacer = new QSpacerItem(40, 20, QSizePolicy::Policy::Expanding, QSizePolicy::Policy::Minimum);

        verticalLayout_2->addItem(horizontalSpacer);


        verticalLayout->addWidget(legendGroupBox);


        retranslateUi(ExportImageDialog);

        QMetaObject::connectSlotsByName(ExportImageDialog);
    } // setupUi

    void retranslateUi(QWidget *ExportImageDialog)
    {
        legendGroupBox->setTitle(tr2i18n("Legend Configuration", nullptr));
        addLegendCheckBox->setText(tr2i18n("Add legend to exported sky image", nullptr));
        legendOrientationLabel->setText(tr2i18n("Legend orientation:", nullptr));
        legendTypeLabel->setText(tr2i18n("Legend type:", nullptr));
        legendPositionLabel->setText(tr2i18n("Legend position:", nullptr));
        (void)ExportImageDialog;
    } // retranslateUi

};

namespace Ui {
    class ExportImageDialog: public Ui_ExportImageDialog {};
} // namespace Ui

QT_END_NAMESPACE

#endif // EXPORTIMAGEDIALOG_H

