/********************************************************************************
** Form generated from reading UI file 'focusprogresswidget.ui'
**
** Created by: Qt User Interface Compiler version 6.11.1
**
** WARNING! All changes made in this file will be lost when recompiling UI file!
********************************************************************************/

#ifndef UI_FOCUSPROGRESSWIDGET_H
#define UI_FOCUSPROGRESSWIDGET_H

#include <QtCore/QVariant>
#include <QtWidgets/QApplication>
#include <QtWidgets/QHBoxLayout>
#include <QtWidgets/QLabel>
#include <QtWidgets/QPushButton>
#include <QtWidgets/QSpacerItem>
#include <QtWidgets/QStackedWidget>
#include <QtWidgets/QVBoxLayout>
#include <QtWidgets/QWidget>
#include <klocalizedstring.h>
#include "ekos/auxiliary/ledstatuswidget.h"
#include "ekos/focus/focushfrvplot.h"
#include "ekos/focus/focusprofileplot.h"

QT_BEGIN_NAMESPACE

class Ui_FocusProgressWidget
{
public:
    QVBoxLayout *focusManagerLayout;
    QHBoxLayout *focusStatusLayout;
    QVBoxLayout *focusHeaderLayout;
    QHBoxLayout *focusTitleLayout;
    QLabel *label_10;
    QSpacerItem *horizontalSpacer_5;
    Ekos::LedStatusWidget *focusStatus;
    QHBoxLayout *focusDataLayout;
    QLabel *label_9;
    QLabel *currentHFR;
    QSpacerItem *horizontalSpacer_13;
    QHBoxLayout *focusDetailsLayout;
    QPushButton *focusDetailPrevButton;
    QStackedWidget *focusDetailView;
    FocusProfilePlot *profilePlot;
    FocusHFRVPlot *hfrVPlot;
    QWidget *focusStarPage;
    QHBoxLayout *horizontalLayout;
    QLabel *focusStarView;
    QPushButton *focusDetailNextButton;

    void setupUi(QWidget *FocusProgressWidget)
    {
        if (FocusProgressWidget->objectName().isEmpty())
            FocusProgressWidget->setObjectName("FocusProgressWidget");
        FocusProgressWidget->setEnabled(false);
        FocusProgressWidget->resize(336, 200);
        QSizePolicy sizePolicy(QSizePolicy::Policy::MinimumExpanding, QSizePolicy::Policy::MinimumExpanding);
        sizePolicy.setHorizontalStretch(0);
        sizePolicy.setVerticalStretch(0);
        sizePolicy.setHeightForWidth(FocusProgressWidget->sizePolicy().hasHeightForWidth());
        FocusProgressWidget->setSizePolicy(sizePolicy);
        FocusProgressWidget->setMinimumSize(QSize(200, 200));
        FocusProgressWidget->setMaximumSize(QSize(16777215, 16777215));
        FocusProgressWidget->setBaseSize(QSize(0, 0));
        focusManagerLayout = new QVBoxLayout(FocusProgressWidget);
        focusManagerLayout->setSpacing(0);
        focusManagerLayout->setObjectName("focusManagerLayout");
        focusManagerLayout->setContentsMargins(0, 0, 0, 0);
        focusStatusLayout = new QHBoxLayout();
        focusStatusLayout->setSpacing(1);
        focusStatusLayout->setObjectName("focusStatusLayout");
        focusHeaderLayout = new QVBoxLayout();
        focusHeaderLayout->setSpacing(0);
        focusHeaderLayout->setObjectName("focusHeaderLayout");
        focusHeaderLayout->setContentsMargins(-1, -1, -1, 4);
        focusTitleLayout = new QHBoxLayout();
        focusTitleLayout->setSpacing(0);
        focusTitleLayout->setObjectName("focusTitleLayout");
        label_10 = new QLabel(FocusProgressWidget);
        label_10->setObjectName("label_10");
        QSizePolicy sizePolicy1(QSizePolicy::Policy::Preferred, QSizePolicy::Policy::Preferred);
        sizePolicy1.setHorizontalStretch(0);
        sizePolicy1.setVerticalStretch(0);
        sizePolicy1.setHeightForWidth(label_10->sizePolicy().hasHeightForWidth());
        label_10->setSizePolicy(sizePolicy1);
        label_10->setMinimumSize(QSize(0, 24));
        label_10->setMaximumSize(QSize(16777215, 20));
        label_10->setStyleSheet(QString::fromUtf8("font-weight:bold;"));
        label_10->setTextFormat(Qt::AutoText);
        label_10->setAlignment(Qt::AlignLeading|Qt::AlignLeft|Qt::AlignVCenter);
        label_10->setMargin(1);

        focusTitleLayout->addWidget(label_10);

        horizontalSpacer_5 = new QSpacerItem(40, 20, QSizePolicy::Policy::Expanding, QSizePolicy::Policy::Minimum);

        focusTitleLayout->addItem(horizontalSpacer_5);

        focusStatus = new Ekos::LedStatusWidget(FocusProgressWidget);
        focusStatus->setObjectName("focusStatus");
        QSizePolicy sizePolicy2(QSizePolicy::Policy::Preferred, QSizePolicy::Policy::Preferred);
        sizePolicy2.setHorizontalStretch(0);
        sizePolicy2.setVerticalStretch(1);
        sizePolicy2.setHeightForWidth(focusStatus->sizePolicy().hasHeightForWidth());
        focusStatus->setSizePolicy(sizePolicy2);
        focusStatus->setMinimumSize(QSize(20, 0));

        focusTitleLayout->addWidget(focusStatus);


        focusHeaderLayout->addLayout(focusTitleLayout);

        focusDataLayout = new QHBoxLayout();
        focusDataLayout->setSpacing(0);
        focusDataLayout->setObjectName("focusDataLayout");
        label_9 = new QLabel(FocusProgressWidget);
        label_9->setObjectName("label_9");
        label_9->setMinimumSize(QSize(20, 24));
        label_9->setMaximumSize(QSize(16777215, 24));
        label_9->setTextFormat(Qt::RichText);
        label_9->setAlignment(Qt::AlignLeading|Qt::AlignLeft|Qt::AlignVCenter);
        label_9->setMargin(1);

        focusDataLayout->addWidget(label_9);

        currentHFR = new QLabel(FocusProgressWidget);
        currentHFR->setObjectName("currentHFR");
        sizePolicy1.setHeightForWidth(currentHFR->sizePolicy().hasHeightForWidth());
        currentHFR->setSizePolicy(sizePolicy1);
        currentHFR->setMinimumSize(QSize(20, 24));
        currentHFR->setMaximumSize(QSize(16777215, 24));
        currentHFR->setTextFormat(Qt::RichText);
        currentHFR->setAlignment(Qt::AlignLeading|Qt::AlignLeft|Qt::AlignVCenter);
        currentHFR->setMargin(1);

        focusDataLayout->addWidget(currentHFR);

        horizontalSpacer_13 = new QSpacerItem(40, 24, QSizePolicy::Policy::Expanding, QSizePolicy::Policy::Minimum);

        focusDataLayout->addItem(horizontalSpacer_13);

        focusDataLayout->setStretch(2, 1);

        focusHeaderLayout->addLayout(focusDataLayout);


        focusStatusLayout->addLayout(focusHeaderLayout);

        focusStatusLayout->setStretch(0, 1);

        focusManagerLayout->addLayout(focusStatusLayout);

        focusDetailsLayout = new QHBoxLayout();
        focusDetailsLayout->setSpacing(0);
        focusDetailsLayout->setObjectName("focusDetailsLayout");
        focusDetailsLayout->setSizeConstraint(QLayout::SetDefaultConstraint);
        focusDetailPrevButton = new QPushButton(FocusProgressWidget);
        focusDetailPrevButton->setObjectName("focusDetailPrevButton");
        sizePolicy1.setHeightForWidth(focusDetailPrevButton->sizePolicy().hasHeightForWidth());
        focusDetailPrevButton->setSizePolicy(sizePolicy1);
        focusDetailPrevButton->setMinimumSize(QSize(20, 0));
        focusDetailPrevButton->setMaximumSize(QSize(20, 16777215));
        QFont font;
        font.setPointSize(16);
        font.setBold(true);
        focusDetailPrevButton->setFont(font);

        focusDetailsLayout->addWidget(focusDetailPrevButton);

        focusDetailView = new QStackedWidget(FocusProgressWidget);
        focusDetailView->setObjectName("focusDetailView");
        profilePlot = new FocusProfilePlot();
        profilePlot->setObjectName("profilePlot");
        profilePlot->setStyleSheet(QString::fromUtf8("background-color: qlineargradient(x1:0, y1:0, x2:0, y2:0.5,\n"
"                                      stop:0 darkgray, stop:1 black);"));
        focusDetailView->addWidget(profilePlot);
        hfrVPlot = new FocusHFRVPlot();
        hfrVPlot->setObjectName("hfrVPlot");
        hfrVPlot->setStyleSheet(QString::fromUtf8("background-color: qlineargradient(x1:0, y1:0, x2:0, y2:0.5,\n"
"                                      stop:0 darkgray, stop:1 black);"));
        focusDetailView->addWidget(hfrVPlot);
        focusStarPage = new QWidget();
        focusStarPage->setObjectName("focusStarPage");
        horizontalLayout = new QHBoxLayout(focusStarPage);
        horizontalLayout->setObjectName("horizontalLayout");
        focusStarView = new QLabel(focusStarPage);
        focusStarView->setObjectName("focusStarView");
        focusStarView->setStyleSheet(QString::fromUtf8("background-color: qlineargradient(x1:0, y1:0, x2:0, y2:0.5,\n"
"                                      stop:0 darkgray, stop:1 black);"));
        focusStarView->setAlignment(Qt::AlignCenter);

        horizontalLayout->addWidget(focusStarView);

        focusDetailView->addWidget(focusStarPage);

        focusDetailsLayout->addWidget(focusDetailView);

        focusDetailNextButton = new QPushButton(FocusProgressWidget);
        focusDetailNextButton->setObjectName("focusDetailNextButton");
        QSizePolicy sizePolicy3(QSizePolicy::Policy::Minimum, QSizePolicy::Policy::Preferred);
        sizePolicy3.setHorizontalStretch(0);
        sizePolicy3.setVerticalStretch(0);
        sizePolicy3.setHeightForWidth(focusDetailNextButton->sizePolicy().hasHeightForWidth());
        focusDetailNextButton->setSizePolicy(sizePolicy3);
        focusDetailNextButton->setMinimumSize(QSize(20, 0));
        focusDetailNextButton->setMaximumSize(QSize(20, 16777215));
        focusDetailNextButton->setFont(font);

        focusDetailsLayout->addWidget(focusDetailNextButton);


        focusManagerLayout->addLayout(focusDetailsLayout);

        focusManagerLayout->setStretch(1, 1);

        retranslateUi(FocusProgressWidget);

        QMetaObject::connectSlotsByName(FocusProgressWidget);
    } // setupUi

    void retranslateUi(QWidget *FocusProgressWidget)
    {
        FocusProgressWidget->setWindowTitle(tr2i18n("Ekos", nullptr));
        label_10->setText(tr2i18n("Focus", nullptr));
        label_9->setText(tr2i18n("HFR:", nullptr));
        currentHFR->setText(QString());
        focusDetailPrevButton->setText(tr2i18n("<", nullptr));
#if QT_CONFIG(tooltip)
        profilePlot->setToolTip(tr2i18n("Focus HFR profile", nullptr));
#endif // QT_CONFIG(tooltip)
#if QT_CONFIG(tooltip)
        focusStarView->setToolTip(tr2i18n("Focus star", nullptr));
#endif // QT_CONFIG(tooltip)
        focusStarView->setText(tr2i18n("Focus star", nullptr));
        focusDetailNextButton->setText(tr2i18n(">", nullptr));
    } // retranslateUi

};

namespace Ui {
    class FocusProgressWidget: public Ui_FocusProgressWidget {};
} // namespace Ui

QT_END_NAMESPACE

#endif // FOCUSPROGRESSWIDGET_H

