/********************************************************************************
** Form generated from reading UI file 'observatory.ui'
**
** Created by: Qt User Interface Compiler version 6.11.1
**
** WARNING! All changes made in this file will be lost when recompiling UI file!
********************************************************************************/

#ifndef UI_OBSERVATORY_H
#define UI_OBSERVATORY_H

#include <QtCore/QVariant>
#include <QtGui/QIcon>
#include <QtWidgets/QApplication>
#include <QtWidgets/QCheckBox>
#include <QtWidgets/QComboBox>
#include <QtWidgets/QDoubleSpinBox>
#include <QtWidgets/QFormLayout>
#include <QtWidgets/QGridLayout>
#include <QtWidgets/QGroupBox>
#include <QtWidgets/QHBoxLayout>
#include <QtWidgets/QLabel>
#include <QtWidgets/QPushButton>
#include <QtWidgets/QSpacerItem>
#include <QtWidgets/QSpinBox>
#include <QtWidgets/QSplitter>
#include <QtWidgets/QVBoxLayout>
#include <QtWidgets/QWidget>
#include <klocalizedstring.h>
#include "auxiliary/qcustomplot.h"

QT_BEGIN_NAMESPACE

class Ui_Observatory
{
public:
    QVBoxLayout *verticalLayout_2;
    QSplitter *splitter;
    QWidget *layoutWidget;
    QVBoxLayout *leftLayout;
    QGroupBox *domeBox;
    QVBoxLayout *verticalLayout_3;
    QGridLayout *domeStatusBox;
    QLabel *domeAzimuthPosition;
    QLabel *domeAzimuthPositionLabel;
    QLabel *motionStatusLabel;
    QWidget *MotionBox;
    QFormLayout *formLayout;
    QLabel *motionLabel;
    QDoubleSpinBox *absoluteMotionSB;
    QPushButton *motionMoveAbsButton;
    QDoubleSpinBox *relativeMotionSB;
    QPushButton *motionMoveRelButton;
    QPushButton *motionCWButton;
    QPushButton *motionCCWButton;
    QWidget *SlavingBox;
    QHBoxLayout *slavingBox;
    QLabel *label;
    QSpacerItem *horizontalSpacer;
    QPushButton *slavingEnableButton;
    QPushButton *slavingDisableButton;
    QHBoxLayout *parkingBox;
    QPushButton *domePark;
    QPushButton *domeUnpark;
    QSpacerItem *horizontalSpacer_2;
    QPushButton *motionAbortButton;
    QGroupBox *shutterBox;
    QHBoxLayout *horizontalLayout_4;
    QSpacerItem *horizontalSpacer_4;
    QPushButton *shutterClosed;
    QPushButton *shutterOpen;
    QGroupBox *statusDefinitionBox;
    QHBoxLayout *horizontalLayout_5;
    QCheckBox *useDomeCB;
    QCheckBox *useShutterCB;
    QCheckBox *useWeatherCB;
    QPushButton *statusReadyButton;
    QGroupBox *weatherBox;
    QGridLayout *gridLayout_5;
    QCheckBox *autoscaleValuesCB;
    QPushButton *clearGraphHistory;
    QComboBox *weatherSourceCombo;
    QGroupBox *weatherActionsBox;
    QHBoxLayout *horizontalLayout_7;
    QGroupBox *weatherAlertBox;
    QGridLayout *gridLayout_7;
    QCheckBox *weatherAlertShutterCB;
    QCheckBox *weatherAlertDomeCB;
    QCheckBox *weatherAlertSchedulerCB;
    QHBoxLayout *horizontalLayout_2;
    QLabel *weatherAlertStatusLabel;
    QSpacerItem *horizontalSpacer_7;
    QLabel *weatherAlertDelayLabel;
    QSpinBox *weatherAlertDelaySB;
    QGroupBox *weatherWarningBox;
    QGridLayout *gridLayout_6;
    QHBoxLayout *horizontalLayout;
    QLabel *weatherWarningStatusLabel;
    QSpacerItem *horizontalSpacer_6;
    QLabel *weatherWarningDelayLabel;
    QSpinBox *weatherWarningDelaySB;
    QCheckBox *weatherWarningDomeCB;
    QCheckBox *weatherWarningSchedulerCB;
    QCheckBox *weatherWarningShutterCB;
    QSpacerItem *horizontalSpacer_3;
    QLabel *weatherStatusLabel;
    QWidget *sensorData;
    QCustomPlot *sensorGraphs;
    QSpacerItem *verticalSpacer;

    void setupUi(QWidget *Observatory)
    {
        if (Observatory->objectName().isEmpty())
            Observatory->setObjectName("Observatory");
        Observatory->resize(1057, 451);
        verticalLayout_2 = new QVBoxLayout(Observatory);
        verticalLayout_2->setSpacing(3);
        verticalLayout_2->setObjectName("verticalLayout_2");
        verticalLayout_2->setContentsMargins(3, 3, 3, 3);
        splitter = new QSplitter(Observatory);
        splitter->setObjectName("splitter");
        splitter->setOrientation(Qt::Horizontal);
        layoutWidget = new QWidget(splitter);
        layoutWidget->setObjectName("layoutWidget");
        leftLayout = new QVBoxLayout(layoutWidget);
        leftLayout->setSpacing(3);
        leftLayout->setObjectName("leftLayout");
        leftLayout->setContentsMargins(0, 0, 0, 0);
        domeBox = new QGroupBox(layoutWidget);
        domeBox->setObjectName("domeBox");
        domeBox->setEnabled(false);
        QSizePolicy sizePolicy(QSizePolicy::Policy::Preferred, QSizePolicy::Policy::Preferred);
        sizePolicy.setHorizontalStretch(1);
        sizePolicy.setVerticalStretch(0);
        sizePolicy.setHeightForWidth(domeBox->sizePolicy().hasHeightForWidth());
        domeBox->setSizePolicy(sizePolicy);
        verticalLayout_3 = new QVBoxLayout(domeBox);
        verticalLayout_3->setObjectName("verticalLayout_3");
        verticalLayout_3->setContentsMargins(3, 3, 3, 3);
        domeStatusBox = new QGridLayout();
        domeStatusBox->setSpacing(3);
        domeStatusBox->setObjectName("domeStatusBox");
        domeAzimuthPosition = new QLabel(domeBox);
        domeAzimuthPosition->setObjectName("domeAzimuthPosition");
        domeAzimuthPosition->setMinimumSize(QSize(160, 0));
        domeAzimuthPosition->setMaximumSize(QSize(320, 16777215));
        QFont font;
        font.setPointSize(24);
        font.setBold(true);
        domeAzimuthPosition->setFont(font);
        domeAzimuthPosition->setText(QString::fromUtf8("0"));
        domeAzimuthPosition->setAlignment(Qt::AlignCenter);

        domeStatusBox->addWidget(domeAzimuthPosition, 1, 0, 2, 1);

        domeAzimuthPositionLabel = new QLabel(domeBox);
        domeAzimuthPositionLabel->setObjectName("domeAzimuthPositionLabel");

        domeStatusBox->addWidget(domeAzimuthPositionLabel, 0, 0, 1, 1, Qt::AlignLeft|Qt::AlignTop);

        motionStatusLabel = new QLabel(domeBox);
        motionStatusLabel->setObjectName("motionStatusLabel");

        domeStatusBox->addWidget(motionStatusLabel, 4, 0, 1, 4);

        MotionBox = new QWidget(domeBox);
        MotionBox->setObjectName("MotionBox");
        formLayout = new QFormLayout(MotionBox);
        formLayout->setObjectName("formLayout");
        formLayout->setContentsMargins(3, 3, 3, 3);
        motionLabel = new QLabel(MotionBox);
        motionLabel->setObjectName("motionLabel");
        motionLabel->setEnabled(false);

        formLayout->setWidget(0, QFormLayout::ItemRole::LabelRole, motionLabel);

        absoluteMotionSB = new QDoubleSpinBox(MotionBox);
        absoluteMotionSB->setObjectName("absoluteMotionSB");
        absoluteMotionSB->setEnabled(false);
        absoluteMotionSB->setMaximum(999.990000000000009);

        formLayout->setWidget(1, QFormLayout::ItemRole::LabelRole, absoluteMotionSB);

        motionMoveAbsButton = new QPushButton(MotionBox);
        motionMoveAbsButton->setObjectName("motionMoveAbsButton");
        motionMoveAbsButton->setEnabled(false);
        motionMoveAbsButton->setMinimumSize(QSize(96, 36));
        motionMoveAbsButton->setMaximumSize(QSize(96, 36));

        formLayout->setWidget(1, QFormLayout::ItemRole::FieldRole, motionMoveAbsButton);

        relativeMotionSB = new QDoubleSpinBox(MotionBox);
        relativeMotionSB->setObjectName("relativeMotionSB");
        relativeMotionSB->setEnabled(false);
        relativeMotionSB->setMinimum(-999.990000000000009);
        relativeMotionSB->setMaximum(999.990000000000009);

        formLayout->setWidget(2, QFormLayout::ItemRole::LabelRole, relativeMotionSB);

        motionMoveRelButton = new QPushButton(MotionBox);
        motionMoveRelButton->setObjectName("motionMoveRelButton");
        motionMoveRelButton->setEnabled(false);
        motionMoveRelButton->setMinimumSize(QSize(96, 36));
        motionMoveRelButton->setMaximumSize(QSize(96, 36));
        motionMoveRelButton->setStyleSheet(QString::fromUtf8("QPushButton:checked\n"
"{\n"
"background-color: maroon;\n"
"border: 1px outset;\n"
"font-weight:bold;\n"
"}"));

        formLayout->setWidget(2, QFormLayout::ItemRole::FieldRole, motionMoveRelButton);

        motionCWButton = new QPushButton(MotionBox);
        motionCWButton->setObjectName("motionCWButton");
        motionCWButton->setEnabled(false);
        motionCWButton->setMinimumSize(QSize(96, 36));
        motionCWButton->setMaximumSize(QSize(96, 36));
        motionCWButton->setStyleSheet(QString::fromUtf8("QPushButton:checked\n"
"{\n"
"background-color: maroon;\n"
"border: 1px outset;\n"
"font-weight:bold;\n"
"}"));
        motionCWButton->setCheckable(true);

        formLayout->setWidget(3, QFormLayout::ItemRole::LabelRole, motionCWButton);

        motionCCWButton = new QPushButton(MotionBox);
        motionCCWButton->setObjectName("motionCCWButton");
        motionCCWButton->setEnabled(false);
        motionCCWButton->setMinimumSize(QSize(96, 36));
        motionCCWButton->setMaximumSize(QSize(96, 36));
        motionCCWButton->setStyleSheet(QString::fromUtf8("QPushButton:checked\n"
"{\n"
"background-color: maroon;\n"
"border: 1px outset;\n"
"font-weight:bold;\n"
"}"));
        motionCCWButton->setCheckable(true);

        formLayout->setWidget(3, QFormLayout::ItemRole::FieldRole, motionCCWButton);


        domeStatusBox->addWidget(MotionBox, 0, 2, 3, 2);


        verticalLayout_3->addLayout(domeStatusBox);

        SlavingBox = new QWidget(domeBox);
        SlavingBox->setObjectName("SlavingBox");
        slavingBox = new QHBoxLayout(SlavingBox);
        slavingBox->setObjectName("slavingBox");
        slavingBox->setContentsMargins(3, 3, 3, 3);
        label = new QLabel(SlavingBox);
        label->setObjectName("label");

        slavingBox->addWidget(label);

        horizontalSpacer = new QSpacerItem(40, 20, QSizePolicy::Policy::Expanding, QSizePolicy::Policy::Minimum);

        slavingBox->addItem(horizontalSpacer);

        slavingEnableButton = new QPushButton(SlavingBox);
        slavingEnableButton->setObjectName("slavingEnableButton");
        slavingEnableButton->setMinimumSize(QSize(96, 36));
        slavingEnableButton->setMaximumSize(QSize(96, 36));
        slavingEnableButton->setStyleSheet(QString::fromUtf8("QPushButton:checked\n"
"{\n"
"background-color: maroon;\n"
"border: 1px outset;\n"
"font-weight:bold;\n"
"}"));
        slavingEnableButton->setCheckable(true);

        slavingBox->addWidget(slavingEnableButton);

        slavingDisableButton = new QPushButton(SlavingBox);
        slavingDisableButton->setObjectName("slavingDisableButton");
        slavingDisableButton->setMinimumSize(QSize(96, 36));
        slavingDisableButton->setMaximumSize(QSize(96, 36));
        slavingDisableButton->setStyleSheet(QString::fromUtf8("QPushButton:checked\n"
"{\n"
"background-color: maroon;\n"
"border: 1px outset;\n"
"font-weight:bold;\n"
"}"));
        slavingDisableButton->setCheckable(true);

        slavingBox->addWidget(slavingDisableButton);


        verticalLayout_3->addWidget(SlavingBox, 0, Qt::AlignTop);

        parkingBox = new QHBoxLayout();
        parkingBox->setObjectName("parkingBox");
        parkingBox->setContentsMargins(3, 3, 3, 3);
        domePark = new QPushButton(domeBox);
        domePark->setObjectName("domePark");
        domePark->setEnabled(false);
        domePark->setMinimumSize(QSize(96, 36));
        domePark->setMaximumSize(QSize(96, 36));
        domePark->setStyleSheet(QString::fromUtf8("QPushButton:checked\n"
"{\n"
"background-color: maroon;\n"
"border: 1px outset;\n"
"font-weight:bold;\n"
"}"));
        domePark->setIconSize(QSize(32, 16));
        domePark->setCheckable(false);

        parkingBox->addWidget(domePark);

        domeUnpark = new QPushButton(domeBox);
        domeUnpark->setObjectName("domeUnpark");
        domeUnpark->setEnabled(false);
        domeUnpark->setMinimumSize(QSize(96, 36));
        domeUnpark->setMaximumSize(QSize(96, 36));
        domeUnpark->setStyleSheet(QString::fromUtf8("QPushButton:checked\n"
"{\n"
"background-color: maroon;\n"
"border: 1px outset;\n"
"font-weight:bold;\n"
"}"));
        domeUnpark->setCheckable(false);
        domeUnpark->setChecked(false);

        parkingBox->addWidget(domeUnpark);

        horizontalSpacer_2 = new QSpacerItem(40, 20, QSizePolicy::Policy::Expanding, QSizePolicy::Policy::Minimum);

        parkingBox->addItem(horizontalSpacer_2);

        motionAbortButton = new QPushButton(domeBox);
        motionAbortButton->setObjectName("motionAbortButton");
        motionAbortButton->setEnabled(false);
        motionAbortButton->setMinimumSize(QSize(96, 36));
        motionAbortButton->setMaximumSize(QSize(96, 36));
        motionAbortButton->setStyleSheet(QString::fromUtf8("QPushButton:checked\n"
"{\n"
"background-color: maroon;\n"
"border: 1px outset;\n"
"font-weight:bold;\n"
"}"));

        parkingBox->addWidget(motionAbortButton);


        verticalLayout_3->addLayout(parkingBox);


        leftLayout->addWidget(domeBox);

        shutterBox = new QGroupBox(layoutWidget);
        shutterBox->setObjectName("shutterBox");
        shutterBox->setEnabled(false);
        sizePolicy.setHeightForWidth(shutterBox->sizePolicy().hasHeightForWidth());
        shutterBox->setSizePolicy(sizePolicy);
        horizontalLayout_4 = new QHBoxLayout(shutterBox);
        horizontalLayout_4->setSpacing(3);
        horizontalLayout_4->setObjectName("horizontalLayout_4");
        horizontalLayout_4->setContentsMargins(3, 3, 3, 3);
        horizontalSpacer_4 = new QSpacerItem(40, 20, QSizePolicy::Policy::Expanding, QSizePolicy::Policy::Minimum);

        horizontalLayout_4->addItem(horizontalSpacer_4);

        shutterClosed = new QPushButton(shutterBox);
        shutterClosed->setObjectName("shutterClosed");
        shutterClosed->setEnabled(false);
        shutterClosed->setMinimumSize(QSize(96, 36));
        shutterClosed->setMaximumSize(QSize(72, 36));
        shutterClosed->setStyleSheet(QString::fromUtf8("QPushButton:checked\n"
"{\n"
"background-color: maroon;\n"
"border: 1px outset;\n"
"font-weight:bold;\n"
"}"));
        shutterClosed->setIconSize(QSize(32, 16));
        shutterClosed->setCheckable(false);

        horizontalLayout_4->addWidget(shutterClosed);

        shutterOpen = new QPushButton(shutterBox);
        shutterOpen->setObjectName("shutterOpen");
        shutterOpen->setEnabled(false);
        shutterOpen->setMinimumSize(QSize(96, 36));
        shutterOpen->setMaximumSize(QSize(72, 36));
        shutterOpen->setStyleSheet(QString::fromUtf8("QPushButton:checked\n"
"{\n"
"background-color: maroon;\n"
"border: 1px outset;\n"
"font-weight:bold;\n"
"}"));
        shutterOpen->setCheckable(false);
        shutterOpen->setChecked(false);

        horizontalLayout_4->addWidget(shutterOpen);


        leftLayout->addWidget(shutterBox, 0, Qt::AlignTop);

        statusDefinitionBox = new QGroupBox(layoutWidget);
        statusDefinitionBox->setObjectName("statusDefinitionBox");
        statusDefinitionBox->setEnabled(false);
        sizePolicy.setHeightForWidth(statusDefinitionBox->sizePolicy().hasHeightForWidth());
        statusDefinitionBox->setSizePolicy(sizePolicy);
        horizontalLayout_5 = new QHBoxLayout(statusDefinitionBox);
        horizontalLayout_5->setSpacing(3);
        horizontalLayout_5->setObjectName("horizontalLayout_5");
        horizontalLayout_5->setContentsMargins(3, 3, 3, 3);
        useDomeCB = new QCheckBox(statusDefinitionBox);
        useDomeCB->setObjectName("useDomeCB");

        horizontalLayout_5->addWidget(useDomeCB);

        useShutterCB = new QCheckBox(statusDefinitionBox);
        useShutterCB->setObjectName("useShutterCB");

        horizontalLayout_5->addWidget(useShutterCB);

        useWeatherCB = new QCheckBox(statusDefinitionBox);
        useWeatherCB->setObjectName("useWeatherCB");

        horizontalLayout_5->addWidget(useWeatherCB);

        statusReadyButton = new QPushButton(statusDefinitionBox);
        statusReadyButton->setObjectName("statusReadyButton");
        statusReadyButton->setEnabled(false);
        statusReadyButton->setMinimumSize(QSize(96, 36));
        statusReadyButton->setMaximumSize(QSize(72, 36));
        statusReadyButton->setStyleSheet(QString::fromUtf8("QPushButton:checked\n"
"{\n"
"background-color: maroon;\n"
"border: 1px outset;\n"
"font-weight:bold;\n"
"}"));
        statusReadyButton->setIconSize(QSize(32, 16));
        statusReadyButton->setCheckable(true);
        statusReadyButton->setFlat(false);

        horizontalLayout_5->addWidget(statusReadyButton);


        leftLayout->addWidget(statusDefinitionBox, 0, Qt::AlignTop);

        splitter->addWidget(layoutWidget);
        weatherBox = new QGroupBox(splitter);
        weatherBox->setObjectName("weatherBox");
        weatherBox->setEnabled(false);
        sizePolicy.setHeightForWidth(weatherBox->sizePolicy().hasHeightForWidth());
        weatherBox->setSizePolicy(sizePolicy);
        gridLayout_5 = new QGridLayout(weatherBox);
        gridLayout_5->setSpacing(3);
        gridLayout_5->setObjectName("gridLayout_5");
        gridLayout_5->setContentsMargins(3, 3, 3, 3);
        autoscaleValuesCB = new QCheckBox(weatherBox);
        autoscaleValuesCB->setObjectName("autoscaleValuesCB");

        gridLayout_5->addWidget(autoscaleValuesCB, 3, 4, 1, 1);

        clearGraphHistory = new QPushButton(weatherBox);
        clearGraphHistory->setObjectName("clearGraphHistory");
        clearGraphHistory->setEnabled(false);
        clearGraphHistory->setMinimumSize(QSize(24, 24));
        clearGraphHistory->setMaximumSize(QSize(24, 24));
        QIcon icon;
        QString iconThemeName = QString::fromUtf8("edit-delete");
        if (QIcon::hasThemeIcon(iconThemeName)) {
            icon = QIcon::fromTheme(iconThemeName);
        } else {
            icon.addFile(QString::fromUtf8("."), QSize(), QIcon::Mode::Normal, QIcon::State::Off);
        }
        clearGraphHistory->setIcon(icon);
        clearGraphHistory->setIconSize(QSize(24, 24));

        gridLayout_5->addWidget(clearGraphHistory, 3, 8, 1, 1);

        weatherSourceCombo = new QComboBox(weatherBox);
        weatherSourceCombo->setObjectName("weatherSourceCombo");
        QSizePolicy sizePolicy1(QSizePolicy::Policy::MinimumExpanding, QSizePolicy::Policy::Fixed);
        sizePolicy1.setHorizontalStretch(0);
        sizePolicy1.setVerticalStretch(0);
        sizePolicy1.setHeightForWidth(weatherSourceCombo->sizePolicy().hasHeightForWidth());
        weatherSourceCombo->setSizePolicy(sizePolicy1);

        gridLayout_5->addWidget(weatherSourceCombo, 3, 2, 1, 1);

        weatherActionsBox = new QGroupBox(weatherBox);
        weatherActionsBox->setObjectName("weatherActionsBox");
        weatherActionsBox->setEnabled(false);
        horizontalLayout_7 = new QHBoxLayout(weatherActionsBox);
        horizontalLayout_7->setSpacing(3);
        horizontalLayout_7->setObjectName("horizontalLayout_7");
        horizontalLayout_7->setContentsMargins(3, 3, 3, 3);
        weatherAlertBox = new QGroupBox(weatherActionsBox);
        weatherAlertBox->setObjectName("weatherAlertBox");
        weatherAlertBox->setCheckable(true);
        gridLayout_7 = new QGridLayout(weatherAlertBox);
        gridLayout_7->setObjectName("gridLayout_7");
        gridLayout_7->setHorizontalSpacing(3);
        gridLayout_7->setContentsMargins(3, 3, 3, 0);
        weatherAlertShutterCB = new QCheckBox(weatherAlertBox);
        weatherAlertShutterCB->setObjectName("weatherAlertShutterCB");

        gridLayout_7->addWidget(weatherAlertShutterCB, 0, 1, 1, 1);

        weatherAlertDomeCB = new QCheckBox(weatherAlertBox);
        weatherAlertDomeCB->setObjectName("weatherAlertDomeCB");

        gridLayout_7->addWidget(weatherAlertDomeCB, 0, 0, 1, 1);

        weatherAlertSchedulerCB = new QCheckBox(weatherAlertBox);
        weatherAlertSchedulerCB->setObjectName("weatherAlertSchedulerCB");

        gridLayout_7->addWidget(weatherAlertSchedulerCB, 0, 2, 1, 1);

        horizontalLayout_2 = new QHBoxLayout();
        horizontalLayout_2->setSpacing(3);
        horizontalLayout_2->setObjectName("horizontalLayout_2");
        weatherAlertStatusLabel = new QLabel(weatherAlertBox);
        weatherAlertStatusLabel->setObjectName("weatherAlertStatusLabel");
        weatherAlertStatusLabel->setTextFormat(Qt::AutoText);

        horizontalLayout_2->addWidget(weatherAlertStatusLabel);

        horizontalSpacer_7 = new QSpacerItem(40, 20, QSizePolicy::Policy::Expanding, QSizePolicy::Policy::Minimum);

        horizontalLayout_2->addItem(horizontalSpacer_7);

        weatherAlertDelayLabel = new QLabel(weatherAlertBox);
        weatherAlertDelayLabel->setObjectName("weatherAlertDelayLabel");

        horizontalLayout_2->addWidget(weatherAlertDelayLabel);

        weatherAlertDelaySB = new QSpinBox(weatherAlertBox);
        weatherAlertDelaySB->setObjectName("weatherAlertDelaySB");
        weatherAlertDelaySB->setAlignment(Qt::AlignRight|Qt::AlignTrailing|Qt::AlignVCenter);
        weatherAlertDelaySB->setMaximum(9999);

        horizontalLayout_2->addWidget(weatherAlertDelaySB);


        gridLayout_7->addLayout(horizontalLayout_2, 1, 0, 1, 3);


        horizontalLayout_7->addWidget(weatherAlertBox);

        weatherWarningBox = new QGroupBox(weatherActionsBox);
        weatherWarningBox->setObjectName("weatherWarningBox");
        weatherWarningBox->setCheckable(true);
        gridLayout_6 = new QGridLayout(weatherWarningBox);
        gridLayout_6->setSpacing(3);
        gridLayout_6->setObjectName("gridLayout_6");
        gridLayout_6->setContentsMargins(3, 0, 3, 0);
        horizontalLayout = new QHBoxLayout();
        horizontalLayout->setSpacing(3);
        horizontalLayout->setObjectName("horizontalLayout");
        weatherWarningStatusLabel = new QLabel(weatherWarningBox);
        weatherWarningStatusLabel->setObjectName("weatherWarningStatusLabel");
        weatherWarningStatusLabel->setTextFormat(Qt::AutoText);

        horizontalLayout->addWidget(weatherWarningStatusLabel);

        horizontalSpacer_6 = new QSpacerItem(40, 20, QSizePolicy::Policy::Expanding, QSizePolicy::Policy::Minimum);

        horizontalLayout->addItem(horizontalSpacer_6);

        weatherWarningDelayLabel = new QLabel(weatherWarningBox);
        weatherWarningDelayLabel->setObjectName("weatherWarningDelayLabel");

        horizontalLayout->addWidget(weatherWarningDelayLabel);

        weatherWarningDelaySB = new QSpinBox(weatherWarningBox);
        weatherWarningDelaySB->setObjectName("weatherWarningDelaySB");
        weatherWarningDelaySB->setAlignment(Qt::AlignRight|Qt::AlignTrailing|Qt::AlignVCenter);
        weatherWarningDelaySB->setMaximum(9999);

        horizontalLayout->addWidget(weatherWarningDelaySB);


        gridLayout_6->addLayout(horizontalLayout, 1, 0, 1, 3);

        weatherWarningDomeCB = new QCheckBox(weatherWarningBox);
        weatherWarningDomeCB->setObjectName("weatherWarningDomeCB");

        gridLayout_6->addWidget(weatherWarningDomeCB, 0, 0, 1, 1);

        weatherWarningSchedulerCB = new QCheckBox(weatherWarningBox);
        weatherWarningSchedulerCB->setObjectName("weatherWarningSchedulerCB");

        gridLayout_6->addWidget(weatherWarningSchedulerCB, 0, 2, 1, 1);

        weatherWarningShutterCB = new QCheckBox(weatherWarningBox);
        weatherWarningShutterCB->setObjectName("weatherWarningShutterCB");

        gridLayout_6->addWidget(weatherWarningShutterCB, 0, 1, 1, 1);


        horizontalLayout_7->addWidget(weatherWarningBox);


        gridLayout_5->addWidget(weatherActionsBox, 4, 2, 1, 8, Qt::AlignTop);

        horizontalSpacer_3 = new QSpacerItem(40, 20, QSizePolicy::Policy::Expanding, QSizePolicy::Policy::Minimum);

        gridLayout_5->addItem(horizontalSpacer_3, 3, 6, 1, 1);

        weatherStatusLabel = new QLabel(weatherBox);
        weatherStatusLabel->setObjectName("weatherStatusLabel");
        QSizePolicy sizePolicy2(QSizePolicy::Policy::Fixed, QSizePolicy::Policy::Fixed);
        sizePolicy2.setHorizontalStretch(0);
        sizePolicy2.setVerticalStretch(0);
        sizePolicy2.setHeightForWidth(weatherStatusLabel->sizePolicy().hasHeightForWidth());
        weatherStatusLabel->setSizePolicy(sizePolicy2);
        weatherStatusLabel->setMinimumSize(QSize(28, 28));
        weatherStatusLabel->setMaximumSize(QSize(28, 28));

        gridLayout_5->addWidget(weatherStatusLabel, 3, 3, 1, 1);

        sensorData = new QWidget(weatherBox);
        sensorData->setObjectName("sensorData");
        sensorData->setMinimumSize(QSize(140, 0));

        gridLayout_5->addWidget(sensorData, 1, 2, 2, 1);

        sensorGraphs = new QCustomPlot(weatherBox);
        sensorGraphs->setObjectName("sensorGraphs");
        QSizePolicy sizePolicy3(QSizePolicy::Policy::Expanding, QSizePolicy::Policy::Expanding);
        sizePolicy3.setHorizontalStretch(0);
        sizePolicy3.setVerticalStretch(0);
        sizePolicy3.setHeightForWidth(sensorGraphs->sizePolicy().hasHeightForWidth());
        sensorGraphs->setSizePolicy(sizePolicy3);

        gridLayout_5->addWidget(sensorGraphs, 1, 3, 2, 6);

        splitter->addWidget(weatherBox);

        verticalLayout_2->addWidget(splitter);

        verticalSpacer = new QSpacerItem(20, 3, QSizePolicy::Policy::Minimum, QSizePolicy::Policy::Expanding);

        verticalLayout_2->addItem(verticalSpacer);


        retranslateUi(Observatory);

        QMetaObject::connectSlotsByName(Observatory);
    } // setupUi

    void retranslateUi(QWidget *Observatory)
    {
        Observatory->setWindowTitle(tr2i18n("Observatory", nullptr));
#if QT_CONFIG(tooltip)
        Observatory->setToolTip(QString());
#endif // QT_CONFIG(tooltip)
        domeBox->setTitle(tr2i18n("Dome", nullptr));
        domeAzimuthPositionLabel->setText(tr2i18n("Position", nullptr));
        motionStatusLabel->setText(QString());
        motionLabel->setText(tr2i18n("Motion", nullptr));
#if QT_CONFIG(tooltip)
        absoluteMotionSB->setToolTip(tr2i18n("Absolute position the dome should move.", nullptr));
#endif // QT_CONFIG(tooltip)
#if QT_CONFIG(tooltip)
        motionMoveAbsButton->setToolTip(tr2i18n("Move the dome to the given absolute position.", nullptr));
#endif // QT_CONFIG(tooltip)
        motionMoveAbsButton->setText(tr2i18n("Move (abs)", nullptr));
#if QT_CONFIG(tooltip)
        relativeMotionSB->setToolTip(tr2i18n("Relative position the dome should move.", nullptr));
#endif // QT_CONFIG(tooltip)
#if QT_CONFIG(tooltip)
        motionMoveRelButton->setToolTip(tr2i18n("Move the dome for the given degrees and direction.", nullptr));
#endif // QT_CONFIG(tooltip)
        motionMoveRelButton->setText(tr2i18n("Move (rel)", nullptr));
#if QT_CONFIG(tooltip)
        motionCWButton->setToolTip(tr2i18n("Rotate clockwise", nullptr));
#endif // QT_CONFIG(tooltip)
        motionCWButton->setText(tr2i18n("&CW", nullptr));
#if QT_CONFIG(tooltip)
        motionCCWButton->setToolTip(tr2i18n("Rotate counter clockwise", nullptr));
#endif // QT_CONFIG(tooltip)
        motionCCWButton->setText(tr2i18n("CCW", nullptr));
        label->setText(tr2i18n("Slaving", nullptr));
#if QT_CONFIG(tooltip)
        slavingEnableButton->setToolTip(tr2i18n("<html><head/><body><p>Enable slaving, dome motion <span style=\" font-weight:600;\">follows telescope motion</span></p></body></html>", nullptr));
#endif // QT_CONFIG(tooltip)
        slavingEnableButton->setText(tr2i18n("Enable", nullptr));
#if QT_CONFIG(tooltip)
        slavingDisableButton->setToolTip(tr2i18n("<html><head/><body><p>Disable slaving, dome <span style=\" font-weight:600;\">does not follow telescope motion</span>.</p></body></html>", nullptr));
#endif // QT_CONFIG(tooltip)
        slavingDisableButton->setText(tr2i18n("Disable", nullptr));
#if QT_CONFIG(tooltip)
        domePark->setToolTip(tr2i18n("<html><head/><body><p>Park the dome. For advanced control of the dome please use the INDI tab.</p></body></html>", nullptr));
#endif // QT_CONFIG(tooltip)
        domePark->setText(tr2i18n("Park", nullptr));
#if QT_CONFIG(tooltip)
        domeUnpark->setToolTip(tr2i18n("<html><head/><body><p>Unpark the dome. For advanced control of the dome please use the INDI tab.</p></body></html>", nullptr));
#endif // QT_CONFIG(tooltip)
        domeUnpark->setText(tr2i18n("UnPark", nullptr));
#if QT_CONFIG(tooltip)
        motionAbortButton->setToolTip(tr2i18n("Abort dome motion", nullptr));
#endif // QT_CONFIG(tooltip)
        motionAbortButton->setText(tr2i18n("Abort", nullptr));
        shutterBox->setTitle(tr2i18n("Shutter", nullptr));
#if QT_CONFIG(tooltip)
        shutterClosed->setToolTip(tr2i18n("<html><head/><body><p>Close the shutter of the dome. For advanced control of the dome please use the INDI tab.</p></body></html>", nullptr));
#endif // QT_CONFIG(tooltip)
        shutterClosed->setText(tr2i18n("Close", nullptr));
#if QT_CONFIG(tooltip)
        shutterOpen->setToolTip(tr2i18n("<html><head/><body><p>Open the shutter of the dome. For advanced control of the dome please use the INDI tab.</p></body></html>", nullptr));
#endif // QT_CONFIG(tooltip)
        shutterOpen->setText(tr2i18n("Open", "opens dome shutter"));
        statusDefinitionBox->setTitle(tr2i18n("Observatory Status", nullptr));
#if QT_CONFIG(tooltip)
        useDomeCB->setToolTip(tr2i18n("<html><head/><body><p>If selected, the dome needs to be unparked for the observatory status being &quot;READY&quot;.</p></body></html>", nullptr));
#endif // QT_CONFIG(tooltip)
        useDomeCB->setText(tr2i18n("Dome", nullptr));
#if QT_CONFIG(tooltip)
        useShutterCB->setToolTip(tr2i18n("<html><head/><body><p>If selected, the shutter needs to be open for the observatory status being &quot;READY&quot;.</p></body></html>", nullptr));
#endif // QT_CONFIG(tooltip)
        useShutterCB->setText(tr2i18n("Shutter", nullptr));
#if QT_CONFIG(tooltip)
        useWeatherCB->setToolTip(tr2i18n("<html><head/><body><p>If selected, the weather needs to be OK for the observatory status being &quot;READY&quot;.</p></body></html>", nullptr));
#endif // QT_CONFIG(tooltip)
        useWeatherCB->setText(tr2i18n("Weather", nullptr));
#if QT_CONFIG(tooltip)
        statusReadyButton->setToolTip(tr2i18n("<html><head/><body><p>Observatory status. Select the observatory elements that are relevant for the status:</p>\n"
"<ul>\n"
"<li><b>Dome</b>: unparked &rarr; ready</li>\n"
"<li><b>Shutter</b>: open &rarr; ready</li>\n"
"<li><b>Weather</b>: OK &rarr; ready</li>\n"
"</ul>\n"
"</body></html>", nullptr));
#endif // QT_CONFIG(tooltip)
        statusReadyButton->setText(tr2i18n("Ready", nullptr));
        weatherBox->setTitle(tr2i18n("Weather", nullptr));
#if QT_CONFIG(tooltip)
        autoscaleValuesCB->setToolTip(tr2i18n("<html><head/><body><p>Scale the value axis to the current value range.</p></body></html>", nullptr));
#endif // QT_CONFIG(tooltip)
        autoscaleValuesCB->setText(tr2i18n("Auto Scale", nullptr));
#if QT_CONFIG(tooltip)
        clearGraphHistory->setToolTip(tr2i18n("<html><head/><body><p>Clear sensor data history</p></body></html>", nullptr));
#endif // QT_CONFIG(tooltip)
        clearGraphHistory->setText(QString());
        weatherActionsBox->setTitle(tr2i18n("Actions", nullptr));
        weatherAlertBox->setTitle(tr2i18n("Ale&rt", nullptr));
        weatherAlertShutterCB->setText(tr2i18n("Close Shutter", nullptr));
        weatherAlertDomeCB->setText(tr2i18n("Park Dome", nullptr));
        weatherAlertSchedulerCB->setText(tr2i18n("Stop Scheduler", nullptr));
        weatherAlertStatusLabel->setText(tr2i18n("<html><head/><body><p><span style=\" font-style:italic;\">Status: inactive</span></p></body></html>", nullptr));
        weatherAlertDelayLabel->setText(tr2i18n("Delay (sec):", nullptr));
        weatherWarningBox->setTitle(tr2i18n("War&ning", nullptr));
        weatherWarningStatusLabel->setText(tr2i18n("<html><head/><body><p><span style=\" font-style:italic;\">Status: inactive</span></p></body></html>", nullptr));
        weatherWarningDelayLabel->setText(tr2i18n("Delay (sec):", nullptr));
        weatherWarningDomeCB->setText(tr2i18n("Park Dome", nullptr));
        weatherWarningSchedulerCB->setText(tr2i18n("Stop Scheduler", nullptr));
        weatherWarningShutterCB->setText(tr2i18n("Close Shutter", nullptr));
        weatherStatusLabel->setText(QString());
#if QT_CONFIG(tooltip)
        sensorData->setToolTip(tr2i18n("<html><head/><body><p>Current data of the weather sensors. Click on the sensor name to display its data over time.</p></body></html>", nullptr));
#endif // QT_CONFIG(tooltip)
#if QT_CONFIG(tooltip)
        sensorGraphs->setToolTip(QString());
#endif // QT_CONFIG(tooltip)
    } // retranslateUi

};

namespace Ui {
    class Observatory: public Ui_Observatory {};
} // namespace Ui

QT_END_NAMESPACE

#endif // OBSERVATORY_H

