/********************************************************************************
** Form generated from reading UI file 'pwizfovmanual.ui'
**
** Created by: Qt User Interface Compiler version 6.11.1
**
** WARNING! All changes made in this file will be lost when recompiling UI file!
********************************************************************************/

#ifndef UI_PWIZFOVMANUAL_H
#define UI_PWIZFOVMANUAL_H

#include <QtCore/QVariant>
#include <QtWidgets/QApplication>
#include <QtWidgets/QHBoxLayout>
#include <QtWidgets/QLabel>
#include <QtWidgets/QPushButton>
#include <QtWidgets/QSpacerItem>
#include <QtWidgets/QVBoxLayout>
#include <QtWidgets/QWidget>
#include <klocalizedstring.h>

QT_BEGIN_NAMESPACE

class Ui_PWizFovManual
{
public:
    QHBoxLayout *horizontalLayout_2;
    QLabel *banner;
    QSpacerItem *horSpacer3;
    QVBoxLayout *fovManualLayout;
    QLabel *stepTitle;
    QSpacerItem *vertSpacer1;
    QLabel *stepText;
    QSpacerItem *vertSpacer2;
    QHBoxLayout *horizontalLayout;
    QSpacerItem *horSpacer1;
    QPushButton *pushButton;
    QSpacerItem *horSpacer2;
    QSpacerItem *vertSpacer3;

    void setupUi(QWidget *PWizFovManual)
    {
        if (PWizFovManual->objectName().isEmpty())
            PWizFovManual->setObjectName("PWizFovManual");
        PWizFovManual->resize(586, 395);
        horizontalLayout_2 = new QHBoxLayout(PWizFovManual);
        horizontalLayout_2->setObjectName("horizontalLayout_2");
        banner = new QLabel(PWizFovManual);
        banner->setObjectName("banner");
        QSizePolicy sizePolicy(QSizePolicy::Policy::Fixed, QSizePolicy::Policy::Fixed);
        sizePolicy.setHorizontalStretch(0);
        sizePolicy.setVerticalStretch(0);
        sizePolicy.setHeightForWidth(banner->sizePolicy().hasHeightForWidth());
        banner->setSizePolicy(sizePolicy);
        banner->setMinimumSize(QSize(120, 360));

        horizontalLayout_2->addWidget(banner);

        horSpacer3 = new QSpacerItem(5, 20, QSizePolicy::Policy::Fixed, QSizePolicy::Policy::Minimum);

        horizontalLayout_2->addItem(horSpacer3);

        fovManualLayout = new QVBoxLayout();
#ifndef UI_Q_OS_MAC
        fovManualLayout->setSpacing(6);
#endif
        fovManualLayout->setContentsMargins(0, 0, 0, 0);
        fovManualLayout->setObjectName("fovManualLayout");
        stepTitle = new QLabel(PWizFovManual);
        stepTitle->setObjectName("stepTitle");
        QFont font;
        font.setFamilies({QString::fromUtf8("Sans Serif")});
        font.setPointSize(11);
        font.setBold(true);
        font.setItalic(false);
        font.setUnderline(false);
        font.setStrikeOut(false);
        stepTitle->setFont(font);

        fovManualLayout->addWidget(stepTitle);

        vertSpacer1 = new QSpacerItem(20, 12, QSizePolicy::Policy::Minimum, QSizePolicy::Policy::Fixed);

        fovManualLayout->addItem(vertSpacer1);

        stepText = new QLabel(PWizFovManual);
        stepText->setObjectName("stepText");
        stepText->setWordWrap(true);

        fovManualLayout->addWidget(stepText);

        vertSpacer2 = new QSpacerItem(20, 12, QSizePolicy::Policy::Minimum, QSizePolicy::Policy::Fixed);

        fovManualLayout->addItem(vertSpacer2);

        horizontalLayout = new QHBoxLayout();
        horizontalLayout->setObjectName("horizontalLayout");
        horSpacer1 = new QSpacerItem(40, 20, QSizePolicy::Policy::Expanding, QSizePolicy::Policy::Minimum);

        horizontalLayout->addItem(horSpacer1);

        pushButton = new QPushButton(PWizFovManual);
        pushButton->setObjectName("pushButton");

        horizontalLayout->addWidget(pushButton);

        horSpacer2 = new QSpacerItem(40, 20, QSizePolicy::Policy::Expanding, QSizePolicy::Policy::Minimum);

        horizontalLayout->addItem(horSpacer2);


        fovManualLayout->addLayout(horizontalLayout);

        vertSpacer3 = new QSpacerItem(20, 40, QSizePolicy::Policy::Minimum, QSizePolicy::Policy::Expanding);

        fovManualLayout->addItem(vertSpacer3);


        horizontalLayout_2->addLayout(fovManualLayout);


        retranslateUi(PWizFovManual);

        QMetaObject::connectSlotsByName(PWizFovManual);
    } // setupUi

    void retranslateUi(QWidget *PWizFovManual)
    {
        banner->setText(QString());
        stepTitle->setText(tr2i18n("Manually Capture Field of View Snapshots", nullptr));
        stepText->setText(tr2i18n("<p>In manual field of view capture method, user centers sky map to a point of interest, then captures snapshots of sky fragments inside the active FOV symbol.</p>\n"
"<p>When in field of view capture mode, press <b>Page Up</b> and <b>Page Down</b> to switch FOV symbols. Snapshots are captured by pressing <b>K</b> key. When done, press <b>Escape</b> key to return to the Printing Wizard.</p>\n"
"<p>Press <b>Next</b> when done.</p>", nullptr));
        pushButton->setText(tr2i18n("Begin capture", nullptr));
        (void)PWizFovManual;
    } // retranslateUi

};

namespace Ui {
    class PWizFovManual: public Ui_PWizFovManual {};
} // namespace Ui

QT_END_NAMESPACE

#endif // PWIZFOVMANUAL_H

