/********************************************************************************
** Form generated from reading UI file 'guidestatewidget.ui'
**
** Created by: Qt User Interface Compiler version 6.11.1
**
** WARNING! All changes made in this file will be lost when recompiling UI file!
********************************************************************************/

#ifndef UI_GUIDESTATEWIDGET_H
#define UI_GUIDESTATEWIDGET_H

#include <QtCore/QVariant>
#include <QtWidgets/QApplication>
#include <QtWidgets/QHBoxLayout>
#include <QtWidgets/QLabel>
#include <QtWidgets/QWidget>
#include <klocalizedstring.h>

QT_BEGIN_NAMESPACE

class Ui_GuideStateWidget
{
public:
    QHBoxLayout *guideStateLayout;
    QLabel *idlingStateLabel;
    QLabel *preparingStateLabel;
    QLabel *runningStateLabel;

    void setupUi(QWidget *GuideStateWidget)
    {
        if (GuideStateWidget->objectName().isEmpty())
            GuideStateWidget->setObjectName("GuideStateWidget");
        GuideStateWidget->resize(303, 25);
        guideStateLayout = new QHBoxLayout(GuideStateWidget);
        guideStateLayout->setSpacing(3);
        guideStateLayout->setObjectName("guideStateLayout");
        guideStateLayout->setContentsMargins(0, 0, 0, 0);
        idlingStateLabel = new QLabel(GuideStateWidget);
        idlingStateLabel->setObjectName("idlingStateLabel");
        QSizePolicy sizePolicy(QSizePolicy::Policy::Preferred, QSizePolicy::Policy::Preferred);
        sizePolicy.setHorizontalStretch(1);
        sizePolicy.setVerticalStretch(0);
        sizePolicy.setHeightForWidth(idlingStateLabel->sizePolicy().hasHeightForWidth());
        idlingStateLabel->setSizePolicy(sizePolicy);

        guideStateLayout->addWidget(idlingStateLabel);

        preparingStateLabel = new QLabel(GuideStateWidget);
        preparingStateLabel->setObjectName("preparingStateLabel");
        sizePolicy.setHeightForWidth(preparingStateLabel->sizePolicy().hasHeightForWidth());
        preparingStateLabel->setSizePolicy(sizePolicy);

        guideStateLayout->addWidget(preparingStateLabel);

        runningStateLabel = new QLabel(GuideStateWidget);
        runningStateLabel->setObjectName("runningStateLabel");
        sizePolicy.setHeightForWidth(runningStateLabel->sizePolicy().hasHeightForWidth());
        runningStateLabel->setSizePolicy(sizePolicy);

        guideStateLayout->addWidget(runningStateLabel);


        retranslateUi(GuideStateWidget);

        QMetaObject::connectSlotsByName(GuideStateWidget);
    } // setupUi

    void retranslateUi(QWidget *GuideStateWidget)
    {
        idlingStateLabel->setText(tr2i18n("Idle", nullptr));
        preparingStateLabel->setText(tr2i18n("Prep", nullptr));
        runningStateLabel->setText(tr2i18n("Run", nullptr));
        (void)GuideStateWidget;
    } // retranslateUi

};

namespace Ui {
    class GuideStateWidget: public Ui_GuideStateWidget {};
} // namespace Ui

QT_END_NAMESPACE

#endif // GUIDESTATEWIDGET_H

