/********************************************************************************
** Form generated from reading UI file 'thumbnailpicker.ui'
**
** Created by: Qt User Interface Compiler version 6.11.1
**
** WARNING! All changes made in this file will be lost when recompiling UI file!
********************************************************************************/

#ifndef UI_THUMBNAILPICKER_H
#define UI_THUMBNAILPICKER_H

#include <QtCore/QVariant>
#include <QtWidgets/QApplication>
#include <QtWidgets/QHBoxLayout>
#include <QtWidgets/QLabel>
#include <QtWidgets/QListWidget>
#include <QtWidgets/QProgressBar>
#include <QtWidgets/QPushButton>
#include <QtWidgets/QSpacerItem>
#include <QtWidgets/QVBoxLayout>
#include <QtWidgets/QWidget>
#include <klocalizedstring.h>
#include "kurlrequester.h"

QT_BEGIN_NAMESPACE

class Ui_ThumbnailPicker
{
public:
    QHBoxLayout *hboxLayout;
    QVBoxLayout *vboxLayout;
    QHBoxLayout *hboxLayout1;
    QLabel *SearchLabel;
    QSpacerItem *spacerItem;
    QProgressBar *SearchProgress;
    QListWidget *ImageList;
    QLabel *textLabel3;
    KUrlRequester *ImageURLBox;
    QVBoxLayout *vboxLayout1;
    QHBoxLayout *hboxLayout2;
    QSpacerItem *spacerItem1;
    QVBoxLayout *vboxLayout2;
    QLabel *textLabel1;
    QLabel *CurrentImage;
    QSpacerItem *spacerItem2;
    QHBoxLayout *hboxLayout3;
    QSpacerItem *spacerItem3;
    QVBoxLayout *vboxLayout3;
    QPushButton *EditButton;
    QPushButton *UnsetButton;
    QSpacerItem *spacerItem4;
    QSpacerItem *spacerItem5;

    void setupUi(QWidget *ThumbnailPicker)
    {
        if (ThumbnailPicker->objectName().isEmpty())
            ThumbnailPicker->setObjectName("ThumbnailPicker");
        ThumbnailPicker->resize(593, 374);
        hboxLayout = new QHBoxLayout(ThumbnailPicker);
        hboxLayout->setObjectName("hboxLayout");
        vboxLayout = new QVBoxLayout();
        vboxLayout->setObjectName("vboxLayout");
        hboxLayout1 = new QHBoxLayout();
        hboxLayout1->setObjectName("hboxLayout1");
        SearchLabel = new QLabel(ThumbnailPicker);
        SearchLabel->setObjectName("SearchLabel");

        hboxLayout1->addWidget(SearchLabel);

        spacerItem = new QSpacerItem(41, 20, QSizePolicy::Policy::Expanding, QSizePolicy::Policy::Minimum);

        hboxLayout1->addItem(spacerItem);

        SearchProgress = new QProgressBar(ThumbnailPicker);
        SearchProgress->setObjectName("SearchProgress");
        SearchProgress->setValue(24);
        SearchProgress->setOrientation(Qt::Horizontal);

        hboxLayout1->addWidget(SearchProgress);


        vboxLayout->addLayout(hboxLayout1);

        ImageList = new QListWidget(ThumbnailPicker);
        ImageList->setObjectName("ImageList");
        ImageList->setMinimumSize(QSize(300, 0));

        vboxLayout->addWidget(ImageList);

        textLabel3 = new QLabel(ThumbnailPicker);
        textLabel3->setObjectName("textLabel3");

        vboxLayout->addWidget(textLabel3);

        ImageURLBox = new KUrlRequester(ThumbnailPicker);
        ImageURLBox->setObjectName("ImageURLBox");

        vboxLayout->addWidget(ImageURLBox);


        hboxLayout->addLayout(vboxLayout);

        vboxLayout1 = new QVBoxLayout();
        vboxLayout1->setObjectName("vboxLayout1");
        hboxLayout2 = new QHBoxLayout();
        hboxLayout2->setObjectName("hboxLayout2");
        spacerItem1 = new QSpacerItem(53, 20, QSizePolicy::Policy::Expanding, QSizePolicy::Policy::Minimum);

        hboxLayout2->addItem(spacerItem1);

        vboxLayout2 = new QVBoxLayout();
        vboxLayout2->setObjectName("vboxLayout2");
        textLabel1 = new QLabel(ThumbnailPicker);
        textLabel1->setObjectName("textLabel1");

        vboxLayout2->addWidget(textLabel1);

        CurrentImage = new QLabel(ThumbnailPicker);
        CurrentImage->setObjectName("CurrentImage");
        QSizePolicy sizePolicy(QSizePolicy::Policy::Fixed, QSizePolicy::Policy::Fixed);
        sizePolicy.setHorizontalStretch(0);
        sizePolicy.setVerticalStretch(0);
        sizePolicy.setHeightForWidth(CurrentImage->sizePolicy().hasHeightForWidth());
        CurrentImage->setSizePolicy(sizePolicy);
        CurrentImage->setMinimumSize(QSize(200, 200));
        CurrentImage->setMaximumSize(QSize(200, 200));
        CurrentImage->setFrameShape(QFrame::Box);
        CurrentImage->setScaledContents(false);

        vboxLayout2->addWidget(CurrentImage);


        hboxLayout2->addLayout(vboxLayout2);

        spacerItem2 = new QSpacerItem(53, 20, QSizePolicy::Policy::Expanding, QSizePolicy::Policy::Minimum);

        hboxLayout2->addItem(spacerItem2);


        vboxLayout1->addLayout(hboxLayout2);

        hboxLayout3 = new QHBoxLayout();
        hboxLayout3->setObjectName("hboxLayout3");
        spacerItem3 = new QSpacerItem(40, 20, QSizePolicy::Policy::Expanding, QSizePolicy::Policy::Minimum);

        hboxLayout3->addItem(spacerItem3);

        vboxLayout3 = new QVBoxLayout();
        vboxLayout3->setObjectName("vboxLayout3");
        EditButton = new QPushButton(ThumbnailPicker);
        EditButton->setObjectName("EditButton");

        vboxLayout3->addWidget(EditButton);

        UnsetButton = new QPushButton(ThumbnailPicker);
        UnsetButton->setObjectName("UnsetButton");

        vboxLayout3->addWidget(UnsetButton);


        hboxLayout3->addLayout(vboxLayout3);

        spacerItem4 = new QSpacerItem(40, 20, QSizePolicy::Policy::Expanding, QSizePolicy::Policy::Minimum);

        hboxLayout3->addItem(spacerItem4);


        vboxLayout1->addLayout(hboxLayout3);

        spacerItem5 = new QSpacerItem(20, 233, QSizePolicy::Policy::Minimum, QSizePolicy::Policy::Expanding);

        vboxLayout1->addItem(spacerItem5);


        hboxLayout->addLayout(vboxLayout1);


        retranslateUi(ThumbnailPicker);

        QMetaObject::connectSlotsByName(ThumbnailPicker);
    } // setupUi

    void retranslateUi(QWidget *ThumbnailPicker)
    {
        ThumbnailPicker->setWindowTitle(tr2i18n("Thumbnail Picker", nullptr));
        SearchLabel->setText(tr2i18n("Search results:", nullptr));
        SearchProgress->setFormat(tr2i18n("%p%", nullptr));
        textLabel3->setText(tr2i18n("Specify image location:", nullptr));
        textLabel1->setText(tr2i18n("Current thumbnail:", nullptr));
        EditButton->setText(tr2i18n("Edit Ima&ge...", nullptr));
        UnsetButton->setText(tr2i18n("Unset Image", nullptr));
    } // retranslateUi

};

namespace Ui {
    class ThumbnailPicker: public Ui_ThumbnailPicker {};
} // namespace Ui

QT_END_NAMESPACE

#endif // THUMBNAILPICKER_H

