/*
 * This file was generated by qdbusxml2cpp version 0.8
 * Source file was org.kde.kstars.INDI.Dome.xml
 *
 * qdbusxml2cpp is Copyright (C) The Qt Company Ltd. and other contributors.
 *
 * This is an auto-generated file.
 * Do not edit! All changes made to it will be lost.
 */

#include "domeadaptor.h"
#include <QtCore/QMetaObject>
#include <QtCore/QByteArray>
#include <QtCore/QList>
#include <QtCore/QMap>
#include <QtCore/QString>
#include <QtCore/QStringList>
#include <QtCore/QVariant>

/*
 * Implementation of adaptor class DomeAdaptor
 */

DomeAdaptor::DomeAdaptor(ISD::Dome *parent)
    : QDBusAbstractAdaptor(parent)
{
    // constructor
    setAutoRelaySignals(true);
}

DomeAdaptor::~DomeAdaptor()
{
    // destructor
}

bool DomeAdaptor::canAbort() const
{
    // get the value of property canAbort
    return qvariant_cast< bool >(parent()->property("canAbort"));
}

bool DomeAdaptor::canAbsMove() const
{
    // get the value of property canAbsMove
    return qvariant_cast< bool >(parent()->property("canAbsMove"));
}

bool DomeAdaptor::canPark() const
{
    // get the value of property canPark
    return qvariant_cast< bool >(parent()->property("canPark"));
}

bool DomeAdaptor::canRelMove() const
{
    // get the value of property canRelMove
    return qvariant_cast< bool >(parent()->property("canRelMove"));
}

bool DomeAdaptor::connected() const
{
    // get the value of property connected
    return qvariant_cast< bool >(parent()->property("connected"));
}

bool DomeAdaptor::isMoving() const
{
    // get the value of property isMoving
    return qvariant_cast< bool >(parent()->property("isMoving"));
}

QString DomeAdaptor::name() const
{
    // get the value of property name
    return qvariant_cast< QString >(parent()->property("name"));
}

int DomeAdaptor::parkStatus() const
{
    // get the value of property parkStatus
    return qvariant_cast< int >(parent()->property("parkStatus"));
}

double DomeAdaptor::position() const
{
    // get the value of property position
    return qvariant_cast< double >(parent()->property("position"));
}

void DomeAdaptor::setPosition(double value)
{
    // set the value of property position
    parent()->setProperty("position", QVariant::fromValue(value));
}

int DomeAdaptor::shutterStatus() const
{
    // get the value of property shutterStatus
    return qvariant_cast< int >(parent()->property("shutterStatus"));
}

int DomeAdaptor::status() const
{
    // get the value of property status
    return qvariant_cast< int >(parent()->property("status"));
}

void DomeAdaptor::Connect()
{
    // handle method call org.kde.kstars.INDI.Dome.Connect
    parent()->Connect();
}

void DomeAdaptor::Disconnect()
{
    // handle method call org.kde.kstars.INDI.Dome.Disconnect
    parent()->Disconnect();
}

bool DomeAdaptor::abort()
{
    // handle method call org.kde.kstars.INDI.Dome.abort
    return parent()->abort();
}

bool DomeAdaptor::controlShutter(bool open)
{
    // handle method call org.kde.kstars.INDI.Dome.controlShutter
    return parent()->controlShutter(open);
}

bool DomeAdaptor::hasShutter()
{
    // handle method call org.kde.kstars.INDI.Dome.hasShutter
    return parent()->hasShutter();
}

bool DomeAdaptor::isParked()
{
    // handle method call org.kde.kstars.INDI.Dome.isParked
    return parent()->isParked();
}

bool DomeAdaptor::moveCCW()
{
    // handle method call org.kde.kstars.INDI.Dome.moveCCW
    return parent()->moveCCW();
}

bool DomeAdaptor::moveCW()
{
    // handle method call org.kde.kstars.INDI.Dome.moveCW
    return parent()->moveCW();
}

bool DomeAdaptor::park()
{
    // handle method call org.kde.kstars.INDI.Dome.park
    return parent()->park();
}

bool DomeAdaptor::unpark()
{
    // handle method call org.kde.kstars.INDI.Dome.unpark
    return parent()->unpark();
}


#include "moc_domeadaptor.cpp"
