/********************************************************************************
** Form generated from reading UI file 'focusmodule.ui'
**
** Created by: Qt User Interface Compiler version 6.11.1
**
** WARNING! All changes made in this file will be lost when recompiling UI file!
********************************************************************************/

#ifndef UI_FOCUSMODULE_H
#define UI_FOCUSMODULE_H

#include <QtCore/QVariant>
#include <QtWidgets/QApplication>
#include <QtWidgets/QTabWidget>
#include <QtWidgets/QVBoxLayout>
#include <QtWidgets/QWidget>
#include <klocalizedstring.h>

QT_BEGIN_NAMESPACE

class Ui_FocusManager
{
public:
    QVBoxLayout *wholeLayout;
    QTabWidget *focusTabs;

    void setupUi(QWidget *FocusManager)
    {
        if (FocusManager->objectName().isEmpty())
            FocusManager->setObjectName("FocusManager");
        FocusManager->resize(815, 539);
        wholeLayout = new QVBoxLayout(FocusManager);
        wholeLayout->setObjectName("wholeLayout");
        focusTabs = new QTabWidget(FocusManager);
        focusTabs->setObjectName("focusTabs");
        focusTabs->setTabsClosable(true);

        wholeLayout->addWidget(focusTabs);


        retranslateUi(FocusManager);

        focusTabs->setCurrentIndex(-1);


        QMetaObject::connectSlotsByName(FocusManager);
    } // setupUi

    void retranslateUi(QWidget *FocusManager)
    {
        (void)FocusManager;
    } // retranslateUi

};

namespace Ui {
    class FocusManager: public Ui_FocusManager {};
} // namespace Ui

QT_END_NAMESPACE

#endif // FOCUSMODULE_H

