/********************************************************************************
** Form generated from reading UI file 'statform.ui'
**
** Created by: Qt User Interface Compiler version 6.11.1
**
** WARNING! All changes made in this file will be lost when recompiling UI file!
********************************************************************************/

#ifndef UI_STATFORM_H
#define UI_STATFORM_H

#include <QtCore/QVariant>
#include <QtWidgets/QApplication>
#include <QtWidgets/QDialog>
#include <QtWidgets/QHeaderView>
#include <QtWidgets/QSpacerItem>
#include <QtWidgets/QTableWidget>
#include <QtWidgets/QVBoxLayout>
#include <klocalizedstring.h>

QT_BEGIN_NAMESPACE

class Ui_statForm
{
public:
    QVBoxLayout *verticalLayout;
    QTableWidget *statsTable;
    QSpacerItem *verticalSpacer;

    void setupUi(QDialog *statForm)
    {
        if (statForm->objectName().isEmpty())
            statForm->setObjectName("statForm");
        statForm->resize(211, 323);
        verticalLayout = new QVBoxLayout(statForm);
        verticalLayout->setSpacing(3);
        verticalLayout->setObjectName("verticalLayout");
        verticalLayout->setContentsMargins(3, 3, 3, 3);
        statsTable = new QTableWidget(statForm);
        if (statsTable->columnCount() < 3)
            statsTable->setColumnCount(3);
        QTableWidgetItem *__qtablewidgetitem = new QTableWidgetItem();
        statsTable->setHorizontalHeaderItem(0, __qtablewidgetitem);
        QTableWidgetItem *__qtablewidgetitem1 = new QTableWidgetItem();
        statsTable->setHorizontalHeaderItem(1, __qtablewidgetitem1);
        QTableWidgetItem *__qtablewidgetitem2 = new QTableWidgetItem();
        statsTable->setHorizontalHeaderItem(2, __qtablewidgetitem2);
        if (statsTable->rowCount() < 9)
            statsTable->setRowCount(9);
        QTableWidgetItem *__qtablewidgetitem3 = new QTableWidgetItem();
        statsTable->setVerticalHeaderItem(0, __qtablewidgetitem3);
        QTableWidgetItem *__qtablewidgetitem4 = new QTableWidgetItem();
        statsTable->setVerticalHeaderItem(1, __qtablewidgetitem4);
        QTableWidgetItem *__qtablewidgetitem5 = new QTableWidgetItem();
        statsTable->setVerticalHeaderItem(2, __qtablewidgetitem5);
        QTableWidgetItem *__qtablewidgetitem6 = new QTableWidgetItem();
        statsTable->setVerticalHeaderItem(3, __qtablewidgetitem6);
        QTableWidgetItem *__qtablewidgetitem7 = new QTableWidgetItem();
        statsTable->setVerticalHeaderItem(4, __qtablewidgetitem7);
        QTableWidgetItem *__qtablewidgetitem8 = new QTableWidgetItem();
        statsTable->setVerticalHeaderItem(5, __qtablewidgetitem8);
        QTableWidgetItem *__qtablewidgetitem9 = new QTableWidgetItem();
        statsTable->setVerticalHeaderItem(6, __qtablewidgetitem9);
        QTableWidgetItem *__qtablewidgetitem10 = new QTableWidgetItem();
        statsTable->setVerticalHeaderItem(7, __qtablewidgetitem10);
        QTableWidgetItem *__qtablewidgetitem11 = new QTableWidgetItem();
        statsTable->setVerticalHeaderItem(8, __qtablewidgetitem11);
        statsTable->setObjectName("statsTable");
        statsTable->setVerticalScrollBarPolicy(Qt::ScrollBarAlwaysOff);
        statsTable->setHorizontalScrollBarPolicy(Qt::ScrollBarAlwaysOff);
        statsTable->setSizeAdjustPolicy(QAbstractScrollArea::AdjustToContents);
        statsTable->setEditTriggers(QAbstractItemView::NoEditTriggers);
        statsTable->setSelectionMode(QAbstractItemView::SingleSelection);
        statsTable->horizontalHeader()->setCascadingSectionResizes(false);
        statsTable->horizontalHeader()->setDefaultSectionSize(50);
        statsTable->horizontalHeader()->setStretchLastSection(true);
        statsTable->verticalHeader()->setProperty("showSortIndicator", QVariant(false));
        statsTable->verticalHeader()->setStretchLastSection(true);

        verticalLayout->addWidget(statsTable);

        verticalSpacer = new QSpacerItem(20, 40, QSizePolicy::Policy::Minimum, QSizePolicy::Policy::Expanding);

        verticalLayout->addItem(verticalSpacer);


        retranslateUi(statForm);

        QMetaObject::connectSlotsByName(statForm);
    } // setupUi

    void retranslateUi(QDialog *statForm)
    {
        statForm->setWindowTitle(tr2i18n("Statistics", nullptr));
        QTableWidgetItem *___qtablewidgetitem = statsTable->horizontalHeaderItem(0);
        ___qtablewidgetitem->setText(tr2i18n("R", nullptr));
        QTableWidgetItem *___qtablewidgetitem1 = statsTable->horizontalHeaderItem(1);
        ___qtablewidgetitem1->setText(tr2i18n("G", nullptr));
        QTableWidgetItem *___qtablewidgetitem2 = statsTable->horizontalHeaderItem(2);
        ___qtablewidgetitem2->setText(tr2i18n("B", nullptr));
        QTableWidgetItem *___qtablewidgetitem3 = statsTable->verticalHeaderItem(0);
        ___qtablewidgetitem3->setText(tr2i18n("Width", nullptr));
        QTableWidgetItem *___qtablewidgetitem4 = statsTable->verticalHeaderItem(1);
        ___qtablewidgetitem4->setText(tr2i18n("Height", nullptr));
        QTableWidgetItem *___qtablewidgetitem5 = statsTable->verticalHeaderItem(2);
        ___qtablewidgetitem5->setText(tr2i18n("Bitpix", nullptr));
        QTableWidgetItem *___qtablewidgetitem6 = statsTable->verticalHeaderItem(3);
        ___qtablewidgetitem6->setText(tr2i18n("HFR", nullptr));
        QTableWidgetItem *___qtablewidgetitem7 = statsTable->verticalHeaderItem(4);
        ___qtablewidgetitem7->setText(tr2i18n("Min", nullptr));
        QTableWidgetItem *___qtablewidgetitem8 = statsTable->verticalHeaderItem(5);
        ___qtablewidgetitem8->setText(tr2i18n("Max", nullptr));
        QTableWidgetItem *___qtablewidgetitem9 = statsTable->verticalHeaderItem(6);
        ___qtablewidgetitem9->setText(tr2i18n("Mean", nullptr));
        QTableWidgetItem *___qtablewidgetitem10 = statsTable->verticalHeaderItem(7);
        ___qtablewidgetitem10->setText(tr2i18n("Median", nullptr));
        QTableWidgetItem *___qtablewidgetitem11 = statsTable->verticalHeaderItem(8);
        ___qtablewidgetitem11->setText(tr2i18n("Std. Dev", nullptr));
    } // retranslateUi

};

namespace Ui {
    class statForm: public Ui_statForm {};
} // namespace Ui

QT_END_NAMESPACE

#endif // STATFORM_H

