/****************************************************************************
** Meta object code from reading C++ file 'mountmodel.h'
**
** Created by: The Qt Meta Object Compiler version 69 (Qt 6.11.1)
**
** WARNING! All changes made in this file will be lost!
*****************************************************************************/

#include "../../../../kstars-3.8.4.1/kstars/ekos/align/mountmodel.h"
#include <QtCore/qmetatype.h>

#include <QtCore/qtmochelpers.h>

#include <memory>


#include <QtCore/qxptype_traits.h>
#if !defined(Q_MOC_OUTPUT_REVISION)
#error "The header file 'mountmodel.h' doesn't include <QObject>."
#elif Q_MOC_OUTPUT_REVISION != 69
#error "This file was generated using the moc from 6.11.1. It"
#error "cannot be used with the include files from this version of Qt."
#error "(The moc has changed too much.)"
#endif

#ifndef Q_CONSTINIT
#define Q_CONSTINIT
#endif

QT_WARNING_PUSH
QT_WARNING_DISABLE_DEPRECATED
QT_WARNING_DISABLE_GCC("-Wuseless-cast")
namespace {
struct qt_meta_tag_ZN4Ekos10MountModelE_t {};
} // unnamed namespace

template <> constexpr inline auto Ekos::MountModel::qt_create_metaobjectdata<qt_meta_tag_ZN4Ekos10MountModelE_t>()
{
    namespace QMC = QtMocConstants;
    QtMocHelpers::StringRefStorage qt_stringData {
        "Ekos::MountModel",
        "newLog",
        "",
        "aborted",
        "progressUpdated",
        "QVariantMap",
        "settings",
        "getAllSettings",
        "setAllSettings",
        "startStopAlignmentProcedure",
        "resetAlignmentProcedure",
        "slotClearAllAlignPoints",
        "slotWizardAlignmentPoints",
        "slotAddAlignPoint",
        "slotRemoveAlignPoint",
        "slotSortAlignmentPoints"
    };

    QtMocHelpers::UintData qt_methods {
        // Signal 'newLog'
        QtMocHelpers::SignalData<void(const QString &)>(1, 2, QMC::AccessPublic, QMetaType::Void, {{
            { QMetaType::QString, 2 },
        }}),
        // Signal 'aborted'
        QtMocHelpers::SignalData<void()>(3, 2, QMC::AccessPublic, QMetaType::Void),
        // Signal 'progressUpdated'
        QtMocHelpers::SignalData<void(const QVariantMap &)>(4, 2, QMC::AccessPublic, QMetaType::Void, {{
            { 0x80000000 | 5, 6 },
        }}),
        // Method 'getAllSettings'
        QtMocHelpers::MethodData<QVariantMap()>(7, 2, QMC::AccessPublic, 0x80000000 | 5),
        // Method 'setAllSettings'
        QtMocHelpers::MethodData<void(const QVariantMap &)>(8, 2, QMC::AccessPublic, QMetaType::Void, {{
            { 0x80000000 | 5, 6 },
        }}),
        // Method 'startStopAlignmentProcedure'
        QtMocHelpers::MethodData<void()>(9, 2, QMC::AccessPublic, QMetaType::Void),
        // Method 'resetAlignmentProcedure'
        QtMocHelpers::MethodData<void()>(10, 2, QMC::AccessPublic, QMetaType::Void),
        // Method 'slotClearAllAlignPoints'
        QtMocHelpers::MethodData<void()>(11, 2, QMC::AccessPublic, QMetaType::Void),
        // Method 'slotWizardAlignmentPoints'
        QtMocHelpers::MethodData<void()>(12, 2, QMC::AccessPublic, QMetaType::Void),
        // Method 'slotAddAlignPoint'
        QtMocHelpers::MethodData<void()>(13, 2, QMC::AccessPublic, QMetaType::Void),
        // Method 'slotRemoveAlignPoint'
        QtMocHelpers::MethodData<void()>(14, 2, QMC::AccessPublic, QMetaType::Void),
        // Method 'slotSortAlignmentPoints'
        QtMocHelpers::MethodData<void()>(15, 2, QMC::AccessPublic, QMetaType::Void),
    };
    QtMocHelpers::UintData qt_properties {
    };
    QtMocHelpers::UintData qt_enums {
    };
    return QtMocHelpers::metaObjectData<MountModel, qt_meta_tag_ZN4Ekos10MountModelE_t>(QMC::MetaObjectFlag{}, qt_stringData,
            qt_methods, qt_properties, qt_enums);
}
Q_CONSTINIT const QMetaObject Ekos::MountModel::staticMetaObject = { {
    QMetaObject::SuperData::link<QDialog::staticMetaObject>(),
    qt_staticMetaObjectStaticContent<qt_meta_tag_ZN4Ekos10MountModelE_t>.stringdata,
    qt_staticMetaObjectStaticContent<qt_meta_tag_ZN4Ekos10MountModelE_t>.data,
    qt_static_metacall,
    nullptr,
    qt_staticMetaObjectRelocatingContent<qt_meta_tag_ZN4Ekos10MountModelE_t>.metaTypes,
    nullptr
} };

void Ekos::MountModel::qt_static_metacall(QObject *_o, QMetaObject::Call _c, int _id, void **_a)
{
    auto *_t = static_cast<MountModel *>(_o);
    if (_c == QMetaObject::InvokeMetaMethod) {
        switch (_id) {
        case 0: _t->newLog((*reinterpret_cast<std::add_pointer_t<QString>>(_a[1]))); break;
        case 1: _t->aborted(); break;
        case 2: _t->progressUpdated((*reinterpret_cast<std::add_pointer_t<QVariantMap>>(_a[1]))); break;
        case 3: { QVariantMap _r = _t->getAllSettings();
            if (_a[0]) *reinterpret_cast<QVariantMap*>(_a[0]) = std::move(_r); }  break;
        case 4: _t->setAllSettings((*reinterpret_cast<std::add_pointer_t<QVariantMap>>(_a[1]))); break;
        case 5: _t->startStopAlignmentProcedure(); break;
        case 6: _t->resetAlignmentProcedure(); break;
        case 7: _t->slotClearAllAlignPoints(); break;
        case 8: _t->slotWizardAlignmentPoints(); break;
        case 9: _t->slotAddAlignPoint(); break;
        case 10: _t->slotRemoveAlignPoint(); break;
        case 11: _t->slotSortAlignmentPoints(); break;
        default: ;
        }
    }
    if (_c == QMetaObject::IndexOfMethod) {
        if (QtMocHelpers::indexOfMethod<void (MountModel::*)(const QString & )>(_a, &MountModel::newLog, 0))
            return;
        if (QtMocHelpers::indexOfMethod<void (MountModel::*)()>(_a, &MountModel::aborted, 1))
            return;
        if (QtMocHelpers::indexOfMethod<void (MountModel::*)(const QVariantMap & )>(_a, &MountModel::progressUpdated, 2))
            return;
    }
}

const QMetaObject *Ekos::MountModel::metaObject() const
{
    return QObject::d_ptr->metaObject ? QObject::d_ptr->dynamicMetaObject() : &staticMetaObject;
}

void *Ekos::MountModel::qt_metacast(const char *_clname)
{
    if (!_clname) return nullptr;
    if (!strcmp(_clname, qt_staticMetaObjectStaticContent<qt_meta_tag_ZN4Ekos10MountModelE_t>.strings))
        return static_cast<void*>(this);
    if (!strcmp(_clname, "Ui::mountModel"))
        return static_cast< Ui::mountModel*>(this);
    return QDialog::qt_metacast(_clname);
}

int Ekos::MountModel::qt_metacall(QMetaObject::Call _c, int _id, void **_a)
{
    _id = QDialog::qt_metacall(_c, _id, _a);
    if (_id < 0)
        return _id;
    if (_c == QMetaObject::InvokeMetaMethod) {
        if (_id < 12)
            qt_static_metacall(this, _c, _id, _a);
        _id -= 12;
    }
    if (_c == QMetaObject::RegisterMethodArgumentMetaType) {
        if (_id < 12)
            *reinterpret_cast<QMetaType *>(_a[0]) = QMetaType();
        _id -= 12;
    }
    return _id;
}

// SIGNAL 0
void Ekos::MountModel::newLog(const QString & _t1)
{
    QMetaObject::activate<void>(this, &staticMetaObject, 0, nullptr, _t1);
}

// SIGNAL 1
void Ekos::MountModel::aborted()
{
    QMetaObject::activate(this, &staticMetaObject, 1, nullptr);
}

// SIGNAL 2
void Ekos::MountModel::progressUpdated(const QVariantMap & _t1)
{
    QMetaObject::activate<void>(this, &staticMetaObject, 2, nullptr, _t1);
}
QT_WARNING_POP
