/********************************************************************************
** Form generated from reading UI file 'opsterrain.ui'
**
** Created by: Qt User Interface Compiler version 6.11.1
**
** WARNING! All changes made in this file will be lost when recompiling UI file!
********************************************************************************/

#ifndef UI_OPSTERRAIN_H
#define UI_OPSTERRAIN_H

#include <QtCore/QVariant>
#include <QtWidgets/QApplication>
#include <QtWidgets/QCheckBox>
#include <QtWidgets/QGroupBox>
#include <QtWidgets/QHBoxLayout>
#include <QtWidgets/QLabel>
#include <QtWidgets/QLineEdit>
#include <QtWidgets/QPushButton>
#include <QtWidgets/QSpacerItem>
#include <QtWidgets/QSpinBox>
#include <QtWidgets/QVBoxLayout>
#include <QtWidgets/QWidget>
#include <klocalizedstring.h>

QT_BEGIN_NAMESPACE

class Ui_OpsTerrain
{
public:
    QVBoxLayout *terrainVerticalLayout_2;
    QGroupBox *TerrainBox;
    QVBoxLayout *vboxLayout;
    QVBoxLayout *vboxLayout1;
    QCheckBox *kcfg_ShowTerrain;
    QHBoxLayout *terrainFileLayout;
    QLabel *terrainFileLabel;
    QLineEdit *kcfg_TerrainSource;
    QPushButton *selectTerrainFileB;
    QHBoxLayout *terrainSourceCorrectAzLayout;
    QLabel *terrainSourceCorrectAzLabel;
    QSpinBox *kcfg_TerrainSourceCorrectAz;
    QSpacerItem *spacerItem;
    QHBoxLayout *terrainSourceCorrectAltLayout;
    QLabel *terrainSourceCorrectAltLabel;
    QSpinBox *kcfg_TerrainSourceCorrectAlt;
    QSpacerItem *spacerItem1;
    QGroupBox *TerrainSpeedupGroupBox_2;
    QVBoxLayout *TerrainSpeedupVerticalLayout;
    QHBoxLayout *terrainDownsampleLayout;
    QLabel *terrainDownsamplingLabel;
    QSpinBox *kcfg_TerrainDownsampling;
    QSpacerItem *spacerItem2;
    QCheckBox *kcfg_TerrainPanning;
    QCheckBox *kcfg_TerrainSmoothPixels;
    QCheckBox *kcfg_TerrainSkipSpeedup;
    QCheckBox *kcfg_TerrainTransparencySpeedup;
    QSpacerItem *spacerItem3;

    void setupUi(QWidget *OpsTerrain)
    {
        if (OpsTerrain->objectName().isEmpty())
            OpsTerrain->setObjectName("OpsTerrain");
        OpsTerrain->resize(346, 357);
        terrainVerticalLayout_2 = new QVBoxLayout(OpsTerrain);
        terrainVerticalLayout_2->setObjectName("terrainVerticalLayout_2");
        TerrainBox = new QGroupBox(OpsTerrain);
        TerrainBox->setObjectName("TerrainBox");
        TerrainBox->setMaximumSize(QSize(16777215, 150));
        vboxLayout = new QVBoxLayout(TerrainBox);
        vboxLayout->setObjectName("vboxLayout");
        vboxLayout1 = new QVBoxLayout();
        vboxLayout1->setObjectName("vboxLayout1");
        kcfg_ShowTerrain = new QCheckBox(TerrainBox);
        kcfg_ShowTerrain->setObjectName("kcfg_ShowTerrain");

        vboxLayout1->addWidget(kcfg_ShowTerrain);

        terrainFileLayout = new QHBoxLayout();
        terrainFileLayout->setObjectName("terrainFileLayout");
        terrainFileLabel = new QLabel(TerrainBox);
        terrainFileLabel->setObjectName("terrainFileLabel");
        QSizePolicy sizePolicy(QSizePolicy::Policy::Fixed, QSizePolicy::Policy::Preferred);
        sizePolicy.setHorizontalStretch(0);
        sizePolicy.setVerticalStretch(0);
        sizePolicy.setHeightForWidth(terrainFileLabel->sizePolicy().hasHeightForWidth());
        terrainFileLabel->setSizePolicy(sizePolicy);

        terrainFileLayout->addWidget(terrainFileLabel);

        kcfg_TerrainSource = new QLineEdit(TerrainBox);
        kcfg_TerrainSource->setObjectName("kcfg_TerrainSource");
        QSizePolicy sizePolicy1(QSizePolicy::Policy::Expanding, QSizePolicy::Policy::Fixed);
        sizePolicy1.setHorizontalStretch(0);
        sizePolicy1.setVerticalStretch(0);
        sizePolicy1.setHeightForWidth(kcfg_TerrainSource->sizePolicy().hasHeightForWidth());
        kcfg_TerrainSource->setSizePolicy(sizePolicy1);

        terrainFileLayout->addWidget(kcfg_TerrainSource);

        selectTerrainFileB = new QPushButton(TerrainBox);
        selectTerrainFileB->setObjectName("selectTerrainFileB");
        QSizePolicy sizePolicy2(QSizePolicy::Policy::Fixed, QSizePolicy::Policy::Fixed);
        sizePolicy2.setHorizontalStretch(0);
        sizePolicy2.setVerticalStretch(0);
        sizePolicy2.setHeightForWidth(selectTerrainFileB->sizePolicy().hasHeightForWidth());
        selectTerrainFileB->setSizePolicy(sizePolicy2);
        selectTerrainFileB->setMinimumSize(QSize(28, 28));
        selectTerrainFileB->setMaximumSize(QSize(28, 28));

        terrainFileLayout->addWidget(selectTerrainFileB);


        vboxLayout1->addLayout(terrainFileLayout);

        terrainSourceCorrectAzLayout = new QHBoxLayout();
        terrainSourceCorrectAzLayout->setObjectName("terrainSourceCorrectAzLayout");
        terrainSourceCorrectAzLabel = new QLabel(TerrainBox);
        terrainSourceCorrectAzLabel->setObjectName("terrainSourceCorrectAzLabel");
        sizePolicy.setHeightForWidth(terrainSourceCorrectAzLabel->sizePolicy().hasHeightForWidth());
        terrainSourceCorrectAzLabel->setSizePolicy(sizePolicy);

        terrainSourceCorrectAzLayout->addWidget(terrainSourceCorrectAzLabel);

        kcfg_TerrainSourceCorrectAz = new QSpinBox(TerrainBox);
        kcfg_TerrainSourceCorrectAz->setObjectName("kcfg_TerrainSourceCorrectAz");
        sizePolicy2.setHeightForWidth(kcfg_TerrainSourceCorrectAz->sizePolicy().hasHeightForWidth());
        kcfg_TerrainSourceCorrectAz->setSizePolicy(sizePolicy2);
        kcfg_TerrainSourceCorrectAz->setMinimum(-360);
        kcfg_TerrainSourceCorrectAz->setMaximum(360);
        kcfg_TerrainSourceCorrectAz->setValue(0);

        terrainSourceCorrectAzLayout->addWidget(kcfg_TerrainSourceCorrectAz);

        spacerItem = new QSpacerItem(200, 16, QSizePolicy::Policy::Expanding, QSizePolicy::Policy::Minimum);

        terrainSourceCorrectAzLayout->addItem(spacerItem);


        vboxLayout1->addLayout(terrainSourceCorrectAzLayout);

        terrainSourceCorrectAltLayout = new QHBoxLayout();
        terrainSourceCorrectAltLayout->setObjectName("terrainSourceCorrectAltLayout");
        terrainSourceCorrectAltLabel = new QLabel(TerrainBox);
        terrainSourceCorrectAltLabel->setObjectName("terrainSourceCorrectAltLabel");
        sizePolicy.setHeightForWidth(terrainSourceCorrectAltLabel->sizePolicy().hasHeightForWidth());
        terrainSourceCorrectAltLabel->setSizePolicy(sizePolicy);

        terrainSourceCorrectAltLayout->addWidget(terrainSourceCorrectAltLabel);

        kcfg_TerrainSourceCorrectAlt = new QSpinBox(TerrainBox);
        kcfg_TerrainSourceCorrectAlt->setObjectName("kcfg_TerrainSourceCorrectAlt");
        sizePolicy2.setHeightForWidth(kcfg_TerrainSourceCorrectAlt->sizePolicy().hasHeightForWidth());
        kcfg_TerrainSourceCorrectAlt->setSizePolicy(sizePolicy2);
        kcfg_TerrainSourceCorrectAlt->setMinimum(-360);
        kcfg_TerrainSourceCorrectAlt->setMaximum(360);
        kcfg_TerrainSourceCorrectAlt->setValue(0);

        terrainSourceCorrectAltLayout->addWidget(kcfg_TerrainSourceCorrectAlt);

        spacerItem1 = new QSpacerItem(200, 16, QSizePolicy::Policy::Expanding, QSizePolicy::Policy::Minimum);

        terrainSourceCorrectAltLayout->addItem(spacerItem1);


        vboxLayout1->addLayout(terrainSourceCorrectAltLayout);


        vboxLayout->addLayout(vboxLayout1);


        terrainVerticalLayout_2->addWidget(TerrainBox);

        TerrainSpeedupGroupBox_2 = new QGroupBox(OpsTerrain);
        TerrainSpeedupGroupBox_2->setObjectName("TerrainSpeedupGroupBox_2");
        TerrainSpeedupVerticalLayout = new QVBoxLayout(TerrainSpeedupGroupBox_2);
        TerrainSpeedupVerticalLayout->setObjectName("TerrainSpeedupVerticalLayout");
        terrainDownsampleLayout = new QHBoxLayout();
        terrainDownsampleLayout->setObjectName("terrainDownsampleLayout");
        terrainDownsamplingLabel = new QLabel(TerrainSpeedupGroupBox_2);
        terrainDownsamplingLabel->setObjectName("terrainDownsamplingLabel");
        sizePolicy2.setHeightForWidth(terrainDownsamplingLabel->sizePolicy().hasHeightForWidth());
        terrainDownsamplingLabel->setSizePolicy(sizePolicy2);

        terrainDownsampleLayout->addWidget(terrainDownsamplingLabel);

        kcfg_TerrainDownsampling = new QSpinBox(TerrainSpeedupGroupBox_2);
        kcfg_TerrainDownsampling->setObjectName("kcfg_TerrainDownsampling");
        kcfg_TerrainDownsampling->setMinimum(1);
        kcfg_TerrainDownsampling->setMaximum(8);
        kcfg_TerrainDownsampling->setValue(4);

        terrainDownsampleLayout->addWidget(kcfg_TerrainDownsampling);

        spacerItem2 = new QSpacerItem(200, 16, QSizePolicy::Policy::Expanding, QSizePolicy::Policy::Minimum);

        terrainDownsampleLayout->addItem(spacerItem2);


        TerrainSpeedupVerticalLayout->addLayout(terrainDownsampleLayout);

        kcfg_TerrainPanning = new QCheckBox(TerrainSpeedupGroupBox_2);
        kcfg_TerrainPanning->setObjectName("kcfg_TerrainPanning");

        TerrainSpeedupVerticalLayout->addWidget(kcfg_TerrainPanning);

        kcfg_TerrainSmoothPixels = new QCheckBox(TerrainSpeedupGroupBox_2);
        kcfg_TerrainSmoothPixels->setObjectName("kcfg_TerrainSmoothPixels");

        TerrainSpeedupVerticalLayout->addWidget(kcfg_TerrainSmoothPixels);

        kcfg_TerrainSkipSpeedup = new QCheckBox(TerrainSpeedupGroupBox_2);
        kcfg_TerrainSkipSpeedup->setObjectName("kcfg_TerrainSkipSpeedup");

        TerrainSpeedupVerticalLayout->addWidget(kcfg_TerrainSkipSpeedup);

        kcfg_TerrainTransparencySpeedup = new QCheckBox(TerrainSpeedupGroupBox_2);
        kcfg_TerrainTransparencySpeedup->setObjectName("kcfg_TerrainTransparencySpeedup");

        TerrainSpeedupVerticalLayout->addWidget(kcfg_TerrainTransparencySpeedup);


        terrainVerticalLayout_2->addWidget(TerrainSpeedupGroupBox_2);

        spacerItem3 = new QSpacerItem(20, 16, QSizePolicy::Policy::Minimum, QSizePolicy::Policy::Expanding);

        terrainVerticalLayout_2->addItem(spacerItem3);

        QWidget::setTabOrder(kcfg_ShowTerrain, kcfg_TerrainSource);
        QWidget::setTabOrder(kcfg_TerrainSource, selectTerrainFileB);
        QWidget::setTabOrder(selectTerrainFileB, kcfg_TerrainSourceCorrectAz);
        QWidget::setTabOrder(kcfg_TerrainSourceCorrectAz, kcfg_TerrainSourceCorrectAlt);
        QWidget::setTabOrder(kcfg_TerrainSourceCorrectAlt, kcfg_TerrainDownsampling);
        QWidget::setTabOrder(kcfg_TerrainDownsampling, kcfg_TerrainPanning);
        QWidget::setTabOrder(kcfg_TerrainPanning, kcfg_TerrainSmoothPixels);
        QWidget::setTabOrder(kcfg_TerrainSmoothPixels, kcfg_TerrainSkipSpeedup);
        QWidget::setTabOrder(kcfg_TerrainSkipSpeedup, kcfg_TerrainTransparencySpeedup);

        retranslateUi(OpsTerrain);

        QMetaObject::connectSlotsByName(OpsTerrain);
    } // setupUi

    void retranslateUi(QWidget *OpsTerrain)
    {
        TerrainBox->setTitle(tr2i18n("Source Options", nullptr));
        kcfg_ShowTerrain->setText(tr2i18n("Show terrain", nullptr));
#if QT_CONFIG(whatsthis)
        terrainFileLabel->setWhatsThis(tr2i18n("Specify the terrain file to use.", nullptr));
#endif // QT_CONFIG(whatsthis)
        terrainFileLabel->setText(tr2i18n("Terrain file:", nullptr));
        selectTerrainFileB->setText(QString());
#if QT_CONFIG(tooltip)
        terrainSourceCorrectAzLabel->setToolTip(tr2i18n("Rotate terrain in azimuth degrees so north is actually north", nullptr));
#endif // QT_CONFIG(tooltip)
        terrainSourceCorrectAzLabel->setText(tr2i18n("Terrain image azimuth correction degrees:", nullptr));
#if QT_CONFIG(tooltip)
        kcfg_TerrainSourceCorrectAz->setToolTip(tr2i18n("Rotate terrain in azimuth degrees so north is actually north", nullptr));
#endif // QT_CONFIG(tooltip)
#if QT_CONFIG(tooltip)
        terrainSourceCorrectAltLabel->setToolTip(tr2i18n("Rotate terrain in altitude degrees so horizon is at 0 degrees altitude", nullptr));
#endif // QT_CONFIG(tooltip)
        terrainSourceCorrectAltLabel->setText(tr2i18n("Terrain image altitude correction degrees:", nullptr));
#if QT_CONFIG(tooltip)
        kcfg_TerrainSourceCorrectAlt->setToolTip(tr2i18n("Rotate terrain in altitude degrees so north is actually north", nullptr));
#endif // QT_CONFIG(tooltip)
        TerrainSpeedupGroupBox_2->setTitle(tr2i18n("Speedup options", nullptr));
#if QT_CONFIG(tooltip)
        terrainDownsamplingLabel->setToolTip(tr2i18n("Set the coarseness of the terrain image rendered. 1 is full resolution, but can be slow, 6 or more would be coarse resolution and fast.", nullptr));
#endif // QT_CONFIG(tooltip)
        terrainDownsamplingLabel->setText(tr2i18n("Terrain downsampling:", nullptr));
#if QT_CONFIG(tooltip)
        kcfg_TerrainDownsampling->setToolTip(tr2i18n("Set the coarseness of the terrain image rendered. 1 is full resolution, but can be slow, 6 or more would be coarse resolution and fast.", nullptr));
#endif // QT_CONFIG(tooltip)
        kcfg_TerrainPanning->setText(tr2i18n("Show terrain while panning", nullptr));
#if QT_CONFIG(tooltip)
        kcfg_TerrainSmoothPixels->setToolTip(tr2i18n("Creates a smoother image at the cost of some extra computation.", nullptr));
#endif // QT_CONFIG(tooltip)
        kcfg_TerrainSmoothPixels->setText(tr2i18n("Smooth pixels", nullptr));
#if QT_CONFIG(tooltip)
        kcfg_TerrainSkipSpeedup->setToolTip(tr2i18n("A speedup with minor image quality cost.", nullptr));
#endif // QT_CONFIG(tooltip)
        kcfg_TerrainSkipSpeedup->setText(tr2i18n("Skip pixels speedup", nullptr));
#if QT_CONFIG(tooltip)
        kcfg_TerrainTransparencySpeedup->setToolTip(tr2i18n("A speedup with minor image quality cost.", nullptr));
#endif // QT_CONFIG(tooltip)
        kcfg_TerrainTransparencySpeedup->setText(tr2i18n("Transparency speedup", nullptr));
        (void)OpsTerrain;
    } // retranslateUi

};

namespace Ui {
    class OpsTerrain: public Ui_OpsTerrain {};
} // namespace Ui

QT_END_NAMESPACE

#endif // OPSTERRAIN_H

