/********************************************************************************
** Form generated from reading UI file 'opsjobssettings.ui'
**
** Created by: Qt User Interface Compiler version 6.11.1
**
** WARNING! All changes made in this file will be lost when recompiling UI file!
********************************************************************************/

#ifndef UI_OPSJOBSSETTINGS_H
#define UI_OPSJOBSSETTINGS_H

#include <QtCore/QVariant>
#include <QtWidgets/QApplication>
#include <QtWidgets/QCheckBox>
#include <QtWidgets/QSpacerItem>
#include <QtWidgets/QVBoxLayout>
#include <QtWidgets/QWidget>
#include <klocalizedstring.h>

QT_BEGIN_NAMESPACE

class Ui_OpsJobsSettings
{
public:
    QVBoxLayout *verticalLayout;
    QCheckBox *kcfg_RememberJobProgress;
    QCheckBox *kcfg_GreedyScheduling;
    QSpacerItem *verticalSpacer;

    void setupUi(QWidget *OpsJobsSettings)
    {
        if (OpsJobsSettings->objectName().isEmpty())
            OpsJobsSettings->setObjectName("OpsJobsSettings");
        OpsJobsSettings->resize(168, 58);
        OpsJobsSettings->setProperty("currentIndex", QVariant(0));
        verticalLayout = new QVBoxLayout(OpsJobsSettings);
        verticalLayout->setSpacing(3);
        verticalLayout->setObjectName("verticalLayout");
        verticalLayout->setContentsMargins(3, 3, 3, 3);
        kcfg_RememberJobProgress = new QCheckBox(OpsJobsSettings);
        kcfg_RememberJobProgress->setObjectName("kcfg_RememberJobProgress");
        kcfg_RememberJobProgress->setChecked(false);

        verticalLayout->addWidget(kcfg_RememberJobProgress);

        kcfg_GreedyScheduling = new QCheckBox(OpsJobsSettings);
        kcfg_GreedyScheduling->setObjectName("kcfg_GreedyScheduling");
        kcfg_GreedyScheduling->setChecked(true);

        verticalLayout->addWidget(kcfg_GreedyScheduling);

        verticalSpacer = new QSpacerItem(20, 40, QSizePolicy::Policy::Minimum, QSizePolicy::Policy::Expanding);

        verticalLayout->addItem(verticalSpacer);


        retranslateUi(OpsJobsSettings);

        QMetaObject::connectSlotsByName(OpsJobsSettings);
    } // setupUi

    void retranslateUi(QWidget *OpsJobsSettings)
    {
        OpsJobsSettings->setWindowTitle(tr2i18n("TabWidget", nullptr));
#if QT_CONFIG(tooltip)
        kcfg_RememberJobProgress->setToolTip(tr2i18n("<html><head/><body><p>When processing a scheduled job, resume the sequence starting from the last image present in storage.</p></body></html>", nullptr));
#endif // QT_CONFIG(tooltip)
        kcfg_RememberJobProgress->setText(tr2i18n("Remember job progress", nullptr));
#if QT_CONFIG(tooltip)
        kcfg_GreedyScheduling->setToolTip(tr2i18n("<html><head/><body><p>When checked the scheduler tries to run lower priority jobs when no higher priority job can run. Recommended.</p></body></html>", nullptr));
#endif // QT_CONFIG(tooltip)
        kcfg_GreedyScheduling->setText(tr2i18n("Use greedy scheduling", nullptr));
    } // retranslateUi

};

namespace Ui {
    class OpsJobsSettings: public Ui_OpsJobsSettings {};
} // namespace Ui

QT_END_NAMESPACE

#endif // OPSJOBSSETTINGS_H

