/****************************************************************************
** Meta object code from reading C++ file 'mount.h'
**
** Created by: The Qt Meta Object Compiler version 69 (Qt 6.11.1)
**
** WARNING! All changes made in this file will be lost!
*****************************************************************************/

#include "../../../../kstars-3.8.4.1/kstars/ekos/mount/mount.h"
#include <QtCore/qmetatype.h>
#include <QtCore/QList>

#include <QtCore/qtmochelpers.h>

#include <memory>


#include <QtCore/qxptype_traits.h>
#if !defined(Q_MOC_OUTPUT_REVISION)
#error "The header file 'mount.h' doesn't include <QObject>."
#elif Q_MOC_OUTPUT_REVISION != 69
#error "This file was generated using the moc from 6.11.1. It"
#error "cannot be used with the include files from this version of Qt."
#error "(The moc has changed too much.)"
#endif

#ifndef Q_CONSTINIT
#define Q_CONSTINIT
#endif

QT_WARNING_PUSH
QT_WARNING_DISABLE_DEPRECATED
QT_WARNING_DISABLE_GCC("-Wuseless-cast")
namespace {
struct qt_meta_tag_ZN4Ekos5MountE_t {};
} // unnamed namespace

template <> constexpr inline auto Ekos::Mount::qt_create_metaobjectdata<qt_meta_tag_ZN4Ekos5MountE_t>()
{
    namespace QMC = QtMocConstants;
    QtMocHelpers::StringRefStorage qt_stringData {
        "Ekos::Mount",
        "D-Bus Interface",
        "org.kde.kstars.Ekos.Mount",
        "newLog",
        "",
        "text",
        "newCoords",
        "SkyPoint",
        "position",
        "ISD::Mount::PierSide",
        "pierSide",
        "dms",
        "ha",
        "newTarget",
        "SkyPoint&",
        "currentCoord",
        "newTargetName",
        "name",
        "newStatus",
        "ISD::Mount::Status",
        "status",
        "newParkStatus",
        "ISD::ParkStatus",
        "pierSideChanged",
        "side",
        "slewRateChanged",
        "index",
        "ready",
        "newMeridianFlipText",
        "autoParkCountdownUpdated",
        "settingsUpdated",
        "QVariantMap",
        "settings",
        "trainChanged",
        "syncTelescopeInfo",
        "updateProperty",
        "INDI::Property",
        "prop",
        "updateLog",
        "messageID",
        "updateTelescopeCoords",
        "motionCommand",
        "command",
        "NS",
        "WE",
        "doPulse",
        "GuideDirection",
        "ra_dir",
        "ra_msecs",
        "dec_dir",
        "dec_msecs",
        "saveLimits",
        "setAltitudeLimits",
        "enable",
        "resumeAltLimits",
        "suspendAltLimits",
        "enableHourAngleLimits",
        "enableHaLimits",
        "disableHaLimits",
        "toggleMountToolBox",
        "setMeridianFlipValues",
        "activate",
        "degrees",
        "paaStageChanged",
        "stage",
        "registerNewModule",
        "gotoTarget",
        "target",
        "setTargetName",
        "syncAxisReversed",
        "INDI_EQ_AXIS",
        "axis",
        "reversed",
        "stopTimers",
        "syncTimeSource",
        "syncLocationSource",
        "startParkTimer",
        "stopParkTimer",
        "startAutoPark",
        "altitudeLimits",
        "QList<double>",
        "Q_NOREPLY",
        "limits",
        "setAltitudeLimitsEnabled",
        "altitudeLimitsEnabled",
        "hourAngleLimit",
        "setHourAngleLimit",
        "limit",
        "setHourAngleLimitEnabled",
        "hourAngleLimitEnabled",
        "autoParkEnabled",
        "setAutoParkEnabled",
        "setAutoParkDailyEnabled",
        "enabled",
        "setAutoParkStartup",
        "startup",
        "meridianFlipEnabled",
        "meridianFlipValue",
        "slew",
        "RA",
        "DEC",
        "sync",
        "syncTarget",
        "equatorialCoords",
        "horizontalCoords",
        "currentTarget",
        "hourAngle",
        "initialHA",
        "abort",
        "slewStatus",
        "IPState",
        "slewRate",
        "setSlewRate",
        "resetModel",
        "alignmentModel",
        "canPark",
        "park",
        "unpark",
        "setTrackEnabled",
        "setJ2000Enabled",
        "raDecToAzAlt",
        "qsRA",
        "qsDec",
        "raDecToHaDec",
        "azAltToRaDec",
        "qsAz",
        "qsAlt",
        "azAltToHaDec",
        "haDecToRaDec",
        "qsHA",
        "haDecToAzAlt",
        "centerMount",
        "setUpDownReversed",
        "setLeftRightReversed",
        "timeSources",
        "locationSources",
        "opticalTrain",
        "parkStatus",
        "logText"
    };

    QtMocHelpers::UintData qt_methods {
        // Signal 'newLog'
        QtMocHelpers::SignalData<void(const QString &)>(3, 4, QMC::AccessPublic, QMetaType::Void, {{
            { QMetaType::QString, 5 },
        }}),
        // Signal 'newCoords'
        QtMocHelpers::SignalData<void(const SkyPoint &, ISD::Mount::PierSide, const dms &)>(6, 4, QMC::AccessPublic, QMetaType::Void, {{
            { 0x80000000 | 7, 8 }, { 0x80000000 | 9, 10 }, { 0x80000000 | 11, 12 },
        }}),
        // Signal 'newTarget'
        QtMocHelpers::SignalData<void(SkyPoint &)>(13, 4, QMC::AccessPublic, QMetaType::Void, {{
            { 0x80000000 | 14, 15 },
        }}),
        // Signal 'newTargetName'
        QtMocHelpers::SignalData<void(const QString &)>(16, 4, QMC::AccessPublic, QMetaType::Void, {{
            { QMetaType::QString, 17 },
        }}),
        // Signal 'newStatus'
        QtMocHelpers::SignalData<void(ISD::Mount::Status)>(18, 4, QMC::AccessPublic, QMetaType::Void, {{
            { 0x80000000 | 19, 20 },
        }}),
        // Signal 'newParkStatus'
        QtMocHelpers::SignalData<void(ISD::ParkStatus)>(21, 4, QMC::AccessPublic, QMetaType::Void, {{
            { 0x80000000 | 22, 20 },
        }}),
        // Signal 'pierSideChanged'
        QtMocHelpers::SignalData<void(ISD::Mount::PierSide)>(23, 4, QMC::AccessPublic, QMetaType::Void, {{
            { 0x80000000 | 9, 24 },
        }}),
        // Signal 'slewRateChanged'
        QtMocHelpers::SignalData<void(int)>(25, 4, QMC::AccessPublic, QMetaType::Void, {{
            { QMetaType::Int, 26 },
        }}),
        // Signal 'ready'
        QtMocHelpers::SignalData<void()>(27, 4, QMC::AccessPublic, QMetaType::Void),
        // Signal 'newMeridianFlipText'
        QtMocHelpers::SignalData<void(const QString &)>(28, 4, QMC::AccessPublic, QMetaType::Void, {{
            { QMetaType::QString, 5 },
        }}),
        // Signal 'autoParkCountdownUpdated'
        QtMocHelpers::SignalData<void(const QString &)>(29, 4, QMC::AccessPublic, QMetaType::Void, {{
            { QMetaType::QString, 5 },
        }}),
        // Signal 'settingsUpdated'
        QtMocHelpers::SignalData<void(const QVariantMap &)>(30, 4, QMC::AccessPublic, QMetaType::Void, {{
            { 0x80000000 | 31, 32 },
        }}),
        // Signal 'trainChanged'
        QtMocHelpers::SignalData<void()>(33, 4, QMC::AccessPublic, QMetaType::Void),
        // Slot 'syncTelescopeInfo'
        QtMocHelpers::SlotData<void()>(34, 4, QMC::AccessPublic, QMetaType::Void),
        // Slot 'updateProperty'
        QtMocHelpers::SlotData<void(INDI::Property)>(35, 4, QMC::AccessPublic, QMetaType::Void, {{
            { 0x80000000 | 36, 37 },
        }}),
        // Slot 'updateLog'
        QtMocHelpers::SlotData<void(int)>(38, 4, QMC::AccessPublic, QMetaType::Void, {{
            { QMetaType::Int, 39 },
        }}),
        // Slot 'updateTelescopeCoords'
        QtMocHelpers::SlotData<void(const SkyPoint &, ISD::Mount::PierSide, const dms &)>(40, 4, QMC::AccessPublic, QMetaType::Void, {{
            { 0x80000000 | 7, 8 }, { 0x80000000 | 9, 10 }, { 0x80000000 | 11, 12 },
        }}),
        // Slot 'motionCommand'
        QtMocHelpers::SlotData<void(int, int, int)>(41, 4, QMC::AccessPublic, QMetaType::Void, {{
            { QMetaType::Int, 42 }, { QMetaType::Int, 43 }, { QMetaType::Int, 44 },
        }}),
        // Slot 'doPulse'
        QtMocHelpers::SlotData<void(GuideDirection, int, GuideDirection, int)>(45, 4, QMC::AccessPublic, QMetaType::Void, {{
            { 0x80000000 | 46, 47 }, { QMetaType::Int, 48 }, { 0x80000000 | 46, 49 }, { QMetaType::Int, 50 },
        }}),
        // Slot 'saveLimits'
        QtMocHelpers::SlotData<void()>(51, 4, QMC::AccessPublic, QMetaType::Void),
        // Slot 'setAltitudeLimits'
        QtMocHelpers::SlotData<void(bool)>(52, 4, QMC::AccessPublic, QMetaType::Void, {{
            { QMetaType::Bool, 53 },
        }}),
        // Slot 'resumeAltLimits'
        QtMocHelpers::SlotData<void()>(54, 4, QMC::AccessPublic, QMetaType::Void),
        // Slot 'suspendAltLimits'
        QtMocHelpers::SlotData<void()>(55, 4, QMC::AccessPublic, QMetaType::Void),
        // Slot 'enableHourAngleLimits'
        QtMocHelpers::SlotData<void(bool)>(56, 4, QMC::AccessPublic, QMetaType::Void, {{
            { QMetaType::Bool, 53 },
        }}),
        // Slot 'enableHaLimits'
        QtMocHelpers::SlotData<void()>(57, 4, QMC::AccessPublic, QMetaType::Void),
        // Slot 'disableHaLimits'
        QtMocHelpers::SlotData<void()>(58, 4, QMC::AccessPublic, QMetaType::Void),
        // Slot 'toggleMountToolBox'
        QtMocHelpers::SlotData<void()>(59, 4, QMC::AccessPublic, QMetaType::Void),
        // Slot 'setMeridianFlipValues'
        QtMocHelpers::SlotData<void(bool, double)>(60, 4, QMC::AccessPublic, QMetaType::Void, {{
            { QMetaType::Bool, 61 }, { QMetaType::Double, 62 },
        }}),
        // Slot 'paaStageChanged'
        QtMocHelpers::SlotData<void(int)>(63, 4, QMC::AccessPublic, QMetaType::Void, {{
            { QMetaType::Int, 64 },
        }}),
        // Slot 'registerNewModule'
        QtMocHelpers::SlotData<void(const QString &)>(65, 4, QMC::AccessPublic, QMetaType::Void, {{
            { QMetaType::QString, 17 },
        }}),
        // Slot 'gotoTarget'
        QtMocHelpers::SlotData<bool(const SkyPoint &)>(66, 4, QMC::AccessPublic, QMetaType::Bool, {{
            { 0x80000000 | 7, 67 },
        }}),
        // Slot 'setTargetName'
        QtMocHelpers::SlotData<void(const QString &)>(68, 4, QMC::AccessPublic, QMetaType::Void, {{
            { QMetaType::QString, 17 },
        }}),
        // Slot 'syncAxisReversed'
        QtMocHelpers::SlotData<void(INDI_EQ_AXIS, bool)>(69, 4, QMC::AccessPublic, QMetaType::Void, {{
            { 0x80000000 | 70, 71 }, { QMetaType::Bool, 72 },
        }}),
        // Slot 'stopTimers'
        QtMocHelpers::SlotData<void()>(73, 4, QMC::AccessPublic, QMetaType::Void),
        // Slot 'syncTimeSource'
        QtMocHelpers::SlotData<void()>(74, 4, QMC::AccessPublic, QMetaType::Void),
        // Slot 'syncLocationSource'
        QtMocHelpers::SlotData<void()>(75, 4, QMC::AccessPublic, QMetaType::Void),
        // Slot 'startParkTimer'
        QtMocHelpers::SlotData<void()>(76, 4, QMC::AccessPrivate, QMetaType::Void),
        // Slot 'stopParkTimer'
        QtMocHelpers::SlotData<void()>(77, 4, QMC::AccessPrivate, QMetaType::Void),
        // Slot 'startAutoPark'
        QtMocHelpers::SlotData<void()>(78, 4, QMC::AccessPrivate, QMetaType::Void),
        // Method 'altitudeLimits'
        QtMocHelpers::MethodData<QList<double>()>(79, 4, QMC::AccessPublic | QMC::MethodScriptable, 0x80000000 | 80),
        // Method 'setAltitudeLimits'
        QtMocHelpers::MethodData<void(QList<double>)>(52, 81, QMC::AccessPublic | QMC::MethodScriptable, QMetaType::Void, {{
            { 0x80000000 | 80, 82 },
        }}),
        // Method 'setAltitudeLimitsEnabled'
        QtMocHelpers::MethodData<void(bool)>(83, 4, QMC::AccessPublic | QMC::MethodScriptable, QMetaType::Void, {{
            { QMetaType::Bool, 53 },
        }}),
        // Method 'altitudeLimitsEnabled'
        QtMocHelpers::MethodData<bool()>(84, 4, QMC::AccessPublic | QMC::MethodScriptable, QMetaType::Bool),
        // Method 'hourAngleLimit'
        QtMocHelpers::MethodData<double()>(85, 4, QMC::AccessPublic | QMC::MethodScriptable, QMetaType::Double),
        // Method 'setHourAngleLimit'
        QtMocHelpers::MethodData<void(double)>(86, 81, QMC::AccessPublic | QMC::MethodScriptable, QMetaType::Void, {{
            { QMetaType::Double, 87 },
        }}),
        // Method 'setHourAngleLimitEnabled'
        QtMocHelpers::MethodData<void(bool)>(88, 4, QMC::AccessPublic | QMC::MethodScriptable, QMetaType::Void, {{
            { QMetaType::Bool, 53 },
        }}),
        // Method 'hourAngleLimitEnabled'
        QtMocHelpers::MethodData<bool()>(89, 4, QMC::AccessPublic | QMC::MethodScriptable, QMetaType::Bool),
        // Method 'autoParkEnabled'
        QtMocHelpers::MethodData<bool()>(90, 4, QMC::AccessPublic | QMC::MethodScriptable, QMetaType::Bool),
        // Method 'setAutoParkEnabled'
        QtMocHelpers::MethodData<void(bool)>(91, 4, QMC::AccessPublic | QMC::MethodScriptable, QMetaType::Void, {{
            { QMetaType::Bool, 53 },
        }}),
        // Method 'setAutoParkDailyEnabled'
        QtMocHelpers::MethodData<void(bool)>(92, 4, QMC::AccessPublic | QMC::MethodScriptable, QMetaType::Void, {{
            { QMetaType::Bool, 93 },
        }}),
        // Method 'setAutoParkStartup'
        QtMocHelpers::MethodData<void(QTime)>(94, 4, QMC::AccessPublic | QMC::MethodScriptable, QMetaType::Void, {{
            { QMetaType::QTime, 95 },
        }}),
        // Method 'meridianFlipEnabled'
        QtMocHelpers::MethodData<bool()>(96, 4, QMC::AccessPublic | QMC::MethodScriptable, QMetaType::Bool),
        // Method 'meridianFlipValue'
        QtMocHelpers::MethodData<double()>(97, 4, QMC::AccessPublic | QMC::MethodScriptable, QMetaType::Double),
        // Method 'slew'
        QtMocHelpers::MethodData<bool(double, double)>(98, 4, QMC::AccessPublic | QMC::MethodScriptable, QMetaType::Bool, {{
            { QMetaType::Double, 99 }, { QMetaType::Double, 100 },
        }}),
        // Method 'gotoTarget'
        QtMocHelpers::MethodData<bool(const QString &)>(66, 4, QMC::AccessPublic | QMC::MethodScriptable, QMetaType::Bool, {{
            { QMetaType::QString, 67 },
        }}),
        // Method 'sync'
        QtMocHelpers::MethodData<bool(double, double)>(101, 4, QMC::AccessPublic | QMC::MethodScriptable, QMetaType::Bool, {{
            { QMetaType::Double, 99 }, { QMetaType::Double, 100 },
        }}),
        // Method 'syncTarget'
        QtMocHelpers::MethodData<bool(const QString &)>(102, 4, QMC::AccessPublic | QMC::MethodScriptable, QMetaType::Bool, {{
            { QMetaType::QString, 67 },
        }}),
        // Method 'equatorialCoords'
        QtMocHelpers::MethodData<QList<double>()>(103, 4, QMC::AccessPublic | QMC::MethodScriptable, 0x80000000 | 80),
        // Method 'horizontalCoords'
        QtMocHelpers::MethodData<QList<double>()>(104, 4, QMC::AccessPublic | QMC::MethodScriptable, 0x80000000 | 80),
        // Method 'currentTarget'
        QtMocHelpers::MethodData<SkyPoint()>(105, 4, QMC::AccessPublic | QMC::MethodScriptable, 0x80000000 | 7),
        // Method 'hourAngle'
        QtMocHelpers::MethodData<double()>(106, 4, QMC::AccessPublic | QMC::MethodScriptable, QMetaType::Double),
        // Method 'initialHA'
        QtMocHelpers::MethodData<double()>(107, 4, QMC::AccessPublic | QMC::MethodScriptable, QMetaType::Double),
        // Method 'abort'
        QtMocHelpers::MethodData<bool()>(108, 4, QMC::AccessPublic | QMC::MethodScriptable, QMetaType::Bool),
        // Method 'slewStatus'
        QtMocHelpers::MethodData<IPState()>(109, 4, QMC::AccessPublic | QMC::MethodScriptable, 0x80000000 | 110),
        // Method 'slewRate'
        QtMocHelpers::MethodData<int()>(111, 4, QMC::AccessPublic | QMC::MethodScriptable, QMetaType::Int),
        // Method 'setSlewRate'
        QtMocHelpers::MethodData<bool(int)>(112, 4, QMC::AccessPublic | QMC::MethodScriptable, QMetaType::Bool, {{
            { QMetaType::Int, 26 },
        }}),
        // Method 'resetModel'
        QtMocHelpers::MethodData<bool()>(113, 4, QMC::AccessPublic | QMC::MethodScriptable, QMetaType::Bool),
        // Method 'alignmentModel'
        QtMocHelpers::MethodData<QVariantMap()>(114, 4, QMC::AccessPublic | QMC::MethodScriptable, 0x80000000 | 31),
        // Method 'canPark'
        QtMocHelpers::MethodData<bool()>(115, 4, QMC::AccessPublic | QMC::MethodScriptable, QMetaType::Bool),
        // Method 'park'
        QtMocHelpers::MethodData<bool()>(116, 4, QMC::AccessPublic | QMC::MethodScriptable, QMetaType::Bool),
        // Method 'unpark'
        QtMocHelpers::MethodData<bool()>(117, 4, QMC::AccessPublic | QMC::MethodScriptable, QMetaType::Bool),
        // Method 'setTrackEnabled'
        QtMocHelpers::MethodData<void(bool)>(118, 4, QMC::AccessPublic, QMetaType::Void, {{
            { QMetaType::Bool, 93 },
        }}),
        // Method 'setJ2000Enabled'
        QtMocHelpers::MethodData<void(bool)>(119, 4, QMC::AccessPublic, QMetaType::Void, {{
            { QMetaType::Bool, 93 },
        }}),
        // Method 'raDecToAzAlt'
        QtMocHelpers::MethodData<bool(QString, QString)>(120, 4, QMC::AccessPublic, QMetaType::Bool, {{
            { QMetaType::QString, 121 }, { QMetaType::QString, 122 },
        }}),
        // Method 'raDecToHaDec'
        QtMocHelpers::MethodData<bool(QString)>(123, 4, QMC::AccessPublic, QMetaType::Bool, {{
            { QMetaType::QString, 121 },
        }}),
        // Method 'azAltToRaDec'
        QtMocHelpers::MethodData<bool(QString, QString)>(124, 4, QMC::AccessPublic, QMetaType::Bool, {{
            { QMetaType::QString, 125 }, { QMetaType::QString, 126 },
        }}),
        // Method 'azAltToHaDec'
        QtMocHelpers::MethodData<bool(QString, QString)>(127, 4, QMC::AccessPublic, QMetaType::Bool, {{
            { QMetaType::QString, 125 }, { QMetaType::QString, 126 },
        }}),
        // Method 'haDecToRaDec'
        QtMocHelpers::MethodData<bool(QString)>(128, 4, QMC::AccessPublic, QMetaType::Bool, {{
            { QMetaType::QString, 129 },
        }}),
        // Method 'haDecToAzAlt'
        QtMocHelpers::MethodData<bool(QString, QString)>(130, 4, QMC::AccessPublic, QMetaType::Bool, {{
            { QMetaType::QString, 129 }, { QMetaType::QString, 122 },
        }}),
        // Method 'centerMount'
        QtMocHelpers::MethodData<void()>(131, 4, QMC::AccessPublic, QMetaType::Void),
        // Method 'setUpDownReversed'
        QtMocHelpers::MethodData<void(bool)>(132, 4, QMC::AccessPublic, QMetaType::Void, {{
            { QMetaType::Bool, 93 },
        }}),
        // Method 'setLeftRightReversed'
        QtMocHelpers::MethodData<void(bool)>(133, 4, QMC::AccessPublic, QMetaType::Void, {{
            { QMetaType::Bool, 93 },
        }}),
        // Method 'timeSources'
        QtMocHelpers::MethodData<QStringList()>(134, 4, QMC::AccessPublic, QMetaType::QStringList),
        // Method 'locationSources'
        QtMocHelpers::MethodData<QStringList()>(135, 4, QMC::AccessPublic, QMetaType::QStringList),
    };
    QtMocHelpers::UintData qt_properties {
        // property 'opticalTrain'
        QtMocHelpers::PropertyData<QString>(136, QMetaType::QString, QMC::DefaultPropertyFlags | QMC::Writable | QMC::StdCppSet),
        // property 'status'
        QtMocHelpers::PropertyData<ISD::Mount::Status>(20, 0x80000000 | 19, QMC::DefaultPropertyFlags | QMC::EnumOrFlag, 4),
        // property 'parkStatus'
        QtMocHelpers::PropertyData<ISD::ParkStatus>(137, 0x80000000 | 22, QMC::DefaultPropertyFlags | QMC::EnumOrFlag, 5),
        // property 'logText'
        QtMocHelpers::PropertyData<QStringList>(138, QMetaType::QStringList, QMC::DefaultPropertyFlags, 0),
        // property 'altitudeLimits'
        QtMocHelpers::PropertyData<QList<double>>(79, 0x80000000 | 80, QMC::DefaultPropertyFlags | QMC::Writable | QMC::EnumOrFlag | QMC::StdCppSet),
        // property 'altitudeLimitsEnabled'
        QtMocHelpers::PropertyData<bool>(84, QMetaType::Bool, QMC::DefaultPropertyFlags | QMC::Writable | QMC::StdCppSet),
        // property 'hourAngleLimit'
        QtMocHelpers::PropertyData<double>(85, QMetaType::Double, QMC::DefaultPropertyFlags | QMC::Writable | QMC::StdCppSet),
        // property 'hourAngleLimitEnabled'
        QtMocHelpers::PropertyData<bool>(89, QMetaType::Bool, QMC::DefaultPropertyFlags | QMC::Writable | QMC::StdCppSet),
        // property 'autoParkEnabled'
        QtMocHelpers::PropertyData<bool>(90, QMetaType::Bool, QMC::DefaultPropertyFlags | QMC::Writable | QMC::StdCppSet),
        // property 'equatorialCoords'
        QtMocHelpers::PropertyData<QList<double>>(103, 0x80000000 | 80, QMC::DefaultPropertyFlags | QMC::EnumOrFlag),
        // property 'horizontalCoords'
        QtMocHelpers::PropertyData<QList<double>>(104, 0x80000000 | 80, QMC::DefaultPropertyFlags | QMC::EnumOrFlag),
        // property 'hourAngle'
        QtMocHelpers::PropertyData<double>(106, QMetaType::Double, QMC::DefaultPropertyFlags),
        // property 'slewRate'
        QtMocHelpers::PropertyData<int>(111, QMetaType::Int, QMC::DefaultPropertyFlags | QMC::Writable | QMC::StdCppSet),
        // property 'slewStatus'
        QtMocHelpers::PropertyData<int>(109, QMetaType::Int, QMC::DefaultPropertyFlags),
        // property 'canPark'
        QtMocHelpers::PropertyData<bool>(115, QMetaType::Bool, QMC::DefaultPropertyFlags),
        // property 'pierSide'
        QtMocHelpers::PropertyData<ISD::Mount::PierSide>(10, 0x80000000 | 9, QMC::DefaultPropertyFlags | QMC::EnumOrFlag, 6),
        // property 'timeSources'
        QtMocHelpers::PropertyData<QStringList>(134, QMetaType::QStringList, QMC::DefaultPropertyFlags),
        // property 'locationSources'
        QtMocHelpers::PropertyData<QStringList>(135, QMetaType::QStringList, QMC::DefaultPropertyFlags),
    };
    QtMocHelpers::UintData qt_enums {
    };
    QtMocHelpers::UintData qt_constructors {};
    QtMocHelpers::ClassInfos qt_classinfo({
            {    1,    2 },
    });
    return QtMocHelpers::metaObjectData<Mount, qt_meta_tag_ZN4Ekos5MountE_t>(QMC::MetaObjectFlag{}, qt_stringData,
            qt_methods, qt_properties, qt_enums, qt_constructors, qt_classinfo);
}
Q_CONSTINIT static const QMetaObject::SuperData qt_meta_extradata_ZN4Ekos5MountE[] = {
    QMetaObject::SuperData::link<ISD::Mount::staticMetaObject>(),
    nullptr
};

Q_CONSTINIT const QMetaObject Ekos::Mount::staticMetaObject = { {
    QMetaObject::SuperData::link<QWidget::staticMetaObject>(),
    qt_staticMetaObjectStaticContent<qt_meta_tag_ZN4Ekos5MountE_t>.stringdata,
    qt_staticMetaObjectStaticContent<qt_meta_tag_ZN4Ekos5MountE_t>.data,
    qt_static_metacall,
    qt_meta_extradata_ZN4Ekos5MountE,
    qt_staticMetaObjectRelocatingContent<qt_meta_tag_ZN4Ekos5MountE_t>.metaTypes,
    nullptr
} };

void Ekos::Mount::qt_static_metacall(QObject *_o, QMetaObject::Call _c, int _id, void **_a)
{
    auto *_t = static_cast<Mount *>(_o);
    if (_c == QMetaObject::InvokeMetaMethod) {
        switch (_id) {
        case 0: _t->newLog((*reinterpret_cast<std::add_pointer_t<QString>>(_a[1]))); break;
        case 1: _t->newCoords((*reinterpret_cast<std::add_pointer_t<SkyPoint>>(_a[1])),(*reinterpret_cast<std::add_pointer_t<ISD::Mount::PierSide>>(_a[2])),(*reinterpret_cast<std::add_pointer_t<dms>>(_a[3]))); break;
        case 2: _t->newTarget((*reinterpret_cast<std::add_pointer_t<SkyPoint&>>(_a[1]))); break;
        case 3: _t->newTargetName((*reinterpret_cast<std::add_pointer_t<QString>>(_a[1]))); break;
        case 4: _t->newStatus((*reinterpret_cast<std::add_pointer_t<ISD::Mount::Status>>(_a[1]))); break;
        case 5: _t->newParkStatus((*reinterpret_cast<std::add_pointer_t<ISD::ParkStatus>>(_a[1]))); break;
        case 6: _t->pierSideChanged((*reinterpret_cast<std::add_pointer_t<ISD::Mount::PierSide>>(_a[1]))); break;
        case 7: _t->slewRateChanged((*reinterpret_cast<std::add_pointer_t<int>>(_a[1]))); break;
        case 8: _t->ready(); break;
        case 9: _t->newMeridianFlipText((*reinterpret_cast<std::add_pointer_t<QString>>(_a[1]))); break;
        case 10: _t->autoParkCountdownUpdated((*reinterpret_cast<std::add_pointer_t<QString>>(_a[1]))); break;
        case 11: _t->settingsUpdated((*reinterpret_cast<std::add_pointer_t<QVariantMap>>(_a[1]))); break;
        case 12: _t->trainChanged(); break;
        case 13: _t->syncTelescopeInfo(); break;
        case 14: _t->updateProperty((*reinterpret_cast<std::add_pointer_t<INDI::Property>>(_a[1]))); break;
        case 15: _t->updateLog((*reinterpret_cast<std::add_pointer_t<int>>(_a[1]))); break;
        case 16: _t->updateTelescopeCoords((*reinterpret_cast<std::add_pointer_t<SkyPoint>>(_a[1])),(*reinterpret_cast<std::add_pointer_t<ISD::Mount::PierSide>>(_a[2])),(*reinterpret_cast<std::add_pointer_t<dms>>(_a[3]))); break;
        case 17: _t->motionCommand((*reinterpret_cast<std::add_pointer_t<int>>(_a[1])),(*reinterpret_cast<std::add_pointer_t<int>>(_a[2])),(*reinterpret_cast<std::add_pointer_t<int>>(_a[3]))); break;
        case 18: _t->doPulse((*reinterpret_cast<std::add_pointer_t<GuideDirection>>(_a[1])),(*reinterpret_cast<std::add_pointer_t<int>>(_a[2])),(*reinterpret_cast<std::add_pointer_t<GuideDirection>>(_a[3])),(*reinterpret_cast<std::add_pointer_t<int>>(_a[4]))); break;
        case 19: _t->saveLimits(); break;
        case 20: _t->setAltitudeLimits((*reinterpret_cast<std::add_pointer_t<bool>>(_a[1]))); break;
        case 21: _t->resumeAltLimits(); break;
        case 22: _t->suspendAltLimits(); break;
        case 23: _t->enableHourAngleLimits((*reinterpret_cast<std::add_pointer_t<bool>>(_a[1]))); break;
        case 24: _t->enableHaLimits(); break;
        case 25: _t->disableHaLimits(); break;
        case 26: _t->toggleMountToolBox(); break;
        case 27: _t->setMeridianFlipValues((*reinterpret_cast<std::add_pointer_t<bool>>(_a[1])),(*reinterpret_cast<std::add_pointer_t<double>>(_a[2]))); break;
        case 28: _t->paaStageChanged((*reinterpret_cast<std::add_pointer_t<int>>(_a[1]))); break;
        case 29: _t->registerNewModule((*reinterpret_cast<std::add_pointer_t<QString>>(_a[1]))); break;
        case 30: { bool _r = _t->gotoTarget((*reinterpret_cast<std::add_pointer_t<SkyPoint>>(_a[1])));
            if (_a[0]) *reinterpret_cast<bool*>(_a[0]) = std::move(_r); }  break;
        case 31: _t->setTargetName((*reinterpret_cast<std::add_pointer_t<QString>>(_a[1]))); break;
        case 32: _t->syncAxisReversed((*reinterpret_cast<std::add_pointer_t<INDI_EQ_AXIS>>(_a[1])),(*reinterpret_cast<std::add_pointer_t<bool>>(_a[2]))); break;
        case 33: _t->stopTimers(); break;
        case 34: _t->syncTimeSource(); break;
        case 35: _t->syncLocationSource(); break;
        case 36: _t->startParkTimer(); break;
        case 37: _t->stopParkTimer(); break;
        case 38: _t->startAutoPark(); break;
        case 39: { QList<double> _r = _t->altitudeLimits();
            if (_a[0]) *reinterpret_cast<QList<double>*>(_a[0]) = std::move(_r); }  break;
        case 40: _t->setAltitudeLimits((*reinterpret_cast<std::add_pointer_t<QList<double>>>(_a[1]))); break;
        case 41: _t->setAltitudeLimitsEnabled((*reinterpret_cast<std::add_pointer_t<bool>>(_a[1]))); break;
        case 42: { bool _r = _t->altitudeLimitsEnabled();
            if (_a[0]) *reinterpret_cast<bool*>(_a[0]) = std::move(_r); }  break;
        case 43: { double _r = _t->hourAngleLimit();
            if (_a[0]) *reinterpret_cast<double*>(_a[0]) = std::move(_r); }  break;
        case 44: _t->setHourAngleLimit((*reinterpret_cast<std::add_pointer_t<double>>(_a[1]))); break;
        case 45: _t->setHourAngleLimitEnabled((*reinterpret_cast<std::add_pointer_t<bool>>(_a[1]))); break;
        case 46: { bool _r = _t->hourAngleLimitEnabled();
            if (_a[0]) *reinterpret_cast<bool*>(_a[0]) = std::move(_r); }  break;
        case 47: { bool _r = _t->autoParkEnabled();
            if (_a[0]) *reinterpret_cast<bool*>(_a[0]) = std::move(_r); }  break;
        case 48: _t->setAutoParkEnabled((*reinterpret_cast<std::add_pointer_t<bool>>(_a[1]))); break;
        case 49: _t->setAutoParkDailyEnabled((*reinterpret_cast<std::add_pointer_t<bool>>(_a[1]))); break;
        case 50: _t->setAutoParkStartup((*reinterpret_cast<std::add_pointer_t<QTime>>(_a[1]))); break;
        case 51: { bool _r = _t->meridianFlipEnabled();
            if (_a[0]) *reinterpret_cast<bool*>(_a[0]) = std::move(_r); }  break;
        case 52: { double _r = _t->meridianFlipValue();
            if (_a[0]) *reinterpret_cast<double*>(_a[0]) = std::move(_r); }  break;
        case 53: { bool _r = _t->slew((*reinterpret_cast<std::add_pointer_t<double>>(_a[1])),(*reinterpret_cast<std::add_pointer_t<double>>(_a[2])));
            if (_a[0]) *reinterpret_cast<bool*>(_a[0]) = std::move(_r); }  break;
        case 54: { bool _r = _t->gotoTarget((*reinterpret_cast<std::add_pointer_t<QString>>(_a[1])));
            if (_a[0]) *reinterpret_cast<bool*>(_a[0]) = std::move(_r); }  break;
        case 55: { bool _r = _t->sync((*reinterpret_cast<std::add_pointer_t<double>>(_a[1])),(*reinterpret_cast<std::add_pointer_t<double>>(_a[2])));
            if (_a[0]) *reinterpret_cast<bool*>(_a[0]) = std::move(_r); }  break;
        case 56: { bool _r = _t->syncTarget((*reinterpret_cast<std::add_pointer_t<QString>>(_a[1])));
            if (_a[0]) *reinterpret_cast<bool*>(_a[0]) = std::move(_r); }  break;
        case 57: { QList<double> _r = _t->equatorialCoords();
            if (_a[0]) *reinterpret_cast<QList<double>*>(_a[0]) = std::move(_r); }  break;
        case 58: { QList<double> _r = _t->horizontalCoords();
            if (_a[0]) *reinterpret_cast<QList<double>*>(_a[0]) = std::move(_r); }  break;
        case 59: { SkyPoint _r = _t->currentTarget();
            if (_a[0]) *reinterpret_cast<SkyPoint*>(_a[0]) = std::move(_r); }  break;
        case 60: { double _r = _t->hourAngle();
            if (_a[0]) *reinterpret_cast<double*>(_a[0]) = std::move(_r); }  break;
        case 61: { double _r = _t->initialHA();
            if (_a[0]) *reinterpret_cast<double*>(_a[0]) = std::move(_r); }  break;
        case 62: { bool _r = _t->abort();
            if (_a[0]) *reinterpret_cast<bool*>(_a[0]) = std::move(_r); }  break;
        case 63: { IPState _r = _t->slewStatus();
            if (_a[0]) *reinterpret_cast<IPState*>(_a[0]) = std::move(_r); }  break;
        case 64: { int _r = _t->slewRate();
            if (_a[0]) *reinterpret_cast<int*>(_a[0]) = std::move(_r); }  break;
        case 65: { bool _r = _t->setSlewRate((*reinterpret_cast<std::add_pointer_t<int>>(_a[1])));
            if (_a[0]) *reinterpret_cast<bool*>(_a[0]) = std::move(_r); }  break;
        case 66: { bool _r = _t->resetModel();
            if (_a[0]) *reinterpret_cast<bool*>(_a[0]) = std::move(_r); }  break;
        case 67: { QVariantMap _r = _t->alignmentModel();
            if (_a[0]) *reinterpret_cast<QVariantMap*>(_a[0]) = std::move(_r); }  break;
        case 68: { bool _r = _t->canPark();
            if (_a[0]) *reinterpret_cast<bool*>(_a[0]) = std::move(_r); }  break;
        case 69: { bool _r = _t->park();
            if (_a[0]) *reinterpret_cast<bool*>(_a[0]) = std::move(_r); }  break;
        case 70: { bool _r = _t->unpark();
            if (_a[0]) *reinterpret_cast<bool*>(_a[0]) = std::move(_r); }  break;
        case 71: _t->setTrackEnabled((*reinterpret_cast<std::add_pointer_t<bool>>(_a[1]))); break;
        case 72: _t->setJ2000Enabled((*reinterpret_cast<std::add_pointer_t<bool>>(_a[1]))); break;
        case 73: { bool _r = _t->raDecToAzAlt((*reinterpret_cast<std::add_pointer_t<QString>>(_a[1])),(*reinterpret_cast<std::add_pointer_t<QString>>(_a[2])));
            if (_a[0]) *reinterpret_cast<bool*>(_a[0]) = std::move(_r); }  break;
        case 74: { bool _r = _t->raDecToHaDec((*reinterpret_cast<std::add_pointer_t<QString>>(_a[1])));
            if (_a[0]) *reinterpret_cast<bool*>(_a[0]) = std::move(_r); }  break;
        case 75: { bool _r = _t->azAltToRaDec((*reinterpret_cast<std::add_pointer_t<QString>>(_a[1])),(*reinterpret_cast<std::add_pointer_t<QString>>(_a[2])));
            if (_a[0]) *reinterpret_cast<bool*>(_a[0]) = std::move(_r); }  break;
        case 76: { bool _r = _t->azAltToHaDec((*reinterpret_cast<std::add_pointer_t<QString>>(_a[1])),(*reinterpret_cast<std::add_pointer_t<QString>>(_a[2])));
            if (_a[0]) *reinterpret_cast<bool*>(_a[0]) = std::move(_r); }  break;
        case 77: { bool _r = _t->haDecToRaDec((*reinterpret_cast<std::add_pointer_t<QString>>(_a[1])));
            if (_a[0]) *reinterpret_cast<bool*>(_a[0]) = std::move(_r); }  break;
        case 78: { bool _r = _t->haDecToAzAlt((*reinterpret_cast<std::add_pointer_t<QString>>(_a[1])),(*reinterpret_cast<std::add_pointer_t<QString>>(_a[2])));
            if (_a[0]) *reinterpret_cast<bool*>(_a[0]) = std::move(_r); }  break;
        case 79: _t->centerMount(); break;
        case 80: _t->setUpDownReversed((*reinterpret_cast<std::add_pointer_t<bool>>(_a[1]))); break;
        case 81: _t->setLeftRightReversed((*reinterpret_cast<std::add_pointer_t<bool>>(_a[1]))); break;
        case 82: { QStringList _r = _t->timeSources();
            if (_a[0]) *reinterpret_cast<QStringList*>(_a[0]) = std::move(_r); }  break;
        case 83: { QStringList _r = _t->locationSources();
            if (_a[0]) *reinterpret_cast<QStringList*>(_a[0]) = std::move(_r); }  break;
        default: ;
        }
    }
    if (_c == QMetaObject::RegisterMethodArgumentMetaType) {
        switch (_id) {
        default: *reinterpret_cast<QMetaType *>(_a[0]) = QMetaType(); break;
        case 1:
            switch (*reinterpret_cast<int*>(_a[1])) {
            default: *reinterpret_cast<QMetaType *>(_a[0]) = QMetaType(); break;
            case 1:
                *reinterpret_cast<QMetaType *>(_a[0]) = QMetaType::fromType< ISD::Mount::PierSide >(); break;
            case 0:
                *reinterpret_cast<QMetaType *>(_a[0]) = QMetaType::fromType< SkyPoint >(); break;
            }
            break;
        case 4:
            switch (*reinterpret_cast<int*>(_a[1])) {
            default: *reinterpret_cast<QMetaType *>(_a[0]) = QMetaType(); break;
            case 0:
                *reinterpret_cast<QMetaType *>(_a[0]) = QMetaType::fromType< ISD::Mount::Status >(); break;
            }
            break;
        case 5:
            switch (*reinterpret_cast<int*>(_a[1])) {
            default: *reinterpret_cast<QMetaType *>(_a[0]) = QMetaType(); break;
            case 0:
                *reinterpret_cast<QMetaType *>(_a[0]) = QMetaType::fromType< ISD::ParkStatus >(); break;
            }
            break;
        case 6:
            switch (*reinterpret_cast<int*>(_a[1])) {
            default: *reinterpret_cast<QMetaType *>(_a[0]) = QMetaType(); break;
            case 0:
                *reinterpret_cast<QMetaType *>(_a[0]) = QMetaType::fromType< ISD::Mount::PierSide >(); break;
            }
            break;
        case 14:
            switch (*reinterpret_cast<int*>(_a[1])) {
            default: *reinterpret_cast<QMetaType *>(_a[0]) = QMetaType(); break;
            case 0:
                *reinterpret_cast<QMetaType *>(_a[0]) = QMetaType::fromType< INDI::Property >(); break;
            }
            break;
        case 16:
            switch (*reinterpret_cast<int*>(_a[1])) {
            default: *reinterpret_cast<QMetaType *>(_a[0]) = QMetaType(); break;
            case 1:
                *reinterpret_cast<QMetaType *>(_a[0]) = QMetaType::fromType< ISD::Mount::PierSide >(); break;
            case 0:
                *reinterpret_cast<QMetaType *>(_a[0]) = QMetaType::fromType< SkyPoint >(); break;
            }
            break;
        case 30:
            switch (*reinterpret_cast<int*>(_a[1])) {
            default: *reinterpret_cast<QMetaType *>(_a[0]) = QMetaType(); break;
            case 0:
                *reinterpret_cast<QMetaType *>(_a[0]) = QMetaType::fromType< SkyPoint >(); break;
            }
            break;
        case 40:
            switch (*reinterpret_cast<int*>(_a[1])) {
            default: *reinterpret_cast<QMetaType *>(_a[0]) = QMetaType(); break;
            case 0:
                *reinterpret_cast<QMetaType *>(_a[0]) = QMetaType::fromType< QList<double> >(); break;
            }
            break;
        }
    }
    if (_c == QMetaObject::IndexOfMethod) {
        if (QtMocHelpers::indexOfMethod<void (Mount::*)(const QString & )>(_a, &Mount::newLog, 0))
            return;
        if (QtMocHelpers::indexOfMethod<void (Mount::*)(const SkyPoint & , ISD::Mount::PierSide , const dms & )>(_a, &Mount::newCoords, 1))
            return;
        if (QtMocHelpers::indexOfMethod<void (Mount::*)(SkyPoint & )>(_a, &Mount::newTarget, 2))
            return;
        if (QtMocHelpers::indexOfMethod<void (Mount::*)(const QString & )>(_a, &Mount::newTargetName, 3))
            return;
        if (QtMocHelpers::indexOfMethod<void (Mount::*)(ISD::Mount::Status )>(_a, &Mount::newStatus, 4))
            return;
        if (QtMocHelpers::indexOfMethod<void (Mount::*)(ISD::ParkStatus )>(_a, &Mount::newParkStatus, 5))
            return;
        if (QtMocHelpers::indexOfMethod<void (Mount::*)(ISD::Mount::PierSide )>(_a, &Mount::pierSideChanged, 6))
            return;
        if (QtMocHelpers::indexOfMethod<void (Mount::*)(int )>(_a, &Mount::slewRateChanged, 7))
            return;
        if (QtMocHelpers::indexOfMethod<void (Mount::*)()>(_a, &Mount::ready, 8))
            return;
        if (QtMocHelpers::indexOfMethod<void (Mount::*)(const QString & )>(_a, &Mount::newMeridianFlipText, 9))
            return;
        if (QtMocHelpers::indexOfMethod<void (Mount::*)(const QString & )>(_a, &Mount::autoParkCountdownUpdated, 10))
            return;
        if (QtMocHelpers::indexOfMethod<void (Mount::*)(const QVariantMap & )>(_a, &Mount::settingsUpdated, 11))
            return;
        if (QtMocHelpers::indexOfMethod<void (Mount::*)()>(_a, &Mount::trainChanged, 12))
            return;
    }
    if (_c == QMetaObject::RegisterPropertyMetaType) {
        switch (_id) {
        default: *reinterpret_cast<int*>(_a[0]) = -1; break;
        case 15:
            *reinterpret_cast<int*>(_a[0]) = qRegisterMetaType< ISD::Mount::PierSide >(); break;
        case 1:
            *reinterpret_cast<int*>(_a[0]) = qRegisterMetaType< ISD::Mount::Status >(); break;
        case 2:
            *reinterpret_cast<int*>(_a[0]) = qRegisterMetaType< ISD::ParkStatus >(); break;
        case 10:
        case 9:
        case 4:
            *reinterpret_cast<int*>(_a[0]) = qRegisterMetaType< QList<double> >(); break;
        }
    }
    if (_c == QMetaObject::ReadProperty) {
        void *_v = _a[0];
        switch (_id) {
        case 0: *reinterpret_cast<QString*>(_v) = _t->opticalTrain(); break;
        case 1: *reinterpret_cast<ISD::Mount::Status*>(_v) = _t->status(); break;
        case 2: *reinterpret_cast<ISD::ParkStatus*>(_v) = _t->parkStatus(); break;
        case 3: *reinterpret_cast<QStringList*>(_v) = _t->logText(); break;
        case 4: *reinterpret_cast<QList<double>*>(_v) = _t->altitudeLimits(); break;
        case 5: *reinterpret_cast<bool*>(_v) = _t->altitudeLimitsEnabled(); break;
        case 6: *reinterpret_cast<double*>(_v) = _t->hourAngleLimit(); break;
        case 7: *reinterpret_cast<bool*>(_v) = _t->hourAngleLimitEnabled(); break;
        case 8: *reinterpret_cast<bool*>(_v) = _t->autoParkEnabled(); break;
        case 9: *reinterpret_cast<QList<double>*>(_v) = _t->equatorialCoords(); break;
        case 10: *reinterpret_cast<QList<double>*>(_v) = _t->horizontalCoords(); break;
        case 11: *reinterpret_cast<double*>(_v) = _t->hourAngle(); break;
        case 12: *reinterpret_cast<int*>(_v) = _t->slewRate(); break;
        case 13: *reinterpret_cast<int*>(_v) = _t->slewStatus(); break;
        case 14: *reinterpret_cast<bool*>(_v) = _t->canPark(); break;
        case 15: *reinterpret_cast<ISD::Mount::PierSide*>(_v) = _t->pierSide(); break;
        case 16: *reinterpret_cast<QStringList*>(_v) = _t->timeSources(); break;
        case 17: *reinterpret_cast<QStringList*>(_v) = _t->locationSources(); break;
        default: break;
        }
    }
    if (_c == QMetaObject::WriteProperty) {
        void *_v = _a[0];
        switch (_id) {
        case 0: _t->setOpticalTrain(*reinterpret_cast<QString*>(_v)); break;
        case 4: _t->setAltitudeLimits(*reinterpret_cast<QList<double>*>(_v)); break;
        case 5: _t->setAltitudeLimitsEnabled(*reinterpret_cast<bool*>(_v)); break;
        case 6: _t->setHourAngleLimit(*reinterpret_cast<double*>(_v)); break;
        case 7: _t->setHourAngleLimitEnabled(*reinterpret_cast<bool*>(_v)); break;
        case 8: _t->setAutoParkEnabled(*reinterpret_cast<bool*>(_v)); break;
        case 12: _t->setSlewRate(*reinterpret_cast<int*>(_v)); break;
        default: break;
        }
    }
}

const QMetaObject *Ekos::Mount::metaObject() const
{
    return QObject::d_ptr->metaObject ? QObject::d_ptr->dynamicMetaObject() : &staticMetaObject;
}

void *Ekos::Mount::qt_metacast(const char *_clname)
{
    if (!_clname) return nullptr;
    if (!strcmp(_clname, qt_staticMetaObjectStaticContent<qt_meta_tag_ZN4Ekos5MountE_t>.strings))
        return static_cast<void*>(this);
    if (!strcmp(_clname, "Ui::Mount"))
        return static_cast< Ui::Mount*>(this);
    return QWidget::qt_metacast(_clname);
}

int Ekos::Mount::qt_metacall(QMetaObject::Call _c, int _id, void **_a)
{
    _id = QWidget::qt_metacall(_c, _id, _a);
    if (_id < 0)
        return _id;
    if (_c == QMetaObject::InvokeMetaMethod) {
        if (_id < 84)
            qt_static_metacall(this, _c, _id, _a);
        _id -= 84;
    }
    if (_c == QMetaObject::RegisterMethodArgumentMetaType) {
        if (_id < 84)
            qt_static_metacall(this, _c, _id, _a);
        _id -= 84;
    }
    if (_c == QMetaObject::ReadProperty || _c == QMetaObject::WriteProperty
            || _c == QMetaObject::ResetProperty || _c == QMetaObject::BindableProperty
            || _c == QMetaObject::RegisterPropertyMetaType) {
        qt_static_metacall(this, _c, _id, _a);
        _id -= 18;
    }
    return _id;
}

// SIGNAL 0
void Ekos::Mount::newLog(const QString & _t1)
{
    QMetaObject::activate<void>(this, &staticMetaObject, 0, nullptr, _t1);
}

// SIGNAL 1
void Ekos::Mount::newCoords(const SkyPoint & _t1, ISD::Mount::PierSide _t2, const dms & _t3)
{
    QMetaObject::activate<void>(this, &staticMetaObject, 1, nullptr, _t1, _t2, _t3);
}

// SIGNAL 2
void Ekos::Mount::newTarget(SkyPoint & _t1)
{
    QMetaObject::activate<void>(this, &staticMetaObject, 2, nullptr, _t1);
}

// SIGNAL 3
void Ekos::Mount::newTargetName(const QString & _t1)
{
    QMetaObject::activate<void>(this, &staticMetaObject, 3, nullptr, _t1);
}

// SIGNAL 4
void Ekos::Mount::newStatus(ISD::Mount::Status _t1)
{
    QMetaObject::activate<void>(this, &staticMetaObject, 4, nullptr, _t1);
}

// SIGNAL 5
void Ekos::Mount::newParkStatus(ISD::ParkStatus _t1)
{
    QMetaObject::activate<void>(this, &staticMetaObject, 5, nullptr, _t1);
}

// SIGNAL 6
void Ekos::Mount::pierSideChanged(ISD::Mount::PierSide _t1)
{
    QMetaObject::activate<void>(this, &staticMetaObject, 6, nullptr, _t1);
}

// SIGNAL 7
void Ekos::Mount::slewRateChanged(int _t1)
{
    QMetaObject::activate<void>(this, &staticMetaObject, 7, nullptr, _t1);
}

// SIGNAL 8
void Ekos::Mount::ready()
{
    QMetaObject::activate(this, &staticMetaObject, 8, nullptr);
}

// SIGNAL 9
void Ekos::Mount::newMeridianFlipText(const QString & _t1)
{
    QMetaObject::activate<void>(this, &staticMetaObject, 9, nullptr, _t1);
}

// SIGNAL 10
void Ekos::Mount::autoParkCountdownUpdated(const QString & _t1)
{
    QMetaObject::activate<void>(this, &staticMetaObject, 10, nullptr, _t1);
}

// SIGNAL 11
void Ekos::Mount::settingsUpdated(const QVariantMap & _t1)
{
    QMetaObject::activate<void>(this, &staticMetaObject, 11, nullptr, _t1);
}

// SIGNAL 12
void Ekos::Mount::trainChanged()
{
    QMetaObject::activate(this, &staticMetaObject, 12, nullptr);
}
QT_WARNING_POP
