/********************************************************************************
** Form generated from reading UI file 'cfz.ui'
**
** Created by: Qt User Interface Compiler version 6.11.1
**
** WARNING! All changes made in this file will be lost when recompiling UI file!
********************************************************************************/

#ifndef UI_CFZ_H
#define UI_CFZ_H

#include <QtCore/QVariant>
#include <QtWidgets/QAbstractButton>
#include <QtWidgets/QApplication>
#include <QtWidgets/QCheckBox>
#include <QtWidgets/QComboBox>
#include <QtWidgets/QDialog>
#include <QtWidgets/QDialogButtonBox>
#include <QtWidgets/QDoubleSpinBox>
#include <QtWidgets/QGridLayout>
#include <QtWidgets/QGroupBox>
#include <QtWidgets/QLabel>
#include <QtWidgets/QLineEdit>
#include <QtWidgets/QPushButton>
#include <QtWidgets/QSpacerItem>
#include <QtWidgets/QSpinBox>
#include <QtWidgets/QVBoxLayout>
#include <klocalizedstring.h>

QT_BEGIN_NAMESPACE

class Ui_focusCFZDialog
{
public:
    QVBoxLayout *verticalLayout;
    QGroupBox *groupBox;
    QGridLayout *gridLayoutCFZ;
    QLabel *focusCFZToleranceLabel;
    QLabel *focusCFZTauLabel;
    QLabel *focusCFZLabel;
    QLabel *focusCFZApertureLabel;
    QCheckBox *focusCFZDisplayVCurve;
    QSpinBox *focusCFZAperture;
    QLineEdit *focusCFZCameraSteps;
    QLineEdit *focusCFZ;
    QDoubleSpinBox *focusCFZTolerance;
    QLineEdit *focusCFZFinal;
    QLabel *label_37;
    QLabel *label_19;
    QDoubleSpinBox *focusCFZTau;
    QLineEdit *focusCFZSteps;
    QLabel *focusCFZFormula;
    QLabel *focusCFZStepsLabel;
    QLabel *focusCFZWavelengthLabel;
    QDoubleSpinBox *focusCFZStepSize;
    QDoubleSpinBox *focusCFZSeeing;
    QPushButton *resetToOTB;
    QLabel *label_14;
    QLabel *label_34;
    QComboBox *focusCFZAlgorithm;
    QDoubleSpinBox *focusCFZFNumber;
    QLabel *label_20;
    QLabel *focusCFZSeeingLabel;
    QDoubleSpinBox *focusCFZWavelength;
    QDialogButtonBox *buttonBox;
    QSpacerItem *verticalSpacer;

    void setupUi(QDialog *focusCFZDialog)
    {
        if (focusCFZDialog->objectName().isEmpty())
            focusCFZDialog->setObjectName("focusCFZDialog");
        focusCFZDialog->resize(425, 237);
        verticalLayout = new QVBoxLayout(focusCFZDialog);
        verticalLayout->setObjectName("verticalLayout");
        verticalLayout->setContentsMargins(3, 3, 3, 3);
        groupBox = new QGroupBox(focusCFZDialog);
        groupBox->setObjectName("groupBox");
        gridLayoutCFZ = new QGridLayout(groupBox);
        gridLayoutCFZ->setObjectName("gridLayoutCFZ");
        gridLayoutCFZ->setHorizontalSpacing(6);
        gridLayoutCFZ->setVerticalSpacing(3);
        gridLayoutCFZ->setContentsMargins(3, 3, 3, 3);
        focusCFZToleranceLabel = new QLabel(groupBox);
        focusCFZToleranceLabel->setObjectName("focusCFZToleranceLabel");
        QSizePolicy sizePolicy(QSizePolicy::Policy::Preferred, QSizePolicy::Policy::Fixed);
        sizePolicy.setHorizontalStretch(0);
        sizePolicy.setVerticalStretch(0);
        sizePolicy.setHeightForWidth(focusCFZToleranceLabel->sizePolicy().hasHeightForWidth());
        focusCFZToleranceLabel->setSizePolicy(sizePolicy);

        gridLayoutCFZ->addWidget(focusCFZToleranceLabel, 1, 0, 1, 1);

        focusCFZTauLabel = new QLabel(groupBox);
        focusCFZTauLabel->setObjectName("focusCFZTauLabel");
        sizePolicy.setHeightForWidth(focusCFZTauLabel->sizePolicy().hasHeightForWidth());
        focusCFZTauLabel->setSizePolicy(sizePolicy);

        gridLayoutCFZ->addWidget(focusCFZTauLabel, 6, 0, 1, 1);

        focusCFZLabel = new QLabel(groupBox);
        focusCFZLabel->setObjectName("focusCFZLabel");
        sizePolicy.setHeightForWidth(focusCFZLabel->sizePolicy().hasHeightForWidth());
        focusCFZLabel->setSizePolicy(sizePolicy);
        focusCFZLabel->setAlignment(Qt::AlignRight|Qt::AlignTrailing|Qt::AlignVCenter);

        gridLayoutCFZ->addWidget(focusCFZLabel, 3, 2, 1, 1);

        focusCFZApertureLabel = new QLabel(groupBox);
        focusCFZApertureLabel->setObjectName("focusCFZApertureLabel");
        sizePolicy.setHeightForWidth(focusCFZApertureLabel->sizePolicy().hasHeightForWidth());
        focusCFZApertureLabel->setSizePolicy(sizePolicy);
        focusCFZApertureLabel->setAlignment(Qt::AlignRight|Qt::AlignTrailing|Qt::AlignVCenter);

        gridLayoutCFZ->addWidget(focusCFZApertureLabel, 2, 2, 1, 1);

        focusCFZDisplayVCurve = new QCheckBox(groupBox);
        focusCFZDisplayVCurve->setObjectName("focusCFZDisplayVCurve");
        sizePolicy.setHeightForWidth(focusCFZDisplayVCurve->sizePolicy().hasHeightForWidth());
        focusCFZDisplayVCurve->setSizePolicy(sizePolicy);
        focusCFZDisplayVCurve->setChecked(true);
        focusCFZDisplayVCurve->setAutoRepeatDelay(298);

        gridLayoutCFZ->addWidget(focusCFZDisplayVCurve, 1, 2, 1, 1);

        focusCFZAperture = new QSpinBox(groupBox);
        focusCFZAperture->setObjectName("focusCFZAperture");
        sizePolicy.setHeightForWidth(focusCFZAperture->sizePolicy().hasHeightForWidth());
        focusCFZAperture->setSizePolicy(sizePolicy);
        focusCFZAperture->setMinimum(10);
        focusCFZAperture->setMaximum(1000);
        focusCFZAperture->setValue(100);

        gridLayoutCFZ->addWidget(focusCFZAperture, 2, 3, 1, 1);

        focusCFZCameraSteps = new QLineEdit(groupBox);
        focusCFZCameraSteps->setObjectName("focusCFZCameraSteps");
        sizePolicy.setHeightForWidth(focusCFZCameraSteps->sizePolicy().hasHeightForWidth());
        focusCFZCameraSteps->setSizePolicy(sizePolicy);
        focusCFZCameraSteps->setReadOnly(true);

        gridLayoutCFZ->addWidget(focusCFZCameraSteps, 5, 1, 1, 1);

        focusCFZ = new QLineEdit(groupBox);
        focusCFZ->setObjectName("focusCFZ");
        sizePolicy.setHeightForWidth(focusCFZ->sizePolicy().hasHeightForWidth());
        focusCFZ->setSizePolicy(sizePolicy);
        focusCFZ->setReadOnly(true);

        gridLayoutCFZ->addWidget(focusCFZ, 3, 3, 1, 1);

        focusCFZTolerance = new QDoubleSpinBox(groupBox);
        focusCFZTolerance->setObjectName("focusCFZTolerance");
        sizePolicy.setHeightForWidth(focusCFZTolerance->sizePolicy().hasHeightForWidth());
        focusCFZTolerance->setSizePolicy(sizePolicy);
        focusCFZTolerance->setFocusPolicy(Qt::WheelFocus);
        focusCFZTolerance->setMinimum(0.000000000000000);
        focusCFZTolerance->setMaximum(1.000000000000000);
        focusCFZTolerance->setSingleStep(0.010000000000000);
        focusCFZTolerance->setValue(0.330000000000000);

        gridLayoutCFZ->addWidget(focusCFZTolerance, 1, 1, 1, 1);

        focusCFZFinal = new QLineEdit(groupBox);
        focusCFZFinal->setObjectName("focusCFZFinal");
        sizePolicy.setHeightForWidth(focusCFZFinal->sizePolicy().hasHeightForWidth());
        focusCFZFinal->setSizePolicy(sizePolicy);
        focusCFZFinal->setReadOnly(true);

        gridLayoutCFZ->addWidget(focusCFZFinal, 5, 3, 1, 1);

        label_37 = new QLabel(groupBox);
        label_37->setObjectName("label_37");
        sizePolicy.setHeightForWidth(label_37->sizePolicy().hasHeightForWidth());
        label_37->setSizePolicy(sizePolicy);

        gridLayoutCFZ->addWidget(label_37, 4, 0, 1, 1);

        label_19 = new QLabel(groupBox);
        label_19->setObjectName("label_19");
        sizePolicy.setHeightForWidth(label_19->sizePolicy().hasHeightForWidth());
        label_19->setSizePolicy(sizePolicy);

        gridLayoutCFZ->addWidget(label_19, 5, 0, 1, 1);

        focusCFZTau = new QDoubleSpinBox(groupBox);
        focusCFZTau->setObjectName("focusCFZTau");
        sizePolicy.setHeightForWidth(focusCFZTau->sizePolicy().hasHeightForWidth());
        focusCFZTau->setSizePolicy(sizePolicy);
        focusCFZTau->setFocusPolicy(Qt::WheelFocus);
        focusCFZTau->setMinimum(0.000000000000000);
        focusCFZTau->setMaximum(100.000000000000000);
        focusCFZTau->setSingleStep(1.000000000000000);
        focusCFZTau->setValue(3.000000000000000);

        gridLayoutCFZ->addWidget(focusCFZTau, 6, 1, 1, 1);

        focusCFZSteps = new QLineEdit(groupBox);
        focusCFZSteps->setObjectName("focusCFZSteps");
        sizePolicy.setHeightForWidth(focusCFZSteps->sizePolicy().hasHeightForWidth());
        focusCFZSteps->setSizePolicy(sizePolicy);
        focusCFZSteps->setReadOnly(true);

        gridLayoutCFZ->addWidget(focusCFZSteps, 4, 3, 1, 1);

        focusCFZFormula = new QLabel(groupBox);
        focusCFZFormula->setObjectName("focusCFZFormula");
        sizePolicy.setHeightForWidth(focusCFZFormula->sizePolicy().hasHeightForWidth());
        focusCFZFormula->setSizePolicy(sizePolicy);
        focusCFZFormula->setScaledContents(false);
        focusCFZFormula->setAlignment(Qt::AlignRight|Qt::AlignTrailing|Qt::AlignVCenter);

        gridLayoutCFZ->addWidget(focusCFZFormula, 0, 2, 1, 2);

        focusCFZStepsLabel = new QLabel(groupBox);
        focusCFZStepsLabel->setObjectName("focusCFZStepsLabel");
        sizePolicy.setHeightForWidth(focusCFZStepsLabel->sizePolicy().hasHeightForWidth());
        focusCFZStepsLabel->setSizePolicy(sizePolicy);
        focusCFZStepsLabel->setAlignment(Qt::AlignRight|Qt::AlignTrailing|Qt::AlignVCenter);

        gridLayoutCFZ->addWidget(focusCFZStepsLabel, 4, 2, 1, 1);

        focusCFZWavelengthLabel = new QLabel(groupBox);
        focusCFZWavelengthLabel->setObjectName("focusCFZWavelengthLabel");
        sizePolicy.setHeightForWidth(focusCFZWavelengthLabel->sizePolicy().hasHeightForWidth());
        focusCFZWavelengthLabel->setSizePolicy(sizePolicy);

        gridLayoutCFZ->addWidget(focusCFZWavelengthLabel, 2, 0, 1, 1);

        focusCFZStepSize = new QDoubleSpinBox(groupBox);
        focusCFZStepSize->setObjectName("focusCFZStepSize");
        sizePolicy.setHeightForWidth(focusCFZStepSize->sizePolicy().hasHeightForWidth());
        focusCFZStepSize->setSizePolicy(sizePolicy);
        focusCFZStepSize->setDecimals(3);
        focusCFZStepSize->setMinimum(0.001000000000000);
        focusCFZStepSize->setMaximum(100.000000000000000);
        focusCFZStepSize->setValue(5.000000000000000);

        gridLayoutCFZ->addWidget(focusCFZStepSize, 4, 1, 1, 1);

        focusCFZSeeing = new QDoubleSpinBox(groupBox);
        focusCFZSeeing->setObjectName("focusCFZSeeing");
        sizePolicy.setHeightForWidth(focusCFZSeeing->sizePolicy().hasHeightForWidth());
        focusCFZSeeing->setSizePolicy(sizePolicy);
        focusCFZSeeing->setMinimum(1.000000000000000);
        focusCFZSeeing->setMaximum(10.000000000000000);
        focusCFZSeeing->setSingleStep(1.000000000000000);
        focusCFZSeeing->setValue(3.000000000000000);

        gridLayoutCFZ->addWidget(focusCFZSeeing, 6, 3, 1, 1);

        resetToOTB = new QPushButton(groupBox);
        resetToOTB->setObjectName("resetToOTB");
        sizePolicy.setHeightForWidth(resetToOTB->sizePolicy().hasHeightForWidth());
        resetToOTB->setSizePolicy(sizePolicy);

        gridLayoutCFZ->addWidget(resetToOTB, 1, 3, 1, 1);

        label_14 = new QLabel(groupBox);
        label_14->setObjectName("label_14");
        sizePolicy.setHeightForWidth(label_14->sizePolicy().hasHeightForWidth());
        label_14->setSizePolicy(sizePolicy);

        gridLayoutCFZ->addWidget(label_14, 3, 0, 1, 1);

        label_34 = new QLabel(groupBox);
        label_34->setObjectName("label_34");
        sizePolicy.setHeightForWidth(label_34->sizePolicy().hasHeightForWidth());
        label_34->setSizePolicy(sizePolicy);
        label_34->setAlignment(Qt::AlignLeading|Qt::AlignLeft|Qt::AlignVCenter);

        gridLayoutCFZ->addWidget(label_34, 0, 0, 1, 1);

        focusCFZAlgorithm = new QComboBox(groupBox);
        focusCFZAlgorithm->addItem(QString());
        focusCFZAlgorithm->addItem(QString());
        focusCFZAlgorithm->addItem(QString());
        focusCFZAlgorithm->setObjectName("focusCFZAlgorithm");
        sizePolicy.setHeightForWidth(focusCFZAlgorithm->sizePolicy().hasHeightForWidth());
        focusCFZAlgorithm->setSizePolicy(sizePolicy);

        gridLayoutCFZ->addWidget(focusCFZAlgorithm, 0, 1, 1, 1);

        focusCFZFNumber = new QDoubleSpinBox(groupBox);
        focusCFZFNumber->setObjectName("focusCFZFNumber");
        sizePolicy.setHeightForWidth(focusCFZFNumber->sizePolicy().hasHeightForWidth());
        focusCFZFNumber->setSizePolicy(sizePolicy);
        focusCFZFNumber->setDecimals(2);
        focusCFZFNumber->setMinimum(1.000000000000000);
        focusCFZFNumber->setMaximum(30.000000000000000);
        focusCFZFNumber->setValue(5.000000000000000);

        gridLayoutCFZ->addWidget(focusCFZFNumber, 3, 1, 1, 1);

        label_20 = new QLabel(groupBox);
        label_20->setObjectName("label_20");
        sizePolicy.setHeightForWidth(label_20->sizePolicy().hasHeightForWidth());
        label_20->setSizePolicy(sizePolicy);
        label_20->setAlignment(Qt::AlignRight|Qt::AlignTrailing|Qt::AlignVCenter);

        gridLayoutCFZ->addWidget(label_20, 5, 2, 1, 1);

        focusCFZSeeingLabel = new QLabel(groupBox);
        focusCFZSeeingLabel->setObjectName("focusCFZSeeingLabel");
        sizePolicy.setHeightForWidth(focusCFZSeeingLabel->sizePolicy().hasHeightForWidth());
        focusCFZSeeingLabel->setSizePolicy(sizePolicy);

        gridLayoutCFZ->addWidget(focusCFZSeeingLabel, 6, 2, 1, 1);

        focusCFZWavelength = new QDoubleSpinBox(groupBox);
        focusCFZWavelength->setObjectName("focusCFZWavelength");
        sizePolicy.setHeightForWidth(focusCFZWavelength->sizePolicy().hasHeightForWidth());
        focusCFZWavelength->setSizePolicy(sizePolicy);
        focusCFZWavelength->setDecimals(0);
        focusCFZWavelength->setMinimum(100.000000000000000);
        focusCFZWavelength->setMaximum(800.000000000000000);
        focusCFZWavelength->setValue(550.000000000000000);

        gridLayoutCFZ->addWidget(focusCFZWavelength, 2, 1, 1, 1);


        verticalLayout->addWidget(groupBox);

        buttonBox = new QDialogButtonBox(focusCFZDialog);
        buttonBox->setObjectName("buttonBox");
        buttonBox->setOrientation(Qt::Horizontal);
        buttonBox->setStandardButtons(QDialogButtonBox::Close);

        verticalLayout->addWidget(buttonBox);

        verticalSpacer = new QSpacerItem(20, 40, QSizePolicy::Policy::Minimum, QSizePolicy::Policy::Expanding);

        verticalLayout->addItem(verticalSpacer);

#if QT_CONFIG(shortcut)
        focusCFZToleranceLabel->setBuddy(focusCFZTolerance);
        focusCFZTauLabel->setBuddy(focusCFZTau);
        focusCFZApertureLabel->setBuddy(focusCFZAperture);
        label_37->setBuddy(focusCFZStepSize);
        focusCFZWavelengthLabel->setBuddy(focusCFZWavelength);
        label_14->setBuddy(focusCFZFNumber);
        label_34->setBuddy(focusCFZAlgorithm);
        focusCFZSeeingLabel->setBuddy(focusCFZSeeing);
#endif // QT_CONFIG(shortcut)
        QWidget::setTabOrder(focusCFZAlgorithm, focusCFZTolerance);
        QWidget::setTabOrder(focusCFZTolerance, focusCFZDisplayVCurve);
        QWidget::setTabOrder(focusCFZDisplayVCurve, resetToOTB);
        QWidget::setTabOrder(resetToOTB, focusCFZWavelength);
        QWidget::setTabOrder(focusCFZWavelength, focusCFZAperture);
        QWidget::setTabOrder(focusCFZAperture, focusCFZFNumber);
        QWidget::setTabOrder(focusCFZFNumber, focusCFZ);
        QWidget::setTabOrder(focusCFZ, focusCFZStepSize);
        QWidget::setTabOrder(focusCFZStepSize, focusCFZSteps);
        QWidget::setTabOrder(focusCFZSteps, focusCFZCameraSteps);
        QWidget::setTabOrder(focusCFZCameraSteps, focusCFZFinal);
        QWidget::setTabOrder(focusCFZFinal, focusCFZTau);
        QWidget::setTabOrder(focusCFZTau, focusCFZSeeing);

        retranslateUi(focusCFZDialog);
        QObject::connect(buttonBox, &QDialogButtonBox::accepted, focusCFZDialog, qOverload<>(&QDialog::accept));
        QObject::connect(buttonBox, &QDialogButtonBox::rejected, focusCFZDialog, qOverload<>(&QDialog::reject));

        focusCFZAlgorithm->setCurrentIndex(0);


        QMetaObject::connectSlotsByName(focusCFZDialog);
    } // setupUi

    void retranslateUi(QDialog *focusCFZDialog)
    {
        focusCFZDialog->setWindowTitle(tr2i18n("Focus CFZ", nullptr));
#if QT_CONFIG(tooltip)
        focusCFZToleranceLabel->setToolTip(QString());
#endif // QT_CONFIG(tooltip)
#if QT_CONFIG(whatsthis)
        focusCFZToleranceLabel->setWhatsThis(QString());
#endif // QT_CONFIG(whatsthis)
        focusCFZToleranceLabel->setText(tr2i18n("Tolerance:", nullptr));
#if QT_CONFIG(tooltip)
        focusCFZTauLabel->setToolTip(QString());
#endif // QT_CONFIG(tooltip)
#if QT_CONFIG(whatsthis)
        focusCFZTauLabel->setWhatsThis(QString());
#endif // QT_CONFIG(whatsthis)
        focusCFZTauLabel->setText(tr2i18n("Tolerance (\317\204):", nullptr));
        focusCFZLabel->setText(tr2i18n("<html><head/><body><p>CFZ:</p></body></html>", nullptr));
        focusCFZApertureLabel->setText(tr2i18n("Aperture (A):", nullptr));
#if QT_CONFIG(tooltip)
        focusCFZDisplayVCurve->setToolTip(tr2i18n("<html><head/><body><p>Check to display the CFZ on the V-curve after a successful Autofocus run.</p></body></html>", nullptr));
#endif // QT_CONFIG(tooltip)
        focusCFZDisplayVCurve->setText(tr2i18n("Display:", nullptr));
#if QT_CONFIG(tooltip)
        focusCFZAperture->setToolTip(tr2i18n("<html><head/><body><p>Set the aperture of your telescope in mm. This is defaulted from the selected optical train.</p></body></html>", nullptr));
#endif // QT_CONFIG(tooltip)
        focusCFZAperture->setSuffix(tr2i18n(" mm", nullptr));
        focusCFZAperture->setPrefix(QString());
#if QT_CONFIG(tooltip)
        focusCFZCameraSteps->setToolTip(tr2i18n("<html><head/><body><p>The CFZ of the camera (resolution limit) in the active optical train.</p></body></html>", nullptr));
#endif // QT_CONFIG(tooltip)
#if QT_CONFIG(tooltip)
        focusCFZ->setToolTip(tr2i18n("<html><head/><body><p>The calculated CFZ in \316\274m.</p></body></html>", nullptr));
#endif // QT_CONFIG(tooltip)
#if QT_CONFIG(tooltip)
        focusCFZTolerance->setToolTip(tr2i18n("<html><head/><body><p>Set the tolerance=t value between 0 and 1. This scales the classic CFZ calculation of 4.88 \316\273 f<span style=\" vertical-align:super;\">2</span></p></body></html>", nullptr));
#endif // QT_CONFIG(tooltip)
#if QT_CONFIG(tooltip)
        focusCFZFinal->setToolTip(tr2i18n("<html><head/><body><p>The Final CFZ is the greater of the calculated CFZ and camera CFZ.</p></body></html>", nullptr));
#endif // QT_CONFIG(tooltip)
        label_37->setText(tr2i18n("<html><head/><body><p>Step size:</p></body></html>", nullptr));
        label_19->setText(tr2i18n("CFZ camera:", nullptr));
#if QT_CONFIG(tooltip)
        focusCFZTau->setToolTip(tr2i18n("<html><head/><body><p>Set the <span style=\" font-family:'Arial','Helvetica','sans-serif'; font-size:medium; color:#000000; background-color:#ffffff;\">focus tolerance, </span>\317\204<span style=\" font-family:'Arial','Helvetica','sans-serif'; font-size:medium; color:#000000; background-color:#ffffff;\"> as a percentage of total seeing.</span></p></body></html>", nullptr));
#endif // QT_CONFIG(tooltip)
        focusCFZTau->setSuffix(tr2i18n(" %", nullptr));
#if QT_CONFIG(tooltip)
        focusCFZSteps->setToolTip(tr2i18n("<html><head/><body><p>The calculated CFZ in steps.</p></body></html>", nullptr));
#endif // QT_CONFIG(tooltip)
        focusCFZFormula->setText(tr2i18n("<html><head/><body><p>CFZ = 4.88 t \316\273 f<span style=\" vertical-align:super;\">2</span></p></body></html>", nullptr));
        focusCFZStepsLabel->setText(tr2i18n("CFZ:", nullptr));
        focusCFZWavelengthLabel->setText(tr2i18n("Wavelength (\316\273):", nullptr));
#if QT_CONFIG(tooltip)
        focusCFZStepSize->setToolTip(tr2i18n("<html><head/><body><p>Set the step size (in microns) of your focuser. To calculate this move your focuser from one end of its travel to the other (being careful not to force the focuser beyond its limits). Measure the distance the drawtube moves as accurately as you can (e.g. with calipers) and convert this to microns. Note how many steps you have moved the focuser. The step size = distance_in_microns / number_steps.</p></body></html>", nullptr));
#endif // QT_CONFIG(tooltip)
        focusCFZStepSize->setSuffix(tr2i18n(" \316\274m", nullptr));
#if QT_CONFIG(tooltip)
        focusCFZSeeing->setToolTip(tr2i18n("<html><head/><body><p>The total seeing FWHM (in arc-seconds).</p></body></html>", nullptr));
#endif // QT_CONFIG(tooltip)
        focusCFZSeeing->setSuffix(tr2i18n("\"", nullptr));
#if QT_CONFIG(tooltip)
        resetToOTB->setToolTip(tr2i18n("<html><head/><body><p>Reset Wavelength,  Aperture,  Focal ratio to values from the currently selected filter and optical train</p></body></html>", nullptr));
#endif // QT_CONFIG(tooltip)
        resetToOTB->setText(tr2i18n("Reset To OT", nullptr));
        label_14->setText(tr2i18n("Focal ratio (f):", nullptr));
#if QT_CONFIG(tooltip)
        label_34->setToolTip(QString());
#endif // QT_CONFIG(tooltip)
        label_34->setText(tr2i18n("Algorithm:", nullptr));
        focusCFZAlgorithm->setItemText(0, tr2i18n("Classic", nullptr));
        focusCFZAlgorithm->setItemText(1, tr2i18n("Wavefront", nullptr));
        focusCFZAlgorithm->setItemText(2, tr2i18n("Gold", nullptr));

#if QT_CONFIG(tooltip)
        focusCFZAlgorithm->setToolTip(tr2i18n("<html><head/><body><p>Select the Critical Focus Zone (CFZ) algorithm:</p><ul style=\"margin-top: 0px; margin-bottom: 0px; margin-left: 0px; margin-right: 0px; -qt-list-indent: 1;\"><li style=\" margin-top:0px; margin-bottom:0px; margin-left:0px; margin-right:0px; -qt-block-indent:0; text-indent:0px;\"><span style=\" font-weight:600;\">Classic</span>: Uses the formula, CFZ = 4.88 t \316\273 f<span style=\" vertical-align:super;\">2.</span>.  Set tolerance, t=1 for the basic formula. Some have suggested t=1/3 empirically.</li></ul><ul style=\"margin-top: 0px; margin-bottom: 0px; margin-left: 0px; margin-right: 0px; -qt-list-indent: 1;\"><li style=\" margin-top:0px; margin-bottom:0px; margin-left:0px; margin-right:0px; -qt-block-indent:0; text-indent:0px;\"><span style=\" font-weight:600;\">Wavefront: </span>Uses the formula, CFZ = 4 t \316\273 f<span style=\" vertical-align:super;\">2</span>.  Formula derived from wavefront aberration theory. Some have suggested t=1/3 or even t=1/10.</li></ul><ul style=\"margin-"
                        "top: 0px; margin-bottom: 0px; margin-left: 0px; margin-right: 0px; -qt-list-indent: 1;\"><li style=\" margin-top:0px; margin-bottom:0px; margin-left:0px; margin-right:0px; -qt-block-indent:0; text-indent:0px;\"><span style=\" font-weight:600;\">Gold: </span>Uses the formula, CFZ = 0.00225 \342\210\232\317\204 \316\270 f<span style=\" vertical-align:super;\">2. </span>A.  See http://www.goldastro.com/goldfocus/ncfz.php for more details.</li></ul></body></html>", nullptr));
#endif // QT_CONFIG(tooltip)
#if QT_CONFIG(tooltip)
        focusCFZFNumber->setToolTip(tr2i18n("<html><head/><body><p>Set the F# to use. This is defaulted from the selected optical train.</p></body></html>", nullptr));
#endif // QT_CONFIG(tooltip)
        focusCFZFNumber->setSuffix(QString());
        label_20->setText(tr2i18n("Final CFZ:", nullptr));
        focusCFZSeeingLabel->setText(tr2i18n("FWHM (\316\270):", nullptr));
#if QT_CONFIG(tooltip)
        focusCFZWavelength->setToolTip(tr2i18n("<html><head/><body><p>Set the light wavelength to use. This is defaulted from the Filter Settings popup for the selected filter. </p></body></html>", nullptr));
#endif // QT_CONFIG(tooltip)
        focusCFZWavelength->setSuffix(tr2i18n(" nm", nullptr));
    } // retranslateUi

};

namespace Ui {
    class focusCFZDialog: public Ui_focusCFZDialog {};
} // namespace Ui

QT_END_NAMESPACE

#endif // CFZ_H

