/****************************************************************************
** Meta object code from reading C++ file 'alignadaptor.h'
**
** Created by: The Qt Meta Object Compiler version 69 (Qt 6.11.1)
**
** WARNING! All changes made in this file will be lost!
*****************************************************************************/

#include "alignadaptor.h"
#include <QtCore/qmetatype.h>
#include <QtCore/QList>

#include <QtCore/qtmochelpers.h>

#include <memory>


#include <QtCore/qxptype_traits.h>
#if !defined(Q_MOC_OUTPUT_REVISION)
#error "The header file 'alignadaptor.h' doesn't include <QObject>."
#elif Q_MOC_OUTPUT_REVISION != 69
#error "This file was generated using the moc from 6.11.1. It"
#error "cannot be used with the include files from this version of Qt."
#error "(The moc has changed too much.)"
#endif

#ifndef Q_CONSTINIT
#define Q_CONSTINIT
#endif

QT_WARNING_PUSH
QT_WARNING_DISABLE_DEPRECATED
QT_WARNING_DISABLE_GCC("-Wuseless-cast")
namespace {
struct qt_meta_tag_ZN12AlignAdaptorE_t {};
} // unnamed namespace

template <> constexpr inline auto AlignAdaptor::qt_create_metaobjectdata<qt_meta_tag_ZN12AlignAdaptorE_t>()
{
    namespace QMC = QtMocConstants;
    QtMocHelpers::StringRefStorage qt_stringData {
        "AlignAdaptor",
        "D-Bus Interface",
        "org.kde.kstars.Ekos.Align",
        "D-Bus Introspection",
        "  <interface name=\"org.kde.kstars.Ekos.Align\">\n    <property ac"
        "cess=\"readwrite\" type=\"s\" name=\"opticalTrain\"/>\n    <proper"
        "ty access=\"read\" type=\"s\" name=\"camera\"/>\n    <property acc"
        "ess=\"read\" type=\"s\" name=\"filterWheel\"/>\n    <property acce"
        "ss=\"readwrite\" type=\"s\" name=\"filter\"/>\n    <property acces"
        "s=\"read\" type=\"as\" name=\"logText\"/>\n    <property access=\""
        "read\" type=\"i\" name=\"status\">\n      <annotation value=\"Ekos"
        "::AlignState\" name=\"org.qtproject.QtDBus.QtTypeName\"/>\n    </p"
        "roperty>\n    <property access=\"read\" type=\"ad\" name=\"fov\">\n"
        "      <annotation value=\"QList&lt;double&gt;\" name=\"org.qtproje"
        "ct.QtDBus.QtTypeName\"/>\n    </property>\n    <property access=\""
        "readwrite\" type=\"s\" name=\"solverArguments\"/>\n    <method nam"
        "e=\"abort\">\n      <annotation value=\"true\" name=\"org.freedesk"
        "top.DBus.Method.NoReply\"/>\n    </method>\n    <method name=\"cap"
        "tureAndSolve\">\n      <arg direction=\"out\" type=\"b\"/>\n    </"
        "method>\n    <method name=\"loadAndSlew\">\n      <arg direction=\""
        "out\" type=\"b\"/>\n      <arg direction=\"in\" type=\"s\" name=\""
        "fileURL\"/>\n    </method>\n    <method name=\"setSolverMode\">\n "
        "     <arg direction=\"in\" type=\"u\" name=\"mode\"/>\n      <anno"
        "tation value=\"true\" name=\"org.freedesktop.DBus.Method.NoReply\""
        "/>\n    </method>\n    <method name=\"setSolverAction\">\n      <a"
        "rg direction=\"in\" type=\"i\" name=\"mode\"/>\n      <annotation "
        "value=\"true\" name=\"org.freedesktop.DBus.Method.NoReply\"/>\n   "
        " </method>\n    <method name=\"cameraInfo\">\n      <arg direction"
        "=\"out\" type=\"ad\"/>\n      <annotation value=\"QList&lt;double&"
        "gt;\" name=\"org.qtproject.QtDBus.QtTypeName.In0\"/>\n      <annot"
        "ation value=\"QList&lt;double&gt;\" name=\"org.qtproject.QtDBus.Qt"
        "TypeName.Out0\"/>\n    </method>\n    <method name=\"getSolutionRe"
        "sult\">\n      <arg direction=\"out\" type=\"ad\"/>\n      <annota"
        "tion value=\"QList&lt;double&gt;\" name=\"org.qtproject.QtDBus.QtT"
        "ypeName.In0\"/>\n      <annotation value=\"QList&lt;double&gt;\" n"
        "ame=\"org.qtproject.QtDBus.QtTypeName.Out0\"/>\n    </method>\n   "
        " <method name=\"telescopeInfo\">\n      <arg direction=\"out\" typ"
        "e=\"ad\"/>\n      <annotation value=\"QList&lt;double&gt;\" name=\""
        "org.qtproject.QtDBus.QtTypeName.In0\"/>\n      <annotation value=\""
        "QList&lt;double&gt;\" name=\"org.qtproject.QtDBus.QtTypeName.Out0\""
        "/>\n    </method>\n    <method name=\"getLoadAndSlewStatus\">\n   "
        "   <arg direction=\"out\" type=\"i\"/>\n    </method>\n    <method"
        " name=\"setBinningIndex\">\n      <arg direction=\"in\" type=\"i\""
        " name=\"binningIndex\"/>\n      <annotation value=\"true\" name=\""
        "org.freedesktop.DBus.Method.NoReply\"/>\n    </method>\n    <metho"
        "d name=\"setTargetCoords\">\n      <arg direction=\"in\" type=\"d\""
        " name=\"ra\"/>\n      <arg direction=\"in\" type=\"d\" name=\"de\""
        "/>\n      <annotation value=\"true\" name=\"org.freedesktop.DBus.M"
        "ethod.NoReply\"/>\n    </method>\n    <method name=\"getTargetCoor"
        "ds\">\n      <arg direction=\"out\" type=\"ad\"/>\n      <annotati"
        "on value=\"QList&lt;double&gt;\" name=\"org.qtproject.QtDBus.QtTyp"
        "eName.In0\"/>\n      <annotation value=\"QList&lt;double&gt;\" nam"
        "e=\"org.qtproject.QtDBus.QtTypeName.Out0\"/>\n    </method>\n    <"
        "method name=\"setTargetPositionAngle\">\n      <arg direction=\"in"
        "\" type=\"d\" name=\"value\"/>\n      <annotation value=\"true\" n"
        "ame=\"org.freedesktop.DBus.Method.NoReply\"/>\n    </method>\n    "
        "<signal name=\"newStatus\">\n      <arg direction=\"out\" type=\"("
        "i)\" name=\"status\"/>\n      <annotation value=\"Ekos::AlignState"
        "\" name=\"org.qtproject.QtDBus.QtTypeName.In0\"/>\n      <annotati"
        "on value=\"Ekos::AlignState\" name=\"org.qtproject.QtDBus.QtTypeNa"
        "me.Out0\"/>\n    </signal>\n    <signal name=\"newSolution\">\n   "
        "   <arg direction=\"out\" type=\"a{sv}\" name=\"solution\"/>\n    "
        "  <annotation value=\"QVariantMap\" name=\"org.qtproject.QtDBus.Qt"
        "TypeName.In0\"/>\n      <annotation value=\"QVariantMap\" name=\"o"
        "rg.qtproject.QtDBus.QtTypeName.Out0\"/>\n    </signal>\n    <signa"
        "l name=\"newLog\">\n      <arg direction=\"out\" type=\"s\" name=\""
        "text\"/>\n    </signal>\n  </interface>\n",
        "newLog",
        "",
        "text",
        "newSolution",
        "QVariantMap",
        "solution",
        "newStatus",
        "Ekos::AlignState",
        "status",
        "abort",
        "Q_NOREPLY",
        "cameraInfo",
        "QList<double>",
        "captureAndSolve",
        "getLoadAndSlewStatus",
        "getSolutionResult",
        "getTargetCoords",
        "loadAndSlew",
        "fileURL",
        "setBinningIndex",
        "binningIndex",
        "setSolverAction",
        "mode",
        "setSolverMode",
        "setTargetCoords",
        "ra",
        "de",
        "setTargetPositionAngle",
        "value",
        "telescopeInfo",
        "camera",
        "filter",
        "filterWheel",
        "fov",
        "logText",
        "opticalTrain",
        "solverArguments"
    };

    QtMocHelpers::UintData qt_methods {
        // Signal 'newLog'
        QtMocHelpers::SignalData<void(const QString &)>(5, 6, QMC::AccessPublic, QMetaType::Void, {{
            { QMetaType::QString, 7 },
        }}),
        // Signal 'newSolution'
        QtMocHelpers::SignalData<void(const QVariantMap &)>(8, 6, QMC::AccessPublic, QMetaType::Void, {{
            { 0x80000000 | 9, 10 },
        }}),
        // Signal 'newStatus'
        QtMocHelpers::SignalData<void(Ekos::AlignState)>(11, 6, QMC::AccessPublic, QMetaType::Void, {{
            { 0x80000000 | 12, 13 },
        }}),
        // Slot 'abort'
        QtMocHelpers::SlotData<void()>(14, 15, QMC::AccessPublic, QMetaType::Void),
        // Slot 'cameraInfo'
        QtMocHelpers::SlotData<QList<double>()>(16, 6, QMC::AccessPublic, 0x80000000 | 17),
        // Slot 'captureAndSolve'
        QtMocHelpers::SlotData<bool()>(18, 6, QMC::AccessPublic, QMetaType::Bool),
        // Slot 'getLoadAndSlewStatus'
        QtMocHelpers::SlotData<int()>(19, 6, QMC::AccessPublic, QMetaType::Int),
        // Slot 'getSolutionResult'
        QtMocHelpers::SlotData<QList<double>()>(20, 6, QMC::AccessPublic, 0x80000000 | 17),
        // Slot 'getTargetCoords'
        QtMocHelpers::SlotData<QList<double>()>(21, 6, QMC::AccessPublic, 0x80000000 | 17),
        // Slot 'loadAndSlew'
        QtMocHelpers::SlotData<bool(const QString &)>(22, 6, QMC::AccessPublic, QMetaType::Bool, {{
            { QMetaType::QString, 23 },
        }}),
        // Slot 'setBinningIndex'
        QtMocHelpers::SlotData<void(int)>(24, 15, QMC::AccessPublic, QMetaType::Void, {{
            { QMetaType::Int, 25 },
        }}),
        // Slot 'setSolverAction'
        QtMocHelpers::SlotData<void(int)>(26, 15, QMC::AccessPublic, QMetaType::Void, {{
            { QMetaType::Int, 27 },
        }}),
        // Slot 'setSolverMode'
        QtMocHelpers::SlotData<void(uint)>(28, 15, QMC::AccessPublic, QMetaType::Void, {{
            { QMetaType::UInt, 27 },
        }}),
        // Slot 'setTargetCoords'
        QtMocHelpers::SlotData<void(double, double)>(29, 15, QMC::AccessPublic, QMetaType::Void, {{
            { QMetaType::Double, 30 }, { QMetaType::Double, 31 },
        }}),
        // Slot 'setTargetPositionAngle'
        QtMocHelpers::SlotData<void(double)>(32, 15, QMC::AccessPublic, QMetaType::Void, {{
            { QMetaType::Double, 33 },
        }}),
        // Slot 'telescopeInfo'
        QtMocHelpers::SlotData<QList<double>()>(34, 6, QMC::AccessPublic, 0x80000000 | 17),
    };
    QtMocHelpers::UintData qt_properties {
        // property 'camera'
        QtMocHelpers::PropertyData<QString>(35, QMetaType::QString, QMC::DefaultPropertyFlags),
        // property 'filter'
        QtMocHelpers::PropertyData<QString>(36, QMetaType::QString, QMC::DefaultPropertyFlags | QMC::Writable | QMC::StdCppSet),
        // property 'filterWheel'
        QtMocHelpers::PropertyData<QString>(37, QMetaType::QString, QMC::DefaultPropertyFlags),
        // property 'fov'
        QtMocHelpers::PropertyData<QList<double>>(38, 0x80000000 | 17, QMC::DefaultPropertyFlags | QMC::EnumOrFlag),
        // property 'logText'
        QtMocHelpers::PropertyData<QStringList>(39, QMetaType::QStringList, QMC::DefaultPropertyFlags),
        // property 'opticalTrain'
        QtMocHelpers::PropertyData<QString>(40, QMetaType::QString, QMC::DefaultPropertyFlags | QMC::Writable | QMC::StdCppSet),
        // property 'solverArguments'
        QtMocHelpers::PropertyData<QString>(41, QMetaType::QString, QMC::DefaultPropertyFlags | QMC::Writable | QMC::StdCppSet),
        // property 'status'
        QtMocHelpers::PropertyData<int>(13, QMetaType::Int, QMC::DefaultPropertyFlags),
    };
    QtMocHelpers::UintData qt_enums {
    };
    QtMocHelpers::UintData qt_constructors {};
    QtMocHelpers::ClassInfos qt_classinfo({
            {    1,    2 },
            {    3,    4 },
    });
    return QtMocHelpers::metaObjectData<AlignAdaptor, qt_meta_tag_ZN12AlignAdaptorE_t>(QMC::MetaObjectFlag{}, qt_stringData,
            qt_methods, qt_properties, qt_enums, qt_constructors, qt_classinfo);
}
Q_CONSTINIT const QMetaObject AlignAdaptor::staticMetaObject = { {
    QMetaObject::SuperData::link<QDBusAbstractAdaptor::staticMetaObject>(),
    qt_staticMetaObjectStaticContent<qt_meta_tag_ZN12AlignAdaptorE_t>.stringdata,
    qt_staticMetaObjectStaticContent<qt_meta_tag_ZN12AlignAdaptorE_t>.data,
    qt_static_metacall,
    nullptr,
    qt_staticMetaObjectRelocatingContent<qt_meta_tag_ZN12AlignAdaptorE_t>.metaTypes,
    nullptr
} };

void AlignAdaptor::qt_static_metacall(QObject *_o, QMetaObject::Call _c, int _id, void **_a)
{
    auto *_t = static_cast<AlignAdaptor *>(_o);
    if (_c == QMetaObject::InvokeMetaMethod) {
        switch (_id) {
        case 0: _t->newLog((*reinterpret_cast<std::add_pointer_t<QString>>(_a[1]))); break;
        case 1: _t->newSolution((*reinterpret_cast<std::add_pointer_t<QVariantMap>>(_a[1]))); break;
        case 2: _t->newStatus((*reinterpret_cast<std::add_pointer_t<Ekos::AlignState>>(_a[1]))); break;
        case 3: _t->abort(); break;
        case 4: { QList<double> _r = _t->cameraInfo();
            if (_a[0]) *reinterpret_cast<QList<double>*>(_a[0]) = std::move(_r); }  break;
        case 5: { bool _r = _t->captureAndSolve();
            if (_a[0]) *reinterpret_cast<bool*>(_a[0]) = std::move(_r); }  break;
        case 6: { int _r = _t->getLoadAndSlewStatus();
            if (_a[0]) *reinterpret_cast<int*>(_a[0]) = std::move(_r); }  break;
        case 7: { QList<double> _r = _t->getSolutionResult();
            if (_a[0]) *reinterpret_cast<QList<double>*>(_a[0]) = std::move(_r); }  break;
        case 8: { QList<double> _r = _t->getTargetCoords();
            if (_a[0]) *reinterpret_cast<QList<double>*>(_a[0]) = std::move(_r); }  break;
        case 9: { bool _r = _t->loadAndSlew((*reinterpret_cast<std::add_pointer_t<QString>>(_a[1])));
            if (_a[0]) *reinterpret_cast<bool*>(_a[0]) = std::move(_r); }  break;
        case 10: _t->setBinningIndex((*reinterpret_cast<std::add_pointer_t<int>>(_a[1]))); break;
        case 11: _t->setSolverAction((*reinterpret_cast<std::add_pointer_t<int>>(_a[1]))); break;
        case 12: _t->setSolverMode((*reinterpret_cast<std::add_pointer_t<uint>>(_a[1]))); break;
        case 13: _t->setTargetCoords((*reinterpret_cast<std::add_pointer_t<double>>(_a[1])),(*reinterpret_cast<std::add_pointer_t<double>>(_a[2]))); break;
        case 14: _t->setTargetPositionAngle((*reinterpret_cast<std::add_pointer_t<double>>(_a[1]))); break;
        case 15: { QList<double> _r = _t->telescopeInfo();
            if (_a[0]) *reinterpret_cast<QList<double>*>(_a[0]) = std::move(_r); }  break;
        default: ;
        }
    }
    if (_c == QMetaObject::RegisterMethodArgumentMetaType) {
        switch (_id) {
        default: *reinterpret_cast<QMetaType *>(_a[0]) = QMetaType(); break;
        case 2:
            switch (*reinterpret_cast<int*>(_a[1])) {
            default: *reinterpret_cast<QMetaType *>(_a[0]) = QMetaType(); break;
            case 0:
                *reinterpret_cast<QMetaType *>(_a[0]) = QMetaType::fromType< Ekos::AlignState >(); break;
            }
            break;
        }
    }
    if (_c == QMetaObject::IndexOfMethod) {
        if (QtMocHelpers::indexOfMethod<void (AlignAdaptor::*)(const QString & )>(_a, &AlignAdaptor::newLog, 0))
            return;
        if (QtMocHelpers::indexOfMethod<void (AlignAdaptor::*)(const QVariantMap & )>(_a, &AlignAdaptor::newSolution, 1))
            return;
        if (QtMocHelpers::indexOfMethod<void (AlignAdaptor::*)(Ekos::AlignState )>(_a, &AlignAdaptor::newStatus, 2))
            return;
    }
    if (_c == QMetaObject::RegisterPropertyMetaType) {
        switch (_id) {
        default: *reinterpret_cast<int*>(_a[0]) = -1; break;
        case 3:
            *reinterpret_cast<int*>(_a[0]) = qRegisterMetaType< QList<double> >(); break;
        }
    }
    if (_c == QMetaObject::ReadProperty) {
        void *_v = _a[0];
        switch (_id) {
        case 0: *reinterpret_cast<QString*>(_v) = _t->camera(); break;
        case 1: *reinterpret_cast<QString*>(_v) = _t->filter(); break;
        case 2: *reinterpret_cast<QString*>(_v) = _t->filterWheel(); break;
        case 3: *reinterpret_cast<QList<double>*>(_v) = _t->fov(); break;
        case 4: *reinterpret_cast<QStringList*>(_v) = _t->logText(); break;
        case 5: *reinterpret_cast<QString*>(_v) = _t->opticalTrain(); break;
        case 6: *reinterpret_cast<QString*>(_v) = _t->solverArguments(); break;
        case 7: *reinterpret_cast<int*>(_v) = _t->status(); break;
        default: break;
        }
    }
    if (_c == QMetaObject::WriteProperty) {
        void *_v = _a[0];
        switch (_id) {
        case 1: _t->setFilter(*reinterpret_cast<QString*>(_v)); break;
        case 5: _t->setOpticalTrain(*reinterpret_cast<QString*>(_v)); break;
        case 6: _t->setSolverArguments(*reinterpret_cast<QString*>(_v)); break;
        default: break;
        }
    }
}

const QMetaObject *AlignAdaptor::metaObject() const
{
    return QObject::d_ptr->metaObject ? QObject::d_ptr->dynamicMetaObject() : &staticMetaObject;
}

void *AlignAdaptor::qt_metacast(const char *_clname)
{
    if (!_clname) return nullptr;
    if (!strcmp(_clname, qt_staticMetaObjectStaticContent<qt_meta_tag_ZN12AlignAdaptorE_t>.strings))
        return static_cast<void*>(this);
    return QDBusAbstractAdaptor::qt_metacast(_clname);
}

int AlignAdaptor::qt_metacall(QMetaObject::Call _c, int _id, void **_a)
{
    _id = QDBusAbstractAdaptor::qt_metacall(_c, _id, _a);
    if (_id < 0)
        return _id;
    if (_c == QMetaObject::InvokeMetaMethod) {
        if (_id < 16)
            qt_static_metacall(this, _c, _id, _a);
        _id -= 16;
    }
    if (_c == QMetaObject::RegisterMethodArgumentMetaType) {
        if (_id < 16)
            qt_static_metacall(this, _c, _id, _a);
        _id -= 16;
    }
    if (_c == QMetaObject::ReadProperty || _c == QMetaObject::WriteProperty
            || _c == QMetaObject::ResetProperty || _c == QMetaObject::BindableProperty
            || _c == QMetaObject::RegisterPropertyMetaType) {
        qt_static_metacall(this, _c, _id, _a);
        _id -= 8;
    }
    return _id;
}

// SIGNAL 0
void AlignAdaptor::newLog(const QString & _t1)
{
    QMetaObject::activate<void>(this, &staticMetaObject, 0, nullptr, _t1);
}

// SIGNAL 1
void AlignAdaptor::newSolution(const QVariantMap & _t1)
{
    QMetaObject::activate<void>(this, &staticMetaObject, 1, nullptr, _t1);
}

// SIGNAL 2
void AlignAdaptor::newStatus(Ekos::AlignState _t1)
{
    QMetaObject::activate<void>(this, &staticMetaObject, 2, nullptr, _t1);
}
QT_WARNING_POP
