/****************************************************************************
** Meta object code from reading C++ file 'focus.h'
**
** Created by: The Qt Meta Object Compiler version 69 (Qt 6.11.1)
**
** WARNING! All changes made in this file will be lost!
*****************************************************************************/

#include "../../../../kstars-3.8.4.1/kstars/ekos/focus/focus.h"
#include <QtNetwork/QSslError>
#include <QtDataVisualization/qbar3dseries.h>
#include <QtDataVisualization/q3dscene.h>
#include <QtGui/qtextcursor.h>
#include <QtGui/qscreen.h>
#include <QtCore/qmetatype.h>
#include <QtCore/QSharedPointer>

#include <QtCore/qtmochelpers.h>

#include <memory>


#include <QtCore/qxptype_traits.h>
#if !defined(Q_MOC_OUTPUT_REVISION)
#error "The header file 'focus.h' doesn't include <QObject>."
#elif Q_MOC_OUTPUT_REVISION != 69
#error "This file was generated using the moc from 6.11.1. It"
#error "cannot be used with the include files from this version of Qt."
#error "(The moc has changed too much.)"
#endif

#ifndef Q_CONSTINIT
#define Q_CONSTINIT
#endif

QT_WARNING_PUSH
QT_WARNING_DISABLE_DEPRECATED
QT_WARNING_DISABLE_GCC("-Wuseless-cast")
namespace {
struct qt_meta_tag_ZN4Ekos5FocusE_t {};
} // unnamed namespace

template <> constexpr inline auto Ekos::Focus::qt_create_metaobjectdata<qt_meta_tag_ZN4Ekos5FocusE_t>()
{
    namespace QMC = QtMocConstants;
    QtMocHelpers::StringRefStorage qt_stringData {
        "Ekos::Focus",
        "newLog",
        "",
        "text",
        "newFocusLog",
        "newStatus",
        "Ekos::FocusState",
        "state",
        "trainname",
        "update",
        "newHFR",
        "hfr",
        "position",
        "inAutofocus",
        "newFocusTemperatureDelta",
        "delta",
        "absTemperature",
        "inSequenceAF",
        "requested",
        "absolutePositionChanged",
        "value",
        "focusPositionAdjusted",
        "focusAdaptiveComplete",
        "success",
        "focusAFOptimise",
        "trainChanged",
        "focuserChanged",
        "id",
        "isValid",
        "suspendGuiding",
        "resumeGuiding",
        "newImage",
        "QSharedPointer<FITSView>",
        "view",
        "newStarPixmap",
        "QPixmap&",
        "settingsUpdated",
        "QVariantMap",
        "settings",
        "autofocusStarting",
        "temperature",
        "filter",
        "AutofocusReason",
        "reason",
        "reasonInfo",
        "autofocusComplete",
        "points",
        "useWeights",
        "curve",
        "title",
        "autofocusAborted",
        "AutofocusFailReason",
        "failCode",
        "failCodeInfo",
        "newFocusAdvisorStage",
        "stage",
        "newFocusAdvisorMessage",
        "name",
        "adaptiveFocusComplete",
        "tempTicks",
        "altitude",
        "altTicks",
        "prevPosError",
        "thisPosError",
        "totalTicks",
        "focuserMoved",
        "initHFRPlot",
        "str",
        "starUnits",
        "minimum",
        "showPosition",
        "newHFRPlotPosition",
        "pos",
        "sigma",
        "outlier",
        "pulseDuration",
        "plot",
        "drawPolynomial",
        "PolynomialFit*",
        "poly",
        "isVShape",
        "activate",
        "drawCurve",
        "CurveFitting*",
        "minimumFound",
        "solutionPosition",
        "solutionValue",
        "drawCFZ",
        "minPosition",
        "minValue",
        "m_cfzSteps",
        "plt",
        "redrawHFRPlot",
        "setTitle",
        "finalUpdates",
        "focuserTimedout",
        "focuser",
        "driverTimedout",
        "deviceName",
        "start",
        "Q_NOREPLY",
        "abort",
        "capture",
        "settleTime",
        "focusIn",
        "ms",
        "speedFactor",
        "focusOut",
        "checkFocus",
        "requiredHFR",
        "runAutoFocus",
        "autofocusReason",
        "startFraming",
        "resetFocuser",
        "checkStopFocus",
        "meridianFlipStarted",
        "checkCamera",
        "syncCameraInfo",
        "syncCCDControls",
        "checkFocuser",
        "checkFilter",
        "checkTemperatureSource",
        "clearDataPoints",
        "clearCurrentRun",
        "deleteFiles",
        "useTrash",
        "focusStarSelected",
        "x",
        "y",
        "selectFocusStarFraction",
        "processData",
        "QSharedPointer<FITSData>",
        "data",
        "updateProperty",
        "INDI::Property",
        "prop",
        "processTemperatureSource",
        "appendLogText",
        "logtext",
        "appendFocusLogText",
        "adjustFocusOffset",
        "useAbsoluteOffset",
        "setMountStatus",
        "ISD::Mount::Status",
        "newState",
        "setMountCoords",
        "SkyPoint",
        "ISD::Mount::PierSide",
        "pierSide",
        "dms",
        "ha",
        "toggleVideo",
        "enabled",
        "loadStellarSolverProfiles",
        "getStellarSolverProfiles",
        "opticalTrain",
        "setOpticalTrain",
        "adaptiveFocus",
        "showFirstFrame",
        "showLastFrame",
        "showPreviousFrame",
        "showNextFrame",
        "showPreviousAFRun",
        "showNextAFRun",
        "toggleSubframe",
        "enable",
        "checkAutoStarTimeout",
        "setAbsoluteFocusTicks",
        "updateBoxSize",
        "processCaptureTimeout",
        "processCaptureErrorDefault",
        "processCaptureError",
        "ISD::Camera::ErrorType",
        "type",
        "setCaptureComplete",
        "showFITSViewer",
        "toggleFocusingWidgetFullScreen",
        "setVideoStreamEnabled",
        "starDetectionFinished",
        "updateMeasurements",
        "startAbIns",
        "manualStart",
        "clearDataRequested",
        "resetHFRPlot",
        "onDustCapStatusChanged",
        "ISD::DustCap::Status",
        "status",
        "camera",
        "filterWheel",
        "setFilter",
        "canAutoFocus",
        "useFullField",
        "getHFR",
        "setExposure",
        "exposure",
        "setBinning",
        "binX",
        "binY",
        "setAutoStarEnabled",
        "setAutoSubFrameEnabled",
        "setAutoFocusParameters",
        "boxSize",
        "stepSize",
        "maxTravel",
        "tolerance",
        "resetFrame"
    };

    QtMocHelpers::UintData qt_methods {
        // Signal 'newLog'
        QtMocHelpers::SignalData<void(const QString &)>(1, 2, QMC::AccessPublic, QMetaType::Void, {{
            { QMetaType::QString, 3 },
        }}),
        // Signal 'newFocusLog'
        QtMocHelpers::SignalData<void(const QString &)>(4, 2, QMC::AccessPublic, QMetaType::Void, {{
            { QMetaType::QString, 3 },
        }}),
        // Signal 'newStatus'
        QtMocHelpers::SignalData<void(Ekos::FocusState, const QString &, const bool)>(5, 2, QMC::AccessPublic, QMetaType::Void, {{
            { 0x80000000 | 6, 7 }, { QMetaType::QString, 8 }, { QMetaType::Bool, 9 },
        }}),
        // Signal 'newStatus'
        QtMocHelpers::SignalData<void(Ekos::FocusState, const QString &)>(5, 2, QMC::AccessPublic | QMC::MethodCloned, QMetaType::Void, {{
            { 0x80000000 | 6, 7 }, { QMetaType::QString, 8 },
        }}),
        // Signal 'newHFR'
        QtMocHelpers::SignalData<void(double, int, bool, const QString &)>(10, 2, QMC::AccessPublic, QMetaType::Void, {{
            { QMetaType::Double, 11 }, { QMetaType::Int, 12 }, { QMetaType::Bool, 13 }, { QMetaType::QString, 8 },
        }}),
        // Signal 'newFocusTemperatureDelta'
        QtMocHelpers::SignalData<void(double, double, const QString &)>(14, 2, QMC::AccessPublic, QMetaType::Void, {{
            { QMetaType::Double, 15 }, { QMetaType::Double, 16 }, { QMetaType::QString, 8 },
        }}),
        // Signal 'inSequenceAF'
        QtMocHelpers::SignalData<void(bool, const QString &)>(17, 2, QMC::AccessPublic, QMetaType::Void, {{
            { QMetaType::Bool, 18 }, { QMetaType::QString, 8 },
        }}),
        // Signal 'absolutePositionChanged'
        QtMocHelpers::SignalData<void(int)>(19, 2, QMC::AccessPublic, QMetaType::Void, {{
            { QMetaType::Int, 20 },
        }}),
        // Signal 'focusPositionAdjusted'
        QtMocHelpers::SignalData<void()>(21, 2, QMC::AccessPublic, QMetaType::Void),
        // Signal 'focusAdaptiveComplete'
        QtMocHelpers::SignalData<void(bool, const QString &)>(22, 2, QMC::AccessPublic, QMetaType::Void, {{
            { QMetaType::Bool, 23 }, { QMetaType::QString, 8 },
        }}),
        // Signal 'focusAFOptimise'
        QtMocHelpers::SignalData<void()>(24, 2, QMC::AccessPublic, QMetaType::Void),
        // Signal 'trainChanged'
        QtMocHelpers::SignalData<void()>(25, 2, QMC::AccessPublic, QMetaType::Void),
        // Signal 'focuserChanged'
        QtMocHelpers::SignalData<void(int, bool)>(26, 2, QMC::AccessPublic, QMetaType::Void, {{
            { QMetaType::Int, 27 }, { QMetaType::Bool, 28 },
        }}),
        // Signal 'suspendGuiding'
        QtMocHelpers::SignalData<void()>(29, 2, QMC::AccessPublic, QMetaType::Void),
        // Signal 'resumeGuiding'
        QtMocHelpers::SignalData<void()>(30, 2, QMC::AccessPublic, QMetaType::Void),
        // Signal 'newImage'
        QtMocHelpers::SignalData<void(const QSharedPointer<FITSView> &)>(31, 2, QMC::AccessPublic, QMetaType::Void, {{
            { 0x80000000 | 32, 33 },
        }}),
        // Signal 'newStarPixmap'
        QtMocHelpers::SignalData<void(QPixmap &)>(34, 2, QMC::AccessPublic, QMetaType::Void, {{
            { 0x80000000 | 35, 2 },
        }}),
        // Signal 'settingsUpdated'
        QtMocHelpers::SignalData<void(const QVariantMap &)>(36, 2, QMC::AccessPublic, QMetaType::Void, {{
            { 0x80000000 | 37, 38 },
        }}),
        // Signal 'autofocusStarting'
        QtMocHelpers::SignalData<void(double, const QString &, AutofocusReason, const QString &)>(39, 2, QMC::AccessPublic, QMetaType::Void, {{
            { QMetaType::Double, 40 }, { QMetaType::QString, 41 }, { 0x80000000 | 42, 43 }, { QMetaType::QString, 44 },
        }}),
        // Signal 'autofocusComplete'
        QtMocHelpers::SignalData<void(double, const QString &, const QString &, const bool, const QString &, const QString &)>(45, 2, QMC::AccessPublic, QMetaType::Void, {{
            { QMetaType::Double, 40 }, { QMetaType::QString, 41 }, { QMetaType::QString, 46 }, { QMetaType::Bool, 47 },
            { QMetaType::QString, 48 }, { QMetaType::QString, 49 },
        }}),
        // Signal 'autofocusComplete'
        QtMocHelpers::SignalData<void(double, const QString &, const QString &, const bool, const QString &)>(45, 2, QMC::AccessPublic | QMC::MethodCloned, QMetaType::Void, {{
            { QMetaType::Double, 40 }, { QMetaType::QString, 41 }, { QMetaType::QString, 46 }, { QMetaType::Bool, 47 },
            { QMetaType::QString, 48 },
        }}),
        // Signal 'autofocusComplete'
        QtMocHelpers::SignalData<void(double, const QString &, const QString &, const bool)>(45, 2, QMC::AccessPublic | QMC::MethodCloned, QMetaType::Void, {{
            { QMetaType::Double, 40 }, { QMetaType::QString, 41 }, { QMetaType::QString, 46 }, { QMetaType::Bool, 47 },
        }}),
        // Signal 'autofocusAborted'
        QtMocHelpers::SignalData<void(const QString &, const QString &, const bool, const AutofocusFailReason, const QString &)>(50, 2, QMC::AccessPublic, QMetaType::Void, {{
            { QMetaType::QString, 41 }, { QMetaType::QString, 46 }, { QMetaType::Bool, 47 }, { 0x80000000 | 51, 52 },
            { QMetaType::QString, 53 },
        }}),
        // Signal 'newFocusAdvisorStage'
        QtMocHelpers::SignalData<void(int)>(54, 2, QMC::AccessPublic, QMetaType::Void, {{
            { QMetaType::Int, 55 },
        }}),
        // Signal 'newFocusAdvisorMessage'
        QtMocHelpers::SignalData<void(QString)>(56, 2, QMC::AccessPublic, QMetaType::Void, {{
            { QMetaType::QString, 57 },
        }}),
        // Signal 'adaptiveFocusComplete'
        QtMocHelpers::SignalData<void(const QString &, double, double, double, double, int, int, int, int, bool)>(58, 2, QMC::AccessPublic, QMetaType::Void, {{
            { QMetaType::QString, 41 }, { QMetaType::Double, 40 }, { QMetaType::Double, 59 }, { QMetaType::Double, 60 },
            { QMetaType::Double, 61 }, { QMetaType::Int, 62 }, { QMetaType::Int, 63 }, { QMetaType::Int, 64 },
            { QMetaType::Int, 12 }, { QMetaType::Bool, 65 },
        }}),
        // Signal 'initHFRPlot'
        QtMocHelpers::SignalData<void(QString, double, bool, bool, bool)>(66, 2, QMC::AccessPublic, QMetaType::Void, {{
            { QMetaType::QString, 67 }, { QMetaType::Double, 68 }, { QMetaType::Bool, 69 }, { QMetaType::Bool, 47 },
            { QMetaType::Bool, 70 },
        }}),
        // Signal 'newHFRPlotPosition'
        QtMocHelpers::SignalData<void(double, double, double, bool, int, bool)>(71, 2, QMC::AccessPublic, QMetaType::Void, {{
            { QMetaType::Double, 72 }, { QMetaType::Double, 11 }, { QMetaType::Double, 73 }, { QMetaType::Bool, 74 },
            { QMetaType::Int, 75 }, { QMetaType::Bool, 76 },
        }}),
        // Signal 'newHFRPlotPosition'
        QtMocHelpers::SignalData<void(double, double, double, bool, int)>(71, 2, QMC::AccessPublic | QMC::MethodCloned, QMetaType::Void, {{
            { QMetaType::Double, 72 }, { QMetaType::Double, 11 }, { QMetaType::Double, 73 }, { QMetaType::Bool, 74 },
            { QMetaType::Int, 75 },
        }}),
        // Signal 'drawPolynomial'
        QtMocHelpers::SignalData<void(PolynomialFit *, bool, bool, bool)>(77, 2, QMC::AccessPublic, QMetaType::Void, {{
            { 0x80000000 | 78, 79 }, { QMetaType::Bool, 80 }, { QMetaType::Bool, 81 }, { QMetaType::Bool, 76 },
        }}),
        // Signal 'drawPolynomial'
        QtMocHelpers::SignalData<void(PolynomialFit *, bool, bool)>(77, 2, QMC::AccessPublic | QMC::MethodCloned, QMetaType::Void, {{
            { 0x80000000 | 78, 79 }, { QMetaType::Bool, 80 }, { QMetaType::Bool, 81 },
        }}),
        // Signal 'drawCurve'
        QtMocHelpers::SignalData<void(CurveFitting *, bool, bool, bool)>(82, 2, QMC::AccessPublic, QMetaType::Void, {{
            { 0x80000000 | 83, 48 }, { QMetaType::Bool, 80 }, { QMetaType::Bool, 81 }, { QMetaType::Bool, 76 },
        }}),
        // Signal 'drawCurve'
        QtMocHelpers::SignalData<void(CurveFitting *, bool, bool)>(82, 2, QMC::AccessPublic | QMC::MethodCloned, QMetaType::Void, {{
            { 0x80000000 | 83, 48 }, { QMetaType::Bool, 80 }, { QMetaType::Bool, 81 },
        }}),
        // Signal 'minimumFound'
        QtMocHelpers::SignalData<void(double, double, bool)>(84, 2, QMC::AccessPublic, QMetaType::Void, {{
            { QMetaType::Double, 85 }, { QMetaType::Double, 86 }, { QMetaType::Bool, 76 },
        }}),
        // Signal 'minimumFound'
        QtMocHelpers::SignalData<void(double, double)>(84, 2, QMC::AccessPublic | QMC::MethodCloned, QMetaType::Void, {{
            { QMetaType::Double, 85 }, { QMetaType::Double, 86 },
        }}),
        // Signal 'drawCFZ'
        QtMocHelpers::SignalData<void(double, double, int, bool)>(87, 2, QMC::AccessPublic, QMetaType::Void, {{
            { QMetaType::Double, 88 }, { QMetaType::Double, 89 }, { QMetaType::Int, 90 }, { QMetaType::Bool, 91 },
        }}),
        // Signal 'redrawHFRPlot'
        QtMocHelpers::SignalData<void(PolynomialFit *, double, double)>(92, 2, QMC::AccessPublic, QMetaType::Void, {{
            { 0x80000000 | 78, 79 }, { QMetaType::Double, 85 }, { QMetaType::Double, 86 },
        }}),
        // Signal 'setTitle'
        QtMocHelpers::SignalData<void(const QString &, bool)>(93, 2, QMC::AccessPublic, QMetaType::Void, {{
            { QMetaType::QString, 49 }, { QMetaType::Bool, 76 },
        }}),
        // Signal 'setTitle'
        QtMocHelpers::SignalData<void(const QString &)>(93, 2, QMC::AccessPublic | QMC::MethodCloned, QMetaType::Void, {{
            { QMetaType::QString, 49 },
        }}),
        // Signal 'finalUpdates'
        QtMocHelpers::SignalData<void(const QString &, bool)>(94, 2, QMC::AccessPublic, QMetaType::Void, {{
            { QMetaType::QString, 49 }, { QMetaType::Bool, 76 },
        }}),
        // Signal 'finalUpdates'
        QtMocHelpers::SignalData<void(const QString &)>(94, 2, QMC::AccessPublic | QMC::MethodCloned, QMetaType::Void, {{
            { QMetaType::QString, 49 },
        }}),
        // Signal 'focuserTimedout'
        QtMocHelpers::SignalData<void(const QString &)>(95, 2, QMC::AccessPublic, QMetaType::Void, {{
            { QMetaType::QString, 96 },
        }}),
        // Signal 'driverTimedout'
        QtMocHelpers::SignalData<void(const QString &)>(97, 2, QMC::AccessPublic, QMetaType::Void, {{
            { QMetaType::QString, 98 },
        }}),
        // Slot 'start'
        QtMocHelpers::SlotData<void()>(99, 100, QMC::AccessPublic | QMC::MethodScriptable, QMetaType::Void),
        // Slot 'abort'
        QtMocHelpers::SlotData<void()>(101, 100, QMC::AccessPublic | QMC::MethodScriptable, QMetaType::Void),
        // Slot 'capture'
        QtMocHelpers::SlotData<void(double)>(102, 100, QMC::AccessPublic | QMC::MethodScriptable, QMetaType::Void, {{
            { QMetaType::Double, 103 },
        }}),
        // Slot 'capture'
        QtMocHelpers::SlotData<void()>(102, 100, QMC::AccessPublic | QMC::MethodCloned | QMC::MethodScriptable, QMetaType::Void),
        // Slot 'focusIn'
        QtMocHelpers::SlotData<bool(int, int)>(104, 2, QMC::AccessPublic | QMC::MethodScriptable, QMetaType::Bool, {{
            { QMetaType::Int, 105 }, { QMetaType::Int, 106 },
        }}),
        // Slot 'focusIn'
        QtMocHelpers::SlotData<bool(int)>(104, 2, QMC::AccessPublic | QMC::MethodCloned | QMC::MethodScriptable, QMetaType::Bool, {{
            { QMetaType::Int, 105 },
        }}),
        // Slot 'focusIn'
        QtMocHelpers::SlotData<bool()>(104, 2, QMC::AccessPublic | QMC::MethodCloned | QMC::MethodScriptable, QMetaType::Bool),
        // Slot 'focusOut'
        QtMocHelpers::SlotData<bool(int, int)>(107, 2, QMC::AccessPublic | QMC::MethodScriptable, QMetaType::Bool, {{
            { QMetaType::Int, 105 }, { QMetaType::Int, 106 },
        }}),
        // Slot 'focusOut'
        QtMocHelpers::SlotData<bool(int)>(107, 2, QMC::AccessPublic | QMC::MethodCloned | QMC::MethodScriptable, QMetaType::Bool, {{
            { QMetaType::Int, 105 },
        }}),
        // Slot 'focusOut'
        QtMocHelpers::SlotData<bool()>(107, 2, QMC::AccessPublic | QMC::MethodCloned | QMC::MethodScriptable, QMetaType::Bool),
        // Slot 'checkFocus'
        QtMocHelpers::SlotData<void(double)>(108, 100, QMC::AccessPublic | QMC::MethodScriptable, QMetaType::Void, {{
            { QMetaType::Double, 109 },
        }}),
        // Slot 'runAutoFocus'
        QtMocHelpers::SlotData<void(const AutofocusReason, const QString &)>(110, 2, QMC::AccessPublic, QMetaType::Void, {{
            { 0x80000000 | 42, 111 }, { QMetaType::QString, 44 },
        }}),
        // Slot 'startFraming'
        QtMocHelpers::SlotData<void()>(112, 2, QMC::AccessPublic, QMetaType::Void),
        // Slot 'resetFocuser'
        QtMocHelpers::SlotData<void()>(113, 2, QMC::AccessPublic, QMetaType::Void),
        // Slot 'checkStopFocus'
        QtMocHelpers::SlotData<void(bool)>(114, 2, QMC::AccessPublic, QMetaType::Void, {{
            { QMetaType::Bool, 101 },
        }}),
        // Slot 'meridianFlipStarted'
        QtMocHelpers::SlotData<void()>(115, 2, QMC::AccessPublic, QMetaType::Void),
        // Slot 'checkCamera'
        QtMocHelpers::SlotData<void()>(116, 2, QMC::AccessPublic, QMetaType::Void),
        // Slot 'syncCameraInfo'
        QtMocHelpers::SlotData<void()>(117, 2, QMC::AccessPublic, QMetaType::Void),
        // Slot 'syncCCDControls'
        QtMocHelpers::SlotData<void()>(118, 2, QMC::AccessPublic, QMetaType::Void),
        // Slot 'checkFocuser'
        QtMocHelpers::SlotData<void()>(119, 2, QMC::AccessPublic, QMetaType::Void),
        // Slot 'checkFilter'
        QtMocHelpers::SlotData<void()>(120, 2, QMC::AccessPublic, QMetaType::Void),
        // Slot 'checkTemperatureSource'
        QtMocHelpers::SlotData<void(const QString &)>(121, 2, QMC::AccessPublic, QMetaType::Void, {{
            { QMetaType::QString, 57 },
        }}),
        // Slot 'checkTemperatureSource'
        QtMocHelpers::SlotData<void()>(121, 2, QMC::AccessPublic | QMC::MethodCloned, QMetaType::Void),
        // Slot 'clearDataPoints'
        QtMocHelpers::SlotData<void()>(122, 2, QMC::AccessPublic, QMetaType::Void),
        // Slot 'clearCurrentRun'
        QtMocHelpers::SlotData<void(bool, bool)>(123, 2, QMC::AccessPublic, QMetaType::Void, {{
            { QMetaType::Bool, 124 }, { QMetaType::Bool, 125 },
        }}),
        // Slot 'focusStarSelected'
        QtMocHelpers::SlotData<void(int, int)>(126, 2, QMC::AccessPublic, QMetaType::Void, {{
            { QMetaType::Int, 127 }, { QMetaType::Int, 128 },
        }}),
        // Slot 'selectFocusStarFraction'
        QtMocHelpers::SlotData<void(double, double)>(129, 2, QMC::AccessPublic, QMetaType::Void, {{
            { QMetaType::Double, 127 }, { QMetaType::Double, 128 },
        }}),
        // Slot 'processData'
        QtMocHelpers::SlotData<void(const QSharedPointer<FITSData> &)>(130, 2, QMC::AccessPublic, QMetaType::Void, {{
            { 0x80000000 | 131, 132 },
        }}),
        // Slot 'updateProperty'
        QtMocHelpers::SlotData<void(INDI::Property)>(133, 2, QMC::AccessPublic, QMetaType::Void, {{
            { 0x80000000 | 134, 135 },
        }}),
        // Slot 'processTemperatureSource'
        QtMocHelpers::SlotData<void(INDI::Property)>(136, 2, QMC::AccessPublic, QMetaType::Void, {{
            { 0x80000000 | 134, 135 },
        }}),
        // Slot 'appendLogText'
        QtMocHelpers::SlotData<void(const QString &)>(137, 2, QMC::AccessPublic, QMetaType::Void, {{
            { QMetaType::QString, 138 },
        }}),
        // Slot 'appendFocusLogText'
        QtMocHelpers::SlotData<void(const QString &)>(139, 2, QMC::AccessPublic, QMetaType::Void, {{
            { QMetaType::QString, 3 },
        }}),
        // Slot 'adjustFocusOffset'
        QtMocHelpers::SlotData<void(int, bool)>(140, 2, QMC::AccessPublic, QMetaType::Void, {{
            { QMetaType::Int, 20 }, { QMetaType::Bool, 141 },
        }}),
        // Slot 'setMountStatus'
        QtMocHelpers::SlotData<void(ISD::Mount::Status)>(142, 2, QMC::AccessPublic, QMetaType::Void, {{
            { 0x80000000 | 143, 144 },
        }}),
        // Slot 'setMountCoords'
        QtMocHelpers::SlotData<void(const SkyPoint &, ISD::Mount::PierSide, const dms &)>(145, 2, QMC::AccessPublic, QMetaType::Void, {{
            { 0x80000000 | 146, 12 }, { 0x80000000 | 147, 148 }, { 0x80000000 | 149, 150 },
        }}),
        // Slot 'toggleVideo'
        QtMocHelpers::SlotData<void(bool)>(151, 2, QMC::AccessPublic, QMetaType::Void, {{
            { QMetaType::Bool, 152 },
        }}),
        // Slot 'loadStellarSolverProfiles'
        QtMocHelpers::SlotData<void()>(153, 2, QMC::AccessPublic, QMetaType::Void),
        // Slot 'getStellarSolverProfiles'
        QtMocHelpers::SlotData<QStringList()>(154, 2, QMC::AccessPublic, QMetaType::QStringList),
        // Slot 'opticalTrain'
        QtMocHelpers::SlotData<QString() const>(155, 2, QMC::AccessPublic, QMetaType::QString),
        // Slot 'setOpticalTrain'
        QtMocHelpers::SlotData<void(const QString &)>(156, 2, QMC::AccessPublic, QMetaType::Void, {{
            { QMetaType::QString, 20 },
        }}),
        // Slot 'adaptiveFocus'
        QtMocHelpers::SlotData<void()>(157, 2, QMC::AccessPublic, QMetaType::Void),
        // Slot 'showFirstFrame'
        QtMocHelpers::SlotData<void()>(158, 2, QMC::AccessPublic, QMetaType::Void),
        // Slot 'showLastFrame'
        QtMocHelpers::SlotData<void()>(159, 2, QMC::AccessPublic, QMetaType::Void),
        // Slot 'showPreviousFrame'
        QtMocHelpers::SlotData<void()>(160, 2, QMC::AccessPublic, QMetaType::Void),
        // Slot 'showNextFrame'
        QtMocHelpers::SlotData<void()>(161, 2, QMC::AccessPublic, QMetaType::Void),
        // Slot 'showPreviousAFRun'
        QtMocHelpers::SlotData<void()>(162, 2, QMC::AccessPublic, QMetaType::Void),
        // Slot 'showNextAFRun'
        QtMocHelpers::SlotData<void()>(163, 2, QMC::AccessPublic, QMetaType::Void),
        // Slot 'toggleSubframe'
        QtMocHelpers::SlotData<void(bool)>(164, 2, QMC::AccessPrivate, QMetaType::Void, {{
            { QMetaType::Bool, 165 },
        }}),
        // Slot 'checkAutoStarTimeout'
        QtMocHelpers::SlotData<void()>(166, 2, QMC::AccessPrivate, QMetaType::Void),
        // Slot 'setAbsoluteFocusTicks'
        QtMocHelpers::SlotData<void()>(167, 2, QMC::AccessPrivate, QMetaType::Void),
        // Slot 'updateBoxSize'
        QtMocHelpers::SlotData<void(int)>(168, 2, QMC::AccessPrivate, QMetaType::Void, {{
            { QMetaType::Int, 20 },
        }}),
        // Slot 'processCaptureTimeout'
        QtMocHelpers::SlotData<void()>(169, 2, QMC::AccessPrivate, QMetaType::Void),
        // Slot 'processCaptureErrorDefault'
        QtMocHelpers::SlotData<void()>(170, 2, QMC::AccessPrivate, QMetaType::Void),
        // Slot 'processCaptureError'
        QtMocHelpers::SlotData<void(ISD::Camera::ErrorType)>(171, 2, QMC::AccessPrivate, QMetaType::Void, {{
            { 0x80000000 | 172, 173 },
        }}),
        // Slot 'setCaptureComplete'
        QtMocHelpers::SlotData<void()>(174, 2, QMC::AccessPrivate, QMetaType::Void),
        // Slot 'showFITSViewer'
        QtMocHelpers::SlotData<void()>(175, 2, QMC::AccessPrivate, QMetaType::Void),
        // Slot 'toggleFocusingWidgetFullScreen'
        QtMocHelpers::SlotData<void()>(176, 2, QMC::AccessPrivate, QMetaType::Void),
        // Slot 'setVideoStreamEnabled'
        QtMocHelpers::SlotData<void(bool)>(177, 2, QMC::AccessPrivate, QMetaType::Void, {{
            { QMetaType::Bool, 152 },
        }}),
        // Slot 'starDetectionFinished'
        QtMocHelpers::SlotData<void()>(178, 2, QMC::AccessPrivate, QMetaType::Void),
        // Slot 'updateMeasurements'
        QtMocHelpers::SlotData<void()>(179, 2, QMC::AccessPrivate, QMetaType::Void),
        // Slot 'startAbIns'
        QtMocHelpers::SlotData<void()>(180, 2, QMC::AccessPrivate, QMetaType::Void),
        // Slot 'manualStart'
        QtMocHelpers::SlotData<void()>(181, 2, QMC::AccessPrivate, QMetaType::Void),
        // Slot 'clearDataRequested'
        QtMocHelpers::SlotData<void()>(182, 2, QMC::AccessPrivate, QMetaType::Void),
        // Slot 'resetHFRPlot'
        QtMocHelpers::SlotData<void()>(183, 2, QMC::AccessPrivate, QMetaType::Void),
        // Slot 'onDustCapStatusChanged'
        QtMocHelpers::SlotData<void(ISD::DustCap::Status)>(184, 2, QMC::AccessPrivate, QMetaType::Void, {{
            { 0x80000000 | 185, 186 },
        }}),
        // Method 'camera'
        QtMocHelpers::MethodData<QString()>(187, 2, QMC::AccessPublic | QMC::MethodScriptable, QMetaType::QString),
        // Method 'focuser'
        QtMocHelpers::MethodData<QString()>(96, 2, QMC::AccessPublic | QMC::MethodScriptable, QMetaType::QString),
        // Method 'filterWheel'
        QtMocHelpers::MethodData<QString()>(188, 2, QMC::AccessPublic | QMC::MethodScriptable, QMetaType::QString),
        // Method 'setFilter'
        QtMocHelpers::MethodData<bool(const QString &)>(189, 2, QMC::AccessPublic | QMC::MethodScriptable, QMetaType::Bool, {{
            { QMetaType::QString, 41 },
        }}),
        // Method 'filter'
        QtMocHelpers::MethodData<QString()>(41, 2, QMC::AccessPublic | QMC::MethodScriptable, QMetaType::QString),
        // Method 'canAutoFocus'
        QtMocHelpers::MethodData<bool()>(190, 2, QMC::AccessPublic | QMC::MethodScriptable, QMetaType::Bool),
        // Method 'useFullField'
        QtMocHelpers::MethodData<bool()>(191, 2, QMC::AccessPublic | QMC::MethodScriptable, QMetaType::Bool),
        // Method 'getHFR'
        QtMocHelpers::MethodData<double()>(192, 2, QMC::AccessPublic | QMC::MethodScriptable, QMetaType::Double),
        // Method 'setExposure'
        QtMocHelpers::MethodData<void(double)>(193, 100, QMC::AccessPublic | QMC::MethodScriptable, QMetaType::Void, {{
            { QMetaType::Double, 20 },
        }}),
        // Method 'exposure'
        QtMocHelpers::MethodData<double()>(194, 2, QMC::AccessPublic | QMC::MethodScriptable, QMetaType::Double),
        // Method 'setBinning'
        QtMocHelpers::MethodData<void(int, int)>(195, 100, QMC::AccessPublic | QMC::MethodScriptable, QMetaType::Void, {{
            { QMetaType::Int, 196 }, { QMetaType::Int, 197 },
        }}),
        // Method 'setAutoStarEnabled'
        QtMocHelpers::MethodData<void(bool)>(198, 100, QMC::AccessPublic | QMC::MethodScriptable, QMetaType::Void, {{
            { QMetaType::Bool, 165 },
        }}),
        // Method 'setAutoSubFrameEnabled'
        QtMocHelpers::MethodData<void(bool)>(199, 100, QMC::AccessPublic | QMC::MethodScriptable, QMetaType::Void, {{
            { QMetaType::Bool, 165 },
        }}),
        // Method 'setAutoFocusParameters'
        QtMocHelpers::MethodData<void(int, int, int, double)>(200, 100, QMC::AccessPublic | QMC::MethodScriptable, QMetaType::Void, {{
            { QMetaType::Int, 201 }, { QMetaType::Int, 202 }, { QMetaType::Int, 203 }, { QMetaType::Double, 204 },
        }}),
        // Method 'resetFrame'
        QtMocHelpers::MethodData<void()>(205, 100, QMC::AccessPublic | QMC::MethodScriptable, QMetaType::Void),
        // Method 'status'
        QtMocHelpers::MethodData<Ekos::FocusState()>(186, 2, QMC::AccessPublic | QMC::MethodScriptable, 0x80000000 | 6),
    };
    QtMocHelpers::UintData qt_properties {
    };
    QtMocHelpers::UintData qt_enums {
    };
    return QtMocHelpers::metaObjectData<Focus, qt_meta_tag_ZN4Ekos5FocusE_t>(QMC::MetaObjectFlag{}, qt_stringData,
            qt_methods, qt_properties, qt_enums);
}
Q_CONSTINIT const QMetaObject Ekos::Focus::staticMetaObject = { {
    QMetaObject::SuperData::link<QWidget::staticMetaObject>(),
    qt_staticMetaObjectStaticContent<qt_meta_tag_ZN4Ekos5FocusE_t>.stringdata,
    qt_staticMetaObjectStaticContent<qt_meta_tag_ZN4Ekos5FocusE_t>.data,
    qt_static_metacall,
    nullptr,
    qt_staticMetaObjectRelocatingContent<qt_meta_tag_ZN4Ekos5FocusE_t>.metaTypes,
    nullptr
} };

void Ekos::Focus::qt_static_metacall(QObject *_o, QMetaObject::Call _c, int _id, void **_a)
{
    auto *_t = static_cast<Focus *>(_o);
    if (_c == QMetaObject::InvokeMetaMethod) {
        switch (_id) {
        case 0: _t->newLog((*reinterpret_cast<std::add_pointer_t<QString>>(_a[1]))); break;
        case 1: _t->newFocusLog((*reinterpret_cast<std::add_pointer_t<QString>>(_a[1]))); break;
        case 2: _t->newStatus((*reinterpret_cast<std::add_pointer_t<Ekos::FocusState>>(_a[1])),(*reinterpret_cast<std::add_pointer_t<QString>>(_a[2])),(*reinterpret_cast<std::add_pointer_t<bool>>(_a[3]))); break;
        case 3: _t->newStatus((*reinterpret_cast<std::add_pointer_t<Ekos::FocusState>>(_a[1])),(*reinterpret_cast<std::add_pointer_t<QString>>(_a[2]))); break;
        case 4: _t->newHFR((*reinterpret_cast<std::add_pointer_t<double>>(_a[1])),(*reinterpret_cast<std::add_pointer_t<int>>(_a[2])),(*reinterpret_cast<std::add_pointer_t<bool>>(_a[3])),(*reinterpret_cast<std::add_pointer_t<QString>>(_a[4]))); break;
        case 5: _t->newFocusTemperatureDelta((*reinterpret_cast<std::add_pointer_t<double>>(_a[1])),(*reinterpret_cast<std::add_pointer_t<double>>(_a[2])),(*reinterpret_cast<std::add_pointer_t<QString>>(_a[3]))); break;
        case 6: _t->inSequenceAF((*reinterpret_cast<std::add_pointer_t<bool>>(_a[1])),(*reinterpret_cast<std::add_pointer_t<QString>>(_a[2]))); break;
        case 7: _t->absolutePositionChanged((*reinterpret_cast<std::add_pointer_t<int>>(_a[1]))); break;
        case 8: _t->focusPositionAdjusted(); break;
        case 9: _t->focusAdaptiveComplete((*reinterpret_cast<std::add_pointer_t<bool>>(_a[1])),(*reinterpret_cast<std::add_pointer_t<QString>>(_a[2]))); break;
        case 10: _t->focusAFOptimise(); break;
        case 11: _t->trainChanged(); break;
        case 12: _t->focuserChanged((*reinterpret_cast<std::add_pointer_t<int>>(_a[1])),(*reinterpret_cast<std::add_pointer_t<bool>>(_a[2]))); break;
        case 13: _t->suspendGuiding(); break;
        case 14: _t->resumeGuiding(); break;
        case 15: _t->newImage((*reinterpret_cast<std::add_pointer_t<QSharedPointer<FITSView>>>(_a[1]))); break;
        case 16: _t->newStarPixmap((*reinterpret_cast<std::add_pointer_t<QPixmap&>>(_a[1]))); break;
        case 17: _t->settingsUpdated((*reinterpret_cast<std::add_pointer_t<QVariantMap>>(_a[1]))); break;
        case 18: _t->autofocusStarting((*reinterpret_cast<std::add_pointer_t<double>>(_a[1])),(*reinterpret_cast<std::add_pointer_t<QString>>(_a[2])),(*reinterpret_cast<std::add_pointer_t<AutofocusReason>>(_a[3])),(*reinterpret_cast<std::add_pointer_t<QString>>(_a[4]))); break;
        case 19: _t->autofocusComplete((*reinterpret_cast<std::add_pointer_t<double>>(_a[1])),(*reinterpret_cast<std::add_pointer_t<QString>>(_a[2])),(*reinterpret_cast<std::add_pointer_t<QString>>(_a[3])),(*reinterpret_cast<std::add_pointer_t<bool>>(_a[4])),(*reinterpret_cast<std::add_pointer_t<QString>>(_a[5])),(*reinterpret_cast<std::add_pointer_t<QString>>(_a[6]))); break;
        case 20: _t->autofocusComplete((*reinterpret_cast<std::add_pointer_t<double>>(_a[1])),(*reinterpret_cast<std::add_pointer_t<QString>>(_a[2])),(*reinterpret_cast<std::add_pointer_t<QString>>(_a[3])),(*reinterpret_cast<std::add_pointer_t<bool>>(_a[4])),(*reinterpret_cast<std::add_pointer_t<QString>>(_a[5]))); break;
        case 21: _t->autofocusComplete((*reinterpret_cast<std::add_pointer_t<double>>(_a[1])),(*reinterpret_cast<std::add_pointer_t<QString>>(_a[2])),(*reinterpret_cast<std::add_pointer_t<QString>>(_a[3])),(*reinterpret_cast<std::add_pointer_t<bool>>(_a[4]))); break;
        case 22: _t->autofocusAborted((*reinterpret_cast<std::add_pointer_t<QString>>(_a[1])),(*reinterpret_cast<std::add_pointer_t<QString>>(_a[2])),(*reinterpret_cast<std::add_pointer_t<bool>>(_a[3])),(*reinterpret_cast<std::add_pointer_t<AutofocusFailReason>>(_a[4])),(*reinterpret_cast<std::add_pointer_t<QString>>(_a[5]))); break;
        case 23: _t->newFocusAdvisorStage((*reinterpret_cast<std::add_pointer_t<int>>(_a[1]))); break;
        case 24: _t->newFocusAdvisorMessage((*reinterpret_cast<std::add_pointer_t<QString>>(_a[1]))); break;
        case 25: _t->adaptiveFocusComplete((*reinterpret_cast<std::add_pointer_t<QString>>(_a[1])),(*reinterpret_cast<std::add_pointer_t<double>>(_a[2])),(*reinterpret_cast<std::add_pointer_t<double>>(_a[3])),(*reinterpret_cast<std::add_pointer_t<double>>(_a[4])),(*reinterpret_cast<std::add_pointer_t<double>>(_a[5])),(*reinterpret_cast<std::add_pointer_t<int>>(_a[6])),(*reinterpret_cast<std::add_pointer_t<int>>(_a[7])),(*reinterpret_cast<std::add_pointer_t<int>>(_a[8])),(*reinterpret_cast<std::add_pointer_t<int>>(_a[9])),(*reinterpret_cast<std::add_pointer_t<bool>>(_a[10]))); break;
        case 26: _t->initHFRPlot((*reinterpret_cast<std::add_pointer_t<QString>>(_a[1])),(*reinterpret_cast<std::add_pointer_t<double>>(_a[2])),(*reinterpret_cast<std::add_pointer_t<bool>>(_a[3])),(*reinterpret_cast<std::add_pointer_t<bool>>(_a[4])),(*reinterpret_cast<std::add_pointer_t<bool>>(_a[5]))); break;
        case 27: _t->newHFRPlotPosition((*reinterpret_cast<std::add_pointer_t<double>>(_a[1])),(*reinterpret_cast<std::add_pointer_t<double>>(_a[2])),(*reinterpret_cast<std::add_pointer_t<double>>(_a[3])),(*reinterpret_cast<std::add_pointer_t<bool>>(_a[4])),(*reinterpret_cast<std::add_pointer_t<int>>(_a[5])),(*reinterpret_cast<std::add_pointer_t<bool>>(_a[6]))); break;
        case 28: _t->newHFRPlotPosition((*reinterpret_cast<std::add_pointer_t<double>>(_a[1])),(*reinterpret_cast<std::add_pointer_t<double>>(_a[2])),(*reinterpret_cast<std::add_pointer_t<double>>(_a[3])),(*reinterpret_cast<std::add_pointer_t<bool>>(_a[4])),(*reinterpret_cast<std::add_pointer_t<int>>(_a[5]))); break;
        case 29: _t->drawPolynomial((*reinterpret_cast<std::add_pointer_t<PolynomialFit*>>(_a[1])),(*reinterpret_cast<std::add_pointer_t<bool>>(_a[2])),(*reinterpret_cast<std::add_pointer_t<bool>>(_a[3])),(*reinterpret_cast<std::add_pointer_t<bool>>(_a[4]))); break;
        case 30: _t->drawPolynomial((*reinterpret_cast<std::add_pointer_t<PolynomialFit*>>(_a[1])),(*reinterpret_cast<std::add_pointer_t<bool>>(_a[2])),(*reinterpret_cast<std::add_pointer_t<bool>>(_a[3]))); break;
        case 31: _t->drawCurve((*reinterpret_cast<std::add_pointer_t<CurveFitting*>>(_a[1])),(*reinterpret_cast<std::add_pointer_t<bool>>(_a[2])),(*reinterpret_cast<std::add_pointer_t<bool>>(_a[3])),(*reinterpret_cast<std::add_pointer_t<bool>>(_a[4]))); break;
        case 32: _t->drawCurve((*reinterpret_cast<std::add_pointer_t<CurveFitting*>>(_a[1])),(*reinterpret_cast<std::add_pointer_t<bool>>(_a[2])),(*reinterpret_cast<std::add_pointer_t<bool>>(_a[3]))); break;
        case 33: _t->minimumFound((*reinterpret_cast<std::add_pointer_t<double>>(_a[1])),(*reinterpret_cast<std::add_pointer_t<double>>(_a[2])),(*reinterpret_cast<std::add_pointer_t<bool>>(_a[3]))); break;
        case 34: _t->minimumFound((*reinterpret_cast<std::add_pointer_t<double>>(_a[1])),(*reinterpret_cast<std::add_pointer_t<double>>(_a[2]))); break;
        case 35: _t->drawCFZ((*reinterpret_cast<std::add_pointer_t<double>>(_a[1])),(*reinterpret_cast<std::add_pointer_t<double>>(_a[2])),(*reinterpret_cast<std::add_pointer_t<int>>(_a[3])),(*reinterpret_cast<std::add_pointer_t<bool>>(_a[4]))); break;
        case 36: _t->redrawHFRPlot((*reinterpret_cast<std::add_pointer_t<PolynomialFit*>>(_a[1])),(*reinterpret_cast<std::add_pointer_t<double>>(_a[2])),(*reinterpret_cast<std::add_pointer_t<double>>(_a[3]))); break;
        case 37: _t->setTitle((*reinterpret_cast<std::add_pointer_t<QString>>(_a[1])),(*reinterpret_cast<std::add_pointer_t<bool>>(_a[2]))); break;
        case 38: _t->setTitle((*reinterpret_cast<std::add_pointer_t<QString>>(_a[1]))); break;
        case 39: _t->finalUpdates((*reinterpret_cast<std::add_pointer_t<QString>>(_a[1])),(*reinterpret_cast<std::add_pointer_t<bool>>(_a[2]))); break;
        case 40: _t->finalUpdates((*reinterpret_cast<std::add_pointer_t<QString>>(_a[1]))); break;
        case 41: _t->focuserTimedout((*reinterpret_cast<std::add_pointer_t<QString>>(_a[1]))); break;
        case 42: _t->driverTimedout((*reinterpret_cast<std::add_pointer_t<QString>>(_a[1]))); break;
        case 43: _t->start(); break;
        case 44: _t->abort(); break;
        case 45: _t->capture((*reinterpret_cast<std::add_pointer_t<double>>(_a[1]))); break;
        case 46: _t->capture(); break;
        case 47: { bool _r = _t->focusIn((*reinterpret_cast<std::add_pointer_t<int>>(_a[1])),(*reinterpret_cast<std::add_pointer_t<int>>(_a[2])));
            if (_a[0]) *reinterpret_cast<bool*>(_a[0]) = std::move(_r); }  break;
        case 48: { bool _r = _t->focusIn((*reinterpret_cast<std::add_pointer_t<int>>(_a[1])));
            if (_a[0]) *reinterpret_cast<bool*>(_a[0]) = std::move(_r); }  break;
        case 49: { bool _r = _t->focusIn();
            if (_a[0]) *reinterpret_cast<bool*>(_a[0]) = std::move(_r); }  break;
        case 50: { bool _r = _t->focusOut((*reinterpret_cast<std::add_pointer_t<int>>(_a[1])),(*reinterpret_cast<std::add_pointer_t<int>>(_a[2])));
            if (_a[0]) *reinterpret_cast<bool*>(_a[0]) = std::move(_r); }  break;
        case 51: { bool _r = _t->focusOut((*reinterpret_cast<std::add_pointer_t<int>>(_a[1])));
            if (_a[0]) *reinterpret_cast<bool*>(_a[0]) = std::move(_r); }  break;
        case 52: { bool _r = _t->focusOut();
            if (_a[0]) *reinterpret_cast<bool*>(_a[0]) = std::move(_r); }  break;
        case 53: _t->checkFocus((*reinterpret_cast<std::add_pointer_t<double>>(_a[1]))); break;
        case 54: _t->runAutoFocus((*reinterpret_cast<std::add_pointer_t<AutofocusReason>>(_a[1])),(*reinterpret_cast<std::add_pointer_t<QString>>(_a[2]))); break;
        case 55: _t->startFraming(); break;
        case 56: _t->resetFocuser(); break;
        case 57: _t->checkStopFocus((*reinterpret_cast<std::add_pointer_t<bool>>(_a[1]))); break;
        case 58: _t->meridianFlipStarted(); break;
        case 59: _t->checkCamera(); break;
        case 60: _t->syncCameraInfo(); break;
        case 61: _t->syncCCDControls(); break;
        case 62: _t->checkFocuser(); break;
        case 63: _t->checkFilter(); break;
        case 64: _t->checkTemperatureSource((*reinterpret_cast<std::add_pointer_t<QString>>(_a[1]))); break;
        case 65: _t->checkTemperatureSource(); break;
        case 66: _t->clearDataPoints(); break;
        case 67: _t->clearCurrentRun((*reinterpret_cast<std::add_pointer_t<bool>>(_a[1])),(*reinterpret_cast<std::add_pointer_t<bool>>(_a[2]))); break;
        case 68: _t->focusStarSelected((*reinterpret_cast<std::add_pointer_t<int>>(_a[1])),(*reinterpret_cast<std::add_pointer_t<int>>(_a[2]))); break;
        case 69: _t->selectFocusStarFraction((*reinterpret_cast<std::add_pointer_t<double>>(_a[1])),(*reinterpret_cast<std::add_pointer_t<double>>(_a[2]))); break;
        case 70: _t->processData((*reinterpret_cast<std::add_pointer_t<QSharedPointer<FITSData>>>(_a[1]))); break;
        case 71: _t->updateProperty((*reinterpret_cast<std::add_pointer_t<INDI::Property>>(_a[1]))); break;
        case 72: _t->processTemperatureSource((*reinterpret_cast<std::add_pointer_t<INDI::Property>>(_a[1]))); break;
        case 73: _t->appendLogText((*reinterpret_cast<std::add_pointer_t<QString>>(_a[1]))); break;
        case 74: _t->appendFocusLogText((*reinterpret_cast<std::add_pointer_t<QString>>(_a[1]))); break;
        case 75: _t->adjustFocusOffset((*reinterpret_cast<std::add_pointer_t<int>>(_a[1])),(*reinterpret_cast<std::add_pointer_t<bool>>(_a[2]))); break;
        case 76: _t->setMountStatus((*reinterpret_cast<std::add_pointer_t<ISD::Mount::Status>>(_a[1]))); break;
        case 77: _t->setMountCoords((*reinterpret_cast<std::add_pointer_t<SkyPoint>>(_a[1])),(*reinterpret_cast<std::add_pointer_t<ISD::Mount::PierSide>>(_a[2])),(*reinterpret_cast<std::add_pointer_t<dms>>(_a[3]))); break;
        case 78: _t->toggleVideo((*reinterpret_cast<std::add_pointer_t<bool>>(_a[1]))); break;
        case 79: _t->loadStellarSolverProfiles(); break;
        case 80: { QStringList _r = _t->getStellarSolverProfiles();
            if (_a[0]) *reinterpret_cast<QStringList*>(_a[0]) = std::move(_r); }  break;
        case 81: { QString _r = _t->opticalTrain();
            if (_a[0]) *reinterpret_cast<QString*>(_a[0]) = std::move(_r); }  break;
        case 82: _t->setOpticalTrain((*reinterpret_cast<std::add_pointer_t<QString>>(_a[1]))); break;
        case 83: _t->adaptiveFocus(); break;
        case 84: _t->showFirstFrame(); break;
        case 85: _t->showLastFrame(); break;
        case 86: _t->showPreviousFrame(); break;
        case 87: _t->showNextFrame(); break;
        case 88: _t->showPreviousAFRun(); break;
        case 89: _t->showNextAFRun(); break;
        case 90: _t->toggleSubframe((*reinterpret_cast<std::add_pointer_t<bool>>(_a[1]))); break;
        case 91: _t->checkAutoStarTimeout(); break;
        case 92: _t->setAbsoluteFocusTicks(); break;
        case 93: _t->updateBoxSize((*reinterpret_cast<std::add_pointer_t<int>>(_a[1]))); break;
        case 94: _t->processCaptureTimeout(); break;
        case 95: _t->processCaptureErrorDefault(); break;
        case 96: _t->processCaptureError((*reinterpret_cast<std::add_pointer_t<ISD::Camera::ErrorType>>(_a[1]))); break;
        case 97: _t->setCaptureComplete(); break;
        case 98: _t->showFITSViewer(); break;
        case 99: _t->toggleFocusingWidgetFullScreen(); break;
        case 100: _t->setVideoStreamEnabled((*reinterpret_cast<std::add_pointer_t<bool>>(_a[1]))); break;
        case 101: _t->starDetectionFinished(); break;
        case 102: _t->updateMeasurements(); break;
        case 103: _t->startAbIns(); break;
        case 104: _t->manualStart(); break;
        case 105: _t->clearDataRequested(); break;
        case 106: _t->resetHFRPlot(); break;
        case 107: _t->onDustCapStatusChanged((*reinterpret_cast<std::add_pointer_t<ISD::DustCap::Status>>(_a[1]))); break;
        case 108: { QString _r = _t->camera();
            if (_a[0]) *reinterpret_cast<QString*>(_a[0]) = std::move(_r); }  break;
        case 109: { QString _r = _t->focuser();
            if (_a[0]) *reinterpret_cast<QString*>(_a[0]) = std::move(_r); }  break;
        case 110: { QString _r = _t->filterWheel();
            if (_a[0]) *reinterpret_cast<QString*>(_a[0]) = std::move(_r); }  break;
        case 111: { bool _r = _t->setFilter((*reinterpret_cast<std::add_pointer_t<QString>>(_a[1])));
            if (_a[0]) *reinterpret_cast<bool*>(_a[0]) = std::move(_r); }  break;
        case 112: { QString _r = _t->filter();
            if (_a[0]) *reinterpret_cast<QString*>(_a[0]) = std::move(_r); }  break;
        case 113: { bool _r = _t->canAutoFocus();
            if (_a[0]) *reinterpret_cast<bool*>(_a[0]) = std::move(_r); }  break;
        case 114: { bool _r = _t->useFullField();
            if (_a[0]) *reinterpret_cast<bool*>(_a[0]) = std::move(_r); }  break;
        case 115: { double _r = _t->getHFR();
            if (_a[0]) *reinterpret_cast<double*>(_a[0]) = std::move(_r); }  break;
        case 116: _t->setExposure((*reinterpret_cast<std::add_pointer_t<double>>(_a[1]))); break;
        case 117: { double _r = _t->exposure();
            if (_a[0]) *reinterpret_cast<double*>(_a[0]) = std::move(_r); }  break;
        case 118: _t->setBinning((*reinterpret_cast<std::add_pointer_t<int>>(_a[1])),(*reinterpret_cast<std::add_pointer_t<int>>(_a[2]))); break;
        case 119: _t->setAutoStarEnabled((*reinterpret_cast<std::add_pointer_t<bool>>(_a[1]))); break;
        case 120: _t->setAutoSubFrameEnabled((*reinterpret_cast<std::add_pointer_t<bool>>(_a[1]))); break;
        case 121: _t->setAutoFocusParameters((*reinterpret_cast<std::add_pointer_t<int>>(_a[1])),(*reinterpret_cast<std::add_pointer_t<int>>(_a[2])),(*reinterpret_cast<std::add_pointer_t<int>>(_a[3])),(*reinterpret_cast<std::add_pointer_t<double>>(_a[4]))); break;
        case 122: _t->resetFrame(); break;
        case 123: { Ekos::FocusState _r = _t->status();
            if (_a[0]) *reinterpret_cast<Ekos::FocusState*>(_a[0]) = std::move(_r); }  break;
        default: ;
        }
    }
    if (_c == QMetaObject::RegisterMethodArgumentMetaType) {
        switch (_id) {
        default: *reinterpret_cast<QMetaType *>(_a[0]) = QMetaType(); break;
        case 2:
            switch (*reinterpret_cast<int*>(_a[1])) {
            default: *reinterpret_cast<QMetaType *>(_a[0]) = QMetaType(); break;
            case 0:
                *reinterpret_cast<QMetaType *>(_a[0]) = QMetaType::fromType< Ekos::FocusState >(); break;
            }
            break;
        case 3:
            switch (*reinterpret_cast<int*>(_a[1])) {
            default: *reinterpret_cast<QMetaType *>(_a[0]) = QMetaType(); break;
            case 0:
                *reinterpret_cast<QMetaType *>(_a[0]) = QMetaType::fromType< Ekos::FocusState >(); break;
            }
            break;
        case 15:
            switch (*reinterpret_cast<int*>(_a[1])) {
            default: *reinterpret_cast<QMetaType *>(_a[0]) = QMetaType(); break;
            case 0:
                *reinterpret_cast<QMetaType *>(_a[0]) = QMetaType::fromType< QSharedPointer<FITSView> >(); break;
            }
            break;
        case 70:
            switch (*reinterpret_cast<int*>(_a[1])) {
            default: *reinterpret_cast<QMetaType *>(_a[0]) = QMetaType(); break;
            case 0:
                *reinterpret_cast<QMetaType *>(_a[0]) = QMetaType::fromType< QSharedPointer<FITSData> >(); break;
            }
            break;
        case 71:
            switch (*reinterpret_cast<int*>(_a[1])) {
            default: *reinterpret_cast<QMetaType *>(_a[0]) = QMetaType(); break;
            case 0:
                *reinterpret_cast<QMetaType *>(_a[0]) = QMetaType::fromType< INDI::Property >(); break;
            }
            break;
        case 72:
            switch (*reinterpret_cast<int*>(_a[1])) {
            default: *reinterpret_cast<QMetaType *>(_a[0]) = QMetaType(); break;
            case 0:
                *reinterpret_cast<QMetaType *>(_a[0]) = QMetaType::fromType< INDI::Property >(); break;
            }
            break;
        case 76:
            switch (*reinterpret_cast<int*>(_a[1])) {
            default: *reinterpret_cast<QMetaType *>(_a[0]) = QMetaType(); break;
            case 0:
                *reinterpret_cast<QMetaType *>(_a[0]) = QMetaType::fromType< ISD::Mount::Status >(); break;
            }
            break;
        case 77:
            switch (*reinterpret_cast<int*>(_a[1])) {
            default: *reinterpret_cast<QMetaType *>(_a[0]) = QMetaType(); break;
            case 1:
                *reinterpret_cast<QMetaType *>(_a[0]) = QMetaType::fromType< ISD::Mount::PierSide >(); break;
            case 0:
                *reinterpret_cast<QMetaType *>(_a[0]) = QMetaType::fromType< SkyPoint >(); break;
            }
            break;
        case 107:
            switch (*reinterpret_cast<int*>(_a[1])) {
            default: *reinterpret_cast<QMetaType *>(_a[0]) = QMetaType(); break;
            case 0:
                *reinterpret_cast<QMetaType *>(_a[0]) = QMetaType::fromType< ISD::DustCap::Status >(); break;
            }
            break;
        }
    }
    if (_c == QMetaObject::IndexOfMethod) {
        if (QtMocHelpers::indexOfMethod<void (Focus::*)(const QString & )>(_a, &Focus::newLog, 0))
            return;
        if (QtMocHelpers::indexOfMethod<void (Focus::*)(const QString & )>(_a, &Focus::newFocusLog, 1))
            return;
        if (QtMocHelpers::indexOfMethod<void (Focus::*)(Ekos::FocusState , const QString & , const bool )>(_a, &Focus::newStatus, 2))
            return;
        if (QtMocHelpers::indexOfMethod<void (Focus::*)(double , int , bool , const QString & )>(_a, &Focus::newHFR, 4))
            return;
        if (QtMocHelpers::indexOfMethod<void (Focus::*)(double , double , const QString & )>(_a, &Focus::newFocusTemperatureDelta, 5))
            return;
        if (QtMocHelpers::indexOfMethod<void (Focus::*)(bool , const QString & )>(_a, &Focus::inSequenceAF, 6))
            return;
        if (QtMocHelpers::indexOfMethod<void (Focus::*)(int )>(_a, &Focus::absolutePositionChanged, 7))
            return;
        if (QtMocHelpers::indexOfMethod<void (Focus::*)()>(_a, &Focus::focusPositionAdjusted, 8))
            return;
        if (QtMocHelpers::indexOfMethod<void (Focus::*)(bool , const QString & )>(_a, &Focus::focusAdaptiveComplete, 9))
            return;
        if (QtMocHelpers::indexOfMethod<void (Focus::*)()>(_a, &Focus::focusAFOptimise, 10))
            return;
        if (QtMocHelpers::indexOfMethod<void (Focus::*)()>(_a, &Focus::trainChanged, 11))
            return;
        if (QtMocHelpers::indexOfMethod<void (Focus::*)(int , bool )>(_a, &Focus::focuserChanged, 12))
            return;
        if (QtMocHelpers::indexOfMethod<void (Focus::*)()>(_a, &Focus::suspendGuiding, 13))
            return;
        if (QtMocHelpers::indexOfMethod<void (Focus::*)()>(_a, &Focus::resumeGuiding, 14))
            return;
        if (QtMocHelpers::indexOfMethod<void (Focus::*)(const QSharedPointer<FITSView> & )>(_a, &Focus::newImage, 15))
            return;
        if (QtMocHelpers::indexOfMethod<void (Focus::*)(QPixmap & )>(_a, &Focus::newStarPixmap, 16))
            return;
        if (QtMocHelpers::indexOfMethod<void (Focus::*)(const QVariantMap & )>(_a, &Focus::settingsUpdated, 17))
            return;
        if (QtMocHelpers::indexOfMethod<void (Focus::*)(double , const QString & , AutofocusReason , const QString & )>(_a, &Focus::autofocusStarting, 18))
            return;
        if (QtMocHelpers::indexOfMethod<void (Focus::*)(double , const QString & , const QString & , const bool , const QString & , const QString & )>(_a, &Focus::autofocusComplete, 19))
            return;
        if (QtMocHelpers::indexOfMethod<void (Focus::*)(const QString & , const QString & , const bool , const AutofocusFailReason , const QString & )>(_a, &Focus::autofocusAborted, 22))
            return;
        if (QtMocHelpers::indexOfMethod<void (Focus::*)(int )>(_a, &Focus::newFocusAdvisorStage, 23))
            return;
        if (QtMocHelpers::indexOfMethod<void (Focus::*)(QString )>(_a, &Focus::newFocusAdvisorMessage, 24))
            return;
        if (QtMocHelpers::indexOfMethod<void (Focus::*)(const QString & , double , double , double , double , int , int , int , int , bool )>(_a, &Focus::adaptiveFocusComplete, 25))
            return;
        if (QtMocHelpers::indexOfMethod<void (Focus::*)(QString , double , bool , bool , bool )>(_a, &Focus::initHFRPlot, 26))
            return;
        if (QtMocHelpers::indexOfMethod<void (Focus::*)(double , double , double , bool , int , bool )>(_a, &Focus::newHFRPlotPosition, 27))
            return;
        if (QtMocHelpers::indexOfMethod<void (Focus::*)(PolynomialFit * , bool , bool , bool )>(_a, &Focus::drawPolynomial, 29))
            return;
        if (QtMocHelpers::indexOfMethod<void (Focus::*)(CurveFitting * , bool , bool , bool )>(_a, &Focus::drawCurve, 31))
            return;
        if (QtMocHelpers::indexOfMethod<void (Focus::*)(double , double , bool )>(_a, &Focus::minimumFound, 33))
            return;
        if (QtMocHelpers::indexOfMethod<void (Focus::*)(double , double , int , bool )>(_a, &Focus::drawCFZ, 35))
            return;
        if (QtMocHelpers::indexOfMethod<void (Focus::*)(PolynomialFit * , double , double )>(_a, &Focus::redrawHFRPlot, 36))
            return;
        if (QtMocHelpers::indexOfMethod<void (Focus::*)(const QString & , bool )>(_a, &Focus::setTitle, 37))
            return;
        if (QtMocHelpers::indexOfMethod<void (Focus::*)(const QString & , bool )>(_a, &Focus::finalUpdates, 39))
            return;
        if (QtMocHelpers::indexOfMethod<void (Focus::*)(const QString & )>(_a, &Focus::focuserTimedout, 41))
            return;
        if (QtMocHelpers::indexOfMethod<void (Focus::*)(const QString & )>(_a, &Focus::driverTimedout, 42))
            return;
    }
}

const QMetaObject *Ekos::Focus::metaObject() const
{
    return QObject::d_ptr->metaObject ? QObject::d_ptr->dynamicMetaObject() : &staticMetaObject;
}

void *Ekos::Focus::qt_metacast(const char *_clname)
{
    if (!_clname) return nullptr;
    if (!strcmp(_clname, qt_staticMetaObjectStaticContent<qt_meta_tag_ZN4Ekos5FocusE_t>.strings))
        return static_cast<void*>(this);
    if (!strcmp(_clname, "Ui::Focus"))
        return static_cast< Ui::Focus*>(this);
    return QWidget::qt_metacast(_clname);
}

int Ekos::Focus::qt_metacall(QMetaObject::Call _c, int _id, void **_a)
{
    _id = QWidget::qt_metacall(_c, _id, _a);
    if (_id < 0)
        return _id;
    if (_c == QMetaObject::InvokeMetaMethod) {
        if (_id < 124)
            qt_static_metacall(this, _c, _id, _a);
        _id -= 124;
    }
    if (_c == QMetaObject::RegisterMethodArgumentMetaType) {
        if (_id < 124)
            qt_static_metacall(this, _c, _id, _a);
        _id -= 124;
    }
    return _id;
}

// SIGNAL 0
void Ekos::Focus::newLog(const QString & _t1)
{
    QMetaObject::activate<void>(this, &staticMetaObject, 0, nullptr, _t1);
}

// SIGNAL 1
void Ekos::Focus::newFocusLog(const QString & _t1)
{
    QMetaObject::activate<void>(this, &staticMetaObject, 1, nullptr, _t1);
}

// SIGNAL 2
void Ekos::Focus::newStatus(Ekos::FocusState _t1, const QString & _t2, const bool _t3)
{
    QMetaObject::activate<void>(this, &staticMetaObject, 2, nullptr, _t1, _t2, _t3);
}

// SIGNAL 4
void Ekos::Focus::newHFR(double _t1, int _t2, bool _t3, const QString & _t4)
{
    QMetaObject::activate<void>(this, &staticMetaObject, 4, nullptr, _t1, _t2, _t3, _t4);
}

// SIGNAL 5
void Ekos::Focus::newFocusTemperatureDelta(double _t1, double _t2, const QString & _t3)
{
    QMetaObject::activate<void>(this, &staticMetaObject, 5, nullptr, _t1, _t2, _t3);
}

// SIGNAL 6
void Ekos::Focus::inSequenceAF(bool _t1, const QString & _t2)
{
    QMetaObject::activate<void>(this, &staticMetaObject, 6, nullptr, _t1, _t2);
}

// SIGNAL 7
void Ekos::Focus::absolutePositionChanged(int _t1)
{
    QMetaObject::activate<void>(this, &staticMetaObject, 7, nullptr, _t1);
}

// SIGNAL 8
void Ekos::Focus::focusPositionAdjusted()
{
    QMetaObject::activate(this, &staticMetaObject, 8, nullptr);
}

// SIGNAL 9
void Ekos::Focus::focusAdaptiveComplete(bool _t1, const QString & _t2)
{
    QMetaObject::activate<void>(this, &staticMetaObject, 9, nullptr, _t1, _t2);
}

// SIGNAL 10
void Ekos::Focus::focusAFOptimise()
{
    QMetaObject::activate(this, &staticMetaObject, 10, nullptr);
}

// SIGNAL 11
void Ekos::Focus::trainChanged()
{
    QMetaObject::activate(this, &staticMetaObject, 11, nullptr);
}

// SIGNAL 12
void Ekos::Focus::focuserChanged(int _t1, bool _t2)
{
    QMetaObject::activate<void>(this, &staticMetaObject, 12, nullptr, _t1, _t2);
}

// SIGNAL 13
void Ekos::Focus::suspendGuiding()
{
    QMetaObject::activate(this, &staticMetaObject, 13, nullptr);
}

// SIGNAL 14
void Ekos::Focus::resumeGuiding()
{
    QMetaObject::activate(this, &staticMetaObject, 14, nullptr);
}

// SIGNAL 15
void Ekos::Focus::newImage(const QSharedPointer<FITSView> & _t1)
{
    QMetaObject::activate<void>(this, &staticMetaObject, 15, nullptr, _t1);
}

// SIGNAL 16
void Ekos::Focus::newStarPixmap(QPixmap & _t1)
{
    QMetaObject::activate<void>(this, &staticMetaObject, 16, nullptr, _t1);
}

// SIGNAL 17
void Ekos::Focus::settingsUpdated(const QVariantMap & _t1)
{
    QMetaObject::activate<void>(this, &staticMetaObject, 17, nullptr, _t1);
}

// SIGNAL 18
void Ekos::Focus::autofocusStarting(double _t1, const QString & _t2, AutofocusReason _t3, const QString & _t4)
{
    QMetaObject::activate<void>(this, &staticMetaObject, 18, nullptr, _t1, _t2, _t3, _t4);
}

// SIGNAL 19
void Ekos::Focus::autofocusComplete(double _t1, const QString & _t2, const QString & _t3, const bool _t4, const QString & _t5, const QString & _t6)
{
    QMetaObject::activate<void>(this, &staticMetaObject, 19, nullptr, _t1, _t2, _t3, _t4, _t5, _t6);
}

// SIGNAL 22
void Ekos::Focus::autofocusAborted(const QString & _t1, const QString & _t2, const bool _t3, const AutofocusFailReason _t4, const QString & _t5)
{
    QMetaObject::activate<void>(this, &staticMetaObject, 22, nullptr, _t1, _t2, _t3, _t4, _t5);
}

// SIGNAL 23
void Ekos::Focus::newFocusAdvisorStage(int _t1)
{
    QMetaObject::activate<void>(this, &staticMetaObject, 23, nullptr, _t1);
}

// SIGNAL 24
void Ekos::Focus::newFocusAdvisorMessage(QString _t1)
{
    QMetaObject::activate<void>(this, &staticMetaObject, 24, nullptr, _t1);
}

// SIGNAL 25
void Ekos::Focus::adaptiveFocusComplete(const QString & _t1, double _t2, double _t3, double _t4, double _t5, int _t6, int _t7, int _t8, int _t9, bool _t10)
{
    QMetaObject::activate<void>(this, &staticMetaObject, 25, nullptr, _t1, _t2, _t3, _t4, _t5, _t6, _t7, _t8, _t9, _t10);
}

// SIGNAL 26
void Ekos::Focus::initHFRPlot(QString _t1, double _t2, bool _t3, bool _t4, bool _t5)
{
    QMetaObject::activate<void>(this, &staticMetaObject, 26, nullptr, _t1, _t2, _t3, _t4, _t5);
}

// SIGNAL 27
void Ekos::Focus::newHFRPlotPosition(double _t1, double _t2, double _t3, bool _t4, int _t5, bool _t6)
{
    QMetaObject::activate<void>(this, &staticMetaObject, 27, nullptr, _t1, _t2, _t3, _t4, _t5, _t6);
}

// SIGNAL 29
void Ekos::Focus::drawPolynomial(PolynomialFit * _t1, bool _t2, bool _t3, bool _t4)
{
    QMetaObject::activate<void>(this, &staticMetaObject, 29, nullptr, _t1, _t2, _t3, _t4);
}

// SIGNAL 31
void Ekos::Focus::drawCurve(CurveFitting * _t1, bool _t2, bool _t3, bool _t4)
{
    QMetaObject::activate<void>(this, &staticMetaObject, 31, nullptr, _t1, _t2, _t3, _t4);
}

// SIGNAL 33
void Ekos::Focus::minimumFound(double _t1, double _t2, bool _t3)
{
    QMetaObject::activate<void>(this, &staticMetaObject, 33, nullptr, _t1, _t2, _t3);
}

// SIGNAL 35
void Ekos::Focus::drawCFZ(double _t1, double _t2, int _t3, bool _t4)
{
    QMetaObject::activate<void>(this, &staticMetaObject, 35, nullptr, _t1, _t2, _t3, _t4);
}

// SIGNAL 36
void Ekos::Focus::redrawHFRPlot(PolynomialFit * _t1, double _t2, double _t3)
{
    QMetaObject::activate<void>(this, &staticMetaObject, 36, nullptr, _t1, _t2, _t3);
}

// SIGNAL 37
void Ekos::Focus::setTitle(const QString & _t1, bool _t2)
{
    QMetaObject::activate<void>(this, &staticMetaObject, 37, nullptr, _t1, _t2);
}

// SIGNAL 39
void Ekos::Focus::finalUpdates(const QString & _t1, bool _t2)
{
    QMetaObject::activate<void>(this, &staticMetaObject, 39, nullptr, _t1, _t2);
}

// SIGNAL 41
void Ekos::Focus::focuserTimedout(const QString & _t1)
{
    QMetaObject::activate<void>(this, &staticMetaObject, 41, nullptr, _t1);
}

// SIGNAL 42
void Ekos::Focus::driverTimedout(const QString & _t1)
{
    QMetaObject::activate<void>(this, &staticMetaObject, 42, nullptr, _t1);
}
QT_WARNING_POP
