/********************************************************************************
** Form generated from reading UI file 'align.ui'
**
** Created by: Qt User Interface Compiler version 6.11.1
**
** WARNING! All changes made in this file will be lost when recompiling UI file!
********************************************************************************/

#ifndef UI_ALIGN_H
#define UI_ALIGN_H

#include <QtCore/QVariant>
#include <QtGui/QIcon>
#include <QtWidgets/QApplication>
#include <QtWidgets/QButtonGroup>
#include <QtWidgets/QCheckBox>
#include <QtWidgets/QComboBox>
#include <QtWidgets/QDoubleSpinBox>
#include <QtWidgets/QGridLayout>
#include <QtWidgets/QGroupBox>
#include <QtWidgets/QHBoxLayout>
#include <QtWidgets/QHeaderView>
#include <QtWidgets/QLabel>
#include <QtWidgets/QLineEdit>
#include <QtWidgets/QPushButton>
#include <QtWidgets/QRadioButton>
#include <QtWidgets/QSpacerItem>
#include <QtWidgets/QSpinBox>
#include <QtWidgets/QSplitter>
#include <QtWidgets/QTabWidget>
#include <QtWidgets/QTableWidget>
#include <QtWidgets/QVBoxLayout>
#include <QtWidgets/QWidget>
#include <klocalizedstring.h>
#include "auxiliary/qcustomplot.h"

QT_BEGIN_NAMESPACE

class Ui_Align
{
public:
    QHBoxLayout *horizontalLayout_2;
    QSplitter *mainSplitter;
    QWidget *layoutWidget;
    QVBoxLayout *leftLayout;
    QHBoxLayout *trainLayout;
    QLabel *trainLabel;
    QComboBox *opticalTrainCombo;
    QPushButton *trainB;
    QHBoxLayout *controlLayout;
    QGroupBox *controlBox;
    QVBoxLayout *verticalLayout_4;
    QPushButton *solveB;
    QPushButton *loadSlewB;
    QHBoxLayout *stopLayout;
    QPushButton *stopB;
    QGroupBox *gotoBox;
    QVBoxLayout *verticalLayout_7;
    QRadioButton *syncR;
    QRadioButton *slewR;
    QRadioButton *nothingR;
    QGroupBox *telescopeCoordinateGroup;
    QGridLayout *gridLayout;
    QSpinBox *alignAccuracyThreshold;
    QLabel *label_13;
    QLineEdit *ScopeDecOut;
    QLabel *label_22;
    QLineEdit *ScopeRAOut;
    QSpinBox *alignSettlingTime;
    QLabel *label_12;
    QLabel *label_9;
    QGroupBox *solutionCoordinatesGroupBox;
    QGridLayout *gridLayout_2;
    QLabel *label_8;
    QLineEdit *SolverRAOut;
    QLabel *label_6;
    QLabel *err;
    QLineEdit *errOut;
    QLabel *label_2;
    QLabel *label_17;
    QLineEdit *SolverDecOut;
    QLabel *label_10;
    QLineEdit *PAOut;
    QLineEdit *pixScaleOut;
    QLabel *label_14;
    QLineEdit *FocalLengthOut;
    QLabel *label_16;
    QLineEdit *FocalRatioOut;
    QLineEdit *FOVOut;
    QLabel *label;
    QLineEdit *ReducerOut;
    QGroupBox *plateSolverOptionsGroup;
    QGridLayout *gridLayout_3;
    QLabel *label_5;
    QLabel *label_18;
    QComboBox *alignFilter;
    QPushButton *showFITSViewerB;
    QCheckBox *alignDarkFrame;
    QComboBox *alignBinning;
    QPushButton *toggleFullScreenB;
    QDoubleSpinBox *alignExposure;
    QDoubleSpinBox *alignGain;
    QLabel *FilterPosLabel;
    QComboBox *alignISO;
    QLabel *label_7;
    QPushButton *rotatorB;
    QLabel *label_11;
    QCheckBox *alignUseCurrentFilter;
    QGroupBox *stellarSolverOptionsGroup;
    QHBoxLayout *horizontalLayout;
    QRadioButton *localSolverR;
    QRadioButton *remoteSolverR;
    QSpacerItem *horizontalSpacer;
    QSplitter *rightLayout;
    QWidget *alignWidget;
    QTabWidget *tabWidget;
    QWidget *solutionResults;
    QVBoxLayout *verticalLayout_11;
    QLabel *label_15;
    QSplitter *alignSplitter;
    QWidget *verticalLayoutWidget;
    QVBoxLayout *verticalLayout_20;
    QTableWidget *solutionTable;
    QHBoxLayout *horizontalLayout_19;
    QPushButton *clearAllSolutionsB;
    QPushButton *removeSolutionB;
    QPushButton *exportSolutionsCSV;
    QPushButton *autoScaleGraphB;
    QSpacerItem *horizontalSpacer_11;
    QPushButton *mountModelB;
    QCustomPlot *alignPlot;
    QButtonGroup *gotoModeButtonGroup;
    QButtonGroup *solverModeButtonGroup;

    void setupUi(QWidget *Align)
    {
        if (Align->objectName().isEmpty())
            Align->setObjectName("Align");
        Align->resize(648, 640);
        horizontalLayout_2 = new QHBoxLayout(Align);
        horizontalLayout_2->setObjectName("horizontalLayout_2");
        mainSplitter = new QSplitter(Align);
        mainSplitter->setObjectName("mainSplitter");
        mainSplitter->setOrientation(Qt::Horizontal);
        layoutWidget = new QWidget(mainSplitter);
        layoutWidget->setObjectName("layoutWidget");
        leftLayout = new QVBoxLayout(layoutWidget);
        leftLayout->setSpacing(3);
        leftLayout->setObjectName("leftLayout");
        leftLayout->setContentsMargins(0, 0, 0, 0);
        trainLayout = new QHBoxLayout();
        trainLayout->setSpacing(3);
        trainLayout->setObjectName("trainLayout");
        trainLabel = new QLabel(layoutWidget);
        trainLabel->setObjectName("trainLabel");

        trainLayout->addWidget(trainLabel);

        opticalTrainCombo = new QComboBox(layoutWidget);
        opticalTrainCombo->setObjectName("opticalTrainCombo");
        QSizePolicy sizePolicy(QSizePolicy::Policy::MinimumExpanding, QSizePolicy::Policy::Fixed);
        sizePolicy.setHorizontalStretch(0);
        sizePolicy.setVerticalStretch(0);
        sizePolicy.setHeightForWidth(opticalTrainCombo->sizePolicy().hasHeightForWidth());
        opticalTrainCombo->setSizePolicy(sizePolicy);
        opticalTrainCombo->setMinimumSize(QSize(0, 32));

        trainLayout->addWidget(opticalTrainCombo);

        trainB = new QPushButton(layoutWidget);
        trainB->setObjectName("trainB");
        trainB->setEnabled(false);
        trainB->setMinimumSize(QSize(24, 24));
        trainB->setMaximumSize(QSize(16777215, 32));
        QIcon icon(QIcon::fromTheme(QString::fromUtf8("document-edit")));
        trainB->setIcon(icon);
        trainB->setIconSize(QSize(24, 24));

        trainLayout->addWidget(trainB);


        leftLayout->addLayout(trainLayout);

        controlLayout = new QHBoxLayout();
        controlLayout->setSpacing(3);
        controlLayout->setObjectName("controlLayout");
        controlBox = new QGroupBox(layoutWidget);
        controlBox->setObjectName("controlBox");
        controlBox->setAlignment(Qt::AlignLeading|Qt::AlignLeft|Qt::AlignVCenter);
        verticalLayout_4 = new QVBoxLayout(controlBox);
        verticalLayout_4->setSpacing(3);
        verticalLayout_4->setObjectName("verticalLayout_4");
        verticalLayout_4->setContentsMargins(3, 3, 3, 3);
        solveB = new QPushButton(controlBox);
        solveB->setObjectName("solveB");
        solveB->setEnabled(true);
        solveB->setAutoDefault(true);

        verticalLayout_4->addWidget(solveB);

        loadSlewB = new QPushButton(controlBox);
        loadSlewB->setObjectName("loadSlewB");

        verticalLayout_4->addWidget(loadSlewB);

        stopLayout = new QHBoxLayout();
        stopLayout->setObjectName("stopLayout");
        stopB = new QPushButton(controlBox);
        stopB->setObjectName("stopB");
        stopB->setEnabled(false);

        stopLayout->addWidget(stopB);


        verticalLayout_4->addLayout(stopLayout);


        controlLayout->addWidget(controlBox);

        gotoBox = new QGroupBox(layoutWidget);
        gotoBox->setObjectName("gotoBox");
        verticalLayout_7 = new QVBoxLayout(gotoBox);
        verticalLayout_7->setSpacing(3);
        verticalLayout_7->setObjectName("verticalLayout_7");
        verticalLayout_7->setContentsMargins(3, 3, 3, 3);
        syncR = new QRadioButton(gotoBox);
        gotoModeButtonGroup = new QButtonGroup(Align);
        gotoModeButtonGroup->setObjectName("gotoModeButtonGroup");
        gotoModeButtonGroup->addButton(syncR);
        syncR->setObjectName("syncR");
        syncR->setChecked(true);

        verticalLayout_7->addWidget(syncR);

        slewR = new QRadioButton(gotoBox);
        gotoModeButtonGroup->addButton(slewR);
        slewR->setObjectName("slewR");

        verticalLayout_7->addWidget(slewR);

        nothingR = new QRadioButton(gotoBox);
        gotoModeButtonGroup->addButton(nothingR);
        nothingR->setObjectName("nothingR");

        verticalLayout_7->addWidget(nothingR);


        controlLayout->addWidget(gotoBox);


        leftLayout->addLayout(controlLayout);

        telescopeCoordinateGroup = new QGroupBox(layoutWidget);
        telescopeCoordinateGroup->setObjectName("telescopeCoordinateGroup");
        gridLayout = new QGridLayout(telescopeCoordinateGroup);
        gridLayout->setSpacing(3);
        gridLayout->setObjectName("gridLayout");
        gridLayout->setContentsMargins(3, 3, 3, 3);
        alignAccuracyThreshold = new QSpinBox(telescopeCoordinateGroup);
        alignAccuracyThreshold->setObjectName("alignAccuracyThreshold");
        alignAccuracyThreshold->setMinimum(1);
        alignAccuracyThreshold->setMaximum(1200);
        alignAccuracyThreshold->setSingleStep(10);
        alignAccuracyThreshold->setValue(30);

        gridLayout->addWidget(alignAccuracyThreshold, 0, 3, 1, 1);

        label_13 = new QLabel(telescopeCoordinateGroup);
        label_13->setObjectName("label_13");

        gridLayout->addWidget(label_13, 1, 0, 1, 1);

        ScopeDecOut = new QLineEdit(telescopeCoordinateGroup);
        ScopeDecOut->setObjectName("ScopeDecOut");
        ScopeDecOut->setReadOnly(true);

        gridLayout->addWidget(ScopeDecOut, 1, 1, 1, 1);

        label_22 = new QLabel(telescopeCoordinateGroup);
        label_22->setObjectName("label_22");

        gridLayout->addWidget(label_22, 1, 2, 1, 1);

        ScopeRAOut = new QLineEdit(telescopeCoordinateGroup);
        ScopeRAOut->setObjectName("ScopeRAOut");
        ScopeRAOut->setReadOnly(true);

        gridLayout->addWidget(ScopeRAOut, 0, 1, 1, 1);

        alignSettlingTime = new QSpinBox(telescopeCoordinateGroup);
        alignSettlingTime->setObjectName("alignSettlingTime");
        alignSettlingTime->setMaximum(15000);
        alignSettlingTime->setSingleStep(100);

        gridLayout->addWidget(alignSettlingTime, 1, 3, 1, 1);

        label_12 = new QLabel(telescopeCoordinateGroup);
        label_12->setObjectName("label_12");

        gridLayout->addWidget(label_12, 0, 0, 1, 1);

        label_9 = new QLabel(telescopeCoordinateGroup);
        label_9->setObjectName("label_9");

        gridLayout->addWidget(label_9, 0, 2, 1, 1);


        leftLayout->addWidget(telescopeCoordinateGroup);

        solutionCoordinatesGroupBox = new QGroupBox(layoutWidget);
        solutionCoordinatesGroupBox->setObjectName("solutionCoordinatesGroupBox");
        gridLayout_2 = new QGridLayout(solutionCoordinatesGroupBox);
        gridLayout_2->setSpacing(3);
        gridLayout_2->setObjectName("gridLayout_2");
        gridLayout_2->setContentsMargins(3, 3, 3, 3);
        label_8 = new QLabel(solutionCoordinatesGroupBox);
        label_8->setObjectName("label_8");

        gridLayout_2->addWidget(label_8, 3, 0, 1, 1);

        SolverRAOut = new QLineEdit(solutionCoordinatesGroupBox);
        SolverRAOut->setObjectName("SolverRAOut");
        SolverRAOut->setReadOnly(true);

        gridLayout_2->addWidget(SolverRAOut, 0, 1, 1, 1);

        label_6 = new QLabel(solutionCoordinatesGroupBox);
        label_6->setObjectName("label_6");

        gridLayout_2->addWidget(label_6, 0, 2, 1, 1);

        err = new QLabel(solutionCoordinatesGroupBox);
        err->setObjectName("err");

        gridLayout_2->addWidget(err, 1, 0, 1, 1);

        errOut = new QLineEdit(solutionCoordinatesGroupBox);
        errOut->setObjectName("errOut");
        errOut->setReadOnly(true);

        gridLayout_2->addWidget(errOut, 1, 1, 1, 3);

        label_2 = new QLabel(solutionCoordinatesGroupBox);
        label_2->setObjectName("label_2");

        gridLayout_2->addWidget(label_2, 0, 0, 1, 1);

        label_17 = new QLabel(solutionCoordinatesGroupBox);
        label_17->setObjectName("label_17");

        gridLayout_2->addWidget(label_17, 2, 0, 1, 1);

        SolverDecOut = new QLineEdit(solutionCoordinatesGroupBox);
        SolverDecOut->setObjectName("SolverDecOut");
        SolverDecOut->setReadOnly(true);

        gridLayout_2->addWidget(SolverDecOut, 0, 3, 1, 1);

        label_10 = new QLabel(solutionCoordinatesGroupBox);
        label_10->setObjectName("label_10");

        gridLayout_2->addWidget(label_10, 2, 2, 1, 1);

        PAOut = new QLineEdit(solutionCoordinatesGroupBox);
        PAOut->setObjectName("PAOut");
        PAOut->setReadOnly(true);

        gridLayout_2->addWidget(PAOut, 2, 3, 1, 1);

        pixScaleOut = new QLineEdit(solutionCoordinatesGroupBox);
        pixScaleOut->setObjectName("pixScaleOut");
        pixScaleOut->setReadOnly(true);

        gridLayout_2->addWidget(pixScaleOut, 2, 1, 1, 1);

        label_14 = new QLabel(solutionCoordinatesGroupBox);
        label_14->setObjectName("label_14");

        gridLayout_2->addWidget(label_14, 4, 0, 1, 1);

        FocalLengthOut = new QLineEdit(solutionCoordinatesGroupBox);
        FocalLengthOut->setObjectName("FocalLengthOut");
        FocalLengthOut->setReadOnly(true);

        gridLayout_2->addWidget(FocalLengthOut, 4, 1, 1, 1);

        label_16 = new QLabel(solutionCoordinatesGroupBox);
        label_16->setObjectName("label_16");

        gridLayout_2->addWidget(label_16, 4, 2, 1, 1);

        FocalRatioOut = new QLineEdit(solutionCoordinatesGroupBox);
        FocalRatioOut->setObjectName("FocalRatioOut");
        FocalRatioOut->setReadOnly(true);

        gridLayout_2->addWidget(FocalRatioOut, 4, 3, 1, 1);

        FOVOut = new QLineEdit(solutionCoordinatesGroupBox);
        FOVOut->setObjectName("FOVOut");
        FOVOut->setReadOnly(false);

        gridLayout_2->addWidget(FOVOut, 3, 1, 1, 1);

        label = new QLabel(solutionCoordinatesGroupBox);
        label->setObjectName("label");

        gridLayout_2->addWidget(label, 3, 2, 1, 1);

        ReducerOut = new QLineEdit(solutionCoordinatesGroupBox);
        ReducerOut->setObjectName("ReducerOut");

        gridLayout_2->addWidget(ReducerOut, 3, 3, 1, 1);


        leftLayout->addWidget(solutionCoordinatesGroupBox);

        plateSolverOptionsGroup = new QGroupBox(layoutWidget);
        plateSolverOptionsGroup->setObjectName("plateSolverOptionsGroup");
        gridLayout_3 = new QGridLayout(plateSolverOptionsGroup);
        gridLayout_3->setSpacing(3);
        gridLayout_3->setObjectName("gridLayout_3");
        gridLayout_3->setContentsMargins(3, 3, 3, 3);
        label_5 = new QLabel(plateSolverOptionsGroup);
        label_5->setObjectName("label_5");

        gridLayout_3->addWidget(label_5, 2, 2, 1, 1);

        label_18 = new QLabel(plateSolverOptionsGroup);
        label_18->setObjectName("label_18");

        gridLayout_3->addWidget(label_18, 2, 0, 1, 1);

        alignFilter = new QComboBox(plateSolverOptionsGroup);
        alignFilter->setObjectName("alignFilter");

        gridLayout_3->addWidget(alignFilter, 5, 1, 1, 1);

        showFITSViewerB = new QPushButton(plateSolverOptionsGroup);
        showFITSViewerB->setObjectName("showFITSViewerB");
        showFITSViewerB->setMinimumSize(QSize(24, 24));
        showFITSViewerB->setMaximumSize(QSize(16777215, 32));
        showFITSViewerB->setIconSize(QSize(24, 24));

        gridLayout_3->addWidget(showFITSViewerB, 1, 4, 1, 1);

        alignDarkFrame = new QCheckBox(plateSolverOptionsGroup);
        alignDarkFrame->setObjectName("alignDarkFrame");

        gridLayout_3->addWidget(alignDarkFrame, 3, 3, 1, 2);

        alignBinning = new QComboBox(plateSolverOptionsGroup);
        alignBinning->setObjectName("alignBinning");

        gridLayout_3->addWidget(alignBinning, 2, 1, 1, 1);

        toggleFullScreenB = new QPushButton(plateSolverOptionsGroup);
        toggleFullScreenB->setObjectName("toggleFullScreenB");
        toggleFullScreenB->setMinimumSize(QSize(24, 24));
        toggleFullScreenB->setMaximumSize(QSize(16777215, 32));
        toggleFullScreenB->setIconSize(QSize(24, 24));

        gridLayout_3->addWidget(toggleFullScreenB, 1, 3, 1, 1);

        alignExposure = new QDoubleSpinBox(plateSolverOptionsGroup);
        alignExposure->setObjectName("alignExposure");
        alignExposure->setMinimum(0.100000000000000);
        alignExposure->setMaximum(300.000000000000000);
        alignExposure->setSingleStep(1.000000000000000);
        alignExposure->setValue(5.000000000000000);

        gridLayout_3->addWidget(alignExposure, 1, 1, 1, 2);

        alignGain = new QDoubleSpinBox(plateSolverOptionsGroup);
        alignGain->setObjectName("alignGain");
        sizePolicy.setHeightForWidth(alignGain->sizePolicy().hasHeightForWidth());
        alignGain->setSizePolicy(sizePolicy);
        alignGain->setDecimals(1);
        alignGain->setMaximum(10000.000000000000000);
        alignGain->setSingleStep(10.000000000000000);

        gridLayout_3->addWidget(alignGain, 2, 3, 1, 2);

        FilterPosLabel = new QLabel(plateSolverOptionsGroup);
        FilterPosLabel->setObjectName("FilterPosLabel");

        gridLayout_3->addWidget(FilterPosLabel, 5, 0, 1, 1);

        alignISO = new QComboBox(plateSolverOptionsGroup);
        alignISO->setObjectName("alignISO");

        gridLayout_3->addWidget(alignISO, 3, 1, 1, 1);

        label_7 = new QLabel(plateSolverOptionsGroup);
        label_7->setObjectName("label_7");

        gridLayout_3->addWidget(label_7, 1, 0, 1, 1);

        rotatorB = new QPushButton(plateSolverOptionsGroup);
        rotatorB->setObjectName("rotatorB");
        rotatorB->setEnabled(false);
        rotatorB->setMinimumSize(QSize(24, 24));
        QIcon icon1(QIcon::fromTheme(QString::fromUtf8("rotation-allowed")));
        rotatorB->setIcon(icon1);
        rotatorB->setIconSize(QSize(24, 24));

        gridLayout_3->addWidget(rotatorB, 3, 2, 1, 1);

        label_11 = new QLabel(plateSolverOptionsGroup);
        label_11->setObjectName("label_11");

        gridLayout_3->addWidget(label_11, 3, 0, 1, 1);

        alignUseCurrentFilter = new QCheckBox(plateSolverOptionsGroup);
        alignUseCurrentFilter->setObjectName("alignUseCurrentFilter");

        gridLayout_3->addWidget(alignUseCurrentFilter, 5, 2, 1, 3);


        leftLayout->addWidget(plateSolverOptionsGroup);

        stellarSolverOptionsGroup = new QGroupBox(layoutWidget);
        stellarSolverOptionsGroup->setObjectName("stellarSolverOptionsGroup");
        horizontalLayout = new QHBoxLayout(stellarSolverOptionsGroup);
        horizontalLayout->setSpacing(3);
        horizontalLayout->setObjectName("horizontalLayout");
        horizontalLayout->setContentsMargins(3, 3, 3, 3);
        localSolverR = new QRadioButton(stellarSolverOptionsGroup);
        solverModeButtonGroup = new QButtonGroup(Align);
        solverModeButtonGroup->setObjectName("solverModeButtonGroup");
        solverModeButtonGroup->addButton(localSolverR);
        localSolverR->setObjectName("localSolverR");
        localSolverR->setChecked(true);

        horizontalLayout->addWidget(localSolverR);

        remoteSolverR = new QRadioButton(stellarSolverOptionsGroup);
        solverModeButtonGroup->addButton(remoteSolverR);
        remoteSolverR->setObjectName("remoteSolverR");
        remoteSolverR->setEnabled(false);

        horizontalLayout->addWidget(remoteSolverR);

        horizontalSpacer = new QSpacerItem(40, 20, QSizePolicy::Policy::Expanding, QSizePolicy::Policy::Minimum);

        horizontalLayout->addItem(horizontalSpacer);


        leftLayout->addWidget(stellarSolverOptionsGroup);

        mainSplitter->addWidget(layoutWidget);
        rightLayout = new QSplitter(mainSplitter);
        rightLayout->setObjectName("rightLayout");
        QSizePolicy sizePolicy1(QSizePolicy::Policy::Expanding, QSizePolicy::Policy::Expanding);
        sizePolicy1.setHorizontalStretch(0);
        sizePolicy1.setVerticalStretch(0);
        sizePolicy1.setHeightForWidth(rightLayout->sizePolicy().hasHeightForWidth());
        rightLayout->setSizePolicy(sizePolicy1);
        rightLayout->setOrientation(Qt::Vertical);
        alignWidget = new QWidget(rightLayout);
        alignWidget->setObjectName("alignWidget");
        sizePolicy1.setHeightForWidth(alignWidget->sizePolicy().hasHeightForWidth());
        alignWidget->setSizePolicy(sizePolicy1);
        alignWidget->setMinimumSize(QSize(320, 240));
        rightLayout->addWidget(alignWidget);
        tabWidget = new QTabWidget(rightLayout);
        tabWidget->setObjectName("tabWidget");
        solutionResults = new QWidget();
        solutionResults->setObjectName("solutionResults");
        verticalLayout_11 = new QVBoxLayout(solutionResults);
        verticalLayout_11->setSpacing(3);
        verticalLayout_11->setObjectName("verticalLayout_11");
        verticalLayout_11->setContentsMargins(0, 0, 0, 0);
        label_15 = new QLabel(solutionResults);
        label_15->setObjectName("label_15");
        QSizePolicy sizePolicy2(QSizePolicy::Policy::Preferred, QSizePolicy::Policy::Preferred);
        sizePolicy2.setHorizontalStretch(0);
        sizePolicy2.setVerticalStretch(0);
        sizePolicy2.setHeightForWidth(label_15->sizePolicy().hasHeightForWidth());
        label_15->setSizePolicy(sizePolicy2);
        label_15->setWordWrap(true);

        verticalLayout_11->addWidget(label_15);

        alignSplitter = new QSplitter(solutionResults);
        alignSplitter->setObjectName("alignSplitter");
        sizePolicy1.setHeightForWidth(alignSplitter->sizePolicy().hasHeightForWidth());
        alignSplitter->setSizePolicy(sizePolicy1);
        alignSplitter->setOrientation(Qt::Horizontal);
        verticalLayoutWidget = new QWidget(alignSplitter);
        verticalLayoutWidget->setObjectName("verticalLayoutWidget");
        verticalLayout_20 = new QVBoxLayout(verticalLayoutWidget);
        verticalLayout_20->setSpacing(0);
        verticalLayout_20->setObjectName("verticalLayout_20");
        verticalLayout_20->setContentsMargins(0, 0, 0, 0);
        solutionTable = new QTableWidget(verticalLayoutWidget);
        if (solutionTable->columnCount() < 6)
            solutionTable->setColumnCount(6);
        QTableWidgetItem *__qtablewidgetitem = new QTableWidgetItem();
        solutionTable->setHorizontalHeaderItem(0, __qtablewidgetitem);
        QTableWidgetItem *__qtablewidgetitem1 = new QTableWidgetItem();
        solutionTable->setHorizontalHeaderItem(1, __qtablewidgetitem1);
        QTableWidgetItem *__qtablewidgetitem2 = new QTableWidgetItem();
        solutionTable->setHorizontalHeaderItem(2, __qtablewidgetitem2);
        QTableWidgetItem *__qtablewidgetitem3 = new QTableWidgetItem();
        solutionTable->setHorizontalHeaderItem(3, __qtablewidgetitem3);
        QTableWidgetItem *__qtablewidgetitem4 = new QTableWidgetItem();
        solutionTable->setHorizontalHeaderItem(4, __qtablewidgetitem4);
        QTableWidgetItem *__qtablewidgetitem5 = new QTableWidgetItem();
        solutionTable->setHorizontalHeaderItem(5, __qtablewidgetitem5);
        solutionTable->setObjectName("solutionTable");
        solutionTable->setColumnCount(6);
        solutionTable->horizontalHeader()->setDefaultSectionSize(75);

        verticalLayout_20->addWidget(solutionTable);

        horizontalLayout_19 = new QHBoxLayout();
        horizontalLayout_19->setObjectName("horizontalLayout_19");
        horizontalLayout_19->setContentsMargins(-1, 0, -1, -1);
        clearAllSolutionsB = new QPushButton(verticalLayoutWidget);
        clearAllSolutionsB->setObjectName("clearAllSolutionsB");
        clearAllSolutionsB->setMinimumSize(QSize(32, 32));
        clearAllSolutionsB->setMaximumSize(QSize(32, 32));

        horizontalLayout_19->addWidget(clearAllSolutionsB);

        removeSolutionB = new QPushButton(verticalLayoutWidget);
        removeSolutionB->setObjectName("removeSolutionB");
        removeSolutionB->setMinimumSize(QSize(32, 32));
        removeSolutionB->setMaximumSize(QSize(32, 33));

        horizontalLayout_19->addWidget(removeSolutionB);

        exportSolutionsCSV = new QPushButton(verticalLayoutWidget);
        exportSolutionsCSV->setObjectName("exportSolutionsCSV");
        exportSolutionsCSV->setMinimumSize(QSize(32, 32));
        exportSolutionsCSV->setMaximumSize(QSize(32, 33));

        horizontalLayout_19->addWidget(exportSolutionsCSV);

        autoScaleGraphB = new QPushButton(verticalLayoutWidget);
        autoScaleGraphB->setObjectName("autoScaleGraphB");
        autoScaleGraphB->setMinimumSize(QSize(32, 32));
        autoScaleGraphB->setMaximumSize(QSize(32, 33));

        horizontalLayout_19->addWidget(autoScaleGraphB);

        horizontalSpacer_11 = new QSpacerItem(40, 20, QSizePolicy::Policy::Expanding, QSizePolicy::Policy::Minimum);

        horizontalLayout_19->addItem(horizontalSpacer_11);

        mountModelB = new QPushButton(verticalLayoutWidget);
        mountModelB->setObjectName("mountModelB");

        horizontalLayout_19->addWidget(mountModelB);


        verticalLayout_20->addLayout(horizontalLayout_19);

        alignSplitter->addWidget(verticalLayoutWidget);
        alignPlot = new QCustomPlot(alignSplitter);
        alignPlot->setObjectName("alignPlot");
        sizePolicy1.setHeightForWidth(alignPlot->sizePolicy().hasHeightForWidth());
        alignPlot->setSizePolicy(sizePolicy1);
        alignPlot->setMinimumSize(QSize(100, 100));
        alignPlot->setBaseSize(QSize(190, 190));
        alignSplitter->addWidget(alignPlot);

        verticalLayout_11->addWidget(alignSplitter);

        tabWidget->addTab(solutionResults, QString());
        rightLayout->addWidget(tabWidget);
        mainSplitter->addWidget(rightLayout);

        horizontalLayout_2->addWidget(mainSplitter);

        QWidget::setTabOrder(opticalTrainCombo, trainB);
        QWidget::setTabOrder(trainB, solveB);
        QWidget::setTabOrder(solveB, loadSlewB);
        QWidget::setTabOrder(loadSlewB, stopB);
        QWidget::setTabOrder(stopB, syncR);
        QWidget::setTabOrder(syncR, slewR);
        QWidget::setTabOrder(slewR, nothingR);
        QWidget::setTabOrder(nothingR, ScopeRAOut);
        QWidget::setTabOrder(ScopeRAOut, alignAccuracyThreshold);
        QWidget::setTabOrder(alignAccuracyThreshold, ScopeDecOut);
        QWidget::setTabOrder(ScopeDecOut, alignSettlingTime);
        QWidget::setTabOrder(alignSettlingTime, SolverRAOut);
        QWidget::setTabOrder(SolverRAOut, SolverDecOut);
        QWidget::setTabOrder(SolverDecOut, errOut);
        QWidget::setTabOrder(errOut, pixScaleOut);
        QWidget::setTabOrder(pixScaleOut, PAOut);
        QWidget::setTabOrder(PAOut, FOVOut);
        QWidget::setTabOrder(FOVOut, ReducerOut);
        QWidget::setTabOrder(ReducerOut, FocalLengthOut);
        QWidget::setTabOrder(FocalLengthOut, FocalRatioOut);
        QWidget::setTabOrder(FocalRatioOut, alignExposure);
        QWidget::setTabOrder(alignExposure, toggleFullScreenB);
        QWidget::setTabOrder(toggleFullScreenB, showFITSViewerB);
        QWidget::setTabOrder(showFITSViewerB, alignBinning);
        QWidget::setTabOrder(alignBinning, alignGain);
        QWidget::setTabOrder(alignGain, alignISO);
        QWidget::setTabOrder(alignISO, rotatorB);
        QWidget::setTabOrder(rotatorB, alignDarkFrame);
        QWidget::setTabOrder(alignDarkFrame, alignFilter);
        QWidget::setTabOrder(alignFilter, localSolverR);
        QWidget::setTabOrder(localSolverR, remoteSolverR);
        QWidget::setTabOrder(remoteSolverR, clearAllSolutionsB);
        QWidget::setTabOrder(clearAllSolutionsB, removeSolutionB);
        QWidget::setTabOrder(removeSolutionB, exportSolutionsCSV);
        QWidget::setTabOrder(exportSolutionsCSV, autoScaleGraphB);
        QWidget::setTabOrder(autoScaleGraphB, mountModelB);
        QWidget::setTabOrder(mountModelB, tabWidget);
        QWidget::setTabOrder(tabWidget, solutionTable);

        retranslateUi(Align);

        solveB->setDefault(true);
        tabWidget->setCurrentIndex(0);


        QMetaObject::connectSlotsByName(Align);
    } // setupUi

    void retranslateUi(QWidget *Align)
    {
        trainLabel->setText(tr2i18n("Train:", nullptr));
        trainB->setText(QString());
        controlBox->setTitle(tr2i18n("Solver Control", nullptr));
        solveB->setText(tr2i18n("Capture && Solve", nullptr));
#if QT_CONFIG(tooltip)
        loadSlewB->setToolTip(tr2i18n("Load a FITS image and solve. Slew mount to image central coordinates.", nullptr));
#endif // QT_CONFIG(tooltip)
        loadSlewB->setText(tr2i18n("Load && Slew...", nullptr));
        stopB->setText(tr2i18n("Stop", nullptr));
#if QT_CONFIG(tooltip)
        gotoBox->setToolTip(tr2i18n("Select which action to perform after the captured image is solved", nullptr));
#endif // QT_CONFIG(tooltip)
#if QT_CONFIG(statustip)
        gotoBox->setStatusTip(tr2i18n("Select what action to take once a solution is found.", nullptr));
#endif // QT_CONFIG(statustip)
        gotoBox->setTitle(tr2i18n("Solver Action", nullptr));
#if QT_CONFIG(tooltip)
        syncR->setToolTip(tr2i18n("Synchronize the telescope to the solution coordinates", nullptr));
#endif // QT_CONFIG(tooltip)
#if QT_CONFIG(statustip)
        syncR->setStatusTip(QString());
#endif // QT_CONFIG(statustip)
        syncR->setText(tr2i18n("S&ync", nullptr));
#if QT_CONFIG(tooltip)
        slewR->setToolTip(tr2i18n("Synchronize the telescope to the solution coordinates and then slew to the target coordinates", nullptr));
#endif // QT_CONFIG(tooltip)
#if QT_CONFIG(statustip)
        slewR->setStatusTip(QString());
#endif // QT_CONFIG(statustip)
        slewR->setText(tr2i18n("S&lew to Target", nullptr));
#if QT_CONFIG(tooltip)
        nothingR->setToolTip(tr2i18n("Just solve", nullptr));
#endif // QT_CONFIG(tooltip)
#if QT_CONFIG(statustip)
        nothingR->setStatusTip(QString());
#endif // QT_CONFIG(statustip)
        nothingR->setText(tr2i18n("&Nothing", nullptr));
        telescopeCoordinateGroup->setTitle(tr2i18n("Telescope Coordinates (JNow)", nullptr));
#if QT_CONFIG(tooltip)
        alignAccuracyThreshold->setToolTip(tr2i18n("Accuracy threshold in arcseconds between solution and target coordinates. Plate solver shall be repeatedly executed until the solution coordinates are below the accuracy threshold", nullptr));
#endif // QT_CONFIG(tooltip)
        label_13->setText(tr2i18n("DE:", nullptr));
#if QT_CONFIG(tooltip)
        label_22->setToolTip(tr2i18n("After telescope completes slewing, wait until it settles for this many milliseconds before capturing the next image.", nullptr));
#endif // QT_CONFIG(tooltip)
        label_22->setText(tr2i18n("Settle:", nullptr));
#if QT_CONFIG(tooltip)
        alignSettlingTime->setToolTip(tr2i18n("After telescope completes slewing, wait until it settles for this many milliseconds before capturing the next image.", nullptr));
#endif // QT_CONFIG(tooltip)
        label_12->setText(tr2i18n("RA:", nullptr));
#if QT_CONFIG(tooltip)
        label_9->setToolTip(tr2i18n("Accuracy threshold in arcseconds between solution and target coordinates. Plate solver shall be repeatedly executed until the solution coordinates are below the accuracy threshold", nullptr));
#endif // QT_CONFIG(tooltip)
        label_9->setText(tr2i18n("Accuracy:", nullptr));
        solutionCoordinatesGroupBox->setTitle(tr2i18n("Solution Coordinates (JNow)", nullptr));
#if QT_CONFIG(tooltip)
        label_8->setToolTip(tr2i18n("Effective field of view size in arcminutes.", nullptr));
#endif // QT_CONFIG(tooltip)
        label_8->setText(tr2i18n("FOV:", nullptr));
        label_6->setText(tr2i18n("DE:", nullptr));
#if QT_CONFIG(tooltip)
        err->setToolTip(tr2i18n("Difference between telescope coordinates and solution coordinates in arcsec", nullptr));
#endif // QT_CONFIG(tooltip)
        err->setText(tr2i18n("Err:", nullptr));
#if QT_CONFIG(tooltip)
        errOut->setToolTip(tr2i18n("Difference between telescope coordinates and solution coordinates in arcsec", nullptr));
#endif // QT_CONFIG(tooltip)
        errOut->setText(QString());
        label_2->setText(tr2i18n("RA:", nullptr));
#if QT_CONFIG(tooltip)
        label_17->setToolTip(tr2i18n("Image scale in arcsecs/pixel", nullptr));
#endif // QT_CONFIG(tooltip)
        label_17->setText(tr2i18n("Pix:", nullptr));
#if QT_CONFIG(tooltip)
        label_10->setToolTip(tr2i18n("Image rotation angle, East of North", nullptr));
#endif // QT_CONFIG(tooltip)
        label_10->setText(tr2i18n("PA:", nullptr));
#if QT_CONFIG(tooltip)
        PAOut->setToolTip(tr2i18n("Position angle in degrees, East of North", nullptr));
#endif // QT_CONFIG(tooltip)
#if QT_CONFIG(tooltip)
        pixScaleOut->setToolTip(tr2i18n("Image scale in arcsecs/pixel", nullptr));
#endif // QT_CONFIG(tooltip)
        label_14->setText(tr2i18n("FL:", nullptr));
#if QT_CONFIG(tooltip)
        FocalLengthOut->setToolTip(tr2i18n("<html><head/><body><p>Calculated telescope (effective) focal length in millimeters. The effective focal length is measured from plate-solving.</p></body></html>", nullptr));
#endif // QT_CONFIG(tooltip)
        label_16->setText(tr2i18n("F/:", nullptr));
#if QT_CONFIG(tooltip)
        FocalRatioOut->setToolTip(tr2i18n("<html><head/><body><p>Calculated telescope (effective) focal ratio. The effective focal ratio is measured from astrometry.</p></body></html>", nullptr));
#endif // QT_CONFIG(tooltip)
#if QT_CONFIG(tooltip)
        FOVOut->setToolTip(tr2i18n("Effective field of view size in arcminutes.", nullptr));
#endif // QT_CONFIG(tooltip)
        FOVOut->setText(QString());
        label->setText(tr2i18n("R:", nullptr));
#if QT_CONFIG(tooltip)
        ReducerOut->setToolTip(tr2i18n("<html><head/><body><p>Reducer or Barlow factor.</p></body></html>", nullptr));
#endif // QT_CONFIG(tooltip)
        plateSolverOptionsGroup->setTitle(tr2i18n("Plate Solve Capture Options", nullptr));
        label_5->setText(tr2i18n("Gain:", nullptr));
        label_18->setText(tr2i18n("Bin:", nullptr));
#if QT_CONFIG(tooltip)
        showFITSViewerB->setToolTip(tr2i18n("Show in FITS Viewer...", nullptr));
#endif // QT_CONFIG(tooltip)
        showFITSViewerB->setText(QString());
#if QT_CONFIG(tooltip)
        alignDarkFrame->setToolTip(tr2i18n("<html><head/><body><p>Subtract dark frame. Create dark frames or defect maps in the Dark Library tool in the capture module.</p></body></html>", nullptr));
#endif // QT_CONFIG(tooltip)
        alignDarkFrame->setText(tr2i18n("Dark", nullptr));
#if QT_CONFIG(tooltip)
        alignBinning->setToolTip(tr2i18n("Camera binning", nullptr));
#endif // QT_CONFIG(tooltip)
#if QT_CONFIG(tooltip)
        toggleFullScreenB->setToolTip(tr2i18n("Toggle Full Screen", nullptr));
#endif // QT_CONFIG(tooltip)
        toggleFullScreenB->setText(QString());
#if QT_CONFIG(tooltip)
        alignExposure->setToolTip(tr2i18n("Exposure duration in seconds", nullptr));
#endif // QT_CONFIG(tooltip)
#if QT_CONFIG(tooltip)
        alignGain->setToolTip(tr2i18n("Camera Gain", nullptr));
#endif // QT_CONFIG(tooltip)
        FilterPosLabel->setText(tr2i18n("Filter:", nullptr));
#if QT_CONFIG(tooltip)
        alignISO->setToolTip(tr2i18n("Camera ISO", nullptr));
#endif // QT_CONFIG(tooltip)
        label_7->setText(tr2i18n("Exp:", nullptr));
#if QT_CONFIG(tooltip)
        rotatorB->setToolTip(tr2i18n("Rotator Settings", nullptr));
#endif // QT_CONFIG(tooltip)
        rotatorB->setText(QString());
        label_11->setText(tr2i18n("ISO:", nullptr));
#if QT_CONFIG(tooltip)
        alignUseCurrentFilter->setToolTip(tr2i18n("<html><head/><body><p>If checked, the currently selected filter will be used for alignment. </p><p>If you want to use a certain (fixed) filter for alignment, leave unchecked and select the filter manually.</p></body></html>", nullptr));
#endif // QT_CONFIG(tooltip)
        alignUseCurrentFilter->setText(tr2i18n("Use current", nullptr));
        stellarSolverOptionsGroup->setTitle(tr2i18n("Solver Mode", nullptr));
        localSolverR->setText(tr2i18n("StellarSolver", nullptr));
        remoteSolverR->setText(tr2i18n("Remote", nullptr));
        label_15->setText(tr2i18n("The results from Astrometric Solutions from the Capture and Solve Tool, the Load and Slew Tool, and the Mount Model Tool will be displayed below.", nullptr));
        QTableWidgetItem *___qtablewidgetitem = solutionTable->horizontalHeaderItem(0);
        ___qtablewidgetitem->setText(tr2i18n("RA", nullptr));
        QTableWidgetItem *___qtablewidgetitem1 = solutionTable->horizontalHeaderItem(1);
        ___qtablewidgetitem1->setText(tr2i18n("DEC", nullptr));
        QTableWidgetItem *___qtablewidgetitem2 = solutionTable->horizontalHeaderItem(2);
        ___qtablewidgetitem2->setText(tr2i18n("Obj Name", nullptr));
        QTableWidgetItem *___qtablewidgetitem3 = solutionTable->horizontalHeaderItem(3);
        ___qtablewidgetitem3->setText(tr2i18n("~~", nullptr));
        QTableWidgetItem *___qtablewidgetitem4 = solutionTable->horizontalHeaderItem(4);
        ___qtablewidgetitem4->setText(tr2i18n("dRA", nullptr));
        QTableWidgetItem *___qtablewidgetitem5 = solutionTable->horizontalHeaderItem(5);
        ___qtablewidgetitem5->setText(tr2i18n("dDE", nullptr));
#if QT_CONFIG(tooltip)
        clearAllSolutionsB->setToolTip(tr2i18n("Clear all of the solutions from the solutions table.  Be careful because you cannot get them back.", nullptr));
#endif // QT_CONFIG(tooltip)
        clearAllSolutionsB->setText(QString());
#if QT_CONFIG(tooltip)
        removeSolutionB->setToolTip(tr2i18n("Remove the selected row from the solutions table.  This can be useful for getting rid of results that did not actually solve from the table and/or results that you do not need any more.  It can clean up clutter on both the graph and table.", nullptr));
#endif // QT_CONFIG(tooltip)
        removeSolutionB->setText(QString());
#if QT_CONFIG(tooltip)
        exportSolutionsCSV->setToolTip(tr2i18n("Export all of the solutions in the Solution Results table to CSV file of your choosing for further analysis in a spreadsheet.", nullptr));
#endif // QT_CONFIG(tooltip)
        exportSolutionsCSV->setText(QString());
#if QT_CONFIG(tooltip)
        autoScaleGraphB->setToolTip(tr2i18n("Auto scale and center the Solution Results graph.", nullptr));
#endif // QT_CONFIG(tooltip)
        autoScaleGraphB->setText(QString());
#if QT_CONFIG(tooltip)
        mountModelB->setToolTip(tr2i18n("Launch the mount model tool. This tool enables you to create pre-programmed list of points to go to and solve. It can aid in building a pointing model for better accuracy.", nullptr));
#endif // QT_CONFIG(tooltip)
        mountModelB->setText(tr2i18n("Mount Model", nullptr));
        tabWidget->setTabText(tabWidget->indexOf(solutionResults), tr2i18n("Solution Results", nullptr));
        (void)Align;
    } // retranslateUi

};

namespace Ui {
    class Align: public Ui_Align {};
} // namespace Ui

QT_END_NAMESPACE

#endif // ALIGN_H

