/****************************************************************************
** Meta object code from reading C++ file 'analyze.h'
**
** Created by: The Qt Meta Object Compiler version 69 (Qt 6.11.1)
**
** WARNING! All changes made in this file will be lost!
*****************************************************************************/

#include "../../../../kstars-3.8.4.1/kstars/ekos/analyze/analyze.h"
#include <QtGui/qtextcursor.h>
#include <QtGui/qscreen.h>
#include <QtCore/qmetatype.h>

#include <QtCore/qtmochelpers.h>

#include <memory>


#include <QtCore/qxptype_traits.h>
#if !defined(Q_MOC_OUTPUT_REVISION)
#error "The header file 'analyze.h' doesn't include <QObject>."
#elif Q_MOC_OUTPUT_REVISION != 69
#error "This file was generated using the moc from 6.11.1. It"
#error "cannot be used with the include files from this version of Qt."
#error "(The moc has changed too much.)"
#endif

#ifndef Q_CONSTINIT
#define Q_CONSTINIT
#endif

QT_WARNING_PUSH
QT_WARNING_DISABLE_DEPRECATED
QT_WARNING_DISABLE_GCC("-Wuseless-cast")
namespace {
struct qt_meta_tag_ZN4Ekos7AnalyzeE_t {};
} // unnamed namespace

template <> constexpr inline auto Ekos::Analyze::qt_create_metaobjectdata<qt_meta_tag_ZN4Ekos7AnalyzeE_t>()
{
    namespace QMC = QtMocConstants;
    QtMocHelpers::StringRefStorage qt_stringData {
        "Ekos::Analyze",
        "newLog",
        "",
        "text",
        "captureComplete",
        "QVariantMap",
        "metadata",
        "captureStarting",
        "exposureSeconds",
        "filter",
        "captureAborted",
        "guideState",
        "Ekos::GuideState",
        "status",
        "guideStats",
        "raError",
        "decError",
        "raPulse",
        "decPulse",
        "snr",
        "skyBg",
        "numStars",
        "autofocusStarting",
        "temperature",
        "AutofocusReason",
        "reason",
        "reasonInfo",
        "autofocusComplete",
        "points",
        "useWeights",
        "curve",
        "title",
        "adaptiveFocusComplete",
        "tempTicks",
        "altitude",
        "altTicks",
        "prevPosError",
        "thisPosError",
        "totalTicks",
        "position",
        "focuserMoved",
        "autofocusAborted",
        "AutofocusFailReason",
        "failCode",
        "failCodeInfo",
        "newTemperature",
        "temperatureDelta",
        "alignState",
        "Ekos::AlignState",
        "state",
        "mountState",
        "ISD::Mount::Status",
        "mountCoords",
        "SkyPoint",
        "ISD::Mount::PierSide",
        "pierSide",
        "dms",
        "haValue",
        "mountFlipStatus",
        "Ekos::MeridianFlipState::MeridianFlipMountState",
        "schedulerJobStarted",
        "jobName",
        "schedulerJobEnded",
        "endReason",
        "newTargetDistance",
        "targetDistance",
        "userChangedYAxis",
        "key",
        "YAxisInfo",
        "axisInfo",
        "userSetLeftAxis",
        "QCPAxis*",
        "axis",
        "userSetAxisColor",
        "QColor",
        "color",
        "yAxisRangeChanged",
        "QCPRange",
        "newRange",
        "appendLogText"
    };

    QtMocHelpers::UintData qt_methods {
        // Signal 'newLog'
        QtMocHelpers::SignalData<void(const QString &)>(1, 2, QMC::AccessPublic, QMetaType::Void, {{
            { QMetaType::QString, 3 },
        }}),
        // Slot 'captureComplete'
        QtMocHelpers::SlotData<void(const QVariantMap &)>(4, 2, QMC::AccessPublic, QMetaType::Void, {{
            { 0x80000000 | 5, 6 },
        }}),
        // Slot 'captureStarting'
        QtMocHelpers::SlotData<void(double, const QString &)>(7, 2, QMC::AccessPublic, QMetaType::Void, {{
            { QMetaType::Double, 8 }, { QMetaType::QString, 9 },
        }}),
        // Slot 'captureAborted'
        QtMocHelpers::SlotData<void(double)>(10, 2, QMC::AccessPublic, QMetaType::Void, {{
            { QMetaType::Double, 8 },
        }}),
        // Slot 'guideState'
        QtMocHelpers::SlotData<void(Ekos::GuideState)>(11, 2, QMC::AccessPublic, QMetaType::Void, {{
            { 0x80000000 | 12, 13 },
        }}),
        // Slot 'guideStats'
        QtMocHelpers::SlotData<void(double, double, int, int, double, double, int)>(14, 2, QMC::AccessPublic, QMetaType::Void, {{
            { QMetaType::Double, 15 }, { QMetaType::Double, 16 }, { QMetaType::Int, 17 }, { QMetaType::Int, 18 },
            { QMetaType::Double, 19 }, { QMetaType::Double, 20 }, { QMetaType::Int, 21 },
        }}),
        // Slot 'autofocusStarting'
        QtMocHelpers::SlotData<void(double, const QString &, const AutofocusReason, const QString &)>(22, 2, QMC::AccessPublic, QMetaType::Void, {{
            { QMetaType::Double, 23 }, { QMetaType::QString, 9 }, { 0x80000000 | 24, 25 }, { QMetaType::QString, 26 },
        }}),
        // Slot 'autofocusComplete'
        QtMocHelpers::SlotData<void(const double, const QString &, const QString &, const bool, const QString &, const QString &)>(27, 2, QMC::AccessPublic, QMetaType::Void, {{
            { QMetaType::Double, 23 }, { QMetaType::QString, 9 }, { QMetaType::QString, 28 }, { QMetaType::Bool, 29 },
            { QMetaType::QString, 30 }, { QMetaType::QString, 31 },
        }}),
        // Slot 'adaptiveFocusComplete'
        QtMocHelpers::SlotData<void(const QString &, double, double, double, double, int, int, int, int, bool)>(32, 2, QMC::AccessPublic, QMetaType::Void, {{
            { QMetaType::QString, 9 }, { QMetaType::Double, 23 }, { QMetaType::Double, 33 }, { QMetaType::Double, 34 },
            { QMetaType::Double, 35 }, { QMetaType::Int, 36 }, { QMetaType::Int, 37 }, { QMetaType::Int, 38 },
            { QMetaType::Int, 39 }, { QMetaType::Bool, 40 },
        }}),
        // Slot 'autofocusAborted'
        QtMocHelpers::SlotData<void(const QString &, const QString &, const bool, const AutofocusFailReason, const QString)>(41, 2, QMC::AccessPublic, QMetaType::Void, {{
            { QMetaType::QString, 9 }, { QMetaType::QString, 28 }, { QMetaType::Bool, 29 }, { 0x80000000 | 42, 43 },
            { QMetaType::QString, 44 },
        }}),
        // Slot 'newTemperature'
        QtMocHelpers::SlotData<void(double, double)>(45, 2, QMC::AccessPublic, QMetaType::Void, {{
            { QMetaType::Double, 46 }, { QMetaType::Double, 23 },
        }}),
        // Slot 'alignState'
        QtMocHelpers::SlotData<void(Ekos::AlignState)>(47, 2, QMC::AccessPublic, QMetaType::Void, {{
            { 0x80000000 | 48, 49 },
        }}),
        // Slot 'mountState'
        QtMocHelpers::SlotData<void(ISD::Mount::Status)>(50, 2, QMC::AccessPublic, QMetaType::Void, {{
            { 0x80000000 | 51, 13 },
        }}),
        // Slot 'mountCoords'
        QtMocHelpers::SlotData<void(const SkyPoint &, ISD::Mount::PierSide, const dms &)>(52, 2, QMC::AccessPublic, QMetaType::Void, {{
            { 0x80000000 | 53, 39 }, { 0x80000000 | 54, 55 }, { 0x80000000 | 56, 57 },
        }}),
        // Slot 'mountFlipStatus'
        QtMocHelpers::SlotData<void(Ekos::MeridianFlipState::MeridianFlipMountState)>(58, 2, QMC::AccessPublic, QMetaType::Void, {{
            { 0x80000000 | 59, 13 },
        }}),
        // Slot 'schedulerJobStarted'
        QtMocHelpers::SlotData<void(const QString &)>(60, 2, QMC::AccessPublic, QMetaType::Void, {{
            { QMetaType::QString, 61 },
        }}),
        // Slot 'schedulerJobEnded'
        QtMocHelpers::SlotData<void(const QString &, const QString &)>(62, 2, QMC::AccessPublic, QMetaType::Void, {{
            { QMetaType::QString, 61 }, { QMetaType::QString, 63 },
        }}),
        // Slot 'newTargetDistance'
        QtMocHelpers::SlotData<void(double)>(64, 2, QMC::AccessPublic, QMetaType::Void, {{
            { QMetaType::Double, 65 },
        }}),
        // Slot 'userChangedYAxis'
        QtMocHelpers::SlotData<void(QObject *, const YAxisInfo &)>(66, 2, QMC::AccessPublic, QMetaType::Void, {{
            { QMetaType::QObjectStar, 67 }, { 0x80000000 | 68, 69 },
        }}),
        // Slot 'userSetLeftAxis'
        QtMocHelpers::SlotData<void(QCPAxis *)>(70, 2, QMC::AccessPublic, QMetaType::Void, {{
            { 0x80000000 | 71, 72 },
        }}),
        // Slot 'userSetAxisColor'
        QtMocHelpers::SlotData<void(QObject *, const YAxisInfo &, const QColor &)>(73, 2, QMC::AccessPublic, QMetaType::Void, {{
            { QMetaType::QObjectStar, 67 }, { 0x80000000 | 68, 69 }, { 0x80000000 | 74, 75 },
        }}),
        // Slot 'yAxisRangeChanged'
        QtMocHelpers::SlotData<void(const QCPRange &)>(76, 2, QMC::AccessPublic, QMetaType::Void, {{
            { 0x80000000 | 77, 78 },
        }}),
        // Slot 'appendLogText'
        QtMocHelpers::SlotData<void(const QString &)>(79, 2, QMC::AccessPublic, QMetaType::Void, {{
            { QMetaType::QString, 2 },
        }}),
    };
    QtMocHelpers::UintData qt_properties {
    };
    QtMocHelpers::UintData qt_enums {
    };
    return QtMocHelpers::metaObjectData<Analyze, qt_meta_tag_ZN4Ekos7AnalyzeE_t>(QMC::MetaObjectFlag{}, qt_stringData,
            qt_methods, qt_properties, qt_enums);
}
Q_CONSTINIT const QMetaObject Ekos::Analyze::staticMetaObject = { {
    QMetaObject::SuperData::link<QWidget::staticMetaObject>(),
    qt_staticMetaObjectStaticContent<qt_meta_tag_ZN4Ekos7AnalyzeE_t>.stringdata,
    qt_staticMetaObjectStaticContent<qt_meta_tag_ZN4Ekos7AnalyzeE_t>.data,
    qt_static_metacall,
    nullptr,
    qt_staticMetaObjectRelocatingContent<qt_meta_tag_ZN4Ekos7AnalyzeE_t>.metaTypes,
    nullptr
} };

void Ekos::Analyze::qt_static_metacall(QObject *_o, QMetaObject::Call _c, int _id, void **_a)
{
    auto *_t = static_cast<Analyze *>(_o);
    if (_c == QMetaObject::InvokeMetaMethod) {
        switch (_id) {
        case 0: _t->newLog((*reinterpret_cast<std::add_pointer_t<QString>>(_a[1]))); break;
        case 1: _t->captureComplete((*reinterpret_cast<std::add_pointer_t<QVariantMap>>(_a[1]))); break;
        case 2: _t->captureStarting((*reinterpret_cast<std::add_pointer_t<double>>(_a[1])),(*reinterpret_cast<std::add_pointer_t<QString>>(_a[2]))); break;
        case 3: _t->captureAborted((*reinterpret_cast<std::add_pointer_t<double>>(_a[1]))); break;
        case 4: _t->guideState((*reinterpret_cast<std::add_pointer_t<Ekos::GuideState>>(_a[1]))); break;
        case 5: _t->guideStats((*reinterpret_cast<std::add_pointer_t<double>>(_a[1])),(*reinterpret_cast<std::add_pointer_t<double>>(_a[2])),(*reinterpret_cast<std::add_pointer_t<int>>(_a[3])),(*reinterpret_cast<std::add_pointer_t<int>>(_a[4])),(*reinterpret_cast<std::add_pointer_t<double>>(_a[5])),(*reinterpret_cast<std::add_pointer_t<double>>(_a[6])),(*reinterpret_cast<std::add_pointer_t<int>>(_a[7]))); break;
        case 6: _t->autofocusStarting((*reinterpret_cast<std::add_pointer_t<double>>(_a[1])),(*reinterpret_cast<std::add_pointer_t<QString>>(_a[2])),(*reinterpret_cast<std::add_pointer_t<AutofocusReason>>(_a[3])),(*reinterpret_cast<std::add_pointer_t<QString>>(_a[4]))); break;
        case 7: _t->autofocusComplete((*reinterpret_cast<std::add_pointer_t<double>>(_a[1])),(*reinterpret_cast<std::add_pointer_t<QString>>(_a[2])),(*reinterpret_cast<std::add_pointer_t<QString>>(_a[3])),(*reinterpret_cast<std::add_pointer_t<bool>>(_a[4])),(*reinterpret_cast<std::add_pointer_t<QString>>(_a[5])),(*reinterpret_cast<std::add_pointer_t<QString>>(_a[6]))); break;
        case 8: _t->adaptiveFocusComplete((*reinterpret_cast<std::add_pointer_t<QString>>(_a[1])),(*reinterpret_cast<std::add_pointer_t<double>>(_a[2])),(*reinterpret_cast<std::add_pointer_t<double>>(_a[3])),(*reinterpret_cast<std::add_pointer_t<double>>(_a[4])),(*reinterpret_cast<std::add_pointer_t<double>>(_a[5])),(*reinterpret_cast<std::add_pointer_t<int>>(_a[6])),(*reinterpret_cast<std::add_pointer_t<int>>(_a[7])),(*reinterpret_cast<std::add_pointer_t<int>>(_a[8])),(*reinterpret_cast<std::add_pointer_t<int>>(_a[9])),(*reinterpret_cast<std::add_pointer_t<bool>>(_a[10]))); break;
        case 9: _t->autofocusAborted((*reinterpret_cast<std::add_pointer_t<QString>>(_a[1])),(*reinterpret_cast<std::add_pointer_t<QString>>(_a[2])),(*reinterpret_cast<std::add_pointer_t<bool>>(_a[3])),(*reinterpret_cast<std::add_pointer_t<AutofocusFailReason>>(_a[4])),(*reinterpret_cast<std::add_pointer_t<QString>>(_a[5]))); break;
        case 10: _t->newTemperature((*reinterpret_cast<std::add_pointer_t<double>>(_a[1])),(*reinterpret_cast<std::add_pointer_t<double>>(_a[2]))); break;
        case 11: _t->alignState((*reinterpret_cast<std::add_pointer_t<Ekos::AlignState>>(_a[1]))); break;
        case 12: _t->mountState((*reinterpret_cast<std::add_pointer_t<ISD::Mount::Status>>(_a[1]))); break;
        case 13: _t->mountCoords((*reinterpret_cast<std::add_pointer_t<SkyPoint>>(_a[1])),(*reinterpret_cast<std::add_pointer_t<ISD::Mount::PierSide>>(_a[2])),(*reinterpret_cast<std::add_pointer_t<dms>>(_a[3]))); break;
        case 14: _t->mountFlipStatus((*reinterpret_cast<std::add_pointer_t<Ekos::MeridianFlipState::MeridianFlipMountState>>(_a[1]))); break;
        case 15: _t->schedulerJobStarted((*reinterpret_cast<std::add_pointer_t<QString>>(_a[1]))); break;
        case 16: _t->schedulerJobEnded((*reinterpret_cast<std::add_pointer_t<QString>>(_a[1])),(*reinterpret_cast<std::add_pointer_t<QString>>(_a[2]))); break;
        case 17: _t->newTargetDistance((*reinterpret_cast<std::add_pointer_t<double>>(_a[1]))); break;
        case 18: _t->userChangedYAxis((*reinterpret_cast<std::add_pointer_t<QObject*>>(_a[1])),(*reinterpret_cast<std::add_pointer_t<YAxisInfo>>(_a[2]))); break;
        case 19: _t->userSetLeftAxis((*reinterpret_cast<std::add_pointer_t<QCPAxis*>>(_a[1]))); break;
        case 20: _t->userSetAxisColor((*reinterpret_cast<std::add_pointer_t<QObject*>>(_a[1])),(*reinterpret_cast<std::add_pointer_t<YAxisInfo>>(_a[2])),(*reinterpret_cast<std::add_pointer_t<QColor>>(_a[3]))); break;
        case 21: _t->yAxisRangeChanged((*reinterpret_cast<std::add_pointer_t<QCPRange>>(_a[1]))); break;
        case 22: _t->appendLogText((*reinterpret_cast<std::add_pointer_t<QString>>(_a[1]))); break;
        default: ;
        }
    }
    if (_c == QMetaObject::RegisterMethodArgumentMetaType) {
        switch (_id) {
        default: *reinterpret_cast<QMetaType *>(_a[0]) = QMetaType(); break;
        case 4:
            switch (*reinterpret_cast<int*>(_a[1])) {
            default: *reinterpret_cast<QMetaType *>(_a[0]) = QMetaType(); break;
            case 0:
                *reinterpret_cast<QMetaType *>(_a[0]) = QMetaType::fromType< Ekos::GuideState >(); break;
            }
            break;
        case 11:
            switch (*reinterpret_cast<int*>(_a[1])) {
            default: *reinterpret_cast<QMetaType *>(_a[0]) = QMetaType(); break;
            case 0:
                *reinterpret_cast<QMetaType *>(_a[0]) = QMetaType::fromType< Ekos::AlignState >(); break;
            }
            break;
        case 12:
            switch (*reinterpret_cast<int*>(_a[1])) {
            default: *reinterpret_cast<QMetaType *>(_a[0]) = QMetaType(); break;
            case 0:
                *reinterpret_cast<QMetaType *>(_a[0]) = QMetaType::fromType< ISD::Mount::Status >(); break;
            }
            break;
        case 13:
            switch (*reinterpret_cast<int*>(_a[1])) {
            default: *reinterpret_cast<QMetaType *>(_a[0]) = QMetaType(); break;
            case 1:
                *reinterpret_cast<QMetaType *>(_a[0]) = QMetaType::fromType< ISD::Mount::PierSide >(); break;
            case 0:
                *reinterpret_cast<QMetaType *>(_a[0]) = QMetaType::fromType< SkyPoint >(); break;
            }
            break;
        case 19:
            switch (*reinterpret_cast<int*>(_a[1])) {
            default: *reinterpret_cast<QMetaType *>(_a[0]) = QMetaType(); break;
            case 0:
                *reinterpret_cast<QMetaType *>(_a[0]) = QMetaType::fromType< QCPAxis* >(); break;
            }
            break;
        }
    }
    if (_c == QMetaObject::IndexOfMethod) {
        if (QtMocHelpers::indexOfMethod<void (Analyze::*)(const QString & )>(_a, &Analyze::newLog, 0))
            return;
    }
}

const QMetaObject *Ekos::Analyze::metaObject() const
{
    return QObject::d_ptr->metaObject ? QObject::d_ptr->dynamicMetaObject() : &staticMetaObject;
}

void *Ekos::Analyze::qt_metacast(const char *_clname)
{
    if (!_clname) return nullptr;
    if (!strcmp(_clname, qt_staticMetaObjectStaticContent<qt_meta_tag_ZN4Ekos7AnalyzeE_t>.strings))
        return static_cast<void*>(this);
    if (!strcmp(_clname, "Ui::Analyze"))
        return static_cast< Ui::Analyze*>(this);
    return QWidget::qt_metacast(_clname);
}

int Ekos::Analyze::qt_metacall(QMetaObject::Call _c, int _id, void **_a)
{
    _id = QWidget::qt_metacall(_c, _id, _a);
    if (_id < 0)
        return _id;
    if (_c == QMetaObject::InvokeMetaMethod) {
        if (_id < 23)
            qt_static_metacall(this, _c, _id, _a);
        _id -= 23;
    }
    if (_c == QMetaObject::RegisterMethodArgumentMetaType) {
        if (_id < 23)
            qt_static_metacall(this, _c, _id, _a);
        _id -= 23;
    }
    return _id;
}

// SIGNAL 0
void Ekos::Analyze::newLog(const QString & _t1)
{
    QMetaObject::activate<void>(this, &staticMetaObject, 0, nullptr, _t1);
}
QT_WARNING_POP
