/********************************************************************************
** Form generated from reading UI file 'argsettrack.ui'
**
** Created by: Qt User Interface Compiler version 6.11.1
**
** WARNING! All changes made in this file will be lost when recompiling UI file!
********************************************************************************/

#ifndef UI_ARGSETTRACK_H
#define UI_ARGSETTRACK_H

#include <QtCore/QVariant>
#include <QtWidgets/QApplication>
#include <QtWidgets/QCheckBox>
#include <QtWidgets/QHBoxLayout>
#include <QtWidgets/QSpacerItem>
#include <QtWidgets/QVBoxLayout>
#include <QtWidgets/QWidget>
#include <klocalizedstring.h>

QT_BEGIN_NAMESPACE

class Ui_ArgSetTrack
{
public:
    QVBoxLayout *vboxLayout;
    QHBoxLayout *hboxLayout;
    QCheckBox *CheckTrack;
    QSpacerItem *spacerItem;
    QSpacerItem *spacerItem1;

    void setupUi(QWidget *ArgSetTrack)
    {
        if (ArgSetTrack->objectName().isEmpty())
            ArgSetTrack->setObjectName("ArgSetTrack");
        ArgSetTrack->resize(274, 61);
        vboxLayout = new QVBoxLayout(ArgSetTrack);
#ifndef UI_Q_OS_MAC
        vboxLayout->setSpacing(6);
#endif
        vboxLayout->setContentsMargins(10, 10, 10, 10);
        vboxLayout->setObjectName("vboxLayout");
        hboxLayout = new QHBoxLayout();
#ifndef UI_Q_OS_MAC
        hboxLayout->setSpacing(6);
#endif
#ifndef UI_Q_OS_MAC
        hboxLayout->setContentsMargins(0, 0, 0, 0);
#endif
        hboxLayout->setObjectName("hboxLayout");
        CheckTrack = new QCheckBox(ArgSetTrack);
        CheckTrack->setObjectName("CheckTrack");

        hboxLayout->addWidget(CheckTrack);

        spacerItem = new QSpacerItem(40, 20, QSizePolicy::Policy::Expanding, QSizePolicy::Policy::Minimum);

        hboxLayout->addItem(spacerItem);


        vboxLayout->addLayout(hboxLayout);

        spacerItem1 = new QSpacerItem(20, 40, QSizePolicy::Policy::Minimum, QSizePolicy::Policy::Expanding);

        vboxLayout->addItem(spacerItem1);


        retranslateUi(ArgSetTrack);

        QMetaObject::connectSlotsByName(ArgSetTrack);
    } // setupUi

    void retranslateUi(QWidget *ArgSetTrack)
    {
#if QT_CONFIG(tooltip)
        CheckTrack->setToolTip(tr2i18n("Toggle Tracking on/off", nullptr));
#endif // QT_CONFIG(tooltip)
#if QT_CONFIG(whatsthis)
        CheckTrack->setWhatsThis(tr2i18n("If checked, the sky will remain focused on its current position or object as time passes.  This is called \"Tracking\".  Note that tracking is automatically engaged whenever an object is centered at the focus point.  So, if you use \"lookToward\" with an object name, you do not need to engage tracking.  \n"
"\n"
"If unchecked, then Tracking will be forced off, even if an object has been centered.  As time passes, the sky will then appear to drift by (due to the rotation of the Earth).", nullptr));
#endif // QT_CONFIG(whatsthis)
        CheckTrack->setText(tr2i18n("Track", nullptr));
        (void)ArgSetTrack;
    } // retranslateUi

};

namespace Ui {
    class ArgSetTrack: public Ui_ArgSetTrack {};
} // namespace Ui

QT_END_NAMESPACE

#endif // ARGSETTRACK_H

