/********************************************************************************
** Form generated from reading UI file 'opsfocussettings.ui'
**
** Created by: Qt User Interface Compiler version 6.11.1
**
** WARNING! All changes made in this file will be lost when recompiling UI file!
********************************************************************************/

#ifndef UI_OPSFOCUSSETTINGS_H
#define UI_OPSFOCUSSETTINGS_H

#include <QtCore/QVariant>
#include <QtWidgets/QApplication>
#include <QtWidgets/QCheckBox>
#include <QtWidgets/QComboBox>
#include <QtWidgets/QDoubleSpinBox>
#include <QtWidgets/QGridLayout>
#include <QtWidgets/QGroupBox>
#include <QtWidgets/QLabel>
#include <QtWidgets/QRadioButton>
#include <QtWidgets/QSpinBox>
#include <QtWidgets/QVBoxLayout>
#include <QtWidgets/QWidget>
#include <klocalizedstring.h>

QT_BEGIN_NAMESPACE

class Ui_OpsFocusSettings
{
public:
    QVBoxLayout *verticalLayout_3;
    QGroupBox *generaGroupBox;
    QGridLayout *gridLayoutSettings_2;
    QRadioButton *focusUseFullField;
    QLabel *focusBoxSizeLabel;
    QComboBox *focusUnits;
    QLabel *label_39;
    QCheckBox *focusAutoStarEnabled;
    QDoubleSpinBox *focusGuideSettleTime;
    QRadioButton *focusSubFrame;
    QCheckBox *useFocusDarkFrame;
    QLabel *label_18;
    QSpinBox *focusBoxSize;
    QCheckBox *focusSuspendGuiding;
    QLabel *label;
    QSpinBox *focusAFOptimize;
    QSpinBox *maxFocusFrameFiles;
    QLabel *label_2;
    QGroupBox *maskGroupBox;
    QGridLayout *gridLayout;
    QRadioButton *focusMosaicMaskRB;
    QRadioButton *focusRingMaskRB;
    QSpinBox *focusMosaicSpace;
    QSpinBox *focusMosaicTileWidth;
    QDoubleSpinBox *focusFullFieldInnerRadius;
    QLabel *focusSpacerLabel;
    QRadioButton *focusNoMaskRB;
    QDoubleSpinBox *focusFullFieldOuterRadius;
    QGroupBox *adaptiveFocusGroup;
    QGridLayout *gridLayout_2;
    QSpinBox *focusAdaptiveMinMove;
    QSpinBox *focusAdaptiveMaxMove;
    QCheckBox *focusAdaptive;
    QLabel *label_7;
    QCheckBox *focusAdaptStart;
    QLabel *label_6;

    void setupUi(QWidget *OpsFocusSettings)
    {
        if (OpsFocusSettings->objectName().isEmpty())
            OpsFocusSettings->setObjectName("OpsFocusSettings");
        OpsFocusSettings->resize(601, 484);
        verticalLayout_3 = new QVBoxLayout(OpsFocusSettings);
        verticalLayout_3->setObjectName("verticalLayout_3");
        generaGroupBox = new QGroupBox(OpsFocusSettings);
        generaGroupBox->setObjectName("generaGroupBox");
        gridLayoutSettings_2 = new QGridLayout(generaGroupBox);
        gridLayoutSettings_2->setSpacing(6);
        gridLayoutSettings_2->setObjectName("gridLayoutSettings_2");
        focusUseFullField = new QRadioButton(generaGroupBox);
        focusUseFullField->setObjectName("focusUseFullField");
        QSizePolicy sizePolicy(QSizePolicy::Policy::Preferred, QSizePolicy::Policy::Fixed);
        sizePolicy.setHorizontalStretch(0);
        sizePolicy.setVerticalStretch(0);
        sizePolicy.setHeightForWidth(focusUseFullField->sizePolicy().hasHeightForWidth());
        focusUseFullField->setSizePolicy(sizePolicy);
        focusUseFullField->setChecked(false);

        gridLayoutSettings_2->addWidget(focusUseFullField, 1, 0, 1, 1);

        focusBoxSizeLabel = new QLabel(generaGroupBox);
        focusBoxSizeLabel->setObjectName("focusBoxSizeLabel");
        sizePolicy.setHeightForWidth(focusBoxSizeLabel->sizePolicy().hasHeightForWidth());
        focusBoxSizeLabel->setSizePolicy(sizePolicy);
        focusBoxSizeLabel->setAlignment(Qt::AlignRight|Qt::AlignTrailing|Qt::AlignVCenter);

        gridLayoutSettings_2->addWidget(focusBoxSizeLabel, 1, 3, 1, 1);

        focusUnits = new QComboBox(generaGroupBox);
        focusUnits->addItem(QString());
        focusUnits->addItem(QString());
        focusUnits->setObjectName("focusUnits");

        gridLayoutSettings_2->addWidget(focusUnits, 2, 1, 1, 1);

        label_39 = new QLabel(generaGroupBox);
        label_39->setObjectName("label_39");
        sizePolicy.setHeightForWidth(label_39->sizePolicy().hasHeightForWidth());
        label_39->setSizePolicy(sizePolicy);
        label_39->setAlignment(Qt::AlignLeading|Qt::AlignLeft|Qt::AlignVCenter);

        gridLayoutSettings_2->addWidget(label_39, 2, 0, 1, 1);

        focusAutoStarEnabled = new QCheckBox(generaGroupBox);
        focusAutoStarEnabled->setObjectName("focusAutoStarEnabled");
        sizePolicy.setHeightForWidth(focusAutoStarEnabled->sizePolicy().hasHeightForWidth());
        focusAutoStarEnabled->setSizePolicy(sizePolicy);
        focusAutoStarEnabled->setAutoRepeatDelay(298);

        gridLayoutSettings_2->addWidget(focusAutoStarEnabled, 0, 0, 1, 1);

        focusGuideSettleTime = new QDoubleSpinBox(generaGroupBox);
        focusGuideSettleTime->setObjectName("focusGuideSettleTime");
        sizePolicy.setHeightForWidth(focusGuideSettleTime->sizePolicy().hasHeightForWidth());
        focusGuideSettleTime->setSizePolicy(sizePolicy);
        focusGuideSettleTime->setMaximum(60.000000000000000);

        gridLayoutSettings_2->addWidget(focusGuideSettleTime, 2, 4, 1, 1);

        focusSubFrame = new QRadioButton(generaGroupBox);
        focusSubFrame->setObjectName("focusSubFrame");
        sizePolicy.setHeightForWidth(focusSubFrame->sizePolicy().hasHeightForWidth());
        focusSubFrame->setSizePolicy(sizePolicy);
        focusSubFrame->setChecked(false);

        gridLayoutSettings_2->addWidget(focusSubFrame, 1, 1, 1, 2);

        useFocusDarkFrame = new QCheckBox(generaGroupBox);
        useFocusDarkFrame->setObjectName("useFocusDarkFrame");
        sizePolicy.setHeightForWidth(useFocusDarkFrame->sizePolicy().hasHeightForWidth());
        useFocusDarkFrame->setSizePolicy(sizePolicy);

        gridLayoutSettings_2->addWidget(useFocusDarkFrame, 0, 3, 1, 1);

        label_18 = new QLabel(generaGroupBox);
        label_18->setObjectName("label_18");
        sizePolicy.setHeightForWidth(label_18->sizePolicy().hasHeightForWidth());
        label_18->setSizePolicy(sizePolicy);
        label_18->setAlignment(Qt::AlignRight|Qt::AlignTrailing|Qt::AlignVCenter);

        gridLayoutSettings_2->addWidget(label_18, 2, 3, 1, 1);

        focusBoxSize = new QSpinBox(generaGroupBox);
        focusBoxSize->setObjectName("focusBoxSize");
        sizePolicy.setHeightForWidth(focusBoxSize->sizePolicy().hasHeightForWidth());
        focusBoxSize->setSizePolicy(sizePolicy);
        focusBoxSize->setMinimum(16);
        focusBoxSize->setMaximum(256);
        focusBoxSize->setSingleStep(16);
        focusBoxSize->setStepType(QAbstractSpinBox::DefaultStepType);
        focusBoxSize->setValue(32);

        gridLayoutSettings_2->addWidget(focusBoxSize, 1, 4, 1, 1);

        focusSuspendGuiding = new QCheckBox(generaGroupBox);
        focusSuspendGuiding->setObjectName("focusSuspendGuiding");
        sizePolicy.setHeightForWidth(focusSuspendGuiding->sizePolicy().hasHeightForWidth());
        focusSuspendGuiding->setSizePolicy(sizePolicy);

        gridLayoutSettings_2->addWidget(focusSuspendGuiding, 0, 1, 1, 1);

        label = new QLabel(generaGroupBox);
        label->setObjectName("label");
        sizePolicy.setHeightForWidth(label->sizePolicy().hasHeightForWidth());
        label->setSizePolicy(sizePolicy);

        gridLayoutSettings_2->addWidget(label, 3, 0, 1, 1);

        focusAFOptimize = new QSpinBox(generaGroupBox);
        focusAFOptimize->setObjectName("focusAFOptimize");
        sizePolicy.setHeightForWidth(focusAFOptimize->sizePolicy().hasHeightForWidth());
        focusAFOptimize->setSizePolicy(sizePolicy);
        focusAFOptimize->setAlignment(Qt::AlignRight|Qt::AlignTrailing|Qt::AlignVCenter);
        focusAFOptimize->setMaximum(1000);

        gridLayoutSettings_2->addWidget(focusAFOptimize, 3, 1, 1, 1);

        maxFocusFrameFiles = new QSpinBox(generaGroupBox);
        maxFocusFrameFiles->setObjectName("maxFocusFrameFiles");
        maxFocusFrameFiles->setMinimum(-1);
        maxFocusFrameFiles->setMaximum(9999);

        gridLayoutSettings_2->addWidget(maxFocusFrameFiles, 3, 4, 1, 1);

        label_2 = new QLabel(generaGroupBox);
        label_2->setObjectName("label_2");

        gridLayoutSettings_2->addWidget(label_2, 3, 2, 1, 2, Qt::AlignRight);


        verticalLayout_3->addWidget(generaGroupBox);

        maskGroupBox = new QGroupBox(OpsFocusSettings);
        maskGroupBox->setObjectName("maskGroupBox");
        gridLayout = new QGridLayout(maskGroupBox);
        gridLayout->setSpacing(6);
        gridLayout->setObjectName("gridLayout");
        focusMosaicMaskRB = new QRadioButton(maskGroupBox);
        focusMosaicMaskRB->setObjectName("focusMosaicMaskRB");
        sizePolicy.setHeightForWidth(focusMosaicMaskRB->sizePolicy().hasHeightForWidth());
        focusMosaicMaskRB->setSizePolicy(sizePolicy);

        gridLayout->addWidget(focusMosaicMaskRB, 2, 0, 1, 1);

        focusRingMaskRB = new QRadioButton(maskGroupBox);
        focusRingMaskRB->setObjectName("focusRingMaskRB");
        sizePolicy.setHeightForWidth(focusRingMaskRB->sizePolicy().hasHeightForWidth());
        focusRingMaskRB->setSizePolicy(sizePolicy);
        focusRingMaskRB->setChecked(false);

        gridLayout->addWidget(focusRingMaskRB, 1, 0, 1, 1);

        focusMosaicSpace = new QSpinBox(maskGroupBox);
        focusMosaicSpace->setObjectName("focusMosaicSpace");
        sizePolicy.setHeightForWidth(focusMosaicSpace->sizePolicy().hasHeightForWidth());
        focusMosaicSpace->setSizePolicy(sizePolicy);
        focusMosaicSpace->setAlignment(Qt::AlignRight|Qt::AlignTrailing|Qt::AlignVCenter);
        focusMosaicSpace->setMinimum(1);
        focusMosaicSpace->setValue(5);

        gridLayout->addWidget(focusMosaicSpace, 2, 3, 1, 1);

        focusMosaicTileWidth = new QSpinBox(maskGroupBox);
        focusMosaicTileWidth->setObjectName("focusMosaicTileWidth");
        sizePolicy.setHeightForWidth(focusMosaicTileWidth->sizePolicy().hasHeightForWidth());
        focusMosaicTileWidth->setSizePolicy(sizePolicy);
        focusMosaicTileWidth->setAlignment(Qt::AlignRight|Qt::AlignTrailing|Qt::AlignVCenter);
        focusMosaicTileWidth->setMinimum(1);
        focusMosaicTileWidth->setMaximum(33);
        focusMosaicTileWidth->setSingleStep(1);
        focusMosaicTileWidth->setValue(25);

        gridLayout->addWidget(focusMosaicTileWidth, 2, 1, 1, 1);

        focusFullFieldInnerRadius = new QDoubleSpinBox(maskGroupBox);
        focusFullFieldInnerRadius->setObjectName("focusFullFieldInnerRadius");
        sizePolicy.setHeightForWidth(focusFullFieldInnerRadius->sizePolicy().hasHeightForWidth());
        focusFullFieldInnerRadius->setSizePolicy(sizePolicy);
        focusFullFieldInnerRadius->setAlignment(Qt::AlignRight|Qt::AlignTrailing|Qt::AlignVCenter);
        focusFullFieldInnerRadius->setDecimals(1);
        focusFullFieldInnerRadius->setSingleStep(10.000000000000000);

        gridLayout->addWidget(focusFullFieldInnerRadius, 1, 1, 1, 1);

        focusSpacerLabel = new QLabel(maskGroupBox);
        focusSpacerLabel->setObjectName("focusSpacerLabel");
        sizePolicy.setHeightForWidth(focusSpacerLabel->sizePolicy().hasHeightForWidth());
        focusSpacerLabel->setSizePolicy(sizePolicy);

        gridLayout->addWidget(focusSpacerLabel, 2, 2, 1, 1, Qt::AlignRight);

        focusNoMaskRB = new QRadioButton(maskGroupBox);
        focusNoMaskRB->setObjectName("focusNoMaskRB");
        sizePolicy.setHeightForWidth(focusNoMaskRB->sizePolicy().hasHeightForWidth());
        focusNoMaskRB->setSizePolicy(sizePolicy);
        focusNoMaskRB->setChecked(true);

        gridLayout->addWidget(focusNoMaskRB, 0, 0, 1, 2);

        focusFullFieldOuterRadius = new QDoubleSpinBox(maskGroupBox);
        focusFullFieldOuterRadius->setObjectName("focusFullFieldOuterRadius");
        sizePolicy.setHeightForWidth(focusFullFieldOuterRadius->sizePolicy().hasHeightForWidth());
        focusFullFieldOuterRadius->setSizePolicy(sizePolicy);
        focusFullFieldOuterRadius->setAlignment(Qt::AlignRight|Qt::AlignTrailing|Qt::AlignVCenter);
        focusFullFieldOuterRadius->setDecimals(1);
        focusFullFieldOuterRadius->setSingleStep(10.000000000000000);
        focusFullFieldOuterRadius->setValue(100.000000000000000);

        gridLayout->addWidget(focusFullFieldOuterRadius, 1, 3, 1, 1);


        verticalLayout_3->addWidget(maskGroupBox);

        adaptiveFocusGroup = new QGroupBox(OpsFocusSettings);
        adaptiveFocusGroup->setObjectName("adaptiveFocusGroup");
        adaptiveFocusGroup->setEnabled(true);
        QSizePolicy sizePolicy1(QSizePolicy::Policy::Preferred, QSizePolicy::Policy::Preferred);
        sizePolicy1.setHorizontalStretch(0);
        sizePolicy1.setVerticalStretch(0);
        sizePolicy1.setHeightForWidth(adaptiveFocusGroup->sizePolicy().hasHeightForWidth());
        adaptiveFocusGroup->setSizePolicy(sizePolicy1);
        gridLayout_2 = new QGridLayout(adaptiveFocusGroup);
        gridLayout_2->setSpacing(6);
        gridLayout_2->setObjectName("gridLayout_2");
        gridLayout_2->setContentsMargins(12, 12, 12, 12);
        focusAdaptiveMinMove = new QSpinBox(adaptiveFocusGroup);
        focusAdaptiveMinMove->setObjectName("focusAdaptiveMinMove");
        sizePolicy.setHeightForWidth(focusAdaptiveMinMove->sizePolicy().hasHeightForWidth());
        focusAdaptiveMinMove->setSizePolicy(sizePolicy);
        focusAdaptiveMinMove->setMinimum(1);
        focusAdaptiveMinMove->setMaximum(10000);
        focusAdaptiveMinMove->setValue(1);

        gridLayout_2->addWidget(focusAdaptiveMinMove, 0, 2, 1, 1);

        focusAdaptiveMaxMove = new QSpinBox(adaptiveFocusGroup);
        focusAdaptiveMaxMove->setObjectName("focusAdaptiveMaxMove");
        sizePolicy.setHeightForWidth(focusAdaptiveMaxMove->sizePolicy().hasHeightForWidth());
        focusAdaptiveMaxMove->setSizePolicy(sizePolicy);
        focusAdaptiveMaxMove->setMinimum(1);
        focusAdaptiveMaxMove->setMaximum(100000);
        focusAdaptiveMaxMove->setValue(1000);

        gridLayout_2->addWidget(focusAdaptiveMaxMove, 3, 2, 4, 1);

        focusAdaptive = new QCheckBox(adaptiveFocusGroup);
        focusAdaptive->setObjectName("focusAdaptive");
        sizePolicy.setHeightForWidth(focusAdaptive->sizePolicy().hasHeightForWidth());
        focusAdaptive->setSizePolicy(sizePolicy);

        gridLayout_2->addWidget(focusAdaptive, 0, 0, 1, 1);

        label_7 = new QLabel(adaptiveFocusGroup);
        label_7->setObjectName("label_7");
        sizePolicy.setHeightForWidth(label_7->sizePolicy().hasHeightForWidth());
        label_7->setSizePolicy(sizePolicy);
        label_7->setAlignment(Qt::AlignRight|Qt::AlignTrailing|Qt::AlignVCenter);

        gridLayout_2->addWidget(label_7, 0, 1, 1, 1);

        focusAdaptStart = new QCheckBox(adaptiveFocusGroup);
        focusAdaptStart->setObjectName("focusAdaptStart");
        sizePolicy.setHeightForWidth(focusAdaptStart->sizePolicy().hasHeightForWidth());
        focusAdaptStart->setSizePolicy(sizePolicy);

        gridLayout_2->addWidget(focusAdaptStart, 3, 0, 4, 1);

        label_6 = new QLabel(adaptiveFocusGroup);
        label_6->setObjectName("label_6");
        sizePolicy.setHeightForWidth(label_6->sizePolicy().hasHeightForWidth());
        label_6->setSizePolicy(sizePolicy);
        label_6->setAlignment(Qt::AlignRight|Qt::AlignTrailing|Qt::AlignVCenter);

        gridLayout_2->addWidget(label_6, 4, 1, 1, 1);


        verticalLayout_3->addWidget(adaptiveFocusGroup);

#if QT_CONFIG(shortcut)
        focusBoxSizeLabel->setBuddy(focusBoxSize);
        label_39->setBuddy(focusUnits);
        label_18->setBuddy(focusGuideSettleTime);
        focusSpacerLabel->setBuddy(focusMosaicSpace);
        label_7->setBuddy(focusAdaptiveMinMove);
        label_6->setBuddy(focusAdaptiveMaxMove);
#endif // QT_CONFIG(shortcut)
        QWidget::setTabOrder(focusAutoStarEnabled, focusSuspendGuiding);
        QWidget::setTabOrder(focusSuspendGuiding, useFocusDarkFrame);
        QWidget::setTabOrder(useFocusDarkFrame, focusUseFullField);
        QWidget::setTabOrder(focusUseFullField, focusSubFrame);
        QWidget::setTabOrder(focusSubFrame, focusBoxSize);
        QWidget::setTabOrder(focusBoxSize, focusUnits);
        QWidget::setTabOrder(focusUnits, focusGuideSettleTime);
        QWidget::setTabOrder(focusGuideSettleTime, focusNoMaskRB);
        QWidget::setTabOrder(focusNoMaskRB, focusRingMaskRB);
        QWidget::setTabOrder(focusRingMaskRB, focusFullFieldInnerRadius);
        QWidget::setTabOrder(focusFullFieldInnerRadius, focusFullFieldOuterRadius);
        QWidget::setTabOrder(focusFullFieldOuterRadius, focusMosaicMaskRB);
        QWidget::setTabOrder(focusMosaicMaskRB, focusMosaicTileWidth);
        QWidget::setTabOrder(focusMosaicTileWidth, focusMosaicSpace);
        QWidget::setTabOrder(focusMosaicSpace, focusAdaptive);
        QWidget::setTabOrder(focusAdaptive, focusAdaptiveMinMove);
        QWidget::setTabOrder(focusAdaptiveMinMove, focusAdaptStart);
        QWidget::setTabOrder(focusAdaptStart, focusAdaptiveMaxMove);

        retranslateUi(OpsFocusSettings);

        QMetaObject::connectSlotsByName(OpsFocusSettings);
    } // setupUi

    void retranslateUi(QWidget *OpsFocusSettings)
    {
        OpsFocusSettings->setWindowTitle(tr2i18n("Focus Settings", nullptr));
        generaGroupBox->setTitle(tr2i18n("General", nullptr));
#if QT_CONFIG(tooltip)
        focusUseFullField->setToolTip(tr2i18n("<html><head/><body><p>Select Full Field to allow focus to use multiple stars (note: Sub Frame uses a single star).  In this mode Ekos will automatically select multiple stars during Autofocus and,  for example,  average the HFR of all stars detected to perform focus. </p></body></html>", nullptr));
#endif // QT_CONFIG(tooltip)
        focusUseFullField->setText(tr2i18n("Full Field", nullptr));
        focusBoxSizeLabel->setText(tr2i18n("Box:", nullptr));
        focusUnits->setItemText(0, tr2i18n("Pixels", nullptr));
        focusUnits->setItemText(1, tr2i18n("Arc Seconds", nullptr));

#if QT_CONFIG(tooltip)
        focusUnits->setToolTip(tr2i18n("<html><head/><body><p>Display units for HFR and FWHM.</p></body></html>", nullptr));
#endif // QT_CONFIG(tooltip)
        label_39->setText(tr2i18n("Display Units:", nullptr));
#if QT_CONFIG(tooltip)
        focusAutoStarEnabled->setToolTip(tr2i18n("<html><head/><body><p>This option is only active when Sub Frame is selected.  Check to allow Ekos to select a single star for focus; uncheck to allow the user to select the star to use in FitsViewer.</p></body></html>", nullptr));
#endif // QT_CONFIG(tooltip)
        focusAutoStarEnabled->setText(tr2i18n("Auto Select Star", nullptr));
#if QT_CONFIG(tooltip)
        focusGuideSettleTime->setToolTip(tr2i18n("<html><head/><body><p>Wait this many seconds after autofocus completes before resuming guiding.</p></body></html>", nullptr));
#endif // QT_CONFIG(tooltip)
        focusGuideSettleTime->setSuffix(tr2i18n(" s", nullptr));
#if QT_CONFIG(tooltip)
        focusSubFrame->setToolTip(tr2i18n("<html><head/><body><p>Select Sub Frame to make focus to use a single star (note: Full Field uses multiple stars).  In this mode the Auto Select Star checkbox becomes active to allow either Ekos to select a star (when checked) or to allow the user to manually select the star in FitsViewer (when unchecked).</p></body></html>", nullptr));
#endif // QT_CONFIG(tooltip)
        focusSubFrame->setText(tr2i18n("Sub Frame", nullptr));
#if QT_CONFIG(tooltip)
        useFocusDarkFrame->setToolTip(tr2i18n("<html><head/><body><p>Subtract dark frame. Create dark frames or defect maps in the Dark Library tool in the capture module.</p></body></html>", nullptr));
#endif // QT_CONFIG(tooltip)
        useFocusDarkFrame->setText(tr2i18n("Dark Frame", nullptr));
        label_18->setText(tr2i18n("Guide Settle:", nullptr));
#if QT_CONFIG(tooltip)
        focusBoxSize->setToolTip(tr2i18n("<html><head/><body><p>Size of the subframe in pixels.</p></body></html>", nullptr));
#endif // QT_CONFIG(tooltip)
        focusBoxSize->setSuffix(tr2i18n(" px", nullptr));
#if QT_CONFIG(tooltip)
        focusSuspendGuiding->setToolTip(tr2i18n("Suspend Guiding while autofocus in progress", nullptr));
#endif // QT_CONFIG(tooltip)
        focusSuspendGuiding->setText(tr2i18n("Suspend Guiding", nullptr));
        label->setText(tr2i18n("Optimize AF:", nullptr));
#if QT_CONFIG(tooltip)
        focusAFOptimize->setToolTip(tr2i18n("<html><head/><body><p>Create an &quot;optimization zone&quot; of this many seconds. When an automated Autofocus run is requested by another process, e.g. Scheduler or Capture, a check is performed on the timestamp of the last successful Autofocus for that filter. If we are within the optimization zone then no Autofocus is run; if outside the zone, Autofocus is run as normal.</p><p>Note that filter offsets and Adaptive Focus settings are always honoured.</p><p>Set to zero to disable this feature.</p><p>NOTE: manually initiated runs will always be performed.</p><p>This is currently an experimental feature enabled for Linear and Linear 1 Pass only.</p></body></html>", nullptr));
#endif // QT_CONFIG(tooltip)
        focusAFOptimize->setSuffix(tr2i18n(" s", nullptr));
#if QT_CONFIG(tooltip)
        maxFocusFrameFiles->setToolTip(tr2i18n("Upper limit how many focus frames should be kept on disk. Set to -1 to allow arbitrary many files.", nullptr));
#endif // QT_CONFIG(tooltip)
        label_2->setText(tr2i18n("Max. Stored Frames:", nullptr));
        maskGroupBox->setTitle(tr2i18n("Mask", nullptr));
#if QT_CONFIG(tooltip)
        focusMosaicMaskRB->setToolTip(tr2i18n("<html><head/><body><p>Aberration inspector style mask with a 3x3 mosaic formed with tiles from the center, the corners and the edges.</p></body></html>", nullptr));
#endif // QT_CONFIG(tooltip)
        focusMosaicMaskRB->setText(tr2i18n("Mosaic Mask:", nullptr));
#if QT_CONFIG(tooltip)
        focusRingMaskRB->setToolTip(tr2i18n("<html><head/><body><p>During Full Field focusing, this controls the size of an Annulus centred at the middle of the sensor to include for processing. Set inner % to zero to include the centre of the sensor and set outer % to 100 to include the outer edges of the sensor. </p></body></html>", nullptr));
#endif // QT_CONFIG(tooltip)
        focusRingMaskRB->setText(tr2i18n("Ring Mask:", nullptr));
#if QT_CONFIG(tooltip)
        focusMosaicSpace->setToolTip(tr2i18n("<html><head/><body><p>Size of the separator between the tiles.</p></body></html>", nullptr));
#endif // QT_CONFIG(tooltip)
        focusMosaicSpace->setSuffix(tr2i18n(" px", nullptr));
#if QT_CONFIG(tooltip)
        focusMosaicTileWidth->setToolTip(tr2i18n("<html><head/><body><p>Tiles are squares with an edge length calculated by the given percentage of the image width. The percentage is limited such that the tile size does not exceed one third of the shorter side of the image (in most cases, it's height).</p></body></html>", nullptr));
#endif // QT_CONFIG(tooltip)
        focusMosaicTileWidth->setSuffix(tr2i18n(" %", nullptr));
        focusMosaicTileWidth->setPrefix(QString());
#if QT_CONFIG(tooltip)
        focusFullFieldInnerRadius->setToolTip(tr2i18n("<html><head/><body><p>Diameter of the inner circle to be excluded from focusing (e.g. a centered galaxy or star cluster). The diameter is given as percentage of the image diagonal. Set to zero to include the centre of the sensor.</p></body></html>", nullptr));
#endif // QT_CONFIG(tooltip)
        focusFullFieldInnerRadius->setSuffix(tr2i18n(" %", nullptr));
        focusSpacerLabel->setText(tr2i18n("Spacer:", nullptr));
#if QT_CONFIG(tooltip)
        focusNoMaskRB->setToolTip(tr2i18n("All stars are used for focusing.", nullptr));
#endif // QT_CONFIG(tooltip)
        focusNoMaskRB->setText(tr2i18n("Use all stars for focusing", nullptr));
#if QT_CONFIG(tooltip)
        focusFullFieldOuterRadius->setToolTip(tr2i18n("<html><head/><body><p>Diameter of the outer circle to be excluded from focusing. The diameter is given as percentage of the image diagonal. Set to 100% to include the outer edges of the sensor. </p></body></html>", nullptr));
#endif // QT_CONFIG(tooltip)
        focusFullFieldOuterRadius->setSuffix(tr2i18n(" %", nullptr));
        adaptiveFocusGroup->setTitle(tr2i18n("Adaptive Focus", nullptr));
#if QT_CONFIG(tooltip)
        focusAdaptiveMinMove->setToolTip(tr2i18n("<html><head/><body><p>The minimum size of an adaptive focus change that will be sent to the focuser.</p></body></html>", nullptr));
#endif // QT_CONFIG(tooltip)
        focusAdaptiveMinMove->setSuffix(tr2i18n(" ticks", nullptr));
#if QT_CONFIG(tooltip)
        focusAdaptiveMaxMove->setToolTip(tr2i18n("<html><head/><body><p>The maximum total Adaptive focuser movement between Autofocus runs.  If this value is hit,  adaptive focusing is suspended.  The purpose of this control is to handle runaway adaptive focusing.</p></body></html>", nullptr));
#endif // QT_CONFIG(tooltip)
        focusAdaptiveMaxMove->setSuffix(tr2i18n(" ticks", nullptr));
#if QT_CONFIG(tooltip)
        focusAdaptive->setToolTip(tr2i18n("<html><head/><body><p>Enable Adaptive Focus between subframes. This is an experimental feature.</p></body></html>", nullptr));
#endif // QT_CONFIG(tooltip)
        focusAdaptive->setText(tr2i18n("Adaptive Focus", nullptr));
#if QT_CONFIG(tooltip)
        label_7->setToolTip(tr2i18n("<html><head/><body><p>Minimum focuser movement when using Adaptive Focus.</p></body></html>", nullptr));
#endif // QT_CONFIG(tooltip)
        label_7->setText(tr2i18n("Min Move:", nullptr));
#if QT_CONFIG(tooltip)
        focusAdaptStart->setToolTip(tr2i18n("<html><head/><body><p>Adapt the Autofocus start position based on filter and the Adaptive Focus settings. This is an experimental feature.</p></body></html>", nullptr));
#endif // QT_CONFIG(tooltip)
        focusAdaptStart->setText(tr2i18n("Adapt Start Pos", nullptr));
        label_6->setText(tr2i18n("Max Total Move:", nullptr));
    } // retranslateUi

};

namespace Ui {
    class OpsFocusSettings: public Ui_OpsFocusSettings {};
} // namespace Ui

QT_END_NAMESPACE

#endif // OPSFOCUSSETTINGS_H

