/*
 * This file was generated by qdbusxml2cpp version 0.8
 * Source file was org.kde.kstars.Ekos.Scheduler.xml
 *
 * qdbusxml2cpp is Copyright (C) The Qt Company Ltd. and other contributors.
 *
 * This is an auto-generated file.
 * This file may have been hand-edited. Look for HAND-EDIT comments
 * before re-generating it.
 */

#ifndef SCHEDULERADAPTOR_H
#define SCHEDULERADAPTOR_H

#include <QtCore/QObject>
#include <QtDBus/QtDBus>
#include "ekos/scheduler/schedulerprocess.h"
#include <QtCore/qcontainerfwd.h>

/*
 * Adaptor class for interface org.kde.kstars.Ekos.Scheduler
 */
class SchedulerAdaptor: public QDBusAbstractAdaptor
{
    Q_OBJECT
    Q_CLASSINFO("D-Bus Interface", "org.kde.kstars.Ekos.Scheduler")
    Q_CLASSINFO("D-Bus Introspection", ""
"  <interface name=\"org.kde.kstars.Ekos.Scheduler\">\n"
"    <property access=\"readwrite\" type=\"s\" name=\"profile\"/>\n"
"    <property access=\"read\" type=\"s\" name=\"currentJobName\"/>\n"
"    <property access=\"read\" type=\"s\" name=\"currentJobJson\"/>\n"
"    <property access=\"read\" type=\"s\" name=\"jsonJobs\"/>\n"
"    <property access=\"read\" type=\"as\" name=\"logText\"/>\n"
"    <property access=\"read\" type=\"i\" name=\"status\">\n"
"      <annotation value=\"Ekos::SchedulerState\" name=\"org.qtproject.QtDBus.QtTypeName\"/>\n"
"    </property>\n"
"    <method name=\"start\">\n"
"      <annotation value=\"true\" name=\"org.freedesktop.DBus.Method.NoReply\"/>\n"
"    </method>\n"
"    <method name=\"stop\">\n"
"      <annotation value=\"true\" name=\"org.freedesktop.DBus.Method.NoReply\"/>\n"
"    </method>\n"
"    <method name=\"removeAllJobs\">\n"
"      <annotation value=\"true\" name=\"org.freedesktop.DBus.Method.NoReply\"/>\n"
"    </method>\n"
"    <method name=\"loadScheduler\">\n"
"      <arg direction=\"in\" type=\"s\" name=\"fileURL\"/>\n"
"      <arg direction=\"out\" type=\"b\"/>\n"
"      <annotation value=\"QUrl\" name=\"org.qtproject.QtDBus.QtTypeName.In0\"/>\n"
"    </method>\n"
"    <method name=\"setSequence\">\n"
"      <annotation value=\"true\" name=\"org.freedesktop.DBus.Method.NoReply\"/>\n"
"      <arg direction=\"in\" type=\"s\" name=\"sequenceFileURL\"/>\n"
"      <annotation value=\"QUrl\" name=\"org.qtproject.QtDBus.QtTypeName.In0\"/>\n"
"    </method>\n"
"    <method name=\"resetAllJobs\">\n"
"      <annotation value=\"true\" name=\"org.freedesktop.DBus.Method.NoReply\"/>\n"
"    </method>\n"
"    <signal name=\"newStatus\">\n"
"      <arg direction=\"out\" type=\"(i)\" name=\"status\"/>\n"
"      <annotation value=\"Ekos::SchedulerState\" name=\"org.qtproject.QtDBus.QtTypeName.In0\"/>\n"
"      <annotation value=\"Ekos::SchedulerState\" name=\"org.qtproject.QtDBus.QtTypeName.Out0\"/>\n"
"    </signal>\n"
"    <signal name=\"newLog\">\n"
"      <arg direction=\"out\" type=\"s\" name=\"text\"/>\n"
"    </signal>\n"
"  </interface>\n"
        "")
public:
    SchedulerAdaptor(Ekos::SchedulerProcess *parent);
    ~SchedulerAdaptor() override;

    inline Ekos::SchedulerProcess *parent() const
    { return static_cast<Ekos::SchedulerProcess *>(QObject::parent()); }

public: // PROPERTIES
    Q_PROPERTY(QString currentJobJson READ currentJobJson)
    QString currentJobJson() const;

    Q_PROPERTY(QString currentJobName READ currentJobName)
    QString currentJobName() const;

    Q_PROPERTY(QString jsonJobs READ jsonJobs)
    QString jsonJobs() const;

    Q_PROPERTY(QStringList logText READ logText)
    QStringList logText() const;

    Q_PROPERTY(QString profile READ profile WRITE setProfile)
    QString profile() const;
    void setProfile(const QString &value);

    Q_PROPERTY(int status READ status)
    int status() const;

public Q_SLOTS: // METHODS
    bool loadScheduler(const QString &fileURL);
    Q_NOREPLY void removeAllJobs();
    Q_NOREPLY void resetAllJobs();
    Q_NOREPLY void setSequence(const QString &sequenceFileURL);
    Q_NOREPLY void start();
    Q_NOREPLY void stop();
Q_SIGNALS: // SIGNALS
    void newLog(const QString &text);
    void newStatus(Ekos::SchedulerState status);
};

#endif
