/********************************************************************************
** Form generated from reading UI file 'foveditordialog.ui'
**
** Created by: Qt User Interface Compiler version 6.11.1
**
** WARNING! All changes made in this file will be lost when recompiling UI file!
********************************************************************************/

#ifndef UI_FOVEDITORDIALOG_H
#define UI_FOVEDITORDIALOG_H

#include <QtCore/QVariant>
#include <QtWidgets/QApplication>
#include <QtWidgets/QGridLayout>
#include <QtWidgets/QHBoxLayout>
#include <QtWidgets/QLabel>
#include <QtWidgets/QLineEdit>
#include <QtWidgets/QPushButton>
#include <QtWidgets/QSpacerItem>
#include <QtWidgets/QVBoxLayout>
#include <QtWidgets/QWidget>
#include <klocalizedstring.h>

QT_BEGIN_NAMESPACE

class Ui_FovEditorDialog
{
public:
    QVBoxLayout *verticalLayout;
    QSpacerItem *vertSpacer1;
    QHBoxLayout *horLayout1;
    QSpacerItem *horSpacer1;
    QLabel *imageLabel;
    QSpacerItem *horSpacer2;
    QSpacerItem *vertSpacer2;
    QLabel *fovInfoLabel;
    QGridLayout *gridLayout;
    QPushButton *previousButton;
    QPushButton *nextButton;
    QLabel *descriptionLabel;
    QLineEdit *descriptionEdit;
    QHBoxLayout *horLayout2;
    QSpacerItem *horSpacer3;
    QPushButton *recaptureButton;
    QSpacerItem *horSpacer4;
    QPushButton *deleteButton;
    QSpacerItem *horSpacer5;
    QPushButton *saveButton;
    QSpacerItem *horizontalSpacer;

    void setupUi(QWidget *FovEditorDialog)
    {
        if (FovEditorDialog->objectName().isEmpty())
            FovEditorDialog->setObjectName("FovEditorDialog");
        FovEditorDialog->resize(940, 570);
        verticalLayout = new QVBoxLayout(FovEditorDialog);
        verticalLayout->setObjectName("verticalLayout");
        vertSpacer1 = new QSpacerItem(20, 12, QSizePolicy::Policy::Minimum, QSizePolicy::Policy::Minimum);

        verticalLayout->addItem(vertSpacer1);

        horLayout1 = new QHBoxLayout();
        horLayout1->setObjectName("horLayout1");
        horSpacer1 = new QSpacerItem(12, 20, QSizePolicy::Policy::Expanding, QSizePolicy::Policy::Minimum);

        horLayout1->addItem(horSpacer1);

        imageLabel = new QLabel(FovEditorDialog);
        imageLabel->setObjectName("imageLabel");
        QFont font;
        font.setFamilies({QString::fromUtf8("Sans Serif")});
        font.setPointSize(12);
        font.setBold(true);
        imageLabel->setFont(font);

        horLayout1->addWidget(imageLabel);

        horSpacer2 = new QSpacerItem(12, 20, QSizePolicy::Policy::Expanding, QSizePolicy::Policy::Minimum);

        horLayout1->addItem(horSpacer2);


        verticalLayout->addLayout(horLayout1);

        vertSpacer2 = new QSpacerItem(20, 12, QSizePolicy::Policy::Minimum, QSizePolicy::Policy::Minimum);

        verticalLayout->addItem(vertSpacer2);

        fovInfoLabel = new QLabel(FovEditorDialog);
        fovInfoLabel->setObjectName("fovInfoLabel");
        QSizePolicy sizePolicy(QSizePolicy::Policy::Maximum, QSizePolicy::Policy::Maximum);
        sizePolicy.setHorizontalStretch(0);
        sizePolicy.setVerticalStretch(0);
        sizePolicy.setHeightForWidth(fovInfoLabel->sizePolicy().hasHeightForWidth());
        fovInfoLabel->setSizePolicy(sizePolicy);
        QFont font1;
        font1.setBold(true);
        fovInfoLabel->setFont(font1);

        verticalLayout->addWidget(fovInfoLabel);

        gridLayout = new QGridLayout();
        gridLayout->setObjectName("gridLayout");
        previousButton = new QPushButton(FovEditorDialog);
        previousButton->setObjectName("previousButton");

        gridLayout->addWidget(previousButton, 0, 0, 1, 1);

        nextButton = new QPushButton(FovEditorDialog);
        nextButton->setObjectName("nextButton");

        gridLayout->addWidget(nextButton, 0, 3, 1, 1);

        descriptionLabel = new QLabel(FovEditorDialog);
        descriptionLabel->setObjectName("descriptionLabel");

        gridLayout->addWidget(descriptionLabel, 0, 1, 1, 1);

        descriptionEdit = new QLineEdit(FovEditorDialog);
        descriptionEdit->setObjectName("descriptionEdit");

        gridLayout->addWidget(descriptionEdit, 0, 2, 1, 1);

        horLayout2 = new QHBoxLayout();
        horLayout2->setObjectName("horLayout2");
        horSpacer3 = new QSpacerItem(40, 20, QSizePolicy::Policy::Expanding, QSizePolicy::Policy::Minimum);

        horLayout2->addItem(horSpacer3);

        recaptureButton = new QPushButton(FovEditorDialog);
        recaptureButton->setObjectName("recaptureButton");

        horLayout2->addWidget(recaptureButton);

        horSpacer4 = new QSpacerItem(48, 25, QSizePolicy::Policy::Expanding, QSizePolicy::Policy::Minimum);

        horLayout2->addItem(horSpacer4);

        deleteButton = new QPushButton(FovEditorDialog);
        deleteButton->setObjectName("deleteButton");

        horLayout2->addWidget(deleteButton);

        horSpacer5 = new QSpacerItem(40, 20, QSizePolicy::Policy::Expanding, QSizePolicy::Policy::Minimum);

        horLayout2->addItem(horSpacer5);

        saveButton = new QPushButton(FovEditorDialog);
        saveButton->setObjectName("saveButton");

        horLayout2->addWidget(saveButton);

        horizontalSpacer = new QSpacerItem(40, 20, QSizePolicy::Policy::Expanding, QSizePolicy::Policy::Minimum);

        horLayout2->addItem(horizontalSpacer);


        gridLayout->addLayout(horLayout2, 1, 1, 1, 2);


        verticalLayout->addLayout(gridLayout);


        retranslateUi(FovEditorDialog);

        QMetaObject::connectSlotsByName(FovEditorDialog);
    } // setupUi

    void retranslateUi(QWidget *FovEditorDialog)
    {
        imageLabel->setText(QString());
        fovInfoLabel->setText(QString());
        previousButton->setText(tr2i18n("<", nullptr));
        nextButton->setText(tr2i18n(">", nullptr));
        descriptionLabel->setText(tr2i18n("Description:", nullptr));
        recaptureButton->setText(tr2i18n("Capture again...", nullptr));
        deleteButton->setText(tr2i18n("Delete snapshot", nullptr));
        saveButton->setText(tr2i18n("Save to file...", nullptr));
        (void)FovEditorDialog;
    } // retranslateUi

};

namespace Ui {
    class FovEditorDialog: public Ui_FovEditorDialog {};
} // namespace Ui

QT_END_NAMESPACE

#endif // FOVEDITORDIALOG_H

