/****************************************************************************
** Meta object code from reading C++ file 'kstarsdata.h'
**
** Created by: The Qt Meta Object Compiler version 69 (Qt 6.11.1)
**
** WARNING! All changes made in this file will be lost!
*****************************************************************************/

#include "../../../../kstars-3.8.4.1/kstars/kstarsdata.h"
#include <QtCore/qmetatype.h>

#include <QtCore/qtmochelpers.h>

#include <memory>


#include <QtCore/qxptype_traits.h>
#if !defined(Q_MOC_OUTPUT_REVISION)
#error "The header file 'kstarsdata.h' doesn't include <QObject>."
#elif Q_MOC_OUTPUT_REVISION != 69
#error "This file was generated using the moc from 6.11.1. It"
#error "cannot be used with the include files from this version of Qt."
#error "(The moc has changed too much.)"
#endif

#ifndef Q_CONSTINIT
#define Q_CONSTINIT
#endif

QT_WARNING_PUSH
QT_WARNING_DISABLE_DEPRECATED
QT_WARNING_DISABLE_GCC("-Wuseless-cast")
namespace {
struct qt_meta_tag_ZN10KStarsDataE_t {};
} // unnamed namespace

template <> constexpr inline auto KStarsData::qt_create_metaobjectdata<qt_meta_tag_ZN10KStarsDataE_t>()
{
    namespace QMC = QtMocConstants;
    QtMocHelpers::StringRefStorage qt_stringData {
        "KStarsData",
        "progressText",
        "",
        "text",
        "skyUpdate",
        "clearCache",
        "geoChanged",
        "slotConsoleMessage",
        "s",
        "updateTime",
        "GeoLocation*",
        "geo",
        "automaticDSTchange",
        "setTimeDirection",
        "scale",
        "getUserData",
        "name",
        "addToUserData",
        "std::pair<bool,QString>",
        "SkyObjectUserdata::LinkData",
        "data",
        "editUserData",
        "index",
        "deleteUserData",
        "SkyObjectUserdata::Type",
        "type",
        "updateUserLog",
        "newLog",
        "colorSchemeFileName",
        "colorSchemeName",
        "clock",
        "SimClock*"
    };

    QtMocHelpers::UintData qt_methods {
        // Signal 'progressText'
        QtMocHelpers::SignalData<void(const QString &)>(1, 2, QMC::AccessPublic, QMetaType::Void, {{
            { QMetaType::QString, 3 },
        }}),
        // Signal 'skyUpdate'
        QtMocHelpers::SignalData<void(bool)>(4, 2, QMC::AccessPublic, QMetaType::Void, {{
            { QMetaType::Bool, 2 },
        }}),
        // Signal 'clearCache'
        QtMocHelpers::SignalData<void()>(5, 2, QMC::AccessPublic, QMetaType::Void),
        // Signal 'geoChanged'
        QtMocHelpers::SignalData<void()>(6, 2, QMC::AccessPublic, QMetaType::Void),
        // Slot 'slotConsoleMessage'
        QtMocHelpers::SlotData<void(QString)>(7, 2, QMC::AccessPublic, QMetaType::Void, {{
            { QMetaType::QString, 8 },
        }}),
        // Slot 'updateTime'
        QtMocHelpers::SlotData<void(GeoLocation *, const bool)>(9, 2, QMC::AccessPublic, QMetaType::Void, {{
            { 0x80000000 | 10, 11 }, { QMetaType::Bool, 12 },
        }}),
        // Slot 'updateTime'
        QtMocHelpers::SlotData<void(GeoLocation *)>(9, 2, QMC::AccessPublic | QMC::MethodCloned, QMetaType::Void, {{
            { 0x80000000 | 10, 11 },
        }}),
        // Slot 'setTimeDirection'
        QtMocHelpers::SlotData<void(float)>(13, 2, QMC::AccessPublic, QMetaType::Void, {{
            { QMetaType::Float, 14 },
        }}),
        // Slot 'getUserData'
        QtMocHelpers::SlotData<void(const QString &)>(15, 2, QMC::AccessPublic, QMetaType::Void, {{
            { QMetaType::QString, 16 },
        }}),
        // Slot 'addToUserData'
        QtMocHelpers::SlotData<std::pair<bool,QString>(const QString &, const SkyObjectUserdata::LinkData &)>(17, 2, QMC::AccessPublic, 0x80000000 | 18, {{
            { QMetaType::QString, 16 }, { 0x80000000 | 19, 20 },
        }}),
        // Slot 'editUserData'
        QtMocHelpers::SlotData<std::pair<bool,QString>(const QString &, const unsigned int, const SkyObjectUserdata::LinkData &)>(21, 2, QMC::AccessPublic, 0x80000000 | 18, {{
            { QMetaType::QString, 16 }, { QMetaType::UInt, 22 }, { 0x80000000 | 19, 20 },
        }}),
        // Slot 'deleteUserData'
        QtMocHelpers::SlotData<std::pair<bool,QString>(const QString &, const unsigned int, SkyObjectUserdata::Type)>(23, 2, QMC::AccessPublic, 0x80000000 | 18, {{
            { QMetaType::QString, 16 }, { QMetaType::UInt, 22 }, { 0x80000000 | 24, 25 },
        }}),
        // Slot 'updateUserLog'
        QtMocHelpers::SlotData<std::pair<bool,QString>(const QString &, const QString &)>(26, 2, QMC::AccessPublic, 0x80000000 | 18, {{
            { QMetaType::QString, 16 }, { QMetaType::QString, 27 },
        }}),
        // Method 'colorSchemeFileName'
        QtMocHelpers::MethodData<QString()>(28, 2, QMC::AccessPublic, QMetaType::QString),
        // Method 'colorSchemeName'
        QtMocHelpers::MethodData<QString()>(29, 2, QMC::AccessPublic, QMetaType::QString),
        // Method 'clock'
        QtMocHelpers::MethodData<SimClock *()>(30, 2, QMC::AccessPublic, 0x80000000 | 31),
    };
    QtMocHelpers::UintData qt_properties {
    };
    QtMocHelpers::UintData qt_enums {
    };
    return QtMocHelpers::metaObjectData<KStarsData, qt_meta_tag_ZN10KStarsDataE_t>(QMC::MetaObjectFlag{}, qt_stringData,
            qt_methods, qt_properties, qt_enums);
}
Q_CONSTINIT const QMetaObject KStarsData::staticMetaObject = { {
    QMetaObject::SuperData::link<QObject::staticMetaObject>(),
    qt_staticMetaObjectStaticContent<qt_meta_tag_ZN10KStarsDataE_t>.stringdata,
    qt_staticMetaObjectStaticContent<qt_meta_tag_ZN10KStarsDataE_t>.data,
    qt_static_metacall,
    nullptr,
    qt_staticMetaObjectRelocatingContent<qt_meta_tag_ZN10KStarsDataE_t>.metaTypes,
    nullptr
} };

void KStarsData::qt_static_metacall(QObject *_o, QMetaObject::Call _c, int _id, void **_a)
{
    auto *_t = static_cast<KStarsData *>(_o);
    if (_c == QMetaObject::InvokeMetaMethod) {
        switch (_id) {
        case 0: _t->progressText((*reinterpret_cast<std::add_pointer_t<QString>>(_a[1]))); break;
        case 1: _t->skyUpdate((*reinterpret_cast<std::add_pointer_t<bool>>(_a[1]))); break;
        case 2: _t->clearCache(); break;
        case 3: _t->geoChanged(); break;
        case 4: _t->slotConsoleMessage((*reinterpret_cast<std::add_pointer_t<QString>>(_a[1]))); break;
        case 5: _t->updateTime((*reinterpret_cast<std::add_pointer_t<GeoLocation*>>(_a[1])),(*reinterpret_cast<std::add_pointer_t<bool>>(_a[2]))); break;
        case 6: _t->updateTime((*reinterpret_cast<std::add_pointer_t<GeoLocation*>>(_a[1]))); break;
        case 7: _t->setTimeDirection((*reinterpret_cast<std::add_pointer_t<float>>(_a[1]))); break;
        case 8: _t->getUserData((*reinterpret_cast<std::add_pointer_t<QString>>(_a[1]))); break;
        case 9: { std::pair<bool,QString> _r = _t->addToUserData((*reinterpret_cast<std::add_pointer_t<QString>>(_a[1])),(*reinterpret_cast<std::add_pointer_t<SkyObjectUserdata::LinkData>>(_a[2])));
            if (_a[0]) *reinterpret_cast<std::pair<bool,QString>*>(_a[0]) = std::move(_r); }  break;
        case 10: { std::pair<bool,QString> _r = _t->editUserData((*reinterpret_cast<std::add_pointer_t<QString>>(_a[1])),(*reinterpret_cast<std::add_pointer_t<uint>>(_a[2])),(*reinterpret_cast<std::add_pointer_t<SkyObjectUserdata::LinkData>>(_a[3])));
            if (_a[0]) *reinterpret_cast<std::pair<bool,QString>*>(_a[0]) = std::move(_r); }  break;
        case 11: { std::pair<bool,QString> _r = _t->deleteUserData((*reinterpret_cast<std::add_pointer_t<QString>>(_a[1])),(*reinterpret_cast<std::add_pointer_t<uint>>(_a[2])),(*reinterpret_cast<std::add_pointer_t<SkyObjectUserdata::Type>>(_a[3])));
            if (_a[0]) *reinterpret_cast<std::pair<bool,QString>*>(_a[0]) = std::move(_r); }  break;
        case 12: { std::pair<bool,QString> _r = _t->updateUserLog((*reinterpret_cast<std::add_pointer_t<QString>>(_a[1])),(*reinterpret_cast<std::add_pointer_t<QString>>(_a[2])));
            if (_a[0]) *reinterpret_cast<std::pair<bool,QString>*>(_a[0]) = std::move(_r); }  break;
        case 13: { QString _r = _t->colorSchemeFileName();
            if (_a[0]) *reinterpret_cast<QString*>(_a[0]) = std::move(_r); }  break;
        case 14: { QString _r = _t->colorSchemeName();
            if (_a[0]) *reinterpret_cast<QString*>(_a[0]) = std::move(_r); }  break;
        case 15: { SimClock* _r = _t->clock();
            if (_a[0]) *reinterpret_cast<SimClock**>(_a[0]) = std::move(_r); }  break;
        default: ;
        }
    }
    if (_c == QMetaObject::IndexOfMethod) {
        if (QtMocHelpers::indexOfMethod<void (KStarsData::*)(const QString & )>(_a, &KStarsData::progressText, 0))
            return;
        if (QtMocHelpers::indexOfMethod<void (KStarsData::*)(bool )>(_a, &KStarsData::skyUpdate, 1))
            return;
        if (QtMocHelpers::indexOfMethod<void (KStarsData::*)()>(_a, &KStarsData::clearCache, 2))
            return;
        if (QtMocHelpers::indexOfMethod<void (KStarsData::*)()>(_a, &KStarsData::geoChanged, 3))
            return;
    }
}

const QMetaObject *KStarsData::metaObject() const
{
    return QObject::d_ptr->metaObject ? QObject::d_ptr->dynamicMetaObject() : &staticMetaObject;
}

void *KStarsData::qt_metacast(const char *_clname)
{
    if (!_clname) return nullptr;
    if (!strcmp(_clname, qt_staticMetaObjectStaticContent<qt_meta_tag_ZN10KStarsDataE_t>.strings))
        return static_cast<void*>(this);
    return QObject::qt_metacast(_clname);
}

int KStarsData::qt_metacall(QMetaObject::Call _c, int _id, void **_a)
{
    _id = QObject::qt_metacall(_c, _id, _a);
    if (_id < 0)
        return _id;
    if (_c == QMetaObject::InvokeMetaMethod) {
        if (_id < 16)
            qt_static_metacall(this, _c, _id, _a);
        _id -= 16;
    }
    if (_c == QMetaObject::RegisterMethodArgumentMetaType) {
        if (_id < 16)
            *reinterpret_cast<QMetaType *>(_a[0]) = QMetaType();
        _id -= 16;
    }
    return _id;
}

// SIGNAL 0
void KStarsData::progressText(const QString & _t1)
{
    QMetaObject::activate<void>(this, &staticMetaObject, 0, nullptr, _t1);
}

// SIGNAL 1
void KStarsData::skyUpdate(bool _t1)
{
    QMetaObject::activate<void>(this, &staticMetaObject, 1, nullptr, _t1);
}

// SIGNAL 2
void KStarsData::clearCache()
{
    QMetaObject::activate(this, &staticMetaObject, 2, nullptr);
}

// SIGNAL 3
void KStarsData::geoChanged()
{
    QMetaObject::activate(this, &staticMetaObject, 3, nullptr);
}
QT_WARNING_POP
