/****************************************************************************
** Meta object code from reading C++ file 'darklibrary.h'
**
** Created by: The Qt Meta Object Compiler version 69 (Qt 6.11.1)
**
** WARNING! All changes made in this file will be lost!
*****************************************************************************/

#include "../../../../kstars-3.8.4.1/kstars/ekos/auxiliary/darklibrary.h"
#include <QtNetwork/QSslError>
#include <QtDataVisualization/qbar3dseries.h>
#include <QtDataVisualization/q3dscene.h>
#include <QtGui/qtextcursor.h>
#include <QtCore/qmetatype.h>
#include <QtCore/QSharedPointer>

#include <QtCore/qtmochelpers.h>

#include <memory>


#include <QtCore/qxptype_traits.h>
#if !defined(Q_MOC_OUTPUT_REVISION)
#error "The header file 'darklibrary.h' doesn't include <QObject>."
#elif Q_MOC_OUTPUT_REVISION != 69
#error "This file was generated using the moc from 6.11.1. It"
#error "cannot be used with the include files from this version of Qt."
#error "(The moc has changed too much.)"
#endif

#ifndef Q_CONSTINIT
#define Q_CONSTINIT
#endif

QT_WARNING_PUSH
QT_WARNING_DISABLE_DEPRECATED
QT_WARNING_DISABLE_GCC("-Wuseless-cast")
namespace {
struct qt_meta_tag_ZN4Ekos11DarkLibraryE_t {};
} // unnamed namespace

template <> constexpr inline auto Ekos::DarkLibrary::qt_create_metaobjectdata<qt_meta_tag_ZN4Ekos11DarkLibraryE_t>()
{
    namespace QMC = QtMocConstants;
    QtMocHelpers::StringRefStorage qt_stringData {
        "Ekos::DarkLibrary",
        "newLog",
        "",
        "message",
        "newImage",
        "QSharedPointer<FITSData>",
        "data",
        "newFrame",
        "QSharedPointer<FITSView>",
        "view",
        "settingsUpdated",
        "QVariantMap",
        "settings",
        "trainChanged",
        "processNewImage",
        "QSharedPointer<SequenceJob>",
        "job",
        "updateProperty",
        "INDI::Property",
        "prop",
        "loadIndexInView",
        "row",
        "clearRow",
        "clearAll",
        "clearExpired",
        "openDarksFolder",
        "saveDefectMap",
        "setCompleted"
    };

    QtMocHelpers::UintData qt_methods {
        // Signal 'newLog'
        QtMocHelpers::SignalData<void(const QString &)>(1, 2, QMC::AccessPublic, QMetaType::Void, {{
            { QMetaType::QString, 3 },
        }}),
        // Signal 'newImage'
        QtMocHelpers::SignalData<void(const QSharedPointer<FITSData> &)>(4, 2, QMC::AccessPublic, QMetaType::Void, {{
            { 0x80000000 | 5, 6 },
        }}),
        // Signal 'newFrame'
        QtMocHelpers::SignalData<void(const QSharedPointer<FITSView> &)>(7, 2, QMC::AccessPublic, QMetaType::Void, {{
            { 0x80000000 | 8, 9 },
        }}),
        // Signal 'settingsUpdated'
        QtMocHelpers::SignalData<void(const QVariantMap &)>(10, 2, QMC::AccessPublic, QMetaType::Void, {{
            { 0x80000000 | 11, 12 },
        }}),
        // Signal 'trainChanged'
        QtMocHelpers::SignalData<void()>(13, 2, QMC::AccessPublic, QMetaType::Void),
        // Slot 'processNewImage'
        QtMocHelpers::SlotData<void(const QSharedPointer<SequenceJob> &, const QSharedPointer<FITSData> &)>(14, 2, QMC::AccessPublic, QMetaType::Void, {{
            { 0x80000000 | 15, 16 }, { 0x80000000 | 5, 6 },
        }}),
        // Slot 'updateProperty'
        QtMocHelpers::SlotData<void(INDI::Property)>(17, 2, QMC::AccessPublic, QMetaType::Void, {{
            { 0x80000000 | 18, 19 },
        }}),
        // Slot 'loadIndexInView'
        QtMocHelpers::SlotData<void(int)>(20, 2, QMC::AccessPublic, QMetaType::Void, {{
            { QMetaType::Int, 21 },
        }}),
        // Slot 'clearRow'
        QtMocHelpers::SlotData<void(int)>(22, 2, QMC::AccessPublic, QMetaType::Void, {{
            { QMetaType::Int, 21 },
        }}),
        // Slot 'clearRow'
        QtMocHelpers::SlotData<void()>(22, 2, QMC::AccessPublic | QMC::MethodCloned, QMetaType::Void),
        // Slot 'clearAll'
        QtMocHelpers::SlotData<void()>(23, 2, QMC::AccessPrivate, QMetaType::Void),
        // Slot 'clearExpired'
        QtMocHelpers::SlotData<void()>(24, 2, QMC::AccessPrivate, QMetaType::Void),
        // Slot 'openDarksFolder'
        QtMocHelpers::SlotData<void()>(25, 2, QMC::AccessPrivate, QMetaType::Void),
        // Slot 'saveDefectMap'
        QtMocHelpers::SlotData<void()>(26, 2, QMC::AccessPrivate, QMetaType::Void),
        // Slot 'setCompleted'
        QtMocHelpers::SlotData<void()>(27, 2, QMC::AccessPrivate, QMetaType::Void),
    };
    QtMocHelpers::UintData qt_properties {
    };
    QtMocHelpers::UintData qt_enums {
    };
    return QtMocHelpers::metaObjectData<DarkLibrary, qt_meta_tag_ZN4Ekos11DarkLibraryE_t>(QMC::MetaObjectFlag{}, qt_stringData,
            qt_methods, qt_properties, qt_enums);
}
Q_CONSTINIT const QMetaObject Ekos::DarkLibrary::staticMetaObject = { {
    QMetaObject::SuperData::link<QDialog::staticMetaObject>(),
    qt_staticMetaObjectStaticContent<qt_meta_tag_ZN4Ekos11DarkLibraryE_t>.stringdata,
    qt_staticMetaObjectStaticContent<qt_meta_tag_ZN4Ekos11DarkLibraryE_t>.data,
    qt_static_metacall,
    nullptr,
    qt_staticMetaObjectRelocatingContent<qt_meta_tag_ZN4Ekos11DarkLibraryE_t>.metaTypes,
    nullptr
} };

void Ekos::DarkLibrary::qt_static_metacall(QObject *_o, QMetaObject::Call _c, int _id, void **_a)
{
    auto *_t = static_cast<DarkLibrary *>(_o);
    if (_c == QMetaObject::InvokeMetaMethod) {
        switch (_id) {
        case 0: _t->newLog((*reinterpret_cast<std::add_pointer_t<QString>>(_a[1]))); break;
        case 1: _t->newImage((*reinterpret_cast<std::add_pointer_t<QSharedPointer<FITSData>>>(_a[1]))); break;
        case 2: _t->newFrame((*reinterpret_cast<std::add_pointer_t<QSharedPointer<FITSView>>>(_a[1]))); break;
        case 3: _t->settingsUpdated((*reinterpret_cast<std::add_pointer_t<QVariantMap>>(_a[1]))); break;
        case 4: _t->trainChanged(); break;
        case 5: _t->processNewImage((*reinterpret_cast<std::add_pointer_t<QSharedPointer<SequenceJob>>>(_a[1])),(*reinterpret_cast<std::add_pointer_t<QSharedPointer<FITSData>>>(_a[2]))); break;
        case 6: _t->updateProperty((*reinterpret_cast<std::add_pointer_t<INDI::Property>>(_a[1]))); break;
        case 7: _t->loadIndexInView((*reinterpret_cast<std::add_pointer_t<int>>(_a[1]))); break;
        case 8: _t->clearRow((*reinterpret_cast<std::add_pointer_t<int>>(_a[1]))); break;
        case 9: _t->clearRow(); break;
        case 10: _t->clearAll(); break;
        case 11: _t->clearExpired(); break;
        case 12: _t->openDarksFolder(); break;
        case 13: _t->saveDefectMap(); break;
        case 14: _t->setCompleted(); break;
        default: ;
        }
    }
    if (_c == QMetaObject::RegisterMethodArgumentMetaType) {
        switch (_id) {
        default: *reinterpret_cast<QMetaType *>(_a[0]) = QMetaType(); break;
        case 1:
            switch (*reinterpret_cast<int*>(_a[1])) {
            default: *reinterpret_cast<QMetaType *>(_a[0]) = QMetaType(); break;
            case 0:
                *reinterpret_cast<QMetaType *>(_a[0]) = QMetaType::fromType< QSharedPointer<FITSData> >(); break;
            }
            break;
        case 2:
            switch (*reinterpret_cast<int*>(_a[1])) {
            default: *reinterpret_cast<QMetaType *>(_a[0]) = QMetaType(); break;
            case 0:
                *reinterpret_cast<QMetaType *>(_a[0]) = QMetaType::fromType< QSharedPointer<FITSView> >(); break;
            }
            break;
        case 5:
            switch (*reinterpret_cast<int*>(_a[1])) {
            default: *reinterpret_cast<QMetaType *>(_a[0]) = QMetaType(); break;
            case 1:
                *reinterpret_cast<QMetaType *>(_a[0]) = QMetaType::fromType< QSharedPointer<FITSData> >(); break;
            }
            break;
        case 6:
            switch (*reinterpret_cast<int*>(_a[1])) {
            default: *reinterpret_cast<QMetaType *>(_a[0]) = QMetaType(); break;
            case 0:
                *reinterpret_cast<QMetaType *>(_a[0]) = QMetaType::fromType< INDI::Property >(); break;
            }
            break;
        }
    }
    if (_c == QMetaObject::IndexOfMethod) {
        if (QtMocHelpers::indexOfMethod<void (DarkLibrary::*)(const QString & )>(_a, &DarkLibrary::newLog, 0))
            return;
        if (QtMocHelpers::indexOfMethod<void (DarkLibrary::*)(const QSharedPointer<FITSData> & )>(_a, &DarkLibrary::newImage, 1))
            return;
        if (QtMocHelpers::indexOfMethod<void (DarkLibrary::*)(const QSharedPointer<FITSView> & )>(_a, &DarkLibrary::newFrame, 2))
            return;
        if (QtMocHelpers::indexOfMethod<void (DarkLibrary::*)(const QVariantMap & )>(_a, &DarkLibrary::settingsUpdated, 3))
            return;
        if (QtMocHelpers::indexOfMethod<void (DarkLibrary::*)()>(_a, &DarkLibrary::trainChanged, 4))
            return;
    }
}

const QMetaObject *Ekos::DarkLibrary::metaObject() const
{
    return QObject::d_ptr->metaObject ? QObject::d_ptr->dynamicMetaObject() : &staticMetaObject;
}

void *Ekos::DarkLibrary::qt_metacast(const char *_clname)
{
    if (!_clname) return nullptr;
    if (!strcmp(_clname, qt_staticMetaObjectStaticContent<qt_meta_tag_ZN4Ekos11DarkLibraryE_t>.strings))
        return static_cast<void*>(this);
    if (!strcmp(_clname, "Ui::DarkLibrary"))
        return static_cast< Ui::DarkLibrary*>(this);
    return QDialog::qt_metacast(_clname);
}

int Ekos::DarkLibrary::qt_metacall(QMetaObject::Call _c, int _id, void **_a)
{
    _id = QDialog::qt_metacall(_c, _id, _a);
    if (_id < 0)
        return _id;
    if (_c == QMetaObject::InvokeMetaMethod) {
        if (_id < 15)
            qt_static_metacall(this, _c, _id, _a);
        _id -= 15;
    }
    if (_c == QMetaObject::RegisterMethodArgumentMetaType) {
        if (_id < 15)
            qt_static_metacall(this, _c, _id, _a);
        _id -= 15;
    }
    return _id;
}

// SIGNAL 0
void Ekos::DarkLibrary::newLog(const QString & _t1)
{
    QMetaObject::activate<void>(this, &staticMetaObject, 0, nullptr, _t1);
}

// SIGNAL 1
void Ekos::DarkLibrary::newImage(const QSharedPointer<FITSData> & _t1)
{
    QMetaObject::activate<void>(this, &staticMetaObject, 1, nullptr, _t1);
}

// SIGNAL 2
void Ekos::DarkLibrary::newFrame(const QSharedPointer<FITSView> & _t1)
{
    QMetaObject::activate<void>(this, &staticMetaObject, 2, nullptr, _t1);
}

// SIGNAL 3
void Ekos::DarkLibrary::settingsUpdated(const QVariantMap & _t1)
{
    QMetaObject::activate<void>(this, &staticMetaObject, 3, nullptr, _t1);
}

// SIGNAL 4
void Ekos::DarkLibrary::trainChanged()
{
    QMetaObject::activate(this, &staticMetaObject, 4, nullptr);
}
QT_WARNING_POP
