/********************************************************************************
** Form generated from reading UI file 'filtersettings.ui'
**
** Created by: Qt User Interface Compiler version 6.11.1
**
** WARNING! All changes made in this file will be lost when recompiling UI file!
********************************************************************************/

#ifndef UI_FILTERSETTINGS_H
#define UI_FILTERSETTINGS_H

#include <QtCore/QVariant>
#include <QtWidgets/QAbstractButton>
#include <QtWidgets/QApplication>
#include <QtWidgets/QCheckBox>
#include <QtWidgets/QDialog>
#include <QtWidgets/QDialogButtonBox>
#include <QtWidgets/QHBoxLayout>
#include <QtWidgets/QHeaderView>
#include <QtWidgets/QLabel>
#include <QtWidgets/QPushButton>
#include <QtWidgets/QSpacerItem>
#include <QtWidgets/QTableView>
#include <QtWidgets/QVBoxLayout>
#include <klocalizedstring.h>

QT_BEGIN_NAMESPACE

class Ui_FilterSettings
{
public:
    QVBoxLayout *verticalLayout;
    QHBoxLayout *horizontalLayout;
    QLabel *label;
    QLabel *filterNameLabel;
    QSpacerItem *horizontalSpacer;
    QTableView *m_FilterView;
    QHBoxLayout *horizontalLayout_2;
    QLabel *label_2;
    QPushButton *buildOffsetsButton;
    QHBoxLayout *horizontalLayout_3;
    QCheckBox *kcfg_FlatSyncFocus;
    QDialogButtonBox *buttonBox;

    void setupUi(QDialog *FilterSettings)
    {
        if (FilterSettings->objectName().isEmpty())
            FilterSettings->setObjectName("FilterSettings");
        FilterSettings->resize(436, 315);
        QSizePolicy sizePolicy(QSizePolicy::Policy::MinimumExpanding, QSizePolicy::Policy::MinimumExpanding);
        sizePolicy.setHorizontalStretch(0);
        sizePolicy.setVerticalStretch(0);
        sizePolicy.setHeightForWidth(FilterSettings->sizePolicy().hasHeightForWidth());
        FilterSettings->setSizePolicy(sizePolicy);
        verticalLayout = new QVBoxLayout(FilterSettings);
        verticalLayout->setObjectName("verticalLayout");
        horizontalLayout = new QHBoxLayout();
        horizontalLayout->setObjectName("horizontalLayout");
        label = new QLabel(FilterSettings);
        label->setObjectName("label");

        horizontalLayout->addWidget(label);

        filterNameLabel = new QLabel(FilterSettings);
        filterNameLabel->setObjectName("filterNameLabel");
        filterNameLabel->setStyleSheet(QString::fromUtf8("font-weight:bold;"));

        horizontalLayout->addWidget(filterNameLabel);

        horizontalSpacer = new QSpacerItem(40, 20, QSizePolicy::Policy::Expanding, QSizePolicy::Policy::Minimum);

        horizontalLayout->addItem(horizontalSpacer);


        verticalLayout->addLayout(horizontalLayout);

        m_FilterView = new QTableView(FilterSettings);
        m_FilterView->setObjectName("m_FilterView");
        m_FilterView->setSizeAdjustPolicy(QAbstractScrollArea::AdjustToContents);
        m_FilterView->setEditTriggers(QAbstractItemView::DoubleClicked|QAbstractItemView::EditKeyPressed|QAbstractItemView::SelectedClicked);
        m_FilterView->setSelectionMode(QAbstractItemView::SingleSelection);
        m_FilterView->horizontalHeader()->setStretchLastSection(true);
        m_FilterView->verticalHeader()->setStretchLastSection(false);

        verticalLayout->addWidget(m_FilterView);

        horizontalLayout_2 = new QHBoxLayout();
        horizontalLayout_2->setSpacing(3);
        horizontalLayout_2->setObjectName("horizontalLayout_2");
        label_2 = new QLabel(FilterSettings);
        label_2->setObjectName("label_2");
        label_2->setWordWrap(true);

        horizontalLayout_2->addWidget(label_2);

        buildOffsetsButton = new QPushButton(FilterSettings);
        buildOffsetsButton->setObjectName("buildOffsetsButton");
        QSizePolicy sizePolicy1(QSizePolicy::Policy::Preferred, QSizePolicy::Policy::Fixed);
        sizePolicy1.setHorizontalStretch(0);
        sizePolicy1.setVerticalStretch(0);
        sizePolicy1.setHeightForWidth(buildOffsetsButton->sizePolicy().hasHeightForWidth());
        buildOffsetsButton->setSizePolicy(sizePolicy1);

        horizontalLayout_2->addWidget(buildOffsetsButton);

        horizontalLayout_2->setStretch(0, 1);

        verticalLayout->addLayout(horizontalLayout_2);

        horizontalLayout_3 = new QHBoxLayout();
        horizontalLayout_3->setSpacing(3);
        horizontalLayout_3->setObjectName("horizontalLayout_3");
        kcfg_FlatSyncFocus = new QCheckBox(FilterSettings);
        kcfg_FlatSyncFocus->setObjectName("kcfg_FlatSyncFocus");

        horizontalLayout_3->addWidget(kcfg_FlatSyncFocus);

        buttonBox = new QDialogButtonBox(FilterSettings);
        buttonBox->setObjectName("buttonBox");
        buttonBox->setOrientation(Qt::Horizontal);
        buttonBox->setStandardButtons(QDialogButtonBox::Close);

        horizontalLayout_3->addWidget(buttonBox);


        verticalLayout->addLayout(horizontalLayout_3);


        retranslateUi(FilterSettings);
        QObject::connect(buttonBox, &QDialogButtonBox::accepted, FilterSettings, qOverload<>(&QDialog::accept));
        QObject::connect(buttonBox, &QDialogButtonBox::rejected, FilterSettings, qOverload<>(&QDialog::reject));

        QMetaObject::connectSlotsByName(FilterSettings);
    } // setupUi

    void retranslateUi(QDialog *FilterSettings)
    {
        FilterSettings->setWindowTitle(tr2i18n("Filter Settings", nullptr));
        label->setText(tr2i18n("Filter Wheel", nullptr));
        filterNameLabel->setText(QString());
        label_2->setText(tr2i18n("<html><head/><body><p>Set <span style=\" font-style:italic;\">relative</span> filter offsets in steps either directly in the table or use the Build Offsets tool.</p></body></html>", nullptr));
        buildOffsetsButton->setText(tr2i18n("Build Offsets", nullptr));
#if QT_CONFIG(tooltip)
        kcfg_FlatSyncFocus->setToolTip(tr2i18n("<html><head/><body><p>If using a filter wheel and an absolute position focuser, then always remember the focus position of the autofocus process for light frames in each filter. Before a flat frame is captured, the focuser is moved to the same focus point as light frames.</p></body></html>", nullptr));
#endif // QT_CONFIG(tooltip)
        kcfg_FlatSyncFocus->setText(tr2i18n("Capture flats at the same focus as lights", nullptr));
    } // retranslateUi

};

namespace Ui {
    class FilterSettings: public Ui_FilterSettings {};
} // namespace Ui

QT_END_NAMESPACE

#endif // FILTERSETTINGS_H

