/********************************************************************************
** Form generated from reading UI file 'focus.ui'
**
** Created by: Qt User Interface Compiler version 6.11.1
**
** WARNING! All changes made in this file will be lost when recompiling UI file!
********************************************************************************/

#ifndef UI_FOCUS_H
#define UI_FOCUS_H

#include <QtCore/QVariant>
#include <QtGui/QIcon>
#include <QtWidgets/QApplication>
#include <QtWidgets/QCheckBox>
#include <QtWidgets/QComboBox>
#include <QtWidgets/QDoubleSpinBox>
#include <QtWidgets/QGridLayout>
#include <QtWidgets/QGroupBox>
#include <QtWidgets/QHBoxLayout>
#include <QtWidgets/QLabel>
#include <QtWidgets/QLineEdit>
#include <QtWidgets/QPushButton>
#include <QtWidgets/QSpacerItem>
#include <QtWidgets/QSpinBox>
#include <QtWidgets/QSplitter>
#include <QtWidgets/QVBoxLayout>
#include <QtWidgets/QWidget>
#include <klocalizedstring.h>
#include "ekos/focus/exposurewidget.h"
#include "ekos/focus/focushfrvplot.h"

QT_BEGIN_NAMESPACE

class Ui_Focus
{
public:
    QHBoxLayout *horizontalLayout_5;
    QSplitter *focusSplitter;
    QWidget *layoutWidget;
    QVBoxLayout *leftLayout;
    QHBoxLayout *trainLayout;
    QLabel *trainLabel;
    QComboBox *opticalTrainCombo;
    QPushButton *trainB;
    QGroupBox *focuserGroup;
    QGridLayout *gridLayout_3;
    QPushButton *stopFocusB;
    QPushButton *captureB;
    QLabel *label_16;
    QPushButton *startLoopB;
    QLabel *label_22;
    QPushButton *startFocusB;
    QHBoxLayout *focuserPositionBox;
    QLineEdit *absTicksLabel;
    QSpinBox *absTicksSpin;
    QPushButton *startGotoB;
    QPushButton *stopGotoB;
    QPushButton *focusOutB;
    QPushButton *focusInB;
    QGroupBox *ccdGroup;
    QGridLayout *gridLayout_4;
    QHBoxLayout *horizontalLayout_2;
    QComboBox *focusBinning;
    QLabel *gainLabel;
    QDoubleSpinBox *focusGain;
    QLabel *focusExposureLabel;
    QComboBox *defaultFocusTemperatureSource;
    QLabel *focusBinningLabel;
    QHBoxLayout *horizontalLayout_10;
    QComboBox *focusFilter;
    QPushButton *filterManagerB;
    QLabel *temperatureSourceLabel;
    QHBoxLayout *horizontalLayout_3;
    QPushButton *toggleFullScreenB;
    QPushButton *showFITSViewerB;
    QPushButton *liveVideoB;
    QLabel *FilterPosLabel;
    QComboBox *focusISO;
    QHBoxLayout *horizontalLayout;
    ExposureWidget *focusExposure;
    QHBoxLayout *horizontalLayout_11;
    QLabel *label_30;
    QLabel *absoluteTemperatureLabel;
    QLabel *label_31;
    QLabel *deltaTemperatureLabel;
    QLabel *ISOLabel;
    QPushButton *resetFrameB;
    QGroupBox *toolsGroup;
    QHBoxLayout *horizontalLayout_8;
    QPushButton *startAbInsB;
    QPushButton *cfzB;
    QPushButton *advisorB;
    QCheckBox *forceInSeqAF;
    QSpacerItem *verticalSpacer;
    QSplitter *rightLayout;
    QWidget *focusingWidget;
    QWidget *widget_4;
    QVBoxLayout *verticalLayout_4;
    QHBoxLayout *horizontalLayout_9;
    QLabel *label;
    QSpacerItem *horizontalSpacer_2;
    QLabel *starsLabel;
    QLabel *starsOut;
    QLabel *hfrLabel;
    QLabel *HFROut;
    QLabel *fwhmLabel;
    QLabel *FWHMOut;
    QSpacerItem *horizontalSpacer_7;
    QPushButton *relativeProfileB;
    QPushButton *clearDataB;
    FocusHFRVPlot *HFRPlot;
    QSpacerItem *verticalSpacer_6;

    void setupUi(QWidget *Focus)
    {
        if (Focus->objectName().isEmpty())
            Focus->setObjectName("Focus");
        Focus->resize(903, 663);
        QSizePolicy sizePolicy(QSizePolicy::Policy::Preferred, QSizePolicy::Policy::Fixed);
        sizePolicy.setHorizontalStretch(0);
        sizePolicy.setVerticalStretch(0);
        sizePolicy.setHeightForWidth(Focus->sizePolicy().hasHeightForWidth());
        Focus->setSizePolicy(sizePolicy);
        Focus->setLayoutDirection(Qt::LeftToRight);
        horizontalLayout_5 = new QHBoxLayout(Focus);
        horizontalLayout_5->setSpacing(3);
        horizontalLayout_5->setObjectName("horizontalLayout_5");
        horizontalLayout_5->setContentsMargins(3, 3, 3, 3);
        focusSplitter = new QSplitter(Focus);
        focusSplitter->setObjectName("focusSplitter");
        focusSplitter->setOrientation(Qt::Horizontal);
        layoutWidget = new QWidget(focusSplitter);
        layoutWidget->setObjectName("layoutWidget");
        leftLayout = new QVBoxLayout(layoutWidget);
        leftLayout->setSpacing(3);
        leftLayout->setObjectName("leftLayout");
        leftLayout->setSizeConstraint(QLayout::SetDefaultConstraint);
        leftLayout->setContentsMargins(0, 0, 0, 0);
        trainLayout = new QHBoxLayout();
        trainLayout->setSpacing(3);
        trainLayout->setObjectName("trainLayout");
        trainLayout->setSizeConstraint(QLayout::SetFixedSize);
        trainLabel = new QLabel(layoutWidget);
        trainLabel->setObjectName("trainLabel");
        QSizePolicy sizePolicy1(QSizePolicy::Policy::Preferred, QSizePolicy::Policy::Preferred);
        sizePolicy1.setHorizontalStretch(0);
        sizePolicy1.setVerticalStretch(0);
        sizePolicy1.setHeightForWidth(trainLabel->sizePolicy().hasHeightForWidth());
        trainLabel->setSizePolicy(sizePolicy1);

        trainLayout->addWidget(trainLabel);

        opticalTrainCombo = new QComboBox(layoutWidget);
        opticalTrainCombo->setObjectName("opticalTrainCombo");
        QSizePolicy sizePolicy2(QSizePolicy::Policy::MinimumExpanding, QSizePolicy::Policy::Fixed);
        sizePolicy2.setHorizontalStretch(0);
        sizePolicy2.setVerticalStretch(0);
        sizePolicy2.setHeightForWidth(opticalTrainCombo->sizePolicy().hasHeightForWidth());
        opticalTrainCombo->setSizePolicy(sizePolicy2);
        opticalTrainCombo->setMinimumSize(QSize(0, 32));

        trainLayout->addWidget(opticalTrainCombo, 0, Qt::AlignTop);

        trainB = new QPushButton(layoutWidget);
        trainB->setObjectName("trainB");
        QSizePolicy sizePolicy3(QSizePolicy::Policy::Minimum, QSizePolicy::Policy::Fixed);
        sizePolicy3.setHorizontalStretch(0);
        sizePolicy3.setVerticalStretch(0);
        sizePolicy3.setHeightForWidth(trainB->sizePolicy().hasHeightForWidth());
        trainB->setSizePolicy(sizePolicy3);
        trainB->setMinimumSize(QSize(24, 24));
        trainB->setMaximumSize(QSize(16777215, 32));
        QIcon icon;
        QString iconThemeName = QString::fromUtf8("document-edit");
        if (QIcon::hasThemeIcon(iconThemeName)) {
            icon = QIcon::fromTheme(iconThemeName);
        } else {
            icon.addFile(QString::fromUtf8("../../../../../../../../../../Projects2/kstars/kstars/ekos/focus"), QSize(), QIcon::Mode::Normal, QIcon::State::Off);
        }
        trainB->setIcon(icon);
        trainB->setIconSize(QSize(24, 24));

        trainLayout->addWidget(trainB);


        leftLayout->addLayout(trainLayout);

        focuserGroup = new QGroupBox(layoutWidget);
        focuserGroup->setObjectName("focuserGroup");
        sizePolicy.setHeightForWidth(focuserGroup->sizePolicy().hasHeightForWidth());
        focuserGroup->setSizePolicy(sizePolicy);
        gridLayout_3 = new QGridLayout(focuserGroup);
        gridLayout_3->setSpacing(3);
        gridLayout_3->setObjectName("gridLayout_3");
        gridLayout_3->setContentsMargins(3, 3, 3, 3);
        stopFocusB = new QPushButton(focuserGroup);
        stopFocusB->setObjectName("stopFocusB");
        stopFocusB->setEnabled(false);
        QSizePolicy sizePolicy4(QSizePolicy::Policy::Expanding, QSizePolicy::Policy::Fixed);
        sizePolicy4.setHorizontalStretch(0);
        sizePolicy4.setVerticalStretch(0);
        sizePolicy4.setHeightForWidth(stopFocusB->sizePolicy().hasHeightForWidth());
        stopFocusB->setSizePolicy(sizePolicy4);
        stopFocusB->setMinimumSize(QSize(0, 32));

        gridLayout_3->addWidget(stopFocusB, 3, 3, 1, 1);

        captureB = new QPushButton(focuserGroup);
        captureB->setObjectName("captureB");
        captureB->setEnabled(false);
        captureB->setMinimumSize(QSize(24, 24));
        QIcon icon1;
        iconThemeName = QString::fromUtf8("camera-photo");
        if (QIcon::hasThemeIcon(iconThemeName)) {
            icon1 = QIcon::fromTheme(iconThemeName);
        } else {
            icon1.addFile(QString::fromUtf8("../../../../../../../../../../Projects2/kstars/kstars/ekos/focus"), QSize(), QIcon::Mode::Normal, QIcon::State::Off);
        }
        captureB->setIcon(icon1);
        captureB->setIconSize(QSize(24, 24));

        gridLayout_3->addWidget(captureB, 3, 6, 1, 1);

        label_16 = new QLabel(focuserGroup);
        label_16->setObjectName("label_16");

        gridLayout_3->addWidget(label_16, 1, 0, 1, 1);

        startLoopB = new QPushButton(focuserGroup);
        startLoopB->setObjectName("startLoopB");
        startLoopB->setEnabled(false);
        startLoopB->setMinimumSize(QSize(24, 24));
        QIcon icon2;
        iconThemeName = QString::fromUtf8("media-playlist-repeat");
        if (QIcon::hasThemeIcon(iconThemeName)) {
            icon2 = QIcon::fromTheme(iconThemeName);
        } else {
            icon2.addFile(QString::fromUtf8("../../../../../../../../../../Projects2/kstars/kstars/ekos/focus"), QSize(), QIcon::Mode::Normal, QIcon::State::Off);
        }
        startLoopB->setIcon(icon2);
        startLoopB->setIconSize(QSize(24, 24));

        gridLayout_3->addWidget(startLoopB, 3, 5, 1, 1);

        label_22 = new QLabel(focuserGroup);
        label_22->setObjectName("label_22");

        gridLayout_3->addWidget(label_22, 3, 0, 1, 1);

        startFocusB = new QPushButton(focuserGroup);
        startFocusB->setObjectName("startFocusB");
        startFocusB->setEnabled(false);
        sizePolicy4.setHeightForWidth(startFocusB->sizePolicy().hasHeightForWidth());
        startFocusB->setSizePolicy(sizePolicy4);
        startFocusB->setMinimumSize(QSize(0, 32));
        startFocusB->setAutoDefault(true);

        gridLayout_3->addWidget(startFocusB, 3, 1, 1, 1);

        focuserPositionBox = new QHBoxLayout();
        focuserPositionBox->setSpacing(3);
        focuserPositionBox->setObjectName("focuserPositionBox");
        absTicksLabel = new QLineEdit(focuserGroup);
        absTicksLabel->setObjectName("absTicksLabel");
        absTicksLabel->setEnabled(false);
        absTicksLabel->setMinimumSize(QSize(0, 32));
        absTicksLabel->setStyleSheet(QString::fromUtf8("QLineEdit[readOnly=\"true\"] { color: gray }"));
        absTicksLabel->setReadOnly(true);

        focuserPositionBox->addWidget(absTicksLabel);

        absTicksSpin = new QSpinBox(focuserGroup);
        absTicksSpin->setObjectName("absTicksSpin");
        absTicksSpin->setEnabled(false);
        sizePolicy4.setHeightForWidth(absTicksSpin->sizePolicy().hasHeightForWidth());
        absTicksSpin->setSizePolicy(sizePolicy4);
        absTicksSpin->setMinimumSize(QSize(0, 32));

        focuserPositionBox->addWidget(absTicksSpin);

        startGotoB = new QPushButton(focuserGroup);
        startGotoB->setObjectName("startGotoB");
        startGotoB->setEnabled(false);
        startGotoB->setMinimumSize(QSize(24, 24));
        QIcon icon3;
        iconThemeName = QString::fromUtf8("run-build");
        if (QIcon::hasThemeIcon(iconThemeName)) {
            icon3 = QIcon::fromTheme(iconThemeName);
        } else {
            icon3.addFile(QString::fromUtf8("../../../../../../../../../../Projects2/kstars/kstars/ekos/focus"), QSize(), QIcon::Mode::Normal, QIcon::State::Off);
        }
        startGotoB->setIcon(icon3);
        startGotoB->setIconSize(QSize(28, 28));

        focuserPositionBox->addWidget(startGotoB);

        stopGotoB = new QPushButton(focuserGroup);
        stopGotoB->setObjectName("stopGotoB");
        stopGotoB->setEnabled(false);
        stopGotoB->setMinimumSize(QSize(24, 24));
        QIcon icon4;
        iconThemeName = QString::fromUtf8("process-stop");
        if (QIcon::hasThemeIcon(iconThemeName)) {
            icon4 = QIcon::fromTheme(iconThemeName);
        } else {
            icon4.addFile(QString::fromUtf8("../../../../../../../../../../Projects2/kstars/kstars/ekos/focus"), QSize(), QIcon::Mode::Normal, QIcon::State::Off);
        }
        stopGotoB->setIcon(icon4);
        stopGotoB->setIconSize(QSize(28, 28));

        focuserPositionBox->addWidget(stopGotoB);

        focuserPositionBox->setStretch(0, 1);
        focuserPositionBox->setStretch(1, 1);

        gridLayout_3->addLayout(focuserPositionBox, 1, 1, 1, 3);

        focusOutB = new QPushButton(focuserGroup);
        focusOutB->setObjectName("focusOutB");
        focusOutB->setEnabled(false);
        focusOutB->setMinimumSize(QSize(24, 24));
        QIcon icon5;
        iconThemeName = QString::fromUtf8("format-align-vertical-top");
        if (QIcon::hasThemeIcon(iconThemeName)) {
            icon5 = QIcon::fromTheme(iconThemeName);
        } else {
            icon5.addFile(QString::fromUtf8("../../../../../../../../../../Projects2/kstars/kstars/ekos/focus"), QSize(), QIcon::Mode::Normal, QIcon::State::Off);
        }
        focusOutB->setIcon(icon5);
        focusOutB->setIconSize(QSize(24, 24));

        gridLayout_3->addWidget(focusOutB, 1, 6, 1, 1);

        focusInB = new QPushButton(focuserGroup);
        focusInB->setObjectName("focusInB");
        focusInB->setEnabled(false);
        focusInB->setMinimumSize(QSize(24, 24));
        QIcon icon6;
        iconThemeName = QString::fromUtf8("format-align-vertical-bottom");
        if (QIcon::hasThemeIcon(iconThemeName)) {
            icon6 = QIcon::fromTheme(iconThemeName);
        } else {
            icon6.addFile(QString::fromUtf8("../../../../../../../../../../Projects2/kstars/kstars/ekos/focus"), QSize(), QIcon::Mode::Normal, QIcon::State::Off);
        }
        focusInB->setIcon(icon6);
        focusInB->setIconSize(QSize(24, 24));

        gridLayout_3->addWidget(focusInB, 1, 5, 1, 1);


        leftLayout->addWidget(focuserGroup);

        ccdGroup = new QGroupBox(layoutWidget);
        ccdGroup->setObjectName("ccdGroup");
        sizePolicy.setHeightForWidth(ccdGroup->sizePolicy().hasHeightForWidth());
        ccdGroup->setSizePolicy(sizePolicy);
        gridLayout_4 = new QGridLayout(ccdGroup);
        gridLayout_4->setSpacing(3);
        gridLayout_4->setObjectName("gridLayout_4");
        gridLayout_4->setContentsMargins(3, 3, 3, 3);
        horizontalLayout_2 = new QHBoxLayout();
        horizontalLayout_2->setSpacing(1);
        horizontalLayout_2->setObjectName("horizontalLayout_2");
        focusBinning = new QComboBox(ccdGroup);
        focusBinning->setObjectName("focusBinning");
        focusBinning->setEnabled(false);
        focusBinning->setMinimumSize(QSize(0, 32));

        horizontalLayout_2->addWidget(focusBinning);

        gainLabel = new QLabel(ccdGroup);
        gainLabel->setObjectName("gainLabel");

        horizontalLayout_2->addWidget(gainLabel);

        focusGain = new QDoubleSpinBox(ccdGroup);
        focusGain->setObjectName("focusGain");
        focusGain->setMinimumSize(QSize(0, 32));

        horizontalLayout_2->addWidget(focusGain);


        gridLayout_4->addLayout(horizontalLayout_2, 1, 1, 1, 1);

        focusExposureLabel = new QLabel(ccdGroup);
        focusExposureLabel->setObjectName("focusExposureLabel");

        gridLayout_4->addWidget(focusExposureLabel, 0, 0, 1, 1);

        defaultFocusTemperatureSource = new QComboBox(ccdGroup);
        defaultFocusTemperatureSource->setObjectName("defaultFocusTemperatureSource");
        defaultFocusTemperatureSource->setMinimumSize(QSize(0, 32));

        gridLayout_4->addWidget(defaultFocusTemperatureSource, 2, 1, 1, 1);

        focusBinningLabel = new QLabel(ccdGroup);
        focusBinningLabel->setObjectName("focusBinningLabel");

        gridLayout_4->addWidget(focusBinningLabel, 1, 0, 1, 1);

        horizontalLayout_10 = new QHBoxLayout();
        horizontalLayout_10->setSpacing(1);
        horizontalLayout_10->setObjectName("horizontalLayout_10");
        focusFilter = new QComboBox(ccdGroup);
        focusFilter->setObjectName("focusFilter");
        focusFilter->setEnabled(false);
        focusFilter->setMinimumSize(QSize(0, 32));

        horizontalLayout_10->addWidget(focusFilter);

        filterManagerB = new QPushButton(ccdGroup);
        filterManagerB->setObjectName("filterManagerB");
        filterManagerB->setEnabled(false);
        QIcon icon7;
        iconThemeName = QString::fromUtf8("view-filter");
        if (QIcon::hasThemeIcon(iconThemeName)) {
            icon7 = QIcon::fromTheme(iconThemeName);
        } else {
            icon7.addFile(QString::fromUtf8("../../../../../../../../../../Projects2/kstars/kstars/ekos/focus"), QSize(), QIcon::Mode::Normal, QIcon::State::Off);
        }
        filterManagerB->setIcon(icon7);
        filterManagerB->setIconSize(QSize(24, 24));

        horizontalLayout_10->addWidget(filterManagerB);


        gridLayout_4->addLayout(horizontalLayout_10, 2, 3, 1, 1);

        temperatureSourceLabel = new QLabel(ccdGroup);
        temperatureSourceLabel->setObjectName("temperatureSourceLabel");

        gridLayout_4->addWidget(temperatureSourceLabel, 2, 0, 1, 1);

        horizontalLayout_3 = new QHBoxLayout();
        horizontalLayout_3->setSpacing(1);
        horizontalLayout_3->setObjectName("horizontalLayout_3");
        toggleFullScreenB = new QPushButton(ccdGroup);
        toggleFullScreenB->setObjectName("toggleFullScreenB");
        toggleFullScreenB->setMinimumSize(QSize(24, 24));
        toggleFullScreenB->setIconSize(QSize(24, 24));

        horizontalLayout_3->addWidget(toggleFullScreenB);

        showFITSViewerB = new QPushButton(ccdGroup);
        showFITSViewerB->setObjectName("showFITSViewerB");
        showFITSViewerB->setMinimumSize(QSize(24, 24));
        showFITSViewerB->setIconSize(QSize(24, 24));

        horizontalLayout_3->addWidget(showFITSViewerB);

        liveVideoB = new QPushButton(ccdGroup);
        liveVideoB->setObjectName("liveVideoB");
        liveVideoB->setEnabled(false);
        liveVideoB->setMinimumSize(QSize(24, 24));
        QIcon icon8;
        iconThemeName = QString::fromUtf8("camera-off");
        if (QIcon::hasThemeIcon(iconThemeName)) {
            icon8 = QIcon::fromTheme(iconThemeName);
        } else {
            icon8.addFile(QString::fromUtf8("../../../../../../../../../../Projects2/kstars/kstars/ekos/focus"), QSize(), QIcon::Mode::Normal, QIcon::State::Off);
        }
        liveVideoB->setIcon(icon8);
        liveVideoB->setIconSize(QSize(24, 24));
        liveVideoB->setCheckable(true);

        horizontalLayout_3->addWidget(liveVideoB);


        gridLayout_4->addLayout(horizontalLayout_3, 0, 3, 1, 1);

        FilterPosLabel = new QLabel(ccdGroup);
        FilterPosLabel->setObjectName("FilterPosLabel");
        FilterPosLabel->setEnabled(false);

        gridLayout_4->addWidget(FilterPosLabel, 2, 2, 1, 1);

        focusISO = new QComboBox(ccdGroup);
        focusISO->setObjectName("focusISO");
        focusISO->setEnabled(false);
        focusISO->setMinimumSize(QSize(0, 32));

        gridLayout_4->addWidget(focusISO, 1, 3, 1, 1);

        horizontalLayout = new QHBoxLayout();
        horizontalLayout->setSpacing(1);
        horizontalLayout->setObjectName("horizontalLayout");
        focusExposure = new ExposureWidget(ccdGroup);
        focusExposure->setObjectName("focusExposure");
        focusExposure->setMinimumSize(QSize(0, 32));
        focusExposure->setDecimals(5);
        focusExposure->setMinimum(0.000010000000000);
        focusExposure->setMaximum(300.000000000000000);
        focusExposure->setSingleStep(1.000000000000000);
        focusExposure->setStepType(QAbstractSpinBox::DefaultStepType);
        focusExposure->setValue(2.000000000000000);

        horizontalLayout->addWidget(focusExposure);


        gridLayout_4->addLayout(horizontalLayout, 0, 1, 1, 1);

        horizontalLayout_11 = new QHBoxLayout();
        horizontalLayout_11->setSpacing(2);
        horizontalLayout_11->setObjectName("horizontalLayout_11");
        label_30 = new QLabel(ccdGroup);
        label_30->setObjectName("label_30");

        horizontalLayout_11->addWidget(label_30);

        absoluteTemperatureLabel = new QLabel(ccdGroup);
        absoluteTemperatureLabel->setObjectName("absoluteTemperatureLabel");
        QSizePolicy sizePolicy5(QSizePolicy::Policy::MinimumExpanding, QSizePolicy::Policy::Preferred);
        sizePolicy5.setHorizontalStretch(0);
        sizePolicy5.setVerticalStretch(0);
        sizePolicy5.setHeightForWidth(absoluteTemperatureLabel->sizePolicy().hasHeightForWidth());
        absoluteTemperatureLabel->setSizePolicy(sizePolicy5);
        absoluteTemperatureLabel->setFrameShape(QFrame::NoFrame);
        absoluteTemperatureLabel->setAlignment(Qt::AlignLeading|Qt::AlignLeft|Qt::AlignVCenter);

        horizontalLayout_11->addWidget(absoluteTemperatureLabel);

        label_31 = new QLabel(ccdGroup);
        label_31->setObjectName("label_31");
        label_31->setAlignment(Qt::AlignCenter);

        horizontalLayout_11->addWidget(label_31);

        deltaTemperatureLabel = new QLabel(ccdGroup);
        deltaTemperatureLabel->setObjectName("deltaTemperatureLabel");
        sizePolicy5.setHeightForWidth(deltaTemperatureLabel->sizePolicy().hasHeightForWidth());
        deltaTemperatureLabel->setSizePolicy(sizePolicy5);
        deltaTemperatureLabel->setFrameShape(QFrame::NoFrame);
        deltaTemperatureLabel->setAlignment(Qt::AlignLeading|Qt::AlignLeft|Qt::AlignVCenter);

        horizontalLayout_11->addWidget(deltaTemperatureLabel);

        horizontalLayout_11->setStretch(1, 1);
        horizontalLayout_11->setStretch(3, 1);

        gridLayout_4->addLayout(horizontalLayout_11, 3, 1, 1, 1);

        ISOLabel = new QLabel(ccdGroup);
        ISOLabel->setObjectName("ISOLabel");
        ISOLabel->setEnabled(false);

        gridLayout_4->addWidget(ISOLabel, 1, 2, 1, 1);

        resetFrameB = new QPushButton(ccdGroup);
        resetFrameB->setObjectName("resetFrameB");
        resetFrameB->setMinimumSize(QSize(0, 32));
        QIcon icon9;
        iconThemeName = QString::fromUtf8("edit-delete");
        if (QIcon::hasThemeIcon(iconThemeName)) {
            icon9 = QIcon::fromTheme(iconThemeName);
        } else {
            icon9.addFile(QString::fromUtf8("../../../../../../../../../../Projects2/kstars/kstars/ekos/focus"), QSize(), QIcon::Mode::Normal, QIcon::State::Off);
        }
        resetFrameB->setIcon(icon9);

        gridLayout_4->addWidget(resetFrameB, 3, 3, 1, 1);


        leftLayout->addWidget(ccdGroup);

        toolsGroup = new QGroupBox(layoutWidget);
        toolsGroup->setObjectName("toolsGroup");
        sizePolicy.setHeightForWidth(toolsGroup->sizePolicy().hasHeightForWidth());
        toolsGroup->setSizePolicy(sizePolicy);
        horizontalLayout_8 = new QHBoxLayout(toolsGroup);
        horizontalLayout_8->setObjectName("horizontalLayout_8");
        startAbInsB = new QPushButton(toolsGroup);
        startAbInsB->setObjectName("startAbInsB");
        startAbInsB->setEnabled(false);
        startAbInsB->setMinimumSize(QSize(0, 0));

        horizontalLayout_8->addWidget(startAbInsB);

        cfzB = new QPushButton(toolsGroup);
        cfzB->setObjectName("cfzB");

        horizontalLayout_8->addWidget(cfzB);

        advisorB = new QPushButton(toolsGroup);
        advisorB->setObjectName("advisorB");

        horizontalLayout_8->addWidget(advisorB);

        forceInSeqAF = new QCheckBox(toolsGroup);
        forceInSeqAF->setObjectName("forceInSeqAF");

        horizontalLayout_8->addWidget(forceInSeqAF);


        leftLayout->addWidget(toolsGroup);

        verticalSpacer = new QSpacerItem(20, 40, QSizePolicy::Policy::Minimum, QSizePolicy::Policy::Expanding);

        leftLayout->addItem(verticalSpacer);

        focusSplitter->addWidget(layoutWidget);
        rightLayout = new QSplitter(focusSplitter);
        rightLayout->setObjectName("rightLayout");
        QSizePolicy sizePolicy6(QSizePolicy::Policy::Expanding, QSizePolicy::Policy::Expanding);
        sizePolicy6.setHorizontalStretch(0);
        sizePolicy6.setVerticalStretch(0);
        sizePolicy6.setHeightForWidth(rightLayout->sizePolicy().hasHeightForWidth());
        rightLayout->setSizePolicy(sizePolicy6);
        rightLayout->setOrientation(Qt::Vertical);
        focusingWidget = new QWidget(rightLayout);
        focusingWidget->setObjectName("focusingWidget");
        sizePolicy6.setHeightForWidth(focusingWidget->sizePolicy().hasHeightForWidth());
        focusingWidget->setSizePolicy(sizePolicy6);
        focusingWidget->setMinimumSize(QSize(320, 240));
        focusingWidget->setSizeIncrement(QSize(40, 30));
        rightLayout->addWidget(focusingWidget);
        widget_4 = new QWidget(rightLayout);
        widget_4->setObjectName("widget_4");
        sizePolicy6.setHeightForWidth(widget_4->sizePolicy().hasHeightForWidth());
        widget_4->setSizePolicy(sizePolicy6);
        widget_4->setMinimumSize(QSize(0, 200));
        verticalLayout_4 = new QVBoxLayout(widget_4);
        verticalLayout_4->setSpacing(3);
        verticalLayout_4->setObjectName("verticalLayout_4");
        verticalLayout_4->setContentsMargins(3, 3, 3, 3);
        horizontalLayout_9 = new QHBoxLayout();
        horizontalLayout_9->setObjectName("horizontalLayout_9");
        label = new QLabel(widget_4);
        label->setObjectName("label");
        QFont font;
        font.setBold(true);
        label->setFont(font);

        horizontalLayout_9->addWidget(label);

        horizontalSpacer_2 = new QSpacerItem(40, 20, QSizePolicy::Policy::Expanding, QSizePolicy::Policy::Minimum);

        horizontalLayout_9->addItem(horizontalSpacer_2);

        starsLabel = new QLabel(widget_4);
        starsLabel->setObjectName("starsLabel");

        horizontalLayout_9->addWidget(starsLabel);

        starsOut = new QLabel(widget_4);
        starsOut->setObjectName("starsOut");

        horizontalLayout_9->addWidget(starsOut);

        hfrLabel = new QLabel(widget_4);
        hfrLabel->setObjectName("hfrLabel");

        horizontalLayout_9->addWidget(hfrLabel);

        HFROut = new QLabel(widget_4);
        HFROut->setObjectName("HFROut");

        horizontalLayout_9->addWidget(HFROut);

        fwhmLabel = new QLabel(widget_4);
        fwhmLabel->setObjectName("fwhmLabel");

        horizontalLayout_9->addWidget(fwhmLabel);

        FWHMOut = new QLabel(widget_4);
        FWHMOut->setObjectName("FWHMOut");

        horizontalLayout_9->addWidget(FWHMOut);

        horizontalSpacer_7 = new QSpacerItem(40, 20, QSizePolicy::Policy::Expanding, QSizePolicy::Policy::Minimum);

        horizontalLayout_9->addItem(horizontalSpacer_7);

        relativeProfileB = new QPushButton(widget_4);
        relativeProfileB->setObjectName("relativeProfileB");
        sizePolicy3.setHeightForWidth(relativeProfileB->sizePolicy().hasHeightForWidth());
        relativeProfileB->setSizePolicy(sizePolicy3);

        horizontalLayout_9->addWidget(relativeProfileB);

        clearDataB = new QPushButton(widget_4);
        clearDataB->setObjectName("clearDataB");

        horizontalLayout_9->addWidget(clearDataB);


        verticalLayout_4->addLayout(horizontalLayout_9);

        HFRPlot = new FocusHFRVPlot(widget_4);
        HFRPlot->setObjectName("HFRPlot");
        sizePolicy6.setHeightForWidth(HFRPlot->sizePolicy().hasHeightForWidth());
        HFRPlot->setSizePolicy(sizePolicy6);
        HFRPlot->setMinimumSize(QSize(200, 100));

        verticalLayout_4->addWidget(HFRPlot);

        rightLayout->addWidget(widget_4);
        focusSplitter->addWidget(rightLayout);

        horizontalLayout_5->addWidget(focusSplitter);

        verticalSpacer_6 = new QSpacerItem(20, 40, QSizePolicy::Policy::Minimum, QSizePolicy::Policy::Expanding);

        horizontalLayout_5->addItem(verticalSpacer_6);

#if QT_CONFIG(shortcut)
        label_16->setBuddy(absTicksLabel);
        label_22->setBuddy(startFocusB);
        gainLabel->setBuddy(focusGain);
        focusExposureLabel->setBuddy(focusExposure);
        focusBinningLabel->setBuddy(focusBinning);
        temperatureSourceLabel->setBuddy(defaultFocusTemperatureSource);
        FilterPosLabel->setBuddy(focusFilter);
        ISOLabel->setBuddy(focusISO);
#endif // QT_CONFIG(shortcut)
        QWidget::setTabOrder(opticalTrainCombo, trainB);
        QWidget::setTabOrder(trainB, startFocusB);
        QWidget::setTabOrder(startFocusB, stopFocusB);
        QWidget::setTabOrder(stopFocusB, startLoopB);
        QWidget::setTabOrder(startLoopB, captureB);
        QWidget::setTabOrder(captureB, focusExposure);
        QWidget::setTabOrder(focusExposure, toggleFullScreenB);
        QWidget::setTabOrder(toggleFullScreenB, showFITSViewerB);
        QWidget::setTabOrder(showFITSViewerB, liveVideoB);
        QWidget::setTabOrder(liveVideoB, focusBinning);
        QWidget::setTabOrder(focusBinning, focusGain);
        QWidget::setTabOrder(focusGain, focusISO);
        QWidget::setTabOrder(focusISO, defaultFocusTemperatureSource);
        QWidget::setTabOrder(defaultFocusTemperatureSource, focusFilter);
        QWidget::setTabOrder(focusFilter, filterManagerB);
        QWidget::setTabOrder(filterManagerB, resetFrameB);

        retranslateUi(Focus);

        startFocusB->setDefault(true);


        QMetaObject::connectSlotsByName(Focus);
    } // setupUi

    void retranslateUi(QWidget *Focus)
    {
        trainLabel->setText(tr2i18n("Train:", nullptr));
        trainB->setText(QString());
        focuserGroup->setTitle(tr2i18n("Focuser", nullptr));
#if QT_CONFIG(tooltip)
        stopFocusB->setToolTip(tr2i18n("Stop Auto Focus process", nullptr));
#endif // QT_CONFIG(tooltip)
        stopFocusB->setText(tr2i18n("Stop", nullptr));
#if QT_CONFIG(tooltip)
        captureB->setToolTip(tr2i18n("Capture image", nullptr));
#endif // QT_CONFIG(tooltip)
        captureB->setText(QString());
        label_16->setText(tr2i18n("Steps:", nullptr));
#if QT_CONFIG(tooltip)
        startLoopB->setToolTip(tr2i18n("Start framing", nullptr));
#endif // QT_CONFIG(tooltip)
        startLoopB->setText(QString());
        label_22->setText(tr2i18n("Start:", nullptr));
#if QT_CONFIG(tooltip)
        startFocusB->setToolTip(tr2i18n("Start Auto Focus process", nullptr));
#endif // QT_CONFIG(tooltip)
        startFocusB->setText(tr2i18n("Auto Focus", nullptr));
#if QT_CONFIG(tooltip)
        absTicksLabel->setToolTip(tr2i18n("Current absolute focuser position", nullptr));
#endif // QT_CONFIG(tooltip)
#if QT_CONFIG(tooltip)
        absTicksSpin->setToolTip(tr2i18n("Desired absolute focus position", nullptr));
#endif // QT_CONFIG(tooltip)
#if QT_CONFIG(tooltip)
        startGotoB->setToolTip(tr2i18n("Go to an absolute focus position", nullptr));
#endif // QT_CONFIG(tooltip)
        startGotoB->setText(QString());
#if QT_CONFIG(tooltip)
        stopGotoB->setToolTip(tr2i18n("Stop focuser motion", nullptr));
#endif // QT_CONFIG(tooltip)
        stopGotoB->setText(QString());
#if QT_CONFIG(tooltip)
        focusOutB->setToolTip(tr2i18n("<html><head/><body><p>Focus Out. Use shift and ctrl key for motion speed up. The factors are configured in the focuser's mechanical options.</p><p>For SCTs this is usually CW.</p></body></html>", nullptr));
#endif // QT_CONFIG(tooltip)
#if QT_CONFIG(statustip)
        focusOutB->setStatusTip(QString());
#endif // QT_CONFIG(statustip)
        focusOutB->setText(QString());
#if QT_CONFIG(tooltip)
        focusInB->setToolTip(tr2i18n("<html><head/><body><p>Focus In. Use shift and ctrl key for motion speed up. The factors are configured in the focuser's mechanical options.</p><p>For SCTs this is usually CCW.</p></body></html>", nullptr));
#endif // QT_CONFIG(tooltip)
#if QT_CONFIG(statustip)
        focusInB->setStatusTip(QString());
#endif // QT_CONFIG(statustip)
        focusInB->setText(QString());
        ccdGroup->setTitle(tr2i18n("Camera && Filter Wheel", nullptr));
#if QT_CONFIG(tooltip)
        gainLabel->setToolTip(tr2i18n("Exposure time in seconds", nullptr));
#endif // QT_CONFIG(tooltip)
        gainLabel->setText(tr2i18n("Gain:", nullptr));
#if QT_CONFIG(tooltip)
        focusExposureLabel->setToolTip(tr2i18n("Exposure time in seconds", nullptr));
#endif // QT_CONFIG(tooltip)
        focusExposureLabel->setText(tr2i18n("Exp:", nullptr));
#if QT_CONFIG(tooltip)
        defaultFocusTemperatureSource->setToolTip(tr2i18n("Select focuser temperature source", nullptr));
#endif // QT_CONFIG(tooltip)
        focusBinningLabel->setText(tr2i18n("Bin:", nullptr));
#if QT_CONFIG(tooltip)
        filterManagerB->setToolTip(tr2i18n("Filter Settings...", nullptr));
#endif // QT_CONFIG(tooltip)
        filterManagerB->setText(QString());
#if QT_CONFIG(tooltip)
        temperatureSourceLabel->setToolTip(tr2i18n("Focuser temperature source", nullptr));
#endif // QT_CONFIG(tooltip)
        temperatureSourceLabel->setText(tr2i18n("TS.", nullptr));
#if QT_CONFIG(tooltip)
        toggleFullScreenB->setToolTip(tr2i18n("Toggle Full Screen", nullptr));
#endif // QT_CONFIG(tooltip)
        toggleFullScreenB->setText(QString());
#if QT_CONFIG(tooltip)
        showFITSViewerB->setToolTip(tr2i18n("Show in FITS Viewer...", nullptr));
#endif // QT_CONFIG(tooltip)
        showFITSViewerB->setText(QString());
#if QT_CONFIG(tooltip)
        liveVideoB->setToolTip(tr2i18n("Live Video...", nullptr));
#endif // QT_CONFIG(tooltip)
        liveVideoB->setText(QString());
#if QT_CONFIG(tooltip)
        FilterPosLabel->setToolTip(tr2i18n("Number of images to capture", nullptr));
#endif // QT_CONFIG(tooltip)
#if QT_CONFIG(whatsthis)
        FilterPosLabel->setWhatsThis(QString());
#endif // QT_CONFIG(whatsthis)
        FilterPosLabel->setText(tr2i18n("Filter:", nullptr));
#if QT_CONFIG(tooltip)
        label_30->setToolTip(tr2i18n("Source temperature in Celsius", nullptr));
#endif // QT_CONFIG(tooltip)
        label_30->setText(tr2i18n("Temp. =", nullptr));
#if QT_CONFIG(tooltip)
        absoluteTemperatureLabel->setToolTip(tr2i18n("Source temperature in Celsius", nullptr));
#endif // QT_CONFIG(tooltip)
        absoluteTemperatureLabel->setText(tr2i18n("NA", nullptr));
#if QT_CONFIG(tooltip)
        label_31->setToolTip(tr2i18n("Delta temperature in Celsius. It is the difference between the last recorded temperature when autofocus was successful and the current source temperature.", nullptr));
#endif // QT_CONFIG(tooltip)
        label_31->setText(tr2i18n("\316\224T =", nullptr));
#if QT_CONFIG(tooltip)
        deltaTemperatureLabel->setToolTip(tr2i18n("Delta temperature in Celsius. It is the difference between the last recorded temperature when autofocus was successful and the current source temperature.", nullptr));
#endif // QT_CONFIG(tooltip)
        deltaTemperatureLabel->setText(tr2i18n("NA", nullptr));
        ISOLabel->setText(tr2i18n("ISO:", nullptr));
#if QT_CONFIG(tooltip)
        resetFrameB->setToolTip(tr2i18n("Reset focus subframe to full capture", nullptr));
#endif // QT_CONFIG(tooltip)
        resetFrameB->setText(tr2i18n("Reset", nullptr));
        toolsGroup->setTitle(tr2i18n("Tools", nullptr));
#if QT_CONFIG(tooltip)
        startAbInsB->setToolTip(tr2i18n("<html><head/><body><p>Run Aberration Inspector (Auto Focus will run first to collect data).</p><p>Note: Mosaic Mask must be set to activate this button.</p><p>This is an experimental feature.</p></body></html>", nullptr));
#endif // QT_CONFIG(tooltip)
        startAbInsB->setText(tr2i18n("Aberration Inspector", nullptr));
        cfzB->setText(tr2i18n("CFZ", nullptr));
        advisorB->setText(tr2i18n("Advisor", nullptr));
#if QT_CONFIG(tooltip)
        forceInSeqAF->setToolTip(tr2i18n("<html><head/><body><p>Check to force an ad-hoc In-Sequence Autofocus at the completion of the current subframe.</p></body></html>", nullptr));
#endif // QT_CONFIG(tooltip)
        forceInSeqAF->setText(tr2i18n("Force AF", nullptr));
        label->setText(tr2i18n("V-Curve", nullptr));
        starsLabel->setText(tr2i18n("Stars:", nullptr));
        starsOut->setText(tr2i18n("--", nullptr));
        hfrLabel->setText(tr2i18n("HFR:", nullptr));
        HFROut->setText(tr2i18n("--", nullptr));
        fwhmLabel->setText(tr2i18n("FWHM:", nullptr));
        FWHMOut->setText(tr2i18n("--", nullptr));
        relativeProfileB->setText(tr2i18n("Profile...", nullptr));
        clearDataB->setText(tr2i18n("Clear", nullptr));
        (void)Focus;
    } // retranslateUi

};

namespace Ui {
    class Focus: public Ui_Focus {};
} // namespace Ui

QT_END_NAMESPACE

#endif // FOCUS_H

