/********************************************************************************
** Form generated from reading UI file 'rotatorsettings.ui'
**
** Created by: Qt User Interface Compiler version 6.11.1
**
** WARNING! All changes made in this file will be lost when recompiling UI file!
********************************************************************************/

#ifndef UI_ROTATORSETTINGS_H
#define UI_ROTATORSETTINGS_H

#include <QtCore/QVariant>
#include <QtWidgets/QApplication>
#include <QtWidgets/QCheckBox>
#include <QtWidgets/QComboBox>
#include <QtWidgets/QDialog>
#include <QtWidgets/QDoubleSpinBox>
#include <QtWidgets/QFrame>
#include <QtWidgets/QGridLayout>
#include <QtWidgets/QGroupBox>
#include <QtWidgets/QHBoxLayout>
#include <QtWidgets/QLabel>
#include <QtWidgets/QLineEdit>
#include <QtWidgets/QPushButton>
#include <QtWidgets/QSlider>
#include <QtWidgets/QVBoxLayout>
#include <klocalizedstring.h>
#include "QRoundProgressBar.h"
#include "auxiliary/qcustomplot.h"

QT_BEGIN_NAMESPACE

class Ui_RotatorDialog
{
public:
    QVBoxLayout *verticalLayout_4;
    QFrame *Display;
    QHBoxLayout *horizontalLayout_4;
    QGridLayout *gridLayout_6;
    QLabel *label_5;
    QRoundProgressBar *paGauge;
    QRoundProgressBar *rotatorGauge;
    QLineEdit *CurrentRotatorAngle;
    QCustomPlot *paRuler;
    QFrame *Parameter;
    QGridLayout *gridLayout_5;
    QComboBox *FlipPolicy;
    QLabel *label;
    QComboBox *MountPierside;
    QDoubleSpinBox *CameraOffset;
    QLabel *RotatorName;
    QLabel *label_6;
    QDoubleSpinBox *RotatorAngle;
    QLabel *label_2;
    QLabel *label_4;
    QFrame *PAControl;
    QGridLayout *gridLayout_2;
    QLabel *label_3;
    QDoubleSpinBox *CameraPA;
    QSlider *CameraPASlider;
    QGroupBox *Options;
    QHBoxLayout *horizontalLayout;
    QCheckBox *reverseDirection;
    QPushButton *AlignOptions;

    void setupUi(QDialog *RotatorDialog)
    {
        if (RotatorDialog->objectName().isEmpty())
            RotatorDialog->setObjectName("RotatorDialog");
        RotatorDialog->resize(500, 450);
        RotatorDialog->setMinimumSize(QSize(500, 450));
        RotatorDialog->setAutoFillBackground(false);
        verticalLayout_4 = new QVBoxLayout(RotatorDialog);
        verticalLayout_4->setSpacing(3);
        verticalLayout_4->setObjectName("verticalLayout_4");
        verticalLayout_4->setContentsMargins(3, 3, 3, 3);
        Display = new QFrame(RotatorDialog);
        Display->setObjectName("Display");
        Display->setMaximumSize(QSize(16777215, 240));
        horizontalLayout_4 = new QHBoxLayout(Display);
        horizontalLayout_4->setSpacing(3);
        horizontalLayout_4->setObjectName("horizontalLayout_4");
        gridLayout_6 = new QGridLayout();
        gridLayout_6->setSpacing(3);
        gridLayout_6->setObjectName("gridLayout_6");
        label_5 = new QLabel(Display);
        label_5->setObjectName("label_5");
        label_5->setMaximumSize(QSize(20, 20));

        gridLayout_6->addWidget(label_5, 0, 0, 1, 1, Qt::AlignHCenter);

        paGauge = new QRoundProgressBar(Display);
        paGauge->setObjectName("paGauge");
        paGauge->setEnabled(false);
        paGauge->setMinimumSize(QSize(200, 200));
        paGauge->setMaximumSize(QSize(200, 200));
        paGauge->setBaseSize(QSize(200, 0));
        paGauge->setStyleSheet(QString::fromUtf8("selection-background-color: rgb(150, 120, 0);"));
        rotatorGauge = new QRoundProgressBar(paGauge);
        rotatorGauge->setObjectName("rotatorGauge");
        rotatorGauge->setEnabled(false);
        rotatorGauge->setGeometry(QRect(25, 25, 150, 150));
        rotatorGauge->setMinimumSize(QSize(150, 150));
        rotatorGauge->setMaximumSize(QSize(150, 150));
        rotatorGauge->setBaseSize(QSize(200, 0));
        rotatorGauge->setStyleSheet(QString::fromUtf8("selection-background-color: rgb(46, 52, 54);"));
        CurrentRotatorAngle = new QLineEdit(rotatorGauge);
        CurrentRotatorAngle->setObjectName("CurrentRotatorAngle");
        CurrentRotatorAngle->setGeometry(QRect(30, 60, 90, 30));
        CurrentRotatorAngle->setMaximumSize(QSize(90, 30));
        QFont font;
        font.setPointSize(20);
        CurrentRotatorAngle->setFont(font);
        CurrentRotatorAngle->setFrame(false);
        CurrentRotatorAngle->setAlignment(Qt::AlignCenter);
        paRuler = new QCustomPlot(paGauge);
        paRuler->setObjectName("paRuler");
        paRuler->setGeometry(QRect(-4, -4, 208, 208));

        gridLayout_6->addWidget(paGauge, 1, 0, 1, 1);


        horizontalLayout_4->addLayout(gridLayout_6);

        Parameter = new QFrame(Display);
        Parameter->setObjectName("Parameter");
        Parameter->setMinimumSize(QSize(30, 0));
        gridLayout_5 = new QGridLayout(Parameter);
        gridLayout_5->setSpacing(3);
        gridLayout_5->setObjectName("gridLayout_5");
        gridLayout_5->setContentsMargins(3, 3, 3, 3);
        FlipPolicy = new QComboBox(Parameter);
        FlipPolicy->addItem(QString());
        FlipPolicy->addItem(QString());
        FlipPolicy->setObjectName("FlipPolicy");

        gridLayout_5->addWidget(FlipPolicy, 5, 1, 1, 2);

        label = new QLabel(Parameter);
        label->setObjectName("label");
        QFont font1;
        font1.setPointSize(13);
        label->setFont(font1);

        gridLayout_5->addWidget(label, 3, 0, 1, 2);

        MountPierside = new QComboBox(Parameter);
        MountPierside->addItem(QString());
        MountPierside->addItem(QString());
        MountPierside->setObjectName("MountPierside");
        MountPierside->setMinimumSize(QSize(75, 0));
        MountPierside->setMaximumSize(QSize(75, 16777215));
        MountPierside->setFont(font1);

        gridLayout_5->addWidget(MountPierside, 3, 2, 1, 1, Qt::AlignRight);

        CameraOffset = new QDoubleSpinBox(Parameter);
        CameraOffset->setObjectName("CameraOffset");
        CameraOffset->setEnabled(false);
        CameraOffset->setMinimumSize(QSize(75, 0));
        CameraOffset->setMaximumSize(QSize(75, 16777215));
        CameraOffset->setDecimals(2);
        CameraOffset->setMinimum(-360.000000000000000);
        CameraOffset->setMaximum(360.000000000000000);
        CameraOffset->setSingleStep(10.000000000000000);

        gridLayout_5->addWidget(CameraOffset, 2, 2, 1, 1, Qt::AlignRight);

        RotatorName = new QLabel(Parameter);
        RotatorName->setObjectName("RotatorName");
        RotatorName->setMaximumSize(QSize(16777215, 22));
        RotatorName->setFrameShape(QFrame::Box);
        RotatorName->setAlignment(Qt::AlignCenter);

        gridLayout_5->addWidget(RotatorName, 0, 0, 1, 3);

        label_6 = new QLabel(Parameter);
        label_6->setObjectName("label_6");
        label_6->setMaximumSize(QSize(16777215, 24));

        gridLayout_5->addWidget(label_6, 5, 0, 1, 1);

        RotatorAngle = new QDoubleSpinBox(Parameter);
        RotatorAngle->setObjectName("RotatorAngle");
        RotatorAngle->setEnabled(false);
        RotatorAngle->setMinimumSize(QSize(75, 0));
        RotatorAngle->setMaximumSize(QSize(75, 16777215));
        RotatorAngle->setStyleSheet(QString::fromUtf8(""));
        RotatorAngle->setDecimals(2);
        RotatorAngle->setMaximum(360.000000000000000);
        RotatorAngle->setSingleStep(1.000000000000000);

        gridLayout_5->addWidget(RotatorAngle, 1, 2, 1, 1, Qt::AlignRight);

        label_2 = new QLabel(Parameter);
        label_2->setObjectName("label_2");
        label_2->setFont(font1);

        gridLayout_5->addWidget(label_2, 1, 0, 1, 2);

        label_4 = new QLabel(Parameter);
        label_4->setObjectName("label_4");
        label_4->setFont(font1);

        gridLayout_5->addWidget(label_4, 2, 0, 1, 2);


        horizontalLayout_4->addWidget(Parameter);


        verticalLayout_4->addWidget(Display);

        PAControl = new QFrame(RotatorDialog);
        PAControl->setObjectName("PAControl");
        PAControl->setMaximumSize(QSize(16777215, 100));
        PAControl->setFrameShape(QFrame::StyledPanel);
        PAControl->setFrameShadow(QFrame::Raised);
        gridLayout_2 = new QGridLayout(PAControl);
        gridLayout_2->setSpacing(3);
        gridLayout_2->setObjectName("gridLayout_2");
        gridLayout_2->setContentsMargins(3, 3, 3, 3);
        label_3 = new QLabel(PAControl);
        label_3->setObjectName("label_3");
        label_3->setMaximumSize(QSize(16777215, 20));

        gridLayout_2->addWidget(label_3, 0, 0, 1, 1);

        CameraPA = new QDoubleSpinBox(PAControl);
        CameraPA->setObjectName("CameraPA");
        CameraPA->setMinimumSize(QSize(80, 0));
        CameraPA->setMaximumSize(QSize(70, 16777215));
        CameraPA->setStyleSheet(QString::fromUtf8("color: rgb(150, 120, 0);"));
        CameraPA->setKeyboardTracking(true);
        CameraPA->setDecimals(2);
        CameraPA->setMinimum(-179.990000000000009);
        CameraPA->setMaximum(180.000000000000000);
        CameraPA->setSingleStep(1.000000000000000);
        CameraPA->setStepType(QAbstractSpinBox::AdaptiveDecimalStepType);

        gridLayout_2->addWidget(CameraPA, 0, 1, 1, 1);

        CameraPASlider = new QSlider(PAControl);
        CameraPASlider->setObjectName("CameraPASlider");
        CameraPASlider->setMinimumSize(QSize(140, 0));
        CameraPASlider->setMinimum(-17999);
        CameraPASlider->setMaximum(18000);
        CameraPASlider->setSingleStep(100);
        CameraPASlider->setPageStep(1000);
        CameraPASlider->setOrientation(Qt::Horizontal);

        gridLayout_2->addWidget(CameraPASlider, 1, 0, 1, 2);


        verticalLayout_4->addWidget(PAControl);

        Options = new QGroupBox(RotatorDialog);
        Options->setObjectName("Options");
        QSizePolicy sizePolicy(QSizePolicy::Policy::Preferred, QSizePolicy::Policy::Fixed);
        sizePolicy.setHorizontalStretch(0);
        sizePolicy.setVerticalStretch(0);
        sizePolicy.setHeightForWidth(Options->sizePolicy().hasHeightForWidth());
        Options->setSizePolicy(sizePolicy);
        horizontalLayout = new QHBoxLayout(Options);
        horizontalLayout->setSpacing(3);
        horizontalLayout->setObjectName("horizontalLayout");
        horizontalLayout->setContentsMargins(3, 3, 3, 3);
        reverseDirection = new QCheckBox(Options);
        reverseDirection->setObjectName("reverseDirection");

        horizontalLayout->addWidget(reverseDirection);

        AlignOptions = new QPushButton(Options);
        AlignOptions->setObjectName("AlignOptions");
        AlignOptions->setMaximumSize(QSize(100, 16777215));
        AlignOptions->setAutoDefault(false);

        horizontalLayout->addWidget(AlignOptions);


        verticalLayout_4->addWidget(Options);


        retranslateUi(RotatorDialog);

        QMetaObject::connectSlotsByName(RotatorDialog);
    } // setupUi

    void retranslateUi(QDialog *RotatorDialog)
    {
        RotatorDialog->setWindowTitle(tr2i18n("Rotator Control", nullptr));
        label_5->setText(tr2i18n("N", nullptr));
#if QT_CONFIG(tooltip)
        paGauge->setToolTip(tr2i18n("<html><head/><body><p>The rotator gauge displays the actual camera position angle (yellow) and the raw rotator angle (gray). Calibrate the rotator by plate solving in the Align module.</p></body></html>", nullptr));
#endif // QT_CONFIG(tooltip)
#if QT_CONFIG(tooltip)
        rotatorGauge->setToolTip(tr2i18n("<html><head/><body><p>The rotator gauge displays the actual camera position angle (yellow) and the raw rotator angle (gray). To calibrate the rotator, capture and solve an image in the Align module.</p></body></html>", nullptr));
#endif // QT_CONFIG(tooltip)
#if QT_CONFIG(tooltip)
        CurrentRotatorAngle->setToolTip(QString());
#endif // QT_CONFIG(tooltip)
#if QT_CONFIG(tooltip)
        Parameter->setToolTip(QString());
#endif // QT_CONFIG(tooltip)
        FlipPolicy->setItemText(0, tr2i18n("Preserve Rotator Angle", nullptr));
        FlipPolicy->setItemText(1, tr2i18n("Preserve Position Angle", nullptr));

#if QT_CONFIG(tooltip)
        label->setToolTip(tr2i18n("<html><head/><body><p>The current pierside of the mount. A red frame indicates an unknown pierside. This is normal if the mount is parked. </p></body></html>", nullptr));
#endif // QT_CONFIG(tooltip)
        label->setText(tr2i18n("Current Pierside", nullptr));
        MountPierside->setItemText(0, tr2i18n("West", nullptr));
        MountPierside->setItemText(1, tr2i18n("East", nullptr));

#if QT_CONFIG(tooltip)
        MountPierside->setToolTip(tr2i18n("<html><head/><body><p>Current pierside of the mount</p></body></html>", nullptr));
#endif // QT_CONFIG(tooltip)
#if QT_CONFIG(tooltip)
        CameraOffset->setToolTip(tr2i18n("<html><head/><body><p>Camera offset angle</p></body></html>", nullptr));
#endif // QT_CONFIG(tooltip)
        RotatorName->setText(QString());
#if QT_CONFIG(tooltip)
        label_6->setToolTip(tr2i18n("<html><head/><body><p><span style=\" font-weight:600;\">Flip Policy</span> determines how the rotator reacts after a flip or if the result of a solved reference image reports a different pierside respective to the actual mount pierside.</p><p>Flip Policy can be altered in <span style=\" font-weight:600;\">Align Options</span><span style=\" font-size:12pt;\"> under &quot;Rotator Settings&quot;.</span></p></body></html>", nullptr));
#endif // QT_CONFIG(tooltip)
        label_6->setText(tr2i18n("Flip Policy", nullptr));
#if QT_CONFIG(tooltip)
        RotatorAngle->setToolTip(tr2i18n("<html><head/><body><p>Raw rotator Angle</p></body></html>", nullptr));
#endif // QT_CONFIG(tooltip)
#if QT_CONFIG(tooltip)
        label_2->setToolTip(tr2i18n("<html><head/><body><p>The raw rotator full circle angle of the rotator device, which is calculated as the difference of the rotator origin (zero angle) respective to North on pierside WEST or respective to South on pierside EAST.</p></body></html>", nullptr));
#endif // QT_CONFIG(tooltip)
        label_2->setText(tr2i18n("Rotator Angle", nullptr));
#if QT_CONFIG(tooltip)
        label_4->setToolTip(tr2i18n("<html><head/><body><p>The angle of the camera upright direction (see FOV) respective to the rotator origin direction. The camera offset is determined automatically by a <span style=\" font-weight:700;\">Capture &amp; Solve</span> or a <span style=\" font-weight:700;\">Load &amp; Slew</span> in the Align module. </p><p>The camera offset is measured in position angle scope (-179.99\302\260 to 180.00\302\260).</p></body></html>", nullptr));
#endif // QT_CONFIG(tooltip)
        label_4->setText(tr2i18n("Camera Offset", nullptr));
#if QT_CONFIG(tooltip)
        label_3->setToolTip(tr2i18n("<html><head/><body><p>Setting the camera position angle shall move the rotator. The gauge reflects the state of the rotator. Depending on the accuracy of the rotator there can be some deviation in the ending position angle.</p><p>The position angle is measured East of North in degrees.</p></body></html>", nullptr));
#endif // QT_CONFIG(tooltip)
        label_3->setText(tr2i18n("Camera Position Angle", nullptr));
#if QT_CONFIG(tooltip)
        CameraPA->setToolTip(tr2i18n("<html><head/><body><p>Current Camera Position Angle</p></body></html>", nullptr));
#endif // QT_CONFIG(tooltip)
#if QT_CONFIG(tooltip)
        CameraPASlider->setToolTip(QString());
#endif // QT_CONFIG(tooltip)
        Options->setTitle(tr2i18n("Options", nullptr));
        reverseDirection->setText(tr2i18n("Reverse Direction of Rotator", nullptr));
        AlignOptions->setText(tr2i18n("Align Options", nullptr));
    } // retranslateUi

};

namespace Ui {
    class RotatorDialog: public Ui_RotatorDialog {};
} // namespace Ui

QT_END_NAMESPACE

#endif // ROTATORSETTINGS_H

