/****************************************************************************
** Meta object code from reading C++ file 'yaxistool.h'
**
** Created by: The Qt Meta Object Compiler version 69 (Qt 6.11.1)
**
** WARNING! All changes made in this file will be lost!
*****************************************************************************/

#include "../../../../kstars-3.8.4.1/kstars/ekos/analyze/yaxistool.h"
#include <QtGui/qtextcursor.h>
#include <QtGui/qscreen.h>
#include <QtCore/qmetatype.h>

#include <QtCore/qtmochelpers.h>

#include <memory>


#include <QtCore/qxptype_traits.h>
#if !defined(Q_MOC_OUTPUT_REVISION)
#error "The header file 'yaxistool.h' doesn't include <QObject>."
#elif Q_MOC_OUTPUT_REVISION != 69
#error "This file was generated using the moc from 6.11.1. It"
#error "cannot be used with the include files from this version of Qt."
#error "(The moc has changed too much.)"
#endif

#ifndef Q_CONSTINIT
#define Q_CONSTINIT
#endif

QT_WARNING_PUSH
QT_WARNING_DISABLE_DEPRECATED
QT_WARNING_DISABLE_GCC("-Wuseless-cast")
namespace {
struct qt_meta_tag_ZN11YAxisToolUIE_t {};
} // unnamed namespace

template <> constexpr inline auto YAxisToolUI::qt_create_metaobjectdata<qt_meta_tag_ZN11YAxisToolUIE_t>()
{
    namespace QMC = QtMocConstants;
    QtMocHelpers::StringRefStorage qt_stringData {
        "YAxisToolUI"
    };

    QtMocHelpers::UintData qt_methods {
    };
    QtMocHelpers::UintData qt_properties {
    };
    QtMocHelpers::UintData qt_enums {
    };
    return QtMocHelpers::metaObjectData<YAxisToolUI, qt_meta_tag_ZN11YAxisToolUIE_t>(QMC::MetaObjectFlag{}, qt_stringData,
            qt_methods, qt_properties, qt_enums);
}
Q_CONSTINIT const QMetaObject YAxisToolUI::staticMetaObject = { {
    QMetaObject::SuperData::link<QFrame::staticMetaObject>(),
    qt_staticMetaObjectStaticContent<qt_meta_tag_ZN11YAxisToolUIE_t>.stringdata,
    qt_staticMetaObjectStaticContent<qt_meta_tag_ZN11YAxisToolUIE_t>.data,
    qt_static_metacall,
    nullptr,
    qt_staticMetaObjectRelocatingContent<qt_meta_tag_ZN11YAxisToolUIE_t>.metaTypes,
    nullptr
} };

void YAxisToolUI::qt_static_metacall(QObject *_o, QMetaObject::Call _c, int _id, void **_a)
{
    auto *_t = static_cast<YAxisToolUI *>(_o);
    (void)_t;
    (void)_c;
    (void)_id;
    (void)_a;
}

const QMetaObject *YAxisToolUI::metaObject() const
{
    return QObject::d_ptr->metaObject ? QObject::d_ptr->dynamicMetaObject() : &staticMetaObject;
}

void *YAxisToolUI::qt_metacast(const char *_clname)
{
    if (!_clname) return nullptr;
    if (!strcmp(_clname, qt_staticMetaObjectStaticContent<qt_meta_tag_ZN11YAxisToolUIE_t>.strings))
        return static_cast<void*>(this);
    if (!strcmp(_clname, "Ui::YAxisTool"))
        return static_cast< Ui::YAxisTool*>(this);
    return QFrame::qt_metacast(_clname);
}

int YAxisToolUI::qt_metacall(QMetaObject::Call _c, int _id, void **_a)
{
    _id = QFrame::qt_metacall(_c, _id, _a);
    return _id;
}
namespace {
struct qt_meta_tag_ZN9YAxisToolE_t {};
} // unnamed namespace

template <> constexpr inline auto YAxisTool::qt_create_metaobjectdata<qt_meta_tag_ZN9YAxisToolE_t>()
{
    namespace QMC = QtMocConstants;
    QtMocHelpers::StringRefStorage qt_stringData {
        "YAxisTool",
        "axisChanged",
        "",
        "key",
        "YAxisInfo",
        "info",
        "axisColorChanged",
        "QColor",
        "color",
        "leftAxisChanged",
        "QCPAxis*",
        "axis",
        "updateValues",
        "value",
        "slotClosed",
        "slotSaveChanges"
    };

    QtMocHelpers::UintData qt_methods {
        // Signal 'axisChanged'
        QtMocHelpers::SignalData<void(QObject *, const YAxisInfo &)>(1, 2, QMC::AccessPublic, QMetaType::Void, {{
            { QMetaType::QObjectStar, 3 }, { 0x80000000 | 4, 5 },
        }}),
        // Signal 'axisColorChanged'
        QtMocHelpers::SignalData<void(QObject *, const YAxisInfo &, const QColor &)>(6, 2, QMC::AccessPublic, QMetaType::Void, {{
            { QMetaType::QObjectStar, 3 }, { 0x80000000 | 4, 5 }, { 0x80000000 | 7, 8 },
        }}),
        // Signal 'leftAxisChanged'
        QtMocHelpers::SignalData<void(QCPAxis *)>(9, 2, QMC::AccessPublic, QMetaType::Void, {{
            { 0x80000000 | 10, 11 },
        }}),
        // Slot 'updateValues'
        QtMocHelpers::SlotData<void(const double)>(12, 2, QMC::AccessPublic, QMetaType::Void, {{
            { QMetaType::Double, 13 },
        }}),
        // Slot 'slotClosed'
        QtMocHelpers::SlotData<void()>(14, 2, QMC::AccessPublic, QMetaType::Void),
        // Slot 'slotSaveChanges'
        QtMocHelpers::SlotData<void()>(15, 2, QMC::AccessPrivate, QMetaType::Void),
    };
    QtMocHelpers::UintData qt_properties {
    };
    QtMocHelpers::UintData qt_enums {
    };
    return QtMocHelpers::metaObjectData<YAxisTool, qt_meta_tag_ZN9YAxisToolE_t>(QMC::MetaObjectFlag{}, qt_stringData,
            qt_methods, qt_properties, qt_enums);
}
Q_CONSTINIT const QMetaObject YAxisTool::staticMetaObject = { {
    QMetaObject::SuperData::link<QDialog::staticMetaObject>(),
    qt_staticMetaObjectStaticContent<qt_meta_tag_ZN9YAxisToolE_t>.stringdata,
    qt_staticMetaObjectStaticContent<qt_meta_tag_ZN9YAxisToolE_t>.data,
    qt_static_metacall,
    nullptr,
    qt_staticMetaObjectRelocatingContent<qt_meta_tag_ZN9YAxisToolE_t>.metaTypes,
    nullptr
} };

void YAxisTool::qt_static_metacall(QObject *_o, QMetaObject::Call _c, int _id, void **_a)
{
    auto *_t = static_cast<YAxisTool *>(_o);
    if (_c == QMetaObject::InvokeMetaMethod) {
        switch (_id) {
        case 0: _t->axisChanged((*reinterpret_cast<std::add_pointer_t<QObject*>>(_a[1])),(*reinterpret_cast<std::add_pointer_t<YAxisInfo>>(_a[2]))); break;
        case 1: _t->axisColorChanged((*reinterpret_cast<std::add_pointer_t<QObject*>>(_a[1])),(*reinterpret_cast<std::add_pointer_t<YAxisInfo>>(_a[2])),(*reinterpret_cast<std::add_pointer_t<QColor>>(_a[3]))); break;
        case 2: _t->leftAxisChanged((*reinterpret_cast<std::add_pointer_t<QCPAxis*>>(_a[1]))); break;
        case 3: _t->updateValues((*reinterpret_cast<std::add_pointer_t<double>>(_a[1]))); break;
        case 4: _t->slotClosed(); break;
        case 5: _t->slotSaveChanges(); break;
        default: ;
        }
    }
    if (_c == QMetaObject::RegisterMethodArgumentMetaType) {
        switch (_id) {
        default: *reinterpret_cast<QMetaType *>(_a[0]) = QMetaType(); break;
        case 2:
            switch (*reinterpret_cast<int*>(_a[1])) {
            default: *reinterpret_cast<QMetaType *>(_a[0]) = QMetaType(); break;
            case 0:
                *reinterpret_cast<QMetaType *>(_a[0]) = QMetaType::fromType< QCPAxis* >(); break;
            }
            break;
        }
    }
    if (_c == QMetaObject::IndexOfMethod) {
        if (QtMocHelpers::indexOfMethod<void (YAxisTool::*)(QObject * , const YAxisInfo & )>(_a, &YAxisTool::axisChanged, 0))
            return;
        if (QtMocHelpers::indexOfMethod<void (YAxisTool::*)(QObject * , const YAxisInfo & , const QColor & )>(_a, &YAxisTool::axisColorChanged, 1))
            return;
        if (QtMocHelpers::indexOfMethod<void (YAxisTool::*)(QCPAxis * )>(_a, &YAxisTool::leftAxisChanged, 2))
            return;
    }
}

const QMetaObject *YAxisTool::metaObject() const
{
    return QObject::d_ptr->metaObject ? QObject::d_ptr->dynamicMetaObject() : &staticMetaObject;
}

void *YAxisTool::qt_metacast(const char *_clname)
{
    if (!_clname) return nullptr;
    if (!strcmp(_clname, qt_staticMetaObjectStaticContent<qt_meta_tag_ZN9YAxisToolE_t>.strings))
        return static_cast<void*>(this);
    return QDialog::qt_metacast(_clname);
}

int YAxisTool::qt_metacall(QMetaObject::Call _c, int _id, void **_a)
{
    _id = QDialog::qt_metacall(_c, _id, _a);
    if (_id < 0)
        return _id;
    if (_c == QMetaObject::InvokeMetaMethod) {
        if (_id < 6)
            qt_static_metacall(this, _c, _id, _a);
        _id -= 6;
    }
    if (_c == QMetaObject::RegisterMethodArgumentMetaType) {
        if (_id < 6)
            qt_static_metacall(this, _c, _id, _a);
        _id -= 6;
    }
    return _id;
}

// SIGNAL 0
void YAxisTool::axisChanged(QObject * _t1, const YAxisInfo & _t2)
{
    QMetaObject::activate<void>(this, &staticMetaObject, 0, nullptr, _t1, _t2);
}

// SIGNAL 1
void YAxisTool::axisColorChanged(QObject * _t1, const YAxisInfo & _t2, const QColor & _t3)
{
    QMetaObject::activate<void>(this, &staticMetaObject, 1, nullptr, _t1, _t2, _t3);
}

// SIGNAL 2
void YAxisTool::leftAxisChanged(QCPAxis * _t1)
{
    QMetaObject::activate<void>(this, &staticMetaObject, 2, nullptr, _t1);
}
QT_WARNING_POP
