/********************************************************************************
** Form generated from reading UI file 'manager.ui'
**
** Created by: Qt User Interface Compiler version 6.11.1
**
** WARNING! All changes made in this file will be lost when recompiling UI file!
********************************************************************************/

#ifndef UI_MANAGER_H
#define UI_MANAGER_H

#include <QtCore/QVariant>
#include <QtGui/QIcon>
#include <QtWidgets/QApplication>
#include <QtWidgets/QComboBox>
#include <QtWidgets/QFrame>
#include <QtWidgets/QGridLayout>
#include <QtWidgets/QGroupBox>
#include <QtWidgets/QHBoxLayout>
#include <QtWidgets/QLabel>
#include <QtWidgets/QPlainTextEdit>
#include <QtWidgets/QPushButton>
#include <QtWidgets/QSpacerItem>
#include <QtWidgets/QSplitter>
#include <QtWidgets/QTabWidget>
#include <QtWidgets/QVBoxLayout>
#include <QtWidgets/QWidget>
#include <klocalizedstring.h>
#include "ekos/auxiliary/ledstatuswidget.h"
#include "ekos/capture/capturepreviewwidget.h"
#include "ekos/manager/focusprogresswidget.h"
#include "ekos/manager/guidemanager.h"
#include "ekos/mount/meridianflipstatuswidget.h"

QT_BEGIN_NAMESPACE

class Ui_Manager
{
public:
    QVBoxLayout *verticalLayout_3;
    QSplitter *splitter;
    QTabWidget *toolsWidget;
    QWidget *setupTab;
    QVBoxLayout *verticalLayout;
    QHBoxLayout *ekosGroup;
    QGroupBox *profileGroup;
    QHBoxLayout *horizontalLayout_6;
    QLabel *label;
    QComboBox *profileCombo;
    QPushButton *addProfileB;
    QPushButton *editProfileB;
    QPushButton *deleteProfileB;
    QPushButton *customDriversB;
    QPushButton *wizardProfileB;
    QSpacerItem *horizontalSpacer_2;
    QGroupBox *groupBox_2;
    QHBoxLayout *horizontalLayout_5;
    QHBoxLayout *horizontalLayout_3;
    QPushButton *processINDIB;
    QPushButton *ekosLiveB;
    QPushButton *indiControlPanelB;
    QPushButton *portSelectorB;
    QPushButton *optionsB;
    QPushButton *logsB;
    QGroupBox *groupBox_3;
    QVBoxLayout *verticalLayout_8;
    QHBoxLayout *horizontalLayout_4;
    QPushButton *connectB;
    QPushButton *disconnectB;
    QGroupBox *groupBox_4;
    QVBoxLayout *verticalLayout_5;
    QHBoxLayout *horizontalLayout_2;
    QComboBox *extensionCombo;
    QPushButton *extensionB;
    QSplitter *deviceSplitter;
    CapturePreviewWidget *capturePreview;
    QWidget *rightLayoutWidget;
    QVBoxLayout *rightLayout;
    QWidget *mountGroup;
    QVBoxLayout *mountGroupLayout;
    QHBoxLayout *mountStatusLayout;
    QLabel *mountLabel;
    QSpacerItem *horizontalSpacer_3;
    Ekos::LedStatusWidget *mountStatus;
    QFrame *mountMotionFrame;
    QVBoxLayout *verticalLayout_2;
    QGridLayout *mountPosLayout;
    QLabel *altLabel;
    QLabel *azLabel;
    QLabel *decLabel;
    QLabel *raLabel;
    QLabel *raOUT;
    QLabel *decOUT;
    QLabel *azOUT;
    QLabel *altOUT;
    QHBoxLayout *meridianFlipLayout;
    Ekos::MeridianFlipStatusWidget *meridianFlipStatusWidget;
    QSpacerItem *horizontalSpacer;
    QSpacerItem *verticalSpacer_2;
    Ekos::FocusProgressWidget *focusProgressWidget;
    Ekos::GuideManager *guideManager;
    QWidget *layoutWidget;
    QHBoxLayout *bottomLayout;
    QPlainTextEdit *ekosLogOut;
    QVBoxLayout *verticalLayout_4;
    QSpacerItem *verticalSpacer;
    QPushButton *helpB;
    QPushButton *ekosOptionsB;
    QPushButton *clearB;

    void setupUi(QWidget *Manager)
    {
        if (Manager->objectName().isEmpty())
            Manager->setObjectName("Manager");
        Manager->resize(700, 700);
        QSizePolicy sizePolicy(QSizePolicy::Policy::MinimumExpanding, QSizePolicy::Policy::MinimumExpanding);
        sizePolicy.setHorizontalStretch(0);
        sizePolicy.setVerticalStretch(0);
        sizePolicy.setHeightForWidth(Manager->sizePolicy().hasHeightForWidth());
        Manager->setSizePolicy(sizePolicy);
        Manager->setMinimumSize(QSize(700, 700));
        Manager->setMaximumSize(QSize(16777215, 16777215));
        Manager->setBaseSize(QSize(0, 0));
        verticalLayout_3 = new QVBoxLayout(Manager);
        verticalLayout_3->setSpacing(1);
        verticalLayout_3->setObjectName("verticalLayout_3");
        verticalLayout_3->setContentsMargins(3, 3, 3, 3);
        splitter = new QSplitter(Manager);
        splitter->setObjectName("splitter");
        sizePolicy.setHeightForWidth(splitter->sizePolicy().hasHeightForWidth());
        splitter->setSizePolicy(sizePolicy);
        splitter->setMinimumSize(QSize(0, 0));
        splitter->setOrientation(Qt::Vertical);
        splitter->setChildrenCollapsible(false);
        toolsWidget = new QTabWidget(splitter);
        toolsWidget->setObjectName("toolsWidget");
        QSizePolicy sizePolicy1(QSizePolicy::Policy::MinimumExpanding, QSizePolicy::Policy::Ignored);
        sizePolicy1.setHorizontalStretch(0);
        sizePolicy1.setVerticalStretch(0);
        sizePolicy1.setHeightForWidth(toolsWidget->sizePolicy().hasHeightForWidth());
        toolsWidget->setSizePolicy(sizePolicy1);
        toolsWidget->setMinimumSize(QSize(0, 0));
        setupTab = new QWidget();
        setupTab->setObjectName("setupTab");
        verticalLayout = new QVBoxLayout(setupTab);
        verticalLayout->setSpacing(0);
        verticalLayout->setObjectName("verticalLayout");
        ekosGroup = new QHBoxLayout();
        ekosGroup->setSpacing(1);
        ekosGroup->setObjectName("ekosGroup");
        profileGroup = new QGroupBox(setupTab);
        profileGroup->setObjectName("profileGroup");
        horizontalLayout_6 = new QHBoxLayout(profileGroup);
        horizontalLayout_6->setSpacing(1);
        horizontalLayout_6->setObjectName("horizontalLayout_6");
        horizontalLayout_6->setContentsMargins(3, 3, 3, 3);
        label = new QLabel(profileGroup);
        label->setObjectName("label");

        horizontalLayout_6->addWidget(label);

        profileCombo = new QComboBox(profileGroup);
        profileCombo->setObjectName("profileCombo");
        QSizePolicy sizePolicy2(QSizePolicy::Policy::MinimumExpanding, QSizePolicy::Policy::Fixed);
        sizePolicy2.setHorizontalStretch(0);
        sizePolicy2.setVerticalStretch(0);
        sizePolicy2.setHeightForWidth(profileCombo->sizePolicy().hasHeightForWidth());
        profileCombo->setSizePolicy(sizePolicy2);
        profileCombo->setSizeAdjustPolicy(QComboBox::AdjustToContents);

        horizontalLayout_6->addWidget(profileCombo);

        addProfileB = new QPushButton(profileGroup);
        addProfileB->setObjectName("addProfileB");
        QSizePolicy sizePolicy3(QSizePolicy::Policy::Fixed, QSizePolicy::Policy::Fixed);
        sizePolicy3.setHorizontalStretch(0);
        sizePolicy3.setVerticalStretch(0);
        sizePolicy3.setHeightForWidth(addProfileB->sizePolicy().hasHeightForWidth());
        addProfileB->setSizePolicy(sizePolicy3);
        addProfileB->setMinimumSize(QSize(22, 22));
        addProfileB->setMaximumSize(QSize(22, 22));
        addProfileB->setIconSize(QSize(22, 22));

        horizontalLayout_6->addWidget(addProfileB);

        editProfileB = new QPushButton(profileGroup);
        editProfileB->setObjectName("editProfileB");
        sizePolicy3.setHeightForWidth(editProfileB->sizePolicy().hasHeightForWidth());
        editProfileB->setSizePolicy(sizePolicy3);
        editProfileB->setMinimumSize(QSize(22, 22));
        editProfileB->setMaximumSize(QSize(22, 22));
        editProfileB->setIconSize(QSize(22, 22));

        horizontalLayout_6->addWidget(editProfileB);

        deleteProfileB = new QPushButton(profileGroup);
        deleteProfileB->setObjectName("deleteProfileB");
        sizePolicy3.setHeightForWidth(deleteProfileB->sizePolicy().hasHeightForWidth());
        deleteProfileB->setSizePolicy(sizePolicy3);
        deleteProfileB->setMinimumSize(QSize(22, 22));
        deleteProfileB->setMaximumSize(QSize(22, 22));
        deleteProfileB->setIconSize(QSize(22, 22));

        horizontalLayout_6->addWidget(deleteProfileB);

        customDriversB = new QPushButton(profileGroup);
        customDriversB->setObjectName("customDriversB");
        customDriversB->setMinimumSize(QSize(22, 22));
        customDriversB->setMaximumSize(QSize(22, 22));
        customDriversB->setIconSize(QSize(22, 22));

        horizontalLayout_6->addWidget(customDriversB);

        wizardProfileB = new QPushButton(profileGroup);
        wizardProfileB->setObjectName("wizardProfileB");
        wizardProfileB->setMinimumSize(QSize(22, 22));
        wizardProfileB->setMaximumSize(QSize(22, 22));
        wizardProfileB->setIconSize(QSize(22, 22));

        horizontalLayout_6->addWidget(wizardProfileB);

        horizontalSpacer_2 = new QSpacerItem(1, 20, QSizePolicy::Policy::Minimum, QSizePolicy::Policy::Minimum);

        horizontalLayout_6->addItem(horizontalSpacer_2);


        ekosGroup->addWidget(profileGroup);

        groupBox_2 = new QGroupBox(setupTab);
        groupBox_2->setObjectName("groupBox_2");
        horizontalLayout_5 = new QHBoxLayout(groupBox_2);
        horizontalLayout_5->setSpacing(1);
        horizontalLayout_5->setObjectName("horizontalLayout_5");
        horizontalLayout_5->setContentsMargins(3, 3, 3, 3);
        horizontalLayout_3 = new QHBoxLayout();
        horizontalLayout_3->setSpacing(1);
        horizontalLayout_3->setObjectName("horizontalLayout_3");
        processINDIB = new QPushButton(groupBox_2);
        processINDIB->setObjectName("processINDIB");
        processINDIB->setEnabled(true);
        processINDIB->setMinimumSize(QSize(32, 32));
        processINDIB->setIconSize(QSize(22, 22));

        horizontalLayout_3->addWidget(processINDIB);

        ekosLiveB = new QPushButton(groupBox_2);
        ekosLiveB->setObjectName("ekosLiveB");
        ekosLiveB->setEnabled(true);
        ekosLiveB->setMinimumSize(QSize(32, 32));
        QIcon icon(QIcon::fromTheme(QString::fromUtf8("folder-cloud")));
        ekosLiveB->setIcon(icon);
        ekosLiveB->setIconSize(QSize(22, 22));

        horizontalLayout_3->addWidget(ekosLiveB);

        indiControlPanelB = new QPushButton(groupBox_2);
        indiControlPanelB->setObjectName("indiControlPanelB");
        indiControlPanelB->setEnabled(false);
        indiControlPanelB->setMinimumSize(QSize(32, 32));
        QIcon icon1(QIcon::fromTheme(QString::fromUtf8("kstars_indi")));
        indiControlPanelB->setIcon(icon1);
        indiControlPanelB->setIconSize(QSize(22, 22));

        horizontalLayout_3->addWidget(indiControlPanelB);

        portSelectorB = new QPushButton(groupBox_2);
        portSelectorB->setObjectName("portSelectorB");
        portSelectorB->setEnabled(true);
        portSelectorB->setMinimumSize(QSize(32, 32));
        QIcon icon2(QIcon::fromTheme(QString::fromUtf8("drive-removable-media")));
        portSelectorB->setIcon(icon2);
        portSelectorB->setIconSize(QSize(22, 22));

        horizontalLayout_3->addWidget(portSelectorB);

        optionsB = new QPushButton(groupBox_2);
        optionsB->setObjectName("optionsB");
        optionsB->setEnabled(true);
        optionsB->setMinimumSize(QSize(32, 32));
        QIcon icon3(QIcon::fromTheme(QString::fromUtf8("configure")));
        optionsB->setIcon(icon3);
        optionsB->setIconSize(QSize(22, 22));

        horizontalLayout_3->addWidget(optionsB);

        logsB = new QPushButton(groupBox_2);
        logsB->setObjectName("logsB");
        logsB->setMinimumSize(QSize(32, 32));
        logsB->setIconSize(QSize(22, 22));

        horizontalLayout_3->addWidget(logsB);


        horizontalLayout_5->addLayout(horizontalLayout_3);


        ekosGroup->addWidget(groupBox_2);

        groupBox_3 = new QGroupBox(setupTab);
        groupBox_3->setObjectName("groupBox_3");
        QSizePolicy sizePolicy4(QSizePolicy::Policy::Preferred, QSizePolicy::Policy::Preferred);
        sizePolicy4.setHorizontalStretch(0);
        sizePolicy4.setVerticalStretch(1);
        sizePolicy4.setHeightForWidth(groupBox_3->sizePolicy().hasHeightForWidth());
        groupBox_3->setSizePolicy(sizePolicy4);
        verticalLayout_8 = new QVBoxLayout(groupBox_3);
        verticalLayout_8->setSpacing(1);
        verticalLayout_8->setObjectName("verticalLayout_8");
        verticalLayout_8->setContentsMargins(3, 3, 3, 3);
        horizontalLayout_4 = new QHBoxLayout();
        horizontalLayout_4->setSpacing(1);
        horizontalLayout_4->setObjectName("horizontalLayout_4");
        connectB = new QPushButton(groupBox_3);
        connectB->setObjectName("connectB");
        connectB->setEnabled(false);
        connectB->setMinimumSize(QSize(32, 32));

        horizontalLayout_4->addWidget(connectB);

        disconnectB = new QPushButton(groupBox_3);
        disconnectB->setObjectName("disconnectB");
        disconnectB->setEnabled(false);
        disconnectB->setMinimumSize(QSize(32, 32));

        horizontalLayout_4->addWidget(disconnectB);


        verticalLayout_8->addLayout(horizontalLayout_4);


        ekosGroup->addWidget(groupBox_3);

        groupBox_4 = new QGroupBox(setupTab);
        groupBox_4->setObjectName("groupBox_4");
        sizePolicy4.setHeightForWidth(groupBox_4->sizePolicy().hasHeightForWidth());
        groupBox_4->setSizePolicy(sizePolicy4);
        groupBox_4->setMinimumSize(QSize(170, 0));
        groupBox_4->setMaximumSize(QSize(170, 16777215));
        groupBox_4->setAlignment(Qt::AlignLeading|Qt::AlignLeft|Qt::AlignVCenter);
        verticalLayout_5 = new QVBoxLayout(groupBox_4);
        verticalLayout_5->setSpacing(1);
        verticalLayout_5->setObjectName("verticalLayout_5");
        verticalLayout_5->setContentsMargins(3, 3, 3, 3);
        horizontalLayout_2 = new QHBoxLayout();
        horizontalLayout_2->setSpacing(1);
        horizontalLayout_2->setObjectName("horizontalLayout_2");
        horizontalLayout_2->setContentsMargins(-1, -1, -1, 0);
        extensionCombo = new QComboBox(groupBox_4);
        extensionCombo->setObjectName("extensionCombo");
        extensionCombo->setEnabled(false);
        sizePolicy2.setHeightForWidth(extensionCombo->sizePolicy().hasHeightForWidth());
        extensionCombo->setSizePolicy(sizePolicy2);
        extensionCombo->setMinimumSize(QSize(120, 32));
        extensionCombo->setMaximumSize(QSize(200, 16777215));

        horizontalLayout_2->addWidget(extensionCombo);

        extensionB = new QPushButton(groupBox_4);
        extensionB->setObjectName("extensionB");
        extensionB->setEnabled(false);
        QSizePolicy sizePolicy5(QSizePolicy::Policy::Minimum, QSizePolicy::Policy::Fixed);
        sizePolicy5.setHorizontalStretch(0);
        sizePolicy5.setVerticalStretch(0);
        sizePolicy5.setHeightForWidth(extensionB->sizePolicy().hasHeightForWidth());
        extensionB->setSizePolicy(sizePolicy5);
        extensionB->setMinimumSize(QSize(32, 32));
        extensionB->setMaximumSize(QSize(32, 32));
        extensionB->setIconSize(QSize(30, 30));

        horizontalLayout_2->addWidget(extensionB);


        verticalLayout_5->addLayout(horizontalLayout_2);


        ekosGroup->addWidget(groupBox_4);


        verticalLayout->addLayout(ekosGroup);

        deviceSplitter = new QSplitter(setupTab);
        deviceSplitter->setObjectName("deviceSplitter");
        deviceSplitter->setOrientation(Qt::Horizontal);
        capturePreview = new CapturePreviewWidget(deviceSplitter);
        capturePreview->setObjectName("capturePreview");
        capturePreview->setEnabled(false);
        deviceSplitter->addWidget(capturePreview);
        rightLayoutWidget = new QWidget(deviceSplitter);
        rightLayoutWidget->setObjectName("rightLayoutWidget");
        rightLayout = new QVBoxLayout(rightLayoutWidget);
        rightLayout->setSpacing(6);
        rightLayout->setObjectName("rightLayout");
        rightLayout->setContentsMargins(4, 4, 4, 4);
        mountGroup = new QWidget(rightLayoutWidget);
        mountGroup->setObjectName("mountGroup");
        mountGroup->setEnabled(false);
        mountGroup->setAutoFillBackground(false);
        mountGroup->setStyleSheet(QString::fromUtf8(""));
        mountGroupLayout = new QVBoxLayout(mountGroup);
        mountGroupLayout->setSpacing(4);
        mountGroupLayout->setObjectName("mountGroupLayout");
        mountGroupLayout->setContentsMargins(0, 0, 0, 0);
        mountStatusLayout = new QHBoxLayout();
        mountStatusLayout->setSpacing(2);
        mountStatusLayout->setObjectName("mountStatusLayout");
        mountLabel = new QLabel(mountGroup);
        mountLabel->setObjectName("mountLabel");
        mountLabel->setMinimumSize(QSize(0, 24));
        mountLabel->setStyleSheet(QString::fromUtf8("font-weight:bold;"));
        mountLabel->setTextFormat(Qt::AutoText);
        mountLabel->setMargin(2);

        mountStatusLayout->addWidget(mountLabel);

        horizontalSpacer_3 = new QSpacerItem(40, 20, QSizePolicy::Policy::Expanding, QSizePolicy::Policy::Minimum);

        mountStatusLayout->addItem(horizontalSpacer_3);

        mountStatus = new Ekos::LedStatusWidget(mountGroup);
        mountStatus->setObjectName("mountStatus");
        mountStatus->setMinimumSize(QSize(20, 0));

        mountStatusLayout->addWidget(mountStatus);

        mountStatusLayout->setStretch(1, 1);

        mountGroupLayout->addLayout(mountStatusLayout);

        mountMotionFrame = new QFrame(mountGroup);
        mountMotionFrame->setObjectName("mountMotionFrame");
        mountMotionFrame->setFrameShape(QFrame::StyledPanel);
        mountMotionFrame->setFrameShadow(QFrame::Sunken);
        verticalLayout_2 = new QVBoxLayout(mountMotionFrame);
        verticalLayout_2->setSpacing(4);
        verticalLayout_2->setObjectName("verticalLayout_2");
        verticalLayout_2->setContentsMargins(4, 4, 4, 4);
        mountPosLayout = new QGridLayout();
        mountPosLayout->setSpacing(3);
        mountPosLayout->setObjectName("mountPosLayout");
        altLabel = new QLabel(mountMotionFrame);
        altLabel->setObjectName("altLabel");
        QFont font;
        font.setBold(true);
        altLabel->setFont(font);

        mountPosLayout->addWidget(altLabel, 1, 2, 1, 1);

        azLabel = new QLabel(mountMotionFrame);
        azLabel->setObjectName("azLabel");
        azLabel->setFont(font);

        mountPosLayout->addWidget(azLabel, 1, 0, 1, 1);

        decLabel = new QLabel(mountMotionFrame);
        decLabel->setObjectName("decLabel");
        decLabel->setFont(font);

        mountPosLayout->addWidget(decLabel, 0, 2, 1, 1);

        raLabel = new QLabel(mountMotionFrame);
        raLabel->setObjectName("raLabel");
        raLabel->setFont(font);

        mountPosLayout->addWidget(raLabel, 0, 0, 1, 1);

        raOUT = new QLabel(mountMotionFrame);
        raOUT->setObjectName("raOUT");
        raOUT->setAlignment(Qt::AlignLeading|Qt::AlignLeft|Qt::AlignVCenter);

        mountPosLayout->addWidget(raOUT, 0, 1, 1, 1);

        decOUT = new QLabel(mountMotionFrame);
        decOUT->setObjectName("decOUT");
        decOUT->setAlignment(Qt::AlignLeading|Qt::AlignLeft|Qt::AlignVCenter);

        mountPosLayout->addWidget(decOUT, 0, 3, 1, 1);

        azOUT = new QLabel(mountMotionFrame);
        azOUT->setObjectName("azOUT");
        azOUT->setAlignment(Qt::AlignLeading|Qt::AlignLeft|Qt::AlignVCenter);

        mountPosLayout->addWidget(azOUT, 1, 1, 1, 1);

        altOUT = new QLabel(mountMotionFrame);
        altOUT->setObjectName("altOUT");
        altOUT->setAlignment(Qt::AlignLeading|Qt::AlignLeft|Qt::AlignVCenter);

        mountPosLayout->addWidget(altOUT, 1, 3, 1, 1);

        mountPosLayout->setColumnStretch(1, 1);
        mountPosLayout->setColumnStretch(3, 1);

        verticalLayout_2->addLayout(mountPosLayout);

        meridianFlipLayout = new QHBoxLayout();
        meridianFlipLayout->setObjectName("meridianFlipLayout");
        meridianFlipStatusWidget = new Ekos::MeridianFlipStatusWidget(mountMotionFrame);
        meridianFlipStatusWidget->setObjectName("meridianFlipStatusWidget");
        meridianFlipStatusWidget->setMinimumSize(QSize(48, 24));
        QFont font1;
        font1.setItalic(false);
        meridianFlipStatusWidget->setFont(font1);

        meridianFlipLayout->addWidget(meridianFlipStatusWidget);

        horizontalSpacer = new QSpacerItem(40, 20, QSizePolicy::Policy::Expanding, QSizePolicy::Policy::Minimum);

        meridianFlipLayout->addItem(horizontalSpacer);

        meridianFlipLayout->setStretch(1, 1);

        verticalLayout_2->addLayout(meridianFlipLayout);


        mountGroupLayout->addWidget(mountMotionFrame);

        verticalSpacer_2 = new QSpacerItem(10, 10, QSizePolicy::Policy::Minimum, QSizePolicy::Policy::Expanding);

        mountGroupLayout->addItem(verticalSpacer_2);

        mountGroupLayout->setStretch(2, 1);

        rightLayout->addWidget(mountGroup);

        focusProgressWidget = new Ekos::FocusProgressWidget(rightLayoutWidget);
        focusProgressWidget->setObjectName("focusProgressWidget");

        rightLayout->addWidget(focusProgressWidget);

        guideManager = new Ekos::GuideManager(rightLayoutWidget);
        guideManager->setObjectName("guideManager");

        rightLayout->addWidget(guideManager);

        rightLayout->setStretch(1, 1);
        rightLayout->setStretch(2, 1);
        deviceSplitter->addWidget(rightLayoutWidget);

        verticalLayout->addWidget(deviceSplitter);

        verticalLayout->setStretch(1, 1);
        toolsWidget->addTab(setupTab, QString());
        splitter->addWidget(toolsWidget);
        layoutWidget = new QWidget(splitter);
        layoutWidget->setObjectName("layoutWidget");
        bottomLayout = new QHBoxLayout(layoutWidget);
        bottomLayout->setObjectName("bottomLayout");
        bottomLayout->setContentsMargins(0, 0, 0, 0);
        ekosLogOut = new QPlainTextEdit(layoutWidget);
        ekosLogOut->setObjectName("ekosLogOut");
        QSizePolicy sizePolicy6(QSizePolicy::Policy::Expanding, QSizePolicy::Policy::Ignored);
        sizePolicy6.setHorizontalStretch(0);
        sizePolicy6.setVerticalStretch(0);
        sizePolicy6.setHeightForWidth(ekosLogOut->sizePolicy().hasHeightForWidth());
        ekosLogOut->setSizePolicy(sizePolicy6);
        ekosLogOut->setMinimumSize(QSize(0, 50));
        ekosLogOut->setMaximumSize(QSize(16777215, 16777215));
        ekosLogOut->setSizeAdjustPolicy(QAbstractScrollArea::AdjustToContents);
        ekosLogOut->setReadOnly(true);

        bottomLayout->addWidget(ekosLogOut);

        verticalLayout_4 = new QVBoxLayout();
        verticalLayout_4->setObjectName("verticalLayout_4");
        verticalSpacer = new QSpacerItem(20, 40, QSizePolicy::Policy::Minimum, QSizePolicy::Policy::Expanding);

        verticalLayout_4->addItem(verticalSpacer);

        helpB = new QPushButton(layoutWidget);
        helpB->setObjectName("helpB");
        sizePolicy5.setHeightForWidth(helpB->sizePolicy().hasHeightForWidth());
        helpB->setSizePolicy(sizePolicy5);

        verticalLayout_4->addWidget(helpB, 0, Qt::AlignHCenter);

        ekosOptionsB = new QPushButton(layoutWidget);
        ekosOptionsB->setObjectName("ekosOptionsB");

        verticalLayout_4->addWidget(ekosOptionsB);

        clearB = new QPushButton(layoutWidget);
        clearB->setObjectName("clearB");

        verticalLayout_4->addWidget(clearB);


        bottomLayout->addLayout(verticalLayout_4);

        splitter->addWidget(layoutWidget);

        verticalLayout_3->addWidget(splitter);

        QWidget::setTabOrder(processINDIB, connectB);
        QWidget::setTabOrder(connectB, disconnectB);
        QWidget::setTabOrder(disconnectB, profileCombo);
        QWidget::setTabOrder(profileCombo, addProfileB);
        QWidget::setTabOrder(addProfileB, editProfileB);
        QWidget::setTabOrder(editProfileB, deleteProfileB);
        QWidget::setTabOrder(deleteProfileB, customDriversB);
        QWidget::setTabOrder(customDriversB, wizardProfileB);
        QWidget::setTabOrder(wizardProfileB, ekosLiveB);
        QWidget::setTabOrder(ekosLiveB, optionsB);
        QWidget::setTabOrder(optionsB, ekosOptionsB);
        QWidget::setTabOrder(ekosOptionsB, clearB);
        QWidget::setTabOrder(clearB, ekosLogOut);
        QWidget::setTabOrder(ekosLogOut, toolsWidget);

        retranslateUi(Manager);

        toolsWidget->setCurrentIndex(0);


        QMetaObject::connectSlotsByName(Manager);
    } // setupUi

    void retranslateUi(QWidget *Manager)
    {
        Manager->setWindowTitle(tr2i18n("Ekos", nullptr));
        profileGroup->setTitle(tr2i18n("1. Select Profile", nullptr));
        label->setText(tr2i18n("Profile:", nullptr));
#if QT_CONFIG(tooltip)
        addProfileB->setToolTip(tr2i18n("Add profile...", nullptr));
#endif // QT_CONFIG(tooltip)
#if QT_CONFIG(statustip)
        addProfileB->setStatusTip(QString());
#endif // QT_CONFIG(statustip)
        addProfileB->setText(QString());
#if QT_CONFIG(tooltip)
        editProfileB->setToolTip(tr2i18n("Edit profile...", nullptr));
#endif // QT_CONFIG(tooltip)
#if QT_CONFIG(statustip)
        editProfileB->setStatusTip(QString());
#endif // QT_CONFIG(statustip)
        editProfileB->setText(QString());
#if QT_CONFIG(tooltip)
        deleteProfileB->setToolTip(tr2i18n("Remove profile", nullptr));
#endif // QT_CONFIG(tooltip)
#if QT_CONFIG(statustip)
        deleteProfileB->setStatusTip(QString());
#endif // QT_CONFIG(statustip)
        deleteProfileB->setText(QString());
#if QT_CONFIG(tooltip)
        customDriversB->setToolTip(tr2i18n("Custom Drivers...", nullptr));
#endif // QT_CONFIG(tooltip)
        customDriversB->setText(QString());
#if QT_CONFIG(tooltip)
        wizardProfileB->setToolTip(tr2i18n("Launch Ekos Profile Wizard...", nullptr));
#endif // QT_CONFIG(tooltip)
        wizardProfileB->setText(QString());
        groupBox_2->setTitle(tr2i18n("2. Start && Stop Ekos", nullptr));
        processINDIB->setText(QString());
#if QT_CONFIG(tooltip)
        ekosLiveB->setToolTip(tr2i18n("Ekos Live...", nullptr));
#endif // QT_CONFIG(tooltip)
        ekosLiveB->setText(QString());
#if QT_CONFIG(tooltip)
        indiControlPanelB->setToolTip(tr2i18n("INDI Control Panel...", nullptr));
#endif // QT_CONFIG(tooltip)
        indiControlPanelB->setText(QString());
#if QT_CONFIG(tooltip)
        portSelectorB->setToolTip(tr2i18n("<html><head/><body><p>Devices Port Selector...</p></body></html>", nullptr));
#endif // QT_CONFIG(tooltip)
        portSelectorB->setText(QString());
#if QT_CONFIG(tooltip)
        optionsB->setToolTip(tr2i18n("Ekos Options...", nullptr));
#endif // QT_CONFIG(tooltip)
        optionsB->setText(QString());
#if QT_CONFIG(tooltip)
        logsB->setToolTip(tr2i18n("Logs to diagnose issues with Ekos and INDI.", nullptr));
#endif // QT_CONFIG(tooltip)
        logsB->setText(tr2i18n("Logs...", nullptr));
        groupBox_3->setTitle(tr2i18n("3. Connect && Disconnect Devices", nullptr));
        connectB->setText(tr2i18n("Connect", nullptr));
        disconnectB->setText(tr2i18n("Disconnect", nullptr));
        groupBox_4->setTitle(tr2i18n("Extensions", nullptr));
#if QT_CONFIG(tooltip)
        extensionB->setToolTip(tr2i18n("Start selected extension", nullptr));
#endif // QT_CONFIG(tooltip)
        extensionB->setText(QString());
        mountLabel->setText(tr2i18n("Mount", nullptr));
#if QT_CONFIG(tooltip)
        altLabel->setToolTip(tr2i18n("Altitude", nullptr));
#endif // QT_CONFIG(tooltip)
        altLabel->setText(tr2i18n("AL:", nullptr));
#if QT_CONFIG(tooltip)
        azLabel->setToolTip(tr2i18n("Azimuth", nullptr));
#endif // QT_CONFIG(tooltip)
        azLabel->setText(tr2i18n("AZ:", nullptr));
#if QT_CONFIG(tooltip)
        decLabel->setToolTip(tr2i18n("Declination", nullptr));
#endif // QT_CONFIG(tooltip)
        decLabel->setText(tr2i18n("DE:", nullptr));
#if QT_CONFIG(tooltip)
        raLabel->setToolTip(tr2i18n("Right Ascension", nullptr));
#endif // QT_CONFIG(tooltip)
        raLabel->setText(tr2i18n("RA:", nullptr));
        raOUT->setText(tr2i18n("  --", nullptr));
        decOUT->setText(tr2i18n("  --", nullptr));
        azOUT->setText(tr2i18n("  --", nullptr));
        altOUT->setText(tr2i18n("  --", nullptr));
        toolsWidget->setTabText(toolsWidget->indexOf(setupTab), QString());
        helpB->setText(tr2i18n("Manual", "opens handbook"));
#if QT_CONFIG(tooltip)
        ekosOptionsB->setToolTip(tr2i18n("Advanced Ekos Options", nullptr));
#endif // QT_CONFIG(tooltip)
        ekosOptionsB->setText(tr2i18n("Options...", nullptr));
        clearB->setText(tr2i18n("Clear", nullptr));
    } // retranslateUi

};

namespace Ui {
    class Manager: public Ui_Manager {};
} // namespace Ui

QT_END_NAMESPACE

#endif // MANAGER_H

