/********************************************************************************
** Form generated from reading UI file 'guide.ui'
**
** Created by: Qt User Interface Compiler version 6.11.1
**
** WARNING! All changes made in this file will be lost when recompiling UI file!
********************************************************************************/

#ifndef UI_GUIDE_H
#define UI_GUIDE_H

#include <QtCore/QVariant>
#include <QtGui/QIcon>
#include <QtWidgets/QApplication>
#include <QtWidgets/QCheckBox>
#include <QtWidgets/QComboBox>
#include <QtWidgets/QDoubleSpinBox>
#include <QtWidgets/QGridLayout>
#include <QtWidgets/QGroupBox>
#include <QtWidgets/QHBoxLayout>
#include <QtWidgets/QLabel>
#include <QtWidgets/QPushButton>
#include <QtWidgets/QSlider>
#include <QtWidgets/QSpacerItem>
#include <QtWidgets/QSplitter>
#include <QtWidgets/QTabWidget>
#include <QtWidgets/QVBoxLayout>
#include <QtWidgets/QWidget>
#include <klocalizedstring.h>
#include "auxiliary/nonlineardoublespinbox.h"
#include "auxiliary/qcustomplot.h"
#include "ekos/guide/guidedriftgraph.h"
#include "ekos/guide/guidetargetplot.h"

QT_BEGIN_NAMESPACE

class Ui_Guide
{
public:
    QHBoxLayout *horizontalLayout;
    QSplitter *mainSplitter;
    QWidget *layoutWidget;
    QVBoxLayout *LeftLayout;
    QHBoxLayout *trainLayout;
    QLabel *trainLabel;
    QComboBox *opticalTrainCombo;
    QPushButton *trainB;
    QGroupBox *controlGroupBox;
    QVBoxLayout *verticalLayout_4;
    QGridLayout *controlLayout;
    QPushButton *guideB;
    QCheckBox *guideDarkFrame;
    QCheckBox *guideSubframe;
    QPushButton *showFITSViewerB;
    QPushButton *loopB;
    QCheckBox *guideAutoStar;
    QPushButton *captureB;
    QPushButton *clearCalibrationB;
    QCheckBox *guideStreamingEnabled;
    QPushButton *stopB;
    QPushButton *manualDitherB;
    QPushButton *aiAssistantB;
    QGridLayout *gridLayout_6;
    QHBoxLayout *horizontalLayout_7;
    QCheckBox *eastRAGuideEnabled;
    QCheckBox *westRAGuideEnabled;
    QPushButton *externalConnectB;
    QCheckBox *dECGuideEnabled;
    NonLinearDoubleSpinBox *guideExposure;
    QLabel *label_5;
    QLabel *label_3;
    QComboBox *guideBinning;
    QPushButton *externalDisconnectB;
    QLabel *label_8;
    QLabel *label_4;
    QCheckBox *rAGuideEnabled;
    QLabel *l_9;
    QDoubleSpinBox *guideDelay;
    QHBoxLayout *horizontalLayout_10;
    QCheckBox *northDECGuideEnabled;
    QCheckBox *southDECGuideEnabled;
    QPushButton *manualPulseB;
    QDoubleSpinBox *guideGain;
    QComboBox *guideSquareSize;
    QPushButton *guideShowFrame;
    QGroupBox *infoGroupScope;
    QGridLayout *gridLayout_2;
    QLabel *l_FOV;
    QLabel *focalLengthIcon;
    QLabel *FOVIcon;
    QLabel *l_Aperture;
    QLabel *apertureIcon;
    QLabel *focalRatioIcon;
    QLabel *l_Focal;
    QLabel *l_Reducer;
    QLabel *l_FbyD;
    QLabel *reducerIcon;
    QGroupBox *infoGroup;
    QVBoxLayout *guideInfoLayout;
    QGridLayout *gridLayout;
    QLabel *l_17;
    QLabel *l_16;
    QHBoxLayout *horizontalLayout_4;
    QLabel *l_PulseRA;
    QLabel *l_PulseDEC;
    QHBoxLayout *horizontalLayout_3;
    QLabel *l_DeltaRA;
    QLabel *l_DeltaDEC;
    QLabel *l_17b;
    QHBoxLayout *horizontalLayout_4b;
    QLabel *l_ErrRA;
    QLabel *l_ErrDEC;
    QLabel *label_7;
    QLabel *l_TotalRMS;
    QLabel *label_7b;
    QLabel *l_SNR;
    QLabel *guideInfoLabel;
    QLabel *guideInfoText;
    QSpacerItem *verticalSpacer2;
    QWidget *layoutWidget_1;
    QVBoxLayout *RightLayout;
    QSplitter *rightLayout;
    QWidget *guideWidget;
    QSplitter *driftSplitter;
    QGroupBox *driftGraphicsGroup;
    QVBoxLayout *verticalLayout_2;
    QHBoxLayout *horizontalLayout_11;
    QSpacerItem *horizontalSpacer;
    GuideDriftGraph *driftGraph;
    QSpacerItem *horizontalSpacer_2;
    QSlider *correctionSlider;
    QTabWidget *tabWidget;
    QWidget *tab_2;
    QVBoxLayout *verticalLayout_7;
    GuideTargetPlot *targetPlot;
    QWidget *tab_3;
    QVBoxLayout *verticalLayout_9;
    QCustomPlot *calibrationPlot;
    QHBoxLayout *horizontalLayout_12;
    QVBoxLayout *verticalLayout_5;
    QCheckBox *rADisplayedOnGuideGraph;
    QCheckBox *rACorrDisplayedOnGuideGraph;
    QVBoxLayout *verticalLayout_8;
    QCheckBox *dEDisplayedOnGuideGraph;
    QCheckBox *dECorrDisplayedOnGuideGraph;
    QVBoxLayout *verticalLayout_8b;
    QCheckBox *sNRDisplayedOnGuideGraph;
    QCheckBox *rMSDisplayedOnGuideGraph;
    QVBoxLayout *verticalLayout_10;
    QHBoxLayout *horizontalLayout_13;
    QPushButton *guideZoomInXB;
    QPushButton *guideZoomOutXB;
    QHBoxLayout *horizontalLayout_14;
    QLabel *label_10;
    QSlider *guideSlider;
    QCheckBox *latestCheck;
    QPushButton *guideAutoScaleGraphB;
    QPushButton *guideSaveDataB;
    QPushButton *guideDataClearB;
    QDoubleSpinBox *guiderAccuracyThreshold;

    void setupUi(QWidget *Guide)
    {
        if (Guide->objectName().isEmpty())
            Guide->setObjectName("Guide");
        Guide->resize(810, 642);
        horizontalLayout = new QHBoxLayout(Guide);
        horizontalLayout->setSpacing(3);
        horizontalLayout->setObjectName("horizontalLayout");
        horizontalLayout->setContentsMargins(3, 3, 3, 3);
        mainSplitter = new QSplitter(Guide);
        mainSplitter->setObjectName("mainSplitter");
        mainSplitter->setOrientation(Qt::Orientation::Horizontal);
        layoutWidget = new QWidget(mainSplitter);
        layoutWidget->setObjectName("layoutWidget");
        LeftLayout = new QVBoxLayout(layoutWidget);
        LeftLayout->setSpacing(3);
        LeftLayout->setObjectName("LeftLayout");
        LeftLayout->setContentsMargins(0, 0, 0, 0);
        trainLayout = new QHBoxLayout();
        trainLayout->setObjectName("trainLayout");
        trainLabel = new QLabel(layoutWidget);
        trainLabel->setObjectName("trainLabel");

        trainLayout->addWidget(trainLabel);

        opticalTrainCombo = new QComboBox(layoutWidget);
        opticalTrainCombo->setObjectName("opticalTrainCombo");
        QSizePolicy sizePolicy(QSizePolicy::Policy::MinimumExpanding, QSizePolicy::Policy::Fixed);
        sizePolicy.setHorizontalStretch(0);
        sizePolicy.setVerticalStretch(0);
        sizePolicy.setHeightForWidth(opticalTrainCombo->sizePolicy().hasHeightForWidth());
        opticalTrainCombo->setSizePolicy(sizePolicy);
        opticalTrainCombo->setMinimumSize(QSize(0, 32));

        trainLayout->addWidget(opticalTrainCombo);

        trainB = new QPushButton(layoutWidget);
        trainB->setObjectName("trainB");
        trainB->setEnabled(false);
        trainB->setMinimumSize(QSize(24, 24));
        QIcon icon(QIcon::fromTheme(QString::fromUtf8("document-edit")));
        trainB->setIcon(icon);
        trainB->setIconSize(QSize(24, 24));

        trainLayout->addWidget(trainB);


        LeftLayout->addLayout(trainLayout);

        controlGroupBox = new QGroupBox(layoutWidget);
        controlGroupBox->setObjectName("controlGroupBox");
        verticalLayout_4 = new QVBoxLayout(controlGroupBox);
        verticalLayout_4->setSpacing(3);
        verticalLayout_4->setObjectName("verticalLayout_4");
        verticalLayout_4->setContentsMargins(3, 3, 3, 3);
        controlLayout = new QGridLayout();
        controlLayout->setSpacing(3);
        controlLayout->setObjectName("controlLayout");
        guideB = new QPushButton(controlGroupBox);
        guideB->setObjectName("guideB");
        guideB->setEnabled(false);
        QSizePolicy sizePolicy1(QSizePolicy::Policy::Preferred, QSizePolicy::Policy::Preferred);
        sizePolicy1.setHorizontalStretch(0);
        sizePolicy1.setVerticalStretch(0);
        sizePolicy1.setHeightForWidth(guideB->sizePolicy().hasHeightForWidth());
        guideB->setSizePolicy(sizePolicy1);
        guideB->setAutoDefault(true);

        controlLayout->addWidget(guideB, 1, 0, 2, 1);

        guideDarkFrame = new QCheckBox(controlGroupBox);
        guideDarkFrame->setObjectName("guideDarkFrame");

        controlLayout->addWidget(guideDarkFrame, 4, 1, 1, 1);

        guideSubframe = new QCheckBox(controlGroupBox);
        guideSubframe->setObjectName("guideSubframe");

        controlLayout->addWidget(guideSubframe, 1, 1, 1, 1);

        showFITSViewerB = new QPushButton(controlGroupBox);
        showFITSViewerB->setObjectName("showFITSViewerB");
        showFITSViewerB->setMinimumSize(QSize(24, 24));
        showFITSViewerB->setIconSize(QSize(24, 24));

        controlLayout->addWidget(showFITSViewerB, 0, 2, 1, 1);

        loopB = new QPushButton(controlGroupBox);
        loopB->setObjectName("loopB");

        controlLayout->addWidget(loopB, 0, 1, 1, 1);

        guideAutoStar = new QCheckBox(controlGroupBox);
        guideAutoStar->setObjectName("guideAutoStar");

        controlLayout->addWidget(guideAutoStar, 2, 1, 1, 1);

        captureB = new QPushButton(controlGroupBox);
        captureB->setObjectName("captureB");
        QSizePolicy sizePolicy2(QSizePolicy::Policy::Preferred, QSizePolicy::Policy::Fixed);
        sizePolicy2.setHorizontalStretch(0);
        sizePolicy2.setVerticalStretch(0);
        sizePolicy2.setHeightForWidth(captureB->sizePolicy().hasHeightForWidth());
        captureB->setSizePolicy(sizePolicy2);

        controlLayout->addWidget(captureB, 0, 0, 1, 1);

        clearCalibrationB = new QPushButton(controlGroupBox);
        clearCalibrationB->setObjectName("clearCalibrationB");
        clearCalibrationB->setMinimumSize(QSize(24, 24));
        QIcon icon1(QIcon::fromTheme(QString::fromUtf8("edit-delete")));
        clearCalibrationB->setIcon(icon1);
        clearCalibrationB->setIconSize(QSize(24, 24));

        controlLayout->addWidget(clearCalibrationB, 2, 2, 1, 1);

        guideStreamingEnabled = new QCheckBox(controlGroupBox);
        guideStreamingEnabled->setObjectName("guideStreamingEnabled");

        controlLayout->addWidget(guideStreamingEnabled, 3, 1, 1, 1);

        stopB = new QPushButton(controlGroupBox);
        stopB->setObjectName("stopB");
        stopB->setEnabled(false);
        sizePolicy1.setHeightForWidth(stopB->sizePolicy().hasHeightForWidth());
        stopB->setSizePolicy(sizePolicy1);

        controlLayout->addWidget(stopB, 3, 0, 2, 1);

        manualDitherB = new QPushButton(controlGroupBox);
        manualDitherB->setObjectName("manualDitherB");
        manualDitherB->setEnabled(false);
        manualDitherB->setMinimumSize(QSize(24, 24));
        QIcon icon2(QIcon::fromTheme(QString::fromUtf8("path-simplify")));
        manualDitherB->setIcon(icon2);
        manualDitherB->setIconSize(QSize(24, 24));

        controlLayout->addWidget(manualDitherB, 4, 2, 1, 1);

        aiAssistantB = new QPushButton(controlGroupBox);
        aiAssistantB->setObjectName("aiAssistantB");
        aiAssistantB->setMinimumSize(QSize(24, 24));
        QIcon icon3(QIcon::fromTheme(QString::fromUtf8("tools-wizard")));
        aiAssistantB->setIcon(icon3);
        aiAssistantB->setIconSize(QSize(24, 24));

        controlLayout->addWidget(aiAssistantB, 3, 2, 1, 1);


        verticalLayout_4->addLayout(controlLayout);

        gridLayout_6 = new QGridLayout();
        gridLayout_6->setObjectName("gridLayout_6");
        gridLayout_6->setHorizontalSpacing(1);
        gridLayout_6->setVerticalSpacing(3);
        horizontalLayout_7 = new QHBoxLayout();
        horizontalLayout_7->setSpacing(2);
        horizontalLayout_7->setObjectName("horizontalLayout_7");
        eastRAGuideEnabled = new QCheckBox(controlGroupBox);
        eastRAGuideEnabled->setObjectName("eastRAGuideEnabled");

        horizontalLayout_7->addWidget(eastRAGuideEnabled);

        westRAGuideEnabled = new QCheckBox(controlGroupBox);
        westRAGuideEnabled->setObjectName("westRAGuideEnabled");

        horizontalLayout_7->addWidget(westRAGuideEnabled);


        gridLayout_6->addLayout(horizontalLayout_7, 5, 1, 1, 1);

        externalConnectB = new QPushButton(controlGroupBox);
        externalConnectB->setObjectName("externalConnectB");
        externalConnectB->setEnabled(false);

        gridLayout_6->addWidget(externalConnectB, 6, 0, 1, 2);

        dECGuideEnabled = new QCheckBox(controlGroupBox);
        dECGuideEnabled->setObjectName("dECGuideEnabled");
        dECGuideEnabled->setStyleSheet(QString::fromUtf8(""));

        gridLayout_6->addWidget(dECGuideEnabled, 4, 2, 1, 1);

        guideExposure = new NonLinearDoubleSpinBox(controlGroupBox);
        guideExposure->setObjectName("guideExposure");
        guideExposure->setDecimals(3);
        guideExposure->setMaximum(60.000000000000000);
        guideExposure->setValue(1.000000000000000);

        gridLayout_6->addWidget(guideExposure, 1, 1, 1, 1);

        label_5 = new QLabel(controlGroupBox);
        label_5->setObjectName("label_5");

        gridLayout_6->addWidget(label_5, 2, 0, 1, 1);

        label_3 = new QLabel(controlGroupBox);
        label_3->setObjectName("label_3");

        gridLayout_6->addWidget(label_3, 1, 0, 1, 1);

        guideBinning = new QComboBox(controlGroupBox);
        guideBinning->setObjectName("guideBinning");

        gridLayout_6->addWidget(guideBinning, 2, 3, 1, 1);

        externalDisconnectB = new QPushButton(controlGroupBox);
        externalDisconnectB->setObjectName("externalDisconnectB");
        externalDisconnectB->setEnabled(false);

        gridLayout_6->addWidget(externalDisconnectB, 6, 2, 1, 2);

        label_8 = new QLabel(controlGroupBox);
        label_8->setObjectName("label_8");

        gridLayout_6->addWidget(label_8, 2, 2, 1, 1);

        label_4 = new QLabel(controlGroupBox);
        label_4->setObjectName("label_4");

        gridLayout_6->addWidget(label_4, 1, 2, 1, 1);

        rAGuideEnabled = new QCheckBox(controlGroupBox);
        rAGuideEnabled->setObjectName("rAGuideEnabled");
        rAGuideEnabled->setStyleSheet(QString::fromUtf8(""));

        gridLayout_6->addWidget(rAGuideEnabled, 4, 1, 1, 1);

        l_9 = new QLabel(controlGroupBox);
        l_9->setObjectName("l_9");

        gridLayout_6->addWidget(l_9, 4, 0, 1, 1);

        guideDelay = new QDoubleSpinBox(controlGroupBox);
        guideDelay->setObjectName("guideDelay");
        guideDelay->setMaximum(60.000000000000000);

        gridLayout_6->addWidget(guideDelay, 1, 3, 1, 1);

        horizontalLayout_10 = new QHBoxLayout();
        horizontalLayout_10->setSpacing(2);
        horizontalLayout_10->setObjectName("horizontalLayout_10");
        northDECGuideEnabled = new QCheckBox(controlGroupBox);
        northDECGuideEnabled->setObjectName("northDECGuideEnabled");

        horizontalLayout_10->addWidget(northDECGuideEnabled);

        southDECGuideEnabled = new QCheckBox(controlGroupBox);
        southDECGuideEnabled->setObjectName("southDECGuideEnabled");

        horizontalLayout_10->addWidget(southDECGuideEnabled);


        gridLayout_6->addLayout(horizontalLayout_10, 5, 2, 1, 1);

        manualPulseB = new QPushButton(controlGroupBox);
        manualPulseB->setObjectName("manualPulseB");
        QIcon icon4(QIcon::fromTheme(QString::fromUtf8("go-jump")));
        manualPulseB->setIcon(icon4);
        manualPulseB->setIconSize(QSize(24, 24));

        gridLayout_6->addWidget(manualPulseB, 4, 3, 1, 1);

        guideGain = new QDoubleSpinBox(controlGroupBox);
        guideGain->setObjectName("guideGain");
        guideGain->setDecimals(2);
        guideGain->setMaximum(10000.000000000000000);
        guideGain->setSingleStep(10.000000000000000);

        gridLayout_6->addWidget(guideGain, 2, 1, 1, 1);

        guideSquareSize = new QComboBox(controlGroupBox);
        guideSquareSize->addItem(QString());
        guideSquareSize->addItem(QString());
        guideSquareSize->addItem(QString());
        guideSquareSize->addItem(QString());
        guideSquareSize->addItem(QString());
        guideSquareSize->setObjectName("guideSquareSize");

        gridLayout_6->addWidget(guideSquareSize, 5, 0, 1, 1);

        guideShowFrame = new QPushButton(controlGroupBox);
        guideShowFrame->setObjectName("guideShowFrame");
        guideShowFrame->setEnabled(false);
        QIcon icon5(QIcon::fromTheme(QString::fromUtf8("kstars_stars")));
        guideShowFrame->setIcon(icon5);
        guideShowFrame->setIconSize(QSize(24, 24));
        guideShowFrame->setCheckable(true);
        guideShowFrame->setChecked(true);

        gridLayout_6->addWidget(guideShowFrame, 5, 3, 1, 1);


        verticalLayout_4->addLayout(gridLayout_6);


        LeftLayout->addWidget(controlGroupBox);

        infoGroupScope = new QGroupBox(layoutWidget);
        infoGroupScope->setObjectName("infoGroupScope");
        gridLayout_2 = new QGridLayout(infoGroupScope);
        gridLayout_2->setSpacing(3);
        gridLayout_2->setObjectName("gridLayout_2");
        gridLayout_2->setContentsMargins(3, 3, 3, 3);
        l_FOV = new QLabel(infoGroupScope);
        l_FOV->setObjectName("l_FOV");
        l_FOV->setScaledContents(false);
        l_FOV->setAlignment(Qt::AlignmentFlag::AlignCenter|Qt::AlignmentFlag::AlignHCenter|Qt::AlignmentFlag::AlignLeading|Qt::AlignmentFlag::AlignLeft|Qt::AlignmentFlag::AlignVCenter);

        gridLayout_2->addWidget(l_FOV, 1, 3, 1, 3);

        focalLengthIcon = new QLabel(infoGroupScope);
        focalLengthIcon->setObjectName("focalLengthIcon");
        focalLengthIcon->setMinimumSize(QSize(32, 32));
        focalLengthIcon->setMaximumSize(QSize(32, 32));

        gridLayout_2->addWidget(focalLengthIcon, 0, 0, 1, 1);

        FOVIcon = new QLabel(infoGroupScope);
        FOVIcon->setObjectName("FOVIcon");
        FOVIcon->setMinimumSize(QSize(32, 32));
        FOVIcon->setMaximumSize(QSize(32, 32));

        gridLayout_2->addWidget(FOVIcon, 1, 2, 1, 1);

        l_Aperture = new QLabel(infoGroupScope);
        l_Aperture->setObjectName("l_Aperture");
        l_Aperture->setText(QString::fromUtf8("--"));
        l_Aperture->setScaledContents(false);
        l_Aperture->setAlignment(Qt::AlignmentFlag::AlignCenter|Qt::AlignmentFlag::AlignHCenter|Qt::AlignmentFlag::AlignLeading|Qt::AlignmentFlag::AlignLeft|Qt::AlignmentFlag::AlignVCenter);

        gridLayout_2->addWidget(l_Aperture, 0, 3, 1, 1);

        apertureIcon = new QLabel(infoGroupScope);
        apertureIcon->setObjectName("apertureIcon");
        apertureIcon->setMinimumSize(QSize(32, 32));
        apertureIcon->setMaximumSize(QSize(32, 32));

        gridLayout_2->addWidget(apertureIcon, 0, 2, 1, 1);

        focalRatioIcon = new QLabel(infoGroupScope);
        focalRatioIcon->setObjectName("focalRatioIcon");
        focalRatioIcon->setMinimumSize(QSize(32, 32));
        focalRatioIcon->setMaximumSize(QSize(32, 32));

        gridLayout_2->addWidget(focalRatioIcon, 1, 0, 1, 1);

        l_Focal = new QLabel(infoGroupScope);
        l_Focal->setObjectName("l_Focal");
        l_Focal->setText(QString::fromUtf8("--"));
        l_Focal->setScaledContents(false);
        l_Focal->setAlignment(Qt::AlignmentFlag::AlignCenter|Qt::AlignmentFlag::AlignHCenter|Qt::AlignmentFlag::AlignLeading|Qt::AlignmentFlag::AlignLeft|Qt::AlignmentFlag::AlignVCenter);

        gridLayout_2->addWidget(l_Focal, 0, 1, 1, 1);

        l_Reducer = new QLabel(infoGroupScope);
        l_Reducer->setObjectName("l_Reducer");

        gridLayout_2->addWidget(l_Reducer, 0, 5, 1, 1);

        l_FbyD = new QLabel(infoGroupScope);
        l_FbyD->setObjectName("l_FbyD");
        l_FbyD->setText(QString::fromUtf8("--"));
        l_FbyD->setScaledContents(false);
        l_FbyD->setAlignment(Qt::AlignmentFlag::AlignCenter|Qt::AlignmentFlag::AlignHCenter|Qt::AlignmentFlag::AlignLeading|Qt::AlignmentFlag::AlignLeft|Qt::AlignmentFlag::AlignVCenter);

        gridLayout_2->addWidget(l_FbyD, 1, 1, 1, 1);

        reducerIcon = new QLabel(infoGroupScope);
        reducerIcon->setObjectName("reducerIcon");
        reducerIcon->setMinimumSize(QSize(32, 32));
        reducerIcon->setMaximumSize(QSize(32, 32));

        gridLayout_2->addWidget(reducerIcon, 0, 4, 1, 1);


        LeftLayout->addWidget(infoGroupScope);

        infoGroup = new QGroupBox(layoutWidget);
        infoGroup->setObjectName("infoGroup");
        guideInfoLayout = new QVBoxLayout(infoGroup);
        guideInfoLayout->setSpacing(3);
        guideInfoLayout->setObjectName("guideInfoLayout");
        guideInfoLayout->setContentsMargins(3, 3, 3, 3);
        gridLayout = new QGridLayout();
        gridLayout->setSpacing(3);
        gridLayout->setObjectName("gridLayout");
        l_17 = new QLabel(infoGroup);
        l_17->setObjectName("l_17");

        gridLayout->addWidget(l_17, 1, 0, 1, 1);

        l_16 = new QLabel(infoGroup);
        l_16->setObjectName("l_16");

        gridLayout->addWidget(l_16, 0, 0, 1, 1);

        horizontalLayout_4 = new QHBoxLayout();
        horizontalLayout_4->setSpacing(1);
        horizontalLayout_4->setObjectName("horizontalLayout_4");
        l_PulseRA = new QLabel(infoGroup);
        l_PulseRA->setObjectName("l_PulseRA");
        l_PulseRA->setText(QString::fromUtf8("xxx"));
        l_PulseRA->setAlignment(Qt::AlignmentFlag::AlignCenter|Qt::AlignmentFlag::AlignHCenter|Qt::AlignmentFlag::AlignLeading|Qt::AlignmentFlag::AlignLeft|Qt::AlignmentFlag::AlignVCenter);

        horizontalLayout_4->addWidget(l_PulseRA);

        l_PulseDEC = new QLabel(infoGroup);
        l_PulseDEC->setObjectName("l_PulseDEC");
        l_PulseDEC->setText(QString::fromUtf8("xxx"));
        l_PulseDEC->setAlignment(Qt::AlignmentFlag::AlignCenter|Qt::AlignmentFlag::AlignHCenter|Qt::AlignmentFlag::AlignLeading|Qt::AlignmentFlag::AlignLeft|Qt::AlignmentFlag::AlignVCenter);

        horizontalLayout_4->addWidget(l_PulseDEC);


        gridLayout->addLayout(horizontalLayout_4, 1, 1, 1, 1);

        horizontalLayout_3 = new QHBoxLayout();
        horizontalLayout_3->setSpacing(1);
        horizontalLayout_3->setObjectName("horizontalLayout_3");
        l_DeltaRA = new QLabel(infoGroup);
        l_DeltaRA->setObjectName("l_DeltaRA");
        l_DeltaRA->setText(QString::fromUtf8("xxx"));
        l_DeltaRA->setAlignment(Qt::AlignmentFlag::AlignCenter|Qt::AlignmentFlag::AlignHCenter|Qt::AlignmentFlag::AlignLeading|Qt::AlignmentFlag::AlignLeft|Qt::AlignmentFlag::AlignVCenter);

        horizontalLayout_3->addWidget(l_DeltaRA);

        l_DeltaDEC = new QLabel(infoGroup);
        l_DeltaDEC->setObjectName("l_DeltaDEC");
        l_DeltaDEC->setText(QString::fromUtf8("xxx"));
        l_DeltaDEC->setAlignment(Qt::AlignmentFlag::AlignCenter|Qt::AlignmentFlag::AlignHCenter|Qt::AlignmentFlag::AlignLeading|Qt::AlignmentFlag::AlignLeft|Qt::AlignmentFlag::AlignVCenter);

        horizontalLayout_3->addWidget(l_DeltaDEC);


        gridLayout->addLayout(horizontalLayout_3, 0, 1, 1, 1);

        l_17b = new QLabel(infoGroup);
        l_17b->setObjectName("l_17b");

        gridLayout->addWidget(l_17b, 2, 0, 1, 1);

        horizontalLayout_4b = new QHBoxLayout();
        horizontalLayout_4b->setSpacing(1);
        horizontalLayout_4b->setObjectName("horizontalLayout_4b");
        l_ErrRA = new QLabel(infoGroup);
        l_ErrRA->setObjectName("l_ErrRA");
        l_ErrRA->setText(QString::fromUtf8("xxx"));
        l_ErrRA->setAlignment(Qt::AlignmentFlag::AlignCenter|Qt::AlignmentFlag::AlignHCenter|Qt::AlignmentFlag::AlignLeading|Qt::AlignmentFlag::AlignLeft|Qt::AlignmentFlag::AlignVCenter);

        horizontalLayout_4b->addWidget(l_ErrRA);

        l_ErrDEC = new QLabel(infoGroup);
        l_ErrDEC->setObjectName("l_ErrDEC");
        l_ErrDEC->setText(QString::fromUtf8("xxx"));
        l_ErrDEC->setAlignment(Qt::AlignmentFlag::AlignCenter|Qt::AlignmentFlag::AlignHCenter|Qt::AlignmentFlag::AlignLeading|Qt::AlignmentFlag::AlignLeft|Qt::AlignmentFlag::AlignVCenter);

        horizontalLayout_4b->addWidget(l_ErrDEC);


        gridLayout->addLayout(horizontalLayout_4b, 2, 1, 1, 1);

        label_7 = new QLabel(infoGroup);
        label_7->setObjectName("label_7");
        label_7->setAlignment(Qt::AlignmentFlag::AlignLeading|Qt::AlignmentFlag::AlignLeft|Qt::AlignmentFlag::AlignVCenter);

        gridLayout->addWidget(label_7, 3, 0, 1, 1);

        l_TotalRMS = new QLabel(infoGroup);
        l_TotalRMS->setObjectName("l_TotalRMS");
        l_TotalRMS->setAlignment(Qt::AlignmentFlag::AlignCenter);

        gridLayout->addWidget(l_TotalRMS, 3, 1, 1, 1);

        label_7b = new QLabel(infoGroup);
        label_7b->setObjectName("label_7b");
        label_7b->setAlignment(Qt::AlignmentFlag::AlignLeading|Qt::AlignmentFlag::AlignLeft|Qt::AlignmentFlag::AlignVCenter);

        gridLayout->addWidget(label_7b, 4, 0, 1, 1);

        l_SNR = new QLabel(infoGroup);
        l_SNR->setObjectName("l_SNR");
        l_SNR->setAlignment(Qt::AlignmentFlag::AlignCenter);

        gridLayout->addWidget(l_SNR, 4, 1, 1, 1);

        guideInfoLabel = new QLabel(infoGroup);
        guideInfoLabel->setObjectName("guideInfoLabel");
        guideInfoLabel->setAlignment(Qt::AlignmentFlag::AlignLeading|Qt::AlignmentFlag::AlignLeft|Qt::AlignmentFlag::AlignVCenter);

        gridLayout->addWidget(guideInfoLabel, 5, 0, 1, 1);

        guideInfoText = new QLabel(infoGroup);
        guideInfoText->setObjectName("guideInfoText");
        guideInfoText->setAlignment(Qt::AlignmentFlag::AlignCenter);

        gridLayout->addWidget(guideInfoText, 5, 1, 1, 1);

        gridLayout->setColumnStretch(1, 1);

        guideInfoLayout->addLayout(gridLayout);

        verticalSpacer2 = new QSpacerItem(20, 40, QSizePolicy::Policy::Minimum, QSizePolicy::Policy::Expanding);

        guideInfoLayout->addItem(verticalSpacer2);


        LeftLayout->addWidget(infoGroup);

        mainSplitter->addWidget(layoutWidget);
        layoutWidget_1 = new QWidget(mainSplitter);
        layoutWidget_1->setObjectName("layoutWidget_1");
        RightLayout = new QVBoxLayout(layoutWidget_1);
        RightLayout->setSpacing(1);
        RightLayout->setObjectName("RightLayout");
        RightLayout->setContentsMargins(0, 0, 0, 0);
        rightLayout = new QSplitter(layoutWidget_1);
        rightLayout->setObjectName("rightLayout");
        QSizePolicy sizePolicy3(QSizePolicy::Policy::Expanding, QSizePolicy::Policy::Expanding);
        sizePolicy3.setHorizontalStretch(0);
        sizePolicy3.setVerticalStretch(0);
        sizePolicy3.setHeightForWidth(rightLayout->sizePolicy().hasHeightForWidth());
        rightLayout->setSizePolicy(sizePolicy3);
        rightLayout->setOrientation(Qt::Orientation::Vertical);
        guideWidget = new QWidget(rightLayout);
        guideWidget->setObjectName("guideWidget");
        sizePolicy3.setHeightForWidth(guideWidget->sizePolicy().hasHeightForWidth());
        guideWidget->setSizePolicy(sizePolicy3);
        guideWidget->setMinimumSize(QSize(320, 240));
        guideWidget->setSizeIncrement(QSize(40, 30));
        rightLayout->addWidget(guideWidget);
        driftSplitter = new QSplitter(rightLayout);
        driftSplitter->setObjectName("driftSplitter");
        driftSplitter->setOrientation(Qt::Orientation::Horizontal);
        driftGraphicsGroup = new QGroupBox(driftSplitter);
        driftGraphicsGroup->setObjectName("driftGraphicsGroup");
        QSizePolicy sizePolicy4(QSizePolicy::Policy::Expanding, QSizePolicy::Policy::Preferred);
        sizePolicy4.setHorizontalStretch(2);
        sizePolicy4.setVerticalStretch(2);
        sizePolicy4.setHeightForWidth(driftGraphicsGroup->sizePolicy().hasHeightForWidth());
        driftGraphicsGroup->setSizePolicy(sizePolicy4);
        verticalLayout_2 = new QVBoxLayout(driftGraphicsGroup);
        verticalLayout_2->setSpacing(1);
        verticalLayout_2->setObjectName("verticalLayout_2");
        verticalLayout_2->setContentsMargins(3, 3, 3, 3);
        horizontalLayout_11 = new QHBoxLayout();
        horizontalLayout_11->setSpacing(0);
        horizontalLayout_11->setObjectName("horizontalLayout_11");
        horizontalSpacer = new QSpacerItem(1, 20, QSizePolicy::Policy::Minimum, QSizePolicy::Policy::Minimum);

        horizontalLayout_11->addItem(horizontalSpacer);

        driftGraph = new GuideDriftGraph(driftGraphicsGroup);
        driftGraph->setObjectName("driftGraph");
        driftGraph->setMinimumSize(QSize(200, 200));
        driftGraph->setMaximumSize(QSize(16777215, 16777215));

        horizontalLayout_11->addWidget(driftGraph);

        horizontalSpacer_2 = new QSpacerItem(1, 20, QSizePolicy::Policy::Minimum, QSizePolicy::Policy::Minimum);

        horizontalLayout_11->addItem(horizontalSpacer_2);

        correctionSlider = new QSlider(driftGraphicsGroup);
        correctionSlider->setObjectName("correctionSlider");
        correctionSlider->setMinimum(1);
        correctionSlider->setMaximum(500);
        correctionSlider->setPageStep(200);
        correctionSlider->setValue(50);
        correctionSlider->setOrientation(Qt::Orientation::Vertical);
        correctionSlider->setInvertedAppearance(true);
        correctionSlider->setInvertedControls(false);

        horizontalLayout_11->addWidget(correctionSlider);


        verticalLayout_2->addLayout(horizontalLayout_11);

        driftSplitter->addWidget(driftGraphicsGroup);
        tabWidget = new QTabWidget(driftSplitter);
        tabWidget->setObjectName("tabWidget");
        sizePolicy1.setHeightForWidth(tabWidget->sizePolicy().hasHeightForWidth());
        tabWidget->setSizePolicy(sizePolicy1);
        tabWidget->setMinimumSize(QSize(225, 200));
        tab_2 = new QWidget();
        tab_2->setObjectName("tab_2");
        verticalLayout_7 = new QVBoxLayout(tab_2);
        verticalLayout_7->setObjectName("verticalLayout_7");
        verticalLayout_7->setContentsMargins(0, 0, 0, 0);
        targetPlot = new GuideTargetPlot(tab_2);
        targetPlot->setObjectName("targetPlot");
        sizePolicy3.setHeightForWidth(targetPlot->sizePolicy().hasHeightForWidth());
        targetPlot->setSizePolicy(sizePolicy3);
        targetPlot->setMinimumSize(QSize(200, 200));

        verticalLayout_7->addWidget(targetPlot);

        tabWidget->addTab(tab_2, QString());
        tab_3 = new QWidget();
        tab_3->setObjectName("tab_3");
        verticalLayout_9 = new QVBoxLayout(tab_3);
        verticalLayout_9->setObjectName("verticalLayout_9");
        verticalLayout_9->setContentsMargins(0, 0, 0, 0);
        calibrationPlot = new QCustomPlot(tab_3);
        calibrationPlot->setObjectName("calibrationPlot");
        sizePolicy3.setHeightForWidth(calibrationPlot->sizePolicy().hasHeightForWidth());
        calibrationPlot->setSizePolicy(sizePolicy3);
        calibrationPlot->setMinimumSize(QSize(200, 200));

        verticalLayout_9->addWidget(calibrationPlot);

        tabWidget->addTab(tab_3, QString());
        driftSplitter->addWidget(tabWidget);
        rightLayout->addWidget(driftSplitter);

        RightLayout->addWidget(rightLayout);

        horizontalLayout_12 = new QHBoxLayout();
        horizontalLayout_12->setSpacing(3);
        horizontalLayout_12->setObjectName("horizontalLayout_12");
        horizontalLayout_12->setContentsMargins(-1, 0, -1, -1);
        verticalLayout_5 = new QVBoxLayout();
        verticalLayout_5->setSpacing(2);
        verticalLayout_5->setObjectName("verticalLayout_5");
        verticalLayout_5->setContentsMargins(0, -1, -1, -1);
        rADisplayedOnGuideGraph = new QCheckBox(layoutWidget_1);
        rADisplayedOnGuideGraph->setObjectName("rADisplayedOnGuideGraph");
        rADisplayedOnGuideGraph->setChecked(true);

        verticalLayout_5->addWidget(rADisplayedOnGuideGraph);

        rACorrDisplayedOnGuideGraph = new QCheckBox(layoutWidget_1);
        rACorrDisplayedOnGuideGraph->setObjectName("rACorrDisplayedOnGuideGraph");

        verticalLayout_5->addWidget(rACorrDisplayedOnGuideGraph);


        horizontalLayout_12->addLayout(verticalLayout_5);

        verticalLayout_8 = new QVBoxLayout();
        verticalLayout_8->setSpacing(2);
        verticalLayout_8->setObjectName("verticalLayout_8");
        verticalLayout_8->setContentsMargins(0, -1, -1, -1);
        dEDisplayedOnGuideGraph = new QCheckBox(layoutWidget_1);
        dEDisplayedOnGuideGraph->setObjectName("dEDisplayedOnGuideGraph");
        dEDisplayedOnGuideGraph->setChecked(true);

        verticalLayout_8->addWidget(dEDisplayedOnGuideGraph);

        dECorrDisplayedOnGuideGraph = new QCheckBox(layoutWidget_1);
        dECorrDisplayedOnGuideGraph->setObjectName("dECorrDisplayedOnGuideGraph");

        verticalLayout_8->addWidget(dECorrDisplayedOnGuideGraph);


        horizontalLayout_12->addLayout(verticalLayout_8);

        verticalLayout_8b = new QVBoxLayout();
        verticalLayout_8b->setSpacing(2);
        verticalLayout_8b->setObjectName("verticalLayout_8b");
        verticalLayout_8b->setContentsMargins(0, -1, -1, -1);
        sNRDisplayedOnGuideGraph = new QCheckBox(layoutWidget_1);
        sNRDisplayedOnGuideGraph->setObjectName("sNRDisplayedOnGuideGraph");
        sNRDisplayedOnGuideGraph->setChecked(true);

        verticalLayout_8b->addWidget(sNRDisplayedOnGuideGraph);

        rMSDisplayedOnGuideGraph = new QCheckBox(layoutWidget_1);
        rMSDisplayedOnGuideGraph->setObjectName("rMSDisplayedOnGuideGraph");
        rMSDisplayedOnGuideGraph->setChecked(true);

        verticalLayout_8b->addWidget(rMSDisplayedOnGuideGraph);


        horizontalLayout_12->addLayout(verticalLayout_8b);

        verticalLayout_10 = new QVBoxLayout();
        verticalLayout_10->setSpacing(2);
        verticalLayout_10->setObjectName("verticalLayout_10");
        verticalLayout_10->setContentsMargins(0, -1, -1, -1);
        horizontalLayout_13 = new QHBoxLayout();
        horizontalLayout_13->setSpacing(3);
        horizontalLayout_13->setObjectName("horizontalLayout_13");
        horizontalLayout_13->setContentsMargins(-1, 0, -1, -1);
        guideZoomInXB = new QPushButton(layoutWidget_1);
        guideZoomInXB->setObjectName("guideZoomInXB");
        guideZoomInXB->setMinimumSize(QSize(24, 24));
        QFont font;
        font.setPointSize(16);
        font.setBold(true);
        guideZoomInXB->setFont(font);
        guideZoomInXB->setIconSize(QSize(24, 24));

        horizontalLayout_13->addWidget(guideZoomInXB);

        guideZoomOutXB = new QPushButton(layoutWidget_1);
        guideZoomOutXB->setObjectName("guideZoomOutXB");
        guideZoomOutXB->setMinimumSize(QSize(24, 24));
        guideZoomOutXB->setFont(font);
        guideZoomOutXB->setIconSize(QSize(24, 24));

        horizontalLayout_13->addWidget(guideZoomOutXB);


        verticalLayout_10->addLayout(horizontalLayout_13);

        horizontalLayout_14 = new QHBoxLayout();
        horizontalLayout_14->setSpacing(3);
        horizontalLayout_14->setObjectName("horizontalLayout_14");
        horizontalLayout_14->setContentsMargins(-1, 0, -1, -1);
        label_10 = new QLabel(layoutWidget_1);
        label_10->setObjectName("label_10");

        horizontalLayout_14->addWidget(label_10);

        guideSlider = new QSlider(layoutWidget_1);
        guideSlider->setObjectName("guideSlider");
        guideSlider->setMaximum(10);
        guideSlider->setValue(10);
        guideSlider->setOrientation(Qt::Orientation::Horizontal);

        horizontalLayout_14->addWidget(guideSlider);

        latestCheck = new QCheckBox(layoutWidget_1);
        latestCheck->setObjectName("latestCheck");
        latestCheck->setChecked(true);

        horizontalLayout_14->addWidget(latestCheck);


        verticalLayout_10->addLayout(horizontalLayout_14);


        horizontalLayout_12->addLayout(verticalLayout_10);

        guideAutoScaleGraphB = new QPushButton(layoutWidget_1);
        guideAutoScaleGraphB->setObjectName("guideAutoScaleGraphB");
        guideAutoScaleGraphB->setMinimumSize(QSize(24, 24));
        guideAutoScaleGraphB->setIconSize(QSize(24, 24));

        horizontalLayout_12->addWidget(guideAutoScaleGraphB);

        guideSaveDataB = new QPushButton(layoutWidget_1);
        guideSaveDataB->setObjectName("guideSaveDataB");
        guideSaveDataB->setMinimumSize(QSize(24, 24));
        guideSaveDataB->setIconSize(QSize(24, 24));

        horizontalLayout_12->addWidget(guideSaveDataB);

        guideDataClearB = new QPushButton(layoutWidget_1);
        guideDataClearB->setObjectName("guideDataClearB");
        guideDataClearB->setMinimumSize(QSize(24, 24));
        guideDataClearB->setIconSize(QSize(24, 24));

        horizontalLayout_12->addWidget(guideDataClearB);

        guiderAccuracyThreshold = new QDoubleSpinBox(layoutWidget_1);
        guiderAccuracyThreshold->setObjectName("guiderAccuracyThreshold");
        guiderAccuracyThreshold->setDecimals(1);
        guiderAccuracyThreshold->setMaximum(20.000000000000000);
        guiderAccuracyThreshold->setSingleStep(0.500000000000000);
        guiderAccuracyThreshold->setValue(2.000000000000000);

        horizontalLayout_12->addWidget(guiderAccuracyThreshold);


        RightLayout->addLayout(horizontalLayout_12);

        RightLayout->setStretch(0, 2);
        mainSplitter->addWidget(layoutWidget_1);

        horizontalLayout->addWidget(mainSplitter);

        QWidget::setTabOrder(opticalTrainCombo, trainB);
        QWidget::setTabOrder(trainB, captureB);
        QWidget::setTabOrder(captureB, loopB);
        QWidget::setTabOrder(loopB, showFITSViewerB);
        QWidget::setTabOrder(showFITSViewerB, guideB);
        QWidget::setTabOrder(guideB, guideSubframe);
        QWidget::setTabOrder(guideSubframe, guideAutoStar);
        QWidget::setTabOrder(guideAutoStar, clearCalibrationB);
        QWidget::setTabOrder(clearCalibrationB, aiAssistantB);
        QWidget::setTabOrder(aiAssistantB, stopB);
        QWidget::setTabOrder(stopB, guideDarkFrame);
        QWidget::setTabOrder(guideDarkFrame, manualDitherB);
        QWidget::setTabOrder(manualDitherB, guideExposure);
        QWidget::setTabOrder(guideExposure, guideDelay);
        QWidget::setTabOrder(guideDelay, guideGain);
        QWidget::setTabOrder(guideGain, guideBinning);
        QWidget::setTabOrder(guideBinning, rAGuideEnabled);
        QWidget::setTabOrder(rAGuideEnabled, dECGuideEnabled);
        QWidget::setTabOrder(dECGuideEnabled, manualPulseB);
        QWidget::setTabOrder(manualPulseB, guideSquareSize);
        QWidget::setTabOrder(guideSquareSize, eastRAGuideEnabled);
        QWidget::setTabOrder(eastRAGuideEnabled, westRAGuideEnabled);
        QWidget::setTabOrder(westRAGuideEnabled, northDECGuideEnabled);
        QWidget::setTabOrder(northDECGuideEnabled, southDECGuideEnabled);
        QWidget::setTabOrder(southDECGuideEnabled, externalConnectB);
        QWidget::setTabOrder(externalConnectB, externalDisconnectB);
        QWidget::setTabOrder(externalDisconnectB, rADisplayedOnGuideGraph);
        QWidget::setTabOrder(rADisplayedOnGuideGraph, dEDisplayedOnGuideGraph);
        QWidget::setTabOrder(dEDisplayedOnGuideGraph, sNRDisplayedOnGuideGraph);
        QWidget::setTabOrder(sNRDisplayedOnGuideGraph, guideZoomInXB);
        QWidget::setTabOrder(guideZoomInXB, rACorrDisplayedOnGuideGraph);
        QWidget::setTabOrder(rACorrDisplayedOnGuideGraph, dECorrDisplayedOnGuideGraph);
        QWidget::setTabOrder(dECorrDisplayedOnGuideGraph, rMSDisplayedOnGuideGraph);
        QWidget::setTabOrder(rMSDisplayedOnGuideGraph, guideSlider);
        QWidget::setTabOrder(guideSlider, guideZoomOutXB);
        QWidget::setTabOrder(guideZoomOutXB, latestCheck);
        QWidget::setTabOrder(latestCheck, guideAutoScaleGraphB);
        QWidget::setTabOrder(guideAutoScaleGraphB, guideSaveDataB);
        QWidget::setTabOrder(guideSaveDataB, guideDataClearB);
        QWidget::setTabOrder(guideDataClearB, guiderAccuracyThreshold);
        QWidget::setTabOrder(guiderAccuracyThreshold, correctionSlider);
        QWidget::setTabOrder(correctionSlider, tabWidget);

        retranslateUi(Guide);

        guideB->setDefault(true);
        tabWidget->setCurrentIndex(0);


        QMetaObject::connectSlotsByName(Guide);
    } // setupUi

    void retranslateUi(QWidget *Guide)
    {
        trainLabel->setText(tr2i18n("Train:", nullptr));
        trainB->setText(QString());
        controlGroupBox->setTitle(tr2i18n("Control", nullptr));
        guideB->setText(tr2i18n("Guide", nullptr));
#if QT_CONFIG(tooltip)
        guideDarkFrame->setToolTip(tr2i18n("<html><head/><body><p>Subtract dark frame. Create dark frames or defect maps in the Dark Library tool in the capture module.</p></body></html>", nullptr));
#endif // QT_CONFIG(tooltip)
        guideDarkFrame->setText(tr2i18n("Dark", nullptr));
#if QT_CONFIG(tooltip)
        guideSubframe->setToolTip(tr2i18n("<html><head/><body><p>Subframe the image around the guide star. Or for PHD2, receive the Guide Star Image instead of the full image frame. For the Internal Guider, before checking this option, you must <span style=\" font-weight:600;\">first</span> capture an image and select a guide star. Uncheck it to take a full frame again. <br/>Please note: 'SEP Multi Star' <span style=\" font-weight:600;\">cannot</span> use subframe.</p></body></html>", nullptr));
#endif // QT_CONFIG(tooltip)
        guideSubframe->setText(tr2i18n("Subframe", nullptr));
#if QT_CONFIG(tooltip)
        showFITSViewerB->setToolTip(tr2i18n("Show in FITS Viewer...", nullptr));
#endif // QT_CONFIG(tooltip)
        showFITSViewerB->setText(QString());
        loopB->setText(tr2i18n("Loop", nullptr));
#if QT_CONFIG(tooltip)
        guideAutoStar->setToolTip(tr2i18n("<html><head/><body><p>Automatically select the calibration star. <br/>Please note: 'SEP Multi Star' does  <span style=\" font-weight:600;\">always</span> use 'auto star' detection.</p></body></html>", nullptr));
#endif // QT_CONFIG(tooltip)
        guideAutoStar->setText(tr2i18n("Auto Star", nullptr));
        captureB->setText(tr2i18n("Capture", nullptr));
#if QT_CONFIG(tooltip)
        clearCalibrationB->setToolTip(tr2i18n("Clear calibration data.", nullptr));
#endif // QT_CONFIG(tooltip)
        clearCalibrationB->setText(QString());
#if QT_CONFIG(tooltip)
        guideStreamingEnabled->setToolTip(tr2i18n("<html><head/><body><p>Enable streaming guide mode. When checked and the camera supports video streaming, the guide module captures frames via a continuous video stream instead of individual exposures. This significantly reduces per-frame overhead and enables higher guiding frequencies (e.g. 2\342\200\2235 Hz) required by harmonic drives. Not compatible with dark-frame subtraction.</p></body></html>", nullptr));
#endif // QT_CONFIG(tooltip)
        guideStreamingEnabled->setText(tr2i18n("Stream", nullptr));
        stopB->setText(tr2i18n("Stop", nullptr));
#if QT_CONFIG(tooltip)
        manualDitherB->setToolTip(tr2i18n("Manual Dither", nullptr));
#endif // QT_CONFIG(tooltip)
        manualDitherB->setText(QString());
#if QT_CONFIG(tooltip)
        aiAssistantB->setToolTip(tr2i18n("<html><head/><body><p><b>AI Guiding (Experimental)</b></p><p>Open the AI Guiding Assistant, or load trained weights.</p></body></html>", nullptr));
#endif // QT_CONFIG(tooltip)
        aiAssistantB->setText(QString());
#if QT_CONFIG(tooltip)
        eastRAGuideEnabled->setToolTip(tr2i18n("East Direction Guiding", nullptr));
#endif // QT_CONFIG(tooltip)
        eastRAGuideEnabled->setText(tr2i18n("+", nullptr));
#if QT_CONFIG(tooltip)
        westRAGuideEnabled->setToolTip(tr2i18n("West Direction Guiding", nullptr));
#endif // QT_CONFIG(tooltip)
        westRAGuideEnabled->setText(tr2i18n("-", nullptr));
#if QT_CONFIG(tooltip)
        externalConnectB->setToolTip(tr2i18n("Connect to external guiding application.", nullptr));
#endif // QT_CONFIG(tooltip)
        externalConnectB->setText(tr2i18n("Connect", nullptr));
#if QT_CONFIG(tooltip)
        dECGuideEnabled->setToolTip(tr2i18n("Guide Declination Axis", nullptr));
#endif // QT_CONFIG(tooltip)
        dECGuideEnabled->setText(tr2i18n("DEC", nullptr));
#if QT_CONFIG(tooltip)
        label_5->setToolTip(tr2i18n("Camera Gain", nullptr));
#endif // QT_CONFIG(tooltip)
        label_5->setText(tr2i18n("Gain:", nullptr));
#if QT_CONFIG(tooltip)
        label_3->setToolTip(tr2i18n("Exposure time in seconds", nullptr));
#endif // QT_CONFIG(tooltip)
        label_3->setText(tr2i18n("Exp:", nullptr));
#if QT_CONFIG(tooltip)
        guideBinning->setToolTip(tr2i18n("Guide camera binning. It is recommended to set binning to 2x2 or higher.", nullptr));
#endif // QT_CONFIG(tooltip)
#if QT_CONFIG(tooltip)
        externalDisconnectB->setToolTip(tr2i18n("Disconnect from external guiding application.", nullptr));
#endif // QT_CONFIG(tooltip)
        externalDisconnectB->setText(tr2i18n("Disconnect", nullptr));
#if QT_CONFIG(tooltip)
        label_8->setToolTip(QString());
#endif // QT_CONFIG(tooltip)
        label_8->setText(tr2i18n("Bin:", nullptr));
#if QT_CONFIG(tooltip)
        label_4->setToolTip(QString());
#endif // QT_CONFIG(tooltip)
        label_4->setText(tr2i18n("Delay:", nullptr));
#if QT_CONFIG(tooltip)
        rAGuideEnabled->setToolTip(tr2i18n("Guide Right Ascention Axis", nullptr));
#endif // QT_CONFIG(tooltip)
        rAGuideEnabled->setText(tr2i18n("RA", nullptr));
        l_9->setText(tr2i18n("Directions:", nullptr));
#if QT_CONFIG(tooltip)
        guideDelay->setToolTip(tr2i18n("Delay next guide exposure this many seconds after a pulse is sent", nullptr));
#endif // QT_CONFIG(tooltip)
#if QT_CONFIG(tooltip)
        northDECGuideEnabled->setToolTip(tr2i18n("North Direction Guiding", nullptr));
#endif // QT_CONFIG(tooltip)
        northDECGuideEnabled->setText(tr2i18n("+", nullptr));
#if QT_CONFIG(tooltip)
        southDECGuideEnabled->setToolTip(tr2i18n("South Direction Guiding", nullptr));
#endif // QT_CONFIG(tooltip)
        southDECGuideEnabled->setText(tr2i18n("-", nullptr));
#if QT_CONFIG(tooltip)
        manualPulseB->setToolTip(tr2i18n("Manual Pulse...", nullptr));
#endif // QT_CONFIG(tooltip)
        manualPulseB->setText(QString());
        guideSquareSize->setItemText(0, tr2i18n("8", nullptr));
        guideSquareSize->setItemText(1, tr2i18n("16", nullptr));
        guideSquareSize->setItemText(2, tr2i18n("32", nullptr));
        guideSquareSize->setItemText(3, tr2i18n("64", nullptr));
        guideSquareSize->setItemText(4, tr2i18n("128", nullptr));

#if QT_CONFIG(tooltip)
        guideSquareSize->setToolTip(tr2i18n("Guide star tracking box size. Box size must be set in accordance to the selected star size.", nullptr));
#endif // QT_CONFIG(tooltip)
#if QT_CONFIG(tooltip)
        guideShowFrame->setToolTip(tr2i18n("Toggle the Guider Image...", nullptr));
#endif // QT_CONFIG(tooltip)
        guideShowFrame->setText(QString());
        infoGroupScope->setTitle(tr2i18n("Scope / Lens Info", nullptr));
#if QT_CONFIG(tooltip)
        l_FOV->setToolTip(tr2i18n("Field of View (arcmin)", nullptr));
#endif // QT_CONFIG(tooltip)
        l_FOV->setText(tr2i18n("--", nullptr));
        focalLengthIcon->setText(QString());
        FOVIcon->setText(QString());
#if QT_CONFIG(tooltip)
        l_Aperture->setToolTip(tr2i18n("Aperture (mm)", nullptr));
#endif // QT_CONFIG(tooltip)
        apertureIcon->setText(QString());
        focalRatioIcon->setText(QString());
#if QT_CONFIG(tooltip)
        l_Focal->setToolTip(tr2i18n("Focal Length (mm)", nullptr));
#endif // QT_CONFIG(tooltip)
#if QT_CONFIG(tooltip)
        l_Reducer->setToolTip(tr2i18n("Reducer", nullptr));
#endif // QT_CONFIG(tooltip)
        l_Reducer->setText(tr2i18n("--", nullptr));
#if QT_CONFIG(tooltip)
        l_FbyD->setToolTip(tr2i18n("Focal Ratio", nullptr));
#endif // QT_CONFIG(tooltip)
        reducerIcon->setText(QString());
        infoGroup->setTitle(tr2i18n("Guide Info", nullptr));
        l_17->setText(tr2i18n("Pulse length (ms):", nullptr));
        l_16->setText(tr2i18n("Guiding delta \":", nullptr));
#if QT_CONFIG(tooltip)
        l_PulseRA->setToolTip(tr2i18n("Generated RA pulse", nullptr));
#endif // QT_CONFIG(tooltip)
#if QT_CONFIG(tooltip)
        l_PulseDEC->setToolTip(tr2i18n("Generated DEC pulse", nullptr));
#endif // QT_CONFIG(tooltip)
#if QT_CONFIG(tooltip)
        l_DeltaRA->setToolTip(tr2i18n("Immediate Guiding RA deviation in arcseconds", nullptr));
#endif // QT_CONFIG(tooltip)
#if QT_CONFIG(tooltip)
        l_DeltaDEC->setToolTip(tr2i18n("Immediate Guiding DEC deviation in arcseconds", nullptr));
#endif // QT_CONFIG(tooltip)
#if QT_CONFIG(tooltip)
        l_17b->setToolTip(tr2i18n("Guiding RMS error", nullptr));
#endif // QT_CONFIG(tooltip)
        l_17b->setText(tr2i18n("RMS\" (RA/DEC):", nullptr));
#if QT_CONFIG(tooltip)
        l_ErrRA->setToolTip(tr2i18n("Guiding RA RMS error", nullptr));
#endif // QT_CONFIG(tooltip)
#if QT_CONFIG(tooltip)
        l_ErrDEC->setToolTip(tr2i18n("Guiding DEC RMS error", nullptr));
#endif // QT_CONFIG(tooltip)
        label_7->setText(tr2i18n("Total RMS\":", nullptr));
        l_TotalRMS->setText(tr2i18n("xxx", nullptr));
        label_7b->setText(tr2i18n("Guide SNR:", nullptr));
        l_SNR->setText(tr2i18n("xxx", nullptr));
        guideInfoLabel->setText(QString());
        guideInfoText->setText(QString());
        driftGraphicsGroup->setTitle(QString());
#if QT_CONFIG(tooltip)
        correctionSlider->setToolTip(tr2i18n("<html><head/><body><p>Drag the slider to adjust the scale of the Corrections Graphs relative to the scale of the drift graphs.</p></body></html>", nullptr));
#endif // QT_CONFIG(tooltip)
        tabWidget->setTabText(tabWidget->indexOf(tab_2), tr2i18n("Mount Drift", nullptr));
        tabWidget->setTabText(tabWidget->indexOf(tab_3), tr2i18n("Calibration Plot", nullptr));
#if QT_CONFIG(tooltip)
        rADisplayedOnGuideGraph->setToolTip(tr2i18n("<html><head/><body><p>Display the RA graph in the Drift Graphics plot.</p></body></html>", nullptr));
#endif // QT_CONFIG(tooltip)
        rADisplayedOnGuideGraph->setText(tr2i18n("RA ", nullptr));
#if QT_CONFIG(tooltip)
        rACorrDisplayedOnGuideGraph->setToolTip(tr2i18n("<html><head/><body><p>Display the RA Corrections graph in the Drift Graphics plot.</p></body></html>", nullptr));
#endif // QT_CONFIG(tooltip)
        rACorrDisplayedOnGuideGraph->setText(tr2i18n("Corr", nullptr));
#if QT_CONFIG(tooltip)
        dEDisplayedOnGuideGraph->setToolTip(tr2i18n("<html><head/><body><p>Display DEC graph in the Drift Graphics plot.</p></body></html>", nullptr));
#endif // QT_CONFIG(tooltip)
        dEDisplayedOnGuideGraph->setText(tr2i18n("DEC", nullptr));
#if QT_CONFIG(tooltip)
        dECorrDisplayedOnGuideGraph->setToolTip(tr2i18n("<html><head/><body><p>Display the DEC Corrections graph in the Drift Graphics plot.</p></body></html>", nullptr));
#endif // QT_CONFIG(tooltip)
        dECorrDisplayedOnGuideGraph->setText(tr2i18n("Corr", nullptr));
#if QT_CONFIG(tooltip)
        sNRDisplayedOnGuideGraph->setToolTip(tr2i18n("<html><head/><body><p>Display SNR graph in the Drift Graphics plot.</p></body></html>", nullptr));
#endif // QT_CONFIG(tooltip)
        sNRDisplayedOnGuideGraph->setText(tr2i18n("SNR", nullptr));
#if QT_CONFIG(tooltip)
        rMSDisplayedOnGuideGraph->setToolTip(tr2i18n("<html><head/><body><p>Display RMS graph in the Drift Graphics plot.</p></body></html>", nullptr));
#endif // QT_CONFIG(tooltip)
        rMSDisplayedOnGuideGraph->setText(tr2i18n("RMS", nullptr));
#if QT_CONFIG(tooltip)
        guideZoomInXB->setToolTip(tr2i18n("<html><head/><body><p>Zoom in for the X-Axis.</p></body></html>", nullptr));
#endif // QT_CONFIG(tooltip)
        guideZoomInXB->setText(QString());
#if QT_CONFIG(tooltip)
        guideZoomOutXB->setToolTip(tr2i18n("<html><head/><body><p>Zoom out for the X-Axis.</p></body></html>", nullptr));
#endif // QT_CONFIG(tooltip)
        guideZoomOutXB->setText(QString());
        label_10->setText(tr2i18n("Trace:", nullptr));
#if QT_CONFIG(tooltip)
        guideSlider->setToolTip(tr2i18n("<html><head/><body><p>Drag the slider to scroll through guide history while displaying the RA and DEC error points on both graphs. Dragging to the far right will set the guide plots to display the latest guide data and autoscroll the graph.</p></body></html>", nullptr));
#endif // QT_CONFIG(tooltip)
#if QT_CONFIG(tooltip)
        latestCheck->setToolTip(tr2i18n("<html><head/><body><p>Check to display the latest guide data and autoscroll the graph.</p></body></html>", nullptr));
#endif // QT_CONFIG(tooltip)
        latestCheck->setText(tr2i18n("Max ", nullptr));
#if QT_CONFIG(tooltip)
        guideAutoScaleGraphB->setToolTip(tr2i18n("<html><head/><body><p>Autoscale both Guide Graphs to their default scale. If any points are located outside this range, the view is expanded to include them (with the exception of the time axis in the drift graphics).</p></body></html>", nullptr));
#endif // QT_CONFIG(tooltip)
        guideAutoScaleGraphB->setText(QString());
#if QT_CONFIG(tooltip)
        guideSaveDataB->setToolTip(tr2i18n("<html><head/><body><p>Export the guide data from the current session to a CSV file readable by a spreadsheet program.</p></body></html>", nullptr));
#endif // QT_CONFIG(tooltip)
        guideSaveDataB->setText(QString());
#if QT_CONFIG(tooltip)
        guideDataClearB->setToolTip(tr2i18n("<html><head/><body><p>Clear all the recent guide data.</p></body></html>", nullptr));
#endif // QT_CONFIG(tooltip)
        guideDataClearB->setText(QString());
#if QT_CONFIG(tooltip)
        guiderAccuracyThreshold->setToolTip(tr2i18n("<html><head/><body><p>Set the desired guiding accuracy in the Drift Plot. The number represents the radius of the green concentric circle in arcseconds.</p></body></html>", nullptr));
#endif // QT_CONFIG(tooltip)
        (void)Guide;
    } // retranslateUi

};

namespace Ui {
    class Guide: public Ui_Guide {};
} // namespace Ui

QT_END_NAMESPACE

#endif // GUIDE_H

