/****************************************************************************
** Meta object code from reading C++ file 'sequencejobstate.h'
**
** Created by: The Qt Meta Object Compiler version 69 (Qt 6.11.1)
**
** WARNING! All changes made in this file will be lost!
*****************************************************************************/

#include "../../../../kstars-3.8.4.1/kstars/ekos/capture/sequencejobstate.h"
#include <QtNetwork/QSslError>
#include <QtDataVisualization/qbar3dseries.h>
#include <QtDataVisualization/q3dscene.h>
#include <QtGui/qtextcursor.h>
#include <QtCore/qmetatype.h>

#include <QtCore/qtmochelpers.h>

#include <memory>


#include <QtCore/qxptype_traits.h>
#if !defined(Q_MOC_OUTPUT_REVISION)
#error "The header file 'sequencejobstate.h' doesn't include <QObject>."
#elif Q_MOC_OUTPUT_REVISION != 69
#error "This file was generated using the moc from 6.11.1. It"
#error "cannot be used with the include files from this version of Qt."
#error "(The moc has changed too much.)"
#endif

#ifndef Q_CONSTINIT
#define Q_CONSTINIT
#endif

QT_WARNING_PUSH
QT_WARNING_DISABLE_DEPRECATED
QT_WARNING_DISABLE_GCC("-Wuseless-cast")
namespace {
struct qt_meta_tag_ZN4Ekos16SequenceJobStateE_t {};
} // unnamed namespace

template <> constexpr inline auto Ekos::SequenceJobState::qt_create_metaobjectdata<qt_meta_tag_ZN4Ekos16SequenceJobStateE_t>()
{
    namespace QMC = QtMocConstants;
    QtMocHelpers::StringRefStorage qt_stringData {
        "Ekos::SequenceJobState",
        "prepareState",
        "",
        "Ekos::CaptureState",
        "state",
        "readCurrentState",
        "readCurrentMountParkState",
        "prepareComplete",
        "success",
        "initCaptureComplete",
        "FITSMode",
        "mode",
        "setRotatorAngle",
        "rawAngle",
        "readFilterPosition",
        "changeFilterPosition",
        "targetFilterPosition",
        "FilterManager::FilterPolicy",
        "policy",
        "setCCDTemperature",
        "temp",
        "setCCDBatchMode",
        "m_preview",
        "askManualScopeCover",
        "question",
        "title",
        "light",
        "askManualScopeOpen",
        "setLightBoxLight",
        "on",
        "setDustCapLight",
        "parkDustCap",
        "park",
        "slewTelescope",
        "SkyPoint&",
        "target",
        "setScopeTracking",
        "setScopeParked",
        "parked",
        "setDomeParked",
        "flatSyncFocus",
        "targetFilterID",
        "queryHasShutter",
        "abortCapture",
        "newLog",
        "setFilterStatus",
        "FilterState",
        "filterState",
        "setCurrentFilterID",
        "value",
        "setCurrentCCDTemperature",
        "setTargetCCDTemperature",
        "setFocusStatus",
        "FocusState",
        "setCurrentRotatorPositionAngle",
        "currentRotation",
        "IPState",
        "setTargetRotatorAngle",
        "updateManualScopeCover",
        "closed",
        "lightBoxLight",
        "dustCapStateChanged",
        "ISD::DustCap::Status",
        "status",
        "lightBoxStateChanged",
        "ISD::LightBox::LightStatus",
        "scopeStatusChanged",
        "ISD::Mount::Status",
        "scopeParkStatusChanged",
        "ISD::ParkStatus",
        "domeStatusChanged",
        "ISD::Dome::Status",
        "flatSyncFocusChanged",
        "completed",
        "hasShutter",
        "present"
    };

    QtMocHelpers::UintData qt_methods {
        // Signal 'prepareState'
        QtMocHelpers::SignalData<void(Ekos::CaptureState)>(1, 2, QMC::AccessPublic, QMetaType::Void, {{
            { 0x80000000 | 3, 4 },
        }}),
        // Signal 'readCurrentState'
        QtMocHelpers::SignalData<void(Ekos::CaptureState)>(5, 2, QMC::AccessPublic, QMetaType::Void, {{
            { 0x80000000 | 3, 4 },
        }}),
        // Signal 'readCurrentMountParkState'
        QtMocHelpers::SignalData<void()>(6, 2, QMC::AccessPublic, QMetaType::Void),
        // Signal 'prepareComplete'
        QtMocHelpers::SignalData<void(bool)>(7, 2, QMC::AccessPublic, QMetaType::Void, {{
            { QMetaType::Bool, 8 },
        }}),
        // Signal 'prepareComplete'
        QtMocHelpers::SignalData<void()>(7, 2, QMC::AccessPublic | QMC::MethodCloned, QMetaType::Void),
        // Signal 'initCaptureComplete'
        QtMocHelpers::SignalData<void(FITSMode)>(9, 2, QMC::AccessPublic, QMetaType::Void, {{
            { 0x80000000 | 10, 11 },
        }}),
        // Signal 'setRotatorAngle'
        QtMocHelpers::SignalData<void(double)>(12, 2, QMC::AccessPublic, QMetaType::Void, {{
            { QMetaType::Double, 13 },
        }}),
        // Signal 'readFilterPosition'
        QtMocHelpers::SignalData<void()>(14, 2, QMC::AccessPublic, QMetaType::Void),
        // Signal 'changeFilterPosition'
        QtMocHelpers::SignalData<void(int, FilterManager::FilterPolicy)>(15, 2, QMC::AccessPublic, QMetaType::Void, {{
            { QMetaType::Int, 16 }, { 0x80000000 | 17, 18 },
        }}),
        // Signal 'setCCDTemperature'
        QtMocHelpers::SignalData<void(double)>(19, 2, QMC::AccessPublic, QMetaType::Void, {{
            { QMetaType::Double, 20 },
        }}),
        // Signal 'setCCDBatchMode'
        QtMocHelpers::SignalData<void(bool)>(21, 2, QMC::AccessPublic, QMetaType::Void, {{
            { QMetaType::Bool, 22 },
        }}),
        // Signal 'askManualScopeCover'
        QtMocHelpers::SignalData<void(QString, QString, bool)>(23, 2, QMC::AccessPublic, QMetaType::Void, {{
            { QMetaType::QString, 24 }, { QMetaType::QString, 25 }, { QMetaType::Bool, 26 },
        }}),
        // Signal 'askManualScopeOpen'
        QtMocHelpers::SignalData<void(bool)>(27, 2, QMC::AccessPublic, QMetaType::Void, {{
            { QMetaType::Bool, 26 },
        }}),
        // Signal 'setLightBoxLight'
        QtMocHelpers::SignalData<void(bool)>(28, 2, QMC::AccessPublic, QMetaType::Void, {{
            { QMetaType::Bool, 29 },
        }}),
        // Signal 'setDustCapLight'
        QtMocHelpers::SignalData<void(bool)>(30, 2, QMC::AccessPublic, QMetaType::Void, {{
            { QMetaType::Bool, 29 },
        }}),
        // Signal 'parkDustCap'
        QtMocHelpers::SignalData<void(bool)>(31, 2, QMC::AccessPublic, QMetaType::Void, {{
            { QMetaType::Bool, 32 },
        }}),
        // Signal 'slewTelescope'
        QtMocHelpers::SignalData<void(SkyPoint &)>(33, 2, QMC::AccessPublic, QMetaType::Void, {{
            { 0x80000000 | 34, 35 },
        }}),
        // Signal 'setScopeTracking'
        QtMocHelpers::SignalData<void(bool)>(36, 2, QMC::AccessPublic, QMetaType::Void, {{
            { QMetaType::Bool, 29 },
        }}),
        // Signal 'setScopeParked'
        QtMocHelpers::SignalData<void(bool)>(37, 2, QMC::AccessPublic, QMetaType::Void, {{
            { QMetaType::Bool, 38 },
        }}),
        // Signal 'setDomeParked'
        QtMocHelpers::SignalData<void(bool)>(39, 2, QMC::AccessPublic, QMetaType::Void, {{
            { QMetaType::Bool, 38 },
        }}),
        // Signal 'flatSyncFocus'
        QtMocHelpers::SignalData<void(int)>(40, 2, QMC::AccessPublic, QMetaType::Void, {{
            { QMetaType::Int, 41 },
        }}),
        // Signal 'queryHasShutter'
        QtMocHelpers::SignalData<void()>(42, 2, QMC::AccessPublic, QMetaType::Void),
        // Signal 'abortCapture'
        QtMocHelpers::SignalData<void()>(43, 2, QMC::AccessPublic, QMetaType::Void),
        // Signal 'newLog'
        QtMocHelpers::SignalData<void(QString)>(44, 2, QMC::AccessPublic, QMetaType::Void, {{
            { QMetaType::QString, 2 },
        }}),
        // Slot 'setFilterStatus'
        QtMocHelpers::SlotData<void(FilterState)>(45, 2, QMC::AccessPublic, QMetaType::Void, {{
            { 0x80000000 | 46, 47 },
        }}),
        // Slot 'setCurrentFilterID'
        QtMocHelpers::SlotData<void(int)>(48, 2, QMC::AccessPublic, QMetaType::Void, {{
            { QMetaType::Int, 49 },
        }}),
        // Slot 'setCurrentCCDTemperature'
        QtMocHelpers::SlotData<void(double)>(50, 2, QMC::AccessPublic, QMetaType::Void, {{
            { QMetaType::Double, 49 },
        }}),
        // Slot 'setTargetCCDTemperature'
        QtMocHelpers::SlotData<void(double)>(51, 2, QMC::AccessPublic, QMetaType::Void, {{
            { QMetaType::Double, 49 },
        }}),
        // Slot 'setFocusStatus'
        QtMocHelpers::SlotData<void(FocusState)>(52, 2, QMC::AccessPublic, QMetaType::Void, {{
            { 0x80000000 | 53, 4 },
        }}),
        // Slot 'setCurrentRotatorPositionAngle'
        QtMocHelpers::SlotData<void(double, IPState)>(54, 2, QMC::AccessPublic, QMetaType::Void, {{
            { QMetaType::Double, 55 }, { 0x80000000 | 56, 4 },
        }}),
        // Slot 'setTargetRotatorAngle'
        QtMocHelpers::SlotData<void(double)>(57, 2, QMC::AccessPublic, QMetaType::Void, {{
            { QMetaType::Double, 49 },
        }}),
        // Slot 'updateManualScopeCover'
        QtMocHelpers::SlotData<void(bool, bool, bool)>(58, 2, QMC::AccessPublic, QMetaType::Void, {{
            { QMetaType::Bool, 59 }, { QMetaType::Bool, 8 }, { QMetaType::Bool, 26 },
        }}),
        // Slot 'lightBoxLight'
        QtMocHelpers::SlotData<void(bool)>(60, 2, QMC::AccessPublic, QMetaType::Void, {{
            { QMetaType::Bool, 29 },
        }}),
        // Slot 'dustCapStateChanged'
        QtMocHelpers::SlotData<void(ISD::DustCap::Status)>(61, 2, QMC::AccessPublic, QMetaType::Void, {{
            { 0x80000000 | 62, 63 },
        }}),
        // Slot 'lightBoxStateChanged'
        QtMocHelpers::SlotData<void(ISD::LightBox::LightStatus)>(64, 2, QMC::AccessPublic, QMetaType::Void, {{
            { 0x80000000 | 65, 63 },
        }}),
        // Slot 'scopeStatusChanged'
        QtMocHelpers::SlotData<void(ISD::Mount::Status)>(66, 2, QMC::AccessPublic, QMetaType::Void, {{
            { 0x80000000 | 67, 63 },
        }}),
        // Slot 'scopeParkStatusChanged'
        QtMocHelpers::SlotData<void(ISD::ParkStatus)>(68, 2, QMC::AccessPublic, QMetaType::Void, {{
            { 0x80000000 | 69, 63 },
        }}),
        // Slot 'domeStatusChanged'
        QtMocHelpers::SlotData<void(ISD::Dome::Status)>(70, 2, QMC::AccessPublic, QMetaType::Void, {{
            { 0x80000000 | 71, 63 },
        }}),
        // Slot 'flatSyncFocusChanged'
        QtMocHelpers::SlotData<void(bool)>(72, 2, QMC::AccessPublic, QMetaType::Void, {{
            { QMetaType::Bool, 73 },
        }}),
        // Slot 'hasShutter'
        QtMocHelpers::SlotData<void(bool)>(74, 2, QMC::AccessPublic, QMetaType::Void, {{
            { QMetaType::Bool, 75 },
        }}),
    };
    QtMocHelpers::UintData qt_properties {
    };
    QtMocHelpers::UintData qt_enums {
    };
    return QtMocHelpers::metaObjectData<SequenceJobState, qt_meta_tag_ZN4Ekos16SequenceJobStateE_t>(QMC::MetaObjectFlag{}, qt_stringData,
            qt_methods, qt_properties, qt_enums);
}
Q_CONSTINIT const QMetaObject Ekos::SequenceJobState::staticMetaObject = { {
    QMetaObject::SuperData::link<QObject::staticMetaObject>(),
    qt_staticMetaObjectStaticContent<qt_meta_tag_ZN4Ekos16SequenceJobStateE_t>.stringdata,
    qt_staticMetaObjectStaticContent<qt_meta_tag_ZN4Ekos16SequenceJobStateE_t>.data,
    qt_static_metacall,
    nullptr,
    qt_staticMetaObjectRelocatingContent<qt_meta_tag_ZN4Ekos16SequenceJobStateE_t>.metaTypes,
    nullptr
} };

void Ekos::SequenceJobState::qt_static_metacall(QObject *_o, QMetaObject::Call _c, int _id, void **_a)
{
    auto *_t = static_cast<SequenceJobState *>(_o);
    if (_c == QMetaObject::InvokeMetaMethod) {
        switch (_id) {
        case 0: _t->prepareState((*reinterpret_cast<std::add_pointer_t<Ekos::CaptureState>>(_a[1]))); break;
        case 1: _t->readCurrentState((*reinterpret_cast<std::add_pointer_t<Ekos::CaptureState>>(_a[1]))); break;
        case 2: _t->readCurrentMountParkState(); break;
        case 3: _t->prepareComplete((*reinterpret_cast<std::add_pointer_t<bool>>(_a[1]))); break;
        case 4: _t->prepareComplete(); break;
        case 5: _t->initCaptureComplete((*reinterpret_cast<std::add_pointer_t<FITSMode>>(_a[1]))); break;
        case 6: _t->setRotatorAngle((*reinterpret_cast<std::add_pointer_t<double>>(_a[1]))); break;
        case 7: _t->readFilterPosition(); break;
        case 8: _t->changeFilterPosition((*reinterpret_cast<std::add_pointer_t<int>>(_a[1])),(*reinterpret_cast<std::add_pointer_t<FilterManager::FilterPolicy>>(_a[2]))); break;
        case 9: _t->setCCDTemperature((*reinterpret_cast<std::add_pointer_t<double>>(_a[1]))); break;
        case 10: _t->setCCDBatchMode((*reinterpret_cast<std::add_pointer_t<bool>>(_a[1]))); break;
        case 11: _t->askManualScopeCover((*reinterpret_cast<std::add_pointer_t<QString>>(_a[1])),(*reinterpret_cast<std::add_pointer_t<QString>>(_a[2])),(*reinterpret_cast<std::add_pointer_t<bool>>(_a[3]))); break;
        case 12: _t->askManualScopeOpen((*reinterpret_cast<std::add_pointer_t<bool>>(_a[1]))); break;
        case 13: _t->setLightBoxLight((*reinterpret_cast<std::add_pointer_t<bool>>(_a[1]))); break;
        case 14: _t->setDustCapLight((*reinterpret_cast<std::add_pointer_t<bool>>(_a[1]))); break;
        case 15: _t->parkDustCap((*reinterpret_cast<std::add_pointer_t<bool>>(_a[1]))); break;
        case 16: _t->slewTelescope((*reinterpret_cast<std::add_pointer_t<SkyPoint&>>(_a[1]))); break;
        case 17: _t->setScopeTracking((*reinterpret_cast<std::add_pointer_t<bool>>(_a[1]))); break;
        case 18: _t->setScopeParked((*reinterpret_cast<std::add_pointer_t<bool>>(_a[1]))); break;
        case 19: _t->setDomeParked((*reinterpret_cast<std::add_pointer_t<bool>>(_a[1]))); break;
        case 20: _t->flatSyncFocus((*reinterpret_cast<std::add_pointer_t<int>>(_a[1]))); break;
        case 21: _t->queryHasShutter(); break;
        case 22: _t->abortCapture(); break;
        case 23: _t->newLog((*reinterpret_cast<std::add_pointer_t<QString>>(_a[1]))); break;
        case 24: _t->setFilterStatus((*reinterpret_cast<std::add_pointer_t<FilterState>>(_a[1]))); break;
        case 25: _t->setCurrentFilterID((*reinterpret_cast<std::add_pointer_t<int>>(_a[1]))); break;
        case 26: _t->setCurrentCCDTemperature((*reinterpret_cast<std::add_pointer_t<double>>(_a[1]))); break;
        case 27: _t->setTargetCCDTemperature((*reinterpret_cast<std::add_pointer_t<double>>(_a[1]))); break;
        case 28: _t->setFocusStatus((*reinterpret_cast<std::add_pointer_t<FocusState>>(_a[1]))); break;
        case 29: _t->setCurrentRotatorPositionAngle((*reinterpret_cast<std::add_pointer_t<double>>(_a[1])),(*reinterpret_cast<std::add_pointer_t<IPState>>(_a[2]))); break;
        case 30: _t->setTargetRotatorAngle((*reinterpret_cast<std::add_pointer_t<double>>(_a[1]))); break;
        case 31: _t->updateManualScopeCover((*reinterpret_cast<std::add_pointer_t<bool>>(_a[1])),(*reinterpret_cast<std::add_pointer_t<bool>>(_a[2])),(*reinterpret_cast<std::add_pointer_t<bool>>(_a[3]))); break;
        case 32: _t->lightBoxLight((*reinterpret_cast<std::add_pointer_t<bool>>(_a[1]))); break;
        case 33: _t->dustCapStateChanged((*reinterpret_cast<std::add_pointer_t<ISD::DustCap::Status>>(_a[1]))); break;
        case 34: _t->lightBoxStateChanged((*reinterpret_cast<std::add_pointer_t<ISD::LightBox::LightStatus>>(_a[1]))); break;
        case 35: _t->scopeStatusChanged((*reinterpret_cast<std::add_pointer_t<ISD::Mount::Status>>(_a[1]))); break;
        case 36: _t->scopeParkStatusChanged((*reinterpret_cast<std::add_pointer_t<ISD::ParkStatus>>(_a[1]))); break;
        case 37: _t->domeStatusChanged((*reinterpret_cast<std::add_pointer_t<ISD::Dome::Status>>(_a[1]))); break;
        case 38: _t->flatSyncFocusChanged((*reinterpret_cast<std::add_pointer_t<bool>>(_a[1]))); break;
        case 39: _t->hasShutter((*reinterpret_cast<std::add_pointer_t<bool>>(_a[1]))); break;
        default: ;
        }
    }
    if (_c == QMetaObject::RegisterMethodArgumentMetaType) {
        switch (_id) {
        default: *reinterpret_cast<QMetaType *>(_a[0]) = QMetaType(); break;
        case 0:
            switch (*reinterpret_cast<int*>(_a[1])) {
            default: *reinterpret_cast<QMetaType *>(_a[0]) = QMetaType(); break;
            case 0:
                *reinterpret_cast<QMetaType *>(_a[0]) = QMetaType::fromType< Ekos::CaptureState >(); break;
            }
            break;
        case 1:
            switch (*reinterpret_cast<int*>(_a[1])) {
            default: *reinterpret_cast<QMetaType *>(_a[0]) = QMetaType(); break;
            case 0:
                *reinterpret_cast<QMetaType *>(_a[0]) = QMetaType::fromType< Ekos::CaptureState >(); break;
            }
            break;
        case 33:
            switch (*reinterpret_cast<int*>(_a[1])) {
            default: *reinterpret_cast<QMetaType *>(_a[0]) = QMetaType(); break;
            case 0:
                *reinterpret_cast<QMetaType *>(_a[0]) = QMetaType::fromType< ISD::DustCap::Status >(); break;
            }
            break;
        case 35:
            switch (*reinterpret_cast<int*>(_a[1])) {
            default: *reinterpret_cast<QMetaType *>(_a[0]) = QMetaType(); break;
            case 0:
                *reinterpret_cast<QMetaType *>(_a[0]) = QMetaType::fromType< ISD::Mount::Status >(); break;
            }
            break;
        case 36:
            switch (*reinterpret_cast<int*>(_a[1])) {
            default: *reinterpret_cast<QMetaType *>(_a[0]) = QMetaType(); break;
            case 0:
                *reinterpret_cast<QMetaType *>(_a[0]) = QMetaType::fromType< ISD::ParkStatus >(); break;
            }
            break;
        case 37:
            switch (*reinterpret_cast<int*>(_a[1])) {
            default: *reinterpret_cast<QMetaType *>(_a[0]) = QMetaType(); break;
            case 0:
                *reinterpret_cast<QMetaType *>(_a[0]) = QMetaType::fromType< ISD::Dome::Status >(); break;
            }
            break;
        }
    }
    if (_c == QMetaObject::IndexOfMethod) {
        if (QtMocHelpers::indexOfMethod<void (SequenceJobState::*)(Ekos::CaptureState )>(_a, &SequenceJobState::prepareState, 0))
            return;
        if (QtMocHelpers::indexOfMethod<void (SequenceJobState::*)(Ekos::CaptureState )>(_a, &SequenceJobState::readCurrentState, 1))
            return;
        if (QtMocHelpers::indexOfMethod<void (SequenceJobState::*)()>(_a, &SequenceJobState::readCurrentMountParkState, 2))
            return;
        if (QtMocHelpers::indexOfMethod<void (SequenceJobState::*)(bool )>(_a, &SequenceJobState::prepareComplete, 3))
            return;
        if (QtMocHelpers::indexOfMethod<void (SequenceJobState::*)(FITSMode )>(_a, &SequenceJobState::initCaptureComplete, 5))
            return;
        if (QtMocHelpers::indexOfMethod<void (SequenceJobState::*)(double )>(_a, &SequenceJobState::setRotatorAngle, 6))
            return;
        if (QtMocHelpers::indexOfMethod<void (SequenceJobState::*)()>(_a, &SequenceJobState::readFilterPosition, 7))
            return;
        if (QtMocHelpers::indexOfMethod<void (SequenceJobState::*)(int , FilterManager::FilterPolicy )>(_a, &SequenceJobState::changeFilterPosition, 8))
            return;
        if (QtMocHelpers::indexOfMethod<void (SequenceJobState::*)(double )>(_a, &SequenceJobState::setCCDTemperature, 9))
            return;
        if (QtMocHelpers::indexOfMethod<void (SequenceJobState::*)(bool )>(_a, &SequenceJobState::setCCDBatchMode, 10))
            return;
        if (QtMocHelpers::indexOfMethod<void (SequenceJobState::*)(QString , QString , bool )>(_a, &SequenceJobState::askManualScopeCover, 11))
            return;
        if (QtMocHelpers::indexOfMethod<void (SequenceJobState::*)(bool )>(_a, &SequenceJobState::askManualScopeOpen, 12))
            return;
        if (QtMocHelpers::indexOfMethod<void (SequenceJobState::*)(bool )>(_a, &SequenceJobState::setLightBoxLight, 13))
            return;
        if (QtMocHelpers::indexOfMethod<void (SequenceJobState::*)(bool )>(_a, &SequenceJobState::setDustCapLight, 14))
            return;
        if (QtMocHelpers::indexOfMethod<void (SequenceJobState::*)(bool )>(_a, &SequenceJobState::parkDustCap, 15))
            return;
        if (QtMocHelpers::indexOfMethod<void (SequenceJobState::*)(SkyPoint & )>(_a, &SequenceJobState::slewTelescope, 16))
            return;
        if (QtMocHelpers::indexOfMethod<void (SequenceJobState::*)(bool )>(_a, &SequenceJobState::setScopeTracking, 17))
            return;
        if (QtMocHelpers::indexOfMethod<void (SequenceJobState::*)(bool )>(_a, &SequenceJobState::setScopeParked, 18))
            return;
        if (QtMocHelpers::indexOfMethod<void (SequenceJobState::*)(bool )>(_a, &SequenceJobState::setDomeParked, 19))
            return;
        if (QtMocHelpers::indexOfMethod<void (SequenceJobState::*)(int )>(_a, &SequenceJobState::flatSyncFocus, 20))
            return;
        if (QtMocHelpers::indexOfMethod<void (SequenceJobState::*)()>(_a, &SequenceJobState::queryHasShutter, 21))
            return;
        if (QtMocHelpers::indexOfMethod<void (SequenceJobState::*)()>(_a, &SequenceJobState::abortCapture, 22))
            return;
        if (QtMocHelpers::indexOfMethod<void (SequenceJobState::*)(QString )>(_a, &SequenceJobState::newLog, 23))
            return;
    }
}

const QMetaObject *Ekos::SequenceJobState::metaObject() const
{
    return QObject::d_ptr->metaObject ? QObject::d_ptr->dynamicMetaObject() : &staticMetaObject;
}

void *Ekos::SequenceJobState::qt_metacast(const char *_clname)
{
    if (!_clname) return nullptr;
    if (!strcmp(_clname, qt_staticMetaObjectStaticContent<qt_meta_tag_ZN4Ekos16SequenceJobStateE_t>.strings))
        return static_cast<void*>(this);
    return QObject::qt_metacast(_clname);
}

int Ekos::SequenceJobState::qt_metacall(QMetaObject::Call _c, int _id, void **_a)
{
    _id = QObject::qt_metacall(_c, _id, _a);
    if (_id < 0)
        return _id;
    if (_c == QMetaObject::InvokeMetaMethod) {
        if (_id < 40)
            qt_static_metacall(this, _c, _id, _a);
        _id -= 40;
    }
    if (_c == QMetaObject::RegisterMethodArgumentMetaType) {
        if (_id < 40)
            qt_static_metacall(this, _c, _id, _a);
        _id -= 40;
    }
    return _id;
}

// SIGNAL 0
void Ekos::SequenceJobState::prepareState(Ekos::CaptureState _t1)
{
    QMetaObject::activate<void>(this, &staticMetaObject, 0, nullptr, _t1);
}

// SIGNAL 1
void Ekos::SequenceJobState::readCurrentState(Ekos::CaptureState _t1)
{
    QMetaObject::activate<void>(this, &staticMetaObject, 1, nullptr, _t1);
}

// SIGNAL 2
void Ekos::SequenceJobState::readCurrentMountParkState()
{
    QMetaObject::activate(this, &staticMetaObject, 2, nullptr);
}

// SIGNAL 3
void Ekos::SequenceJobState::prepareComplete(bool _t1)
{
    QMetaObject::activate<void>(this, &staticMetaObject, 3, nullptr, _t1);
}

// SIGNAL 5
void Ekos::SequenceJobState::initCaptureComplete(FITSMode _t1)
{
    QMetaObject::activate<void>(this, &staticMetaObject, 5, nullptr, _t1);
}

// SIGNAL 6
void Ekos::SequenceJobState::setRotatorAngle(double _t1)
{
    QMetaObject::activate<void>(this, &staticMetaObject, 6, nullptr, _t1);
}

// SIGNAL 7
void Ekos::SequenceJobState::readFilterPosition()
{
    QMetaObject::activate(this, &staticMetaObject, 7, nullptr);
}

// SIGNAL 8
void Ekos::SequenceJobState::changeFilterPosition(int _t1, FilterManager::FilterPolicy _t2)
{
    QMetaObject::activate<void>(this, &staticMetaObject, 8, nullptr, _t1, _t2);
}

// SIGNAL 9
void Ekos::SequenceJobState::setCCDTemperature(double _t1)
{
    QMetaObject::activate<void>(this, &staticMetaObject, 9, nullptr, _t1);
}

// SIGNAL 10
void Ekos::SequenceJobState::setCCDBatchMode(bool _t1)
{
    QMetaObject::activate<void>(this, &staticMetaObject, 10, nullptr, _t1);
}

// SIGNAL 11
void Ekos::SequenceJobState::askManualScopeCover(QString _t1, QString _t2, bool _t3)
{
    QMetaObject::activate<void>(this, &staticMetaObject, 11, nullptr, _t1, _t2, _t3);
}

// SIGNAL 12
void Ekos::SequenceJobState::askManualScopeOpen(bool _t1)
{
    QMetaObject::activate<void>(this, &staticMetaObject, 12, nullptr, _t1);
}

// SIGNAL 13
void Ekos::SequenceJobState::setLightBoxLight(bool _t1)
{
    QMetaObject::activate<void>(this, &staticMetaObject, 13, nullptr, _t1);
}

// SIGNAL 14
void Ekos::SequenceJobState::setDustCapLight(bool _t1)
{
    QMetaObject::activate<void>(this, &staticMetaObject, 14, nullptr, _t1);
}

// SIGNAL 15
void Ekos::SequenceJobState::parkDustCap(bool _t1)
{
    QMetaObject::activate<void>(this, &staticMetaObject, 15, nullptr, _t1);
}

// SIGNAL 16
void Ekos::SequenceJobState::slewTelescope(SkyPoint & _t1)
{
    QMetaObject::activate<void>(this, &staticMetaObject, 16, nullptr, _t1);
}

// SIGNAL 17
void Ekos::SequenceJobState::setScopeTracking(bool _t1)
{
    QMetaObject::activate<void>(this, &staticMetaObject, 17, nullptr, _t1);
}

// SIGNAL 18
void Ekos::SequenceJobState::setScopeParked(bool _t1)
{
    QMetaObject::activate<void>(this, &staticMetaObject, 18, nullptr, _t1);
}

// SIGNAL 19
void Ekos::SequenceJobState::setDomeParked(bool _t1)
{
    QMetaObject::activate<void>(this, &staticMetaObject, 19, nullptr, _t1);
}

// SIGNAL 20
void Ekos::SequenceJobState::flatSyncFocus(int _t1)
{
    QMetaObject::activate<void>(this, &staticMetaObject, 20, nullptr, _t1);
}

// SIGNAL 21
void Ekos::SequenceJobState::queryHasShutter()
{
    QMetaObject::activate(this, &staticMetaObject, 21, nullptr);
}

// SIGNAL 22
void Ekos::SequenceJobState::abortCapture()
{
    QMetaObject::activate(this, &staticMetaObject, 22, nullptr);
}

// SIGNAL 23
void Ekos::SequenceJobState::newLog(QString _t1)
{
    QMetaObject::activate<void>(this, &staticMetaObject, 23, nullptr, _t1);
}
QT_WARNING_POP
