/*
 * This file was generated by qdbusxml2cpp version 0.8
 * Source file was org.kde.kstars.Ekos.Scheduler.xml
 *
 * qdbusxml2cpp is Copyright (C) The Qt Company Ltd. and other contributors.
 *
 * This is an auto-generated file.
 * Do not edit! All changes made to it will be lost.
 */

#include "scheduleradaptor.h"
#include <QtCore/QMetaObject>
#include <QtCore/QByteArray>
#include <QtCore/QList>
#include <QtCore/QMap>
#include <QtCore/QString>
#include <QtCore/QStringList>
#include <QtCore/QVariant>

/*
 * Implementation of adaptor class SchedulerAdaptor
 */

SchedulerAdaptor::SchedulerAdaptor(Ekos::SchedulerProcess *parent)
    : QDBusAbstractAdaptor(parent)
{
    // constructor
    setAutoRelaySignals(true);
}

SchedulerAdaptor::~SchedulerAdaptor()
{
    // destructor
}

QString SchedulerAdaptor::currentJobJson() const
{
    // get the value of property currentJobJson
    return qvariant_cast< QString >(parent()->property("currentJobJson"));
}

QString SchedulerAdaptor::currentJobName() const
{
    // get the value of property currentJobName
    return qvariant_cast< QString >(parent()->property("currentJobName"));
}

QString SchedulerAdaptor::jsonJobs() const
{
    // get the value of property jsonJobs
    return qvariant_cast< QString >(parent()->property("jsonJobs"));
}

QStringList SchedulerAdaptor::logText() const
{
    // get the value of property logText
    return qvariant_cast< QStringList >(parent()->property("logText"));
}

QString SchedulerAdaptor::profile() const
{
    // get the value of property profile
    return qvariant_cast< QString >(parent()->property("profile"));
}

void SchedulerAdaptor::setProfile(const QString &value)
{
    // set the value of property profile
    parent()->setProperty("profile", QVariant::fromValue(value));
}

int SchedulerAdaptor::status() const
{
    // get the value of property status
    return qvariant_cast< int >(parent()->property("status"));
}

bool SchedulerAdaptor::loadScheduler(const QString &fileURL)
{
    // handle method call org.kde.kstars.Ekos.Scheduler.loadScheduler
    return parent()->loadScheduler(fileURL);
}

void SchedulerAdaptor::removeAllJobs()
{
    // handle method call org.kde.kstars.Ekos.Scheduler.removeAllJobs
    parent()->removeAllJobs();
}

void SchedulerAdaptor::resetAllJobs()
{
    // handle method call org.kde.kstars.Ekos.Scheduler.resetAllJobs
    parent()->resetAllJobs();
}

void SchedulerAdaptor::setSequence(const QString &sequenceFileURL)
{
    // handle method call org.kde.kstars.Ekos.Scheduler.setSequence
    parent()->setSequence(sequenceFileURL);
}

void SchedulerAdaptor::start()
{
    // handle method call org.kde.kstars.Ekos.Scheduler.start
    parent()->start();
}

void SchedulerAdaptor::stop()
{
    // handle method call org.kde.kstars.Ekos.Scheduler.stop
    parent()->stop();
}


#include "moc_scheduleradaptor.cpp"
