/********************************************************************************
** Form generated from reading UI file 'details_data.ui'
**
** Created by: Qt User Interface Compiler version 6.11.1
**
** WARNING! All changes made in this file will be lost when recompiling UI file!
********************************************************************************/

#ifndef UI_DETAILS_DATA_H
#define UI_DETAILS_DATA_H

#include <QtCore/QVariant>
#include <QtWidgets/QApplication>
#include <QtWidgets/QFrame>
#include <QtWidgets/QGridLayout>
#include <QtWidgets/QHBoxLayout>
#include <QtWidgets/QLabel>
#include <QtWidgets/QPushButton>
#include <QtWidgets/QSpacerItem>
#include <QtWidgets/QVBoxLayout>
#include <QtWidgets/QWidget>
#include <klocalizedstring.h>
#include "widgets/clicklabel.h"
#include "widgets/kshelplabel.h"

QT_BEGIN_NAMESPACE

class Ui_DetailsData
{
public:
    QVBoxLayout *vboxLayout;
    QLabel *Names;
    QFrame *DataFrame;
    QHBoxLayout *hboxLayout;
    QVBoxLayout *vboxLayout1;
    QHBoxLayout *hboxLayout1;
    QLabel *ObjectTypeInConstellation;
    QSpacerItem *spacerItem;
    QSpacerItem *spacerItem1;
    QHBoxLayout *hboxLayout2;
    ClickLabel *Image;
    QSpacerItem *spacerItem2;
    QVBoxLayout *vboxLayout2;
    QHBoxLayout *hboxLayout3;
    QGridLayout *dataGridLayout;
    QLabel *Magnitude;
    QLabel *AngSizeLabel;
    QLabel *AngSize;
    QLabel *Illumination;
    KSHelpLabel *BVLabel;
    KSHelpLabel *DistanceLabel;
    KSHelpLabel *MagLabel;
    QLabel *IllumLabel;
    QLabel *Distance;
    QLabel *BVIndex;
    QLabel *CatalogLabel;
    QLabel *Catalog;
    QSpacerItem *spacerItem3;
    QWidget *IncludeData;
    QVBoxLayout *verticalLayout_2;
    QHBoxLayout *hboxLayout4;
    QSpacerItem *spacerItem4;
    QVBoxLayout *vboxLayout3;
    QPushButton *ObsListButton;
    QPushButton *CenterButton;
    QPushButton *ScopeButton;
    QSpacerItem *spacerItem5;
    QSpacerItem *spacerItem6;

    void setupUi(QWidget *DetailsData)
    {
        if (DetailsData->objectName().isEmpty())
            DetailsData->setObjectName("DetailsData");
        DetailsData->resize(386, 269);
        vboxLayout = new QVBoxLayout(DetailsData);
        vboxLayout->setSpacing(0);
        vboxLayout->setObjectName("vboxLayout");
        vboxLayout->setContentsMargins(3, 3, 3, 3);
        Names = new QLabel(DetailsData);
        Names->setObjectName("Names");
        QFont font;
        font.setFamilies({QString::fromUtf8("Sans Serif")});
        font.setPointSize(11);
        font.setBold(true);
        font.setItalic(false);
        font.setUnderline(false);
        font.setStrikeOut(false);
        Names->setFont(font);
        Names->setAutoFillBackground(true);
        Names->setAlignment(Qt::AlignCenter);

        vboxLayout->addWidget(Names);

        DataFrame = new QFrame(DetailsData);
        DataFrame->setObjectName("DataFrame");
        DataFrame->setAutoFillBackground(true);
        DataFrame->setFrameShape(QFrame::Box);
        DataFrame->setFrameShadow(QFrame::Plain);
        DataFrame->setLineWidth(4);
        hboxLayout = new QHBoxLayout(DataFrame);
        hboxLayout->setSpacing(3);
        hboxLayout->setObjectName("hboxLayout");
        hboxLayout->setContentsMargins(3, 3, 3, 3);
        vboxLayout1 = new QVBoxLayout();
        vboxLayout1->setSpacing(3);
        vboxLayout1->setObjectName("vboxLayout1");
        vboxLayout1->setContentsMargins(0, 0, 0, 0);
        hboxLayout1 = new QHBoxLayout();
        hboxLayout1->setSpacing(3);
        hboxLayout1->setObjectName("hboxLayout1");
        hboxLayout1->setContentsMargins(0, 0, 0, 0);
        ObjectTypeInConstellation = new QLabel(DataFrame);
        ObjectTypeInConstellation->setObjectName("ObjectTypeInConstellation");

        hboxLayout1->addWidget(ObjectTypeInConstellation);

        spacerItem = new QSpacerItem(40, 20, QSizePolicy::Policy::Expanding, QSizePolicy::Policy::Minimum);

        hboxLayout1->addItem(spacerItem);


        vboxLayout1->addLayout(hboxLayout1);

        spacerItem1 = new QSpacerItem(20, 40, QSizePolicy::Policy::Minimum, QSizePolicy::Policy::Expanding);

        vboxLayout1->addItem(spacerItem1);

        hboxLayout2 = new QHBoxLayout();
        hboxLayout2->setSpacing(3);
        hboxLayout2->setObjectName("hboxLayout2");
        hboxLayout2->setContentsMargins(0, 0, 0, 0);
        Image = new ClickLabel(DataFrame);
        Image->setObjectName("Image");
        QSizePolicy sizePolicy(QSizePolicy::Policy::Expanding, QSizePolicy::Policy::Expanding);
        sizePolicy.setHorizontalStretch(0);
        sizePolicy.setVerticalStretch(0);
        sizePolicy.setHeightForWidth(Image->sizePolicy().hasHeightForWidth());
        Image->setSizePolicy(sizePolicy);
        Image->setMinimumSize(QSize(200, 200));
        Image->setMaximumSize(QSize(200, 200));
        Image->setCursor(QCursor(Qt::CursorShape::PointingHandCursor));
        Image->setFrameShape(QFrame::StyledPanel);
        Image->setFrameShadow(QFrame::Raised);

        hboxLayout2->addWidget(Image);

        spacerItem2 = new QSpacerItem(40, 20, QSizePolicy::Policy::Expanding, QSizePolicy::Policy::Minimum);

        hboxLayout2->addItem(spacerItem2);


        vboxLayout1->addLayout(hboxLayout2);


        hboxLayout->addLayout(vboxLayout1);

        vboxLayout2 = new QVBoxLayout();
        vboxLayout2->setSpacing(3);
        vboxLayout2->setObjectName("vboxLayout2");
        vboxLayout2->setContentsMargins(0, 0, 0, 0);
        hboxLayout3 = new QHBoxLayout();
        hboxLayout3->setSpacing(3);
        hboxLayout3->setObjectName("hboxLayout3");
        hboxLayout3->setContentsMargins(0, 0, 0, 0);
        dataGridLayout = new QGridLayout();
        dataGridLayout->setSpacing(5);
        dataGridLayout->setObjectName("dataGridLayout");
        dataGridLayout->setContentsMargins(0, 0, 0, 0);
        Magnitude = new QLabel(DataFrame);
        Magnitude->setObjectName("Magnitude");
        QFont font1;
        font1.setFamilies({QString::fromUtf8("Monospace")});
        font1.setPointSize(10);
        font1.setBold(true);
        font1.setItalic(false);
        font1.setUnderline(false);
        font1.setStrikeOut(false);
        Magnitude->setFont(font1);

        dataGridLayout->addWidget(Magnitude, 0, 1, 1, 1);

        AngSizeLabel = new QLabel(DataFrame);
        AngSizeLabel->setObjectName("AngSizeLabel");

        dataGridLayout->addWidget(AngSizeLabel, 3, 0, 1, 1);

        AngSize = new QLabel(DataFrame);
        AngSize->setObjectName("AngSize");
        AngSize->setFont(font1);

        dataGridLayout->addWidget(AngSize, 3, 1, 1, 1);

        Illumination = new QLabel(DataFrame);
        Illumination->setObjectName("Illumination");
        Illumination->setFont(font1);

        dataGridLayout->addWidget(Illumination, 5, 1, 1, 1);

        BVLabel = new KSHelpLabel(DataFrame);
        BVLabel->setObjectName("BVLabel");

        dataGridLayout->addWidget(BVLabel, 2, 0, 1, 1);

        DistanceLabel = new KSHelpLabel(DataFrame);
        DistanceLabel->setObjectName("DistanceLabel");

        dataGridLayout->addWidget(DistanceLabel, 1, 0, 1, 1);

        MagLabel = new KSHelpLabel(DataFrame);
        MagLabel->setObjectName("MagLabel");

        dataGridLayout->addWidget(MagLabel, 0, 0, 1, 1);

        IllumLabel = new QLabel(DataFrame);
        IllumLabel->setObjectName("IllumLabel");
        IllumLabel->setOpenExternalLinks(false);

        dataGridLayout->addWidget(IllumLabel, 5, 0, 1, 1);

        Distance = new QLabel(DataFrame);
        Distance->setObjectName("Distance");
        Distance->setFont(font1);

        dataGridLayout->addWidget(Distance, 1, 1, 1, 1);

        BVIndex = new QLabel(DataFrame);
        BVIndex->setObjectName("BVIndex");

        dataGridLayout->addWidget(BVIndex, 2, 1, 1, 1);

        CatalogLabel = new QLabel(DataFrame);
        CatalogLabel->setObjectName("CatalogLabel");

        dataGridLayout->addWidget(CatalogLabel, 6, 0, 1, 1);

        Catalog = new QLabel(DataFrame);
        Catalog->setObjectName("Catalog");
        Catalog->setFont(font1);

        dataGridLayout->addWidget(Catalog, 6, 1, 1, 1);


        hboxLayout3->addLayout(dataGridLayout);

        spacerItem3 = new QSpacerItem(40, 20, QSizePolicy::Policy::Expanding, QSizePolicy::Policy::Minimum);

        hboxLayout3->addItem(spacerItem3);


        vboxLayout2->addLayout(hboxLayout3);

        IncludeData = new QWidget(DataFrame);
        IncludeData->setObjectName("IncludeData");
        verticalLayout_2 = new QVBoxLayout(IncludeData);
        verticalLayout_2->setSpacing(3);
        verticalLayout_2->setObjectName("verticalLayout_2");
        verticalLayout_2->setContentsMargins(3, 3, 3, 3);

        vboxLayout2->addWidget(IncludeData);

        hboxLayout4 = new QHBoxLayout();
        hboxLayout4->setSpacing(3);
        hboxLayout4->setObjectName("hboxLayout4");
        hboxLayout4->setContentsMargins(0, 0, 0, 0);
        spacerItem4 = new QSpacerItem(40, 20, QSizePolicy::Policy::Expanding, QSizePolicy::Policy::Minimum);

        hboxLayout4->addItem(spacerItem4);

        vboxLayout3 = new QVBoxLayout();
        vboxLayout3->setSpacing(3);
        vboxLayout3->setObjectName("vboxLayout3");
        vboxLayout3->setContentsMargins(0, 0, 0, 0);
        ObsListButton = new QPushButton(DataFrame);
        ObsListButton->setObjectName("ObsListButton");

        vboxLayout3->addWidget(ObsListButton);

        CenterButton = new QPushButton(DataFrame);
        CenterButton->setObjectName("CenterButton");

        vboxLayout3->addWidget(CenterButton);

        ScopeButton = new QPushButton(DataFrame);
        ScopeButton->setObjectName("ScopeButton");

        vboxLayout3->addWidget(ScopeButton);

        spacerItem5 = new QSpacerItem(20, 21, QSizePolicy::Policy::Minimum, QSizePolicy::Policy::Fixed);

        vboxLayout3->addItem(spacerItem5);


        hboxLayout4->addLayout(vboxLayout3);

        spacerItem6 = new QSpacerItem(40, 20, QSizePolicy::Policy::Expanding, QSizePolicy::Policy::Minimum);

        hboxLayout4->addItem(spacerItem6);


        vboxLayout2->addLayout(hboxLayout4);


        hboxLayout->addLayout(vboxLayout2);


        vboxLayout->addWidget(DataFrame);


        retranslateUi(DetailsData);

        QMetaObject::connectSlotsByName(DetailsData);
    } // setupUi

    void retranslateUi(QWidget *DetailsData)
    {
        Names->setText(tr2i18n("Primary Name, Other Names", nullptr));
        ObjectTypeInConstellation->setText(tr2i18n("Object_type_in_Constellation", "KDE::DoNotExtract"));
        Magnitude->setText(tr2i18n("0.0 mag", nullptr));
        AngSizeLabel->setText(tr2i18n("Size:", nullptr));
        AngSize->setText(tr2i18n("0.0 arcmin", nullptr));
        Illumination->setText(QString());
        BVLabel->setText(tr2i18n("B - V index:", nullptr));
        BVLabel->setProperty("anchor", QVariant(tr2i18n("colorandtemp", "KDE::DoNotExtract")));
        DistanceLabel->setText(tr2i18n("Distance:", nullptr));
        DistanceLabel->setProperty("anchor", QVariant(tr2i18n("cosmicdist", "KDE::DoNotExtract")));
        MagLabel->setText(tr2i18n("Magnitude:", nullptr));
        MagLabel->setProperty("anchor", QVariant(tr2i18n("magnitude", "KDE::DoNotExtract")));
        IllumLabel->setText(tr2i18n("Illumination:", nullptr));
        Distance->setText(tr2i18n("0.0 pc", nullptr));
        BVIndex->setText(tr2i18n("--", nullptr));
        CatalogLabel->setText(tr2i18n("Catalog:", nullptr));
        Catalog->setText(QString());
        ObsListButton->setText(tr2i18n("Add to Observing List", nullptr));
        CenterButton->setText(tr2i18n("Center in Map", nullptr));
        ScopeButton->setText(tr2i18n("Center in Telescope", nullptr));
        (void)DetailsData;
    } // retranslateUi

};

namespace Ui {
    class DetailsData: public Ui_DetailsData {};
} // namespace Ui

QT_END_NAMESPACE

#endif // DETAILS_DATA_H

