/********************************************************************************
** Form generated from reading UI file 'opscatalog.ui'
**
** Created by: Qt User Interface Compiler version 6.11.1
**
** WARNING! All changes made in this file will be lost when recompiling UI file!
********************************************************************************/

#ifndef UI_OPSCATALOG_H
#define UI_OPSCATALOG_H

#include <QtCore/QVariant>
#include <QtWidgets/QApplication>
#include <QtWidgets/QButtonGroup>
#include <QtWidgets/QCheckBox>
#include <QtWidgets/QGridLayout>
#include <QtWidgets/QGroupBox>
#include <QtWidgets/QHBoxLayout>
#include <QtWidgets/QLabel>
#include <QtWidgets/QPushButton>
#include <QtWidgets/QSlider>
#include <QtWidgets/QSpacerItem>
#include <QtWidgets/QVBoxLayout>
#include <QtWidgets/QWidget>
#include <klocalizedstring.h>
#include "widgets/magnitudespinbox.h"

QT_BEGIN_NAMESPACE

class Ui_OpsCatalog
{
public:
    QVBoxLayout *vboxLayout;
    QGroupBox *StarBox;
    QHBoxLayout *hboxLayout;
    QVBoxLayout *vboxLayout1;
    QCheckBox *kcfg_ShowStars;
    QGridLayout *gridLayout;
    QLabel *LabelStarDensity;
    QSlider *kcfg_StarDensity;
    QSpacerItem *horizontalSpacer_2;
    QSpacerItem *horizontalSpacer_3;
    QGridLayout *gridLayout1;
    QCheckBox *kcfg_ShowStarNames;
    QCheckBox *kcfg_ShowStarMagnitudes;
    QCheckBox *kcfg_ShowStarsOverHIPS;
    QSpacerItem *spacerItem;
    QSpacerItem *spacerItem1;
    QHBoxLayout *hboxLayout1;
    QSpacerItem *spacerItem2;
    QLabel *LabelDensity;
    QSlider *kcfg_StarLabelDensity;
    QSpacerItem *horizontalSpacer;
    QGroupBox *DeepSkyBox;
    QVBoxLayout *vboxLayout2;
    QVBoxLayout *verticalLayout_2;
    QCheckBox *kcfg_ShowDeepSky;
    QHBoxLayout *horizontalLayout_5;
    QSpacerItem *horizontalSpacer_13;
    QLabel *DSOMInZoomLabel;
    QSlider *kcfg_DSOMinZoomFactor;
    QSpacerItem *horizontalSpacer_14;
    QHBoxLayout *horizontalLayout;
    QSpacerItem *horizontalSpacer_11;
    QLabel *DSOCacheLabel;
    QSlider *kcfg_DSOCachePercentage;
    QSpacerItem *horizontalSpacer_12;
    QHBoxLayout *horizontalLayout_1;
    QSpacerItem *horizontalSpacer_4;
    QCheckBox *kcfg_ShowDeepSkyNames;
    QHBoxLayout *horizontalLayout_3;
    QSpacerItem *horizontalSpacer_9;
    QCheckBox *kcfg_DeepSkyLongLabels;
    QSpacerItem *horizontalSpacer_8;
    QHBoxLayout *horizontalLayout_4;
    QSpacerItem *horizontalSpacer_5;
    QCheckBox *kcfg_ShowDeepSkyMagnitudes;
    QHBoxLayout *horizontalLayout_2;
    QSpacerItem *horizontalSpacer_7;
    QLabel *DeepSkyLabelDensityLabel;
    QSlider *kcfg_DeepSkyLabelDensity;
    QSpacerItem *horizontalSpacer_6;
    QHBoxLayout *horizontalLayout_7;
    QSpacerItem *horizontalSpacer_15;
    QPushButton *manageButton;
    QHBoxLayout *hboxLayout2;
    QCheckBox *kcfg_ResolveNamesOnline;
    QHBoxLayout *hboxLayout3;
    QGridLayout *gridLayout2;
    MagnitudeSpinBox *kcfg_MagLimitDrawDeepSkyZoomOut;
    QLabel *LabelMagDeepSkyZoomOut;
    QLabel *LabelMag4;
    QLabel *LabelMagDeepSky;
    MagnitudeSpinBox *kcfg_MagLimitDrawDeepSky;
    QLabel *LabelMag3;
    QSpacerItem *horizontalSpacer_10;
    QCheckBox *kcfg_ShowUnknownMagObjects;
    QSpacerItem *spacer;
    QButtonGroup *catalogButtonGroup;

    void setupUi(QWidget *OpsCatalog)
    {
        if (OpsCatalog->objectName().isEmpty())
            OpsCatalog->setObjectName("OpsCatalog");
        OpsCatalog->resize(821, 564);
        vboxLayout = new QVBoxLayout(OpsCatalog);
        vboxLayout->setObjectName("vboxLayout");
        StarBox = new QGroupBox(OpsCatalog);
        StarBox->setObjectName("StarBox");
        hboxLayout = new QHBoxLayout(StarBox);
        hboxLayout->setObjectName("hboxLayout");
        vboxLayout1 = new QVBoxLayout();
        vboxLayout1->setObjectName("vboxLayout1");
        kcfg_ShowStars = new QCheckBox(StarBox);
        catalogButtonGroup = new QButtonGroup(OpsCatalog);
        catalogButtonGroup->setObjectName("catalogButtonGroup");
        catalogButtonGroup->setExclusive(false);
        catalogButtonGroup->addButton(kcfg_ShowStars);
        kcfg_ShowStars->setObjectName("kcfg_ShowStars");

        vboxLayout1->addWidget(kcfg_ShowStars);

        gridLayout = new QGridLayout();
        gridLayout->setSpacing(6);
        gridLayout->setObjectName("gridLayout");
        gridLayout->setContentsMargins(0, 0, 0, 0);
        LabelStarDensity = new QLabel(StarBox);
        LabelStarDensity->setObjectName("LabelStarDensity");

        gridLayout->addWidget(LabelStarDensity, 0, 1, 1, 1);

        kcfg_StarDensity = new QSlider(StarBox);
        kcfg_StarDensity->setObjectName("kcfg_StarDensity");
        kcfg_StarDensity->setMinimum(1);
        kcfg_StarDensity->setMaximum(100);
        kcfg_StarDensity->setSingleStep(1);
        kcfg_StarDensity->setOrientation(Qt::Horizontal);
        kcfg_StarDensity->setTickPosition(QSlider::NoTicks);
        kcfg_StarDensity->setTickInterval(1);

        gridLayout->addWidget(kcfg_StarDensity, 0, 2, 1, 1);

        horizontalSpacer_2 = new QSpacerItem(16, 20, QSizePolicy::Policy::Fixed, QSizePolicy::Policy::Minimum);

        gridLayout->addItem(horizontalSpacer_2, 0, 0, 1, 1);

        horizontalSpacer_3 = new QSpacerItem(40, 20, QSizePolicy::Policy::Expanding, QSizePolicy::Policy::Minimum);

        gridLayout->addItem(horizontalSpacer_3, 0, 3, 1, 1);


        vboxLayout1->addLayout(gridLayout);

        gridLayout1 = new QGridLayout();
        gridLayout1->setSpacing(6);
        gridLayout1->setObjectName("gridLayout1");
        gridLayout1->setContentsMargins(0, 0, 0, 0);
        kcfg_ShowStarNames = new QCheckBox(StarBox);
        catalogButtonGroup->addButton(kcfg_ShowStarNames);
        kcfg_ShowStarNames->setObjectName("kcfg_ShowStarNames");

        gridLayout1->addWidget(kcfg_ShowStarNames, 0, 1, 1, 1);

        kcfg_ShowStarMagnitudes = new QCheckBox(StarBox);
        catalogButtonGroup->addButton(kcfg_ShowStarMagnitudes);
        kcfg_ShowStarMagnitudes->setObjectName("kcfg_ShowStarMagnitudes");

        gridLayout1->addWidget(kcfg_ShowStarMagnitudes, 1, 1, 1, 1);

        kcfg_ShowStarsOverHIPS = new QCheckBox(StarBox);
        catalogButtonGroup->addButton(kcfg_ShowStarsOverHIPS);
        kcfg_ShowStarsOverHIPS->setObjectName("kcfg_ShowStarsOverHIPS");

        gridLayout1->addWidget(kcfg_ShowStarsOverHIPS, 2, 1, 1, 1);

        spacerItem = new QSpacerItem(16, 20, QSizePolicy::Policy::Fixed, QSizePolicy::Policy::Minimum);

        gridLayout1->addItem(spacerItem, 0, 0, 1, 1);

        spacerItem1 = new QSpacerItem(16, 20, QSizePolicy::Policy::Fixed, QSizePolicy::Policy::Minimum);

        gridLayout1->addItem(spacerItem1, 1, 0, 1, 1);


        vboxLayout1->addLayout(gridLayout1);

        hboxLayout1 = new QHBoxLayout();
        hboxLayout1->setObjectName("hboxLayout1");
        spacerItem2 = new QSpacerItem(40, 20, QSizePolicy::Policy::Fixed, QSizePolicy::Policy::Minimum);

        hboxLayout1->addItem(spacerItem2);

        LabelDensity = new QLabel(StarBox);
        LabelDensity->setObjectName("LabelDensity");

        hboxLayout1->addWidget(LabelDensity);

        kcfg_StarLabelDensity = new QSlider(StarBox);
        kcfg_StarLabelDensity->setObjectName("kcfg_StarLabelDensity");
        kcfg_StarLabelDensity->setMaximum(20);
        kcfg_StarLabelDensity->setOrientation(Qt::Horizontal);

        hboxLayout1->addWidget(kcfg_StarLabelDensity);

        horizontalSpacer = new QSpacerItem(40, 20, QSizePolicy::Policy::Expanding, QSizePolicy::Policy::Minimum);

        hboxLayout1->addItem(horizontalSpacer);


        vboxLayout1->addLayout(hboxLayout1);


        hboxLayout->addLayout(vboxLayout1);


        vboxLayout->addWidget(StarBox);

        DeepSkyBox = new QGroupBox(OpsCatalog);
        DeepSkyBox->setObjectName("DeepSkyBox");
        vboxLayout2 = new QVBoxLayout(DeepSkyBox);
        vboxLayout2->setSpacing(6);
        vboxLayout2->setObjectName("vboxLayout2");
        vboxLayout2->setContentsMargins(8, 8, 8, 8);
        verticalLayout_2 = new QVBoxLayout();
        verticalLayout_2->setObjectName("verticalLayout_2");
        verticalLayout_2->setContentsMargins(-1, 0, -1, 0);
        kcfg_ShowDeepSky = new QCheckBox(DeepSkyBox);
        catalogButtonGroup->addButton(kcfg_ShowDeepSky);
        kcfg_ShowDeepSky->setObjectName("kcfg_ShowDeepSky");

        verticalLayout_2->addWidget(kcfg_ShowDeepSky);

        horizontalLayout_5 = new QHBoxLayout();
        horizontalLayout_5->setObjectName("horizontalLayout_5");
        horizontalLayout_5->setSizeConstraint(QLayout::SetDefaultConstraint);
        horizontalLayout_5->setContentsMargins(-1, 0, -1, -1);
        horizontalSpacer_13 = new QSpacerItem(16, 20, QSizePolicy::Policy::Fixed, QSizePolicy::Policy::Minimum);

        horizontalLayout_5->addItem(horizontalSpacer_13);

        DSOMInZoomLabel = new QLabel(DeepSkyBox);
        DSOMInZoomLabel->setObjectName("DSOMInZoomLabel");

        horizontalLayout_5->addWidget(DSOMInZoomLabel);

        kcfg_DSOMinZoomFactor = new QSlider(DeepSkyBox);
        kcfg_DSOMinZoomFactor->setObjectName("kcfg_DSOMinZoomFactor");
        kcfg_DSOMinZoomFactor->setMinimum(250);
        kcfg_DSOMinZoomFactor->setMaximum(4000);
        kcfg_DSOMinZoomFactor->setPageStep(200);
        kcfg_DSOMinZoomFactor->setOrientation(Qt::Horizontal);

        horizontalLayout_5->addWidget(kcfg_DSOMinZoomFactor);

        horizontalSpacer_14 = new QSpacerItem(40, 20, QSizePolicy::Policy::Expanding, QSizePolicy::Policy::Minimum);

        horizontalLayout_5->addItem(horizontalSpacer_14);


        verticalLayout_2->addLayout(horizontalLayout_5);

        horizontalLayout = new QHBoxLayout();
        horizontalLayout->setSpacing(6);
        horizontalLayout->setObjectName("horizontalLayout");
        horizontalLayout->setSizeConstraint(QLayout::SetDefaultConstraint);
        horizontalLayout->setContentsMargins(-1, -1, -1, 0);
        horizontalSpacer_11 = new QSpacerItem(16, 20, QSizePolicy::Policy::Fixed, QSizePolicy::Policy::Minimum);

        horizontalLayout->addItem(horizontalSpacer_11);

        DSOCacheLabel = new QLabel(DeepSkyBox);
        DSOCacheLabel->setObjectName("DSOCacheLabel");

        horizontalLayout->addWidget(DSOCacheLabel);

        kcfg_DSOCachePercentage = new QSlider(DeepSkyBox);
        kcfg_DSOCachePercentage->setObjectName("kcfg_DSOCachePercentage");
        kcfg_DSOCachePercentage->setMinimum(5);
        kcfg_DSOCachePercentage->setMaximum(100);
        kcfg_DSOCachePercentage->setOrientation(Qt::Horizontal);
        kcfg_DSOCachePercentage->setTickPosition(QSlider::TicksBothSides);
        kcfg_DSOCachePercentage->setTickInterval(10);

        horizontalLayout->addWidget(kcfg_DSOCachePercentage);

        horizontalSpacer_12 = new QSpacerItem(40, 20, QSizePolicy::Policy::Expanding, QSizePolicy::Policy::Minimum);

        horizontalLayout->addItem(horizontalSpacer_12);


        verticalLayout_2->addLayout(horizontalLayout);

        horizontalLayout_1 = new QHBoxLayout();
        horizontalLayout_1->setObjectName("horizontalLayout_1");
        horizontalLayout_1->setContentsMargins(-1, 0, -1, -1);
        horizontalSpacer_4 = new QSpacerItem(16, 20, QSizePolicy::Policy::Fixed, QSizePolicy::Policy::Minimum);

        horizontalLayout_1->addItem(horizontalSpacer_4);

        kcfg_ShowDeepSkyNames = new QCheckBox(DeepSkyBox);
        catalogButtonGroup->addButton(kcfg_ShowDeepSkyNames);
        kcfg_ShowDeepSkyNames->setObjectName("kcfg_ShowDeepSkyNames");

        horizontalLayout_1->addWidget(kcfg_ShowDeepSkyNames);


        verticalLayout_2->addLayout(horizontalLayout_1);

        horizontalLayout_3 = new QHBoxLayout();
        horizontalLayout_3->setObjectName("horizontalLayout_3");
        horizontalLayout_3->setContentsMargins(-1, -1, -1, 0);
        horizontalSpacer_9 = new QSpacerItem(40, 20, QSizePolicy::Policy::Fixed, QSizePolicy::Policy::Minimum);

        horizontalLayout_3->addItem(horizontalSpacer_9);

        kcfg_DeepSkyLongLabels = new QCheckBox(DeepSkyBox);
        catalogButtonGroup->addButton(kcfg_DeepSkyLongLabels);
        kcfg_DeepSkyLongLabels->setObjectName("kcfg_DeepSkyLongLabels");

        horizontalLayout_3->addWidget(kcfg_DeepSkyLongLabels);

        horizontalSpacer_8 = new QSpacerItem(40, 20, QSizePolicy::Policy::Expanding, QSizePolicy::Policy::Minimum);

        horizontalLayout_3->addItem(horizontalSpacer_8);


        verticalLayout_2->addLayout(horizontalLayout_3);

        horizontalLayout_4 = new QHBoxLayout();
        horizontalLayout_4->setObjectName("horizontalLayout_4");
        horizontalLayout_4->setContentsMargins(-1, 0, -1, -1);
        horizontalSpacer_5 = new QSpacerItem(16, 20, QSizePolicy::Policy::Fixed, QSizePolicy::Policy::Minimum);

        horizontalLayout_4->addItem(horizontalSpacer_5);

        kcfg_ShowDeepSkyMagnitudes = new QCheckBox(DeepSkyBox);
        catalogButtonGroup->addButton(kcfg_ShowDeepSkyMagnitudes);
        kcfg_ShowDeepSkyMagnitudes->setObjectName("kcfg_ShowDeepSkyMagnitudes");

        horizontalLayout_4->addWidget(kcfg_ShowDeepSkyMagnitudes);


        verticalLayout_2->addLayout(horizontalLayout_4);

        horizontalLayout_2 = new QHBoxLayout();
        horizontalLayout_2->setObjectName("horizontalLayout_2");
        horizontalLayout_2->setContentsMargins(-1, -1, -1, 0);
        horizontalSpacer_7 = new QSpacerItem(40, 20, QSizePolicy::Policy::Fixed, QSizePolicy::Policy::Minimum);

        horizontalLayout_2->addItem(horizontalSpacer_7);

        DeepSkyLabelDensityLabel = new QLabel(DeepSkyBox);
        DeepSkyLabelDensityLabel->setObjectName("DeepSkyLabelDensityLabel");

        horizontalLayout_2->addWidget(DeepSkyLabelDensityLabel);

        kcfg_DeepSkyLabelDensity = new QSlider(DeepSkyBox);
        kcfg_DeepSkyLabelDensity->setObjectName("kcfg_DeepSkyLabelDensity");
        kcfg_DeepSkyLabelDensity->setMaximum(100);
        kcfg_DeepSkyLabelDensity->setOrientation(Qt::Horizontal);

        horizontalLayout_2->addWidget(kcfg_DeepSkyLabelDensity);

        horizontalSpacer_6 = new QSpacerItem(40, 20, QSizePolicy::Policy::Expanding, QSizePolicy::Policy::Minimum);

        horizontalLayout_2->addItem(horizontalSpacer_6);


        verticalLayout_2->addLayout(horizontalLayout_2);

        horizontalLayout_7 = new QHBoxLayout();
        horizontalLayout_7->setObjectName("horizontalLayout_7");
        horizontalLayout_7->setContentsMargins(-1, 0, -1, -1);
        horizontalSpacer_15 = new QSpacerItem(40, 20, QSizePolicy::Policy::Expanding, QSizePolicy::Policy::Minimum);

        horizontalLayout_7->addItem(horizontalSpacer_15);

        manageButton = new QPushButton(DeepSkyBox);
        manageButton->setObjectName("manageButton");

        horizontalLayout_7->addWidget(manageButton);


        verticalLayout_2->addLayout(horizontalLayout_7);


        vboxLayout2->addLayout(verticalLayout_2);

        hboxLayout2 = new QHBoxLayout();
        hboxLayout2->setObjectName("hboxLayout2");
        kcfg_ResolveNamesOnline = new QCheckBox(DeepSkyBox);
        kcfg_ResolveNamesOnline->setObjectName("kcfg_ResolveNamesOnline");

        hboxLayout2->addWidget(kcfg_ResolveNamesOnline);


        vboxLayout2->addLayout(hboxLayout2);

        hboxLayout3 = new QHBoxLayout();
        hboxLayout3->setSpacing(6);
        hboxLayout3->setObjectName("hboxLayout3");
        hboxLayout3->setContentsMargins(0, 0, 0, 0);
        gridLayout2 = new QGridLayout();
        gridLayout2->setSpacing(6);
        gridLayout2->setObjectName("gridLayout2");
        gridLayout2->setContentsMargins(0, 0, 0, 0);
        kcfg_MagLimitDrawDeepSkyZoomOut = new MagnitudeSpinBox(DeepSkyBox);
        kcfg_MagLimitDrawDeepSkyZoomOut->setObjectName("kcfg_MagLimitDrawDeepSkyZoomOut");
        kcfg_MagLimitDrawDeepSkyZoomOut->setMaximum(36.000000000000000);

        gridLayout2->addWidget(kcfg_MagLimitDrawDeepSkyZoomOut, 1, 1, 1, 1);

        LabelMagDeepSkyZoomOut = new QLabel(DeepSkyBox);
        LabelMagDeepSkyZoomOut->setObjectName("LabelMagDeepSkyZoomOut");

        gridLayout2->addWidget(LabelMagDeepSkyZoomOut, 1, 0, 1, 1);

        LabelMag4 = new QLabel(DeepSkyBox);
        LabelMag4->setObjectName("LabelMag4");

        gridLayout2->addWidget(LabelMag4, 1, 2, 1, 1);

        LabelMagDeepSky = new QLabel(DeepSkyBox);
        LabelMagDeepSky->setObjectName("LabelMagDeepSky");

        gridLayout2->addWidget(LabelMagDeepSky, 0, 0, 1, 1);

        kcfg_MagLimitDrawDeepSky = new MagnitudeSpinBox(DeepSkyBox);
        kcfg_MagLimitDrawDeepSky->setObjectName("kcfg_MagLimitDrawDeepSky");
        kcfg_MagLimitDrawDeepSky->setMaximum(36.000000000000000);

        gridLayout2->addWidget(kcfg_MagLimitDrawDeepSky, 0, 1, 1, 1);

        LabelMag3 = new QLabel(DeepSkyBox);
        LabelMag3->setObjectName("LabelMag3");

        gridLayout2->addWidget(LabelMag3, 0, 2, 1, 1);


        hboxLayout3->addLayout(gridLayout2);

        horizontalSpacer_10 = new QSpacerItem(10, 20, QSizePolicy::Policy::Fixed, QSizePolicy::Policy::Minimum);

        hboxLayout3->addItem(horizontalSpacer_10);

        kcfg_ShowUnknownMagObjects = new QCheckBox(DeepSkyBox);
        catalogButtonGroup->addButton(kcfg_ShowUnknownMagObjects);
        kcfg_ShowUnknownMagObjects->setObjectName("kcfg_ShowUnknownMagObjects");

        hboxLayout3->addWidget(kcfg_ShowUnknownMagObjects);

        spacer = new QSpacerItem(40, 20, QSizePolicy::Policy::Expanding, QSizePolicy::Policy::Minimum);

        hboxLayout3->addItem(spacer);


        vboxLayout2->addLayout(hboxLayout3);


        vboxLayout->addWidget(DeepSkyBox);


        retranslateUi(OpsCatalog);

        QMetaObject::connectSlotsByName(OpsCatalog);
    } // setupUi

    void retranslateUi(QWidget *OpsCatalog)
    {
        StarBox->setTitle(QString());
        kcfg_ShowStars->setText(tr2i18n("&Star catalogs", nullptr));
        LabelStarDensity->setText(tr2i18n("Star density:", nullptr));
        kcfg_ShowStarNames->setText(tr2i18n("Show &name", nullptr));
        kcfg_ShowStarMagnitudes->setText(tr2i18n("Show ma&gnitude", nullptr));
        kcfg_ShowStarsOverHIPS->setText(tr2i18n("Display stars when HIPS is displayed", nullptr));
        LabelDensity->setText(tr2i18n("Label density:", nullptr));
        DeepSkyBox->setTitle(QString());
        kcfg_ShowDeepSky->setText(tr2i18n("Deep-sky catalogs", nullptr));
        DSOMInZoomLabel->setText(tr2i18n("DSO minimal zoom:", nullptr));
        DSOCacheLabel->setText(tr2i18n("DSO cache percentage:", nullptr));
        kcfg_ShowDeepSkyNames->setText(tr2i18n("Show na&me", nullptr));
        kcfg_DeepSkyLongLabels->setText(tr2i18n("Show &long names", nullptr));
        kcfg_ShowDeepSkyMagnitudes->setText(tr2i18n("Show magni&tude", nullptr));
        DeepSkyLabelDensityLabel->setText(tr2i18n("Label density:", nullptr));
        manageButton->setText(tr2i18n("Manage Deep Sky Catalogs...", nullptr));
#if QT_CONFIG(tooltip)
        kcfg_ResolveNamesOnline->setToolTip(tr2i18n("If this checkbox is checked, when an object name unknown to KStars is entered in the Find Dialog, KStars will contact online services (such as CDS Sesame) to learn about the object and then add it to the database.\n"
"The objects acquired in this manner are stored under a catalog that is called user, and it can be edited using the \"Manage DSO Catalogs\" feature.", nullptr));
#endif // QT_CONFIG(tooltip)
        kcfg_ResolveNamesOnline->setText(tr2i18n("Resolve names not known to KStars using online services", nullptr));
#if QT_CONFIG(tooltip)
        kcfg_MagLimitDrawDeepSkyZoomOut->setToolTip(tr2i18n("Set the faint magnitude limit for deep-sky objects when zoomed out.", nullptr));
#endif // QT_CONFIG(tooltip)
#if QT_CONFIG(tooltip)
        LabelMagDeepSkyZoomOut->setToolTip(tr2i18n("Set the faint magnitude limit for deep-sky objects when zoomed out.", nullptr));
#endif // QT_CONFIG(tooltip)
        LabelMagDeepSkyZoomOut->setText(tr2i18n("Faint limit zoomed out:", nullptr));
#if QT_CONFIG(tooltip)
        LabelMag4->setToolTip(tr2i18n("Set the faint magnitude limits for deep-sky objects when zoomed out.", nullptr));
#endif // QT_CONFIG(tooltip)
        LabelMag4->setText(tr2i18n("mag", nullptr));
#if QT_CONFIG(tooltip)
        LabelMagDeepSky->setToolTip(tr2i18n("Set the faint magnitude limits for deep-sky objects when zoomed in.", nullptr));
#endif // QT_CONFIG(tooltip)
        LabelMagDeepSky->setText(tr2i18n("Faint limit zoomed in:", nullptr));
#if QT_CONFIG(tooltip)
        kcfg_MagLimitDrawDeepSky->setToolTip(tr2i18n("Set the faint magnitude limits for deep-sky objects when zoomed in.", nullptr));
#endif // QT_CONFIG(tooltip)
#if QT_CONFIG(tooltip)
        LabelMag3->setToolTip(tr2i18n("Set the faint magnitude limits for deep-sky objects when zoomed in.", nullptr));
#endif // QT_CONFIG(tooltip)
        LabelMag3->setText(tr2i18n("mag", nullptr));
#if QT_CONFIG(tooltip)
        kcfg_ShowUnknownMagObjects->setToolTip(tr2i18n("Many objects do not have known magnitudes in the databases.\n"
"They generally tend to be faint or very diffuse, but this is not always the case.\n"
"Check this checkbox to show such objects which do not have known magnitudes in the database.", nullptr));
#endif // QT_CONFIG(tooltip)
        kcfg_ShowUnknownMagObjects->setText(tr2i18n("Show objects of unknown magnitude", nullptr));
        (void)OpsCatalog;
    } // retranslateUi

};

namespace Ui {
    class OpsCatalog: public Ui_OpsCatalog {};
} // namespace Ui

QT_END_NAMESPACE

#endif // OPSCATALOG_H

