/********************************************************************************
** Form generated from reading UI file 'argsetcolor.ui'
**
** Created by: Qt User Interface Compiler version 6.11.1
**
** WARNING! All changes made in this file will be lost when recompiling UI file!
********************************************************************************/

#ifndef UI_ARGSETCOLOR_H
#define UI_ARGSETCOLOR_H

#include <QtCore/QVariant>
#include <QtWidgets/QApplication>
#include <QtWidgets/QComboBox>
#include <QtWidgets/QGridLayout>
#include <QtWidgets/QHBoxLayout>
#include <QtWidgets/QLabel>
#include <QtWidgets/QSpacerItem>
#include <QtWidgets/QVBoxLayout>
#include <QtWidgets/QWidget>
#include <klocalizedstring.h>
#include "kcolorbutton.h"

QT_BEGIN_NAMESPACE

class Ui_ArgSetColor
{
public:
    QVBoxLayout *vboxLayout;
    QGridLayout *gridLayout;
    QLabel *textLabel1;
    QLabel *textLabel2;
    QHBoxLayout *hboxLayout;
    KColorButton *ColorValue;
    QSpacerItem *spacerItem;
    QComboBox *ColorName;
    QSpacerItem *spacerItem1;

    void setupUi(QWidget *ArgSetColor)
    {
        if (ArgSetColor->objectName().isEmpty())
            ArgSetColor->setObjectName("ArgSetColor");
        ArgSetColor->resize(334, 200);
        vboxLayout = new QVBoxLayout(ArgSetColor);
#ifndef UI_Q_OS_MAC
        vboxLayout->setSpacing(6);
#endif
        vboxLayout->setContentsMargins(10, 10, 10, 10);
        vboxLayout->setObjectName("vboxLayout");
        gridLayout = new QGridLayout();
#ifndef UI_Q_OS_MAC
        gridLayout->setSpacing(6);
#endif
#ifndef UI_Q_OS_MAC
        gridLayout->setContentsMargins(0, 0, 0, 0);
#endif
        gridLayout->setObjectName("gridLayout");
        textLabel1 = new QLabel(ArgSetColor);
        textLabel1->setObjectName("textLabel1");

        gridLayout->addWidget(textLabel1, 0, 0, 1, 1);

        textLabel2 = new QLabel(ArgSetColor);
        textLabel2->setObjectName("textLabel2");

        gridLayout->addWidget(textLabel2, 1, 0, 1, 1);

        hboxLayout = new QHBoxLayout();
#ifndef UI_Q_OS_MAC
        hboxLayout->setSpacing(6);
#endif
        hboxLayout->setContentsMargins(0, 0, 0, 0);
        hboxLayout->setObjectName("hboxLayout");
        ColorValue = new KColorButton(ArgSetColor);
        ColorValue->setObjectName("ColorValue");

        hboxLayout->addWidget(ColorValue);

        spacerItem = new QSpacerItem(40, 20, QSizePolicy::Policy::Expanding, QSizePolicy::Policy::Minimum);

        hboxLayout->addItem(spacerItem);


        gridLayout->addLayout(hboxLayout, 1, 1, 1, 1);

        ColorName = new QComboBox(ArgSetColor);
        ColorName->setObjectName("ColorName");

        gridLayout->addWidget(ColorName, 0, 1, 1, 1);


        vboxLayout->addLayout(gridLayout);

        spacerItem1 = new QSpacerItem(20, 40, QSizePolicy::Policy::Minimum, QSizePolicy::Policy::Expanding);

        vboxLayout->addItem(spacerItem1);


        retranslateUi(ArgSetColor);

        QMetaObject::connectSlotsByName(ArgSetColor);
    } // setupUi

    void retranslateUi(QWidget *ArgSetColor)
    {
        textLabel1->setText(tr2i18n("Color name:", nullptr));
        textLabel2->setText(tr2i18n("Color value:", nullptr));
        ColorValue->setText(QString());
        (void)ArgSetColor;
    } // retranslateUi

};

namespace Ui {
    class ArgSetColor: public Ui_ArgSetColor {};
} // namespace Ui

QT_END_NAMESPACE

#endif // ARGSETCOLOR_H

