/****************************************************************************
** Meta object code from reading C++ file 'genericdeviceadaptor.h'
**
** Created by: The Qt Meta Object Compiler version 69 (Qt 6.11.1)
**
** WARNING! All changes made in this file will be lost!
*****************************************************************************/

#include "genericdeviceadaptor.h"
#include <QtCore/qmetatype.h>

#include <QtCore/qtmochelpers.h>

#include <memory>


#include <QtCore/qxptype_traits.h>
#if !defined(Q_MOC_OUTPUT_REVISION)
#error "The header file 'genericdeviceadaptor.h' doesn't include <QObject>."
#elif Q_MOC_OUTPUT_REVISION != 69
#error "This file was generated using the moc from 6.11.1. It"
#error "cannot be used with the include files from this version of Qt."
#error "(The moc has changed too much.)"
#endif

#ifndef Q_CONSTINIT
#define Q_CONSTINIT
#endif

QT_WARNING_PUSH
QT_WARNING_DISABLE_DEPRECATED
QT_WARNING_DISABLE_GCC("-Wuseless-cast")
namespace {
struct qt_meta_tag_ZN20GenericDeviceAdaptorE_t {};
} // unnamed namespace

template <> constexpr inline auto GenericDeviceAdaptor::qt_create_metaobjectdata<qt_meta_tag_ZN20GenericDeviceAdaptorE_t>()
{
    namespace QMC = QtMocConstants;
    QtMocHelpers::StringRefStorage qt_stringData {
        "GenericDeviceAdaptor",
        "D-Bus Interface",
        "org.kde.kstars.INDI.GenericDevice",
        "D-Bus Introspection",
        "  <interface name=\"org.kde.kstars.INDI.GenericDevice\">\n    <pro"
        "perty access=\"read\" type=\"s\" name=\"name\"/>\n    <property ac"
        "cess=\"read\" type=\"i\" name=\"driverInterface\"/>\n    <property"
        " access=\"read\" type=\"s\" name=\"driverVersion\"/>\n    <propert"
        "y access=\"read\" type=\"b\" name=\"connected\"/>\n    <method nam"
        "e=\"Connect\">\n      <annotation value=\"true\" name=\"org.freede"
        "sktop.DBus.Method.NoReply\"/>\n    </method>\n    <method name=\"D"
        "isconnect\">\n      <annotation value=\"true\" name=\"org.freedesk"
        "top.DBus.Method.NoReply\"/>\n    </method>\n    <signal name=\"Con"
        "nected\"/>\n    <signal name=\"Disconnected\"/>\n    <signal name="
        "\"ready\"/>\n  </interface>\n",
        "Connected",
        "",
        "Disconnected",
        "ready",
        "Connect",
        "Q_NOREPLY",
        "Disconnect",
        "connected",
        "driverInterface",
        "driverVersion",
        "name"
    };

    QtMocHelpers::UintData qt_methods {
        // Signal 'Connected'
        QtMocHelpers::SignalData<void()>(5, 6, QMC::AccessPublic, QMetaType::Void),
        // Signal 'Disconnected'
        QtMocHelpers::SignalData<void()>(7, 6, QMC::AccessPublic, QMetaType::Void),
        // Signal 'ready'
        QtMocHelpers::SignalData<void()>(8, 6, QMC::AccessPublic, QMetaType::Void),
        // Slot 'Connect'
        QtMocHelpers::SlotData<void()>(9, 10, QMC::AccessPublic, QMetaType::Void),
        // Slot 'Disconnect'
        QtMocHelpers::SlotData<void()>(11, 10, QMC::AccessPublic, QMetaType::Void),
    };
    QtMocHelpers::UintData qt_properties {
        // property 'connected'
        QtMocHelpers::PropertyData<bool>(12, QMetaType::Bool, QMC::DefaultPropertyFlags),
        // property 'driverInterface'
        QtMocHelpers::PropertyData<int>(13, QMetaType::Int, QMC::DefaultPropertyFlags),
        // property 'driverVersion'
        QtMocHelpers::PropertyData<QString>(14, QMetaType::QString, QMC::DefaultPropertyFlags),
        // property 'name'
        QtMocHelpers::PropertyData<QString>(15, QMetaType::QString, QMC::DefaultPropertyFlags),
    };
    QtMocHelpers::UintData qt_enums {
    };
    QtMocHelpers::UintData qt_constructors {};
    QtMocHelpers::ClassInfos qt_classinfo({
            {    1,    2 },
            {    3,    4 },
    });
    return QtMocHelpers::metaObjectData<GenericDeviceAdaptor, qt_meta_tag_ZN20GenericDeviceAdaptorE_t>(QMC::MetaObjectFlag{}, qt_stringData,
            qt_methods, qt_properties, qt_enums, qt_constructors, qt_classinfo);
}
Q_CONSTINIT const QMetaObject GenericDeviceAdaptor::staticMetaObject = { {
    QMetaObject::SuperData::link<QDBusAbstractAdaptor::staticMetaObject>(),
    qt_staticMetaObjectStaticContent<qt_meta_tag_ZN20GenericDeviceAdaptorE_t>.stringdata,
    qt_staticMetaObjectStaticContent<qt_meta_tag_ZN20GenericDeviceAdaptorE_t>.data,
    qt_static_metacall,
    nullptr,
    qt_staticMetaObjectRelocatingContent<qt_meta_tag_ZN20GenericDeviceAdaptorE_t>.metaTypes,
    nullptr
} };

void GenericDeviceAdaptor::qt_static_metacall(QObject *_o, QMetaObject::Call _c, int _id, void **_a)
{
    auto *_t = static_cast<GenericDeviceAdaptor *>(_o);
    if (_c == QMetaObject::InvokeMetaMethod) {
        switch (_id) {
        case 0: _t->Connected(); break;
        case 1: _t->Disconnected(); break;
        case 2: _t->ready(); break;
        case 3: _t->Connect(); break;
        case 4: _t->Disconnect(); break;
        default: ;
        }
    }
    if (_c == QMetaObject::IndexOfMethod) {
        if (QtMocHelpers::indexOfMethod<void (GenericDeviceAdaptor::*)()>(_a, &GenericDeviceAdaptor::Connected, 0))
            return;
        if (QtMocHelpers::indexOfMethod<void (GenericDeviceAdaptor::*)()>(_a, &GenericDeviceAdaptor::Disconnected, 1))
            return;
        if (QtMocHelpers::indexOfMethod<void (GenericDeviceAdaptor::*)()>(_a, &GenericDeviceAdaptor::ready, 2))
            return;
    }
    if (_c == QMetaObject::ReadProperty) {
        void *_v = _a[0];
        switch (_id) {
        case 0: *reinterpret_cast<bool*>(_v) = _t->connected(); break;
        case 1: *reinterpret_cast<int*>(_v) = _t->driverInterface(); break;
        case 2: *reinterpret_cast<QString*>(_v) = _t->driverVersion(); break;
        case 3: *reinterpret_cast<QString*>(_v) = _t->name(); break;
        default: break;
        }
    }
}

const QMetaObject *GenericDeviceAdaptor::metaObject() const
{
    return QObject::d_ptr->metaObject ? QObject::d_ptr->dynamicMetaObject() : &staticMetaObject;
}

void *GenericDeviceAdaptor::qt_metacast(const char *_clname)
{
    if (!_clname) return nullptr;
    if (!strcmp(_clname, qt_staticMetaObjectStaticContent<qt_meta_tag_ZN20GenericDeviceAdaptorE_t>.strings))
        return static_cast<void*>(this);
    return QDBusAbstractAdaptor::qt_metacast(_clname);
}

int GenericDeviceAdaptor::qt_metacall(QMetaObject::Call _c, int _id, void **_a)
{
    _id = QDBusAbstractAdaptor::qt_metacall(_c, _id, _a);
    if (_id < 0)
        return _id;
    if (_c == QMetaObject::InvokeMetaMethod) {
        if (_id < 5)
            qt_static_metacall(this, _c, _id, _a);
        _id -= 5;
    }
    if (_c == QMetaObject::RegisterMethodArgumentMetaType) {
        if (_id < 5)
            *reinterpret_cast<QMetaType *>(_a[0]) = QMetaType();
        _id -= 5;
    }
    if (_c == QMetaObject::ReadProperty || _c == QMetaObject::WriteProperty
            || _c == QMetaObject::ResetProperty || _c == QMetaObject::BindableProperty
            || _c == QMetaObject::RegisterPropertyMetaType) {
        qt_static_metacall(this, _c, _id, _a);
        _id -= 4;
    }
    return _id;
}

// SIGNAL 0
void GenericDeviceAdaptor::Connected()
{
    QMetaObject::activate(this, &staticMetaObject, 0, nullptr);
}

// SIGNAL 1
void GenericDeviceAdaptor::Disconnected()
{
    QMetaObject::activate(this, &staticMetaObject, 1, nullptr);
}

// SIGNAL 2
void GenericDeviceAdaptor::ready()
{
    QMetaObject::activate(this, &staticMetaObject, 2, nullptr);
}
QT_WARNING_POP
