/********************************************************************************
** Form generated from reading UI file 'opsekos.ui'
**
** Created by: Qt User Interface Compiler version 6.11.1
**
** WARNING! All changes made in this file will be lost when recompiling UI file!
********************************************************************************/

#ifndef UI_OPSEKOS_H
#define UI_OPSEKOS_H

#include <QtCore/QVariant>
#include <QtGui/QIcon>
#include <QtWidgets/QApplication>
#include <QtWidgets/QButtonGroup>
#include <QtWidgets/QCheckBox>
#include <QtWidgets/QGroupBox>
#include <QtWidgets/QHBoxLayout>
#include <QtWidgets/QHeaderView>
#include <QtWidgets/QLabel>
#include <QtWidgets/QLineEdit>
#include <QtWidgets/QPushButton>
#include <QtWidgets/QRadioButton>
#include <QtWidgets/QSpacerItem>
#include <QtWidgets/QSpinBox>
#include <QtWidgets/QTabWidget>
#include <QtWidgets/QTreeWidget>
#include <QtWidgets/QVBoxLayout>
#include <QtWidgets/QWidget>
#include <kled.h>
#include <klocalizedstring.h>

QT_BEGIN_NAMESPACE

class Ui_OpsEkos
{
public:
    QWidget *generalTab;
    QVBoxLayout *verticalLayout_3;
    QVBoxLayout *verticalLayout;
    QGroupBox *groupBox_3;
    QVBoxLayout *verticalLayout_2;
    QRadioButton *kcfg_neverLoadConfig;
    QRadioButton *kcfg_loadConfigOnConnection;
    QRadioButton *kcfg_loadDefaultConfig;
    QHBoxLayout *horizontalLayout_3;
    QLabel *label_4;
    QRadioButton *kcfg_EkosTopIcons;
    QRadioButton *kcfg_EkosLeftIcons;
    QSpacerItem *horizontalSpacer_3;
    QCheckBox *kcfg_independentWindowEkos;
    QSpacerItem *verticalSpacer_2;
    QWidget *analyzeTab;
    QVBoxLayout *analyzeLayout;
    QGroupBox *analyzeGroupBox;
    QVBoxLayout *verticalLayout_4;
    QCheckBox *kcfg_AnalyzeRestartWithEkos;
    QHBoxLayout *horizontalLayout_2;
    QLabel *AnalyzeAlternativeDirectoryLabel;
    QPushButton *analyzeAlternativeDirectoryB;
    QLineEdit *kcfg_AnalyzeAlternativeDirectoryName;
    QSpacerItem *verticalSpacer;
    QWidget *mcpTab;
    QVBoxLayout *mcpTabLayout;
    QGroupBox *mcpGroupBox;
    QVBoxLayout *verticalLayout_mcp;
    QCheckBox *kcfg_MCPEnabled;
    QHBoxLayout *horizontalLayout_mcp;
    QLabel *mcpPortLabel;
    QSpinBox *kcfg_MCPPort;
    KLed *mcpStatusLed;
    QSpacerItem *horizontalSpacer_mcp;
    QHBoxLayout *horizontalLayout_mcp_token;
    QLabel *mcpTokenLabel;
    QLineEdit *mcpTokenEdit;
    QPushButton *mcpShowTokenButton;
    QPushButton *mcpCopyTokenButton;
    QPushButton *mcpRegenTokenButton;
    QCheckBox *kcfg_MCPReadOnlyMode;
    QHBoxLayout *horizontalLayout_mcp_ro_token;
    QLabel *mcpROTokenLabel;
    QLineEdit *mcpROTokenEdit;
    QPushButton *mcpShowROTokenButton;
    QPushButton *mcpCopyROTokenButton;
    QPushButton *mcpRegenROTokenButton;
    QGroupBox *mcpToolsGroupBox;
    QVBoxLayout *mcpToolsLayout;
    QTreeWidget *mcpToolsTree;
    QSpacerItem *verticalSpacer_mcp;
    QButtonGroup *ekosIconsPositionGroup;

    void setupUi(QTabWidget *OpsEkos)
    {
        if (OpsEkos->objectName().isEmpty())
            OpsEkos->setObjectName("OpsEkos");
        OpsEkos->resize(268, 211);
        generalTab = new QWidget();
        generalTab->setObjectName("generalTab");
        verticalLayout_3 = new QVBoxLayout(generalTab);
        verticalLayout_3->setSpacing(3);
        verticalLayout_3->setObjectName("verticalLayout_3");
        verticalLayout_3->setContentsMargins(3, 3, 3, 3);
        verticalLayout = new QVBoxLayout();
        verticalLayout->setObjectName("verticalLayout");
        groupBox_3 = new QGroupBox(generalTab);
        groupBox_3->setObjectName("groupBox_3");
        verticalLayout_2 = new QVBoxLayout(groupBox_3);
        verticalLayout_2->setSpacing(3);
        verticalLayout_2->setObjectName("verticalLayout_2");
        verticalLayout_2->setContentsMargins(3, 3, 3, 3);
        kcfg_neverLoadConfig = new QRadioButton(groupBox_3);
        kcfg_neverLoadConfig->setObjectName("kcfg_neverLoadConfig");
        kcfg_neverLoadConfig->setChecked(true);

        verticalLayout_2->addWidget(kcfg_neverLoadConfig);

        kcfg_loadConfigOnConnection = new QRadioButton(groupBox_3);
        kcfg_loadConfigOnConnection->setObjectName("kcfg_loadConfigOnConnection");

        verticalLayout_2->addWidget(kcfg_loadConfigOnConnection);

        kcfg_loadDefaultConfig = new QRadioButton(groupBox_3);
        kcfg_loadDefaultConfig->setObjectName("kcfg_loadDefaultConfig");

        verticalLayout_2->addWidget(kcfg_loadDefaultConfig);


        verticalLayout->addWidget(groupBox_3);

        horizontalLayout_3 = new QHBoxLayout();
        horizontalLayout_3->setSpacing(3);
        horizontalLayout_3->setObjectName("horizontalLayout_3");
        label_4 = new QLabel(generalTab);
        label_4->setObjectName("label_4");

        horizontalLayout_3->addWidget(label_4);

        kcfg_EkosTopIcons = new QRadioButton(generalTab);
        ekosIconsPositionGroup = new QButtonGroup(OpsEkos);
        ekosIconsPositionGroup->setObjectName("ekosIconsPositionGroup");
        ekosIconsPositionGroup->addButton(kcfg_EkosTopIcons);
        kcfg_EkosTopIcons->setObjectName("kcfg_EkosTopIcons");
        kcfg_EkosTopIcons->setChecked(true);

        horizontalLayout_3->addWidget(kcfg_EkosTopIcons);

        kcfg_EkosLeftIcons = new QRadioButton(generalTab);
        ekosIconsPositionGroup->addButton(kcfg_EkosLeftIcons);
        kcfg_EkosLeftIcons->setObjectName("kcfg_EkosLeftIcons");

        horizontalLayout_3->addWidget(kcfg_EkosLeftIcons);

        horizontalSpacer_3 = new QSpacerItem(40, 20, QSizePolicy::Policy::Expanding, QSizePolicy::Policy::Minimum);

        horizontalLayout_3->addItem(horizontalSpacer_3);


        verticalLayout->addLayout(horizontalLayout_3);

        kcfg_independentWindowEkos = new QCheckBox(generalTab);
        kcfg_independentWindowEkos->setObjectName("kcfg_independentWindowEkos");

        verticalLayout->addWidget(kcfg_independentWindowEkos);


        verticalLayout_3->addLayout(verticalLayout);

        verticalSpacer_2 = new QSpacerItem(20, 40, QSizePolicy::Policy::Minimum, QSizePolicy::Policy::Expanding);

        verticalLayout_3->addItem(verticalSpacer_2);

        OpsEkos->addTab(generalTab, QString());
        analyzeTab = new QWidget();
        analyzeTab->setObjectName("analyzeTab");
        analyzeLayout = new QVBoxLayout(analyzeTab);
        analyzeLayout->setSpacing(3);
        analyzeLayout->setObjectName("analyzeLayout");
        analyzeLayout->setContentsMargins(3, 3, 3, 3);
        analyzeGroupBox = new QGroupBox(analyzeTab);
        analyzeGroupBox->setObjectName("analyzeGroupBox");
        verticalLayout_4 = new QVBoxLayout(analyzeGroupBox);
        verticalLayout_4->setObjectName("verticalLayout_4");
        kcfg_AnalyzeRestartWithEkos = new QCheckBox(analyzeGroupBox);
        kcfg_AnalyzeRestartWithEkos->setObjectName("kcfg_AnalyzeRestartWithEkos");

        verticalLayout_4->addWidget(kcfg_AnalyzeRestartWithEkos);

        horizontalLayout_2 = new QHBoxLayout();
        horizontalLayout_2->setSpacing(1);
        horizontalLayout_2->setObjectName("horizontalLayout_2");
        horizontalLayout_2->setSizeConstraint(QLayout::SizeConstraint::SetDefaultConstraint);
        horizontalLayout_2->setContentsMargins(-1, -1, -1, 0);
        AnalyzeAlternativeDirectoryLabel = new QLabel(analyzeGroupBox);
        AnalyzeAlternativeDirectoryLabel->setObjectName("AnalyzeAlternativeDirectoryLabel");
        QSizePolicy sizePolicy(QSizePolicy::Policy::Fixed, QSizePolicy::Policy::Preferred);
        sizePolicy.setHorizontalStretch(0);
        sizePolicy.setVerticalStretch(0);
        sizePolicy.setHeightForWidth(AnalyzeAlternativeDirectoryLabel->sizePolicy().hasHeightForWidth());
        AnalyzeAlternativeDirectoryLabel->setSizePolicy(sizePolicy);

        horizontalLayout_2->addWidget(AnalyzeAlternativeDirectoryLabel);

        analyzeAlternativeDirectoryB = new QPushButton(analyzeGroupBox);
        analyzeAlternativeDirectoryB->setObjectName("analyzeAlternativeDirectoryB");
        sizePolicy.setHeightForWidth(analyzeAlternativeDirectoryB->sizePolicy().hasHeightForWidth());
        analyzeAlternativeDirectoryB->setSizePolicy(sizePolicy);
        analyzeAlternativeDirectoryB->setMaximumSize(QSize(32, 16777215));
        QIcon icon(QIcon::fromTheme(QString::fromUtf8("folder")));
        analyzeAlternativeDirectoryB->setIcon(icon);

        horizontalLayout_2->addWidget(analyzeAlternativeDirectoryB);

        kcfg_AnalyzeAlternativeDirectoryName = new QLineEdit(analyzeGroupBox);
        kcfg_AnalyzeAlternativeDirectoryName->setObjectName("kcfg_AnalyzeAlternativeDirectoryName");
        QSizePolicy sizePolicy1(QSizePolicy::Policy::Preferred, QSizePolicy::Policy::Preferred);
        sizePolicy1.setHorizontalStretch(0);
        sizePolicy1.setVerticalStretch(0);
        sizePolicy1.setHeightForWidth(kcfg_AnalyzeAlternativeDirectoryName->sizePolicy().hasHeightForWidth());
        kcfg_AnalyzeAlternativeDirectoryName->setSizePolicy(sizePolicy1);

        horizontalLayout_2->addWidget(kcfg_AnalyzeAlternativeDirectoryName);


        verticalLayout_4->addLayout(horizontalLayout_2);

        verticalSpacer = new QSpacerItem(20, 40, QSizePolicy::Policy::Minimum, QSizePolicy::Policy::Expanding);

        verticalLayout_4->addItem(verticalSpacer);


        analyzeLayout->addWidget(analyzeGroupBox);

        OpsEkos->addTab(analyzeTab, QString());
        mcpTab = new QWidget();
        mcpTab->setObjectName("mcpTab");
        mcpTabLayout = new QVBoxLayout(mcpTab);
        mcpTabLayout->setSpacing(3);
        mcpTabLayout->setObjectName("mcpTabLayout");
        mcpTabLayout->setContentsMargins(3, 3, 3, 3);
        mcpGroupBox = new QGroupBox(mcpTab);
        mcpGroupBox->setObjectName("mcpGroupBox");
        verticalLayout_mcp = new QVBoxLayout(mcpGroupBox);
        verticalLayout_mcp->setObjectName("verticalLayout_mcp");
        kcfg_MCPEnabled = new QCheckBox(mcpGroupBox);
        kcfg_MCPEnabled->setObjectName("kcfg_MCPEnabled");

        verticalLayout_mcp->addWidget(kcfg_MCPEnabled);

        horizontalLayout_mcp = new QHBoxLayout();
        horizontalLayout_mcp->setObjectName("horizontalLayout_mcp");
        mcpPortLabel = new QLabel(mcpGroupBox);
        mcpPortLabel->setObjectName("mcpPortLabel");

        horizontalLayout_mcp->addWidget(mcpPortLabel);

        kcfg_MCPPort = new QSpinBox(mcpGroupBox);
        kcfg_MCPPort->setObjectName("kcfg_MCPPort");
        kcfg_MCPPort->setMinimum(1024);
        kcfg_MCPPort->setMaximum(65535);

        horizontalLayout_mcp->addWidget(kcfg_MCPPort);

        mcpStatusLed = new KLed(mcpGroupBox);
        mcpStatusLed->setObjectName("mcpStatusLed");
        mcpStatusLed->setMinimumSize(QSize(16, 16));
        mcpStatusLed->setMaximumSize(QSize(20, 20));

        horizontalLayout_mcp->addWidget(mcpStatusLed);

        horizontalSpacer_mcp = new QSpacerItem(40, 20, QSizePolicy::Policy::Expanding, QSizePolicy::Policy::Minimum);

        horizontalLayout_mcp->addItem(horizontalSpacer_mcp);


        verticalLayout_mcp->addLayout(horizontalLayout_mcp);

        horizontalLayout_mcp_token = new QHBoxLayout();
        horizontalLayout_mcp_token->setObjectName("horizontalLayout_mcp_token");
        mcpTokenLabel = new QLabel(mcpGroupBox);
        mcpTokenLabel->setObjectName("mcpTokenLabel");

        horizontalLayout_mcp_token->addWidget(mcpTokenLabel);

        mcpTokenEdit = new QLineEdit(mcpGroupBox);
        mcpTokenEdit->setObjectName("mcpTokenEdit");
        mcpTokenEdit->setEchoMode(QLineEdit::Password);
        mcpTokenEdit->setReadOnly(true);

        horizontalLayout_mcp_token->addWidget(mcpTokenEdit);

        mcpShowTokenButton = new QPushButton(mcpGroupBox);
        mcpShowTokenButton->setObjectName("mcpShowTokenButton");
        mcpShowTokenButton->setMaximumSize(QSize(32, 16777215));
        QIcon icon1(QIcon::fromTheme(QString::fromUtf8("password-show-on")));
        mcpShowTokenButton->setIcon(icon1);
        mcpShowTokenButton->setCheckable(true);

        horizontalLayout_mcp_token->addWidget(mcpShowTokenButton);

        mcpCopyTokenButton = new QPushButton(mcpGroupBox);
        mcpCopyTokenButton->setObjectName("mcpCopyTokenButton");
        mcpCopyTokenButton->setMaximumSize(QSize(32, 16777215));
        QIcon icon2(QIcon::fromTheme(QString::fromUtf8("edit-copy")));
        mcpCopyTokenButton->setIcon(icon2);

        horizontalLayout_mcp_token->addWidget(mcpCopyTokenButton);

        mcpRegenTokenButton = new QPushButton(mcpGroupBox);
        mcpRegenTokenButton->setObjectName("mcpRegenTokenButton");

        horizontalLayout_mcp_token->addWidget(mcpRegenTokenButton);


        verticalLayout_mcp->addLayout(horizontalLayout_mcp_token);

        kcfg_MCPReadOnlyMode = new QCheckBox(mcpGroupBox);
        kcfg_MCPReadOnlyMode->setObjectName("kcfg_MCPReadOnlyMode");

        verticalLayout_mcp->addWidget(kcfg_MCPReadOnlyMode);

        horizontalLayout_mcp_ro_token = new QHBoxLayout();
        horizontalLayout_mcp_ro_token->setObjectName("horizontalLayout_mcp_ro_token");
        mcpROTokenLabel = new QLabel(mcpGroupBox);
        mcpROTokenLabel->setObjectName("mcpROTokenLabel");

        horizontalLayout_mcp_ro_token->addWidget(mcpROTokenLabel);

        mcpROTokenEdit = new QLineEdit(mcpGroupBox);
        mcpROTokenEdit->setObjectName("mcpROTokenEdit");
        mcpROTokenEdit->setEchoMode(QLineEdit::Password);
        mcpROTokenEdit->setReadOnly(true);

        horizontalLayout_mcp_ro_token->addWidget(mcpROTokenEdit);

        mcpShowROTokenButton = new QPushButton(mcpGroupBox);
        mcpShowROTokenButton->setObjectName("mcpShowROTokenButton");
        mcpShowROTokenButton->setMaximumSize(QSize(32, 16777215));
        mcpShowROTokenButton->setIcon(icon1);
        mcpShowROTokenButton->setCheckable(true);

        horizontalLayout_mcp_ro_token->addWidget(mcpShowROTokenButton);

        mcpCopyROTokenButton = new QPushButton(mcpGroupBox);
        mcpCopyROTokenButton->setObjectName("mcpCopyROTokenButton");
        mcpCopyROTokenButton->setMaximumSize(QSize(32, 16777215));
        mcpCopyROTokenButton->setIcon(icon2);

        horizontalLayout_mcp_ro_token->addWidget(mcpCopyROTokenButton);

        mcpRegenROTokenButton = new QPushButton(mcpGroupBox);
        mcpRegenROTokenButton->setObjectName("mcpRegenROTokenButton");

        horizontalLayout_mcp_ro_token->addWidget(mcpRegenROTokenButton);


        verticalLayout_mcp->addLayout(horizontalLayout_mcp_ro_token);


        mcpTabLayout->addWidget(mcpGroupBox);

        mcpToolsGroupBox = new QGroupBox(mcpTab);
        mcpToolsGroupBox->setObjectName("mcpToolsGroupBox");
        mcpToolsLayout = new QVBoxLayout(mcpToolsGroupBox);
        mcpToolsLayout->setObjectName("mcpToolsLayout");
        mcpToolsTree = new QTreeWidget(mcpToolsGroupBox);
        mcpToolsTree->setObjectName("mcpToolsTree");
        mcpToolsTree->setRootIsDecorated(true);
        mcpToolsTree->setAlternatingRowColors(true);
        mcpToolsTree->setUniformRowHeights(true);
        mcpToolsTree->setSortingEnabled(true);
        mcpToolsTree->setHeaderHidden(false);

        mcpToolsLayout->addWidget(mcpToolsTree);


        mcpTabLayout->addWidget(mcpToolsGroupBox);

        verticalSpacer_mcp = new QSpacerItem(20, 40, QSizePolicy::Policy::Minimum, QSizePolicy::Policy::Expanding);

        mcpTabLayout->addItem(verticalSpacer_mcp);

        OpsEkos->addTab(mcpTab, QString());

        retranslateUi(OpsEkos);

        OpsEkos->setCurrentIndex(0);


        QMetaObject::connectSlotsByName(OpsEkos);
    } // setupUi

    void retranslateUi(QTabWidget *OpsEkos)
    {
        OpsEkos->setWindowTitle(tr2i18n("TabWidget", nullptr));
        groupBox_3->setTitle(tr2i18n("Load device Configuration", nullptr));
        kcfg_neverLoadConfig->setText(tr2i18n("Ne&ver", nullptr));
        kcfg_loadConfigOnConnection->setText(tr2i18n("O&n connection", nullptr));
        kcfg_loadDefaultConfig->setText(tr2i18n("Alwa&ys load defaults", nullptr));
        label_4->setText(tr2i18n("Icons orientation:", nullptr));
#if QT_CONFIG(tooltip)
        kcfg_EkosTopIcons->setToolTip(tr2i18n("Ekos modules icons are placed on the top of pages", nullptr));
#endif // QT_CONFIG(tooltip)
        kcfg_EkosTopIcons->setText(tr2i18n("Top", nullptr));
#if QT_CONFIG(tooltip)
        kcfg_EkosLeftIcons->setToolTip(tr2i18n("Ekos module icons are placed to the left of pages", nullptr));
#endif // QT_CONFIG(tooltip)
        kcfg_EkosLeftIcons->setText(tr2i18n("&Left", nullptr));
#if QT_CONFIG(tooltip)
        kcfg_independentWindowEkos->setToolTip(tr2i18n("Make Ekos window independent from KStars main window. Requires restart to take effect.", nullptr));
#endif // QT_CONFIG(tooltip)
        kcfg_independentWindowEkos->setText(tr2i18n("Independent window", nullptr));
        OpsEkos->setTabText(OpsEkos->indexOf(generalTab), tr2i18n("General", nullptr));
        analyzeGroupBox->setTitle(tr2i18n("Settings", nullptr));
#if QT_CONFIG(tooltip)
        kcfg_AnalyzeRestartWithEkos->setToolTip(tr2i18n("<html><head/><body><p>If Analyze is running and Ekos is disconnected then reconnected, a new .analyze file will be created and written to, and the graphs in Analyze will only show the new session.</p></body></html>", nullptr));
#endif // QT_CONFIG(tooltip)
        kcfg_AnalyzeRestartWithEkos->setText(tr2i18n("Restart Analyze when Ekos Restarts", nullptr));
        AnalyzeAlternativeDirectoryLabel->setText(tr2i18n("Alternative Image Directory: ", nullptr));
#if QT_CONFIG(tooltip)
        analyzeAlternativeDirectoryB->setToolTip(tr2i18n("Set the alternative image directory for Analyze", nullptr));
#endif // QT_CONFIG(tooltip)
        analyzeAlternativeDirectoryB->setText(QString());
        kcfg_AnalyzeAlternativeDirectoryName->setText(QString());
        OpsEkos->setTabText(OpsEkos->indexOf(analyzeTab), tr2i18n("Analyze", nullptr));
        mcpGroupBox->setTitle(tr2i18n("AI Assistant (MCP)", nullptr));
        kcfg_MCPEnabled->setText(tr2i18n("Enable MCP server", nullptr));
        mcpPortLabel->setText(tr2i18n("Port:", nullptr));
#if QT_CONFIG(tooltip)
        mcpStatusLed->setToolTip(tr2i18n("MCP server status", nullptr));
#endif // QT_CONFIG(tooltip)
        mcpTokenLabel->setText(tr2i18n("Token:", nullptr));
#if QT_CONFIG(tooltip)
        mcpShowTokenButton->setToolTip(tr2i18n("Show token", nullptr));
#endif // QT_CONFIG(tooltip)
        mcpShowTokenButton->setText(QString());
#if QT_CONFIG(tooltip)
        mcpCopyTokenButton->setToolTip(tr2i18n("Copy token to clipboard", nullptr));
#endif // QT_CONFIG(tooltip)
        mcpCopyTokenButton->setText(QString());
        mcpRegenTokenButton->setText(tr2i18n("Regenerate", nullptr));
        kcfg_MCPReadOnlyMode->setText(tr2i18n("Read-only mode (refuse rig control tools)", nullptr));
        mcpROTokenLabel->setText(tr2i18n("Read-only token:", nullptr));
#if QT_CONFIG(tooltip)
        mcpShowROTokenButton->setToolTip(tr2i18n("Show token", nullptr));
#endif // QT_CONFIG(tooltip)
        mcpShowROTokenButton->setText(QString());
#if QT_CONFIG(tooltip)
        mcpCopyROTokenButton->setToolTip(tr2i18n("Copy token to clipboard", nullptr));
#endif // QT_CONFIG(tooltip)
        mcpCopyROTokenButton->setText(QString());
        mcpRegenROTokenButton->setText(tr2i18n("Regenerate", nullptr));
        mcpToolsGroupBox->setTitle(tr2i18n("Available tools", nullptr));
        QTreeWidgetItem *___qtreewidgetitem = mcpToolsTree->headerItem();
        ___qtreewidgetitem->setText(1, tr2i18n("Description", nullptr));
        ___qtreewidgetitem->setText(0, tr2i18n("Tool", nullptr));
        OpsEkos->setTabText(OpsEkos->indexOf(mcpTab), tr2i18n("MCP", nullptr));
    } // retranslateUi

};

namespace Ui {
    class OpsEkos: public Ui_OpsEkos {};
} // namespace Ui

QT_END_NAMESPACE

#endif // OPSEKOS_H

