/****************************************************************************
** Meta object code from reading C++ file 'camerastate.h'
**
** Created by: The Qt Meta Object Compiler version 69 (Qt 6.11.1)
**
** WARNING! All changes made in this file will be lost!
*****************************************************************************/

#include "../../../../kstars-3.8.4.1/kstars/ekos/capture/camerastate.h"
#include <QtNetwork/QSslError>
#include <QtDataVisualization/qbar3dseries.h>
#include <QtDataVisualization/q3dscene.h>
#include <QtGui/qtextcursor.h>
#include <QtCore/qmetatype.h>

#include <QtCore/qtmochelpers.h>

#include <memory>


#include <QtCore/qxptype_traits.h>
#if !defined(Q_MOC_OUTPUT_REVISION)
#error "The header file 'camerastate.h' doesn't include <QObject>."
#elif Q_MOC_OUTPUT_REVISION != 69
#error "This file was generated using the moc from 6.11.1. It"
#error "cannot be used with the include files from this version of Qt."
#error "(The moc has changed too much.)"
#endif

#ifndef Q_CONSTINIT
#define Q_CONSTINIT
#endif

QT_WARNING_PUSH
QT_WARNING_DISABLE_DEPRECATED
QT_WARNING_DISABLE_GCC("-Wuseless-cast")
namespace {
struct qt_meta_tag_ZN4Ekos11CameraStateE_t {};
} // unnamed namespace

template <> constexpr inline auto Ekos::CameraState::qt_create_metaobjectdata<qt_meta_tag_ZN4Ekos11CameraStateE_t>()
{
    namespace QMC = QtMocConstants;
    QtMocHelpers::StringRefStorage qt_stringData {
        "Ekos::CameraState",
        "captureBusy",
        "",
        "busy",
        "startCapture",
        "abortCapture",
        "suspendCapture",
        "executeActiveJob",
        "updatePrepareState",
        "CaptureState",
        "state",
        "captureStarted",
        "CaptureResult",
        "rc",
        "requestAction",
        "CaptureWorkflowActionType",
        "action",
        "newMeridianFlipStage",
        "MeridianFlipState::MFStage",
        "status",
        "meridianFlipStarted",
        "newGuiderDrift",
        "deviation_rms",
        "guideAfterMeridianFlip",
        "resetNonGuidedDither",
        "newStatus",
        "newFocusStatus",
        "FocusState",
        "newAdaptiveFocusStatus",
        "success",
        "checkFocus",
        "hfr",
        "runAutoFocus",
        "AutofocusReason",
        "autofocusReason",
        "reasonInfo",
        "resetFocusFrame",
        "adaptiveFocus",
        "abortFastExposure",
        "newLimitFocusHFR",
        "newFilterPosition",
        "targetFilterPosition",
        "FilterManager::FilterPolicy",
        "policy",
        "sequenceChanged",
        "QJsonArray",
        "sequence",
        "newLog",
        "text"
    };

    QtMocHelpers::UintData qt_methods {
        // Signal 'captureBusy'
        QtMocHelpers::SignalData<void(bool)>(1, 2, QMC::AccessPublic, QMetaType::Void, {{
            { QMetaType::Bool, 3 },
        }}),
        // Signal 'startCapture'
        QtMocHelpers::SignalData<void()>(4, 2, QMC::AccessPublic, QMetaType::Void),
        // Signal 'abortCapture'
        QtMocHelpers::SignalData<void()>(5, 2, QMC::AccessPublic, QMetaType::Void),
        // Signal 'suspendCapture'
        QtMocHelpers::SignalData<void()>(6, 2, QMC::AccessPublic, QMetaType::Void),
        // Signal 'executeActiveJob'
        QtMocHelpers::SignalData<void()>(7, 2, QMC::AccessPublic, QMetaType::Void),
        // Signal 'updatePrepareState'
        QtMocHelpers::SignalData<void(CaptureState)>(8, 2, QMC::AccessPublic, QMetaType::Void, {{
            { 0x80000000 | 9, 10 },
        }}),
        // Signal 'captureStarted'
        QtMocHelpers::SignalData<void(CaptureResult)>(11, 2, QMC::AccessPublic, QMetaType::Void, {{
            { 0x80000000 | 12, 13 },
        }}),
        // Signal 'requestAction'
        QtMocHelpers::SignalData<void(CaptureWorkflowActionType)>(14, 2, QMC::AccessPublic, QMetaType::Void, {{
            { 0x80000000 | 15, 16 },
        }}),
        // Signal 'newMeridianFlipStage'
        QtMocHelpers::SignalData<void(MeridianFlipState::MFStage)>(17, 2, QMC::AccessPublic, QMetaType::Void, {{
            { 0x80000000 | 18, 19 },
        }}),
        // Signal 'meridianFlipStarted'
        QtMocHelpers::SignalData<void()>(20, 2, QMC::AccessPublic, QMetaType::Void),
        // Signal 'newGuiderDrift'
        QtMocHelpers::SignalData<void(double)>(21, 2, QMC::AccessPublic, QMetaType::Void, {{
            { QMetaType::Double, 22 },
        }}),
        // Signal 'guideAfterMeridianFlip'
        QtMocHelpers::SignalData<void()>(23, 2, QMC::AccessPublic, QMetaType::Void),
        // Signal 'resetNonGuidedDither'
        QtMocHelpers::SignalData<void()>(24, 2, QMC::AccessPublic, QMetaType::Void),
        // Signal 'newStatus'
        QtMocHelpers::SignalData<void(CaptureState)>(25, 2, QMC::AccessPublic, QMetaType::Void, {{
            { 0x80000000 | 9, 19 },
        }}),
        // Signal 'newFocusStatus'
        QtMocHelpers::SignalData<void(FocusState)>(26, 2, QMC::AccessPublic, QMetaType::Void, {{
            { 0x80000000 | 27, 19 },
        }}),
        // Signal 'newAdaptiveFocusStatus'
        QtMocHelpers::SignalData<void(bool)>(28, 2, QMC::AccessPublic, QMetaType::Void, {{
            { QMetaType::Bool, 29 },
        }}),
        // Signal 'checkFocus'
        QtMocHelpers::SignalData<void(double)>(30, 2, QMC::AccessPublic, QMetaType::Void, {{
            { QMetaType::Double, 31 },
        }}),
        // Signal 'runAutoFocus'
        QtMocHelpers::SignalData<void(AutofocusReason, const QString &)>(32, 2, QMC::AccessPublic, QMetaType::Void, {{
            { 0x80000000 | 33, 34 }, { QMetaType::QString, 35 },
        }}),
        // Signal 'resetFocusFrame'
        QtMocHelpers::SignalData<void()>(36, 2, QMC::AccessPublic, QMetaType::Void),
        // Signal 'adaptiveFocus'
        QtMocHelpers::SignalData<void()>(37, 2, QMC::AccessPublic, QMetaType::Void),
        // Signal 'abortFastExposure'
        QtMocHelpers::SignalData<void()>(38, 2, QMC::AccessPublic, QMetaType::Void),
        // Signal 'newLimitFocusHFR'
        QtMocHelpers::SignalData<void(double)>(39, 2, QMC::AccessPublic, QMetaType::Void, {{
            { QMetaType::Double, 31 },
        }}),
        // Signal 'newFilterPosition'
        QtMocHelpers::SignalData<void(int, FilterManager::FilterPolicy)>(40, 2, QMC::AccessPublic, QMetaType::Void, {{
            { QMetaType::Int, 41 }, { 0x80000000 | 42, 43 },
        }}),
        // Signal 'newFilterPosition'
        QtMocHelpers::SignalData<void(int)>(40, 2, QMC::AccessPublic | QMC::MethodCloned, QMetaType::Void, {{
            { QMetaType::Int, 41 },
        }}),
        // Signal 'sequenceChanged'
        QtMocHelpers::SignalData<void(const QJsonArray &)>(44, 2, QMC::AccessPublic, QMetaType::Void, {{
            { 0x80000000 | 45, 46 },
        }}),
        // Signal 'newLog'
        QtMocHelpers::SignalData<void(const QString &)>(47, 2, QMC::AccessPublic, QMetaType::Void, {{
            { QMetaType::QString, 48 },
        }}),
    };
    QtMocHelpers::UintData qt_properties {
    };
    QtMocHelpers::UintData qt_enums {
    };
    return QtMocHelpers::metaObjectData<CameraState, qt_meta_tag_ZN4Ekos11CameraStateE_t>(QMC::MetaObjectFlag{}, qt_stringData,
            qt_methods, qt_properties, qt_enums);
}
Q_CONSTINIT const QMetaObject Ekos::CameraState::staticMetaObject = { {
    QMetaObject::SuperData::link<QObject::staticMetaObject>(),
    qt_staticMetaObjectStaticContent<qt_meta_tag_ZN4Ekos11CameraStateE_t>.stringdata,
    qt_staticMetaObjectStaticContent<qt_meta_tag_ZN4Ekos11CameraStateE_t>.data,
    qt_static_metacall,
    nullptr,
    qt_staticMetaObjectRelocatingContent<qt_meta_tag_ZN4Ekos11CameraStateE_t>.metaTypes,
    nullptr
} };

void Ekos::CameraState::qt_static_metacall(QObject *_o, QMetaObject::Call _c, int _id, void **_a)
{
    auto *_t = static_cast<CameraState *>(_o);
    if (_c == QMetaObject::InvokeMetaMethod) {
        switch (_id) {
        case 0: _t->captureBusy((*reinterpret_cast<std::add_pointer_t<bool>>(_a[1]))); break;
        case 1: _t->startCapture(); break;
        case 2: _t->abortCapture(); break;
        case 3: _t->suspendCapture(); break;
        case 4: _t->executeActiveJob(); break;
        case 5: _t->updatePrepareState((*reinterpret_cast<std::add_pointer_t<CaptureState>>(_a[1]))); break;
        case 6: _t->captureStarted((*reinterpret_cast<std::add_pointer_t<CaptureResult>>(_a[1]))); break;
        case 7: _t->requestAction((*reinterpret_cast<std::add_pointer_t<CaptureWorkflowActionType>>(_a[1]))); break;
        case 8: _t->newMeridianFlipStage((*reinterpret_cast<std::add_pointer_t<MeridianFlipState::MFStage>>(_a[1]))); break;
        case 9: _t->meridianFlipStarted(); break;
        case 10: _t->newGuiderDrift((*reinterpret_cast<std::add_pointer_t<double>>(_a[1]))); break;
        case 11: _t->guideAfterMeridianFlip(); break;
        case 12: _t->resetNonGuidedDither(); break;
        case 13: _t->newStatus((*reinterpret_cast<std::add_pointer_t<CaptureState>>(_a[1]))); break;
        case 14: _t->newFocusStatus((*reinterpret_cast<std::add_pointer_t<FocusState>>(_a[1]))); break;
        case 15: _t->newAdaptiveFocusStatus((*reinterpret_cast<std::add_pointer_t<bool>>(_a[1]))); break;
        case 16: _t->checkFocus((*reinterpret_cast<std::add_pointer_t<double>>(_a[1]))); break;
        case 17: _t->runAutoFocus((*reinterpret_cast<std::add_pointer_t<AutofocusReason>>(_a[1])),(*reinterpret_cast<std::add_pointer_t<QString>>(_a[2]))); break;
        case 18: _t->resetFocusFrame(); break;
        case 19: _t->adaptiveFocus(); break;
        case 20: _t->abortFastExposure(); break;
        case 21: _t->newLimitFocusHFR((*reinterpret_cast<std::add_pointer_t<double>>(_a[1]))); break;
        case 22: _t->newFilterPosition((*reinterpret_cast<std::add_pointer_t<int>>(_a[1])),(*reinterpret_cast<std::add_pointer_t<FilterManager::FilterPolicy>>(_a[2]))); break;
        case 23: _t->newFilterPosition((*reinterpret_cast<std::add_pointer_t<int>>(_a[1]))); break;
        case 24: _t->sequenceChanged((*reinterpret_cast<std::add_pointer_t<QJsonArray>>(_a[1]))); break;
        case 25: _t->newLog((*reinterpret_cast<std::add_pointer_t<QString>>(_a[1]))); break;
        default: ;
        }
    }
    if (_c == QMetaObject::IndexOfMethod) {
        if (QtMocHelpers::indexOfMethod<void (CameraState::*)(bool )>(_a, &CameraState::captureBusy, 0))
            return;
        if (QtMocHelpers::indexOfMethod<void (CameraState::*)()>(_a, &CameraState::startCapture, 1))
            return;
        if (QtMocHelpers::indexOfMethod<void (CameraState::*)()>(_a, &CameraState::abortCapture, 2))
            return;
        if (QtMocHelpers::indexOfMethod<void (CameraState::*)()>(_a, &CameraState::suspendCapture, 3))
            return;
        if (QtMocHelpers::indexOfMethod<void (CameraState::*)()>(_a, &CameraState::executeActiveJob, 4))
            return;
        if (QtMocHelpers::indexOfMethod<void (CameraState::*)(CaptureState )>(_a, &CameraState::updatePrepareState, 5))
            return;
        if (QtMocHelpers::indexOfMethod<void (CameraState::*)(CaptureResult )>(_a, &CameraState::captureStarted, 6))
            return;
        if (QtMocHelpers::indexOfMethod<void (CameraState::*)(CaptureWorkflowActionType )>(_a, &CameraState::requestAction, 7))
            return;
        if (QtMocHelpers::indexOfMethod<void (CameraState::*)(MeridianFlipState::MFStage )>(_a, &CameraState::newMeridianFlipStage, 8))
            return;
        if (QtMocHelpers::indexOfMethod<void (CameraState::*)()>(_a, &CameraState::meridianFlipStarted, 9))
            return;
        if (QtMocHelpers::indexOfMethod<void (CameraState::*)(double )>(_a, &CameraState::newGuiderDrift, 10))
            return;
        if (QtMocHelpers::indexOfMethod<void (CameraState::*)()>(_a, &CameraState::guideAfterMeridianFlip, 11))
            return;
        if (QtMocHelpers::indexOfMethod<void (CameraState::*)()>(_a, &CameraState::resetNonGuidedDither, 12))
            return;
        if (QtMocHelpers::indexOfMethod<void (CameraState::*)(CaptureState )>(_a, &CameraState::newStatus, 13))
            return;
        if (QtMocHelpers::indexOfMethod<void (CameraState::*)(FocusState )>(_a, &CameraState::newFocusStatus, 14))
            return;
        if (QtMocHelpers::indexOfMethod<void (CameraState::*)(bool )>(_a, &CameraState::newAdaptiveFocusStatus, 15))
            return;
        if (QtMocHelpers::indexOfMethod<void (CameraState::*)(double )>(_a, &CameraState::checkFocus, 16))
            return;
        if (QtMocHelpers::indexOfMethod<void (CameraState::*)(AutofocusReason , const QString & )>(_a, &CameraState::runAutoFocus, 17))
            return;
        if (QtMocHelpers::indexOfMethod<void (CameraState::*)()>(_a, &CameraState::resetFocusFrame, 18))
            return;
        if (QtMocHelpers::indexOfMethod<void (CameraState::*)()>(_a, &CameraState::adaptiveFocus, 19))
            return;
        if (QtMocHelpers::indexOfMethod<void (CameraState::*)()>(_a, &CameraState::abortFastExposure, 20))
            return;
        if (QtMocHelpers::indexOfMethod<void (CameraState::*)(double )>(_a, &CameraState::newLimitFocusHFR, 21))
            return;
        if (QtMocHelpers::indexOfMethod<void (CameraState::*)(int , FilterManager::FilterPolicy )>(_a, &CameraState::newFilterPosition, 22))
            return;
        if (QtMocHelpers::indexOfMethod<void (CameraState::*)(const QJsonArray & )>(_a, &CameraState::sequenceChanged, 24))
            return;
        if (QtMocHelpers::indexOfMethod<void (CameraState::*)(const QString & )>(_a, &CameraState::newLog, 25))
            return;
    }
}

const QMetaObject *Ekos::CameraState::metaObject() const
{
    return QObject::d_ptr->metaObject ? QObject::d_ptr->dynamicMetaObject() : &staticMetaObject;
}

void *Ekos::CameraState::qt_metacast(const char *_clname)
{
    if (!_clname) return nullptr;
    if (!strcmp(_clname, qt_staticMetaObjectStaticContent<qt_meta_tag_ZN4Ekos11CameraStateE_t>.strings))
        return static_cast<void*>(this);
    return QObject::qt_metacast(_clname);
}

int Ekos::CameraState::qt_metacall(QMetaObject::Call _c, int _id, void **_a)
{
    _id = QObject::qt_metacall(_c, _id, _a);
    if (_id < 0)
        return _id;
    if (_c == QMetaObject::InvokeMetaMethod) {
        if (_id < 26)
            qt_static_metacall(this, _c, _id, _a);
        _id -= 26;
    }
    if (_c == QMetaObject::RegisterMethodArgumentMetaType) {
        if (_id < 26)
            *reinterpret_cast<QMetaType *>(_a[0]) = QMetaType();
        _id -= 26;
    }
    return _id;
}

// SIGNAL 0
void Ekos::CameraState::captureBusy(bool _t1)
{
    QMetaObject::activate<void>(this, &staticMetaObject, 0, nullptr, _t1);
}

// SIGNAL 1
void Ekos::CameraState::startCapture()
{
    QMetaObject::activate(this, &staticMetaObject, 1, nullptr);
}

// SIGNAL 2
void Ekos::CameraState::abortCapture()
{
    QMetaObject::activate(this, &staticMetaObject, 2, nullptr);
}

// SIGNAL 3
void Ekos::CameraState::suspendCapture()
{
    QMetaObject::activate(this, &staticMetaObject, 3, nullptr);
}

// SIGNAL 4
void Ekos::CameraState::executeActiveJob()
{
    QMetaObject::activate(this, &staticMetaObject, 4, nullptr);
}

// SIGNAL 5
void Ekos::CameraState::updatePrepareState(CaptureState _t1)
{
    QMetaObject::activate<void>(this, &staticMetaObject, 5, nullptr, _t1);
}

// SIGNAL 6
void Ekos::CameraState::captureStarted(CaptureResult _t1)
{
    QMetaObject::activate<void>(this, &staticMetaObject, 6, nullptr, _t1);
}

// SIGNAL 7
void Ekos::CameraState::requestAction(CaptureWorkflowActionType _t1)
{
    QMetaObject::activate<void>(this, &staticMetaObject, 7, nullptr, _t1);
}

// SIGNAL 8
void Ekos::CameraState::newMeridianFlipStage(MeridianFlipState::MFStage _t1)
{
    QMetaObject::activate<void>(this, &staticMetaObject, 8, nullptr, _t1);
}

// SIGNAL 9
void Ekos::CameraState::meridianFlipStarted()
{
    QMetaObject::activate(this, &staticMetaObject, 9, nullptr);
}

// SIGNAL 10
void Ekos::CameraState::newGuiderDrift(double _t1)
{
    QMetaObject::activate<void>(this, &staticMetaObject, 10, nullptr, _t1);
}

// SIGNAL 11
void Ekos::CameraState::guideAfterMeridianFlip()
{
    QMetaObject::activate(this, &staticMetaObject, 11, nullptr);
}

// SIGNAL 12
void Ekos::CameraState::resetNonGuidedDither()
{
    QMetaObject::activate(this, &staticMetaObject, 12, nullptr);
}

// SIGNAL 13
void Ekos::CameraState::newStatus(CaptureState _t1)
{
    QMetaObject::activate<void>(this, &staticMetaObject, 13, nullptr, _t1);
}

// SIGNAL 14
void Ekos::CameraState::newFocusStatus(FocusState _t1)
{
    QMetaObject::activate<void>(this, &staticMetaObject, 14, nullptr, _t1);
}

// SIGNAL 15
void Ekos::CameraState::newAdaptiveFocusStatus(bool _t1)
{
    QMetaObject::activate<void>(this, &staticMetaObject, 15, nullptr, _t1);
}

// SIGNAL 16
void Ekos::CameraState::checkFocus(double _t1)
{
    QMetaObject::activate<void>(this, &staticMetaObject, 16, nullptr, _t1);
}

// SIGNAL 17
void Ekos::CameraState::runAutoFocus(AutofocusReason _t1, const QString & _t2)
{
    QMetaObject::activate<void>(this, &staticMetaObject, 17, nullptr, _t1, _t2);
}

// SIGNAL 18
void Ekos::CameraState::resetFocusFrame()
{
    QMetaObject::activate(this, &staticMetaObject, 18, nullptr);
}

// SIGNAL 19
void Ekos::CameraState::adaptiveFocus()
{
    QMetaObject::activate(this, &staticMetaObject, 19, nullptr);
}

// SIGNAL 20
void Ekos::CameraState::abortFastExposure()
{
    QMetaObject::activate(this, &staticMetaObject, 20, nullptr);
}

// SIGNAL 21
void Ekos::CameraState::newLimitFocusHFR(double _t1)
{
    QMetaObject::activate<void>(this, &staticMetaObject, 21, nullptr, _t1);
}

// SIGNAL 22
void Ekos::CameraState::newFilterPosition(int _t1, FilterManager::FilterPolicy _t2)
{
    QMetaObject::activate<void>(this, &staticMetaObject, 22, nullptr, _t1, _t2);
}

// SIGNAL 24
void Ekos::CameraState::sequenceChanged(const QJsonArray & _t1)
{
    QMetaObject::activate<void>(this, &staticMetaObject, 24, nullptr, _t1);
}

// SIGNAL 25
void Ekos::CameraState::newLog(const QString & _t1)
{
    QMetaObject::activate<void>(this, &staticMetaObject, 25, nullptr, _t1);
}
QT_WARNING_POP
