/********************************************************************************
** Form generated from reading UI file 'catalogcoloreditor.ui'
**
** Created by: Qt User Interface Compiler version 6.11.1
**
** WARNING! All changes made in this file will be lost when recompiling UI file!
********************************************************************************/

#ifndef UI_CATALOGCOLOREDITOR_H
#define UI_CATALOGCOLOREDITOR_H

#include <QtCore/QVariant>
#include <QtWidgets/QAbstractButton>
#include <QtWidgets/QApplication>
#include <QtWidgets/QDialog>
#include <QtWidgets/QDialogButtonBox>
#include <QtWidgets/QLabel>
#include <QtWidgets/QSpacerItem>
#include <QtWidgets/QVBoxLayout>
#include <klocalizedstring.h>

QT_BEGIN_NAMESPACE

class Ui_CatalogColorEditor
{
public:
    QVBoxLayout *verticalLayout_2;
    QLabel *catalogName;
    QLabel *label;
    QVBoxLayout *colorButtons;
    QSpacerItem *verticalSpacer;
    QDialogButtonBox *buttonBox;

    void setupUi(QDialog *CatalogColorEditor)
    {
        if (CatalogColorEditor->objectName().isEmpty())
            CatalogColorEditor->setObjectName("CatalogColorEditor");
        CatalogColorEditor->resize(400, 300);
        verticalLayout_2 = new QVBoxLayout(CatalogColorEditor);
        verticalLayout_2->setObjectName("verticalLayout_2");
        catalogName = new QLabel(CatalogColorEditor);
        catalogName->setObjectName("catalogName");
        catalogName->setStyleSheet(QString::fromUtf8("font-weight:600;"));

        verticalLayout_2->addWidget(catalogName);

        label = new QLabel(CatalogColorEditor);
        label->setObjectName("label");
        QSizePolicy sizePolicy(QSizePolicy::Policy::Minimum, QSizePolicy::Policy::Minimum);
        sizePolicy.setHorizontalStretch(0);
        sizePolicy.setVerticalStretch(0);
        sizePolicy.setHeightForWidth(label->sizePolicy().hasHeightForWidth());
        label->setSizePolicy(sizePolicy);

        verticalLayout_2->addWidget(label);

        colorButtons = new QVBoxLayout();
        colorButtons->setObjectName("colorButtons");

        verticalLayout_2->addLayout(colorButtons);

        verticalSpacer = new QSpacerItem(20, 40, QSizePolicy::Policy::Minimum, QSizePolicy::Policy::Expanding);

        verticalLayout_2->addItem(verticalSpacer);

        buttonBox = new QDialogButtonBox(CatalogColorEditor);
        buttonBox->setObjectName("buttonBox");
        buttonBox->setOrientation(Qt::Horizontal);
        buttonBox->setStandardButtons(QDialogButtonBox::Cancel|QDialogButtonBox::Ok);

        verticalLayout_2->addWidget(buttonBox);


        retranslateUi(CatalogColorEditor);
        QObject::connect(buttonBox, &QDialogButtonBox::rejected, CatalogColorEditor, qOverload<>(&QDialog::reject));

        QMetaObject::connectSlotsByName(CatalogColorEditor);
    } // setupUi

    void retranslateUi(QDialog *CatalogColorEditor)
    {
        CatalogColorEditor->setWindowTitle(tr2i18n("Catalog Colors", nullptr));
        catalogName->setText(tr2i18n("_", nullptr));
        label->setText(tr2i18n("Click on a color to change it...", nullptr));
    } // retranslateUi

};

namespace Ui {
    class CatalogColorEditor: public Ui_CatalogColorEditor {};
} // namespace Ui

QT_END_NAMESPACE

#endif // CATALOGCOLOREDITOR_H

