/********************************************************************************
** Form generated from reading UI file 'customproperties.ui'
**
** Created by: Qt User Interface Compiler version 6.11.1
**
** WARNING! All changes made in this file will be lost when recompiling UI file!
********************************************************************************/

#ifndef UI_CUSTOMPROPERTIES_H
#define UI_CUSTOMPROPERTIES_H

#include <QtCore/QVariant>
#include <QtWidgets/QAbstractButton>
#include <QtWidgets/QApplication>
#include <QtWidgets/QDialog>
#include <QtWidgets/QDialogButtonBox>
#include <QtWidgets/QHBoxLayout>
#include <QtWidgets/QLabel>
#include <QtWidgets/QListWidget>
#include <QtWidgets/QPushButton>
#include <QtWidgets/QSpacerItem>
#include <QtWidgets/QVBoxLayout>
#include <klocalizedstring.h>

QT_BEGIN_NAMESPACE

class Ui_CustomProperties
{
public:
    QVBoxLayout *verticalLayout_2;
    QLabel *tipLabel;
    QHBoxLayout *horizontalLayout;
    QVBoxLayout *availablePropertiesLayout;
    QLabel *label_2;
    QListWidget *availablePropertiesList;
    QVBoxLayout *verticalLayout;
    QSpacerItem *verticalSpacer_2;
    QPushButton *addB;
    QPushButton *removeB;
    QPushButton *clearB;
    QSpacerItem *verticalSpacer;
    QVBoxLayout *jobPropertiesLayout;
    QLabel *label_3;
    QListWidget *jobPropertiesList;
    QDialogButtonBox *buttonBox;

    void setupUi(QDialog *CustomProperties)
    {
        if (CustomProperties->objectName().isEmpty())
            CustomProperties->setObjectName("CustomProperties");
        CustomProperties->resize(353, 392);
        verticalLayout_2 = new QVBoxLayout(CustomProperties);
        verticalLayout_2->setObjectName("verticalLayout_2");
        tipLabel = new QLabel(CustomProperties);
        tipLabel->setObjectName("tipLabel");
        tipLabel->setWordWrap(true);

        verticalLayout_2->addWidget(tipLabel);

        horizontalLayout = new QHBoxLayout();
        horizontalLayout->setObjectName("horizontalLayout");
        availablePropertiesLayout = new QVBoxLayout();
        availablePropertiesLayout->setObjectName("availablePropertiesLayout");
        label_2 = new QLabel(CustomProperties);
        label_2->setObjectName("label_2");

        availablePropertiesLayout->addWidget(label_2);

        availablePropertiesList = new QListWidget(CustomProperties);
        availablePropertiesList->setObjectName("availablePropertiesList");
        availablePropertiesList->setDragEnabled(true);
        availablePropertiesList->setDragDropMode(QAbstractItemView::NoDragDrop);

        availablePropertiesLayout->addWidget(availablePropertiesList);


        horizontalLayout->addLayout(availablePropertiesLayout);

        verticalLayout = new QVBoxLayout();
        verticalLayout->setObjectName("verticalLayout");
        verticalSpacer_2 = new QSpacerItem(20, 40, QSizePolicy::Policy::Minimum, QSizePolicy::Policy::Expanding);

        verticalLayout->addItem(verticalSpacer_2);

        addB = new QPushButton(CustomProperties);
        addB->setObjectName("addB");
        addB->setMinimumSize(QSize(32, 32));
        addB->setMaximumSize(QSize(32, 32));

        verticalLayout->addWidget(addB);

        removeB = new QPushButton(CustomProperties);
        removeB->setObjectName("removeB");
        removeB->setMinimumSize(QSize(32, 32));
        removeB->setMaximumSize(QSize(32, 32));

        verticalLayout->addWidget(removeB);

        clearB = new QPushButton(CustomProperties);
        clearB->setObjectName("clearB");
        clearB->setMinimumSize(QSize(32, 32));
        clearB->setMaximumSize(QSize(32, 32));

        verticalLayout->addWidget(clearB);

        verticalSpacer = new QSpacerItem(20, 40, QSizePolicy::Policy::Minimum, QSizePolicy::Policy::Expanding);

        verticalLayout->addItem(verticalSpacer);


        horizontalLayout->addLayout(verticalLayout);

        jobPropertiesLayout = new QVBoxLayout();
        jobPropertiesLayout->setObjectName("jobPropertiesLayout");
        label_3 = new QLabel(CustomProperties);
        label_3->setObjectName("label_3");

        jobPropertiesLayout->addWidget(label_3);

        jobPropertiesList = new QListWidget(CustomProperties);
        jobPropertiesList->setObjectName("jobPropertiesList");
        jobPropertiesList->setDragEnabled(true);
        jobPropertiesList->setDragDropMode(QAbstractItemView::NoDragDrop);

        jobPropertiesLayout->addWidget(jobPropertiesList);


        horizontalLayout->addLayout(jobPropertiesLayout);


        verticalLayout_2->addLayout(horizontalLayout);

        buttonBox = new QDialogButtonBox(CustomProperties);
        buttonBox->setObjectName("buttonBox");
        buttonBox->setOrientation(Qt::Horizontal);
        buttonBox->setStandardButtons(QDialogButtonBox::Apply|QDialogButtonBox::Close);

        verticalLayout_2->addWidget(buttonBox);


        retranslateUi(CustomProperties);
        QObject::connect(buttonBox, &QDialogButtonBox::accepted, CustomProperties, qOverload<>(&QDialog::accept));
        QObject::connect(buttonBox, &QDialogButtonBox::rejected, CustomProperties, qOverload<>(&QDialog::reject));

        QMetaObject::connectSlotsByName(CustomProperties);
    } // setupUi

    void retranslateUi(QDialog *CustomProperties)
    {
        CustomProperties->setWindowTitle(tr2i18n("Custom Capture Properties", nullptr));
        tipLabel->setText(tr2i18n("<html><head/><body><p>Select custom properties to be set when the sequence job is executed in batch mode. After the desired property value is set in INDI Control Panel, add it to the<span style=\" font-weight:600;\"> Job Properties</span> section. Click <span style=\" font-weight:600;\">Apply</span> to record the property values.</p></body></html>", nullptr));
        label_2->setText(tr2i18n("Available Properties", nullptr));
        addB->setText(QString());
        removeB->setText(QString());
        clearB->setText(QString());
        label_3->setText(tr2i18n("Job Properties", nullptr));
    } // retranslateUi

};

namespace Ui {
    class CustomProperties: public Ui_CustomProperties {};
} // namespace Ui

QT_END_NAMESPACE

#endif // CUSTOMPROPERTIES_H

