/********************************************************************************
** Form generated from reading UI file 'wiequipsettings.ui'
**
** Created by: Qt User Interface Compiler version 6.11.1
**
** WARNING! All changes made in this file will be lost when recompiling UI file!
********************************************************************************/

#ifndef UI_WIEQUIPSETTINGS_H
#define UI_WIEQUIPSETTINGS_H

#include <QtCore/QVariant>
#include <QtWidgets/QApplication>
#include <QtWidgets/QCheckBox>
#include <QtWidgets/QDoubleSpinBox>
#include <QtWidgets/QFormLayout>
#include <QtWidgets/QFrame>
#include <QtWidgets/QGridLayout>
#include <QtWidgets/QGroupBox>
#include <QtWidgets/QHBoxLayout>
#include <QtWidgets/QLabel>
#include <QtWidgets/QListWidget>
#include <QtWidgets/QPushButton>
#include <QtWidgets/QSpacerItem>
#include <QtWidgets/QVBoxLayout>
#include <QtWidgets/QWidget>
#include <klocalizedstring.h>

QT_BEGIN_NAMESPACE

class Ui_WIEquipSettings
{
public:
    QGridLayout *gridLayout_3;
    QVBoxLayout *equipSettingsLayout;
    QCheckBox *kcfg_TelescopeCheck;
    QLabel *scopeSelectLabel;
    QFrame *scopeFrame;
    QHBoxLayout *horizontalLayout;
    QListWidget *ScopeListWidget;
    QGroupBox *scopeDetailsBox;
    QVBoxLayout *verticalLayout;
    QFormLayout *formLayout_2;
    QLabel *scopeVendorText;
    QLabel *vendorText;
    QLabel *scopeModelText;
    QLabel *modelText;
    QLabel *scopeApertureText;
    QLabel *apertureText;
    QSpacerItem *verticalSpacer_4;
    QHBoxLayout *horizontalLayout_2;
    QPushButton *saveNewScopeButton;
    QSpacerItem *horizontalSpacer;
    QGroupBox *binoGroupBox;
    QVBoxLayout *verticalLayout_3;
    QCheckBox *kcfg_BinocularsCheck;
    QFrame *binoDetailsFrame;
    QHBoxLayout *horizontalLayout_7;
    QLabel *binoApertureText;
    QDoubleSpinBox *kcfg_BinocularsAperture;
    QLabel *binoApertureUnit;
    QSpacerItem *horizontalSpacer_2;

    void setupUi(QWidget *WIEquipSettings)
    {
        if (WIEquipSettings->objectName().isEmpty())
            WIEquipSettings->setObjectName("WIEquipSettings");
        WIEquipSettings->resize(350, 322);
        gridLayout_3 = new QGridLayout(WIEquipSettings);
        gridLayout_3->setObjectName("gridLayout_3");
        gridLayout_3->setContentsMargins(15, -1, 15, 4);
        equipSettingsLayout = new QVBoxLayout();
        equipSettingsLayout->setSpacing(7);
        equipSettingsLayout->setObjectName("equipSettingsLayout");
        equipSettingsLayout->setContentsMargins(6, 10, 6, 9);
        kcfg_TelescopeCheck = new QCheckBox(WIEquipSettings);
        kcfg_TelescopeCheck->setObjectName("kcfg_TelescopeCheck");

        equipSettingsLayout->addWidget(kcfg_TelescopeCheck);

        scopeSelectLabel = new QLabel(WIEquipSettings);
        scopeSelectLabel->setObjectName("scopeSelectLabel");

        equipSettingsLayout->addWidget(scopeSelectLabel);

        scopeFrame = new QFrame(WIEquipSettings);
        scopeFrame->setObjectName("scopeFrame");
        scopeFrame->setEnabled(false);
        horizontalLayout = new QHBoxLayout(scopeFrame);
        horizontalLayout->setSpacing(5);
        horizontalLayout->setObjectName("horizontalLayout");
        ScopeListWidget = new QListWidget(scopeFrame);
        ScopeListWidget->setObjectName("ScopeListWidget");
        ScopeListWidget->setMinimumSize(QSize(160, 0));

        horizontalLayout->addWidget(ScopeListWidget);

        scopeDetailsBox = new QGroupBox(scopeFrame);
        scopeDetailsBox->setObjectName("scopeDetailsBox");
        scopeDetailsBox->setMinimumSize(QSize(0, 0));
        verticalLayout = new QVBoxLayout(scopeDetailsBox);
        verticalLayout->setObjectName("verticalLayout");
        formLayout_2 = new QFormLayout();
        formLayout_2->setObjectName("formLayout_2");
        scopeVendorText = new QLabel(scopeDetailsBox);
        scopeVendorText->setObjectName("scopeVendorText");
        scopeVendorText->setAlignment(Qt::AlignLeading|Qt::AlignLeft|Qt::AlignVCenter);

        formLayout_2->setWidget(0, QFormLayout::ItemRole::LabelRole, scopeVendorText);

        vendorText = new QLabel(scopeDetailsBox);
        vendorText->setObjectName("vendorText");

        formLayout_2->setWidget(0, QFormLayout::ItemRole::FieldRole, vendorText);

        scopeModelText = new QLabel(scopeDetailsBox);
        scopeModelText->setObjectName("scopeModelText");

        formLayout_2->setWidget(1, QFormLayout::ItemRole::LabelRole, scopeModelText);

        modelText = new QLabel(scopeDetailsBox);
        modelText->setObjectName("modelText");

        formLayout_2->setWidget(1, QFormLayout::ItemRole::FieldRole, modelText);

        scopeApertureText = new QLabel(scopeDetailsBox);
        scopeApertureText->setObjectName("scopeApertureText");

        formLayout_2->setWidget(2, QFormLayout::ItemRole::LabelRole, scopeApertureText);

        apertureText = new QLabel(scopeDetailsBox);
        apertureText->setObjectName("apertureText");

        formLayout_2->setWidget(2, QFormLayout::ItemRole::FieldRole, apertureText);


        verticalLayout->addLayout(formLayout_2);

        verticalSpacer_4 = new QSpacerItem(20, 40, QSizePolicy::Policy::Minimum, QSizePolicy::Policy::Expanding);

        verticalLayout->addItem(verticalSpacer_4);

        horizontalLayout_2 = new QHBoxLayout();
        horizontalLayout_2->setObjectName("horizontalLayout_2");
        saveNewScopeButton = new QPushButton(scopeDetailsBox);
        saveNewScopeButton->setObjectName("saveNewScopeButton");

        horizontalLayout_2->addWidget(saveNewScopeButton);

        horizontalSpacer = new QSpacerItem(40, 20, QSizePolicy::Policy::Expanding, QSizePolicy::Policy::Minimum);

        horizontalLayout_2->addItem(horizontalSpacer);


        verticalLayout->addLayout(horizontalLayout_2);


        horizontalLayout->addWidget(scopeDetailsBox);

        horizontalLayout->setStretch(0, 1);
        horizontalLayout->setStretch(1, 1);

        equipSettingsLayout->addWidget(scopeFrame);

        binoGroupBox = new QGroupBox(WIEquipSettings);
        binoGroupBox->setObjectName("binoGroupBox");
        verticalLayout_3 = new QVBoxLayout(binoGroupBox);
        verticalLayout_3->setObjectName("verticalLayout_3");
        kcfg_BinocularsCheck = new QCheckBox(binoGroupBox);
        kcfg_BinocularsCheck->setObjectName("kcfg_BinocularsCheck");

        verticalLayout_3->addWidget(kcfg_BinocularsCheck);

        binoDetailsFrame = new QFrame(binoGroupBox);
        binoDetailsFrame->setObjectName("binoDetailsFrame");
        binoDetailsFrame->setEnabled(false);
        horizontalLayout_7 = new QHBoxLayout(binoDetailsFrame);
        horizontalLayout_7->setObjectName("horizontalLayout_7");
        binoApertureText = new QLabel(binoDetailsFrame);
        binoApertureText->setObjectName("binoApertureText");

        horizontalLayout_7->addWidget(binoApertureText);

        kcfg_BinocularsAperture = new QDoubleSpinBox(binoDetailsFrame);
        kcfg_BinocularsAperture->setObjectName("kcfg_BinocularsAperture");
        kcfg_BinocularsAperture->setValue(40.000000000000000);

        horizontalLayout_7->addWidget(kcfg_BinocularsAperture);

        binoApertureUnit = new QLabel(binoDetailsFrame);
        binoApertureUnit->setObjectName("binoApertureUnit");

        horizontalLayout_7->addWidget(binoApertureUnit);

        horizontalSpacer_2 = new QSpacerItem(40, 20, QSizePolicy::Policy::Expanding, QSizePolicy::Policy::Minimum);

        horizontalLayout_7->addItem(horizontalSpacer_2);


        verticalLayout_3->addWidget(binoDetailsFrame);


        equipSettingsLayout->addWidget(binoGroupBox);


        gridLayout_3->addLayout(equipSettingsLayout, 0, 0, 1, 1);


        retranslateUi(WIEquipSettings);

        QMetaObject::connectSlotsByName(WIEquipSettings);
    } // setupUi

    void retranslateUi(QWidget *WIEquipSettings)
    {
        kcfg_TelescopeCheck->setText(tr2i18n("Telescope", nullptr));
        scopeSelectLabel->setText(tr2i18n("Select telescope from list to use or add a new telescope", nullptr));
        scopeDetailsBox->setTitle(tr2i18n("Telescope Details", nullptr));
        scopeVendorText->setText(tr2i18n("Vendor: ", nullptr));
        vendorText->setText(tr2i18n("--        ", nullptr));
        scopeModelText->setText(tr2i18n("Model:", nullptr));
        modelText->setText(tr2i18n("--        ", nullptr));
        scopeApertureText->setText(tr2i18n("Aperture:", nullptr));
        apertureText->setText(tr2i18n("--        ", nullptr));
        saveNewScopeButton->setText(tr2i18n("Add new telescope", nullptr));
        binoGroupBox->setTitle(QString());
        kcfg_BinocularsCheck->setText(tr2i18n("Binoculars", nullptr));
        binoApertureText->setText(tr2i18n("Specify aperture:", nullptr));
        binoApertureUnit->setText(tr2i18n("mm", nullptr));
        (void)WIEquipSettings;
    } // retranslateUi

};

namespace Ui {
    class WIEquipSettings: public Ui_WIEquipSettings {};
} // namespace Ui

QT_END_NAMESPACE

#endif // WIEQUIPSETTINGS_H

