/********************************************************************************
** Form generated from reading UI file 'darklibrary.ui'
**
** Created by: Qt User Interface Compiler version 6.11.1
**
** WARNING! All changes made in this file will be lost when recompiling UI file!
********************************************************************************/

#ifndef UI_DARKLIBRARY_H
#define UI_DARKLIBRARY_H

#include <QtCore/QVariant>
#include <QtGui/QIcon>
#include <QtWidgets/QApplication>
#include <QtWidgets/QButtonGroup>
#include <QtWidgets/QCheckBox>
#include <QtWidgets/QComboBox>
#include <QtWidgets/QDoubleSpinBox>
#include <QtWidgets/QGridLayout>
#include <QtWidgets/QGroupBox>
#include <QtWidgets/QHBoxLayout>
#include <QtWidgets/QHeaderView>
#include <QtWidgets/QLabel>
#include <QtWidgets/QProgressBar>
#include <QtWidgets/QPushButton>
#include <QtWidgets/QRadioButton>
#include <QtWidgets/QSlider>
#include <QtWidgets/QSpacerItem>
#include <QtWidgets/QSpinBox>
#include <QtWidgets/QTabWidget>
#include <QtWidgets/QTableView>
#include <QtWidgets/QVBoxLayout>
#include <QtWidgets/QWidget>
#include <klocalizedstring.h>

QT_BEGIN_NAMESPACE

class Ui_DarkLibrary
{
public:
    QVBoxLayout *mainLayout;
    QHBoxLayout *horizontalLayout_10;
    QVBoxLayout *leftLayout;
    QHBoxLayout *horizontalLayout_9;
    QVBoxLayout *verticalLayout_2;
    QLabel *label_25;
    QLabel *label_27;
    QVBoxLayout *verticalLayout_5;
    QHBoxLayout *horizontalLayout_8;
    QComboBox *opticalTrainCombo;
    QPushButton *trainB;
    QHBoxLayout *horizontalLayout_7;
    QRadioButton *preferDarksRadio;
    QRadioButton *preferDefectsRadio;
    QSpacerItem *horizontalSpacer_6;
    QTabWidget *darkTabsWidget;
    QWidget *darkTab;
    QVBoxLayout *verticalLayout_3;
    QGridLayout *gridLayout;
    QLabel *label_11;
    QDoubleSpinBox *maxTemperatureSpin;
    QLabel *label;
    QComboBox *combinAlgorithmCombo;
    QLabel *label_3;
    QLabel *label_14;
    QDoubleSpinBox *minTemperatureSpin;
    QLabel *temperatureLabel;
    QLabel *temperatureStepLabel;
    QLabel *totalTime;
    QHBoxLayout *horizontalLayout_2;
    QCheckBox *bin1Check;
    QCheckBox *bin2Check;
    QCheckBox *bin4Check;
    QSpacerItem *horizontalSpacer_3;
    QLabel *label_12;
    QLabel *label_5;
    QDoubleSpinBox *temperatureStepSpin;
    QDoubleSpinBox *exposureStepSin;
    QLabel *label_13;
    QDoubleSpinBox *minExposureSpin;
    QSpinBox *countSpin;
    QLabel *totalImages;
    QLabel *label_2;
    QDoubleSpinBox *maxExposureSpin;
    QLabel *temperatureToLabel;
    QLabel *label_9;
    QLabel *textLabel1_21;
    QDoubleSpinBox *captureGainN;
    QLabel *ISOLabel;
    QComboBox *captureISOS;
    QSpacerItem *verticalSpacer;
    QProgressBar *darkProgress;
    QHBoxLayout *horizontalLayout;
    QSpacerItem *horizontalSpacer;
    QPushButton *startB;
    QPushButton *stopB;
    QWidget *defectMapsTab;
    QVBoxLayout *verticalLayout_4;
    QHBoxLayout *horizontalLayout_3;
    QLabel *label_4;
    QComboBox *masterDarksCombo;
    QSpacerItem *horizontalSpacer_5;
    QGroupBox *groupBox;
    QGridLayout *gridLayout_2;
    QLabel *label_15;
    QLabel *masterTime;
    QLabel *label_16;
    QLabel *masterExposure;
    QLabel *label_17;
    QLabel *masterTemperature;
    QLabel *label_18;
    QLabel *masterMean;
    QLabel *label_19;
    QLabel *masterMedian;
    QLabel *label_20;
    QLabel *masterDeviation;
    QGroupBox *groupBox_2;
    QGridLayout *gridLayout_4;
    QLabel *label_21;
    QSpinBox *coldPixelsCount;
    QLabel *label_22;
    QCheckBox *coldPixelsEnabled;
    QHBoxLayout *horizontalLayout_4;
    QSlider *aggresivenessHotSlider;
    QSpinBox *aggresivenessHotSpin;
    QCheckBox *hotPixelsEnabled;
    QHBoxLayout *horizontalLayout_5;
    QSlider *aggresivenessColdSlider;
    QSpinBox *aggresivenessColdSpin;
    QSpinBox *hotPixelsCount;
    QHBoxLayout *horizontalLayout_6;
    QPushButton *resetMapParametersB;
    QSpacerItem *horizontalSpacer_4;
    QPushButton *generateMapB;
    QPushButton *saveMapB;
    QSpacerItem *verticalSpacer_2;
    QWidget *mastersTab;
    QVBoxLayout *verticalLayout;
    QGridLayout *gridLayout_3;
    QPushButton *clearRowB;
    QLabel *label_7;
    QPushButton *clearAllB;
    QLabel *label_8;
    QLabel *label_6;
    QSpacerItem *horizontalSpacer_2;
    QDoubleSpinBox *maxDarkTemperatureDiff;
    QPushButton *openDarksFolderB;
    QSpinBox *darkLibraryDuration;
    QLabel *label_10;
    QPushButton *clearExpiredB;
    QPushButton *refreshB;
    QTableView *darkTableView;
    QWidget *darkWidget;
    QButtonGroup *darkHandlingButtonGroup;
    QButtonGroup *binningButtonGroup;

    void setupUi(QWidget *DarkLibrary)
    {
        if (DarkLibrary->objectName().isEmpty())
            DarkLibrary->setObjectName("DarkLibrary");
        DarkLibrary->resize(767, 483);
        mainLayout = new QVBoxLayout(DarkLibrary);
        mainLayout->setSpacing(3);
        mainLayout->setObjectName("mainLayout");
        mainLayout->setContentsMargins(3, 3, 3, 3);
        horizontalLayout_10 = new QHBoxLayout();
        horizontalLayout_10->setObjectName("horizontalLayout_10");
        leftLayout = new QVBoxLayout();
        leftLayout->setObjectName("leftLayout");
        horizontalLayout_9 = new QHBoxLayout();
        horizontalLayout_9->setObjectName("horizontalLayout_9");
        verticalLayout_2 = new QVBoxLayout();
        verticalLayout_2->setObjectName("verticalLayout_2");
        label_25 = new QLabel(DarkLibrary);
        label_25->setObjectName("label_25");
        QSizePolicy sizePolicy(QSizePolicy::Policy::Preferred, QSizePolicy::Policy::Preferred);
        sizePolicy.setHorizontalStretch(0);
        sizePolicy.setVerticalStretch(0);
        sizePolicy.setHeightForWidth(label_25->sizePolicy().hasHeightForWidth());
        label_25->setSizePolicy(sizePolicy);

        verticalLayout_2->addWidget(label_25);

        label_27 = new QLabel(DarkLibrary);
        label_27->setObjectName("label_27");

        verticalLayout_2->addWidget(label_27);


        horizontalLayout_9->addLayout(verticalLayout_2);

        verticalLayout_5 = new QVBoxLayout();
        verticalLayout_5->setObjectName("verticalLayout_5");
        horizontalLayout_8 = new QHBoxLayout();
        horizontalLayout_8->setObjectName("horizontalLayout_8");
        opticalTrainCombo = new QComboBox(DarkLibrary);
        opticalTrainCombo->setObjectName("opticalTrainCombo");
        QSizePolicy sizePolicy1(QSizePolicy::Policy::MinimumExpanding, QSizePolicy::Policy::Fixed);
        sizePolicy1.setHorizontalStretch(0);
        sizePolicy1.setVerticalStretch(0);
        sizePolicy1.setHeightForWidth(opticalTrainCombo->sizePolicy().hasHeightForWidth());
        opticalTrainCombo->setSizePolicy(sizePolicy1);
        opticalTrainCombo->setMinimumSize(QSize(0, 32));

        horizontalLayout_8->addWidget(opticalTrainCombo);

        trainB = new QPushButton(DarkLibrary);
        trainB->setObjectName("trainB");
        trainB->setEnabled(false);
        trainB->setMinimumSize(QSize(24, 24));
        QIcon icon;
        QString iconThemeName = QString::fromUtf8("document-edit");
        if (QIcon::hasThemeIcon(iconThemeName)) {
            icon = QIcon::fromTheme(iconThemeName);
        } else {
            icon.addFile(QString::fromUtf8("."), QSize(), QIcon::Mode::Normal, QIcon::State::Off);
        }
        trainB->setIcon(icon);
        trainB->setIconSize(QSize(24, 24));

        horizontalLayout_8->addWidget(trainB);


        verticalLayout_5->addLayout(horizontalLayout_8);

        horizontalLayout_7 = new QHBoxLayout();
        horizontalLayout_7->setObjectName("horizontalLayout_7");
        preferDarksRadio = new QRadioButton(DarkLibrary);
        darkHandlingButtonGroup = new QButtonGroup(DarkLibrary);
        darkHandlingButtonGroup->setObjectName("darkHandlingButtonGroup");
        darkHandlingButtonGroup->addButton(preferDarksRadio);
        preferDarksRadio->setObjectName("preferDarksRadio");
        preferDarksRadio->setChecked(true);

        horizontalLayout_7->addWidget(preferDarksRadio);

        preferDefectsRadio = new QRadioButton(DarkLibrary);
        darkHandlingButtonGroup->addButton(preferDefectsRadio);
        preferDefectsRadio->setObjectName("preferDefectsRadio");

        horizontalLayout_7->addWidget(preferDefectsRadio);

        horizontalSpacer_6 = new QSpacerItem(40, 20, QSizePolicy::Policy::Expanding, QSizePolicy::Policy::Minimum);

        horizontalLayout_7->addItem(horizontalSpacer_6);


        verticalLayout_5->addLayout(horizontalLayout_7);


        horizontalLayout_9->addLayout(verticalLayout_5);


        leftLayout->addLayout(horizontalLayout_9);

        darkTabsWidget = new QTabWidget(DarkLibrary);
        darkTabsWidget->setObjectName("darkTabsWidget");
        darkTab = new QWidget();
        darkTab->setObjectName("darkTab");
        verticalLayout_3 = new QVBoxLayout(darkTab);
        verticalLayout_3->setSpacing(3);
        verticalLayout_3->setObjectName("verticalLayout_3");
        verticalLayout_3->setContentsMargins(3, 3, 3, 3);
        gridLayout = new QGridLayout();
        gridLayout->setSpacing(3);
        gridLayout->setObjectName("gridLayout");
        label_11 = new QLabel(darkTab);
        label_11->setObjectName("label_11");

        gridLayout->addWidget(label_11, 2, 0, 1, 1);

        maxTemperatureSpin = new QDoubleSpinBox(darkTab);
        maxTemperatureSpin->setObjectName("maxTemperatureSpin");
        maxTemperatureSpin->setMinimum(-50.000000000000000);
        maxTemperatureSpin->setMaximum(20.000000000000000);
        maxTemperatureSpin->setValue(0.000000000000000);

        gridLayout->addWidget(maxTemperatureSpin, 1, 3, 1, 1);

        label = new QLabel(darkTab);
        label->setObjectName("label");

        gridLayout->addWidget(label, 0, 0, 1, 1);

        combinAlgorithmCombo = new QComboBox(darkTab);
        combinAlgorithmCombo->addItem(QString());
        combinAlgorithmCombo->setObjectName("combinAlgorithmCombo");

        gridLayout->addWidget(combinAlgorithmCombo, 4, 4, 1, 2);

        label_3 = new QLabel(darkTab);
        label_3->setObjectName("label_3");

        gridLayout->addWidget(label_3, 0, 4, 1, 1);

        label_14 = new QLabel(darkTab);
        label_14->setObjectName("label_14");

        gridLayout->addWidget(label_14, 5, 5, 1, 1);

        minTemperatureSpin = new QDoubleSpinBox(darkTab);
        minTemperatureSpin->setObjectName("minTemperatureSpin");
        minTemperatureSpin->setMinimum(-50.000000000000000);
        minTemperatureSpin->setMaximum(20.000000000000000);
        minTemperatureSpin->setValue(0.000000000000000);

        gridLayout->addWidget(minTemperatureSpin, 1, 1, 1, 1);

        temperatureLabel = new QLabel(darkTab);
        temperatureLabel->setObjectName("temperatureLabel");

        gridLayout->addWidget(temperatureLabel, 1, 0, 1, 1);

        temperatureStepLabel = new QLabel(darkTab);
        temperatureStepLabel->setObjectName("temperatureStepLabel");

        gridLayout->addWidget(temperatureStepLabel, 1, 4, 1, 1);

        totalTime = new QLabel(darkTab);
        totalTime->setObjectName("totalTime");
        totalTime->setFrameShape(QFrame::Box);
        totalTime->setAlignment(Qt::AlignCenter);

        gridLayout->addWidget(totalTime, 5, 4, 1, 1);

        horizontalLayout_2 = new QHBoxLayout();
        horizontalLayout_2->setSpacing(3);
        horizontalLayout_2->setObjectName("horizontalLayout_2");
        bin1Check = new QCheckBox(darkTab);
        binningButtonGroup = new QButtonGroup(DarkLibrary);
        binningButtonGroup->setObjectName("binningButtonGroup");
        binningButtonGroup->setExclusive(false);
        binningButtonGroup->addButton(bin1Check);
        bin1Check->setObjectName("bin1Check");
        bin1Check->setChecked(true);

        horizontalLayout_2->addWidget(bin1Check);

        bin2Check = new QCheckBox(darkTab);
        binningButtonGroup->addButton(bin2Check);
        bin2Check->setObjectName("bin2Check");

        horizontalLayout_2->addWidget(bin2Check);

        bin4Check = new QCheckBox(darkTab);
        binningButtonGroup->addButton(bin4Check);
        bin4Check->setObjectName("bin4Check");

        horizontalLayout_2->addWidget(bin4Check);

        horizontalSpacer_3 = new QSpacerItem(40, 20, QSizePolicy::Policy::Expanding, QSizePolicy::Policy::Minimum);

        horizontalLayout_2->addItem(horizontalSpacer_3);


        gridLayout->addLayout(horizontalLayout_2, 2, 1, 1, 5);

        label_12 = new QLabel(darkTab);
        label_12->setObjectName("label_12");

        gridLayout->addWidget(label_12, 4, 0, 1, 1);

        label_5 = new QLabel(darkTab);
        label_5->setObjectName("label_5");

        gridLayout->addWidget(label_5, 4, 3, 1, 1);

        temperatureStepSpin = new QDoubleSpinBox(darkTab);
        temperatureStepSpin->setObjectName("temperatureStepSpin");
        temperatureStepSpin->setMinimum(0.500000000000000);
        temperatureStepSpin->setMaximum(20.000000000000000);
        temperatureStepSpin->setValue(1.000000000000000);

        gridLayout->addWidget(temperatureStepSpin, 1, 5, 1, 1);

        exposureStepSin = new QDoubleSpinBox(darkTab);
        exposureStepSin->setObjectName("exposureStepSin");
        exposureStepSin->setMinimum(0.500000000000000);
        exposureStepSin->setMaximum(20.000000000000000);
        exposureStepSin->setValue(1.000000000000000);

        gridLayout->addWidget(exposureStepSin, 0, 5, 1, 1);

        label_13 = new QLabel(darkTab);
        label_13->setObjectName("label_13");

        gridLayout->addWidget(label_13, 5, 3, 1, 1);

        minExposureSpin = new QDoubleSpinBox(darkTab);
        minExposureSpin->setObjectName("minExposureSpin");
        minExposureSpin->setMinimum(0.010000000000000);
        minExposureSpin->setMaximum(998.000000000000000);
        minExposureSpin->setValue(1.000000000000000);

        gridLayout->addWidget(minExposureSpin, 0, 1, 1, 1);

        countSpin = new QSpinBox(darkTab);
        countSpin->setObjectName("countSpin");
        countSpin->setMinimum(3);
        countSpin->setMaximum(20);
        countSpin->setValue(5);

        gridLayout->addWidget(countSpin, 4, 1, 1, 1);

        totalImages = new QLabel(darkTab);
        totalImages->setObjectName("totalImages");
        totalImages->setFrameShape(QFrame::Box);
        totalImages->setAlignment(Qt::AlignCenter);

        gridLayout->addWidget(totalImages, 5, 1, 1, 1);

        label_2 = new QLabel(darkTab);
        label_2->setObjectName("label_2");

        gridLayout->addWidget(label_2, 0, 2, 1, 1);

        maxExposureSpin = new QDoubleSpinBox(darkTab);
        maxExposureSpin->setObjectName("maxExposureSpin");
        maxExposureSpin->setMinimum(0.010000000000000);
        maxExposureSpin->setMaximum(999.000000000000000);
        maxExposureSpin->setValue(5.000000000000000);

        gridLayout->addWidget(maxExposureSpin, 0, 3, 1, 1);

        temperatureToLabel = new QLabel(darkTab);
        temperatureToLabel->setObjectName("temperatureToLabel");

        gridLayout->addWidget(temperatureToLabel, 1, 2, 1, 1);

        label_9 = new QLabel(darkTab);
        label_9->setObjectName("label_9");

        gridLayout->addWidget(label_9, 5, 0, 1, 1);

        textLabel1_21 = new QLabel(darkTab);
        textLabel1_21->setObjectName("textLabel1_21");

        gridLayout->addWidget(textLabel1_21, 3, 0, 1, 1);

        captureGainN = new QDoubleSpinBox(darkTab);
        captureGainN->setObjectName("captureGainN");
        sizePolicy1.setHeightForWidth(captureGainN->sizePolicy().hasHeightForWidth());
        captureGainN->setSizePolicy(sizePolicy1);
        captureGainN->setDecimals(1);
        captureGainN->setMaximum(10000.000000000000000);
        captureGainN->setSingleStep(10.000000000000000);

        gridLayout->addWidget(captureGainN, 3, 1, 1, 1);

        ISOLabel = new QLabel(darkTab);
        ISOLabel->setObjectName("ISOLabel");
        ISOLabel->setAlignment(Qt::AlignLeading|Qt::AlignLeft|Qt::AlignVCenter);

        gridLayout->addWidget(ISOLabel, 3, 2, 1, 1);

        captureISOS = new QComboBox(darkTab);
        captureISOS->setObjectName("captureISOS");

        gridLayout->addWidget(captureISOS, 3, 3, 1, 3);


        verticalLayout_3->addLayout(gridLayout);

        verticalSpacer = new QSpacerItem(20, 144, QSizePolicy::Policy::Minimum, QSizePolicy::Policy::Expanding);

        verticalLayout_3->addItem(verticalSpacer);

        darkProgress = new QProgressBar(darkTab);
        darkProgress->setObjectName("darkProgress");
        darkProgress->setEnabled(false);
        darkProgress->setValue(0);
        darkProgress->setTextVisible(false);
        darkProgress->setInvertedAppearance(false);

        verticalLayout_3->addWidget(darkProgress);

        horizontalLayout = new QHBoxLayout();
        horizontalLayout->setSpacing(3);
        horizontalLayout->setObjectName("horizontalLayout");
        horizontalSpacer = new QSpacerItem(40, 20, QSizePolicy::Policy::Expanding, QSizePolicy::Policy::Minimum);

        horizontalLayout->addItem(horizontalSpacer);

        startB = new QPushButton(darkTab);
        startB->setObjectName("startB");

        horizontalLayout->addWidget(startB);

        stopB = new QPushButton(darkTab);
        stopB->setObjectName("stopB");
        stopB->setEnabled(false);

        horizontalLayout->addWidget(stopB);


        verticalLayout_3->addLayout(horizontalLayout);

        darkTabsWidget->addTab(darkTab, QString());
        defectMapsTab = new QWidget();
        defectMapsTab->setObjectName("defectMapsTab");
        verticalLayout_4 = new QVBoxLayout(defectMapsTab);
        verticalLayout_4->setSpacing(3);
        verticalLayout_4->setObjectName("verticalLayout_4");
        verticalLayout_4->setContentsMargins(3, 3, 3, 3);
        horizontalLayout_3 = new QHBoxLayout();
        horizontalLayout_3->setSpacing(3);
        horizontalLayout_3->setObjectName("horizontalLayout_3");
        label_4 = new QLabel(defectMapsTab);
        label_4->setObjectName("label_4");

        horizontalLayout_3->addWidget(label_4);

        masterDarksCombo = new QComboBox(defectMapsTab);
        masterDarksCombo->setObjectName("masterDarksCombo");
        sizePolicy1.setHeightForWidth(masterDarksCombo->sizePolicy().hasHeightForWidth());
        masterDarksCombo->setSizePolicy(sizePolicy1);
        masterDarksCombo->setMinimumSize(QSize(0, 32));

        horizontalLayout_3->addWidget(masterDarksCombo);

        horizontalSpacer_5 = new QSpacerItem(40, 20, QSizePolicy::Policy::Expanding, QSizePolicy::Policy::Minimum);

        horizontalLayout_3->addItem(horizontalSpacer_5);


        verticalLayout_4->addLayout(horizontalLayout_3);

        groupBox = new QGroupBox(defectMapsTab);
        groupBox->setObjectName("groupBox");
        gridLayout_2 = new QGridLayout(groupBox);
        gridLayout_2->setSpacing(3);
        gridLayout_2->setObjectName("gridLayout_2");
        gridLayout_2->setContentsMargins(3, 3, 3, 3);
        label_15 = new QLabel(groupBox);
        label_15->setObjectName("label_15");

        gridLayout_2->addWidget(label_15, 0, 0, 1, 1);

        masterTime = new QLabel(groupBox);
        masterTime->setObjectName("masterTime");
        masterTime->setFrameShape(QFrame::Box);
        masterTime->setMidLineWidth(0);
        masterTime->setAlignment(Qt::AlignCenter);

        gridLayout_2->addWidget(masterTime, 0, 1, 1, 1);

        label_16 = new QLabel(groupBox);
        label_16->setObjectName("label_16");

        gridLayout_2->addWidget(label_16, 0, 2, 1, 1);

        masterExposure = new QLabel(groupBox);
        masterExposure->setObjectName("masterExposure");
        masterExposure->setFrameShape(QFrame::Box);
        masterExposure->setAlignment(Qt::AlignCenter);

        gridLayout_2->addWidget(masterExposure, 0, 3, 1, 1);

        label_17 = new QLabel(groupBox);
        label_17->setObjectName("label_17");

        gridLayout_2->addWidget(label_17, 1, 0, 1, 1);

        masterTemperature = new QLabel(groupBox);
        masterTemperature->setObjectName("masterTemperature");
        masterTemperature->setFrameShape(QFrame::Box);
        masterTemperature->setAlignment(Qt::AlignCenter);

        gridLayout_2->addWidget(masterTemperature, 1, 1, 1, 1);

        label_18 = new QLabel(groupBox);
        label_18->setObjectName("label_18");

        gridLayout_2->addWidget(label_18, 1, 2, 1, 1);

        masterMean = new QLabel(groupBox);
        masterMean->setObjectName("masterMean");
        masterMean->setFrameShape(QFrame::Box);
        masterMean->setAlignment(Qt::AlignCenter);

        gridLayout_2->addWidget(masterMean, 1, 3, 1, 1);

        label_19 = new QLabel(groupBox);
        label_19->setObjectName("label_19");

        gridLayout_2->addWidget(label_19, 2, 0, 1, 1);

        masterMedian = new QLabel(groupBox);
        masterMedian->setObjectName("masterMedian");
        masterMedian->setFrameShape(QFrame::Box);
        masterMedian->setAlignment(Qt::AlignCenter);

        gridLayout_2->addWidget(masterMedian, 2, 1, 1, 1);

        label_20 = new QLabel(groupBox);
        label_20->setObjectName("label_20");

        gridLayout_2->addWidget(label_20, 2, 2, 1, 1);

        masterDeviation = new QLabel(groupBox);
        masterDeviation->setObjectName("masterDeviation");
        masterDeviation->setFrameShape(QFrame::Box);
        masterDeviation->setAlignment(Qt::AlignCenter);

        gridLayout_2->addWidget(masterDeviation, 2, 3, 1, 1);


        verticalLayout_4->addWidget(groupBox);

        groupBox_2 = new QGroupBox(defectMapsTab);
        groupBox_2->setObjectName("groupBox_2");
        gridLayout_4 = new QGridLayout(groupBox_2);
        gridLayout_4->setSpacing(3);
        gridLayout_4->setObjectName("gridLayout_4");
        gridLayout_4->setContentsMargins(3, 3, 3, 3);
        label_21 = new QLabel(groupBox_2);
        label_21->setObjectName("label_21");

        gridLayout_4->addWidget(label_21, 0, 0, 1, 1);

        coldPixelsCount = new QSpinBox(groupBox_2);
        coldPixelsCount->setObjectName("coldPixelsCount");
        coldPixelsCount->setReadOnly(true);
        coldPixelsCount->setMaximum(10000000);

        gridLayout_4->addWidget(coldPixelsCount, 1, 3, 1, 1);

        label_22 = new QLabel(groupBox_2);
        label_22->setObjectName("label_22");

        gridLayout_4->addWidget(label_22, 1, 0, 1, 1);

        coldPixelsEnabled = new QCheckBox(groupBox_2);
        coldPixelsEnabled->setObjectName("coldPixelsEnabled");
        coldPixelsEnabled->setChecked(true);

        gridLayout_4->addWidget(coldPixelsEnabled, 1, 5, 1, 1);

        horizontalLayout_4 = new QHBoxLayout();
        horizontalLayout_4->setSpacing(3);
        horizontalLayout_4->setObjectName("horizontalLayout_4");
        aggresivenessHotSlider = new QSlider(groupBox_2);
        aggresivenessHotSlider->setObjectName("aggresivenessHotSlider");
        aggresivenessHotSlider->setMaximum(100);
        aggresivenessHotSlider->setSingleStep(5);
        aggresivenessHotSlider->setValue(75);
        aggresivenessHotSlider->setOrientation(Qt::Horizontal);

        horizontalLayout_4->addWidget(aggresivenessHotSlider);

        aggresivenessHotSpin = new QSpinBox(groupBox_2);
        aggresivenessHotSpin->setObjectName("aggresivenessHotSpin");
        aggresivenessHotSpin->setMaximum(100);
        aggresivenessHotSpin->setValue(75);

        horizontalLayout_4->addWidget(aggresivenessHotSpin);


        gridLayout_4->addLayout(horizontalLayout_4, 0, 4, 1, 1);

        hotPixelsEnabled = new QCheckBox(groupBox_2);
        hotPixelsEnabled->setObjectName("hotPixelsEnabled");
        hotPixelsEnabled->setChecked(true);

        gridLayout_4->addWidget(hotPixelsEnabled, 0, 5, 1, 1);

        horizontalLayout_5 = new QHBoxLayout();
        horizontalLayout_5->setSpacing(3);
        horizontalLayout_5->setObjectName("horizontalLayout_5");
        aggresivenessColdSlider = new QSlider(groupBox_2);
        aggresivenessColdSlider->setObjectName("aggresivenessColdSlider");
        aggresivenessColdSlider->setMaximum(100);
        aggresivenessColdSlider->setSingleStep(5);
        aggresivenessColdSlider->setValue(75);
        aggresivenessColdSlider->setOrientation(Qt::Horizontal);

        horizontalLayout_5->addWidget(aggresivenessColdSlider);

        aggresivenessColdSpin = new QSpinBox(groupBox_2);
        aggresivenessColdSpin->setObjectName("aggresivenessColdSpin");
        aggresivenessColdSpin->setMaximum(100);
        aggresivenessColdSpin->setValue(75);

        horizontalLayout_5->addWidget(aggresivenessColdSpin);


        gridLayout_4->addLayout(horizontalLayout_5, 1, 4, 1, 1);

        hotPixelsCount = new QSpinBox(groupBox_2);
        hotPixelsCount->setObjectName("hotPixelsCount");
        hotPixelsCount->setReadOnly(true);
        hotPixelsCount->setMaximum(10000000);

        gridLayout_4->addWidget(hotPixelsCount, 0, 3, 1, 1);


        verticalLayout_4->addWidget(groupBox_2);

        horizontalLayout_6 = new QHBoxLayout();
        horizontalLayout_6->setSpacing(3);
        horizontalLayout_6->setObjectName("horizontalLayout_6");
        resetMapParametersB = new QPushButton(defectMapsTab);
        resetMapParametersB->setObjectName("resetMapParametersB");
        resetMapParametersB->setMinimumSize(QSize(0, 32));

        horizontalLayout_6->addWidget(resetMapParametersB);

        horizontalSpacer_4 = new QSpacerItem(40, 20, QSizePolicy::Policy::Expanding, QSizePolicy::Policy::Minimum);

        horizontalLayout_6->addItem(horizontalSpacer_4);

        generateMapB = new QPushButton(defectMapsTab);
        generateMapB->setObjectName("generateMapB");
        generateMapB->setMinimumSize(QSize(0, 32));

        horizontalLayout_6->addWidget(generateMapB);

        saveMapB = new QPushButton(defectMapsTab);
        saveMapB->setObjectName("saveMapB");
        saveMapB->setMinimumSize(QSize(32, 32));
        saveMapB->setMaximumSize(QSize(32, 32));
        QIcon icon1;
        iconThemeName = QString::fromUtf8("document-save");
        if (QIcon::hasThemeIcon(iconThemeName)) {
            icon1 = QIcon::fromTheme(iconThemeName);
        } else {
            icon1.addFile(QString::fromUtf8("."), QSize(), QIcon::Mode::Normal, QIcon::State::Off);
        }
        saveMapB->setIcon(icon1);
        saveMapB->setIconSize(QSize(28, 28));

        horizontalLayout_6->addWidget(saveMapB);


        verticalLayout_4->addLayout(horizontalLayout_6);

        verticalSpacer_2 = new QSpacerItem(20, 40, QSizePolicy::Policy::Minimum, QSizePolicy::Policy::Expanding);

        verticalLayout_4->addItem(verticalSpacer_2);

        darkTabsWidget->addTab(defectMapsTab, QString());
        mastersTab = new QWidget();
        mastersTab->setObjectName("mastersTab");
        verticalLayout = new QVBoxLayout(mastersTab);
        verticalLayout->setSpacing(3);
        verticalLayout->setObjectName("verticalLayout");
        verticalLayout->setContentsMargins(3, 3, 3, 3);
        gridLayout_3 = new QGridLayout();
        gridLayout_3->setSpacing(3);
        gridLayout_3->setObjectName("gridLayout_3");
        clearRowB = new QPushButton(mastersTab);
        clearRowB->setObjectName("clearRowB");

        gridLayout_3->addWidget(clearRowB, 2, 4, 1, 1);

        label_7 = new QLabel(mastersTab);
        label_7->setObjectName("label_7");

        gridLayout_3->addWidget(label_7, 2, 0, 1, 1);

        clearAllB = new QPushButton(mastersTab);
        clearAllB->setObjectName("clearAllB");

        gridLayout_3->addWidget(clearAllB, 2, 6, 1, 1);

        label_8 = new QLabel(mastersTab);
        label_8->setObjectName("label_8");

        gridLayout_3->addWidget(label_8, 2, 2, 1, 1);

        label_6 = new QLabel(mastersTab);
        label_6->setObjectName("label_6");

        gridLayout_3->addWidget(label_6, 0, 0, 1, 1);

        horizontalSpacer_2 = new QSpacerItem(40, 20, QSizePolicy::Policy::Expanding, QSizePolicy::Policy::Minimum);

        gridLayout_3->addItem(horizontalSpacer_2, 0, 3, 1, 1);

        maxDarkTemperatureDiff = new QDoubleSpinBox(mastersTab);
        maxDarkTemperatureDiff->setObjectName("maxDarkTemperatureDiff");
        maxDarkTemperatureDiff->setMinimum(0.100000000000000);
        maxDarkTemperatureDiff->setMaximum(30.000000000000000);
        maxDarkTemperatureDiff->setSingleStep(0.100000000000000);
        maxDarkTemperatureDiff->setValue(1.000000000000000);

        gridLayout_3->addWidget(maxDarkTemperatureDiff, 2, 1, 1, 1);

        openDarksFolderB = new QPushButton(mastersTab);
        openDarksFolderB->setObjectName("openDarksFolderB");

        gridLayout_3->addWidget(openDarksFolderB, 0, 6, 1, 1);

        darkLibraryDuration = new QSpinBox(mastersTab);
        darkLibraryDuration->setObjectName("darkLibraryDuration");
        darkLibraryDuration->setMaximum(365);
        darkLibraryDuration->setSingleStep(10);

        gridLayout_3->addWidget(darkLibraryDuration, 0, 1, 1, 1);

        label_10 = new QLabel(mastersTab);
        label_10->setObjectName("label_10");

        gridLayout_3->addWidget(label_10, 0, 2, 1, 1);

        clearExpiredB = new QPushButton(mastersTab);
        clearExpiredB->setObjectName("clearExpiredB");

        gridLayout_3->addWidget(clearExpiredB, 2, 5, 1, 1);

        refreshB = new QPushButton(mastersTab);
        refreshB->setObjectName("refreshB");

        gridLayout_3->addWidget(refreshB, 0, 5, 1, 1);


        verticalLayout->addLayout(gridLayout_3);

        darkTableView = new QTableView(mastersTab);
        darkTableView->setObjectName("darkTableView");
        darkTableView->setEditTriggers(QAbstractItemView::NoEditTriggers);
        darkTableView->setAlternatingRowColors(true);
        darkTableView->setSelectionMode(QAbstractItemView::SingleSelection);
        darkTableView->setSelectionBehavior(QAbstractItemView::SelectRows);
        darkTableView->setSortingEnabled(true);
        darkTableView->horizontalHeader()->setStretchLastSection(true);

        verticalLayout->addWidget(darkTableView);

        darkTabsWidget->addTab(mastersTab, QString());

        leftLayout->addWidget(darkTabsWidget);


        horizontalLayout_10->addLayout(leftLayout);

        darkWidget = new QWidget(DarkLibrary);
        darkWidget->setObjectName("darkWidget");
        QSizePolicy sizePolicy2(QSizePolicy::Policy::Expanding, QSizePolicy::Policy::Expanding);
        sizePolicy2.setHorizontalStretch(0);
        sizePolicy2.setVerticalStretch(0);
        sizePolicy2.setHeightForWidth(darkWidget->sizePolicy().hasHeightForWidth());
        darkWidget->setSizePolicy(sizePolicy2);
        darkWidget->setMinimumSize(QSize(320, 240));
        darkWidget->setMaximumSize(QSize(16777215, 16777215));
        darkWidget->setSizeIncrement(QSize(40, 30));

        horizontalLayout_10->addWidget(darkWidget);

        horizontalLayout_10->setStretch(0, 1);
        horizontalLayout_10->setStretch(1, 2);

        mainLayout->addLayout(horizontalLayout_10);


        retranslateUi(DarkLibrary);

        darkTabsWidget->setCurrentIndex(0);


        QMetaObject::connectSlotsByName(DarkLibrary);
    } // setupUi

    void retranslateUi(QWidget *DarkLibrary)
    {
        DarkLibrary->setWindowTitle(tr2i18n("Dark Library", nullptr));
        label_25->setText(tr2i18n("Train:", nullptr));
        label_27->setText(tr2i18n("Prefer:", nullptr));
        trainB->setText(QString());
#if QT_CONFIG(tooltip)
        preferDarksRadio->setToolTip(tr2i18n("For the selected camera, remove noise by means of dark frame subtraction.", nullptr));
#endif // QT_CONFIG(tooltip)
        preferDarksRadio->setText(tr2i18n("Darks", nullptr));
#if QT_CONFIG(tooltip)
        preferDefectsRadio->setToolTip(tr2i18n("For the selected camera, remove noise by means of defect map filtering.", nullptr));
#endif // QT_CONFIG(tooltip)
        preferDefectsRadio->setText(tr2i18n("Defects", nullptr));
        label_11->setText(tr2i18n("Binning:", nullptr));
        label->setText(tr2i18n("Exp. range:", nullptr));
        combinAlgorithmCombo->setItemText(0, tr2i18n("Average", nullptr));

        label_3->setText(tr2i18n("Step:", nullptr));
        label_14->setText(tr2i18n("minutes", nullptr));
        temperatureLabel->setText(tr2i18n("T. range:", nullptr));
        temperatureStepLabel->setText(tr2i18n("Step:", nullptr));
#if QT_CONFIG(tooltip)
        totalTime->setToolTip(tr2i18n("Total estimated time until all dark frames are captured and processed.", nullptr));
#endif // QT_CONFIG(tooltip)
        totalTime->setText(tr2i18n("--", nullptr));
        bin1Check->setText(tr2i18n("1x1", nullptr));
        bin2Check->setText(tr2i18n("2x2", nullptr));
        bin4Check->setText(tr2i18n("4x4", nullptr));
        label_12->setText(tr2i18n("Count:", nullptr));
        label_5->setText(tr2i18n("Algorithm:", nullptr));
#if QT_CONFIG(tooltip)
        exposureStepSin->setToolTip(tr2i18n("Step size in seconds", nullptr));
#endif // QT_CONFIG(tooltip)
        label_13->setText(tr2i18n("Total time:", nullptr));
#if QT_CONFIG(tooltip)
        minExposureSpin->setToolTip(tr2i18n("Minimum exposure time in seconds.", nullptr));
#endif // QT_CONFIG(tooltip)
#if QT_CONFIG(tooltip)
        countSpin->setToolTip(tr2i18n("Captures per configuration. This number of images would be averaged to produce the master dark frame.", nullptr));
#endif // QT_CONFIG(tooltip)
        totalImages->setText(tr2i18n("--", nullptr));
        label_2->setText(tr2i18n("To:", nullptr));
#if QT_CONFIG(tooltip)
        maxExposureSpin->setToolTip(tr2i18n("Maximum exposure time in seconds.", nullptr));
#endif // QT_CONFIG(tooltip)
        temperatureToLabel->setText(tr2i18n("To:", nullptr));
        label_9->setText(tr2i18n("Total images:", nullptr));
#if QT_CONFIG(tooltip)
        textLabel1_21->setToolTip(tr2i18n("Camera Gain", nullptr));
#endif // QT_CONFIG(tooltip)
#if QT_CONFIG(whatsthis)
        textLabel1_21->setWhatsThis(QString());
#endif // QT_CONFIG(whatsthis)
        textLabel1_21->setText(tr2i18n("Gain:", nullptr));
#if QT_CONFIG(tooltip)
        captureGainN->setToolTip(tr2i18n("Camera Gain", nullptr));
#endif // QT_CONFIG(tooltip)
        ISOLabel->setText(tr2i18n("ISO:", nullptr));
#if QT_CONFIG(tooltip)
        captureISOS->setToolTip(tr2i18n("Camera ISO", nullptr));
#endif // QT_CONFIG(tooltip)
        darkProgress->setFormat(tr2i18n("%v/%m", nullptr));
        startB->setText(tr2i18n("Start", nullptr));
        stopB->setText(tr2i18n("Stop", nullptr));
        darkTabsWidget->setTabText(darkTabsWidget->indexOf(darkTab), tr2i18n("Darks", nullptr));
        label_4->setText(tr2i18n("Master Dark:", nullptr));
        groupBox->setTitle(tr2i18n("Info", nullptr));
        label_15->setText(tr2i18n("Time:", nullptr));
        masterTime->setText(tr2i18n("--", nullptr));
        label_16->setText(tr2i18n("Exposure:", nullptr));
        masterExposure->setText(tr2i18n("--", nullptr));
        label_17->setText(tr2i18n("Temperature:", nullptr));
        masterTemperature->setText(tr2i18n("--", nullptr));
        label_18->setText(tr2i18n("Mean:", nullptr));
        masterMean->setText(tr2i18n("--", nullptr));
        label_19->setText(tr2i18n("Median:", nullptr));
        masterMedian->setText(tr2i18n("--", nullptr));
        label_20->setText(tr2i18n("Std. deviation:", nullptr));
        masterDeviation->setText(tr2i18n("--", nullptr));
        groupBox_2->setTitle(tr2i18n("Bad Pixels", nullptr));
        label_21->setText(tr2i18n("Hot pixels:", nullptr));
#if QT_CONFIG(tooltip)
        coldPixelsCount->setToolTip(tr2i18n("Detected pixels after aggressiveness filter", nullptr));
#endif // QT_CONFIG(tooltip)
        label_22->setText(tr2i18n("Cold pixels:", nullptr));
#if QT_CONFIG(tooltip)
        coldPixelsEnabled->setToolTip(tr2i18n("Enable cold pixel detection in the master dark frame.", nullptr));
#endif // QT_CONFIG(tooltip)
        coldPixelsEnabled->setText(tr2i18n("Enabled", nullptr));
#if QT_CONFIG(tooltip)
        aggresivenessHotSlider->setToolTip(tr2i18n("Aggressiveness level. Increase value to include more hot pixels. Click Generate Map to execute.", nullptr));
#endif // QT_CONFIG(tooltip)
#if QT_CONFIG(tooltip)
        hotPixelsEnabled->setToolTip(tr2i18n("Enable detection of hot pixels in the master dark frame.", nullptr));
#endif // QT_CONFIG(tooltip)
        hotPixelsEnabled->setText(tr2i18n("Enabled", nullptr));
#if QT_CONFIG(tooltip)
        aggresivenessColdSlider->setToolTip(tr2i18n("Aggressiveness level. Increase value to include more cold pixels.  Click Generate Map to execute.", nullptr));
#endif // QT_CONFIG(tooltip)
#if QT_CONFIG(tooltip)
        hotPixelsCount->setToolTip(tr2i18n("Detected pixels after aggressiveness filter", nullptr));
#endif // QT_CONFIG(tooltip)
#if QT_CONFIG(tooltip)
        resetMapParametersB->setToolTip(tr2i18n("Reset aggressiveness sliders to default values.", nullptr));
#endif // QT_CONFIG(tooltip)
        resetMapParametersB->setText(tr2i18n("Reset", nullptr));
#if QT_CONFIG(tooltip)
        generateMapB->setToolTip(tr2i18n("Detect hot and cold pixels within the aggressiveness threshold.", nullptr));
#endif // QT_CONFIG(tooltip)
        generateMapB->setText(tr2i18n("Generate Map", nullptr));
#if QT_CONFIG(tooltip)
        saveMapB->setToolTip(tr2i18n("Save defect map to disk once the map results are satisfactory.", nullptr));
#endif // QT_CONFIG(tooltip)
        saveMapB->setText(QString());
        darkTabsWidget->setTabText(darkTabsWidget->indexOf(defectMapsTab), tr2i18n("Defect Maps", nullptr));
#if QT_CONFIG(tooltip)
        clearRowB->setToolTip(tr2i18n("Remove one row from the database and delete the associated dark frame from disk", nullptr));
#endif // QT_CONFIG(tooltip)
        clearRowB->setText(tr2i18n("Clear Row", nullptr));
#if QT_CONFIG(tooltip)
        label_7->setToolTip(tr2i18n("Maximum acceptable difference between current and recorded dark frame temperature set point. When the difference exceeds this value, a new dark frame shall be captured for this set point.", nullptr));
#endif // QT_CONFIG(tooltip)
        label_7->setText(tr2i18n("T. threshold:", nullptr));
#if QT_CONFIG(tooltip)
        clearAllB->setToolTip(tr2i18n("Remove all dark frames data and files", nullptr));
#endif // QT_CONFIG(tooltip)
        clearAllB->setText(tr2i18n("Clear All", nullptr));
        label_8->setText(tr2i18n("\302\260 C", nullptr));
#if QT_CONFIG(tooltip)
        label_6->setToolTip(tr2i18n("Reuse dark frames from the dark library for this many days. If exceeded, a new dark frame shall be captured and stored for future use.", nullptr));
#endif // QT_CONFIG(tooltip)
        label_6->setText(tr2i18n("Dark validity:", nullptr));
#if QT_CONFIG(tooltip)
        openDarksFolderB->setToolTip(tr2i18n("Open folder where dark frames are stored", nullptr));
#endif // QT_CONFIG(tooltip)
        openDarksFolderB->setText(tr2i18n("Darks Folder", nullptr));
        label_10->setText(tr2i18n("days", nullptr));
        clearExpiredB->setText(tr2i18n("Clear Expired", nullptr));
        refreshB->setText(tr2i18n("Refresh", nullptr));
#if QT_CONFIG(tooltip)
        darkTableView->setToolTip(tr2i18n("Double click to load dark frame", nullptr));
#endif // QT_CONFIG(tooltip)
        darkTabsWidget->setTabText(darkTabsWidget->indexOf(mastersTab), tr2i18n("Masters", nullptr));
    } // retranslateUi

};

namespace Ui {
    class DarkLibrary: public Ui_DarkLibrary {};
} // namespace Ui

QT_END_NAMESPACE

#endif // DARKLIBRARY_H

