/********************************************************************************
** Form generated from reading UI file 'execute.ui'
**
** Created by: Qt User Interface Compiler version 6.11.1
**
** WARNING! All changes made in this file will be lost when recompiling UI file!
********************************************************************************/

#ifndef UI_EXECUTE_H
#define UI_EXECUTE_H

#include <QtCore/QVariant>
#include <QtWidgets/QApplication>
#include <QtWidgets/QComboBox>
#include <QtWidgets/QDateTimeEdit>
#include <QtWidgets/QDoubleSpinBox>
#include <QtWidgets/QFormLayout>
#include <QtWidgets/QGridLayout>
#include <QtWidgets/QHBoxLayout>
#include <QtWidgets/QLabel>
#include <QtWidgets/QLineEdit>
#include <QtWidgets/QListWidget>
#include <QtWidgets/QPushButton>
#include <QtWidgets/QSpacerItem>
#include <QtWidgets/QStackedWidget>
#include <QtWidgets/QTextEdit>
#include <QtWidgets/QTimeEdit>
#include <QtWidgets/QVBoxLayout>
#include <QtWidgets/QWidget>
#include <klocalizedstring.h>
#include "ktitlewidget.h"
#include "kurllabel.h"

QT_BEGIN_NAMESPACE

class Ui_Execute
{
public:
    QGridLayout *gridLayout_2;
    QVBoxLayout *verticalLayout;
    QStackedWidget *stackedWidget;
    QWidget *Session;
    QVBoxLayout *verticalLayout_2;
    KTitleWidget *ktitlewidget;
    QFormLayout *formLayout;
    QLabel *label_2;
    QPushButton *Location;
    QLabel *label_3;
    QDateTimeEdit *Begin;
    QLabel *label_4;
    QTextEdit *Weather;
    QLabel *label_5;
    QTextEdit *Equipment;
    QLabel *label_6;
    QTextEdit *Comment;
    QLabel *label_7;
    QLineEdit *Language;
    QWidget *TargetDetails;
    QVBoxLayout *verticalLayout_4;
    KTitleWidget *ktitlewidget_2;
    QGridLayout *gridLayout;
    QLabel *label_20;
    QLineEdit *Mag;
    QLabel *label_22;
    QLineEdit *Type;
    QLabel *label_24;
    QLineEdit *SchTime;
    QLabel *label_26;
    QLineEdit *RA;
    QLabel *label_27;
    QLineEdit *Dec;
    QLabel *label_21;
    QLineEdit *Alt;
    QLabel *label_23;
    QLineEdit *Az;
    KTitleWidget *ktitlewidget_4;
    QHBoxLayout *horizontalLayout_2;
    QTextEdit *Notes;
    QHBoxLayout *horizontalLayout_3;
    QSpacerItem *horizontalSpacer_2;
    QPushButton *Slew;
    QWidget *page_2;
    QVBoxLayout *verticalLayout_3;
    KTitleWidget *ktitlewidget_3;
    QFormLayout *formLayout_2;
    QLabel *label_19;
    QComboBox *Observer;
    QLabel *label_11;
    QComboBox *Scope;
    QLabel *label_12;
    QComboBox *Eyepiece;
    QLabel *label_17;
    QComboBox *Lens;
    QLabel *label_18;
    QComboBox *Filter;
    QLabel *label_14;
    QHBoxLayout *horizontalLayout_11;
    QDoubleSpinBox *Seeing;
    QLabel *label_8;
    QLabel *label_15;
    QHBoxLayout *horizontalLayout_7;
    QDoubleSpinBox *FaintestStar;
    QLabel *label;
    QLabel *label_16;
    QTimeEdit *Time;
    QLabel *label_13;
    QTextEdit *Description;
    QLabel *hintLabel;
    QHBoxLayout *horizontalLayout;
    QSpacerItem *horizontalSpacer;
    QPushButton *NextButton;
    KUrlLabel *SessionURL;
    QVBoxLayout *verticalLayout_5;
    QListWidget *Target;
    KUrlLabel *AddObject;
    KUrlLabel *RemoveObject;
    QSpacerItem *verticalSpacer;
    KUrlLabel *ObservationsURL;

    void setupUi(QWidget *Execute)
    {
        if (Execute->objectName().isEmpty())
            Execute->setObjectName("Execute");
        Execute->resize(606, 436);
        gridLayout_2 = new QGridLayout(Execute);
        gridLayout_2->setObjectName("gridLayout_2");
        verticalLayout = new QVBoxLayout();
        verticalLayout->setObjectName("verticalLayout");
        stackedWidget = new QStackedWidget(Execute);
        stackedWidget->setObjectName("stackedWidget");
        Session = new QWidget();
        Session->setObjectName("Session");
        verticalLayout_2 = new QVBoxLayout(Session);
        verticalLayout_2->setObjectName("verticalLayout_2");
        ktitlewidget = new KTitleWidget(Session);
        ktitlewidget->setObjectName("ktitlewidget");

        verticalLayout_2->addWidget(ktitlewidget);

        formLayout = new QFormLayout();
        formLayout->setObjectName("formLayout");
        formLayout->setFieldGrowthPolicy(QFormLayout::ExpandingFieldsGrow);
        label_2 = new QLabel(Session);
        label_2->setObjectName("label_2");

        formLayout->setWidget(0, QFormLayout::ItemRole::LabelRole, label_2);

        Location = new QPushButton(Session);
        Location->setObjectName("Location");

        formLayout->setWidget(0, QFormLayout::ItemRole::FieldRole, Location);

        label_3 = new QLabel(Session);
        label_3->setObjectName("label_3");

        formLayout->setWidget(1, QFormLayout::ItemRole::LabelRole, label_3);

        Begin = new QDateTimeEdit(Session);
        Begin->setObjectName("Begin");

        formLayout->setWidget(1, QFormLayout::ItemRole::FieldRole, Begin);

        label_4 = new QLabel(Session);
        label_4->setObjectName("label_4");

        formLayout->setWidget(2, QFormLayout::ItemRole::LabelRole, label_4);

        Weather = new QTextEdit(Session);
        Weather->setObjectName("Weather");
        Weather->setTabChangesFocus(true);

        formLayout->setWidget(2, QFormLayout::ItemRole::FieldRole, Weather);

        label_5 = new QLabel(Session);
        label_5->setObjectName("label_5");

        formLayout->setWidget(3, QFormLayout::ItemRole::LabelRole, label_5);

        Equipment = new QTextEdit(Session);
        Equipment->setObjectName("Equipment");
        Equipment->setTabChangesFocus(true);

        formLayout->setWidget(3, QFormLayout::ItemRole::FieldRole, Equipment);

        label_6 = new QLabel(Session);
        label_6->setObjectName("label_6");

        formLayout->setWidget(4, QFormLayout::ItemRole::LabelRole, label_6);

        Comment = new QTextEdit(Session);
        Comment->setObjectName("Comment");
        Comment->setTabChangesFocus(true);

        formLayout->setWidget(4, QFormLayout::ItemRole::FieldRole, Comment);

        label_7 = new QLabel(Session);
        label_7->setObjectName("label_7");

        formLayout->setWidget(5, QFormLayout::ItemRole::LabelRole, label_7);

        Language = new QLineEdit(Session);
        Language->setObjectName("Language");

        formLayout->setWidget(5, QFormLayout::ItemRole::FieldRole, Language);


        verticalLayout_2->addLayout(formLayout);

        stackedWidget->addWidget(Session);
        TargetDetails = new QWidget();
        TargetDetails->setObjectName("TargetDetails");
        verticalLayout_4 = new QVBoxLayout(TargetDetails);
        verticalLayout_4->setObjectName("verticalLayout_4");
        ktitlewidget_2 = new KTitleWidget(TargetDetails);
        ktitlewidget_2->setObjectName("ktitlewidget_2");

        verticalLayout_4->addWidget(ktitlewidget_2);

        gridLayout = new QGridLayout();
        gridLayout->setObjectName("gridLayout");
        label_20 = new QLabel(TargetDetails);
        label_20->setObjectName("label_20");

        gridLayout->addWidget(label_20, 0, 0, 1, 1);

        Mag = new QLineEdit(TargetDetails);
        Mag->setObjectName("Mag");
        Mag->setReadOnly(true);

        gridLayout->addWidget(Mag, 0, 1, 1, 1);

        label_22 = new QLabel(TargetDetails);
        label_22->setObjectName("label_22");

        gridLayout->addWidget(label_22, 2, 0, 1, 1);

        Type = new QLineEdit(TargetDetails);
        Type->setObjectName("Type");
        Type->setReadOnly(true);

        gridLayout->addWidget(Type, 2, 1, 1, 2);

        label_24 = new QLabel(TargetDetails);
        label_24->setObjectName("label_24");

        gridLayout->addWidget(label_24, 1, 0, 1, 1);

        SchTime = new QLineEdit(TargetDetails);
        SchTime->setObjectName("SchTime");
        SchTime->setReadOnly(true);

        gridLayout->addWidget(SchTime, 1, 1, 1, 1);

        label_26 = new QLabel(TargetDetails);
        label_26->setObjectName("label_26");

        gridLayout->addWidget(label_26, 3, 0, 1, 1);

        RA = new QLineEdit(TargetDetails);
        RA->setObjectName("RA");
        RA->setReadOnly(true);

        gridLayout->addWidget(RA, 3, 1, 1, 1);

        label_27 = new QLabel(TargetDetails);
        label_27->setObjectName("label_27");

        gridLayout->addWidget(label_27, 3, 2, 1, 1);

        Dec = new QLineEdit(TargetDetails);
        Dec->setObjectName("Dec");
        Dec->setReadOnly(true);

        gridLayout->addWidget(Dec, 3, 3, 1, 1);

        label_21 = new QLabel(TargetDetails);
        label_21->setObjectName("label_21");

        gridLayout->addWidget(label_21, 4, 0, 1, 1);

        Alt = new QLineEdit(TargetDetails);
        Alt->setObjectName("Alt");
        Alt->setReadOnly(true);

        gridLayout->addWidget(Alt, 4, 1, 1, 1);

        label_23 = new QLabel(TargetDetails);
        label_23->setObjectName("label_23");

        gridLayout->addWidget(label_23, 4, 2, 1, 1);

        Az = new QLineEdit(TargetDetails);
        Az->setObjectName("Az");
        Az->setReadOnly(true);

        gridLayout->addWidget(Az, 4, 3, 1, 1);


        verticalLayout_4->addLayout(gridLayout);

        ktitlewidget_4 = new KTitleWidget(TargetDetails);
        ktitlewidget_4->setObjectName("ktitlewidget_4");

        verticalLayout_4->addWidget(ktitlewidget_4);

        horizontalLayout_2 = new QHBoxLayout();
        horizontalLayout_2->setObjectName("horizontalLayout_2");
        Notes = new QTextEdit(TargetDetails);
        Notes->setObjectName("Notes");
        Notes->setTabChangesFocus(true);

        horizontalLayout_2->addWidget(Notes);


        verticalLayout_4->addLayout(horizontalLayout_2);

        horizontalLayout_3 = new QHBoxLayout();
        horizontalLayout_3->setObjectName("horizontalLayout_3");
        horizontalSpacer_2 = new QSpacerItem(40, 20, QSizePolicy::Policy::Expanding, QSizePolicy::Policy::Minimum);

        horizontalLayout_3->addItem(horizontalSpacer_2);

        Slew = new QPushButton(TargetDetails);
        Slew->setObjectName("Slew");

        horizontalLayout_3->addWidget(Slew);


        verticalLayout_4->addLayout(horizontalLayout_3);

        stackedWidget->addWidget(TargetDetails);
        page_2 = new QWidget();
        page_2->setObjectName("page_2");
        verticalLayout_3 = new QVBoxLayout(page_2);
        verticalLayout_3->setObjectName("verticalLayout_3");
        ktitlewidget_3 = new KTitleWidget(page_2);
        ktitlewidget_3->setObjectName("ktitlewidget_3");

        verticalLayout_3->addWidget(ktitlewidget_3);

        formLayout_2 = new QFormLayout();
        formLayout_2->setObjectName("formLayout_2");
        formLayout_2->setFieldGrowthPolicy(QFormLayout::ExpandingFieldsGrow);
        label_19 = new QLabel(page_2);
        label_19->setObjectName("label_19");

        formLayout_2->setWidget(1, QFormLayout::ItemRole::LabelRole, label_19);

        Observer = new QComboBox(page_2);
        Observer->setObjectName("Observer");
        QSizePolicy sizePolicy(QSizePolicy::Policy::MinimumExpanding, QSizePolicy::Policy::Fixed);
        sizePolicy.setHorizontalStretch(0);
        sizePolicy.setVerticalStretch(0);
        sizePolicy.setHeightForWidth(Observer->sizePolicy().hasHeightForWidth());
        Observer->setSizePolicy(sizePolicy);

        formLayout_2->setWidget(1, QFormLayout::ItemRole::FieldRole, Observer);

        label_11 = new QLabel(page_2);
        label_11->setObjectName("label_11");

        formLayout_2->setWidget(2, QFormLayout::ItemRole::LabelRole, label_11);

        Scope = new QComboBox(page_2);
        Scope->setObjectName("Scope");
        sizePolicy.setHeightForWidth(Scope->sizePolicy().hasHeightForWidth());
        Scope->setSizePolicy(sizePolicy);

        formLayout_2->setWidget(2, QFormLayout::ItemRole::FieldRole, Scope);

        label_12 = new QLabel(page_2);
        label_12->setObjectName("label_12");

        formLayout_2->setWidget(3, QFormLayout::ItemRole::LabelRole, label_12);

        Eyepiece = new QComboBox(page_2);
        Eyepiece->setObjectName("Eyepiece");
        sizePolicy.setHeightForWidth(Eyepiece->sizePolicy().hasHeightForWidth());
        Eyepiece->setSizePolicy(sizePolicy);

        formLayout_2->setWidget(3, QFormLayout::ItemRole::FieldRole, Eyepiece);

        label_17 = new QLabel(page_2);
        label_17->setObjectName("label_17");

        formLayout_2->setWidget(4, QFormLayout::ItemRole::LabelRole, label_17);

        Lens = new QComboBox(page_2);
        Lens->setObjectName("Lens");
        sizePolicy.setHeightForWidth(Lens->sizePolicy().hasHeightForWidth());
        Lens->setSizePolicy(sizePolicy);

        formLayout_2->setWidget(4, QFormLayout::ItemRole::FieldRole, Lens);

        label_18 = new QLabel(page_2);
        label_18->setObjectName("label_18");

        formLayout_2->setWidget(5, QFormLayout::ItemRole::LabelRole, label_18);

        Filter = new QComboBox(page_2);
        Filter->setObjectName("Filter");
        sizePolicy.setHeightForWidth(Filter->sizePolicy().hasHeightForWidth());
        Filter->setSizePolicy(sizePolicy);

        formLayout_2->setWidget(5, QFormLayout::ItemRole::FieldRole, Filter);

        label_14 = new QLabel(page_2);
        label_14->setObjectName("label_14");

        formLayout_2->setWidget(6, QFormLayout::ItemRole::LabelRole, label_14);

        horizontalLayout_11 = new QHBoxLayout();
        horizontalLayout_11->setObjectName("horizontalLayout_11");
        Seeing = new QDoubleSpinBox(page_2);
        Seeing->setObjectName("Seeing");

        horizontalLayout_11->addWidget(Seeing);

        label_8 = new QLabel(page_2);
        label_8->setObjectName("label_8");

        horizontalLayout_11->addWidget(label_8);


        formLayout_2->setLayout(6, QFormLayout::ItemRole::FieldRole, horizontalLayout_11);

        label_15 = new QLabel(page_2);
        label_15->setObjectName("label_15");

        formLayout_2->setWidget(7, QFormLayout::ItemRole::LabelRole, label_15);

        horizontalLayout_7 = new QHBoxLayout();
        horizontalLayout_7->setObjectName("horizontalLayout_7");
        FaintestStar = new QDoubleSpinBox(page_2);
        FaintestStar->setObjectName("FaintestStar");

        horizontalLayout_7->addWidget(FaintestStar);

        label = new QLabel(page_2);
        label->setObjectName("label");

        horizontalLayout_7->addWidget(label);


        formLayout_2->setLayout(7, QFormLayout::ItemRole::FieldRole, horizontalLayout_7);

        label_16 = new QLabel(page_2);
        label_16->setObjectName("label_16");

        formLayout_2->setWidget(8, QFormLayout::ItemRole::LabelRole, label_16);

        Time = new QTimeEdit(page_2);
        Time->setObjectName("Time");

        formLayout_2->setWidget(8, QFormLayout::ItemRole::FieldRole, Time);

        label_13 = new QLabel(page_2);
        label_13->setObjectName("label_13");

        formLayout_2->setWidget(9, QFormLayout::ItemRole::LabelRole, label_13);

        Description = new QTextEdit(page_2);
        Description->setObjectName("Description");

        formLayout_2->setWidget(9, QFormLayout::ItemRole::FieldRole, Description);

        hintLabel = new QLabel(page_2);
        hintLabel->setObjectName("hintLabel");
        QFont font;
        font.setBold(true);
        hintLabel->setFont(font);
        hintLabel->setWordWrap(true);

        formLayout_2->setWidget(0, QFormLayout::ItemRole::SpanningRole, hintLabel);


        verticalLayout_3->addLayout(formLayout_2);

        stackedWidget->addWidget(page_2);

        verticalLayout->addWidget(stackedWidget);

        horizontalLayout = new QHBoxLayout();
        horizontalLayout->setObjectName("horizontalLayout");
        horizontalSpacer = new QSpacerItem(40, 20, QSizePolicy::Policy::Expanding, QSizePolicy::Policy::Minimum);

        horizontalLayout->addItem(horizontalSpacer);

        NextButton = new QPushButton(Execute);
        NextButton->setObjectName("NextButton");

        horizontalLayout->addWidget(NextButton);


        verticalLayout->addLayout(horizontalLayout);


        gridLayout_2->addLayout(verticalLayout, 0, 1, 3, 1);

        SessionURL = new KUrlLabel(Execute);
        SessionURL->setObjectName("SessionURL");

        gridLayout_2->addWidget(SessionURL, 0, 0, 1, 1);

        verticalLayout_5 = new QVBoxLayout();
        verticalLayout_5->setObjectName("verticalLayout_5");
        Target = new QListWidget(Execute);
        Target->setObjectName("Target");

        verticalLayout_5->addWidget(Target);

        AddObject = new KUrlLabel(Execute);
        AddObject->setObjectName("AddObject");
        AddObject->setMaximumSize(QSize(158, 18));

        verticalLayout_5->addWidget(AddObject);

        RemoveObject = new KUrlLabel(Execute);
        RemoveObject->setObjectName("RemoveObject");
        RemoveObject->setMaximumSize(QSize(158, 18));

        verticalLayout_5->addWidget(RemoveObject);

        verticalSpacer = new QSpacerItem(20, 60, QSizePolicy::Policy::Minimum, QSizePolicy::Policy::Expanding);

        verticalLayout_5->addItem(verticalSpacer);


        gridLayout_2->addLayout(verticalLayout_5, 2, 0, 1, 1);

        ObservationsURL = new KUrlLabel(Execute);
        ObservationsURL->setObjectName("ObservationsURL");

        gridLayout_2->addWidget(ObservationsURL, 1, 0, 1, 1);


        retranslateUi(Execute);

        stackedWidget->setCurrentIndex(1);


        QMetaObject::connectSlotsByName(Execute);
    } // setupUi

    void retranslateUi(QWidget *Execute)
    {
        Execute->setWindowTitle(tr2i18n("Execute Session", nullptr));
        ktitlewidget->setProperty("text", QVariant(tr2i18n("Enter Session Details:", nullptr)));
        label_2->setText(tr2i18n("Location:", nullptr));
        Location->setText(tr2i18n("set location", nullptr));
        label_3->setText(tr2i18n("Begin:", nullptr));
        label_4->setText(tr2i18n("Weather:", nullptr));
        label_5->setText(tr2i18n("Equipment:", nullptr));
        label_6->setText(tr2i18n("Comments:", nullptr));
        label_7->setText(tr2i18n("Language:", nullptr));
        ktitlewidget_2->setProperty("text", QVariant(tr2i18n("View Object Details:", nullptr)));
        label_20->setText(tr2i18n("Magnitude:", nullptr));
        label_22->setText(tr2i18n("Type:", nullptr));
        label_24->setText(tr2i18n("Scheduled time:", nullptr));
        label_26->setText(tr2i18n("Right ascension:", nullptr));
        label_27->setText(tr2i18n("Declination:", nullptr));
        label_21->setText(tr2i18n("Altitude:", nullptr));
        label_23->setText(tr2i18n("Azimuth:", nullptr));
        ktitlewidget_4->setProperty("text", QVariant(tr2i18n("Set Observing Notes for the Object:", nullptr)));
        Slew->setText(tr2i18n("Slew Telescope", "Move the telescope to an object or location"));
        ktitlewidget_3->setProperty("text", QVariant(tr2i18n("Enter the Observation Details:", nullptr)));
        label_19->setText(tr2i18n("Observer", nullptr));
        label_11->setText(tr2i18n("Telescope:", nullptr));
        label_12->setText(tr2i18n("Eyepiece:", nullptr));
        label_17->setText(tr2i18n("Lens:", nullptr));
        label_18->setText(tr2i18n("Filter:", nullptr));
        label_14->setText(tr2i18n("Seeing:", nullptr));
        label_8->setText(tr2i18n("arc seconds", nullptr));
        label_15->setText(tr2i18n("Faintest Star:", nullptr));
        label->setText(tr2i18n("(magnitude)", nullptr));
        label_16->setText(tr2i18n("Time:", nullptr));
        label_13->setText(tr2i18n("Description:", nullptr));
        hintLabel->setText(tr2i18n("Looks like you have not listed out your observers / equipment. Please hit Ctrl + 0 and Ctrl + 1 to fix this situation and come back here.", nullptr));
        NextButton->setText(tr2i18n("Next >", nullptr));
        SessionURL->setText(tr2i18n("Step 1: Session Details", nullptr));
        AddObject->setText(tr2i18n("Add new object to list", nullptr));
        RemoveObject->setText(tr2i18n("Remove object from list", nullptr));
        ObservationsURL->setText(tr2i18n("Step 2: Observations", nullptr));
    } // retranslateUi

};

namespace Ui {
    class Execute: public Ui_Execute {};
} // namespace Ui

QT_END_NAMESPACE

#endif // EXECUTE_H

