/****************************************************************************
** Meta object code from reading C++ file 'guideinterface.h'
**
** Created by: The Qt Meta Object Compiler version 69 (Qt 6.11.1)
**
** WARNING! All changes made in this file will be lost!
*****************************************************************************/

#include "../../../../kstars-3.8.4.1/kstars/ekos/guide/guideinterface.h"
#include <QtCore/qmetatype.h>

#include <QtCore/qtmochelpers.h>

#include <memory>


#include <QtCore/qxptype_traits.h>
#if !defined(Q_MOC_OUTPUT_REVISION)
#error "The header file 'guideinterface.h' doesn't include <QObject>."
#elif Q_MOC_OUTPUT_REVISION != 69
#error "This file was generated using the moc from 6.11.1. It"
#error "cannot be used with the include files from this version of Qt."
#error "(The moc has changed too much.)"
#endif

#ifndef Q_CONSTINIT
#define Q_CONSTINIT
#endif

QT_WARNING_PUSH
QT_WARNING_DISABLE_DEPRECATED
QT_WARNING_DISABLE_GCC("-Wuseless-cast")
namespace {
struct qt_meta_tag_ZN4Ekos14GuideInterfaceE_t {};
} // unnamed namespace

template <> constexpr inline auto Ekos::GuideInterface::qt_create_metaobjectdata<qt_meta_tag_ZN4Ekos14GuideInterfaceE_t>()
{
    namespace QMC = QtMocConstants;
    QtMocHelpers::StringRefStorage qt_stringData {
        "Ekos::GuideInterface",
        "newLog",
        "",
        "newStatus",
        "Ekos::GuideState",
        "newAxisDelta",
        "delta_ra",
        "delta_dec",
        "newAxisSigma",
        "sigma_ra",
        "sigma_dec",
        "newAxisPulse",
        "pulse_ra",
        "pulse_dec",
        "newStarPosition",
        "QVector3D",
        "newCenter",
        "updateNow",
        "newStarPixmap",
        "QPixmap&",
        "newSNR",
        "snr",
        "calibrationUpdate",
        "CalibrationUpdateType",
        "type",
        "message",
        "x",
        "y",
        "frameCaptureRequested",
        "guideStats",
        "raError",
        "decError",
        "raPulse",
        "decPulse",
        "skyBg",
        "numStars",
        "guideEquipmentUpdated",
        "guideInfo",
        "abortExposure"
    };

    QtMocHelpers::UintData qt_methods {
        // Signal 'newLog'
        QtMocHelpers::SignalData<void(const QString &)>(1, 2, QMC::AccessPublic, QMetaType::Void, {{
            { QMetaType::QString, 2 },
        }}),
        // Signal 'newStatus'
        QtMocHelpers::SignalData<void(Ekos::GuideState)>(3, 2, QMC::AccessPublic, QMetaType::Void, {{
            { 0x80000000 | 4, 2 },
        }}),
        // Signal 'newAxisDelta'
        QtMocHelpers::SignalData<void(double, double)>(5, 2, QMC::AccessPublic, QMetaType::Void, {{
            { QMetaType::Double, 6 }, { QMetaType::Double, 7 },
        }}),
        // Signal 'newAxisSigma'
        QtMocHelpers::SignalData<void(double, double)>(8, 2, QMC::AccessPublic, QMetaType::Void, {{
            { QMetaType::Double, 9 }, { QMetaType::Double, 10 },
        }}),
        // Signal 'newAxisPulse'
        QtMocHelpers::SignalData<void(double, double)>(11, 2, QMC::AccessPublic, QMetaType::Void, {{
            { QMetaType::Double, 12 }, { QMetaType::Double, 13 },
        }}),
        // Signal 'newStarPosition'
        QtMocHelpers::SignalData<void(const QVector3D &, bool)>(14, 2, QMC::AccessPublic, QMetaType::Void, {{
            { 0x80000000 | 15, 16 }, { QMetaType::Bool, 17 },
        }}),
        // Signal 'newStarPixmap'
        QtMocHelpers::SignalData<void(QPixmap &)>(18, 2, QMC::AccessPublic, QMetaType::Void, {{
            { 0x80000000 | 19, 2 },
        }}),
        // Signal 'newSNR'
        QtMocHelpers::SignalData<void(double)>(20, 2, QMC::AccessPublic, QMetaType::Void, {{
            { QMetaType::Double, 21 },
        }}),
        // Signal 'calibrationUpdate'
        QtMocHelpers::SignalData<void(enum CalibrationUpdateType, const QString &, double, double)>(22, 2, QMC::AccessPublic, QMetaType::Void, {{
            { 0x80000000 | 23, 24 }, { QMetaType::QString, 25 }, { QMetaType::Double, 26 }, { QMetaType::Double, 27 },
        }}),
        // Signal 'calibrationUpdate'
        QtMocHelpers::SignalData<void(enum CalibrationUpdateType, const QString &, double)>(22, 2, QMC::AccessPublic | QMC::MethodCloned, QMetaType::Void, {{
            { 0x80000000 | 23, 24 }, { QMetaType::QString, 25 }, { QMetaType::Double, 26 },
        }}),
        // Signal 'calibrationUpdate'
        QtMocHelpers::SignalData<void(enum CalibrationUpdateType, const QString &)>(22, 2, QMC::AccessPublic | QMC::MethodCloned, QMetaType::Void, {{
            { 0x80000000 | 23, 24 }, { QMetaType::QString, 25 },
        }}),
        // Signal 'calibrationUpdate'
        QtMocHelpers::SignalData<void(enum CalibrationUpdateType)>(22, 2, QMC::AccessPublic | QMC::MethodCloned, QMetaType::Void, {{
            { 0x80000000 | 23, 24 },
        }}),
        // Signal 'frameCaptureRequested'
        QtMocHelpers::SignalData<void()>(28, 2, QMC::AccessPublic, QMetaType::Void),
        // Signal 'guideStats'
        QtMocHelpers::SignalData<void(double, double, int, int, double, double, int)>(29, 2, QMC::AccessPublic, QMetaType::Void, {{
            { QMetaType::Double, 30 }, { QMetaType::Double, 31 }, { QMetaType::Int, 32 }, { QMetaType::Int, 33 },
            { QMetaType::Double, 21 }, { QMetaType::Double, 34 }, { QMetaType::Int, 35 },
        }}),
        // Signal 'guideEquipmentUpdated'
        QtMocHelpers::SignalData<void()>(36, 2, QMC::AccessPublic, QMetaType::Void),
        // Signal 'guideInfo'
        QtMocHelpers::SignalData<void(const QString &)>(37, 2, QMC::AccessPublic, QMetaType::Void, {{
            { QMetaType::QString, 2 },
        }}),
        // Signal 'abortExposure'
        QtMocHelpers::SignalData<void()>(38, 2, QMC::AccessPublic, QMetaType::Void),
    };
    QtMocHelpers::UintData qt_properties {
    };
    QtMocHelpers::UintData qt_enums {
    };
    return QtMocHelpers::metaObjectData<GuideInterface, qt_meta_tag_ZN4Ekos14GuideInterfaceE_t>(QMC::MetaObjectFlag{}, qt_stringData,
            qt_methods, qt_properties, qt_enums);
}
Q_CONSTINIT const QMetaObject Ekos::GuideInterface::staticMetaObject = { {
    QMetaObject::SuperData::link<QObject::staticMetaObject>(),
    qt_staticMetaObjectStaticContent<qt_meta_tag_ZN4Ekos14GuideInterfaceE_t>.stringdata,
    qt_staticMetaObjectStaticContent<qt_meta_tag_ZN4Ekos14GuideInterfaceE_t>.data,
    qt_static_metacall,
    nullptr,
    qt_staticMetaObjectRelocatingContent<qt_meta_tag_ZN4Ekos14GuideInterfaceE_t>.metaTypes,
    nullptr
} };

void Ekos::GuideInterface::qt_static_metacall(QObject *_o, QMetaObject::Call _c, int _id, void **_a)
{
    auto *_t = static_cast<GuideInterface *>(_o);
    if (_c == QMetaObject::InvokeMetaMethod) {
        switch (_id) {
        case 0: _t->newLog((*reinterpret_cast<std::add_pointer_t<QString>>(_a[1]))); break;
        case 1: _t->newStatus((*reinterpret_cast<std::add_pointer_t<Ekos::GuideState>>(_a[1]))); break;
        case 2: _t->newAxisDelta((*reinterpret_cast<std::add_pointer_t<double>>(_a[1])),(*reinterpret_cast<std::add_pointer_t<double>>(_a[2]))); break;
        case 3: _t->newAxisSigma((*reinterpret_cast<std::add_pointer_t<double>>(_a[1])),(*reinterpret_cast<std::add_pointer_t<double>>(_a[2]))); break;
        case 4: _t->newAxisPulse((*reinterpret_cast<std::add_pointer_t<double>>(_a[1])),(*reinterpret_cast<std::add_pointer_t<double>>(_a[2]))); break;
        case 5: _t->newStarPosition((*reinterpret_cast<std::add_pointer_t<QVector3D>>(_a[1])),(*reinterpret_cast<std::add_pointer_t<bool>>(_a[2]))); break;
        case 6: _t->newStarPixmap((*reinterpret_cast<std::add_pointer_t<QPixmap&>>(_a[1]))); break;
        case 7: _t->newSNR((*reinterpret_cast<std::add_pointer_t<double>>(_a[1]))); break;
        case 8: _t->calibrationUpdate((*reinterpret_cast<std::add_pointer_t<enum CalibrationUpdateType>>(_a[1])),(*reinterpret_cast<std::add_pointer_t<QString>>(_a[2])),(*reinterpret_cast<std::add_pointer_t<double>>(_a[3])),(*reinterpret_cast<std::add_pointer_t<double>>(_a[4]))); break;
        case 9: _t->calibrationUpdate((*reinterpret_cast<std::add_pointer_t<enum CalibrationUpdateType>>(_a[1])),(*reinterpret_cast<std::add_pointer_t<QString>>(_a[2])),(*reinterpret_cast<std::add_pointer_t<double>>(_a[3]))); break;
        case 10: _t->calibrationUpdate((*reinterpret_cast<std::add_pointer_t<enum CalibrationUpdateType>>(_a[1])),(*reinterpret_cast<std::add_pointer_t<QString>>(_a[2]))); break;
        case 11: _t->calibrationUpdate((*reinterpret_cast<std::add_pointer_t<enum CalibrationUpdateType>>(_a[1]))); break;
        case 12: _t->frameCaptureRequested(); break;
        case 13: _t->guideStats((*reinterpret_cast<std::add_pointer_t<double>>(_a[1])),(*reinterpret_cast<std::add_pointer_t<double>>(_a[2])),(*reinterpret_cast<std::add_pointer_t<int>>(_a[3])),(*reinterpret_cast<std::add_pointer_t<int>>(_a[4])),(*reinterpret_cast<std::add_pointer_t<double>>(_a[5])),(*reinterpret_cast<std::add_pointer_t<double>>(_a[6])),(*reinterpret_cast<std::add_pointer_t<int>>(_a[7]))); break;
        case 14: _t->guideEquipmentUpdated(); break;
        case 15: _t->guideInfo((*reinterpret_cast<std::add_pointer_t<QString>>(_a[1]))); break;
        case 16: _t->abortExposure(); break;
        default: ;
        }
    }
    if (_c == QMetaObject::RegisterMethodArgumentMetaType) {
        switch (_id) {
        default: *reinterpret_cast<QMetaType *>(_a[0]) = QMetaType(); break;
        case 1:
            switch (*reinterpret_cast<int*>(_a[1])) {
            default: *reinterpret_cast<QMetaType *>(_a[0]) = QMetaType(); break;
            case 0:
                *reinterpret_cast<QMetaType *>(_a[0]) = QMetaType::fromType< Ekos::GuideState >(); break;
            }
            break;
        }
    }
    if (_c == QMetaObject::IndexOfMethod) {
        if (QtMocHelpers::indexOfMethod<void (GuideInterface::*)(const QString & )>(_a, &GuideInterface::newLog, 0))
            return;
        if (QtMocHelpers::indexOfMethod<void (GuideInterface::*)(Ekos::GuideState )>(_a, &GuideInterface::newStatus, 1))
            return;
        if (QtMocHelpers::indexOfMethod<void (GuideInterface::*)(double , double )>(_a, &GuideInterface::newAxisDelta, 2))
            return;
        if (QtMocHelpers::indexOfMethod<void (GuideInterface::*)(double , double )>(_a, &GuideInterface::newAxisSigma, 3))
            return;
        if (QtMocHelpers::indexOfMethod<void (GuideInterface::*)(double , double )>(_a, &GuideInterface::newAxisPulse, 4))
            return;
        if (QtMocHelpers::indexOfMethod<void (GuideInterface::*)(const QVector3D & , bool )>(_a, &GuideInterface::newStarPosition, 5))
            return;
        if (QtMocHelpers::indexOfMethod<void (GuideInterface::*)(QPixmap & )>(_a, &GuideInterface::newStarPixmap, 6))
            return;
        if (QtMocHelpers::indexOfMethod<void (GuideInterface::*)(double )>(_a, &GuideInterface::newSNR, 7))
            return;
        if (QtMocHelpers::indexOfMethod<void (GuideInterface::*)(CalibrationUpdateType , const QString & , double , double )>(_a, &GuideInterface::calibrationUpdate, 8))
            return;
        if (QtMocHelpers::indexOfMethod<void (GuideInterface::*)()>(_a, &GuideInterface::frameCaptureRequested, 12))
            return;
        if (QtMocHelpers::indexOfMethod<void (GuideInterface::*)(double , double , int , int , double , double , int )>(_a, &GuideInterface::guideStats, 13))
            return;
        if (QtMocHelpers::indexOfMethod<void (GuideInterface::*)()>(_a, &GuideInterface::guideEquipmentUpdated, 14))
            return;
        if (QtMocHelpers::indexOfMethod<void (GuideInterface::*)(const QString & )>(_a, &GuideInterface::guideInfo, 15))
            return;
        if (QtMocHelpers::indexOfMethod<void (GuideInterface::*)()>(_a, &GuideInterface::abortExposure, 16))
            return;
    }
}

const QMetaObject *Ekos::GuideInterface::metaObject() const
{
    return QObject::d_ptr->metaObject ? QObject::d_ptr->dynamicMetaObject() : &staticMetaObject;
}

void *Ekos::GuideInterface::qt_metacast(const char *_clname)
{
    if (!_clname) return nullptr;
    if (!strcmp(_clname, qt_staticMetaObjectStaticContent<qt_meta_tag_ZN4Ekos14GuideInterfaceE_t>.strings))
        return static_cast<void*>(this);
    return QObject::qt_metacast(_clname);
}

int Ekos::GuideInterface::qt_metacall(QMetaObject::Call _c, int _id, void **_a)
{
    _id = QObject::qt_metacall(_c, _id, _a);
    if (_id < 0)
        return _id;
    if (_c == QMetaObject::InvokeMetaMethod) {
        if (_id < 17)
            qt_static_metacall(this, _c, _id, _a);
        _id -= 17;
    }
    if (_c == QMetaObject::RegisterMethodArgumentMetaType) {
        if (_id < 17)
            qt_static_metacall(this, _c, _id, _a);
        _id -= 17;
    }
    return _id;
}

// SIGNAL 0
void Ekos::GuideInterface::newLog(const QString & _t1)
{
    QMetaObject::activate<void>(this, &staticMetaObject, 0, nullptr, _t1);
}

// SIGNAL 1
void Ekos::GuideInterface::newStatus(Ekos::GuideState _t1)
{
    QMetaObject::activate<void>(this, &staticMetaObject, 1, nullptr, _t1);
}

// SIGNAL 2
void Ekos::GuideInterface::newAxisDelta(double _t1, double _t2)
{
    QMetaObject::activate<void>(this, &staticMetaObject, 2, nullptr, _t1, _t2);
}

// SIGNAL 3
void Ekos::GuideInterface::newAxisSigma(double _t1, double _t2)
{
    QMetaObject::activate<void>(this, &staticMetaObject, 3, nullptr, _t1, _t2);
}

// SIGNAL 4
void Ekos::GuideInterface::newAxisPulse(double _t1, double _t2)
{
    QMetaObject::activate<void>(this, &staticMetaObject, 4, nullptr, _t1, _t2);
}

// SIGNAL 5
void Ekos::GuideInterface::newStarPosition(const QVector3D & _t1, bool _t2)
{
    QMetaObject::activate<void>(this, &staticMetaObject, 5, nullptr, _t1, _t2);
}

// SIGNAL 6
void Ekos::GuideInterface::newStarPixmap(QPixmap & _t1)
{
    QMetaObject::activate<void>(this, &staticMetaObject, 6, nullptr, _t1);
}

// SIGNAL 7
void Ekos::GuideInterface::newSNR(double _t1)
{
    QMetaObject::activate<void>(this, &staticMetaObject, 7, nullptr, _t1);
}

// SIGNAL 8
void Ekos::GuideInterface::calibrationUpdate(CalibrationUpdateType _t1, const QString & _t2, double _t3, double _t4)
{
    QMetaObject::activate<void>(this, &staticMetaObject, 8, nullptr, _t1, _t2, _t3, _t4);
}

// SIGNAL 12
void Ekos::GuideInterface::frameCaptureRequested()
{
    QMetaObject::activate(this, &staticMetaObject, 12, nullptr);
}

// SIGNAL 13
void Ekos::GuideInterface::guideStats(double _t1, double _t2, int _t3, int _t4, double _t5, double _t6, int _t7)
{
    QMetaObject::activate<void>(this, &staticMetaObject, 13, nullptr, _t1, _t2, _t3, _t4, _t5, _t6, _t7);
}

// SIGNAL 14
void Ekos::GuideInterface::guideEquipmentUpdated()
{
    QMetaObject::activate(this, &staticMetaObject, 14, nullptr);
}

// SIGNAL 15
void Ekos::GuideInterface::guideInfo(const QString & _t1)
{
    QMetaObject::activate<void>(this, &staticMetaObject, 15, nullptr, _t1);
}

// SIGNAL 16
void Ekos::GuideInterface::abortExposure()
{
    QMetaObject::activate(this, &staticMetaObject, 16, nullptr);
}
QT_WARNING_POP
