/*
 * This file was generated by qdbusxml2cpp version 0.8
 * Source file was org.kde.kstars.Ekos.xml
 *
 * qdbusxml2cpp is Copyright (C) The Qt Company Ltd. and other contributors.
 *
 * This is an auto-generated file.
 * Do not edit! All changes made to it will be lost.
 */

#include "ekosadaptor.h"
#include <QtCore/QMetaObject>
#include <QtCore/QByteArray>
#include <QtCore/QList>
#include <QtCore/QMap>
#include <QtCore/QString>
#include <QtCore/QStringList>
#include <QtCore/QVariant>

/*
 * Implementation of adaptor class EkosAdaptor
 */

EkosAdaptor::EkosAdaptor(Ekos::Manager *parent)
    : QDBusAbstractAdaptor(parent)
{
    // constructor
    setAutoRelaySignals(true);
}

EkosAdaptor::~EkosAdaptor()
{
    // destructor
}

bool EkosAdaptor::ekosLiveStatus() const
{
    // get the value of property ekosLiveStatus
    return qvariant_cast< bool >(parent()->property("ekosLiveStatus"));
}

int EkosAdaptor::ekosStatus() const
{
    // get the value of property ekosStatus
    return qvariant_cast< int >(parent()->property("ekosStatus"));
}

int EkosAdaptor::extensionStatus() const
{
    // get the value of property extensionStatus
    return qvariant_cast< int >(parent()->property("extensionStatus"));
}

int EkosAdaptor::indiStatus() const
{
    // get the value of property indiStatus
    return qvariant_cast< int >(parent()->property("indiStatus"));
}

QStringList EkosAdaptor::logText() const
{
    // get the value of property logText
    return qvariant_cast< QStringList >(parent()->property("logText"));
}

uint EkosAdaptor::settleStatus() const
{
    // get the value of property settleStatus
    return qvariant_cast< uint >(parent()->property("settleStatus"));
}

void EkosAdaptor::addProfile(const QString &profileJSON)
{
    // handle method call org.kde.kstars.Ekos.addProfile
    parent()->addProfile(profileJSON);
}

void EkosAdaptor::connectDevices()
{
    // handle method call org.kde.kstars.Ekos.connectDevices
    parent()->connectDevices();
}

void EkosAdaptor::deleteProfile(const QString &name)
{
    // handle method call org.kde.kstars.Ekos.deleteProfile
    parent()->deleteProfile(name);
}

void EkosAdaptor::disconnectDevices()
{
    // handle method call org.kde.kstars.Ekos.disconnectDevices
    parent()->disconnectDevices();
}

void EkosAdaptor::editProfile(const QString &profileJSON)
{
    // handle method call org.kde.kstars.Ekos.editProfile
    parent()->editProfile(profileJSON);
}

QString EkosAdaptor::getProfile(const QString &name)
{
    // handle method call org.kde.kstars.Ekos.getProfile
    return parent()->getProfile(name);
}

QStringList EkosAdaptor::getProfiles()
{
    // handle method call org.kde.kstars.Ekos.getProfiles
    return parent()->getProfiles();
}

void EkosAdaptor::previewFile(const QString &filePath)
{
    // handle method call org.kde.kstars.Ekos.previewFile
    parent()->previewFile(filePath);
}

void EkosAdaptor::setEkosLiveConfig(bool rememberCredentials, bool autoConnect)
{
    // handle method call org.kde.kstars.Ekos.setEkosLiveConfig
    parent()->setEkosLiveConfig(rememberCredentials, autoConnect);
}

void EkosAdaptor::setEkosLiveConnected(bool enabled)
{
    // handle method call org.kde.kstars.Ekos.setEkosLiveConnected
    parent()->setEkosLiveConnected(enabled);
}

void EkosAdaptor::setEkosLiveUser(const QString &username, const QString &password)
{
    // handle method call org.kde.kstars.Ekos.setEkosLiveUser
    parent()->setEkosLiveUser(username, password);
}

void EkosAdaptor::setEkosLoggingEnabled(const QString &name, bool enabled)
{
    // handle method call org.kde.kstars.Ekos.setEkosLoggingEnabled
    parent()->setEkosLoggingEnabled(name, enabled);
}

void EkosAdaptor::setFITSfromFile(bool previewFromFile)
{
    // handle method call org.kde.kstars.Ekos.setFITSfromFile
    parent()->setFITSfromFile(previewFromFile);
}

bool EkosAdaptor::setProfile(const QString &profileName)
{
    // handle method call org.kde.kstars.Ekos.setProfile
    return parent()->setProfile(profileName);
}

void EkosAdaptor::start()
{
    // handle method call org.kde.kstars.Ekos.start
    parent()->start();
}

void EkosAdaptor::stop()
{
    // handle method call org.kde.kstars.Ekos.stop
    parent()->stop();
}


#include "moc_ekosadaptor.cpp"
