/****************************************************************************
** Meta object code from reading C++ file 'opticaltrainadaptor.h'
**
** Created by: The Qt Meta Object Compiler version 69 (Qt 6.11.1)
**
** WARNING! All changes made in this file will be lost!
*****************************************************************************/

#include "opticaltrainadaptor.h"
#include <QtCore/qmetatype.h>

#include <QtCore/qtmochelpers.h>

#include <memory>


#include <QtCore/qxptype_traits.h>
#if !defined(Q_MOC_OUTPUT_REVISION)
#error "The header file 'opticaltrainadaptor.h' doesn't include <QObject>."
#elif Q_MOC_OUTPUT_REVISION != 69
#error "This file was generated using the moc from 6.11.1. It"
#error "cannot be used with the include files from this version of Qt."
#error "(The moc has changed too much.)"
#endif

#ifndef Q_CONSTINIT
#define Q_CONSTINIT
#endif

QT_WARNING_PUSH
QT_WARNING_DISABLE_DEPRECATED
QT_WARNING_DISABLE_GCC("-Wuseless-cast")
namespace {
struct qt_meta_tag_ZN19OpticalTrainAdaptorE_t {};
} // unnamed namespace

template <> constexpr inline auto OpticalTrainAdaptor::qt_create_metaobjectdata<qt_meta_tag_ZN19OpticalTrainAdaptorE_t>()
{
    namespace QMC = QtMocConstants;
    QtMocHelpers::StringRefStorage qt_stringData {
        "OpticalTrainAdaptor",
        "D-Bus Interface",
        "org.kde.kstars.Ekos.OpticalTrain",
        "D-Bus Introspection",
        "  <interface name=\"org.kde.kstars.Ekos.OpticalTrain\">\n    <prop"
        "erty access=\"read\" type=\"s\" name=\"name\"/>\n    <property acc"
        "ess=\"read\" type=\"i\" name=\"id\"/>\n    <property access=\"read"
        "\" type=\"s\" name=\"mount\"/>\n    <property access=\"read\" type"
        "=\"s\" name=\"camera\"/>\n    <property access=\"read\" type=\"s\""
        " name=\"focuser\"/>\n    <property access=\"read\" type=\"s\" name"
        "=\"filterWheel\"/>\n    <property access=\"read\" type=\"s\" name="
        "\"rotator\"/>\n    <property access=\"read\" type=\"s\" name=\"dus"
        "tCap\"/>\n    <property access=\"read\" type=\"s\" name=\"lightBox"
        "\"/>\n    <property access=\"read\" type=\"s\" name=\"scope\"/>\n "
        "   <property access=\"read\" type=\"d\" name=\"reducer\"/>\n    <p"
        "roperty access=\"read\" type=\"s\" name=\"guider\"/>\n    <method "
        "name=\"setMount\">\n      <arg direction=\"in\" type=\"s\" name=\""
        "name\"/>\n      <arg direction=\"out\" type=\"b\"/>\n    </method>"
        "\n    <method name=\"setCamera\">\n      <arg direction=\"in\" typ"
        "e=\"s\" name=\"name\"/>\n      <arg direction=\"out\" type=\"b\"/>"
        "\n    </method>\n    <method name=\"setFocuser\">\n      <arg dire"
        "ction=\"in\" type=\"s\" name=\"name\"/>\n      <arg direction=\"ou"
        "t\" type=\"b\"/>\n    </method>\n    <method name=\"setFilterWheel"
        "\">\n      <arg direction=\"in\" type=\"s\" name=\"name\"/>\n     "
        " <arg direction=\"out\" type=\"b\"/>\n    </method>\n    <method n"
        "ame=\"setRotator\">\n      <arg direction=\"in\" type=\"s\" name=\""
        "name\"/>\n      <arg direction=\"out\" type=\"b\"/>\n    </method>"
        "\n    <method name=\"setDustCap\">\n      <arg direction=\"in\" ty"
        "pe=\"s\" name=\"name\"/>\n      <arg direction=\"out\" type=\"b\"/"
        ">\n    </method>\n    <method name=\"setLightBox\">\n      <arg di"
        "rection=\"in\" type=\"s\" name=\"name\"/>\n      <arg direction=\""
        "out\" type=\"b\"/>\n    </method>\n    <method name=\"setScope\">\n"
        "      <arg direction=\"in\" type=\"s\" name=\"name\"/>\n      <arg"
        " direction=\"out\" type=\"b\"/>\n    </method>\n    <method name=\""
        "setReducer\">\n      <arg direction=\"in\" type=\"d\" name=\"value"
        "\"/>\n      <arg direction=\"out\" type=\"b\"/>\n    </method>\n  "
        "  <method name=\"setGuider\">\n      <arg direction=\"in\" type=\""
        "s\" name=\"name\"/>\n      <arg direction=\"out\" type=\"b\"/>\n  "
        "  </method>\n    <method name=\"remove\">\n      <arg direction=\""
        "out\" type=\"b\"/>\n    </method>\n    <method name=\"reset\">\n  "
        "    <annotation value=\"true\" name=\"org.freedesktop.DBus.Method."
        "NoReply\"/>\n    </method>\n    <signal name=\"updated\"/>\n    <s"
        "ignal name=\"removed\"/>\n  </interface>\n",
        "removed",
        "",
        "updated",
        "remove",
        "reset",
        "Q_NOREPLY",
        "setCamera",
        "name",
        "setDustCap",
        "setFilterWheel",
        "setFocuser",
        "setGuider",
        "setLightBox",
        "setMount",
        "setReducer",
        "value",
        "setRotator",
        "setScope",
        "camera",
        "dustCap",
        "filterWheel",
        "focuser",
        "guider",
        "id",
        "lightBox",
        "mount",
        "reducer",
        "rotator",
        "scope"
    };

    QtMocHelpers::UintData qt_methods {
        // Signal 'removed'
        QtMocHelpers::SignalData<void()>(5, 6, QMC::AccessPublic, QMetaType::Void),
        // Signal 'updated'
        QtMocHelpers::SignalData<void()>(7, 6, QMC::AccessPublic, QMetaType::Void),
        // Slot 'remove'
        QtMocHelpers::SlotData<bool()>(8, 6, QMC::AccessPublic, QMetaType::Bool),
        // Slot 'reset'
        QtMocHelpers::SlotData<void()>(9, 10, QMC::AccessPublic, QMetaType::Void),
        // Slot 'setCamera'
        QtMocHelpers::SlotData<bool(const QString &)>(11, 6, QMC::AccessPublic, QMetaType::Bool, {{
            { QMetaType::QString, 12 },
        }}),
        // Slot 'setDustCap'
        QtMocHelpers::SlotData<bool(const QString &)>(13, 6, QMC::AccessPublic, QMetaType::Bool, {{
            { QMetaType::QString, 12 },
        }}),
        // Slot 'setFilterWheel'
        QtMocHelpers::SlotData<bool(const QString &)>(14, 6, QMC::AccessPublic, QMetaType::Bool, {{
            { QMetaType::QString, 12 },
        }}),
        // Slot 'setFocuser'
        QtMocHelpers::SlotData<bool(const QString &)>(15, 6, QMC::AccessPublic, QMetaType::Bool, {{
            { QMetaType::QString, 12 },
        }}),
        // Slot 'setGuider'
        QtMocHelpers::SlotData<bool(const QString &)>(16, 6, QMC::AccessPublic, QMetaType::Bool, {{
            { QMetaType::QString, 12 },
        }}),
        // Slot 'setLightBox'
        QtMocHelpers::SlotData<bool(const QString &)>(17, 6, QMC::AccessPublic, QMetaType::Bool, {{
            { QMetaType::QString, 12 },
        }}),
        // Slot 'setMount'
        QtMocHelpers::SlotData<bool(const QString &)>(18, 6, QMC::AccessPublic, QMetaType::Bool, {{
            { QMetaType::QString, 12 },
        }}),
        // Slot 'setReducer'
        QtMocHelpers::SlotData<bool(double)>(19, 6, QMC::AccessPublic, QMetaType::Bool, {{
            { QMetaType::Double, 20 },
        }}),
        // Slot 'setRotator'
        QtMocHelpers::SlotData<bool(const QString &)>(21, 6, QMC::AccessPublic, QMetaType::Bool, {{
            { QMetaType::QString, 12 },
        }}),
        // Slot 'setScope'
        QtMocHelpers::SlotData<bool(const QString &)>(22, 6, QMC::AccessPublic, QMetaType::Bool, {{
            { QMetaType::QString, 12 },
        }}),
    };
    QtMocHelpers::UintData qt_properties {
        // property 'camera'
        QtMocHelpers::PropertyData<QString>(23, QMetaType::QString, QMC::DefaultPropertyFlags),
        // property 'dustCap'
        QtMocHelpers::PropertyData<QString>(24, QMetaType::QString, QMC::DefaultPropertyFlags),
        // property 'filterWheel'
        QtMocHelpers::PropertyData<QString>(25, QMetaType::QString, QMC::DefaultPropertyFlags),
        // property 'focuser'
        QtMocHelpers::PropertyData<QString>(26, QMetaType::QString, QMC::DefaultPropertyFlags),
        // property 'guider'
        QtMocHelpers::PropertyData<QString>(27, QMetaType::QString, QMC::DefaultPropertyFlags),
        // property 'id'
        QtMocHelpers::PropertyData<int>(28, QMetaType::Int, QMC::DefaultPropertyFlags),
        // property 'lightBox'
        QtMocHelpers::PropertyData<QString>(29, QMetaType::QString, QMC::DefaultPropertyFlags),
        // property 'mount'
        QtMocHelpers::PropertyData<QString>(30, QMetaType::QString, QMC::DefaultPropertyFlags),
        // property 'name'
        QtMocHelpers::PropertyData<QString>(12, QMetaType::QString, QMC::DefaultPropertyFlags),
        // property 'reducer'
        QtMocHelpers::PropertyData<double>(31, QMetaType::Double, QMC::DefaultPropertyFlags),
        // property 'rotator'
        QtMocHelpers::PropertyData<QString>(32, QMetaType::QString, QMC::DefaultPropertyFlags),
        // property 'scope'
        QtMocHelpers::PropertyData<QString>(33, QMetaType::QString, QMC::DefaultPropertyFlags),
    };
    QtMocHelpers::UintData qt_enums {
    };
    QtMocHelpers::UintData qt_constructors {};
    QtMocHelpers::ClassInfos qt_classinfo({
            {    1,    2 },
            {    3,    4 },
    });
    return QtMocHelpers::metaObjectData<OpticalTrainAdaptor, qt_meta_tag_ZN19OpticalTrainAdaptorE_t>(QMC::MetaObjectFlag{}, qt_stringData,
            qt_methods, qt_properties, qt_enums, qt_constructors, qt_classinfo);
}
Q_CONSTINIT const QMetaObject OpticalTrainAdaptor::staticMetaObject = { {
    QMetaObject::SuperData::link<QDBusAbstractAdaptor::staticMetaObject>(),
    qt_staticMetaObjectStaticContent<qt_meta_tag_ZN19OpticalTrainAdaptorE_t>.stringdata,
    qt_staticMetaObjectStaticContent<qt_meta_tag_ZN19OpticalTrainAdaptorE_t>.data,
    qt_static_metacall,
    nullptr,
    qt_staticMetaObjectRelocatingContent<qt_meta_tag_ZN19OpticalTrainAdaptorE_t>.metaTypes,
    nullptr
} };

void OpticalTrainAdaptor::qt_static_metacall(QObject *_o, QMetaObject::Call _c, int _id, void **_a)
{
    auto *_t = static_cast<OpticalTrainAdaptor *>(_o);
    if (_c == QMetaObject::InvokeMetaMethod) {
        switch (_id) {
        case 0: _t->removed(); break;
        case 1: _t->updated(); break;
        case 2: { bool _r = _t->remove();
            if (_a[0]) *reinterpret_cast<bool*>(_a[0]) = std::move(_r); }  break;
        case 3: _t->reset(); break;
        case 4: { bool _r = _t->setCamera((*reinterpret_cast<std::add_pointer_t<QString>>(_a[1])));
            if (_a[0]) *reinterpret_cast<bool*>(_a[0]) = std::move(_r); }  break;
        case 5: { bool _r = _t->setDustCap((*reinterpret_cast<std::add_pointer_t<QString>>(_a[1])));
            if (_a[0]) *reinterpret_cast<bool*>(_a[0]) = std::move(_r); }  break;
        case 6: { bool _r = _t->setFilterWheel((*reinterpret_cast<std::add_pointer_t<QString>>(_a[1])));
            if (_a[0]) *reinterpret_cast<bool*>(_a[0]) = std::move(_r); }  break;
        case 7: { bool _r = _t->setFocuser((*reinterpret_cast<std::add_pointer_t<QString>>(_a[1])));
            if (_a[0]) *reinterpret_cast<bool*>(_a[0]) = std::move(_r); }  break;
        case 8: { bool _r = _t->setGuider((*reinterpret_cast<std::add_pointer_t<QString>>(_a[1])));
            if (_a[0]) *reinterpret_cast<bool*>(_a[0]) = std::move(_r); }  break;
        case 9: { bool _r = _t->setLightBox((*reinterpret_cast<std::add_pointer_t<QString>>(_a[1])));
            if (_a[0]) *reinterpret_cast<bool*>(_a[0]) = std::move(_r); }  break;
        case 10: { bool _r = _t->setMount((*reinterpret_cast<std::add_pointer_t<QString>>(_a[1])));
            if (_a[0]) *reinterpret_cast<bool*>(_a[0]) = std::move(_r); }  break;
        case 11: { bool _r = _t->setReducer((*reinterpret_cast<std::add_pointer_t<double>>(_a[1])));
            if (_a[0]) *reinterpret_cast<bool*>(_a[0]) = std::move(_r); }  break;
        case 12: { bool _r = _t->setRotator((*reinterpret_cast<std::add_pointer_t<QString>>(_a[1])));
            if (_a[0]) *reinterpret_cast<bool*>(_a[0]) = std::move(_r); }  break;
        case 13: { bool _r = _t->setScope((*reinterpret_cast<std::add_pointer_t<QString>>(_a[1])));
            if (_a[0]) *reinterpret_cast<bool*>(_a[0]) = std::move(_r); }  break;
        default: ;
        }
    }
    if (_c == QMetaObject::IndexOfMethod) {
        if (QtMocHelpers::indexOfMethod<void (OpticalTrainAdaptor::*)()>(_a, &OpticalTrainAdaptor::removed, 0))
            return;
        if (QtMocHelpers::indexOfMethod<void (OpticalTrainAdaptor::*)()>(_a, &OpticalTrainAdaptor::updated, 1))
            return;
    }
    if (_c == QMetaObject::ReadProperty) {
        void *_v = _a[0];
        switch (_id) {
        case 0: *reinterpret_cast<QString*>(_v) = _t->camera(); break;
        case 1: *reinterpret_cast<QString*>(_v) = _t->dustCap(); break;
        case 2: *reinterpret_cast<QString*>(_v) = _t->filterWheel(); break;
        case 3: *reinterpret_cast<QString*>(_v) = _t->focuser(); break;
        case 4: *reinterpret_cast<QString*>(_v) = _t->guider(); break;
        case 5: *reinterpret_cast<int*>(_v) = _t->id(); break;
        case 6: *reinterpret_cast<QString*>(_v) = _t->lightBox(); break;
        case 7: *reinterpret_cast<QString*>(_v) = _t->mount(); break;
        case 8: *reinterpret_cast<QString*>(_v) = _t->name(); break;
        case 9: *reinterpret_cast<double*>(_v) = _t->reducer(); break;
        case 10: *reinterpret_cast<QString*>(_v) = _t->rotator(); break;
        case 11: *reinterpret_cast<QString*>(_v) = _t->scope(); break;
        default: break;
        }
    }
}

const QMetaObject *OpticalTrainAdaptor::metaObject() const
{
    return QObject::d_ptr->metaObject ? QObject::d_ptr->dynamicMetaObject() : &staticMetaObject;
}

void *OpticalTrainAdaptor::qt_metacast(const char *_clname)
{
    if (!_clname) return nullptr;
    if (!strcmp(_clname, qt_staticMetaObjectStaticContent<qt_meta_tag_ZN19OpticalTrainAdaptorE_t>.strings))
        return static_cast<void*>(this);
    return QDBusAbstractAdaptor::qt_metacast(_clname);
}

int OpticalTrainAdaptor::qt_metacall(QMetaObject::Call _c, int _id, void **_a)
{
    _id = QDBusAbstractAdaptor::qt_metacall(_c, _id, _a);
    if (_id < 0)
        return _id;
    if (_c == QMetaObject::InvokeMetaMethod) {
        if (_id < 14)
            qt_static_metacall(this, _c, _id, _a);
        _id -= 14;
    }
    if (_c == QMetaObject::RegisterMethodArgumentMetaType) {
        if (_id < 14)
            *reinterpret_cast<QMetaType *>(_a[0]) = QMetaType();
        _id -= 14;
    }
    if (_c == QMetaObject::ReadProperty || _c == QMetaObject::WriteProperty
            || _c == QMetaObject::ResetProperty || _c == QMetaObject::BindableProperty
            || _c == QMetaObject::RegisterPropertyMetaType) {
        qt_static_metacall(this, _c, _id, _a);
        _id -= 12;
    }
    return _id;
}

// SIGNAL 0
void OpticalTrainAdaptor::removed()
{
    QMetaObject::activate(this, &staticMetaObject, 0, nullptr);
}

// SIGNAL 1
void OpticalTrainAdaptor::updated()
{
    QMetaObject::activate(this, &staticMetaObject, 1, nullptr);
}
QT_WARNING_POP
