/*
 * This file was generated by qdbusxml2cpp version 0.8
 * Source file was org.kde.kstars.INDI.Dome.xml
 *
 * qdbusxml2cpp is Copyright (C) The Qt Company Ltd. and other contributors.
 *
 * This is an auto-generated file.
 * This file may have been hand-edited. Look for HAND-EDIT comments
 * before re-generating it.
 */

#ifndef DOMEADAPTOR_H
#define DOMEADAPTOR_H

#include <QtCore/QObject>
#include <QtDBus/QtDBus>
#include "indi/indidome.h"
#include <QtCore/qcontainerfwd.h>

/*
 * Adaptor class for interface org.kde.kstars.INDI.Dome
 */
class DomeAdaptor: public QDBusAbstractAdaptor
{
    Q_OBJECT
    Q_CLASSINFO("D-Bus Interface", "org.kde.kstars.INDI.Dome")
    Q_CLASSINFO("D-Bus Introspection", ""
"  <interface name=\"org.kde.kstars.INDI.Dome\">\n"
"    <property access=\"read\" type=\"s\" name=\"name\"/>\n"
"    <property access=\"read\" type=\"b\" name=\"connected\"/>\n"
"    <property access=\"read\" type=\"b\" name=\"canPark\"/>\n"
"    <property access=\"read\" type=\"b\" name=\"canAbsMove\"/>\n"
"    <property access=\"read\" type=\"b\" name=\"canRelMove\"/>\n"
"    <property access=\"read\" type=\"b\" name=\"canAbort\"/>\n"
"    <property access=\"readwrite\" type=\"d\" name=\"position\"/>\n"
"    <property access=\"read\" type=\"b\" name=\"isMoving\"/>\n"
"    <property access=\"read\" type=\"i\" name=\"status\">\n"
"      <annotation value=\"ISD::Dome::Status\" name=\"org.qtproject.QtDBus.QtTypeName\"/>\n"
"    </property>\n"
"    <property access=\"read\" type=\"i\" name=\"shutterStatus\">\n"
"      <annotation value=\"ISD::Dome::ShutterStatus\" name=\"org.qtproject.QtDBus.QtTypeName\"/>\n"
"    </property>\n"
"    <property access=\"read\" type=\"i\" name=\"parkStatus\">\n"
"      <annotation value=\"ISD::ParkStatus\" name=\"org.qtproject.QtDBus.QtTypeName\"/>\n"
"    </property>\n"
"    <method name=\"Connect\">\n"
"      <annotation value=\"true\" name=\"org.freedesktop.DBus.Method.NoReply\"/>\n"
"    </method>\n"
"    <method name=\"Disconnect\">\n"
"      <annotation value=\"true\" name=\"org.freedesktop.DBus.Method.NoReply\"/>\n"
"    </method>\n"
"    <method name=\"isParked\">\n"
"      <arg direction=\"out\" type=\"b\"/>\n"
"    </method>\n"
"    <method name=\"park\">\n"
"      <arg direction=\"out\" type=\"b\"/>\n"
"    </method>\n"
"    <method name=\"unpark\">\n"
"      <arg direction=\"out\" type=\"b\"/>\n"
"    </method>\n"
"    <method name=\"abort\">\n"
"      <arg direction=\"out\" type=\"b\"/>\n"
"    </method>\n"
"    <method name=\"moveCW\">\n"
"      <arg direction=\"out\" type=\"b\"/>\n"
"    </method>\n"
"    <method name=\"moveCCW\">\n"
"      <arg direction=\"out\" type=\"b\"/>\n"
"    </method>\n"
"    <method name=\"controlShutter\">\n"
"      <arg direction=\"in\" type=\"b\" name=\"open\"/>\n"
"      <arg direction=\"out\" type=\"b\"/>\n"
"    </method>\n"
"    <method name=\"hasShutter\">\n"
"      <arg direction=\"out\" type=\"b\"/>\n"
"    </method>\n"
"    <signal name=\"Connected\"/>\n"
"    <signal name=\"Disconnected\"/>\n"
"    <signal name=\"ready\"/>\n"
"    <signal name=\"newStatus\">\n"
"      <arg direction=\"out\" type=\"(i)\" name=\"status\"/>\n"
"      <annotation value=\"ISD::Dome::Status\" name=\"org.qtproject.QtDBus.QtTypeName.In0\"/>\n"
"      <annotation value=\"ISD::Dome::Status\" name=\"org.qtproject.QtDBus.QtTypeName.Out0\"/>\n"
"    </signal>\n"
"    <signal name=\"newParkStatus\">\n"
"      <arg direction=\"out\" type=\"(i)\" name=\"status\"/>\n"
"      <annotation value=\"ISD::ParkStatus\" name=\"org.qtproject.QtDBus.QtTypeName.In0\"/>\n"
"      <annotation value=\"ISD::ParkStatus\" name=\"org.qtproject.QtDBus.QtTypeName.Out0\"/>\n"
"    </signal>\n"
"    <signal name=\"newShutterStatus\">\n"
"      <arg direction=\"out\" type=\"(i)\" name=\"status\"/>\n"
"      <annotation value=\"ISD::Dome::ShutterStatus\" name=\"org.qtproject.QtDBus.QtTypeName.In0\"/>\n"
"      <annotation value=\"ISD::Dome::ShutterStatus\" name=\"org.qtproject.QtDBus.QtTypeName.Out0\"/>\n"
"    </signal>\n"
"    <signal name=\"positionChanged\">\n"
"      <arg direction=\"out\" type=\"d\" name=\"degrees\"/>\n"
"    </signal>\n"
"  </interface>\n"
        "")
public:
    DomeAdaptor(ISD::Dome *parent);
    ~DomeAdaptor() override;

    inline ISD::Dome *parent() const
    { return static_cast<ISD::Dome *>(QObject::parent()); }

public: // PROPERTIES
    Q_PROPERTY(bool canAbort READ canAbort)
    bool canAbort() const;

    Q_PROPERTY(bool canAbsMove READ canAbsMove)
    bool canAbsMove() const;

    Q_PROPERTY(bool canPark READ canPark)
    bool canPark() const;

    Q_PROPERTY(bool canRelMove READ canRelMove)
    bool canRelMove() const;

    Q_PROPERTY(bool connected READ connected)
    bool connected() const;

    Q_PROPERTY(bool isMoving READ isMoving)
    bool isMoving() const;

    Q_PROPERTY(QString name READ name)
    QString name() const;

    Q_PROPERTY(int parkStatus READ parkStatus)
    int parkStatus() const;

    Q_PROPERTY(double position READ position WRITE setPosition)
    double position() const;
    void setPosition(double value);

    Q_PROPERTY(int shutterStatus READ shutterStatus)
    int shutterStatus() const;

    Q_PROPERTY(int status READ status)
    int status() const;

public Q_SLOTS: // METHODS
    Q_NOREPLY void Connect();
    Q_NOREPLY void Disconnect();
    bool abort();
    bool controlShutter(bool open);
    bool hasShutter();
    bool isParked();
    bool moveCCW();
    bool moveCW();
    bool park();
    bool unpark();
Q_SIGNALS: // SIGNALS
    void Connected();
    void Disconnected();
    void newParkStatus(ISD::ParkStatus status);
    void newShutterStatus(ISD::Dome::ShutterStatus status);
    void newStatus(ISD::Dome::Status status);
    void positionChanged(double degrees);
    void ready();
};

#endif
