/********************************************************************************
** Form generated from reading UI file 'opsastrometry.ui'
**
** Created by: Qt User Interface Compiler version 6.11.1
**
** WARNING! All changes made in this file will be lost when recompiling UI file!
********************************************************************************/

#ifndef UI_OPSASTROMETRY_H
#define UI_OPSASTROMETRY_H

#include <QtCore/QVariant>
#include <QtWidgets/QApplication>
#include <QtWidgets/QCheckBox>
#include <QtWidgets/QComboBox>
#include <QtWidgets/QDoubleSpinBox>
#include <QtWidgets/QGridLayout>
#include <QtWidgets/QGroupBox>
#include <QtWidgets/QHBoxLayout>
#include <QtWidgets/QLabel>
#include <QtWidgets/QLineEdit>
#include <QtWidgets/QPushButton>
#include <QtWidgets/QSpacerItem>
#include <QtWidgets/QVBoxLayout>
#include <QtWidgets/QWidget>
#include <klocalizedstring.h>
#include "widgets/dmsbox.h"

QT_BEGIN_NAMESPACE

class Ui_OpsAstrometry
{
public:
    QVBoxLayout *verticalLayout_5;
    QGroupBox *groupBox;
    QGridLayout *gridLayout;
    QLineEdit *lineEdit_41;
    QCheckBox *kcfg_AstrometryUseImageScale;
    QLineEdit *lineEdit_50;
    QLineEdit *lineEdit_42;
    QPushButton *updateScale;
    QLabel *label_13;
    QHBoxLayout *horizontalLayout;
    QCheckBox *kcfg_AstrometryAutoUpdateImageScale;
    QLabel *imageWarningLabel;
    QLabel *label_7;
    QDoubleSpinBox *kcfg_AstrometryImageScaleLow;
    QSpacerItem *horizontalSpacer;
    QLabel *label_12;
    QDoubleSpinBox *kcfg_AstrometryImageScaleHigh;
    QComboBox *kcfg_AstrometryImageScaleUnits;
    QGroupBox *groupBox_2;
    QGridLayout *gridLayout_2;
    QCheckBox *kcfg_AstrometryUsePosition;
    QLineEdit *lineEdit_44;
    QDoubleSpinBox *kcfg_AstrometryRadius;
    QLineEdit *lineEdit_47;
    QLabel *label_15;
    dmsBox *estRA;
    QLabel *label_14;
    QPushButton *updatePosition;
    QSpacerItem *horizontalSpacer_2;
    QLabel *label_8;
    dmsBox *estDec;
    QLabel *label;
    QLineEdit *lineEdit_48;
    QHBoxLayout *horizontalLayout_3;
    QCheckBox *kcfg_AstrometryAutoUpdatePosition;
    QLabel *positionWarningLabel;
    QCheckBox *kcfg_AstrometryDifferentialSlewing;
    QSpacerItem *verticalSpacer_4;

    void setupUi(QWidget *OpsAstrometry)
    {
        if (OpsAstrometry->objectName().isEmpty())
            OpsAstrometry->setObjectName("OpsAstrometry");
        OpsAstrometry->resize(323, 298);
        verticalLayout_5 = new QVBoxLayout(OpsAstrometry);
        verticalLayout_5->setSpacing(3);
        verticalLayout_5->setObjectName("verticalLayout_5");
        verticalLayout_5->setContentsMargins(3, 3, 3, 3);
        groupBox = new QGroupBox(OpsAstrometry);
        groupBox->setObjectName("groupBox");
        gridLayout = new QGridLayout(groupBox);
        gridLayout->setObjectName("gridLayout");
        lineEdit_41 = new QLineEdit(groupBox);
        lineEdit_41->setObjectName("lineEdit_41");
        lineEdit_41->setEnabled(false);
        lineEdit_41->setMaximumSize(QSize(30, 16777215));

        gridLayout->addWidget(lineEdit_41, 0, 2, 1, 1);

        kcfg_AstrometryUseImageScale = new QCheckBox(groupBox);
        kcfg_AstrometryUseImageScale->setObjectName("kcfg_AstrometryUseImageScale");
        kcfg_AstrometryUseImageScale->setChecked(false);

        gridLayout->addWidget(kcfg_AstrometryUseImageScale, 0, 0, 1, 1);

        lineEdit_50 = new QLineEdit(groupBox);
        lineEdit_50->setObjectName("lineEdit_50");
        lineEdit_50->setEnabled(false);
        lineEdit_50->setMaximumSize(QSize(30, 16777215));

        gridLayout->addWidget(lineEdit_50, 2, 2, 1, 1);

        lineEdit_42 = new QLineEdit(groupBox);
        lineEdit_42->setObjectName("lineEdit_42");
        lineEdit_42->setEnabled(false);
        lineEdit_42->setMaximumSize(QSize(30, 16777215));

        gridLayout->addWidget(lineEdit_42, 1, 2, 1, 1);

        updateScale = new QPushButton(groupBox);
        updateScale->setObjectName("updateScale");
        updateScale->setMinimumSize(QSize(22, 22));
        updateScale->setMaximumSize(QSize(22, 22));

        gridLayout->addWidget(updateScale, 1, 4, 2, 1);

        label_13 = new QLabel(groupBox);
        label_13->setObjectName("label_13");
        label_13->setAlignment(Qt::AlignCenter);

        gridLayout->addWidget(label_13, 1, 1, 1, 1);

        horizontalLayout = new QHBoxLayout();
        horizontalLayout->setObjectName("horizontalLayout");
        kcfg_AstrometryAutoUpdateImageScale = new QCheckBox(groupBox);
        kcfg_AstrometryAutoUpdateImageScale->setObjectName("kcfg_AstrometryAutoUpdateImageScale");

        horizontalLayout->addWidget(kcfg_AstrometryAutoUpdateImageScale);

        imageWarningLabel = new QLabel(groupBox);
        imageWarningLabel->setObjectName("imageWarningLabel");
        imageWarningLabel->setEnabled(true);
        QSizePolicy sizePolicy(QSizePolicy::Policy::Fixed, QSizePolicy::Policy::Fixed);
        sizePolicy.setHorizontalStretch(0);
        sizePolicy.setVerticalStretch(0);
        sizePolicy.setHeightForWidth(imageWarningLabel->sizePolicy().hasHeightForWidth());
        imageWarningLabel->setSizePolicy(sizePolicy);
        imageWarningLabel->setMinimumSize(QSize(22, 22));
        imageWarningLabel->setMaximumSize(QSize(22, 22));
        imageWarningLabel->setPixmap(QPixmap(QString::fromUtf8(":/icons/AlignWarning.svg")));
        imageWarningLabel->setScaledContents(true);
        imageWarningLabel->setAlignment(Qt::AlignCenter);

        horizontalLayout->addWidget(imageWarningLabel);


        gridLayout->addLayout(horizontalLayout, 1, 0, 1, 1);

        label_7 = new QLabel(groupBox);
        label_7->setObjectName("label_7");
        label_7->setAlignment(Qt::AlignCenter);

        gridLayout->addWidget(label_7, 2, 1, 1, 1);

        kcfg_AstrometryImageScaleLow = new QDoubleSpinBox(groupBox);
        kcfg_AstrometryImageScaleLow->setObjectName("kcfg_AstrometryImageScaleLow");
        kcfg_AstrometryImageScaleLow->setDecimals(3);
        kcfg_AstrometryImageScaleLow->setMinimum(0.000000000000000);
        kcfg_AstrometryImageScaleLow->setMaximum(999.000000000000000);
        kcfg_AstrometryImageScaleLow->setValue(30.000000000000000);

        gridLayout->addWidget(kcfg_AstrometryImageScaleLow, 0, 3, 1, 1);

        horizontalSpacer = new QSpacerItem(40, 20, QSizePolicy::Policy::Expanding, QSizePolicy::Policy::Minimum);

        gridLayout->addItem(horizontalSpacer, 1, 5, 1, 1);

        label_12 = new QLabel(groupBox);
        label_12->setObjectName("label_12");
        label_12->setAlignment(Qt::AlignCenter);

        gridLayout->addWidget(label_12, 0, 1, 1, 1);

        kcfg_AstrometryImageScaleHigh = new QDoubleSpinBox(groupBox);
        kcfg_AstrometryImageScaleHigh->setObjectName("kcfg_AstrometryImageScaleHigh");
        kcfg_AstrometryImageScaleHigh->setDecimals(3);
        kcfg_AstrometryImageScaleHigh->setMinimum(0.000000000000000);
        kcfg_AstrometryImageScaleHigh->setMaximum(999.000000000000000);
        kcfg_AstrometryImageScaleHigh->setValue(40.000000000000000);

        gridLayout->addWidget(kcfg_AstrometryImageScaleHigh, 1, 3, 1, 1);

        kcfg_AstrometryImageScaleUnits = new QComboBox(groupBox);
        kcfg_AstrometryImageScaleUnits->addItem(QString());
        kcfg_AstrometryImageScaleUnits->addItem(QString());
        kcfg_AstrometryImageScaleUnits->addItem(QString());
        kcfg_AstrometryImageScaleUnits->setObjectName("kcfg_AstrometryImageScaleUnits");
        kcfg_AstrometryImageScaleUnits->setMaximumSize(QSize(110, 16777215));

        gridLayout->addWidget(kcfg_AstrometryImageScaleUnits, 2, 3, 1, 1);


        verticalLayout_5->addWidget(groupBox);

        groupBox_2 = new QGroupBox(OpsAstrometry);
        groupBox_2->setObjectName("groupBox_2");
        gridLayout_2 = new QGridLayout(groupBox_2);
        gridLayout_2->setObjectName("gridLayout_2");
        kcfg_AstrometryUsePosition = new QCheckBox(groupBox_2);
        kcfg_AstrometryUsePosition->setObjectName("kcfg_AstrometryUsePosition");
        kcfg_AstrometryUsePosition->setChecked(false);

        gridLayout_2->addWidget(kcfg_AstrometryUsePosition, 1, 0, 1, 1);

        lineEdit_44 = new QLineEdit(groupBox_2);
        lineEdit_44->setObjectName("lineEdit_44");
        lineEdit_44->setEnabled(false);
        lineEdit_44->setMaximumSize(QSize(30, 16777215));

        gridLayout_2->addWidget(lineEdit_44, 3, 2, 1, 1);

        kcfg_AstrometryRadius = new QDoubleSpinBox(groupBox_2);
        kcfg_AstrometryRadius->setObjectName("kcfg_AstrometryRadius");
        kcfg_AstrometryRadius->setMinimum(1.000000000000000);
        kcfg_AstrometryRadius->setMaximum(360.000000000000000);
        kcfg_AstrometryRadius->setValue(30.000000000000000);

        gridLayout_2->addWidget(kcfg_AstrometryRadius, 3, 3, 1, 1);

        lineEdit_47 = new QLineEdit(groupBox_2);
        lineEdit_47->setObjectName("lineEdit_47");
        lineEdit_47->setEnabled(false);
        lineEdit_47->setMaximumSize(QSize(30, 16777215));

        gridLayout_2->addWidget(lineEdit_47, 1, 2, 1, 1);

        label_15 = new QLabel(groupBox_2);
        label_15->setObjectName("label_15");

        gridLayout_2->addWidget(label_15, 2, 1, 1, 1);

        estRA = new dmsBox(groupBox_2);
        estRA->setObjectName("estRA");
        estRA->setEnabled(true);

        gridLayout_2->addWidget(estRA, 1, 3, 1, 1);

        label_14 = new QLabel(groupBox_2);
        label_14->setObjectName("label_14");

        gridLayout_2->addWidget(label_14, 1, 1, 1, 1);

        updatePosition = new QPushButton(groupBox_2);
        updatePosition->setObjectName("updatePosition");
        updatePosition->setMinimumSize(QSize(22, 22));
        updatePosition->setMaximumSize(QSize(22, 22));

        gridLayout_2->addWidget(updatePosition, 2, 4, 2, 1);

        horizontalSpacer_2 = new QSpacerItem(40, 20, QSizePolicy::Policy::Expanding, QSizePolicy::Policy::Minimum);

        gridLayout_2->addItem(horizontalSpacer_2, 2, 5, 1, 1);

        label_8 = new QLabel(groupBox_2);
        label_8->setObjectName("label_8");

        gridLayout_2->addWidget(label_8, 3, 1, 1, 1);

        estDec = new dmsBox(groupBox_2);
        estDec->setObjectName("estDec");
        estDec->setEnabled(true);
        estDec->setMinimumSize(QSize(70, 0));

        gridLayout_2->addWidget(estDec, 2, 3, 1, 1);

        label = new QLabel(groupBox_2);
        label->setObjectName("label");

        gridLayout_2->addWidget(label, 4, 0, 1, 1);

        lineEdit_48 = new QLineEdit(groupBox_2);
        lineEdit_48->setObjectName("lineEdit_48");
        lineEdit_48->setEnabled(false);
        lineEdit_48->setMaximumSize(QSize(30, 16777215));

        gridLayout_2->addWidget(lineEdit_48, 2, 2, 1, 1);

        horizontalLayout_3 = new QHBoxLayout();
        horizontalLayout_3->setObjectName("horizontalLayout_3");
        kcfg_AstrometryAutoUpdatePosition = new QCheckBox(groupBox_2);
        kcfg_AstrometryAutoUpdatePosition->setObjectName("kcfg_AstrometryAutoUpdatePosition");

        horizontalLayout_3->addWidget(kcfg_AstrometryAutoUpdatePosition);

        positionWarningLabel = new QLabel(groupBox_2);
        positionWarningLabel->setObjectName("positionWarningLabel");
        positionWarningLabel->setEnabled(true);
        sizePolicy.setHeightForWidth(positionWarningLabel->sizePolicy().hasHeightForWidth());
        positionWarningLabel->setSizePolicy(sizePolicy);
        positionWarningLabel->setMinimumSize(QSize(22, 22));
        positionWarningLabel->setMaximumSize(QSize(22, 22));
        positionWarningLabel->setPixmap(QPixmap(QString::fromUtf8(":/icons/AlignWarning.svg")));
        positionWarningLabel->setScaledContents(true);
        positionWarningLabel->setAlignment(Qt::AlignCenter);

        horizontalLayout_3->addWidget(positionWarningLabel);


        gridLayout_2->addLayout(horizontalLayout_3, 2, 0, 1, 1);

        kcfg_AstrometryDifferentialSlewing = new QCheckBox(groupBox_2);
        kcfg_AstrometryDifferentialSlewing->setObjectName("kcfg_AstrometryDifferentialSlewing");

        gridLayout_2->addWidget(kcfg_AstrometryDifferentialSlewing, 0, 0, 1, 6);


        verticalLayout_5->addWidget(groupBox_2);

        verticalSpacer_4 = new QSpacerItem(20, 40, QSizePolicy::Policy::Minimum, QSizePolicy::Policy::Expanding);

        verticalLayout_5->addItem(verticalSpacer_4);


        retranslateUi(OpsAstrometry);

        kcfg_AstrometryImageScaleUnits->setCurrentIndex(0);


        QMetaObject::connectSlotsByName(OpsAstrometry);
    } // setupUi

    void retranslateUi(QWidget *OpsAstrometry)
    {
        groupBox->setTitle(tr2i18n("Imaging Options", nullptr));
#if QT_CONFIG(tooltip)
        lineEdit_41->setToolTip(tr2i18n("The lower end of the imager scale, calculated as a little smaller than the shorter dimension of the image.", nullptr));
#endif // QT_CONFIG(tooltip)
        lineEdit_41->setText(tr2i18n("L", nullptr));
#if QT_CONFIG(tooltip)
        kcfg_AstrometryUseImageScale->setToolTip(tr2i18n("Set image scale to speed up solver as it does not have to search index files of different image scales.", nullptr));
#endif // QT_CONFIG(tooltip)
        kcfg_AstrometryUseImageScale->setText(tr2i18n("Use Scale", nullptr));
#if QT_CONFIG(tooltip)
        lineEdit_50->setToolTip(tr2i18n("<p>The units of the imager scale bounds above.</p>\n"
"<ul>\n"
"<li>dw: degree width</li>\n"
"<li>aw: arcminute width</li>\n"
"</ul>", nullptr));
#endif // QT_CONFIG(tooltip)
        lineEdit_50->setText(tr2i18n("u", nullptr));
#if QT_CONFIG(tooltip)
        lineEdit_42->setToolTip(tr2i18n("The high end of the imager scale, calculated as a little bigger than the longer dimension of the image.", nullptr));
#endif // QT_CONFIG(tooltip)
        lineEdit_42->setText(tr2i18n("H", nullptr));
#if QT_CONFIG(tooltip)
        updateScale->setToolTip(tr2i18n("Update Image Scale Bounds from the currently active camera and telescope combination.", nullptr));
#endif // QT_CONFIG(tooltip)
        updateScale->setText(QString());
#if QT_CONFIG(tooltip)
        label_13->setToolTip(tr2i18n("The high end of the imager scale, calculated as a little bigger than the longer dimension of the image.", nullptr));
#endif // QT_CONFIG(tooltip)
        label_13->setText(tr2i18n("High", nullptr));
#if QT_CONFIG(tooltip)
        kcfg_AstrometryAutoUpdateImageScale->setToolTip(tr2i18n("Automatically update image scale values when CCD and/or Mount parameters are updated.", nullptr));
#endif // QT_CONFIG(tooltip)
        kcfg_AstrometryAutoUpdateImageScale->setText(tr2i18n("Auto Update", nullptr));
#if QT_CONFIG(tooltip)
        imageWarningLabel->setToolTip(tr2i18n("Image Scale Auto Update is turned off.", nullptr));
#endif // QT_CONFIG(tooltip)
        imageWarningLabel->setText(QString());
#if QT_CONFIG(tooltip)
        label_7->setToolTip(tr2i18n("<p>The units of the imager scale bounds above.</p>\n"
"<ul>\n"
"<li>dw: degree width</li>\n"
"<li>aw: arcminute width</li>\n"
"<li>app: arcsecs per pixel</li>\n"
"</ul>", nullptr));
#endif // QT_CONFIG(tooltip)
        label_7->setText(tr2i18n("units", nullptr));
#if QT_CONFIG(tooltip)
        label_12->setToolTip(tr2i18n("The lower end of the imager scale, calculated as a little smaller than the shorter dimension of the image.", nullptr));
#endif // QT_CONFIG(tooltip)
        label_12->setText(tr2i18n("Low", nullptr));
        kcfg_AstrometryImageScaleUnits->setItemText(0, tr2i18n("dw", nullptr));
        kcfg_AstrometryImageScaleUnits->setItemText(1, tr2i18n("aw", nullptr));
        kcfg_AstrometryImageScaleUnits->setItemText(2, tr2i18n("app", nullptr));

#if QT_CONFIG(tooltip)
        kcfg_AstrometryImageScaleUnits->setToolTip(tr2i18n("<p>The units of the imager scale bounds above.</p>\n"
"<ul>\n"
"<li>dw: degree width</li>\n"
"<li>aw: arcminute width</li>\n"
"<li>app: arcsecs per pixel</li>\n"
"</ul>", nullptr));
#endif // QT_CONFIG(tooltip)
        groupBox_2->setTitle(tr2i18n("Position Options", nullptr));
#if QT_CONFIG(tooltip)
        kcfg_AstrometryUsePosition->setToolTip(tr2i18n("Set estimated position to speed up astrometry solver as it does not have to search in other areas of the sky.", nullptr));
#endif // QT_CONFIG(tooltip)
        kcfg_AstrometryUsePosition->setText(tr2i18n("Use Position", nullptr));
#if QT_CONFIG(tooltip)
        lineEdit_44->setToolTip(tr2i18n("The Search Radius for the Estimated Telescope/Image Field Position in degrees.", nullptr));
#endif // QT_CONFIG(tooltip)
        lineEdit_44->setText(tr2i18n("5", nullptr));
#if QT_CONFIG(tooltip)
        lineEdit_47->setToolTip(tr2i18n("The RA of the Estimated Telescope/Image Field Position in hh:mm:ss notation", nullptr));
#endif // QT_CONFIG(tooltip)
        lineEdit_47->setText(tr2i18n("3", nullptr));
#if QT_CONFIG(tooltip)
        label_15->setToolTip(tr2i18n("The DEC of the Estimated Telescope/Image Field Position in dd:mm:ss notation", nullptr));
#endif // QT_CONFIG(tooltip)
        label_15->setText(tr2i18n("DEC", nullptr));
#if QT_CONFIG(tooltip)
        estRA->setToolTip(tr2i18n("The RA of the Estimated Telescope/Image Field Position in hh:mm:ss notation", nullptr));
#endif // QT_CONFIG(tooltip)
#if QT_CONFIG(tooltip)
        label_14->setToolTip(tr2i18n("The RA of the Estimated Telescope/Image Field Position in hh:mm:ss notation", nullptr));
#endif // QT_CONFIG(tooltip)
        label_14->setText(tr2i18n("RA", nullptr));
#if QT_CONFIG(tooltip)
        updatePosition->setToolTip(tr2i18n("Update coordinates to the current telescope position", nullptr));
#endif // QT_CONFIG(tooltip)
        updatePosition->setText(QString());
#if QT_CONFIG(tooltip)
        label_8->setToolTip(tr2i18n("The Search Radius for the Estimated Telescope/Image Field Position in degrees.", nullptr));
#endif // QT_CONFIG(tooltip)
        label_8->setText(tr2i18n("Radius", nullptr));
#if QT_CONFIG(tooltip)
        estDec->setToolTip(tr2i18n("The DEC of the Estimated Telescope/Image Field Position in dd:mm:ss notation", nullptr));
#endif // QT_CONFIG(tooltip)
        label->setText(QString());
#if QT_CONFIG(tooltip)
        lineEdit_48->setToolTip(tr2i18n("The DEC of the Estimated Telescope/Image Field Position in dd:mm:ss notation", nullptr));
#endif // QT_CONFIG(tooltip)
        lineEdit_48->setText(tr2i18n("4", nullptr));
#if QT_CONFIG(tooltip)
        kcfg_AstrometryAutoUpdatePosition->setToolTip(tr2i18n("Automatically update position coordinates when mount completes slewing.", nullptr));
#endif // QT_CONFIG(tooltip)
        kcfg_AstrometryAutoUpdatePosition->setText(tr2i18n("Auto Update", nullptr));
#if QT_CONFIG(tooltip)
        positionWarningLabel->setToolTip(tr2i18n("Position Auto Update is turned off.", nullptr));
#endif // QT_CONFIG(tooltip)
        positionWarningLabel->setText(QString());
#if QT_CONFIG(tooltip)
        kcfg_AstrometryDifferentialSlewing->setToolTip(tr2i18n("Do not use Sync when Slew to Target is selected. Use differential slewing to correct for discrepancies. This is useful on some mounts (e.g. Paramount).", nullptr));
#endif // QT_CONFIG(tooltip)
        kcfg_AstrometryDifferentialSlewing->setText(tr2i18n("Use differential slewing instead of syncing", nullptr));
        (void)OpsAstrometry;
    } // retranslateUi

};

namespace Ui {
    class OpsAstrometry: public Ui_OpsAstrometry {};
} // namespace Ui

QT_END_NAMESPACE

#endif // OPSASTROMETRY_H

