/********************************************************************************
** Form generated from reading UI file 'argchangeviewoption.ui'
**
** Created by: Qt User Interface Compiler version 6.11.1
**
** WARNING! All changes made in this file will be lost when recompiling UI file!
********************************************************************************/

#ifndef UI_ARGCHANGEVIEWOPTION_H
#define UI_ARGCHANGEVIEWOPTION_H

#include <QtCore/QVariant>
#include <QtWidgets/QApplication>
#include <QtWidgets/QComboBox>
#include <QtWidgets/QGridLayout>
#include <QtWidgets/QLabel>
#include <QtWidgets/QLineEdit>
#include <QtWidgets/QPushButton>
#include <QtWidgets/QSpacerItem>
#include <QtWidgets/QVBoxLayout>
#include <QtWidgets/QWidget>
#include <klocalizedstring.h>

QT_BEGIN_NAMESPACE

class Ui_ArgChangeViewOption
{
public:
    QVBoxLayout *vboxLayout;
    QGridLayout *gridLayout;
    QComboBox *OptionName;
    QSpacerItem *spacerItem;
    QLabel *textLabel1_2;
    QPushButton *TreeButton;
    QLineEdit *OptionValue;
    QSpacerItem *spacerItem1;
    QLabel *textLabel1;
    QSpacerItem *spacerItem2;

    void setupUi(QWidget *ArgChangeViewOption)
    {
        if (ArgChangeViewOption->objectName().isEmpty())
            ArgChangeViewOption->setObjectName("ArgChangeViewOption");
        ArgChangeViewOption->resize(260, 171);
        vboxLayout = new QVBoxLayout(ArgChangeViewOption);
#ifndef UI_Q_OS_MAC
        vboxLayout->setSpacing(6);
#endif
        vboxLayout->setContentsMargins(10, 10, 10, 10);
        vboxLayout->setObjectName("vboxLayout");
        gridLayout = new QGridLayout();
#ifndef UI_Q_OS_MAC
        gridLayout->setSpacing(6);
#endif
#ifndef UI_Q_OS_MAC
        gridLayout->setContentsMargins(0, 0, 0, 0);
#endif
        gridLayout->setObjectName("gridLayout");
        OptionName = new QComboBox(ArgChangeViewOption);
        OptionName->setObjectName("OptionName");

        gridLayout->addWidget(OptionName, 0, 1, 1, 1);

        spacerItem = new QSpacerItem(50, 20, QSizePolicy::Policy::Expanding, QSizePolicy::Policy::Minimum);

        gridLayout->addItem(spacerItem, 1, 0, 1, 1);

        textLabel1_2 = new QLabel(ArgChangeViewOption);
        textLabel1_2->setObjectName("textLabel1_2");

        gridLayout->addWidget(textLabel1_2, 3, 0, 1, 1);

        TreeButton = new QPushButton(ArgChangeViewOption);
        TreeButton->setObjectName("TreeButton");

        gridLayout->addWidget(TreeButton, 1, 1, 1, 1);

        OptionValue = new QLineEdit(ArgChangeViewOption);
        OptionValue->setObjectName("OptionValue");

        gridLayout->addWidget(OptionValue, 3, 1, 1, 1);

        spacerItem1 = new QSpacerItem(160, 20, QSizePolicy::Policy::Expanding, QSizePolicy::Policy::Minimum);

        gridLayout->addItem(spacerItem1, 2, 0, 1, 2);

        textLabel1 = new QLabel(ArgChangeViewOption);
        textLabel1->setObjectName("textLabel1");

        gridLayout->addWidget(textLabel1, 0, 0, 1, 1);


        vboxLayout->addLayout(gridLayout);

        spacerItem2 = new QSpacerItem(20, 16, QSizePolicy::Policy::Minimum, QSizePolicy::Policy::Expanding);

        vboxLayout->addItem(spacerItem2);


        retranslateUi(ArgChangeViewOption);

        QMetaObject::connectSlotsByName(ArgChangeViewOption);
    } // setupUi

    void retranslateUi(QWidget *ArgChangeViewOption)
    {
#if QT_CONFIG(tooltip)
        OptionName->setToolTip(tr2i18n("List of adjustable options", nullptr));
#endif // QT_CONFIG(tooltip)
#if QT_CONFIG(whatsthis)
        OptionName->setWhatsThis(tr2i18n("Select an option from this list to set its value.  You may also select the option using an organized Tree List using the \"Browse Tree...\" button.", nullptr));
#endif // QT_CONFIG(whatsthis)
        textLabel1_2->setText(tr2i18n("Value:", nullptr));
#if QT_CONFIG(tooltip)
        TreeButton->setToolTip(tr2i18n("Show Tree View of options", nullptr));
#endif // QT_CONFIG(tooltip)
#if QT_CONFIG(whatsthis)
        TreeButton->setWhatsThis(tr2i18n("Press this button to select a View Option from a Tree list, in which they are grouped by subject.  Also shown are a short description of each option, and the data type of the option's value (string, integer, float or boolean).", nullptr));
#endif // QT_CONFIG(whatsthis)
        TreeButton->setText(tr2i18n("Browse Tree...", nullptr));
#if QT_CONFIG(tooltip)
        OptionValue->setToolTip(tr2i18n("value for selected option", nullptr));
#endif // QT_CONFIG(tooltip)
#if QT_CONFIG(whatsthis)
        OptionValue->setWhatsThis(tr2i18n("Set the value for the selected view option here.  Make sure the value you enter matches the data type expected by the option.  For example, the \"UseAltAz\" option expects a boolean value, so you should enter \"true\", \"false\", \"1\", or \"0\".  If you are unsure what data type is expected, examine the Tree View of options using the \"Browse Tree...\" button.", nullptr));
#endif // QT_CONFIG(whatsthis)
        textLabel1->setText(tr2i18n("Option:", nullptr));
        (void)ArgChangeViewOption;
    } // retranslateUi

};

namespace Ui {
    class ArgChangeViewOption: public Ui_ArgChangeViewOption {};
} // namespace Ui

QT_END_NAMESPACE

#endif // ARGCHANGEVIEWOPTION_H

