/********************************************************************************
** Form generated from reading UI file 'modcalcvizequinox.ui'
**
** Created by: Qt User Interface Compiler version 6.11.1
**
** WARNING! All changes made in this file will be lost when recompiling UI file!
********************************************************************************/

#ifndef UI_MODCALCVIZEQUINOX_H
#define UI_MODCALCVIZEQUINOX_H

#include <QtCore/QVariant>
#include <QtWidgets/QApplication>
#include <QtWidgets/QGridLayout>
#include <QtWidgets/QHBoxLayout>
#include <QtWidgets/QLabel>
#include <QtWidgets/QPushButton>
#include <QtWidgets/QSpacerItem>
#include <QtWidgets/QSpinBox>
#include <QtWidgets/QTabWidget>
#include <QtWidgets/QVBoxLayout>
#include <QtWidgets/QWidget>
#include <klocalizedstring.h>
#include "eqplotwidget.h"
#include "kplotwidget.h"
#include "kurlrequester.h"

QT_BEGIN_NAMESPACE

class Ui_modCalcEquinox
{
public:
    QVBoxLayout *vboxLayout;
    QTabWidget *tabWidget;
    QWidget *tab;
    QVBoxLayout *vboxLayout1;
    QHBoxLayout *hboxLayout;
    QSpacerItem *spacerItem;
    QLabel *label;
    QSpinBox *Year;
    QSpacerItem *spacerItem1;
    QHBoxLayout *hboxLayout1;
    QSpacerItem *spacerItem2;
    QGridLayout *gridLayout;
    QLabel *VEquinoxText;
    QLabel *VEquinox;
    QLabel *SSolsticeText;
    QLabel *SSolstice;
    QLabel *AEquinoxText;
    QLabel *AEquinox;
    QLabel *WSolsticeText;
    QLabel *WSolstice;
    QSpacerItem *spacerItem3;
    eqPlotWidget *Plot;
    QWidget *tab_2;
    QVBoxLayout *vboxLayout2;
    QLabel *HelpLabel;
    QGridLayout *gridLayout1;
    QLabel *label_3;
    KUrlRequester *InputFileBatch;
    QLabel *label_4;
    KUrlRequester *OutputFileBatch;
    QHBoxLayout *hboxLayout2;
    QSpacerItem *spacerItem4;
    QVBoxLayout *vboxLayout3;
    QPushButton *RunButtonBatch;
    QPushButton *ViewButtonBatch;
    QSpacerItem *spacerItem5;
    QSpacerItem *spacerItem6;

    void setupUi(QWidget *modCalcEquinox)
    {
        if (modCalcEquinox->objectName().isEmpty())
            modCalcEquinox->setObjectName("modCalcEquinox");
        modCalcEquinox->resize(505, 520);
        vboxLayout = new QVBoxLayout(modCalcEquinox);
        vboxLayout->setObjectName("vboxLayout");
        tabWidget = new QTabWidget(modCalcEquinox);
        tabWidget->setObjectName("tabWidget");
        tab = new QWidget();
        tab->setObjectName("tab");
        vboxLayout1 = new QVBoxLayout(tab);
        vboxLayout1->setObjectName("vboxLayout1");
        hboxLayout = new QHBoxLayout();
        hboxLayout->setSpacing(6);
        hboxLayout->setObjectName("hboxLayout");
        hboxLayout->setContentsMargins(0, 0, 0, 0);
        spacerItem = new QSpacerItem(40, 20, QSizePolicy::Policy::Expanding, QSizePolicy::Policy::Minimum);

        hboxLayout->addItem(spacerItem);

        label = new QLabel(tab);
        label->setObjectName("label");
        QSizePolicy sizePolicy(QSizePolicy::Policy::Preferred, QSizePolicy::Policy::Minimum);
        sizePolicy.setHorizontalStretch(0);
        sizePolicy.setVerticalStretch(0);
        sizePolicy.setHeightForWidth(label->sizePolicy().hasHeightForWidth());
        label->setSizePolicy(sizePolicy);

        hboxLayout->addWidget(label);

        Year = new QSpinBox(tab);
        Year->setObjectName("Year");
        Year->setMinimum(100);
        Year->setMaximum(3000);
        Year->setValue(2014);

        hboxLayout->addWidget(Year);

        spacerItem1 = new QSpacerItem(40, 20, QSizePolicy::Policy::Expanding, QSizePolicy::Policy::Minimum);

        hboxLayout->addItem(spacerItem1);


        vboxLayout1->addLayout(hboxLayout);

        hboxLayout1 = new QHBoxLayout();
        hboxLayout1->setObjectName("hboxLayout1");
        spacerItem2 = new QSpacerItem(40, 20, QSizePolicy::Policy::Expanding, QSizePolicy::Policy::Minimum);

        hboxLayout1->addItem(spacerItem2);

        gridLayout = new QGridLayout();
        gridLayout->setObjectName("gridLayout");
        VEquinoxText = new QLabel(tab);
        VEquinoxText->setObjectName("VEquinoxText");

        gridLayout->addWidget(VEquinoxText, 0, 0, 1, 1);

        VEquinox = new QLabel(tab);
        VEquinox->setObjectName("VEquinox");
        QFont font;
        font.setFamilies({QString::fromUtf8("Monospace")});
        font.setPointSize(12);
        font.setBold(true);
        VEquinox->setFont(font);
        VEquinox->setIndent(5);
        VEquinox->setTextInteractionFlags(Qt::TextSelectableByMouse);

        gridLayout->addWidget(VEquinox, 0, 1, 1, 1);

        SSolsticeText = new QLabel(tab);
        SSolsticeText->setObjectName("SSolsticeText");

        gridLayout->addWidget(SSolsticeText, 1, 0, 1, 1);

        SSolstice = new QLabel(tab);
        SSolstice->setObjectName("SSolstice");
        SSolstice->setFont(font);
        SSolstice->setIndent(5);
        SSolstice->setTextInteractionFlags(Qt::TextSelectableByMouse);

        gridLayout->addWidget(SSolstice, 1, 1, 1, 1);

        AEquinoxText = new QLabel(tab);
        AEquinoxText->setObjectName("AEquinoxText");

        gridLayout->addWidget(AEquinoxText, 2, 0, 1, 1);

        AEquinox = new QLabel(tab);
        AEquinox->setObjectName("AEquinox");
        AEquinox->setFont(font);
        AEquinox->setIndent(5);
        AEquinox->setTextInteractionFlags(Qt::TextSelectableByMouse);

        gridLayout->addWidget(AEquinox, 2, 1, 1, 1);

        WSolsticeText = new QLabel(tab);
        WSolsticeText->setObjectName("WSolsticeText");

        gridLayout->addWidget(WSolsticeText, 3, 0, 1, 1);

        WSolstice = new QLabel(tab);
        WSolstice->setObjectName("WSolstice");
        WSolstice->setFont(font);
        WSolstice->setIndent(5);
        WSolstice->setTextInteractionFlags(Qt::TextSelectableByMouse);

        gridLayout->addWidget(WSolstice, 3, 1, 1, 1);


        hboxLayout1->addLayout(gridLayout);

        spacerItem3 = new QSpacerItem(40, 20, QSizePolicy::Policy::Expanding, QSizePolicy::Policy::Minimum);

        hboxLayout1->addItem(spacerItem3);


        vboxLayout1->addLayout(hboxLayout1);

        Plot = new eqPlotWidget(tab);
        Plot->setObjectName("Plot");
        QSizePolicy sizePolicy1(QSizePolicy::Policy::Expanding, QSizePolicy::Policy::Expanding);
        sizePolicy1.setHorizontalStretch(0);
        sizePolicy1.setVerticalStretch(0);
        sizePolicy1.setHeightForWidth(Plot->sizePolicy().hasHeightForWidth());
        Plot->setSizePolicy(sizePolicy1);

        vboxLayout1->addWidget(Plot);

        tabWidget->addTab(tab, QString());
        tab_2 = new QWidget();
        tab_2->setObjectName("tab_2");
        vboxLayout2 = new QVBoxLayout(tab_2);
        vboxLayout2->setObjectName("vboxLayout2");
        HelpLabel = new QLabel(tab_2);
        HelpLabel->setObjectName("HelpLabel");

        vboxLayout2->addWidget(HelpLabel);

        gridLayout1 = new QGridLayout();
        gridLayout1->setObjectName("gridLayout1");
        label_3 = new QLabel(tab_2);
        label_3->setObjectName("label_3");

        gridLayout1->addWidget(label_3, 0, 0, 1, 1);

        InputFileBatch = new KUrlRequester(tab_2);
        InputFileBatch->setObjectName("InputFileBatch");

        gridLayout1->addWidget(InputFileBatch, 0, 1, 1, 1);

        label_4 = new QLabel(tab_2);
        label_4->setObjectName("label_4");

        gridLayout1->addWidget(label_4, 1, 0, 1, 1);

        OutputFileBatch = new KUrlRequester(tab_2);
        OutputFileBatch->setObjectName("OutputFileBatch");

        gridLayout1->addWidget(OutputFileBatch, 1, 1, 1, 1);


        vboxLayout2->addLayout(gridLayout1);

        hboxLayout2 = new QHBoxLayout();
        hboxLayout2->setObjectName("hboxLayout2");
        spacerItem4 = new QSpacerItem(40, 20, QSizePolicy::Policy::Expanding, QSizePolicy::Policy::Minimum);

        hboxLayout2->addItem(spacerItem4);

        vboxLayout3 = new QVBoxLayout();
        vboxLayout3->setObjectName("vboxLayout3");
        RunButtonBatch = new QPushButton(tab_2);
        RunButtonBatch->setObjectName("RunButtonBatch");

        vboxLayout3->addWidget(RunButtonBatch);

        ViewButtonBatch = new QPushButton(tab_2);
        ViewButtonBatch->setObjectName("ViewButtonBatch");

        vboxLayout3->addWidget(ViewButtonBatch);


        hboxLayout2->addLayout(vboxLayout3);

        spacerItem5 = new QSpacerItem(40, 20, QSizePolicy::Policy::Expanding, QSizePolicy::Policy::Minimum);

        hboxLayout2->addItem(spacerItem5);


        vboxLayout2->addLayout(hboxLayout2);

        spacerItem6 = new QSpacerItem(465, 16, QSizePolicy::Policy::Minimum, QSizePolicy::Policy::Expanding);

        vboxLayout2->addItem(spacerItem6);

        tabWidget->addTab(tab_2, QString());

        vboxLayout->addWidget(tabWidget);


        retranslateUi(modCalcEquinox);

        tabWidget->setCurrentIndex(0);


        QMetaObject::connectSlotsByName(modCalcEquinox);
    } // setupUi

    void retranslateUi(QWidget *modCalcEquinox)
    {
        modCalcEquinox->setWindowTitle(tr2i18n("Equinoxes and Solstices", nullptr));
        label->setText(tr2i18n("Equinoxes and solstices for the year:", nullptr));
        VEquinoxText->setText(tr2i18n("Vernal equinox:", nullptr));
        VEquinox->setText(tr2i18n("1 Jan 2007  00:00", nullptr));
        SSolsticeText->setText(tr2i18n("Summer solstice:", nullptr));
        SSolstice->setText(tr2i18n("1 Jan 2007  00:00", nullptr));
        AEquinoxText->setText(tr2i18n("Autumnal equinox:", nullptr));
        AEquinox->setText(tr2i18n("1 Jan 2007  00:00", nullptr));
        WSolsticeText->setText(tr2i18n("Winter solstice:", nullptr));
        WSolstice->setText(tr2i18n("1 Jan 2007  00:00", nullptr));
        tabWidget->setTabText(tabWidget->indexOf(tab), tr2i18n("Interactive Mode", nullptr));
        HelpLabel->setText(tr2i18n("Specify Years for the Calculation in the Input File", nullptr));
        label_3->setText(tr2i18n("Input file:", nullptr));
        label_4->setText(tr2i18n("Output file:", nullptr));
        RunButtonBatch->setText(tr2i18n("Compute", nullptr));
        ViewButtonBatch->setText(tr2i18n("View Output...", nullptr));
        tabWidget->setTabText(tabWidget->indexOf(tab_2), tr2i18n("Batch Mode", nullptr));
    } // retranslateUi

};

namespace Ui {
    class modCalcEquinox: public Ui_modCalcEquinox {};
} // namespace Ui

QT_END_NAMESPACE

#endif // MODCALCVIZEQUINOX_H

