/********************************************************************************
** Form generated from reading UI file 'calibrationoptions.ui'
**
** Created by: Qt User Interface Compiler version 6.11.1
**
** WARNING! All changes made in this file will be lost when recompiling UI file!
********************************************************************************/

#ifndef UI_CALIBRATIONOPTIONS_H
#define UI_CALIBRATIONOPTIONS_H

#include <QtCore/QVariant>
#include <QtWidgets/QAbstractButton>
#include <QtWidgets/QApplication>
#include <QtWidgets/QButtonGroup>
#include <QtWidgets/QCheckBox>
#include <QtWidgets/QDialog>
#include <QtWidgets/QDialogButtonBox>
#include <QtWidgets/QGridLayout>
#include <QtWidgets/QGroupBox>
#include <QtWidgets/QHBoxLayout>
#include <QtWidgets/QLabel>
#include <QtWidgets/QRadioButton>
#include <QtWidgets/QSpacerItem>
#include <QtWidgets/QSpinBox>
#include <QtWidgets/QVBoxLayout>
#include <klocalizedstring.h>
#include "widgets/dmsbox.h"

QT_BEGIN_NAMESPACE

class Ui_Calibration
{
public:
    QVBoxLayout *verticalLayout_3;
    QHBoxLayout *horizontalLayout_2;
    QGroupBox *groupBox;
    QVBoxLayout *verticalLayout;
    QHBoxLayout *horizontalLayout;
    QCheckBox *captureCalibrationWall;
    QLabel *label;
    dmsBox *azBox;
    QLabel *label_2;
    dmsBox *altBox;
    QCheckBox *captureCalibrationParkMount;
    QCheckBox *captureCalibrationParkDome;
    QSpacerItem *verticalSpacer_2;
    QGroupBox *groupBox_2;
    QVBoxLayout *verticalLayout_2;
    QGridLayout *gridLayout;
    QRadioButton *captureCalibrationDurationManual;
    QRadioButton *captureCalibrationUseADU;
    QSpinBox *captureCalibrationADUValue;
    QLabel *label_3;
    QSpinBox *captureCalibrationADUTolerance;
    QCheckBox *captureCalibrationSkyFlats;
    QSpacerItem *verticalSpacer;
    QDialogButtonBox *buttonBox;
    QButtonGroup *flatDurationGroup;

    void setupUi(QDialog *Calibration)
    {
        if (Calibration->objectName().isEmpty())
            Calibration->setObjectName("Calibration");
        Calibration->resize(575, 186);
        verticalLayout_3 = new QVBoxLayout(Calibration);
        verticalLayout_3->setSpacing(3);
        verticalLayout_3->setObjectName("verticalLayout_3");
        verticalLayout_3->setContentsMargins(3, 3, 3, 3);
        horizontalLayout_2 = new QHBoxLayout();
        horizontalLayout_2->setObjectName("horizontalLayout_2");
        groupBox = new QGroupBox(Calibration);
        groupBox->setObjectName("groupBox");
        verticalLayout = new QVBoxLayout(groupBox);
        verticalLayout->setSpacing(3);
        verticalLayout->setObjectName("verticalLayout");
        verticalLayout->setContentsMargins(3, 3, 3, 3);
        horizontalLayout = new QHBoxLayout();
        horizontalLayout->setObjectName("horizontalLayout");
        captureCalibrationWall = new QCheckBox(groupBox);
        captureCalibrationWall->setObjectName("captureCalibrationWall");

        horizontalLayout->addWidget(captureCalibrationWall);

        label = new QLabel(groupBox);
        label->setObjectName("label");

        horizontalLayout->addWidget(label);

        azBox = new dmsBox(groupBox);
        azBox->setObjectName("azBox");

        horizontalLayout->addWidget(azBox);

        label_2 = new QLabel(groupBox);
        label_2->setObjectName("label_2");

        horizontalLayout->addWidget(label_2);

        altBox = new dmsBox(groupBox);
        altBox->setObjectName("altBox");

        horizontalLayout->addWidget(altBox);


        verticalLayout->addLayout(horizontalLayout);

        captureCalibrationParkMount = new QCheckBox(groupBox);
        captureCalibrationParkMount->setObjectName("captureCalibrationParkMount");

        verticalLayout->addWidget(captureCalibrationParkMount);

        captureCalibrationParkDome = new QCheckBox(groupBox);
        captureCalibrationParkDome->setObjectName("captureCalibrationParkDome");

        verticalLayout->addWidget(captureCalibrationParkDome);

        verticalSpacer_2 = new QSpacerItem(20, 40, QSizePolicy::Policy::Minimum, QSizePolicy::Policy::Expanding);

        verticalLayout->addItem(verticalSpacer_2);


        horizontalLayout_2->addWidget(groupBox);

        groupBox_2 = new QGroupBox(Calibration);
        groupBox_2->setObjectName("groupBox_2");
        verticalLayout_2 = new QVBoxLayout(groupBox_2);
        verticalLayout_2->setSpacing(3);
        verticalLayout_2->setObjectName("verticalLayout_2");
        verticalLayout_2->setContentsMargins(3, 3, 3, 3);
        gridLayout = new QGridLayout();
        gridLayout->setObjectName("gridLayout");
        captureCalibrationDurationManual = new QRadioButton(groupBox_2);
        flatDurationGroup = new QButtonGroup(Calibration);
        flatDurationGroup->setObjectName("flatDurationGroup");
        flatDurationGroup->addButton(captureCalibrationDurationManual);
        captureCalibrationDurationManual->setObjectName("captureCalibrationDurationManual");
        captureCalibrationDurationManual->setChecked(true);

        gridLayout->addWidget(captureCalibrationDurationManual, 0, 0, 1, 1);

        captureCalibrationUseADU = new QRadioButton(groupBox_2);
        flatDurationGroup->addButton(captureCalibrationUseADU);
        captureCalibrationUseADU->setObjectName("captureCalibrationUseADU");

        gridLayout->addWidget(captureCalibrationUseADU, 1, 0, 1, 1);

        captureCalibrationADUValue = new QSpinBox(groupBox_2);
        captureCalibrationADUValue->setObjectName("captureCalibrationADUValue");
        captureCalibrationADUValue->setMaximum(65535);
        captureCalibrationADUValue->setSingleStep(1000);

        gridLayout->addWidget(captureCalibrationADUValue, 1, 1, 1, 1);

        label_3 = new QLabel(groupBox_2);
        label_3->setObjectName("label_3");

        gridLayout->addWidget(label_3, 2, 0, 1, 1);

        captureCalibrationADUTolerance = new QSpinBox(groupBox_2);
        captureCalibrationADUTolerance->setObjectName("captureCalibrationADUTolerance");
        captureCalibrationADUTolerance->setMaximum(50000);
        captureCalibrationADUTolerance->setSingleStep(100);
        captureCalibrationADUTolerance->setValue(1000);

        gridLayout->addWidget(captureCalibrationADUTolerance, 2, 1, 1, 1);


        verticalLayout_2->addLayout(gridLayout);

        captureCalibrationSkyFlats = new QCheckBox(groupBox_2);
        captureCalibrationSkyFlats->setObjectName("captureCalibrationSkyFlats");

        verticalLayout_2->addWidget(captureCalibrationSkyFlats);

        verticalSpacer = new QSpacerItem(20, 40, QSizePolicy::Policy::Minimum, QSizePolicy::Policy::Expanding);

        verticalLayout_2->addItem(verticalSpacer);


        horizontalLayout_2->addWidget(groupBox_2);


        verticalLayout_3->addLayout(horizontalLayout_2);

        buttonBox = new QDialogButtonBox(Calibration);
        buttonBox->setObjectName("buttonBox");
        buttonBox->setOrientation(Qt::Horizontal);
        buttonBox->setStandardButtons(QDialogButtonBox::Cancel|QDialogButtonBox::Ok);

        verticalLayout_3->addWidget(buttonBox);

        QWidget::setTabOrder(captureCalibrationWall, azBox);
        QWidget::setTabOrder(azBox, altBox);
        QWidget::setTabOrder(altBox, captureCalibrationParkMount);
        QWidget::setTabOrder(captureCalibrationParkMount, captureCalibrationParkDome);
        QWidget::setTabOrder(captureCalibrationParkDome, captureCalibrationDurationManual);
        QWidget::setTabOrder(captureCalibrationDurationManual, captureCalibrationUseADU);
        QWidget::setTabOrder(captureCalibrationUseADU, captureCalibrationADUValue);
        QWidget::setTabOrder(captureCalibrationADUValue, captureCalibrationADUTolerance);

        retranslateUi(Calibration);
        QObject::connect(buttonBox, &QDialogButtonBox::accepted, Calibration, qOverload<>(&QDialog::accept));
        QObject::connect(buttonBox, &QDialogButtonBox::rejected, Calibration, qOverload<>(&QDialog::reject));

        QMetaObject::connectSlotsByName(Calibration);
    } // setupUi

    void retranslateUi(QDialog *Calibration)
    {
        Calibration->setWindowTitle(tr2i18n("Calibration Options", nullptr));
#if QT_CONFIG(tooltip)
        groupBox->setToolTip(tr2i18n("<html><head/><body><p>Select which actions to perform before a Bias/Dark/Flat frame is captured.</p></body></html>", nullptr));
#endif // QT_CONFIG(tooltip)
        groupBox->setTitle(tr2i18n("Calibration Pre-Actions", nullptr));
#if QT_CONFIG(tooltip)
        captureCalibrationWall->setToolTip(tr2i18n("Slew mount to the specified Azimuth/Altitude coordinates before taking flat field images", nullptr));
#endif // QT_CONFIG(tooltip)
        captureCalibrationWall->setText(tr2i18n("Goto Wall", nullptr));
        label->setText(tr2i18n("Az:", nullptr));
#if QT_CONFIG(tooltip)
        azBox->setToolTip(QString());
#endif // QT_CONFIG(tooltip)
        label_2->setText(tr2i18n("Alt:", nullptr));
#if QT_CONFIG(tooltip)
        altBox->setToolTip(QString());
#endif // QT_CONFIG(tooltip)
        captureCalibrationParkMount->setText(tr2i18n("Park Mount", nullptr));
        captureCalibrationParkDome->setText(tr2i18n("Park Dome", nullptr));
        groupBox_2->setTitle(tr2i18n("Flat Duration", nullptr));
#if QT_CONFIG(tooltip)
        captureCalibrationDurationManual->setToolTip(tr2i18n("Use the frame exposure value", nullptr));
#endif // QT_CONFIG(tooltip)
        captureCalibrationDurationManual->setText(tr2i18n("Manual", "manual flat field ADU"));
#if QT_CONFIG(tooltip)
        captureCalibrationUseADU->setToolTip(tr2i18n("Calculate optimal exposure time given the required ADU. If a controllable device is selected, calculate optimal brightness.", nullptr));
#endif // QT_CONFIG(tooltip)
        captureCalibrationUseADU->setText(tr2i18n("ADU", nullptr));
#if QT_CONFIG(tooltip)
        captureCalibrationADUValue->setToolTip(tr2i18n("Calculate optimal exposure time given the required ADU. If a controllable device is selected, calculate optimal brightness.", nullptr));
#endif // QT_CONFIG(tooltip)
#if QT_CONFIG(tooltip)
        label_3->setToolTip(tr2i18n("<html><head/><body><p>Accept ADU values that fall within this range around the desired ADU target. For example, if the ADU value was set to 10000 and the tolerance was set to 100, then frames with ADU values f 9900 and 10100 shall be accepted.</p></body></html>", nullptr));
#endif // QT_CONFIG(tooltip)
        label_3->setText(tr2i18n("Tolerance:", nullptr));
#if QT_CONFIG(tooltip)
        captureCalibrationADUTolerance->setToolTip(tr2i18n("<html><head/><body><p>Accept ADU values that fall within this range around the desired ADU target. For example, if the ADU value was set to 10000 and the tolerance was set to 100, then frames with ADU values f 9900 and 10100 shall be accepted.</p></body></html>", nullptr));
#endif // QT_CONFIG(tooltip)
#if QT_CONFIG(tooltip)
        captureCalibrationSkyFlats->setToolTip(tr2i18n("When shooting flats on sky that can change intensity. Will use simpler exposure calculation.", nullptr));
#endif // QT_CONFIG(tooltip)
        captureCalibrationSkyFlats->setText(tr2i18n("Sky flats", nullptr));
    } // retranslateUi

};

namespace Ui {
    class Calibration: public Ui_Calibration {};
} // namespace Ui

QT_END_NAMESPACE

#endif // CALIBRATIONOPTIONS_H

