/********************************************************************************
** Form generated from reading UI file 'opshipsdisplay.ui'
**
** Created by: Qt User Interface Compiler version 6.11.1
**
** WARNING! All changes made in this file will be lost when recompiling UI file!
********************************************************************************/

#ifndef UI_OPSHIPSDISPLAY_H
#define UI_OPSHIPSDISPLAY_H

#include <QtCore/QVariant>
#include <QtWidgets/QApplication>
#include <QtWidgets/QCheckBox>
#include <QtWidgets/QSpacerItem>
#include <QtWidgets/QVBoxLayout>
#include <QtWidgets/QWidget>
#include <klocalizedstring.h>

QT_BEGIN_NAMESPACE

class Ui_OpsHIPSDisplay
{
public:
    QVBoxLayout *verticalLayout;
    QCheckBox *kcfg_HIPSShowGrid;
    QCheckBox *kcfg_HIPSPanning;
    QCheckBox *kcfg_HIPSBiLinearInterpolation;
    QSpacerItem *verticalSpacer;

    void setupUi(QWidget *OpsHIPSDisplay)
    {
        if (OpsHIPSDisplay->objectName().isEmpty())
            OpsHIPSDisplay->setObjectName("OpsHIPSDisplay");
        OpsHIPSDisplay->resize(134, 58);
        verticalLayout = new QVBoxLayout(OpsHIPSDisplay);
        verticalLayout->setObjectName("verticalLayout");
        kcfg_HIPSShowGrid = new QCheckBox(OpsHIPSDisplay);
        kcfg_HIPSShowGrid->setObjectName("kcfg_HIPSShowGrid");

        verticalLayout->addWidget(kcfg_HIPSShowGrid);

        kcfg_HIPSPanning = new QCheckBox(OpsHIPSDisplay);
        kcfg_HIPSPanning->setObjectName("kcfg_HIPSPanning");

        verticalLayout->addWidget(kcfg_HIPSPanning);

        kcfg_HIPSBiLinearInterpolation = new QCheckBox(OpsHIPSDisplay);
        kcfg_HIPSBiLinearInterpolation->setObjectName("kcfg_HIPSBiLinearInterpolation");

        verticalLayout->addWidget(kcfg_HIPSBiLinearInterpolation);

        verticalSpacer = new QSpacerItem(20, 2, QSizePolicy::Policy::Minimum, QSizePolicy::Policy::Expanding);

        verticalLayout->addItem(verticalSpacer);


        retranslateUi(OpsHIPSDisplay);

        QMetaObject::connectSlotsByName(OpsHIPSDisplay);
    } // setupUi

    void retranslateUi(QWidget *OpsHIPSDisplay)
    {
        kcfg_HIPSShowGrid->setText(tr2i18n("Show HiPS grid", nullptr));
        kcfg_HIPSPanning->setText(tr2i18n("Show HiPS While Panning", nullptr));
        kcfg_HIPSBiLinearInterpolation->setText(tr2i18n("Linear interpolation", nullptr));
        (void)OpsHIPSDisplay;
    } // retranslateUi

};

namespace Ui {
    class OpsHIPSDisplay: public Ui_OpsHIPSDisplay {};
} // namespace Ui

QT_END_NAMESPACE

#endif // OPSHIPSDISPLAY_H

