/********************************************************************************
** Form generated from reading UI file 'planetviewer.ui'
**
** Created by: Qt User Interface Compiler version 6.11.1
**
** WARNING! All changes made in this file will be lost when recompiling UI file!
********************************************************************************/

#ifndef UI_PLANETVIEWER_H
#define UI_PLANETVIEWER_H

#include <QtCore/QVariant>
#include <QtWidgets/QApplication>
#include <QtWidgets/QDateEdit>
#include <QtWidgets/QHBoxLayout>
#include <QtWidgets/QPushButton>
#include <QtWidgets/QSpacerItem>
#include <QtWidgets/QVBoxLayout>
#include <QtWidgets/QWidget>
#include <klocalizedstring.h>
#include "pvplotwidget.h"
#include "widgets/timestepbox.h"

QT_BEGIN_NAMESPACE

class Ui_PlanetViewer
{
public:
    QVBoxLayout *vboxLayout;
    PVPlotWidget *map;
    QHBoxLayout *hboxLayout;
    QPushButton *RunButton;
    TimeStepBox *TimeStep;
    QSpacerItem *spacerItem;
    QDateEdit *DateBox;
    QPushButton *TodayButton;
    QSpacerItem *spacerItem1;
    QPushButton *ZoomInButton;
    QPushButton *ZoomOutButton;

    void setupUi(QWidget *PlanetViewer)
    {
        if (PlanetViewer->objectName().isEmpty())
            PlanetViewer->setObjectName("PlanetViewer");
        PlanetViewer->resize(490, 475);
        vboxLayout = new QVBoxLayout(PlanetViewer);
        vboxLayout->setSpacing(6);
        vboxLayout->setObjectName("vboxLayout");
        vboxLayout->setContentsMargins(9, 9, 9, 9);
        map = new PVPlotWidget(PlanetViewer);
        map->setObjectName("map");
        QSizePolicy sizePolicy(QSizePolicy::Policy::Preferred, QSizePolicy::Policy::Expanding);
        sizePolicy.setHorizontalStretch(0);
        sizePolicy.setVerticalStretch(0);
        sizePolicy.setHeightForWidth(map->sizePolicy().hasHeightForWidth());
        map->setSizePolicy(sizePolicy);
        map->setFrameShape(QFrame::StyledPanel);
        map->setFrameShadow(QFrame::Raised);

        vboxLayout->addWidget(map);

        hboxLayout = new QHBoxLayout();
        hboxLayout->setSpacing(6);
        hboxLayout->setObjectName("hboxLayout");
        hboxLayout->setContentsMargins(0, 0, 0, 0);
        RunButton = new QPushButton(PlanetViewer);
        RunButton->setObjectName("RunButton");
        QSizePolicy sizePolicy1(QSizePolicy::Policy::Fixed, QSizePolicy::Policy::Fixed);
        sizePolicy1.setHorizontalStretch(0);
        sizePolicy1.setVerticalStretch(0);
        sizePolicy1.setHeightForWidth(RunButton->sizePolicy().hasHeightForWidth());
        RunButton->setSizePolicy(sizePolicy1);
        RunButton->setMaximumSize(QSize(34, 34));

        hboxLayout->addWidget(RunButton);

        TimeStep = new TimeStepBox(PlanetViewer);
        TimeStep->setObjectName("TimeStep");

        hboxLayout->addWidget(TimeStep);

        spacerItem = new QSpacerItem(140, 34, QSizePolicy::Policy::Expanding, QSizePolicy::Policy::Minimum);

        hboxLayout->addItem(spacerItem);

        DateBox = new QDateEdit(PlanetViewer);
        DateBox->setObjectName("DateBox");

        hboxLayout->addWidget(DateBox);

        TodayButton = new QPushButton(PlanetViewer);
        TodayButton->setObjectName("TodayButton");

        hboxLayout->addWidget(TodayButton);

        spacerItem1 = new QSpacerItem(140, 34, QSizePolicy::Policy::Expanding, QSizePolicy::Policy::Minimum);

        hboxLayout->addItem(spacerItem1);

        ZoomInButton = new QPushButton(PlanetViewer);
        ZoomInButton->setObjectName("ZoomInButton");
        sizePolicy1.setHeightForWidth(ZoomInButton->sizePolicy().hasHeightForWidth());
        ZoomInButton->setSizePolicy(sizePolicy1);
        ZoomInButton->setMaximumSize(QSize(34, 34));

        hboxLayout->addWidget(ZoomInButton);

        ZoomOutButton = new QPushButton(PlanetViewer);
        ZoomOutButton->setObjectName("ZoomOutButton");
        sizePolicy1.setHeightForWidth(ZoomOutButton->sizePolicy().hasHeightForWidth());
        ZoomOutButton->setSizePolicy(sizePolicy1);
        ZoomOutButton->setMaximumSize(QSize(34, 34));

        hboxLayout->addWidget(ZoomOutButton);


        vboxLayout->addLayout(hboxLayout);


        retranslateUi(PlanetViewer);

        QMetaObject::connectSlotsByName(PlanetViewer);
    } // setupUi

    void retranslateUi(QWidget *PlanetViewer)
    {
        RunButton->setText(QString());
        DateBox->setDisplayFormat(tr2i18n("dd/MM/yyyy", nullptr));
        TodayButton->setText(tr2i18n("Today", nullptr));
        ZoomInButton->setText(QString());
        ZoomOutButton->setText(QString());
        (void)PlanetViewer;
    } // retranslateUi

};

namespace Ui {
    class PlanetViewer: public Ui_PlanetViewer {};
} // namespace Ui

QT_END_NAMESPACE

#endif // PLANETVIEWER_H

