/****************************************************************************
** Meta object code from reading C++ file 'queueexecutor.h'
**
** Created by: The Qt Meta Object Compiler version 69 (Qt 6.11.1)
**
** WARNING! All changes made in this file will be lost!
*****************************************************************************/

#include "../../../../kstars-3.8.4.1/kstars/ekos/scheduler/taskqueue/queue/queueexecutor.h"
#include <QtCore/qmetatype.h>

#include <QtCore/qtmochelpers.h>

#include <memory>


#include <QtCore/qxptype_traits.h>
#if !defined(Q_MOC_OUTPUT_REVISION)
#error "The header file 'queueexecutor.h' doesn't include <QObject>."
#elif Q_MOC_OUTPUT_REVISION != 69
#error "This file was generated using the moc from 6.11.1. It"
#error "cannot be used with the include files from this version of Qt."
#error "(The moc has changed too much.)"
#endif

#ifndef Q_CONSTINIT
#define Q_CONSTINIT
#endif

QT_WARNING_PUSH
QT_WARNING_DISABLE_DEPRECATED
QT_WARNING_DISABLE_GCC("-Wuseless-cast")
namespace {
struct qt_meta_tag_ZN4Ekos13QueueExecutorE_t {};
} // unnamed namespace

template <> constexpr inline auto Ekos::QueueExecutor::qt_create_metaobjectdata<qt_meta_tag_ZN4Ekos13QueueExecutorE_t>()
{
    namespace QMC = QtMocConstants;
    QtMocHelpers::StringRefStorage qt_stringData {
        "Ekos::QueueExecutor",
        "started",
        "",
        "paused",
        "resumed",
        "stopped",
        "aborted",
        "completed",
        "itemStarted",
        "QueueItem*",
        "item",
        "itemCompleted",
        "itemFailed",
        "error",
        "actionStarted",
        "TaskAction*",
        "action",
        "actionCompleted",
        "actionFailed",
        "progress",
        "percent",
        "message",
        "newLog",
        "executeNext",
        "onItemStatusChanged",
        "QueueItem::Status",
        "status",
        "onActionStatusChanged",
        "TaskAction::Status",
        "onActionProgress"
    };

    QtMocHelpers::UintData qt_methods {
        // Signal 'started'
        QtMocHelpers::SignalData<void()>(1, 2, QMC::AccessPublic, QMetaType::Void),
        // Signal 'paused'
        QtMocHelpers::SignalData<void()>(3, 2, QMC::AccessPublic, QMetaType::Void),
        // Signal 'resumed'
        QtMocHelpers::SignalData<void()>(4, 2, QMC::AccessPublic, QMetaType::Void),
        // Signal 'stopped'
        QtMocHelpers::SignalData<void()>(5, 2, QMC::AccessPublic, QMetaType::Void),
        // Signal 'aborted'
        QtMocHelpers::SignalData<void()>(6, 2, QMC::AccessPublic, QMetaType::Void),
        // Signal 'completed'
        QtMocHelpers::SignalData<void()>(7, 2, QMC::AccessPublic, QMetaType::Void),
        // Signal 'itemStarted'
        QtMocHelpers::SignalData<void(QueueItem *)>(8, 2, QMC::AccessPublic, QMetaType::Void, {{
            { 0x80000000 | 9, 10 },
        }}),
        // Signal 'itemCompleted'
        QtMocHelpers::SignalData<void(QueueItem *)>(11, 2, QMC::AccessPublic, QMetaType::Void, {{
            { 0x80000000 | 9, 10 },
        }}),
        // Signal 'itemFailed'
        QtMocHelpers::SignalData<void(QueueItem *, const QString &)>(12, 2, QMC::AccessPublic, QMetaType::Void, {{
            { 0x80000000 | 9, 10 }, { QMetaType::QString, 13 },
        }}),
        // Signal 'actionStarted'
        QtMocHelpers::SignalData<void(TaskAction *)>(14, 2, QMC::AccessPublic, QMetaType::Void, {{
            { 0x80000000 | 15, 16 },
        }}),
        // Signal 'actionCompleted'
        QtMocHelpers::SignalData<void(TaskAction *)>(17, 2, QMC::AccessPublic, QMetaType::Void, {{
            { 0x80000000 | 15, 16 },
        }}),
        // Signal 'actionFailed'
        QtMocHelpers::SignalData<void(TaskAction *, const QString &)>(18, 2, QMC::AccessPublic, QMetaType::Void, {{
            { 0x80000000 | 15, 16 }, { QMetaType::QString, 13 },
        }}),
        // Signal 'progress'
        QtMocHelpers::SignalData<void(int, const QString &)>(19, 2, QMC::AccessPublic, QMetaType::Void, {{
            { QMetaType::Int, 20 }, { QMetaType::QString, 21 },
        }}),
        // Signal 'newLog'
        QtMocHelpers::SignalData<void(const QString &)>(22, 2, QMC::AccessPublic, QMetaType::Void, {{
            { QMetaType::QString, 21 },
        }}),
        // Slot 'executeNext'
        QtMocHelpers::SlotData<void()>(23, 2, QMC::AccessPrivate, QMetaType::Void),
        // Slot 'onItemStatusChanged'
        QtMocHelpers::SlotData<void(QueueItem::Status)>(24, 2, QMC::AccessPrivate, QMetaType::Void, {{
            { 0x80000000 | 25, 26 },
        }}),
        // Slot 'onActionStatusChanged'
        QtMocHelpers::SlotData<void(TaskAction::Status)>(27, 2, QMC::AccessPrivate, QMetaType::Void, {{
            { 0x80000000 | 28, 26 },
        }}),
        // Slot 'onActionProgress'
        QtMocHelpers::SlotData<void(const QString &)>(29, 2, QMC::AccessPrivate, QMetaType::Void, {{
            { QMetaType::QString, 21 },
        }}),
    };
    QtMocHelpers::UintData qt_properties {
    };
    QtMocHelpers::UintData qt_enums {
    };
    return QtMocHelpers::metaObjectData<QueueExecutor, qt_meta_tag_ZN4Ekos13QueueExecutorE_t>(QMC::MetaObjectFlag{}, qt_stringData,
            qt_methods, qt_properties, qt_enums);
}
Q_CONSTINIT const QMetaObject Ekos::QueueExecutor::staticMetaObject = { {
    QMetaObject::SuperData::link<QObject::staticMetaObject>(),
    qt_staticMetaObjectStaticContent<qt_meta_tag_ZN4Ekos13QueueExecutorE_t>.stringdata,
    qt_staticMetaObjectStaticContent<qt_meta_tag_ZN4Ekos13QueueExecutorE_t>.data,
    qt_static_metacall,
    nullptr,
    qt_staticMetaObjectRelocatingContent<qt_meta_tag_ZN4Ekos13QueueExecutorE_t>.metaTypes,
    nullptr
} };

void Ekos::QueueExecutor::qt_static_metacall(QObject *_o, QMetaObject::Call _c, int _id, void **_a)
{
    auto *_t = static_cast<QueueExecutor *>(_o);
    if (_c == QMetaObject::InvokeMetaMethod) {
        switch (_id) {
        case 0: _t->started(); break;
        case 1: _t->paused(); break;
        case 2: _t->resumed(); break;
        case 3: _t->stopped(); break;
        case 4: _t->aborted(); break;
        case 5: _t->completed(); break;
        case 6: _t->itemStarted((*reinterpret_cast<std::add_pointer_t<QueueItem*>>(_a[1]))); break;
        case 7: _t->itemCompleted((*reinterpret_cast<std::add_pointer_t<QueueItem*>>(_a[1]))); break;
        case 8: _t->itemFailed((*reinterpret_cast<std::add_pointer_t<QueueItem*>>(_a[1])),(*reinterpret_cast<std::add_pointer_t<QString>>(_a[2]))); break;
        case 9: _t->actionStarted((*reinterpret_cast<std::add_pointer_t<TaskAction*>>(_a[1]))); break;
        case 10: _t->actionCompleted((*reinterpret_cast<std::add_pointer_t<TaskAction*>>(_a[1]))); break;
        case 11: _t->actionFailed((*reinterpret_cast<std::add_pointer_t<TaskAction*>>(_a[1])),(*reinterpret_cast<std::add_pointer_t<QString>>(_a[2]))); break;
        case 12: _t->progress((*reinterpret_cast<std::add_pointer_t<int>>(_a[1])),(*reinterpret_cast<std::add_pointer_t<QString>>(_a[2]))); break;
        case 13: _t->newLog((*reinterpret_cast<std::add_pointer_t<QString>>(_a[1]))); break;
        case 14: _t->executeNext(); break;
        case 15: _t->onItemStatusChanged((*reinterpret_cast<std::add_pointer_t<QueueItem::Status>>(_a[1]))); break;
        case 16: _t->onActionStatusChanged((*reinterpret_cast<std::add_pointer_t<TaskAction::Status>>(_a[1]))); break;
        case 17: _t->onActionProgress((*reinterpret_cast<std::add_pointer_t<QString>>(_a[1]))); break;
        default: ;
        }
    }
    if (_c == QMetaObject::RegisterMethodArgumentMetaType) {
        switch (_id) {
        default: *reinterpret_cast<QMetaType *>(_a[0]) = QMetaType(); break;
        case 6:
            switch (*reinterpret_cast<int*>(_a[1])) {
            default: *reinterpret_cast<QMetaType *>(_a[0]) = QMetaType(); break;
            case 0:
                *reinterpret_cast<QMetaType *>(_a[0]) = QMetaType::fromType< QueueItem* >(); break;
            }
            break;
        case 7:
            switch (*reinterpret_cast<int*>(_a[1])) {
            default: *reinterpret_cast<QMetaType *>(_a[0]) = QMetaType(); break;
            case 0:
                *reinterpret_cast<QMetaType *>(_a[0]) = QMetaType::fromType< QueueItem* >(); break;
            }
            break;
        case 8:
            switch (*reinterpret_cast<int*>(_a[1])) {
            default: *reinterpret_cast<QMetaType *>(_a[0]) = QMetaType(); break;
            case 0:
                *reinterpret_cast<QMetaType *>(_a[0]) = QMetaType::fromType< QueueItem* >(); break;
            }
            break;
        case 9:
            switch (*reinterpret_cast<int*>(_a[1])) {
            default: *reinterpret_cast<QMetaType *>(_a[0]) = QMetaType(); break;
            case 0:
                *reinterpret_cast<QMetaType *>(_a[0]) = QMetaType::fromType< TaskAction* >(); break;
            }
            break;
        case 10:
            switch (*reinterpret_cast<int*>(_a[1])) {
            default: *reinterpret_cast<QMetaType *>(_a[0]) = QMetaType(); break;
            case 0:
                *reinterpret_cast<QMetaType *>(_a[0]) = QMetaType::fromType< TaskAction* >(); break;
            }
            break;
        case 11:
            switch (*reinterpret_cast<int*>(_a[1])) {
            default: *reinterpret_cast<QMetaType *>(_a[0]) = QMetaType(); break;
            case 0:
                *reinterpret_cast<QMetaType *>(_a[0]) = QMetaType::fromType< TaskAction* >(); break;
            }
            break;
        }
    }
    if (_c == QMetaObject::IndexOfMethod) {
        if (QtMocHelpers::indexOfMethod<void (QueueExecutor::*)()>(_a, &QueueExecutor::started, 0))
            return;
        if (QtMocHelpers::indexOfMethod<void (QueueExecutor::*)()>(_a, &QueueExecutor::paused, 1))
            return;
        if (QtMocHelpers::indexOfMethod<void (QueueExecutor::*)()>(_a, &QueueExecutor::resumed, 2))
            return;
        if (QtMocHelpers::indexOfMethod<void (QueueExecutor::*)()>(_a, &QueueExecutor::stopped, 3))
            return;
        if (QtMocHelpers::indexOfMethod<void (QueueExecutor::*)()>(_a, &QueueExecutor::aborted, 4))
            return;
        if (QtMocHelpers::indexOfMethod<void (QueueExecutor::*)()>(_a, &QueueExecutor::completed, 5))
            return;
        if (QtMocHelpers::indexOfMethod<void (QueueExecutor::*)(QueueItem * )>(_a, &QueueExecutor::itemStarted, 6))
            return;
        if (QtMocHelpers::indexOfMethod<void (QueueExecutor::*)(QueueItem * )>(_a, &QueueExecutor::itemCompleted, 7))
            return;
        if (QtMocHelpers::indexOfMethod<void (QueueExecutor::*)(QueueItem * , const QString & )>(_a, &QueueExecutor::itemFailed, 8))
            return;
        if (QtMocHelpers::indexOfMethod<void (QueueExecutor::*)(TaskAction * )>(_a, &QueueExecutor::actionStarted, 9))
            return;
        if (QtMocHelpers::indexOfMethod<void (QueueExecutor::*)(TaskAction * )>(_a, &QueueExecutor::actionCompleted, 10))
            return;
        if (QtMocHelpers::indexOfMethod<void (QueueExecutor::*)(TaskAction * , const QString & )>(_a, &QueueExecutor::actionFailed, 11))
            return;
        if (QtMocHelpers::indexOfMethod<void (QueueExecutor::*)(int , const QString & )>(_a, &QueueExecutor::progress, 12))
            return;
        if (QtMocHelpers::indexOfMethod<void (QueueExecutor::*)(const QString & )>(_a, &QueueExecutor::newLog, 13))
            return;
    }
}

const QMetaObject *Ekos::QueueExecutor::metaObject() const
{
    return QObject::d_ptr->metaObject ? QObject::d_ptr->dynamicMetaObject() : &staticMetaObject;
}

void *Ekos::QueueExecutor::qt_metacast(const char *_clname)
{
    if (!_clname) return nullptr;
    if (!strcmp(_clname, qt_staticMetaObjectStaticContent<qt_meta_tag_ZN4Ekos13QueueExecutorE_t>.strings))
        return static_cast<void*>(this);
    return QObject::qt_metacast(_clname);
}

int Ekos::QueueExecutor::qt_metacall(QMetaObject::Call _c, int _id, void **_a)
{
    _id = QObject::qt_metacall(_c, _id, _a);
    if (_id < 0)
        return _id;
    if (_c == QMetaObject::InvokeMetaMethod) {
        if (_id < 18)
            qt_static_metacall(this, _c, _id, _a);
        _id -= 18;
    }
    if (_c == QMetaObject::RegisterMethodArgumentMetaType) {
        if (_id < 18)
            qt_static_metacall(this, _c, _id, _a);
        _id -= 18;
    }
    return _id;
}

// SIGNAL 0
void Ekos::QueueExecutor::started()
{
    QMetaObject::activate(this, &staticMetaObject, 0, nullptr);
}

// SIGNAL 1
void Ekos::QueueExecutor::paused()
{
    QMetaObject::activate(this, &staticMetaObject, 1, nullptr);
}

// SIGNAL 2
void Ekos::QueueExecutor::resumed()
{
    QMetaObject::activate(this, &staticMetaObject, 2, nullptr);
}

// SIGNAL 3
void Ekos::QueueExecutor::stopped()
{
    QMetaObject::activate(this, &staticMetaObject, 3, nullptr);
}

// SIGNAL 4
void Ekos::QueueExecutor::aborted()
{
    QMetaObject::activate(this, &staticMetaObject, 4, nullptr);
}

// SIGNAL 5
void Ekos::QueueExecutor::completed()
{
    QMetaObject::activate(this, &staticMetaObject, 5, nullptr);
}

// SIGNAL 6
void Ekos::QueueExecutor::itemStarted(QueueItem * _t1)
{
    QMetaObject::activate<void>(this, &staticMetaObject, 6, nullptr, _t1);
}

// SIGNAL 7
void Ekos::QueueExecutor::itemCompleted(QueueItem * _t1)
{
    QMetaObject::activate<void>(this, &staticMetaObject, 7, nullptr, _t1);
}

// SIGNAL 8
void Ekos::QueueExecutor::itemFailed(QueueItem * _t1, const QString & _t2)
{
    QMetaObject::activate<void>(this, &staticMetaObject, 8, nullptr, _t1, _t2);
}

// SIGNAL 9
void Ekos::QueueExecutor::actionStarted(TaskAction * _t1)
{
    QMetaObject::activate<void>(this, &staticMetaObject, 9, nullptr, _t1);
}

// SIGNAL 10
void Ekos::QueueExecutor::actionCompleted(TaskAction * _t1)
{
    QMetaObject::activate<void>(this, &staticMetaObject, 10, nullptr, _t1);
}

// SIGNAL 11
void Ekos::QueueExecutor::actionFailed(TaskAction * _t1, const QString & _t2)
{
    QMetaObject::activate<void>(this, &staticMetaObject, 11, nullptr, _t1, _t2);
}

// SIGNAL 12
void Ekos::QueueExecutor::progress(int _t1, const QString & _t2)
{
    QMetaObject::activate<void>(this, &staticMetaObject, 12, nullptr, _t1, _t2);
}

// SIGNAL 13
void Ekos::QueueExecutor::newLog(const QString & _t1)
{
    QMetaObject::activate<void>(this, &staticMetaObject, 13, nullptr, _t1);
}
QT_WARNING_POP
