/********************************************************************************
** Form generated from reading UI file 'focusadvisor.ui'
**
** Created by: Qt User Interface Compiler version 6.11.1
**
** WARNING! All changes made in this file will be lost when recompiling UI file!
********************************************************************************/

#ifndef UI_FOCUSADVISOR_H
#define UI_FOCUSADVISOR_H

#include <QtCore/QVariant>
#include <QtWidgets/QAbstractButton>
#include <QtWidgets/QApplication>
#include <QtWidgets/QCheckBox>
#include <QtWidgets/QDialog>
#include <QtWidgets/QDialogButtonBox>
#include <QtWidgets/QGridLayout>
#include <QtWidgets/QGroupBox>
#include <QtWidgets/QHeaderView>
#include <QtWidgets/QLabel>
#include <QtWidgets/QSpacerItem>
#include <QtWidgets/QTableWidget>
#include <QtWidgets/QVBoxLayout>
#include <klocalizedstring.h>

QT_BEGIN_NAMESPACE

class Ui_focusAdvisorDialog
{
public:
    QVBoxLayout *verticalLayout;
    QGroupBox *focusAdvGroupBox;
    QGridLayout *gridLayout_2;
    QCheckBox *focusAdvUpdateParams;
    QCheckBox *focusAdvFindStars;
    QLabel *focusAdvUpdateParamsLabel;
    QLabel *focusAdvFindStarsLabel;
    QCheckBox *focusAdvCoarseAdj;
    QCheckBox *focusAdvFineAdj;
    QLabel *focusAdvCoarseAdjLabel;
    QLabel *focusAdvFineAdjLabel;
    QTableWidget *focusAdvTable;
    QDialogButtonBox *focusAdvButtonBox;
    QSpacerItem *verticalSpacer;

    void setupUi(QDialog *focusAdvisorDialog)
    {
        if (focusAdvisorDialog->objectName().isEmpty())
            focusAdvisorDialog->setObjectName("focusAdvisorDialog");
        focusAdvisorDialog->resize(457, 298);
        verticalLayout = new QVBoxLayout(focusAdvisorDialog);
        verticalLayout->setObjectName("verticalLayout");
        focusAdvGroupBox = new QGroupBox(focusAdvisorDialog);
        focusAdvGroupBox->setObjectName("focusAdvGroupBox");
        focusAdvGroupBox->setFlat(true);
        gridLayout_2 = new QGridLayout(focusAdvGroupBox);
        gridLayout_2->setObjectName("gridLayout_2");
        gridLayout_2->setContentsMargins(3, 3, 3, 3);
        focusAdvUpdateParams = new QCheckBox(focusAdvGroupBox);
        focusAdvUpdateParams->setObjectName("focusAdvUpdateParams");
        QSizePolicy sizePolicy(QSizePolicy::Policy::Preferred, QSizePolicy::Policy::Fixed);
        sizePolicy.setHorizontalStretch(0);
        sizePolicy.setVerticalStretch(0);
        sizePolicy.setHeightForWidth(focusAdvUpdateParams->sizePolicy().hasHeightForWidth());
        focusAdvUpdateParams->setSizePolicy(sizePolicy);
        focusAdvUpdateParams->setChecked(true);

        gridLayout_2->addWidget(focusAdvUpdateParams, 0, 3, 1, 1);

        focusAdvFindStars = new QCheckBox(focusAdvGroupBox);
        focusAdvFindStars->setObjectName("focusAdvFindStars");
        sizePolicy.setHeightForWidth(focusAdvFindStars->sizePolicy().hasHeightForWidth());
        focusAdvFindStars->setSizePolicy(sizePolicy);
        focusAdvFindStars->setChecked(true);

        gridLayout_2->addWidget(focusAdvFindStars, 1, 3, 1, 1);

        focusAdvUpdateParamsLabel = new QLabel(focusAdvGroupBox);
        focusAdvUpdateParamsLabel->setObjectName("focusAdvUpdateParamsLabel");
        focusAdvUpdateParamsLabel->setEnabled(false);

        gridLayout_2->addWidget(focusAdvUpdateParamsLabel, 0, 4, 1, 1);

        focusAdvFindStarsLabel = new QLabel(focusAdvGroupBox);
        focusAdvFindStarsLabel->setObjectName("focusAdvFindStarsLabel");
        focusAdvFindStarsLabel->setEnabled(true);

        gridLayout_2->addWidget(focusAdvFindStarsLabel, 1, 4, 1, 1);

        focusAdvCoarseAdj = new QCheckBox(focusAdvGroupBox);
        focusAdvCoarseAdj->setObjectName("focusAdvCoarseAdj");
        sizePolicy.setHeightForWidth(focusAdvCoarseAdj->sizePolicy().hasHeightForWidth());
        focusAdvCoarseAdj->setSizePolicy(sizePolicy);
        focusAdvCoarseAdj->setChecked(true);

        gridLayout_2->addWidget(focusAdvCoarseAdj, 3, 3, 1, 1);

        focusAdvFineAdj = new QCheckBox(focusAdvGroupBox);
        focusAdvFineAdj->setObjectName("focusAdvFineAdj");
        sizePolicy.setHeightForWidth(focusAdvFineAdj->sizePolicy().hasHeightForWidth());
        focusAdvFineAdj->setSizePolicy(sizePolicy);
        focusAdvFineAdj->setChecked(true);

        gridLayout_2->addWidget(focusAdvFineAdj, 4, 3, 1, 1);

        focusAdvCoarseAdjLabel = new QLabel(focusAdvGroupBox);
        focusAdvCoarseAdjLabel->setObjectName("focusAdvCoarseAdjLabel");

        gridLayout_2->addWidget(focusAdvCoarseAdjLabel, 3, 4, 1, 1);

        focusAdvFineAdjLabel = new QLabel(focusAdvGroupBox);
        focusAdvFineAdjLabel->setObjectName("focusAdvFineAdjLabel");

        gridLayout_2->addWidget(focusAdvFineAdjLabel, 4, 4, 1, 1);


        verticalLayout->addWidget(focusAdvGroupBox);

        focusAdvTable = new QTableWidget(focusAdvisorDialog);
        focusAdvTable->setObjectName("focusAdvTable");
        focusAdvTable->setEnabled(true);
        QSizePolicy sizePolicy1(QSizePolicy::Policy::Preferred, QSizePolicy::Policy::Preferred);
        sizePolicy1.setHorizontalStretch(0);
        sizePolicy1.setVerticalStretch(0);
        sizePolicy1.setHeightForWidth(focusAdvTable->sizePolicy().hasHeightForWidth());
        focusAdvTable->setSizePolicy(sizePolicy1);
        focusAdvTable->setMinimumSize(QSize(0, 0));
        focusAdvTable->setEditTriggers(QAbstractItemView::NoEditTriggers);
        focusAdvTable->setAlternatingRowColors(true);
        focusAdvTable->setSelectionMode(QAbstractItemView::NoSelection);
        focusAdvTable->setRowCount(0);
        focusAdvTable->setColumnCount(0);
        focusAdvTable->horizontalHeader()->setCascadingSectionResizes(false);
        focusAdvTable->verticalHeader()->setVisible(false);

        verticalLayout->addWidget(focusAdvTable);

        focusAdvButtonBox = new QDialogButtonBox(focusAdvisorDialog);
        focusAdvButtonBox->setObjectName("focusAdvButtonBox");
        sizePolicy.setHeightForWidth(focusAdvButtonBox->sizePolicy().hasHeightForWidth());
        focusAdvButtonBox->setSizePolicy(sizePolicy);
        focusAdvButtonBox->setOrientation(Qt::Horizontal);
        focusAdvButtonBox->setStandardButtons(QDialogButtonBox::Close);

        verticalLayout->addWidget(focusAdvButtonBox);

        verticalSpacer = new QSpacerItem(20, 40, QSizePolicy::Policy::Minimum, QSizePolicy::Policy::Expanding);

        verticalLayout->addItem(verticalSpacer);


        retranslateUi(focusAdvisorDialog);
        QObject::connect(focusAdvButtonBox, &QDialogButtonBox::accepted, focusAdvisorDialog, qOverload<>(&QDialog::accept));
        QObject::connect(focusAdvButtonBox, &QDialogButtonBox::rejected, focusAdvisorDialog, qOverload<>(&QDialog::reject));

        QMetaObject::connectSlotsByName(focusAdvisorDialog);
    } // setupUi

    void retranslateUi(QDialog *focusAdvisorDialog)
    {
        focusAdvisorDialog->setWindowTitle(tr2i18n("Focus Advisor", nullptr));
        focusAdvGroupBox->setTitle(QString());
#if QT_CONFIG(tooltip)
        focusAdvUpdateParams->setToolTip(tr2i18n("Check to have Focus Advisor update Focus parameters. Click Help to view the proposed changes.", nullptr));
#endif // QT_CONFIG(tooltip)
        focusAdvUpdateParams->setText(tr2i18n("Update Parameters", nullptr));
#if QT_CONFIG(tooltip)
        focusAdvFindStars->setToolTip(tr2i18n("Check to have Focus Advisor search for stars. If you are close enough to Focus to see stars in the Focus frame then this step is not necessary.", nullptr));
#endif // QT_CONFIG(tooltip)
        focusAdvFindStars->setText(tr2i18n("Find Stars", nullptr));
        focusAdvUpdateParamsLabel->setText(QString());
        focusAdvFindStarsLabel->setText(QString());
#if QT_CONFIG(tooltip)
        focusAdvCoarseAdj->setToolTip(tr2i18n("Check to have Focus Advisor find coarse focus. This will find an approximate focus position good enough to run Autofocus.", nullptr));
#endif // QT_CONFIG(tooltip)
        focusAdvCoarseAdj->setText(tr2i18n("Coarse Adjustment (without Autofocus)", nullptr));
#if QT_CONFIG(tooltip)
        focusAdvFineAdj->setToolTip(tr2i18n("Check to have Focus Advisor run Autofocus to make fine adjustments to focus parameters.", nullptr));
#endif // QT_CONFIG(tooltip)
        focusAdvFineAdj->setText(tr2i18n("Fine Adjustment (using Autofocus)", nullptr));
        focusAdvCoarseAdjLabel->setText(QString());
        focusAdvFineAdjLabel->setText(QString());
#if QT_CONFIG(tooltip)
        focusAdvButtonBox->setToolTip(tr2i18n("Close Focus Advisor", nullptr));
#endif // QT_CONFIG(tooltip)
    } // retranslateUi

};

namespace Ui {
    class focusAdvisorDialog: public Ui_focusAdvisorDialog {};
} // namespace Ui

QT_END_NAMESPACE

#endif // FOCUSADVISOR_H

