/********************************************************************************
** Form generated from reading UI file 'details_data_comet.ui'
**
** Created by: Qt User Interface Compiler version 6.11.1
**
** WARNING! All changes made in this file will be lost when recompiling UI file!
********************************************************************************/

#ifndef UI_DETAILS_DATA_COMET_H
#define UI_DETAILS_DATA_COMET_H

#include <QtCore/QVariant>
#include <QtWidgets/QApplication>
#include <QtWidgets/QFormLayout>
#include <QtWidgets/QGridLayout>
#include <QtWidgets/QHBoxLayout>
#include <QtWidgets/QLabel>
#include <QtWidgets/QSpacerItem>
#include <QtWidgets/QWidget>
#include <klocalizedstring.h>

QT_BEGIN_NAMESPACE

class Ui_DetailsDataComet
{
public:
    QGridLayout *gridLayout_2;
    QHBoxLayout *horizontalLayout;
    QFormLayout *formLayout_2;
    QLabel *PerihelionLabel;
    QLabel *Perihelion;
    QLabel *OrbitIDLabel;
    QLabel *OrbitID;
    QLabel *NEOLabel;
    QLabel *NEO;
    QLabel *DiameterLabel;
    QLabel *Diameter;
    QLabel *RotationLabel;
    QLabel *Rotation;
    QSpacerItem *horizontalSpacer;
    QFormLayout *formLayout_4;
    QLabel *EarthMOIDLabel;
    QLabel *EarthMOID;
    QLabel *OrbitClassLabel;
    QLabel *OrbitClass;
    QLabel *AlbedoLabel;
    QLabel *Albedo;
    QLabel *DimensionsLabel;
    QLabel *Dimensions;
    QLabel *PeriodLabel;
    QLabel *Period;

    void setupUi(QWidget *DetailsDataComet)
    {
        if (DetailsDataComet->objectName().isEmpty())
            DetailsDataComet->setObjectName("DetailsDataComet");
        DetailsDataComet->resize(264, 105);
        gridLayout_2 = new QGridLayout(DetailsDataComet);
        gridLayout_2->setContentsMargins(0, 0, 0, 0);
        gridLayout_2->setObjectName("gridLayout_2");
        horizontalLayout = new QHBoxLayout();
        horizontalLayout->setObjectName("horizontalLayout");
        formLayout_2 = new QFormLayout();
        formLayout_2->setObjectName("formLayout_2");
        formLayout_2->setFieldGrowthPolicy(QFormLayout::ExpandingFieldsGrow);
        formLayout_2->setLabelAlignment(Qt::AlignLeading|Qt::AlignLeft|Qt::AlignVCenter);
        PerihelionLabel = new QLabel(DetailsDataComet);
        PerihelionLabel->setObjectName("PerihelionLabel");

        formLayout_2->setWidget(0, QFormLayout::ItemRole::LabelRole, PerihelionLabel);

        Perihelion = new QLabel(DetailsDataComet);
        Perihelion->setObjectName("Perihelion");
        QFont font;
        font.setFamilies({QString::fromUtf8("Monospace")});
        font.setPointSize(10);
        font.setBold(true);
        Perihelion->setFont(font);

        formLayout_2->setWidget(0, QFormLayout::ItemRole::FieldRole, Perihelion);

        OrbitIDLabel = new QLabel(DetailsDataComet);
        OrbitIDLabel->setObjectName("OrbitIDLabel");

        formLayout_2->setWidget(1, QFormLayout::ItemRole::LabelRole, OrbitIDLabel);

        OrbitID = new QLabel(DetailsDataComet);
        OrbitID->setObjectName("OrbitID");
        OrbitID->setFont(font);

        formLayout_2->setWidget(1, QFormLayout::ItemRole::FieldRole, OrbitID);

        NEOLabel = new QLabel(DetailsDataComet);
        NEOLabel->setObjectName("NEOLabel");

        formLayout_2->setWidget(2, QFormLayout::ItemRole::LabelRole, NEOLabel);

        NEO = new QLabel(DetailsDataComet);
        NEO->setObjectName("NEO");
        QFont font1;
        font1.setPointSize(10);
        font1.setBold(true);
        NEO->setFont(font1);

        formLayout_2->setWidget(2, QFormLayout::ItemRole::FieldRole, NEO);

        DiameterLabel = new QLabel(DetailsDataComet);
        DiameterLabel->setObjectName("DiameterLabel");

        formLayout_2->setWidget(3, QFormLayout::ItemRole::LabelRole, DiameterLabel);

        Diameter = new QLabel(DetailsDataComet);
        Diameter->setObjectName("Diameter");
        Diameter->setFont(font);

        formLayout_2->setWidget(3, QFormLayout::ItemRole::FieldRole, Diameter);

        RotationLabel = new QLabel(DetailsDataComet);
        RotationLabel->setObjectName("RotationLabel");

        formLayout_2->setWidget(4, QFormLayout::ItemRole::LabelRole, RotationLabel);

        Rotation = new QLabel(DetailsDataComet);
        Rotation->setObjectName("Rotation");
        Rotation->setFont(font);

        formLayout_2->setWidget(4, QFormLayout::ItemRole::FieldRole, Rotation);


        horizontalLayout->addLayout(formLayout_2);

        horizontalSpacer = new QSpacerItem(40, 20, QSizePolicy::Policy::Expanding, QSizePolicy::Policy::Minimum);

        horizontalLayout->addItem(horizontalSpacer);

        formLayout_4 = new QFormLayout();
        formLayout_4->setObjectName("formLayout_4");
        formLayout_4->setLabelAlignment(Qt::AlignLeading|Qt::AlignLeft|Qt::AlignVCenter);
        EarthMOIDLabel = new QLabel(DetailsDataComet);
        EarthMOIDLabel->setObjectName("EarthMOIDLabel");

        formLayout_4->setWidget(0, QFormLayout::ItemRole::LabelRole, EarthMOIDLabel);

        EarthMOID = new QLabel(DetailsDataComet);
        EarthMOID->setObjectName("EarthMOID");
        EarthMOID->setFont(font);

        formLayout_4->setWidget(0, QFormLayout::ItemRole::FieldRole, EarthMOID);

        OrbitClassLabel = new QLabel(DetailsDataComet);
        OrbitClassLabel->setObjectName("OrbitClassLabel");

        formLayout_4->setWidget(1, QFormLayout::ItemRole::LabelRole, OrbitClassLabel);

        OrbitClass = new QLabel(DetailsDataComet);
        OrbitClass->setObjectName("OrbitClass");
        OrbitClass->setFont(font);

        formLayout_4->setWidget(1, QFormLayout::ItemRole::FieldRole, OrbitClass);

        AlbedoLabel = new QLabel(DetailsDataComet);
        AlbedoLabel->setObjectName("AlbedoLabel");

        formLayout_4->setWidget(2, QFormLayout::ItemRole::LabelRole, AlbedoLabel);

        Albedo = new QLabel(DetailsDataComet);
        Albedo->setObjectName("Albedo");
        Albedo->setFont(font);

        formLayout_4->setWidget(2, QFormLayout::ItemRole::FieldRole, Albedo);

        DimensionsLabel = new QLabel(DetailsDataComet);
        DimensionsLabel->setObjectName("DimensionsLabel");

        formLayout_4->setWidget(3, QFormLayout::ItemRole::LabelRole, DimensionsLabel);

        Dimensions = new QLabel(DetailsDataComet);
        Dimensions->setObjectName("Dimensions");
        Dimensions->setFont(font);

        formLayout_4->setWidget(3, QFormLayout::ItemRole::FieldRole, Dimensions);

        PeriodLabel = new QLabel(DetailsDataComet);
        PeriodLabel->setObjectName("PeriodLabel");

        formLayout_4->setWidget(4, QFormLayout::ItemRole::LabelRole, PeriodLabel);

        Period = new QLabel(DetailsDataComet);
        Period->setObjectName("Period");
        Period->setFont(font);

        formLayout_4->setWidget(4, QFormLayout::ItemRole::FieldRole, Period);


        horizontalLayout->addLayout(formLayout_4);


        gridLayout_2->addLayout(horizontalLayout, 0, 0, 1, 1);


        retranslateUi(DetailsDataComet);

        QMetaObject::connectSlotsByName(DetailsDataComet);
    } // setupUi

    void retranslateUi(QWidget *DetailsDataComet)
    {
        PerihelionLabel->setText(tr2i18n("Perihelion:", nullptr));
        Perihelion->setText(tr2i18n("0.0 AU", nullptr));
        OrbitIDLabel->setText(tr2i18n("Orbit ID:", nullptr));
        OrbitID->setText(tr2i18n("Orbit ID", nullptr));
        NEOLabel->setText(tr2i18n("NEO:", nullptr));
        NEO->setText(tr2i18n("NEO", nullptr));
        DiameterLabel->setText(tr2i18n("Diameter:", nullptr));
        Diameter->setText(tr2i18n("0.0 km", nullptr));
        RotationLabel->setText(tr2i18n("Rotation period:", nullptr));
        Rotation->setText(tr2i18n("0.0 h", nullptr));
        EarthMOIDLabel->setText(tr2i18n("Earth MOID:", nullptr));
        EarthMOID->setText(tr2i18n("0.0 AU", nullptr));
        OrbitClassLabel->setText(tr2i18n("Orbit class:", nullptr));
        OrbitClass->setText(tr2i18n("Class", nullptr));
        AlbedoLabel->setText(tr2i18n("Albedo:", nullptr));
        Albedo->setText(tr2i18n("0.0", nullptr));
        DimensionsLabel->setText(tr2i18n("Dimensions:", nullptr));
        Dimensions->setText(tr2i18n("0.0 km", nullptr));
        PeriodLabel->setText(tr2i18n("Period:", nullptr));
        Period->setText(tr2i18n("0 y", nullptr));
        (void)DetailsDataComet;
    } // retranslateUi

};

namespace Ui {
    class DetailsDataComet: public Ui_DetailsDataComet {};
} // namespace Ui

QT_END_NAMESPACE

#endif // DETAILS_DATA_COMET_H

