/********************************************************************************
** Form generated from reading UI file 'opsimageoverlay.ui'
**
** Created by: Qt User Interface Compiler version 6.11.1
**
** WARNING! All changes made in this file will be lost when recompiling UI file!
********************************************************************************/

#ifndef UI_OPSIMAGEOVERLAY_H
#define UI_OPSIMAGEOVERLAY_H

#include <QtCore/QVariant>
#include <QtGui/QIcon>
#include <QtWidgets/QApplication>
#include <QtWidgets/QCheckBox>
#include <QtWidgets/QComboBox>
#include <QtWidgets/QDoubleSpinBox>
#include <QtWidgets/QGroupBox>
#include <QtWidgets/QHBoxLayout>
#include <QtWidgets/QHeaderView>
#include <QtWidgets/QLabel>
#include <QtWidgets/QPlainTextEdit>
#include <QtWidgets/QPushButton>
#include <QtWidgets/QSpacerItem>
#include <QtWidgets/QSpinBox>
#include <QtWidgets/QTableWidget>
#include <QtWidgets/QVBoxLayout>
#include <QtWidgets/QWidget>
#include <klocalizedstring.h>

QT_BEGIN_NAMESPACE

class Ui_OpsImageOverlay
{
public:
    QVBoxLayout *imageOverlayVerticalLayout_2;
    QGroupBox *ImageOverlayBox;
    QVBoxLayout *vboxLayout;
    QVBoxLayout *vboxLayout1;
    QCheckBox *kcfg_ShowImageOverlays;
    QCheckBox *kcfg_ShowSelectedImageOverlay;
    QCheckBox *kcfg_ShowImageOverlaysBelowCatalogs;
    QHBoxLayout *imageOverlayMaxDimensionLayout;
    QLabel *imageOverlayMaxDimensionLabel;
    QSpinBox *kcfg_ImageOverlayMaxDimension;
    QSpacerItem *spacerItem;
    QPushButton *imageOverlayShowDirButton;
    QPushButton *refreshB;
    QGroupBox *ImageOverlayTableBox;
    QVBoxLayout *ImageOverlayTableLayout;
    QTableWidget *imageOverlayTable;
    QHBoxLayout *imageOverlayButtonLayout;
    QPushButton *solveButton;
    QComboBox *imageOverlaySolverProfile;
    QPushButton *editAlignProfile;
    QLabel *imageOverlayScaleLabel;
    QDoubleSpinBox *kcfg_ImageOverlayDefaultScale;
    QLabel *imageOverlayTimeoutLabel;
    QSpinBox *kcfg_ImageOverlayTimeout;
    QSpacerItem *spacerItem1;
    QPlainTextEdit *imageOverlayStatus;

    void setupUi(QWidget *OpsImageOverlay)
    {
        if (OpsImageOverlay->objectName().isEmpty())
            OpsImageOverlay->setObjectName("OpsImageOverlay");
        OpsImageOverlay->resize(431, 493);
        imageOverlayVerticalLayout_2 = new QVBoxLayout(OpsImageOverlay);
        imageOverlayVerticalLayout_2->setSpacing(3);
        imageOverlayVerticalLayout_2->setObjectName("imageOverlayVerticalLayout_2");
        imageOverlayVerticalLayout_2->setContentsMargins(3, 3, 3, 3);
        ImageOverlayBox = new QGroupBox(OpsImageOverlay);
        ImageOverlayBox->setObjectName("ImageOverlayBox");
        ImageOverlayBox->setMaximumSize(QSize(16777215, 150));
        vboxLayout = new QVBoxLayout(ImageOverlayBox);
        vboxLayout->setSpacing(3);
        vboxLayout->setObjectName("vboxLayout");
        vboxLayout->setContentsMargins(3, 3, 3, 3);
        vboxLayout1 = new QVBoxLayout();
        vboxLayout1->setSpacing(3);
        vboxLayout1->setObjectName("vboxLayout1");
        kcfg_ShowImageOverlays = new QCheckBox(ImageOverlayBox);
        kcfg_ShowImageOverlays->setObjectName("kcfg_ShowImageOverlays");

        vboxLayout1->addWidget(kcfg_ShowImageOverlays);

        kcfg_ShowSelectedImageOverlay = new QCheckBox(ImageOverlayBox);
        kcfg_ShowSelectedImageOverlay->setObjectName("kcfg_ShowSelectedImageOverlay");

        vboxLayout1->addWidget(kcfg_ShowSelectedImageOverlay);

        kcfg_ShowImageOverlaysBelowCatalogs = new QCheckBox(ImageOverlayBox);
        kcfg_ShowImageOverlaysBelowCatalogs->setObjectName("kcfg_ShowImageOverlaysBelowCatalogs");

        vboxLayout1->addWidget(kcfg_ShowImageOverlaysBelowCatalogs);

        imageOverlayMaxDimensionLayout = new QHBoxLayout();
        imageOverlayMaxDimensionLayout->setSpacing(3);
        imageOverlayMaxDimensionLayout->setObjectName("imageOverlayMaxDimensionLayout");
        imageOverlayMaxDimensionLabel = new QLabel(ImageOverlayBox);
        imageOverlayMaxDimensionLabel->setObjectName("imageOverlayMaxDimensionLabel");
        QSizePolicy sizePolicy(QSizePolicy::Policy::Fixed, QSizePolicy::Policy::Preferred);
        sizePolicy.setHorizontalStretch(0);
        sizePolicy.setVerticalStretch(0);
        sizePolicy.setHeightForWidth(imageOverlayMaxDimensionLabel->sizePolicy().hasHeightForWidth());
        imageOverlayMaxDimensionLabel->setSizePolicy(sizePolicy);

        imageOverlayMaxDimensionLayout->addWidget(imageOverlayMaxDimensionLabel);

        kcfg_ImageOverlayMaxDimension = new QSpinBox(ImageOverlayBox);
        kcfg_ImageOverlayMaxDimension->setObjectName("kcfg_ImageOverlayMaxDimension");
        QSizePolicy sizePolicy1(QSizePolicy::Policy::Fixed, QSizePolicy::Policy::Fixed);
        sizePolicy1.setHorizontalStretch(0);
        sizePolicy1.setVerticalStretch(0);
        sizePolicy1.setHeightForWidth(kcfg_ImageOverlayMaxDimension->sizePolicy().hasHeightForWidth());
        kcfg_ImageOverlayMaxDimension->setSizePolicy(sizePolicy1);
        kcfg_ImageOverlayMaxDimension->setMinimum(10);
        kcfg_ImageOverlayMaxDimension->setMaximum(20000);
        kcfg_ImageOverlayMaxDimension->setValue(1000);

        imageOverlayMaxDimensionLayout->addWidget(kcfg_ImageOverlayMaxDimension);

        spacerItem = new QSpacerItem(200, 16, QSizePolicy::Policy::Expanding, QSizePolicy::Policy::Minimum);

        imageOverlayMaxDimensionLayout->addItem(spacerItem);

        imageOverlayShowDirButton = new QPushButton(ImageOverlayBox);
        imageOverlayShowDirButton->setObjectName("imageOverlayShowDirButton");
        imageOverlayShowDirButton->setStyleSheet(QString::fromUtf8("font-weight:bold;"));

        imageOverlayMaxDimensionLayout->addWidget(imageOverlayShowDirButton);

        refreshB = new QPushButton(ImageOverlayBox);
        refreshB->setObjectName("refreshB");
        refreshB->setMinimumSize(QSize(28, 28));
        refreshB->setMaximumSize(QSize(28, 28));
        QIcon icon;
        QString iconThemeName = QString::fromUtf8("system-reboot");
        if (QIcon::hasThemeIcon(iconThemeName)) {
            icon = QIcon::fromTheme(iconThemeName);
        } else {
            icon.addFile(QString::fromUtf8("."), QSize(), QIcon::Mode::Normal, QIcon::State::Off);
        }
        refreshB->setIcon(icon);
        refreshB->setIconSize(QSize(28, 28));

        imageOverlayMaxDimensionLayout->addWidget(refreshB);


        vboxLayout1->addLayout(imageOverlayMaxDimensionLayout);


        vboxLayout->addLayout(vboxLayout1);


        imageOverlayVerticalLayout_2->addWidget(ImageOverlayBox);

        ImageOverlayTableBox = new QGroupBox(OpsImageOverlay);
        ImageOverlayTableBox->setObjectName("ImageOverlayTableBox");
        ImageOverlayTableLayout = new QVBoxLayout(ImageOverlayTableBox);
        ImageOverlayTableLayout->setSpacing(3);
        ImageOverlayTableLayout->setObjectName("ImageOverlayTableLayout");
        ImageOverlayTableLayout->setContentsMargins(3, 3, 3, 3);
        imageOverlayTable = new QTableWidget(ImageOverlayTableBox);
        imageOverlayTable->setObjectName("imageOverlayTable");
        QSizePolicy sizePolicy2(QSizePolicy::Policy::Expanding, QSizePolicy::Policy::Expanding);
        sizePolicy2.setHorizontalStretch(1);
        sizePolicy2.setVerticalStretch(0);
        sizePolicy2.setHeightForWidth(imageOverlayTable->sizePolicy().hasHeightForWidth());
        imageOverlayTable->setSizePolicy(sizePolicy2);
        imageOverlayTable->setVerticalScrollBarPolicy(Qt::ScrollBarAsNeeded);
        imageOverlayTable->setHorizontalScrollBarPolicy(Qt::ScrollBarAsNeeded);

        ImageOverlayTableLayout->addWidget(imageOverlayTable);

        imageOverlayButtonLayout = new QHBoxLayout();
        imageOverlayButtonLayout->setSpacing(3);
        imageOverlayButtonLayout->setObjectName("imageOverlayButtonLayout");
        solveButton = new QPushButton(ImageOverlayTableBox);
        solveButton->setObjectName("solveButton");
        solveButton->setMaximumSize(QSize(50, 16777215));

        imageOverlayButtonLayout->addWidget(solveButton);

        imageOverlaySolverProfile = new QComboBox(ImageOverlayTableBox);
        imageOverlaySolverProfile->setObjectName("imageOverlaySolverProfile");
        QSizePolicy sizePolicy3(QSizePolicy::Policy::Preferred, QSizePolicy::Policy::Fixed);
        sizePolicy3.setHorizontalStretch(0);
        sizePolicy3.setVerticalStretch(0);
        sizePolicy3.setHeightForWidth(imageOverlaySolverProfile->sizePolicy().hasHeightForWidth());
        imageOverlaySolverProfile->setSizePolicy(sizePolicy3);

        imageOverlayButtonLayout->addWidget(imageOverlaySolverProfile);

        editAlignProfile = new QPushButton(ImageOverlayTableBox);
        editAlignProfile->setObjectName("editAlignProfile");
        sizePolicy3.setHeightForWidth(editAlignProfile->sizePolicy().hasHeightForWidth());
        editAlignProfile->setSizePolicy(sizePolicy3);
        editAlignProfile->setMaximumSize(QSize(32, 16777215));

        imageOverlayButtonLayout->addWidget(editAlignProfile);

        imageOverlayScaleLabel = new QLabel(ImageOverlayTableBox);
        imageOverlayScaleLabel->setObjectName("imageOverlayScaleLabel");
        sizePolicy.setHeightForWidth(imageOverlayScaleLabel->sizePolicy().hasHeightForWidth());
        imageOverlayScaleLabel->setSizePolicy(sizePolicy);

        imageOverlayButtonLayout->addWidget(imageOverlayScaleLabel);

        kcfg_ImageOverlayDefaultScale = new QDoubleSpinBox(ImageOverlayTableBox);
        kcfg_ImageOverlayDefaultScale->setObjectName("kcfg_ImageOverlayDefaultScale");
        sizePolicy1.setHeightForWidth(kcfg_ImageOverlayDefaultScale->sizePolicy().hasHeightForWidth());
        kcfg_ImageOverlayDefaultScale->setSizePolicy(sizePolicy1);
        kcfg_ImageOverlayDefaultScale->setMinimum(0.000000000000000);
        kcfg_ImageOverlayDefaultScale->setMaximum(100.000000000000000);
        kcfg_ImageOverlayDefaultScale->setSingleStep(0.100000000000000);
        kcfg_ImageOverlayDefaultScale->setValue(0.000000000000000);

        imageOverlayButtonLayout->addWidget(kcfg_ImageOverlayDefaultScale);

        imageOverlayTimeoutLabel = new QLabel(ImageOverlayTableBox);
        imageOverlayTimeoutLabel->setObjectName("imageOverlayTimeoutLabel");
        sizePolicy.setHeightForWidth(imageOverlayTimeoutLabel->sizePolicy().hasHeightForWidth());
        imageOverlayTimeoutLabel->setSizePolicy(sizePolicy);

        imageOverlayButtonLayout->addWidget(imageOverlayTimeoutLabel);

        kcfg_ImageOverlayTimeout = new QSpinBox(ImageOverlayTableBox);
        kcfg_ImageOverlayTimeout->setObjectName("kcfg_ImageOverlayTimeout");
        sizePolicy1.setHeightForWidth(kcfg_ImageOverlayTimeout->sizePolicy().hasHeightForWidth());
        kcfg_ImageOverlayTimeout->setSizePolicy(sizePolicy1);
        kcfg_ImageOverlayTimeout->setMinimum(1);
        kcfg_ImageOverlayTimeout->setMaximum(200);
        kcfg_ImageOverlayTimeout->setValue(30);

        imageOverlayButtonLayout->addWidget(kcfg_ImageOverlayTimeout);

        spacerItem1 = new QSpacerItem(200, 16, QSizePolicy::Policy::Expanding, QSizePolicy::Policy::Minimum);

        imageOverlayButtonLayout->addItem(spacerItem1);


        ImageOverlayTableLayout->addLayout(imageOverlayButtonLayout);

        imageOverlayStatus = new QPlainTextEdit(ImageOverlayTableBox);
        imageOverlayStatus->setObjectName("imageOverlayStatus");
        QSizePolicy sizePolicy4(QSizePolicy::Policy::Expanding, QSizePolicy::Policy::Minimum);
        sizePolicy4.setHorizontalStretch(0);
        sizePolicy4.setVerticalStretch(0);
        sizePolicy4.setHeightForWidth(imageOverlayStatus->sizePolicy().hasHeightForWidth());
        imageOverlayStatus->setSizePolicy(sizePolicy4);
        imageOverlayStatus->setMinimumSize(QSize(0, 50));
        imageOverlayStatus->setMaximumSize(QSize(16777215, 16777215));
        imageOverlayStatus->setSizeAdjustPolicy(QAbstractScrollArea::AdjustToContents);
        imageOverlayStatus->setReadOnly(true);

        ImageOverlayTableLayout->addWidget(imageOverlayStatus);


        imageOverlayVerticalLayout_2->addWidget(ImageOverlayTableBox);

        QWidget::setTabOrder(kcfg_ShowImageOverlays, kcfg_ImageOverlayMaxDimension);
        QWidget::setTabOrder(kcfg_ImageOverlayMaxDimension, kcfg_ShowSelectedImageOverlay);
        QWidget::setTabOrder(kcfg_ShowSelectedImageOverlay, kcfg_ImageOverlayTimeout);
        QWidget::setTabOrder(kcfg_ImageOverlayTimeout, kcfg_ImageOverlayDefaultScale);

        retranslateUi(OpsImageOverlay);

        imageOverlaySolverProfile->setCurrentIndex(-1);


        QMetaObject::connectSlotsByName(OpsImageOverlay);
    } // setupUi

    void retranslateUi(QWidget *OpsImageOverlay)
    {
        ImageOverlayBox->setTitle(tr2i18n("Settings", nullptr));
        kcfg_ShowImageOverlays->setText(tr2i18n("Show image overlays", nullptr));
#if QT_CONFIG(tooltip)
        kcfg_ShowSelectedImageOverlay->setToolTip(tr2i18n("Center SkyMap over the selected overlay image in the table below (if it's solved).", nullptr));
#endif // QT_CONFIG(tooltip)
        kcfg_ShowSelectedImageOverlay->setText(tr2i18n("Center SkyMap on selection", nullptr));
#if QT_CONFIG(tooltip)
        kcfg_ShowImageOverlaysBelowCatalogs->setToolTip(tr2i18n("Display Image Overlays below catalogs.", nullptr));
#endif // QT_CONFIG(tooltip)
        kcfg_ShowImageOverlaysBelowCatalogs->setText(tr2i18n("Display Image Overlays below catalogs", nullptr));
#if QT_CONFIG(tooltip)
        imageOverlayMaxDimensionLabel->setToolTip(tr2i18n("Maximum dimension for an image overlay image. (Larger images will be scaled down.)", nullptr));
#endif // QT_CONFIG(tooltip)
        imageOverlayMaxDimensionLabel->setText(tr2i18n("Maximum image dimension:", nullptr));
#if QT_CONFIG(tooltip)
        kcfg_ImageOverlayMaxDimension->setToolTip(tr2i18n("Maximum dimension for an image overlay image. (Larger images will be scaled down.)", nullptr));
#endif // QT_CONFIG(tooltip)
#if QT_CONFIG(tooltip)
        imageOverlayShowDirButton->setToolTip(tr2i18n("Open overlay directory. Copy or move images to this directory to process them.", nullptr));
#endif // QT_CONFIG(tooltip)
        imageOverlayShowDirButton->setText(tr2i18n("Overlay Directory...", nullptr));
#if QT_CONFIG(tooltip)
        refreshB->setToolTip(tr2i18n("<html><head/><body><p>Refresh from the overlay directory. Add overlays that have been added there, and remove overlays that are no longer there.</p></body></html>", nullptr));
#endif // QT_CONFIG(tooltip)
        refreshB->setText(QString());
        ImageOverlayTableBox->setTitle(tr2i18n("Image Overlays", nullptr));
#if QT_CONFIG(tooltip)
        solveButton->setToolTip(tr2i18n("<html><head/><body><p>Plate solve the selected overlay image(s).</p><p>Uses the selected Align profile to the right, but not Align scale nor position. It will use the default scale to the right (a-s/px), if none is given on the table row and scale column (0 is no scale constraint). It will not use a position unless RA and DEC are entered on the table row. Uses the timeout above. You can select many rows (with click and shift click) and it will attempt to solve them all.</p><p>Plate solving may be difficult. You may not be able to plate solve all your images. You can try to supply scales and positions, and try different profiles. If you are unsuccessful, but still want to display an image, you can enter an RA, DEC, Scale, Orientation in the appropriate columns for the row you're interested in, then manually set the Status column to OK.</p><p>You cannot re-platesolve a row whose status is OK, but you can manually change the status to something else, then plate-solving is enabled.</p></body></html>", nullptr));
#endif // QT_CONFIG(tooltip)
        solveButton->setText(tr2i18n("Solve", nullptr));
#if QT_CONFIG(tooltip)
        imageOverlaySolverProfile->setToolTip(tr2i18n("Selects the Options Profile (from Align) to use for Plate Solving", nullptr));
#endif // QT_CONFIG(tooltip)
#if QT_CONFIG(tooltip)
        editAlignProfile->setToolTip(tr2i18n("Opens the currently selected Align Profile in the Options Profile Editor", nullptr));
#endif // QT_CONFIG(tooltip)
        editAlignProfile->setText(QString());
#if QT_CONFIG(tooltip)
        imageOverlayScaleLabel->setToolTip(tr2i18n("Default arcsec/px scale to use in solving. 0 is none. Would use what's in table if there.", nullptr));
#endif // QT_CONFIG(tooltip)
        imageOverlayScaleLabel->setText(tr2i18n("Default a-s/px:", nullptr));
#if QT_CONFIG(tooltip)
        kcfg_ImageOverlayDefaultScale->setToolTip(tr2i18n("Default arcsec/px scale to use in solving. 0 is none. Would use what's in table if there.", nullptr));
#endif // QT_CONFIG(tooltip)
#if QT_CONFIG(tooltip)
        imageOverlayTimeoutLabel->setToolTip(tr2i18n("Timeout for plate-solving an overlay image (seconds).", nullptr));
#endif // QT_CONFIG(tooltip)
        imageOverlayTimeoutLabel->setText(tr2i18n("Timeout:", nullptr));
#if QT_CONFIG(tooltip)
        kcfg_ImageOverlayTimeout->setToolTip(tr2i18n("Timeout for plate-solving an overlay image (seconds).", nullptr));
#endif // QT_CONFIG(tooltip)
        (void)OpsImageOverlay;
    } // retranslateUi

};

namespace Ui {
    class OpsImageOverlay: public Ui_OpsImageOverlay {};
} // namespace Ui

QT_END_NAMESPACE

#endif // OPSIMAGEOVERLAY_H

