/****************************************************************************
** Meta object code from reading C++ file 'internalguider.h'
**
** Created by: The Qt Meta Object Compiler version 69 (Qt 6.11.1)
**
** WARNING! All changes made in this file will be lost!
*****************************************************************************/

#include "../../../../kstars-3.8.4.1/kstars/ekos/guide/internalguide/internalguider.h"
#include <QtNetwork/QSslError>
#include <QtCore/qmetatype.h>

#include <QtCore/qtmochelpers.h>

#include <memory>


#include <QtCore/qxptype_traits.h>
#if !defined(Q_MOC_OUTPUT_REVISION)
#error "The header file 'internalguider.h' doesn't include <QObject>."
#elif Q_MOC_OUTPUT_REVISION != 69
#error "This file was generated using the moc from 6.11.1. It"
#error "cannot be used with the include files from this version of Qt."
#error "(The moc has changed too much.)"
#endif

#ifndef Q_CONSTINIT
#define Q_CONSTINIT
#endif

QT_WARNING_PUSH
QT_WARNING_DISABLE_DEPRECATED
QT_WARNING_DISABLE_GCC("-Wuseless-cast")
namespace {
struct qt_meta_tag_ZN4Ekos14InternalGuiderE_t {};
} // unnamed namespace

template <> constexpr inline auto Ekos::InternalGuider::qt_create_metaobjectdata<qt_meta_tag_ZN4Ekos14InternalGuiderE_t>()
{
    namespace QMC = QtMocConstants;
    QtMocHelpers::StringRefStorage qt_stringData {
        "Ekos::InternalGuider",
        "newMultiPulse",
        "",
        "GuideDirection",
        "ra_dir",
        "ra_msecs",
        "dec_dir",
        "dec_msecs",
        "CaptureAfterPulses",
        "followWithCapture",
        "newSinglePulse",
        "dir",
        "msecs",
        "DESwapChanged",
        "enable",
        "newAIState",
        "state",
        "confidence",
        "setDECSwap",
        "getAIGuider",
        "MountSpecificGuider*",
        "const MountSpecificGuider*",
        "reloadAIWeights",
        "trackingStarSelected",
        "x",
        "y",
        "setDitherSettled",
        "darkGuide"
    };

    QtMocHelpers::UintData qt_methods {
        // Signal 'newMultiPulse'
        QtMocHelpers::SignalData<void(GuideDirection, int, GuideDirection, int, CaptureAfterPulses)>(1, 2, QMC::AccessPublic, QMetaType::Void, {{
            { 0x80000000 | 3, 4 }, { QMetaType::Int, 5 }, { 0x80000000 | 3, 6 }, { QMetaType::Int, 7 },
            { 0x80000000 | 8, 9 },
        }}),
        // Signal 'newSinglePulse'
        QtMocHelpers::SignalData<void(GuideDirection, int, CaptureAfterPulses)>(10, 2, QMC::AccessPublic, QMetaType::Void, {{
            { 0x80000000 | 3, 11 }, { QMetaType::Int, 12 }, { 0x80000000 | 8, 9 },
        }}),
        // Signal 'DESwapChanged'
        QtMocHelpers::SignalData<void(bool)>(13, 2, QMC::AccessPublic, QMetaType::Void, {{
            { QMetaType::Bool, 14 },
        }}),
        // Signal 'newAIState'
        QtMocHelpers::SignalData<void(int, double)>(15, 2, QMC::AccessPublic, QMetaType::Void, {{
            { QMetaType::Int, 16 }, { QMetaType::Double, 17 },
        }}),
        // Slot 'setDECSwap'
        QtMocHelpers::SlotData<void(bool)>(18, 2, QMC::AccessPublic, QMetaType::Void, {{
            { QMetaType::Bool, 14 },
        }}),
        // Slot 'getAIGuider'
        QtMocHelpers::SlotData<MountSpecificGuider *()>(19, 2, QMC::AccessPublic, 0x80000000 | 20),
        // Slot 'getAIGuider'
        QtMocHelpers::SlotData<const MountSpecificGuider *() const>(19, 2, QMC::AccessPublic, 0x80000000 | 21),
        // Slot 'reloadAIWeights'
        QtMocHelpers::SlotData<bool()>(22, 2, QMC::AccessPublic, QMetaType::Bool),
        // Slot 'trackingStarSelected'
        QtMocHelpers::SlotData<void(int, int)>(23, 2, QMC::AccessProtected, QMetaType::Void, {{
            { QMetaType::Int, 24 }, { QMetaType::Int, 25 },
        }}),
        // Slot 'setDitherSettled'
        QtMocHelpers::SlotData<void()>(26, 2, QMC::AccessProtected, QMetaType::Void),
        // Slot 'darkGuide'
        QtMocHelpers::SlotData<void()>(27, 2, QMC::AccessProtected, QMetaType::Void),
    };
    QtMocHelpers::UintData qt_properties {
    };
    QtMocHelpers::UintData qt_enums {
    };
    return QtMocHelpers::metaObjectData<InternalGuider, qt_meta_tag_ZN4Ekos14InternalGuiderE_t>(QMC::MetaObjectFlag{}, qt_stringData,
            qt_methods, qt_properties, qt_enums);
}
Q_CONSTINIT const QMetaObject Ekos::InternalGuider::staticMetaObject = { {
    QMetaObject::SuperData::link<GuideInterface::staticMetaObject>(),
    qt_staticMetaObjectStaticContent<qt_meta_tag_ZN4Ekos14InternalGuiderE_t>.stringdata,
    qt_staticMetaObjectStaticContent<qt_meta_tag_ZN4Ekos14InternalGuiderE_t>.data,
    qt_static_metacall,
    nullptr,
    qt_staticMetaObjectRelocatingContent<qt_meta_tag_ZN4Ekos14InternalGuiderE_t>.metaTypes,
    nullptr
} };

void Ekos::InternalGuider::qt_static_metacall(QObject *_o, QMetaObject::Call _c, int _id, void **_a)
{
    auto *_t = static_cast<InternalGuider *>(_o);
    if (_c == QMetaObject::InvokeMetaMethod) {
        switch (_id) {
        case 0: _t->newMultiPulse((*reinterpret_cast<std::add_pointer_t<GuideDirection>>(_a[1])),(*reinterpret_cast<std::add_pointer_t<int>>(_a[2])),(*reinterpret_cast<std::add_pointer_t<GuideDirection>>(_a[3])),(*reinterpret_cast<std::add_pointer_t<int>>(_a[4])),(*reinterpret_cast<std::add_pointer_t<CaptureAfterPulses>>(_a[5]))); break;
        case 1: _t->newSinglePulse((*reinterpret_cast<std::add_pointer_t<GuideDirection>>(_a[1])),(*reinterpret_cast<std::add_pointer_t<int>>(_a[2])),(*reinterpret_cast<std::add_pointer_t<CaptureAfterPulses>>(_a[3]))); break;
        case 2: _t->DESwapChanged((*reinterpret_cast<std::add_pointer_t<bool>>(_a[1]))); break;
        case 3: _t->newAIState((*reinterpret_cast<std::add_pointer_t<int>>(_a[1])),(*reinterpret_cast<std::add_pointer_t<double>>(_a[2]))); break;
        case 4: _t->setDECSwap((*reinterpret_cast<std::add_pointer_t<bool>>(_a[1]))); break;
        case 5: { MountSpecificGuider* _r = _t->getAIGuider();
            if (_a[0]) *reinterpret_cast<MountSpecificGuider**>(_a[0]) = std::move(_r); }  break;
        case 6: { const MountSpecificGuider* _r = _t->getAIGuider();
            if (_a[0]) *reinterpret_cast<const MountSpecificGuider**>(_a[0]) = std::move(_r); }  break;
        case 7: { bool _r = _t->reloadAIWeights();
            if (_a[0]) *reinterpret_cast<bool*>(_a[0]) = std::move(_r); }  break;
        case 8: _t->trackingStarSelected((*reinterpret_cast<std::add_pointer_t<int>>(_a[1])),(*reinterpret_cast<std::add_pointer_t<int>>(_a[2]))); break;
        case 9: _t->setDitherSettled(); break;
        case 10: _t->darkGuide(); break;
        default: ;
        }
    }
    if (_c == QMetaObject::IndexOfMethod) {
        if (QtMocHelpers::indexOfMethod<void (InternalGuider::*)(GuideDirection , int , GuideDirection , int , CaptureAfterPulses )>(_a, &InternalGuider::newMultiPulse, 0))
            return;
        if (QtMocHelpers::indexOfMethod<void (InternalGuider::*)(GuideDirection , int , CaptureAfterPulses )>(_a, &InternalGuider::newSinglePulse, 1))
            return;
        if (QtMocHelpers::indexOfMethod<void (InternalGuider::*)(bool )>(_a, &InternalGuider::DESwapChanged, 2))
            return;
        if (QtMocHelpers::indexOfMethod<void (InternalGuider::*)(int , double )>(_a, &InternalGuider::newAIState, 3))
            return;
    }
}

const QMetaObject *Ekos::InternalGuider::metaObject() const
{
    return QObject::d_ptr->metaObject ? QObject::d_ptr->dynamicMetaObject() : &staticMetaObject;
}

void *Ekos::InternalGuider::qt_metacast(const char *_clname)
{
    if (!_clname) return nullptr;
    if (!strcmp(_clname, qt_staticMetaObjectStaticContent<qt_meta_tag_ZN4Ekos14InternalGuiderE_t>.strings))
        return static_cast<void*>(this);
    return GuideInterface::qt_metacast(_clname);
}

int Ekos::InternalGuider::qt_metacall(QMetaObject::Call _c, int _id, void **_a)
{
    _id = GuideInterface::qt_metacall(_c, _id, _a);
    if (_id < 0)
        return _id;
    if (_c == QMetaObject::InvokeMetaMethod) {
        if (_id < 11)
            qt_static_metacall(this, _c, _id, _a);
        _id -= 11;
    }
    if (_c == QMetaObject::RegisterMethodArgumentMetaType) {
        if (_id < 11)
            *reinterpret_cast<QMetaType *>(_a[0]) = QMetaType();
        _id -= 11;
    }
    return _id;
}

// SIGNAL 0
void Ekos::InternalGuider::newMultiPulse(GuideDirection _t1, int _t2, GuideDirection _t3, int _t4, CaptureAfterPulses _t5)
{
    QMetaObject::activate<void>(this, &staticMetaObject, 0, nullptr, _t1, _t2, _t3, _t4, _t5);
}

// SIGNAL 1
void Ekos::InternalGuider::newSinglePulse(GuideDirection _t1, int _t2, CaptureAfterPulses _t3)
{
    QMetaObject::activate<void>(this, &staticMetaObject, 1, nullptr, _t1, _t2, _t3);
}

// SIGNAL 2
void Ekos::InternalGuider::DESwapChanged(bool _t1)
{
    QMetaObject::activate<void>(this, &staticMetaObject, 2, nullptr, _t1);
}

// SIGNAL 3
void Ekos::InternalGuider::newAIState(int _t1, double _t2)
{
    QMetaObject::activate<void>(this, &staticMetaObject, 3, nullptr, _t1, _t2);
}
QT_WARNING_POP
