/****************************************************************************
** Meta object code from reading C++ file 'fovadaptor.h'
**
** Created by: The Qt Meta Object Compiler version 69 (Qt 6.11.1)
**
** WARNING! All changes made in this file will be lost!
*****************************************************************************/

#include "fovadaptor.h"
#include <QtCore/qmetatype.h>

#include <QtCore/qtmochelpers.h>

#include <memory>


#include <QtCore/qxptype_traits.h>
#if !defined(Q_MOC_OUTPUT_REVISION)
#error "The header file 'fovadaptor.h' doesn't include <QObject>."
#elif Q_MOC_OUTPUT_REVISION != 69
#error "This file was generated using the moc from 6.11.1. It"
#error "cannot be used with the include files from this version of Qt."
#error "(The moc has changed too much.)"
#endif

#ifndef Q_CONSTINIT
#define Q_CONSTINIT
#endif

QT_WARNING_PUSH
QT_WARNING_DISABLE_DEPRECATED
QT_WARNING_DISABLE_GCC("-Wuseless-cast")
namespace {
struct qt_meta_tag_ZN10FovAdaptorE_t {};
} // unnamed namespace

template <> constexpr inline auto FovAdaptor::qt_create_metaobjectdata<qt_meta_tag_ZN10FovAdaptorE_t>()
{
    namespace QMC = QtMocConstants;
    QtMocHelpers::StringRefStorage qt_stringData {
        "FovAdaptor",
        "D-Bus Interface",
        "org.kde.kstars.fov",
        "D-Bus Introspection",
        "  <interface name=\"org.kde.kstars.fov\">\n    <property access=\""
        "readwrite\" type=\"s\" name=\"name\"/>\n    <property access=\"rea"
        "dwrite\" type=\"d\" name=\"sizeX\"/>\n    <property access=\"readw"
        "rite\" type=\"d\" name=\"sizeY\"/>\n    <property access=\"readwri"
        "te\" type=\"d\" name=\"offsetX\"/>\n    <property access=\"readwri"
        "te\" type=\"d\" name=\"offsetY\"/>\n    <property access=\"readwri"
        "te\" type=\"d\" name=\"PA\"/>\n    <property access=\"readwrite\" "
        "type=\"s\" name=\"color\"/>\n    <property access=\"readwrite\" ty"
        "pe=\"b\" name=\"cpLock\"/>\n    <property access=\"readwrite\" typ"
        "e=\"(i)\" name=\"shape\">\n      <annotation value=\"FOV::Shape\" "
        "name=\"org.qtproject.QtDBus.QtTypeName\"/>\n    </property>\n  </i"
        "nterface>\n",
        "PA",
        "color",
        "cpLock",
        "name",
        "offsetX",
        "offsetY",
        "shape",
        "FOV::Shape",
        "sizeX",
        "sizeY"
    };

    QtMocHelpers::UintData qt_methods {
    };
    QtMocHelpers::UintData qt_properties {
        // property 'PA'
        QtMocHelpers::PropertyData<double>(5, QMetaType::Double, QMC::DefaultPropertyFlags | QMC::Writable | QMC::StdCppSet),
        // property 'color'
        QtMocHelpers::PropertyData<QString>(6, QMetaType::QString, QMC::DefaultPropertyFlags | QMC::Writable | QMC::StdCppSet),
        // property 'cpLock'
        QtMocHelpers::PropertyData<bool>(7, QMetaType::Bool, QMC::DefaultPropertyFlags | QMC::Writable | QMC::StdCppSet),
        // property 'name'
        QtMocHelpers::PropertyData<QString>(8, QMetaType::QString, QMC::DefaultPropertyFlags | QMC::Writable | QMC::StdCppSet),
        // property 'offsetX'
        QtMocHelpers::PropertyData<double>(9, QMetaType::Double, QMC::DefaultPropertyFlags | QMC::Writable | QMC::StdCppSet),
        // property 'offsetY'
        QtMocHelpers::PropertyData<double>(10, QMetaType::Double, QMC::DefaultPropertyFlags | QMC::Writable | QMC::StdCppSet),
        // property 'shape'
        QtMocHelpers::PropertyData<FOV::Shape>(11, 0x80000000 | 12, QMC::DefaultPropertyFlags | QMC::Writable | QMC::EnumOrFlag | QMC::StdCppSet),
        // property 'sizeX'
        QtMocHelpers::PropertyData<double>(13, QMetaType::Double, QMC::DefaultPropertyFlags | QMC::Writable | QMC::StdCppSet),
        // property 'sizeY'
        QtMocHelpers::PropertyData<double>(14, QMetaType::Double, QMC::DefaultPropertyFlags | QMC::Writable | QMC::StdCppSet),
    };
    QtMocHelpers::UintData qt_enums {
    };
    QtMocHelpers::UintData qt_constructors {};
    QtMocHelpers::ClassInfos qt_classinfo({
            {    1,    2 },
            {    3,    4 },
    });
    return QtMocHelpers::metaObjectData<FovAdaptor, qt_meta_tag_ZN10FovAdaptorE_t>(QMC::MetaObjectFlag{}, qt_stringData,
            qt_methods, qt_properties, qt_enums, qt_constructors, qt_classinfo);
}
Q_CONSTINIT static const QMetaObject::SuperData qt_meta_extradata_ZN10FovAdaptorE[] = {
    QMetaObject::SuperData::link<FOV::staticMetaObject>(),
    nullptr
};

Q_CONSTINIT const QMetaObject FovAdaptor::staticMetaObject = { {
    QMetaObject::SuperData::link<QDBusAbstractAdaptor::staticMetaObject>(),
    qt_staticMetaObjectStaticContent<qt_meta_tag_ZN10FovAdaptorE_t>.stringdata,
    qt_staticMetaObjectStaticContent<qt_meta_tag_ZN10FovAdaptorE_t>.data,
    qt_static_metacall,
    qt_meta_extradata_ZN10FovAdaptorE,
    qt_staticMetaObjectRelocatingContent<qt_meta_tag_ZN10FovAdaptorE_t>.metaTypes,
    nullptr
} };

void FovAdaptor::qt_static_metacall(QObject *_o, QMetaObject::Call _c, int _id, void **_a)
{
    auto *_t = static_cast<FovAdaptor *>(_o);
    if (_c == QMetaObject::RegisterPropertyMetaType) {
        switch (_id) {
        default: *reinterpret_cast<int*>(_a[0]) = -1; break;
        case 6:
            *reinterpret_cast<int*>(_a[0]) = qRegisterMetaType< FOV::Shape >(); break;
        }
    }
    if (_c == QMetaObject::ReadProperty) {
        void *_v = _a[0];
        switch (_id) {
        case 0: *reinterpret_cast<double*>(_v) = _t->pA(); break;
        case 1: *reinterpret_cast<QString*>(_v) = _t->color(); break;
        case 2: *reinterpret_cast<bool*>(_v) = _t->cpLock(); break;
        case 3: *reinterpret_cast<QString*>(_v) = _t->name(); break;
        case 4: *reinterpret_cast<double*>(_v) = _t->offsetX(); break;
        case 5: *reinterpret_cast<double*>(_v) = _t->offsetY(); break;
        case 6: *reinterpret_cast<FOV::Shape*>(_v) = _t->shape(); break;
        case 7: *reinterpret_cast<double*>(_v) = _t->sizeX(); break;
        case 8: *reinterpret_cast<double*>(_v) = _t->sizeY(); break;
        default: break;
        }
    }
    if (_c == QMetaObject::WriteProperty) {
        void *_v = _a[0];
        switch (_id) {
        case 0: _t->setPA(*reinterpret_cast<double*>(_v)); break;
        case 1: _t->setColor(*reinterpret_cast<QString*>(_v)); break;
        case 2: _t->setCpLock(*reinterpret_cast<bool*>(_v)); break;
        case 3: _t->setName(*reinterpret_cast<QString*>(_v)); break;
        case 4: _t->setOffsetX(*reinterpret_cast<double*>(_v)); break;
        case 5: _t->setOffsetY(*reinterpret_cast<double*>(_v)); break;
        case 6: _t->setShape(*reinterpret_cast<FOV::Shape*>(_v)); break;
        case 7: _t->setSizeX(*reinterpret_cast<double*>(_v)); break;
        case 8: _t->setSizeY(*reinterpret_cast<double*>(_v)); break;
        default: break;
        }
    }
}

const QMetaObject *FovAdaptor::metaObject() const
{
    return QObject::d_ptr->metaObject ? QObject::d_ptr->dynamicMetaObject() : &staticMetaObject;
}

void *FovAdaptor::qt_metacast(const char *_clname)
{
    if (!_clname) return nullptr;
    if (!strcmp(_clname, qt_staticMetaObjectStaticContent<qt_meta_tag_ZN10FovAdaptorE_t>.strings))
        return static_cast<void*>(this);
    return QDBusAbstractAdaptor::qt_metacast(_clname);
}

int FovAdaptor::qt_metacall(QMetaObject::Call _c, int _id, void **_a)
{
    _id = QDBusAbstractAdaptor::qt_metacall(_c, _id, _a);
    if (_id < 0)
        return _id;
    if (_c == QMetaObject::ReadProperty || _c == QMetaObject::WriteProperty
            || _c == QMetaObject::ResetProperty || _c == QMetaObject::BindableProperty
            || _c == QMetaObject::RegisterPropertyMetaType) {
        qt_static_metacall(this, _c, _id, _a);
        _id -= 9;
    }
    return _id;
}
QT_WARNING_POP
