/********************************************************************************
** Form generated from reading UI file 'capturecountswidget.ui'
**
** Created by: Qt User Interface Compiler version 6.11.1
**
** WARNING! All changes made in this file will be lost when recompiling UI file!
********************************************************************************/

#ifndef UI_CAPTURECOUNTSWIDGET_H
#define UI_CAPTURECOUNTSWIDGET_H

#include <QtCore/QVariant>
#include <QtGui/QIcon>
#include <QtWidgets/QApplication>
#include <QtWidgets/QGridLayout>
#include <QtWidgets/QLabel>
#include <QtWidgets/QProgressBar>
#include <QtWidgets/QPushButton>
#include <QtWidgets/QSpacerItem>
#include <QtWidgets/QVBoxLayout>
#include <QtWidgets/QWidget>
#include <klocalizedstring.h>
#include "QRoundProgressBar.h"

QT_BEGIN_NAMESPACE

class Ui_CaptureCountsWidget
{
public:
    QVBoxLayout *verticalLayout;
    QWidget *graphicalView;
    QVBoxLayout *verticalLayout_3;
    QProgressBar *gr_imageProgress;
    QGridLayout *graphicsGrid;
    QLabel *gr_sequenceLabel;
    QLabel *gr_overallLabel;
    QSpacerItem *horizontalSpacer_6;
    QLabel *gr_frameDetailsLabel;
    QLabel *gr_sequenceRemainingTime;
    QLabel *gr_frameLabel;
    QRoundProgressBar *gr_sequenceProgressBar;
    QRoundProgressBar *gr_overallProgressBar;
    QPushButton *switchToTextButton;
    QLabel *gr_frameRemainingTime;
    QLabel *gr_overallRemainingTime;
    QWidget *textView;
    QVBoxLayout *verticalLayout_2;
    QProgressBar *imageProgress;
    QGridLayout *gridLayout;
    QLabel *sequenceLabel;
    QLabel *frameRemainingTime;
    QLabel *jobRemainingTime;
    QLabel *frameInfoLabel;
    QLabel *jobLabel;
    QLabel *overallRemainingTime;
    QLabel *overallLabel;
    QSpacerItem *horizontalSpacer;
    QSpacerItem *horizontalSpacer_2;
    QLabel *sequenceRemainingTime;
    QLabel *frameDetailsLabel;
    QPushButton *switchToGraphicsButton;

    void setupUi(QWidget *CaptureCountsWidget)
    {
        if (CaptureCountsWidget->objectName().isEmpty())
            CaptureCountsWidget->setObjectName("CaptureCountsWidget");
        CaptureCountsWidget->setEnabled(false);
        CaptureCountsWidget->resize(690, 220);
        QSizePolicy sizePolicy(QSizePolicy::Policy::MinimumExpanding, QSizePolicy::Policy::Expanding);
        sizePolicy.setHorizontalStretch(0);
        sizePolicy.setVerticalStretch(0);
        sizePolicy.setHeightForWidth(CaptureCountsWidget->sizePolicy().hasHeightForWidth());
        CaptureCountsWidget->setSizePolicy(sizePolicy);
        CaptureCountsWidget->setMinimumSize(QSize(600, 20));
        CaptureCountsWidget->setMaximumSize(QSize(16777215, 16777215));
        CaptureCountsWidget->setBaseSize(QSize(0, 0));
        verticalLayout = new QVBoxLayout(CaptureCountsWidget);
        verticalLayout->setSpacing(4);
        verticalLayout->setObjectName("verticalLayout");
        verticalLayout->setContentsMargins(0, 0, 0, 4);
        graphicalView = new QWidget(CaptureCountsWidget);
        graphicalView->setObjectName("graphicalView");
        QSizePolicy sizePolicy1(QSizePolicy::Policy::Preferred, QSizePolicy::Policy::Maximum);
        sizePolicy1.setHorizontalStretch(0);
        sizePolicy1.setVerticalStretch(0);
        sizePolicy1.setHeightForWidth(graphicalView->sizePolicy().hasHeightForWidth());
        graphicalView->setSizePolicy(sizePolicy1);
        verticalLayout_3 = new QVBoxLayout(graphicalView);
        verticalLayout_3->setObjectName("verticalLayout_3");
        verticalLayout_3->setContentsMargins(0, 0, 0, 0);
        gr_imageProgress = new QProgressBar(graphicalView);
        gr_imageProgress->setObjectName("gr_imageProgress");
        gr_imageProgress->setMinimumSize(QSize(0, 4));
        gr_imageProgress->setMaximumSize(QSize(16777215, 4));
        gr_imageProgress->setStyleSheet(QString::fromUtf8("QProgressBar::chunk {\n"
"background-color: rgb(164, 0, 0);\n"
"}"));
        gr_imageProgress->setValue(24);
        gr_imageProgress->setTextVisible(false);

        verticalLayout_3->addWidget(gr_imageProgress);

        graphicsGrid = new QGridLayout();
        graphicsGrid->setObjectName("graphicsGrid");
        graphicsGrid->setVerticalSpacing(0);
        gr_sequenceLabel = new QLabel(graphicalView);
        gr_sequenceLabel->setObjectName("gr_sequenceLabel");
        QSizePolicy sizePolicy2(QSizePolicy::Policy::Expanding, QSizePolicy::Policy::Expanding);
        sizePolicy2.setHorizontalStretch(0);
        sizePolicy2.setVerticalStretch(0);
        sizePolicy2.setHeightForWidth(gr_sequenceLabel->sizePolicy().hasHeightForWidth());
        gr_sequenceLabel->setSizePolicy(sizePolicy2);
        gr_sequenceLabel->setAlignment(Qt::AlignBottom|Qt::AlignLeading|Qt::AlignLeft);

        graphicsGrid->addWidget(gr_sequenceLabel, 0, 4, 1, 1);

        gr_overallLabel = new QLabel(graphicalView);
        gr_overallLabel->setObjectName("gr_overallLabel");
        sizePolicy2.setHeightForWidth(gr_overallLabel->sizePolicy().hasHeightForWidth());
        gr_overallLabel->setSizePolicy(sizePolicy2);
        gr_overallLabel->setAlignment(Qt::AlignBottom|Qt::AlignLeading|Qt::AlignLeft);

        graphicsGrid->addWidget(gr_overallLabel, 0, 6, 1, 1);

        horizontalSpacer_6 = new QSpacerItem(40, 20, QSizePolicy::Policy::Expanding, QSizePolicy::Policy::Minimum);

        graphicsGrid->addItem(horizontalSpacer_6, 0, 2, 1, 1);

        gr_frameDetailsLabel = new QLabel(graphicalView);
        gr_frameDetailsLabel->setObjectName("gr_frameDetailsLabel");
        QSizePolicy sizePolicy3(QSizePolicy::Policy::Preferred, QSizePolicy::Policy::Expanding);
        sizePolicy3.setHorizontalStretch(0);
        sizePolicy3.setVerticalStretch(0);
        sizePolicy3.setHeightForWidth(gr_frameDetailsLabel->sizePolicy().hasHeightForWidth());
        gr_frameDetailsLabel->setSizePolicy(sizePolicy3);
        gr_frameDetailsLabel->setAlignment(Qt::AlignLeading|Qt::AlignLeft|Qt::AlignTop);

        graphicsGrid->addWidget(gr_frameDetailsLabel, 1, 0, 1, 2);

        gr_sequenceRemainingTime = new QLabel(graphicalView);
        gr_sequenceRemainingTime->setObjectName("gr_sequenceRemainingTime");
        sizePolicy3.setHeightForWidth(gr_sequenceRemainingTime->sizePolicy().hasHeightForWidth());
        gr_sequenceRemainingTime->setSizePolicy(sizePolicy3);
        gr_sequenceRemainingTime->setAlignment(Qt::AlignLeading|Qt::AlignLeft|Qt::AlignTop);

        graphicsGrid->addWidget(gr_sequenceRemainingTime, 1, 4, 1, 1);

        gr_frameLabel = new QLabel(graphicalView);
        gr_frameLabel->setObjectName("gr_frameLabel");
        sizePolicy3.setHeightForWidth(gr_frameLabel->sizePolicy().hasHeightForWidth());
        gr_frameLabel->setSizePolicy(sizePolicy3);
        QFont font;
        font.setBold(true);
        gr_frameLabel->setFont(font);
        gr_frameLabel->setAlignment(Qt::AlignBottom|Qt::AlignLeading|Qt::AlignLeft);

        graphicsGrid->addWidget(gr_frameLabel, 0, 0, 1, 1);

        gr_sequenceProgressBar = new QRoundProgressBar(graphicalView);
        gr_sequenceProgressBar->setObjectName("gr_sequenceProgressBar");
        gr_sequenceProgressBar->setMinimumSize(QSize(64, 64));
        gr_sequenceProgressBar->setMaximumSize(QSize(64, 64));

        graphicsGrid->addWidget(gr_sequenceProgressBar, 0, 3, 2, 1);

        gr_overallProgressBar = new QRoundProgressBar(graphicalView);
        gr_overallProgressBar->setObjectName("gr_overallProgressBar");
        gr_overallProgressBar->setMinimumSize(QSize(64, 64));
        gr_overallProgressBar->setMaximumSize(QSize(64, 64));

        graphicsGrid->addWidget(gr_overallProgressBar, 0, 5, 2, 1);

        switchToTextButton = new QPushButton(graphicalView);
        switchToTextButton->setObjectName("switchToTextButton");
        switchToTextButton->setMinimumSize(QSize(20, 20));
        switchToTextButton->setMaximumSize(QSize(20, 20));
        switchToTextButton->setFont(font);
        QIcon icon(QIcon::fromTheme(QString::fromUtf8("arrow-down")));
        switchToTextButton->setIcon(icon);

        graphicsGrid->addWidget(switchToTextButton, 1, 7, 1, 1);

        gr_frameRemainingTime = new QLabel(graphicalView);
        gr_frameRemainingTime->setObjectName("gr_frameRemainingTime");
        sizePolicy3.setHeightForWidth(gr_frameRemainingTime->sizePolicy().hasHeightForWidth());
        gr_frameRemainingTime->setSizePolicy(sizePolicy3);
        gr_frameRemainingTime->setMinimumSize(QSize(70, 0));
        gr_frameRemainingTime->setAlignment(Qt::AlignBottom|Qt::AlignRight|Qt::AlignTrailing);

        graphicsGrid->addWidget(gr_frameRemainingTime, 0, 1, 1, 1);

        gr_overallRemainingTime = new QLabel(graphicalView);
        gr_overallRemainingTime->setObjectName("gr_overallRemainingTime");
        sizePolicy3.setHeightForWidth(gr_overallRemainingTime->sizePolicy().hasHeightForWidth());
        gr_overallRemainingTime->setSizePolicy(sizePolicy3);
        gr_overallRemainingTime->setAlignment(Qt::AlignLeading|Qt::AlignLeft|Qt::AlignTop);

        graphicsGrid->addWidget(gr_overallRemainingTime, 1, 6, 1, 1);


        verticalLayout_3->addLayout(graphicsGrid);


        verticalLayout->addWidget(graphicalView);

        textView = new QWidget(CaptureCountsWidget);
        textView->setObjectName("textView");
        sizePolicy1.setHeightForWidth(textView->sizePolicy().hasHeightForWidth());
        textView->setSizePolicy(sizePolicy1);
        verticalLayout_2 = new QVBoxLayout(textView);
        verticalLayout_2->setObjectName("verticalLayout_2");
        verticalLayout_2->setContentsMargins(0, 0, 0, 0);
        imageProgress = new QProgressBar(textView);
        imageProgress->setObjectName("imageProgress");
        imageProgress->setMinimumSize(QSize(0, 4));
        imageProgress->setMaximumSize(QSize(16777215, 4));
        imageProgress->setStyleSheet(QString::fromUtf8("QProgressBar::chunk {\n"
"background-color: rgb(164, 0, 0);\n"
"}"));
        imageProgress->setValue(24);
        imageProgress->setTextVisible(false);

        verticalLayout_2->addWidget(imageProgress);

        gridLayout = new QGridLayout();
        gridLayout->setObjectName("gridLayout");
        gridLayout->setVerticalSpacing(0);
        gridLayout->setContentsMargins(-1, -1, -1, 0);
        sequenceLabel = new QLabel(textView);
        sequenceLabel->setObjectName("sequenceLabel");
        sequenceLabel->setAlignment(Qt::AlignRight|Qt::AlignTrailing|Qt::AlignVCenter);

        gridLayout->addWidget(sequenceLabel, 2, 3, 1, 1);

        frameRemainingTime = new QLabel(textView);
        frameRemainingTime->setObjectName("frameRemainingTime");
        frameRemainingTime->setMinimumSize(QSize(70, 0));
        frameRemainingTime->setAlignment(Qt::AlignRight|Qt::AlignTrailing|Qt::AlignVCenter);

        gridLayout->addWidget(frameRemainingTime, 2, 1, 1, 1);

        jobRemainingTime = new QLabel(textView);
        jobRemainingTime->setObjectName("jobRemainingTime");
        sizePolicy1.setHeightForWidth(jobRemainingTime->sizePolicy().hasHeightForWidth());
        jobRemainingTime->setSizePolicy(sizePolicy1);
        jobRemainingTime->setMinimumSize(QSize(70, 0));
        jobRemainingTime->setAlignment(Qt::AlignRight|Qt::AlignTop|Qt::AlignTrailing);

        gridLayout->addWidget(jobRemainingTime, 3, 4, 1, 1);

        frameInfoLabel = new QLabel(textView);
        frameInfoLabel->setObjectName("frameInfoLabel");
        sizePolicy1.setHeightForWidth(frameInfoLabel->sizePolicy().hasHeightForWidth());
        frameInfoLabel->setSizePolicy(sizePolicy1);
        frameInfoLabel->setFont(font);

        gridLayout->addWidget(frameInfoLabel, 2, 0, 1, 1);

        jobLabel = new QLabel(textView);
        jobLabel->setObjectName("jobLabel");
        jobLabel->setAlignment(Qt::AlignRight|Qt::AlignTrailing|Qt::AlignVCenter);

        gridLayout->addWidget(jobLabel, 2, 4, 1, 1);

        overallRemainingTime = new QLabel(textView);
        overallRemainingTime->setObjectName("overallRemainingTime");
        sizePolicy1.setHeightForWidth(overallRemainingTime->sizePolicy().hasHeightForWidth());
        overallRemainingTime->setSizePolicy(sizePolicy1);
        overallRemainingTime->setMinimumSize(QSize(70, 0));
        overallRemainingTime->setAlignment(Qt::AlignRight|Qt::AlignTop|Qt::AlignTrailing);
        overallRemainingTime->setMargin(0);

        gridLayout->addWidget(overallRemainingTime, 3, 5, 1, 1);

        overallLabel = new QLabel(textView);
        overallLabel->setObjectName("overallLabel");
        overallLabel->setAlignment(Qt::AlignRight|Qt::AlignTrailing|Qt::AlignVCenter);

        gridLayout->addWidget(overallLabel, 2, 5, 1, 1);

        horizontalSpacer = new QSpacerItem(10, 0, QSizePolicy::Policy::Expanding, QSizePolicy::Policy::Minimum);

        gridLayout->addItem(horizontalSpacer, 2, 2, 1, 1);

        horizontalSpacer_2 = new QSpacerItem(40, 20, QSizePolicy::Policy::Expanding, QSizePolicy::Policy::Minimum);

        gridLayout->addItem(horizontalSpacer_2, 3, 2, 1, 1);

        sequenceRemainingTime = new QLabel(textView);
        sequenceRemainingTime->setObjectName("sequenceRemainingTime");
        sizePolicy1.setHeightForWidth(sequenceRemainingTime->sizePolicy().hasHeightForWidth());
        sequenceRemainingTime->setSizePolicy(sizePolicy1);
        sequenceRemainingTime->setMinimumSize(QSize(70, 0));
        sequenceRemainingTime->setAlignment(Qt::AlignRight|Qt::AlignTop|Qt::AlignTrailing);

        gridLayout->addWidget(sequenceRemainingTime, 3, 3, 1, 1);

        frameDetailsLabel = new QLabel(textView);
        frameDetailsLabel->setObjectName("frameDetailsLabel");
        sizePolicy1.setHeightForWidth(frameDetailsLabel->sizePolicy().hasHeightForWidth());
        frameDetailsLabel->setSizePolicy(sizePolicy1);
        QFont font1;
        font1.setPointSize(11);
        frameDetailsLabel->setFont(font1);
        frameDetailsLabel->setAlignment(Qt::AlignLeading|Qt::AlignLeft|Qt::AlignTop);

        gridLayout->addWidget(frameDetailsLabel, 3, 0, 1, 2);

        switchToGraphicsButton = new QPushButton(textView);
        switchToGraphicsButton->setObjectName("switchToGraphicsButton");
        QSizePolicy sizePolicy4(QSizePolicy::Policy::Minimum, QSizePolicy::Policy::Maximum);
        sizePolicy4.setHorizontalStretch(0);
        sizePolicy4.setVerticalStretch(0);
        sizePolicy4.setHeightForWidth(switchToGraphicsButton->sizePolicy().hasHeightForWidth());
        switchToGraphicsButton->setSizePolicy(sizePolicy4);
        switchToGraphicsButton->setMinimumSize(QSize(20, 20));
        switchToGraphicsButton->setMaximumSize(QSize(20, 20));
        QIcon icon1(QIcon::fromTheme(QString::fromUtf8("arrow-up")));
        switchToGraphicsButton->setIcon(icon1);

        gridLayout->addWidget(switchToGraphicsButton, 3, 6, 1, 1);


        verticalLayout_2->addLayout(gridLayout);

        verticalLayout_2->setStretch(1, 1);

        verticalLayout->addWidget(textView);


        retranslateUi(CaptureCountsWidget);

        QMetaObject::connectSlotsByName(CaptureCountsWidget);
    } // setupUi

    void retranslateUi(QWidget *CaptureCountsWidget)
    {
        CaptureCountsWidget->setWindowTitle(tr2i18n("Ekos", nullptr));
#if QT_CONFIG(tooltip)
        gr_imageProgress->setToolTip(tr2i18n("Progress of the currently active capture.", nullptr));
#endif // QT_CONFIG(tooltip)
        gr_sequenceLabel->setText(tr2i18n("Sequence", nullptr));
        gr_overallLabel->setText(tr2i18n("Overall", nullptr));
        gr_frameDetailsLabel->setText(tr2i18n("exposure: 360 sec", nullptr));
#if QT_CONFIG(tooltip)
        gr_sequenceRemainingTime->setToolTip(tr2i18n("<html><head/><body><p>Remaining time to complete the active capture sequence</p></body></html>", nullptr));
#endif // QT_CONFIG(tooltip)
        gr_sequenceRemainingTime->setText(tr2i18n("--:--:--", nullptr));
        gr_frameLabel->setText(tr2i18n("Light Luminance", nullptr));
#if QT_CONFIG(tooltip)
        gr_sequenceProgressBar->setToolTip(tr2i18n("<html><head/><body><p>Captured images in active sequence</p></body></html>", nullptr));
#endif // QT_CONFIG(tooltip)
#if QT_CONFIG(tooltip)
        gr_overallProgressBar->setToolTip(tr2i18n("<html><head/><body><p>Percentage of total images captured</p></body></html>", nullptr));
#endif // QT_CONFIG(tooltip)
#if QT_CONFIG(tooltip)
        switchToTextButton->setToolTip(tr2i18n("Switch to the text display of capture counts display.", nullptr));
#endif // QT_CONFIG(tooltip)
        switchToTextButton->setText(QString());
#if QT_CONFIG(tooltip)
        gr_frameRemainingTime->setToolTip(tr2i18n("Remaining time for current capture", nullptr));
#endif // QT_CONFIG(tooltip)
        gr_frameRemainingTime->setText(tr2i18n("--:--:--", nullptr));
#if QT_CONFIG(tooltip)
        gr_overallRemainingTime->setToolTip(tr2i18n("<html><head/><body><p>Remaining time to completion</p></body></html>", nullptr));
#endif // QT_CONFIG(tooltip)
        gr_overallRemainingTime->setText(tr2i18n("--:--:--", nullptr));
#if QT_CONFIG(tooltip)
        imageProgress->setToolTip(tr2i18n("Progress of the currently active capture.", nullptr));
#endif // QT_CONFIG(tooltip)
        sequenceLabel->setText(tr2i18n("Sequence", nullptr));
#if QT_CONFIG(tooltip)
        frameRemainingTime->setToolTip(tr2i18n("Remaining time for current capture", nullptr));
#endif // QT_CONFIG(tooltip)
        frameRemainingTime->setText(tr2i18n("--:--:--", nullptr));
#if QT_CONFIG(tooltip)
        jobRemainingTime->setToolTip(tr2i18n("<html><head/><body><p>Remaining time to complete one job iteration</p></body></html>", nullptr));
#endif // QT_CONFIG(tooltip)
        jobRemainingTime->setText(tr2i18n("--:--:--", nullptr));
#if QT_CONFIG(tooltip)
        frameInfoLabel->setToolTip(tr2i18n("Type and filter (if present) of the currently active capture.", nullptr));
#endif // QT_CONFIG(tooltip)
        frameInfoLabel->setText(tr2i18n("Light Luminance", nullptr));
        jobLabel->setText(tr2i18n("Job", nullptr));
#if QT_CONFIG(tooltip)
        overallRemainingTime->setToolTip(tr2i18n("<html><head/><body><p>Remaining time to completion</p></body></html>", nullptr));
#endif // QT_CONFIG(tooltip)
        overallRemainingTime->setText(tr2i18n("--:--:--", nullptr));
        overallLabel->setText(tr2i18n("Total", nullptr));
#if QT_CONFIG(tooltip)
        sequenceRemainingTime->setToolTip(tr2i18n("<html><head/><body><p>Remaining time to complete the active capture sequence</p></body></html>", nullptr));
#endif // QT_CONFIG(tooltip)
        sequenceRemainingTime->setText(tr2i18n("--:--:--", nullptr));
        frameDetailsLabel->setText(tr2i18n("exposure: 360 sec", nullptr));
#if QT_CONFIG(tooltip)
        switchToGraphicsButton->setToolTip(tr2i18n("Switch display to the graphical mode of capture counts display.", nullptr));
#endif // QT_CONFIG(tooltip)
        switchToGraphicsButton->setText(QString());
    } // retranslateUi

};

namespace Ui {
    class CaptureCountsWidget: public Ui_CaptureCountsWidget {};
} // namespace Ui

QT_END_NAMESPACE

#endif // CAPTURECOUNTSWIDGET_H

