/********************************************************************************
** Form generated from reading UI file 'yaxistool.ui'
**
** Created by: Qt User Interface Compiler version 6.11.1
**
** WARNING! All changes made in this file will be lost when recompiling UI file!
********************************************************************************/

#ifndef UI_YAXISTOOL_H
#define UI_YAXISTOOL_H

#include <QtCore/QVariant>
#include <QtWidgets/QApplication>
#include <QtWidgets/QCheckBox>
#include <QtWidgets/QDoubleSpinBox>
#include <QtWidgets/QHBoxLayout>
#include <QtWidgets/QLabel>
#include <QtWidgets/QPushButton>
#include <QtWidgets/QSpacerItem>
#include <QtWidgets/QVBoxLayout>
#include <QtWidgets/QWidget>
#include <klocalizedstring.h>

QT_BEGIN_NAMESPACE

class Ui_YAxisTool
{
public:
    QVBoxLayout *verticalLayout_3;
    QVBoxLayout *verticalLayout;
    QLabel *statLabel;
    QLabel *statShortLabel;
    QSpacerItem *verticalSpacer_2;
    QHBoxLayout *horizontalLayout_2;
    QLabel *upperLimitLabel;
    QDoubleSpinBox *upperLimitSpin;
    QSpacerItem *horizontalSpacer_2;
    QHBoxLayout *horizontalLayout;
    QLabel *lowerLimitLabel;
    QDoubleSpinBox *lowerLimitSpin;
    QSpacerItem *horizontalSpacer;
    QCheckBox *autoLimitsCB;
    QCheckBox *leftAxisCB;
    QHBoxLayout *horizontalLayout_3;
    QLabel *label_2;
    QLabel *colorLabel;
    QPushButton *colorB;
    QSpacerItem *verticalSpacer_3;
    QPushButton *defaultB;
    QSpacerItem *verticalSpacer;

    void setupUi(QWidget *YAxisTool)
    {
        if (YAxisTool->objectName().isEmpty())
            YAxisTool->setObjectName("YAxisTool");
        YAxisTool->resize(300, 300);
        verticalLayout_3 = new QVBoxLayout(YAxisTool);
        verticalLayout_3->setObjectName("verticalLayout_3");
        verticalLayout = new QVBoxLayout();
        verticalLayout->setObjectName("verticalLayout");
        statLabel = new QLabel(YAxisTool);
        statLabel->setObjectName("statLabel");
        statLabel->setMaximumSize(QSize(16777215, 16777215));
        statLabel->setAlignment(Qt::AlignCenter);

        verticalLayout->addWidget(statLabel);

        statShortLabel = new QLabel(YAxisTool);
        statShortLabel->setObjectName("statShortLabel");
        QFont font;
        font.setPointSize(9);
        statShortLabel->setFont(font);
        statShortLabel->setAlignment(Qt::AlignCenter);

        verticalLayout->addWidget(statShortLabel);

        verticalSpacer_2 = new QSpacerItem(20, 20, QSizePolicy::Policy::Minimum, QSizePolicy::Policy::Fixed);

        verticalLayout->addItem(verticalSpacer_2);


        verticalLayout_3->addLayout(verticalLayout);

        horizontalLayout_2 = new QHBoxLayout();
        horizontalLayout_2->setObjectName("horizontalLayout_2");
        upperLimitLabel = new QLabel(YAxisTool);
        upperLimitLabel->setObjectName("upperLimitLabel");
        upperLimitLabel->setMaximumSize(QSize(100, 16777215));

        horizontalLayout_2->addWidget(upperLimitLabel);

        upperLimitSpin = new QDoubleSpinBox(YAxisTool);
        upperLimitSpin->setObjectName("upperLimitSpin");
        upperLimitSpin->setMaximumSize(QSize(100, 16777215));
        upperLimitSpin->setMinimum(-100000.000000000000000);
        upperLimitSpin->setMaximum(100000.000000000000000);

        horizontalLayout_2->addWidget(upperLimitSpin);

        horizontalSpacer_2 = new QSpacerItem(40, 20, QSizePolicy::Policy::Expanding, QSizePolicy::Policy::Minimum);

        horizontalLayout_2->addItem(horizontalSpacer_2);


        verticalLayout_3->addLayout(horizontalLayout_2);

        horizontalLayout = new QHBoxLayout();
        horizontalLayout->setObjectName("horizontalLayout");
        lowerLimitLabel = new QLabel(YAxisTool);
        lowerLimitLabel->setObjectName("lowerLimitLabel");
        lowerLimitLabel->setMaximumSize(QSize(100, 16777215));

        horizontalLayout->addWidget(lowerLimitLabel);

        lowerLimitSpin = new QDoubleSpinBox(YAxisTool);
        lowerLimitSpin->setObjectName("lowerLimitSpin");
        lowerLimitSpin->setMaximumSize(QSize(100, 16777215));
        lowerLimitSpin->setMinimum(-100000.000000000000000);
        lowerLimitSpin->setMaximum(100000.000000000000000);

        horizontalLayout->addWidget(lowerLimitSpin);

        horizontalSpacer = new QSpacerItem(40, 20, QSizePolicy::Policy::Expanding, QSizePolicy::Policy::Minimum);

        horizontalLayout->addItem(horizontalSpacer);


        verticalLayout_3->addLayout(horizontalLayout);

        autoLimitsCB = new QCheckBox(YAxisTool);
        autoLimitsCB->setObjectName("autoLimitsCB");
        autoLimitsCB->setMaximumSize(QSize(16777215, 16777215));

        verticalLayout_3->addWidget(autoLimitsCB);

        leftAxisCB = new QCheckBox(YAxisTool);
        leftAxisCB->setObjectName("leftAxisCB");

        verticalLayout_3->addWidget(leftAxisCB);

        horizontalLayout_3 = new QHBoxLayout();
        horizontalLayout_3->setObjectName("horizontalLayout_3");
        label_2 = new QLabel(YAxisTool);
        label_2->setObjectName("label_2");
        label_2->setMaximumSize(QSize(50, 16777206));
        label_2->setAlignment(Qt::AlignCenter);

        horizontalLayout_3->addWidget(label_2);

        colorLabel = new QLabel(YAxisTool);
        colorLabel->setObjectName("colorLabel");
        colorLabel->setMaximumSize(QSize(50, 16777215));

        horizontalLayout_3->addWidget(colorLabel);

        colorB = new QPushButton(YAxisTool);
        colorB->setObjectName("colorB");
        colorB->setMaximumSize(QSize(75, 16777215));

        horizontalLayout_3->addWidget(colorB);


        verticalLayout_3->addLayout(horizontalLayout_3);

        verticalSpacer_3 = new QSpacerItem(20, 30, QSizePolicy::Policy::Minimum, QSizePolicy::Policy::Expanding);

        verticalLayout_3->addItem(verticalSpacer_3);

        defaultB = new QPushButton(YAxisTool);
        defaultB->setObjectName("defaultB");

        verticalLayout_3->addWidget(defaultB);

        verticalSpacer = new QSpacerItem(20, 10, QSizePolicy::Policy::Minimum, QSizePolicy::Policy::Expanding);

        verticalLayout_3->addItem(verticalSpacer);


        retranslateUi(YAxisTool);

        QMetaObject::connectSlotsByName(YAxisTool);
    } // setupUi

    void retranslateUi(QWidget *YAxisTool)
    {
        statLabel->setText(tr2i18n("Stat Name", nullptr));
        statShortLabel->setText(tr2i18n("TextLabel", nullptr));
        upperLimitLabel->setText(tr2i18n("Upper Limit", nullptr));
        lowerLimitLabel->setText(tr2i18n("Lower Limit", nullptr));
        autoLimitsCB->setText(tr2i18n("Automatic Limits", nullptr));
        leftAxisCB->setText(tr2i18n("Use for Left Axis", nullptr));
        label_2->setText(tr2i18n("Color", nullptr));
        colorLabel->setText(QString());
        colorB->setText(tr2i18n("Change", nullptr));
        defaultB->setText(tr2i18n("Use Default Limits", nullptr));
        (void)YAxisTool;
    } // retranslateUi

};

namespace Ui {
    class YAxisTool: public Ui_YAxisTool {};
} // namespace Ui

QT_END_NAMESPACE

#endif // YAXISTOOL_H

