/********************************************************************************
** Form generated from reading UI file 'newview.ui'
**
** Created by: Qt User Interface Compiler version 6.11.1
**
** WARNING! All changes made in this file will be lost when recompiling UI file!
********************************************************************************/

#ifndef UI_NEWVIEW_H
#define UI_NEWVIEW_H

#include <QtCore/QVariant>
#include <QtWidgets/QAbstractButton>
#include <QtWidgets/QApplication>
#include <QtWidgets/QCheckBox>
#include <QtWidgets/QComboBox>
#include <QtWidgets/QDialog>
#include <QtWidgets/QDialogButtonBox>
#include <QtWidgets/QFrame>
#include <QtWidgets/QGridLayout>
#include <QtWidgets/QHBoxLayout>
#include <QtWidgets/QLabel>
#include <QtWidgets/QLineEdit>
#include <QtWidgets/QRadioButton>
#include <QtWidgets/QSlider>
#include <QtWidgets/QSpacerItem>
#include <QtWidgets/QVBoxLayout>
#include <klocalizedstring.h>
#include "widgets/unitspinboxwidget.h"

QT_BEGIN_NAMESPACE

class Ui_NewView
{
public:
    QVBoxLayout *verticalLayout;
    QHBoxLayout *horizontalLayout;
    QLabel *label;
    QLineEdit *viewNameLineEdit;
    QFrame *line_4;
    QHBoxLayout *horizontalLayout_2;
    QLabel *label_2;
    QComboBox *mountTypeComboBox;
    QSpacerItem *horizontalSpacer_2;
    QLabel *label_5;
    QFrame *line_3;
    QGridLayout *gridLayout;
    QRadioButton *correctViewType;
    QRadioButton *mirroredViewType;
    QRadioButton *invertedViewType;
    QLabel *label_3;
    QRadioButton *invertedMirroredViewType;
    QFrame *line;
    QHBoxLayout *horizontalLayout_3;
    QLabel *label_4;
    QSlider *viewingAngleSlider;
    QLabel *viewingAngleLabel;
    QGridLayout *gridLayout_2;
    QLabel *label_8;
    QLabel *label_7;
    QLabel *label_6;
    QLabel *viewingAnglePreviewBottom;
    QLabel *viewingAnglePreviewTop;
    QLabel *label_9;
    QLabel *label_10;
    QCheckBox *disableErectObserverCheckBox;
    QFrame *line_2;
    QHBoxLayout *horizontalLayout_4;
    QCheckBox *fieldOfViewCheckBox;
    UnitSpinBoxWidget *fieldOfViewSpinBox;
    QSpacerItem *horizontalSpacer;
    QSpacerItem *verticalSpacer_2;
    QDialogButtonBox *buttonBox;

    void setupUi(QDialog *NewView)
    {
        if (NewView->objectName().isEmpty())
            NewView->setObjectName("NewView");
        NewView->resize(640, 662);
        verticalLayout = new QVBoxLayout(NewView);
        verticalLayout->setObjectName("verticalLayout");
        horizontalLayout = new QHBoxLayout();
        horizontalLayout->setObjectName("horizontalLayout");
        label = new QLabel(NewView);
        label->setObjectName("label");

        horizontalLayout->addWidget(label);

        viewNameLineEdit = new QLineEdit(NewView);
        viewNameLineEdit->setObjectName("viewNameLineEdit");

        horizontalLayout->addWidget(viewNameLineEdit);


        verticalLayout->addLayout(horizontalLayout);

        line_4 = new QFrame(NewView);
        line_4->setObjectName("line_4");
        line_4->setFrameShape(QFrame::Shape::HLine);
        line_4->setFrameShadow(QFrame::Shadow::Sunken);

        verticalLayout->addWidget(line_4);

        horizontalLayout_2 = new QHBoxLayout();
        horizontalLayout_2->setObjectName("horizontalLayout_2");
        label_2 = new QLabel(NewView);
        label_2->setObjectName("label_2");

        horizontalLayout_2->addWidget(label_2);

        mountTypeComboBox = new QComboBox(NewView);
        mountTypeComboBox->addItem(QString());
        mountTypeComboBox->addItem(QString());
        mountTypeComboBox->setObjectName("mountTypeComboBox");

        horizontalLayout_2->addWidget(mountTypeComboBox);

        horizontalSpacer_2 = new QSpacerItem(40, 20, QSizePolicy::Policy::Expanding, QSizePolicy::Policy::Minimum);

        horizontalLayout_2->addItem(horizontalSpacer_2);


        verticalLayout->addLayout(horizontalLayout_2);

        label_5 = new QLabel(NewView);
        label_5->setObjectName("label_5");
        label_5->setTextFormat(Qt::MarkdownText);
        label_5->setWordWrap(true);

        verticalLayout->addWidget(label_5);

        line_3 = new QFrame(NewView);
        line_3->setObjectName("line_3");
        line_3->setFrameShape(QFrame::Shape::HLine);
        line_3->setFrameShadow(QFrame::Shadow::Sunken);

        verticalLayout->addWidget(line_3);

        gridLayout = new QGridLayout();
        gridLayout->setObjectName("gridLayout");
        correctViewType = new QRadioButton(NewView);
        correctViewType->setObjectName("correctViewType");

        gridLayout->addWidget(correctViewType, 3, 0, 1, 1);

        mirroredViewType = new QRadioButton(NewView);
        mirroredViewType->setObjectName("mirroredViewType");

        gridLayout->addWidget(mirroredViewType, 2, 0, 1, 1);

        invertedViewType = new QRadioButton(NewView);
        invertedViewType->setObjectName("invertedViewType");

        gridLayout->addWidget(invertedViewType, 1, 0, 1, 1);

        label_3 = new QLabel(NewView);
        label_3->setObjectName("label_3");

        gridLayout->addWidget(label_3, 0, 0, 1, 1);

        invertedMirroredViewType = new QRadioButton(NewView);
        invertedMirroredViewType->setObjectName("invertedMirroredViewType");

        gridLayout->addWidget(invertedMirroredViewType, 4, 0, 1, 1);


        verticalLayout->addLayout(gridLayout);

        line = new QFrame(NewView);
        line->setObjectName("line");
        line->setFrameShape(QFrame::Shape::HLine);
        line->setFrameShadow(QFrame::Shadow::Sunken);

        verticalLayout->addWidget(line);

        horizontalLayout_3 = new QHBoxLayout();
        horizontalLayout_3->setObjectName("horizontalLayout_3");
        label_4 = new QLabel(NewView);
        label_4->setObjectName("label_4");

        horizontalLayout_3->addWidget(label_4);

        viewingAngleSlider = new QSlider(NewView);
        viewingAngleSlider->setObjectName("viewingAngleSlider");
        viewingAngleSlider->setMinimum(-179);
        viewingAngleSlider->setMaximum(179);
        viewingAngleSlider->setOrientation(Qt::Horizontal);
        viewingAngleSlider->setTickPosition(QSlider::TicksBothSides);

        horizontalLayout_3->addWidget(viewingAngleSlider);

        viewingAngleLabel = new QLabel(NewView);
        viewingAngleLabel->setObjectName("viewingAngleLabel");
        QSizePolicy sizePolicy(QSizePolicy::Policy::Fixed, QSizePolicy::Policy::Preferred);
        sizePolicy.setHorizontalStretch(0);
        sizePolicy.setVerticalStretch(0);
        sizePolicy.setHeightForWidth(viewingAngleLabel->sizePolicy().hasHeightForWidth());
        viewingAngleLabel->setSizePolicy(sizePolicy);
        viewingAngleLabel->setMinimumSize(QSize(40, 0));
        viewingAngleLabel->setAlignment(Qt::AlignRight|Qt::AlignTrailing|Qt::AlignVCenter);

        horizontalLayout_3->addWidget(viewingAngleLabel);


        verticalLayout->addLayout(horizontalLayout_3);

        gridLayout_2 = new QGridLayout();
        gridLayout_2->setObjectName("gridLayout_2");
        label_8 = new QLabel(NewView);
        label_8->setObjectName("label_8");
        label_8->setAlignment(Qt::AlignCenter);

        gridLayout_2->addWidget(label_8, 1, 1, 1, 1);

        label_7 = new QLabel(NewView);
        label_7->setObjectName("label_7");
        label_7->setAlignment(Qt::AlignCenter);

        gridLayout_2->addWidget(label_7, 1, 0, 1, 1);

        label_6 = new QLabel(NewView);
        label_6->setObjectName("label_6");
        label_6->setAlignment(Qt::AlignCenter);

        gridLayout_2->addWidget(label_6, 3, 0, 1, 2);

        viewingAnglePreviewBottom = new QLabel(NewView);
        viewingAnglePreviewBottom->setObjectName("viewingAnglePreviewBottom");
        viewingAnglePreviewBottom->setMinimumSize(QSize(200, 150));

        gridLayout_2->addWidget(viewingAnglePreviewBottom, 0, 1, 1, 1);

        viewingAnglePreviewTop = new QLabel(NewView);
        viewingAnglePreviewTop->setObjectName("viewingAnglePreviewTop");
        viewingAnglePreviewTop->setMinimumSize(QSize(200, 150));

        gridLayout_2->addWidget(viewingAnglePreviewTop, 0, 0, 1, 1);

        label_9 = new QLabel(NewView);
        label_9->setObjectName("label_9");
        label_9->setAlignment(Qt::AlignCenter);

        gridLayout_2->addWidget(label_9, 2, 0, 1, 1);

        label_10 = new QLabel(NewView);
        label_10->setObjectName("label_10");
        label_10->setAlignment(Qt::AlignCenter);

        gridLayout_2->addWidget(label_10, 2, 1, 1, 1);


        verticalLayout->addLayout(gridLayout_2);

        disableErectObserverCheckBox = new QCheckBox(NewView);
        disableErectObserverCheckBox->setObjectName("disableErectObserverCheckBox");

        verticalLayout->addWidget(disableErectObserverCheckBox);

        line_2 = new QFrame(NewView);
        line_2->setObjectName("line_2");
        line_2->setFrameShape(QFrame::Shape::HLine);
        line_2->setFrameShadow(QFrame::Shadow::Sunken);

        verticalLayout->addWidget(line_2);

        horizontalLayout_4 = new QHBoxLayout();
        horizontalLayout_4->setObjectName("horizontalLayout_4");
        fieldOfViewCheckBox = new QCheckBox(NewView);
        fieldOfViewCheckBox->setObjectName("fieldOfViewCheckBox");
        fieldOfViewCheckBox->setMinimumSize(QSize(0, 30));

        horizontalLayout_4->addWidget(fieldOfViewCheckBox);

        fieldOfViewSpinBox = new UnitSpinBoxWidget(NewView);
        fieldOfViewSpinBox->setObjectName("fieldOfViewSpinBox");
        fieldOfViewSpinBox->setMinimumSize(QSize(195, 0));

        horizontalLayout_4->addWidget(fieldOfViewSpinBox);

        horizontalSpacer = new QSpacerItem(40, 20, QSizePolicy::Policy::Expanding, QSizePolicy::Policy::Minimum);

        horizontalLayout_4->addItem(horizontalSpacer);


        verticalLayout->addLayout(horizontalLayout_4);

        verticalSpacer_2 = new QSpacerItem(20, 40, QSizePolicy::Policy::Minimum, QSizePolicy::Policy::Expanding);

        verticalLayout->addItem(verticalSpacer_2);

        buttonBox = new QDialogButtonBox(NewView);
        buttonBox->setObjectName("buttonBox");
        buttonBox->setOrientation(Qt::Horizontal);
        buttonBox->setStandardButtons(QDialogButtonBox::Cancel|QDialogButtonBox::Ok);

        verticalLayout->addWidget(buttonBox);


        retranslateUi(NewView);
        QObject::connect(buttonBox, &QDialogButtonBox::accepted, NewView, qOverload<>(&QDialog::accept));
        QObject::connect(buttonBox, &QDialogButtonBox::rejected, NewView, qOverload<>(&QDialog::reject));

        mountTypeComboBox->setCurrentIndex(1);


        QMetaObject::connectSlotsByName(NewView);
    } // setupUi

    void retranslateUi(QDialog *NewView)
    {
        NewView->setWindowTitle(tr2i18n("Add / Edit View", nullptr));
        label->setText(tr2i18n("Name:", nullptr));
        viewNameLineEdit->setPlaceholderText(tr2i18n("9x50 RACI finder on Dob", nullptr));
        label_2->setText(tr2i18n("Mount Type:", nullptr));
        mountTypeComboBox->setItemText(0, tr2i18n("Equatorial", nullptr));
        mountTypeComboBox->setItemText(1, tr2i18n("Altazimuth", nullptr));

        label_5->setText(tr2i18n("**Note:** Choose mount type \"Altazimuth\" when visually observing through SCTs / refractors, irrespective of the actual mounting.", nullptr));
        correctViewType->setText(tr2i18n("Correct (e.g. RACI finder or refractor with Amici roof prism)", nullptr));
        mirroredViewType->setText(tr2i18n("Mirrored (e.g. Cassegrain or refractor with erecting prism)", nullptr));
        invertedViewType->setText(tr2i18n("Inverted (e.g. straight through finder, Newtonian)", nullptr));
        label_3->setText(tr2i18n("View Type:", nullptr));
        invertedMirroredViewType->setText(tr2i18n("Mirrored on the vertical axis (i.e. inverted and mirrored)", nullptr));
        label_4->setText(tr2i18n("Eyepiece Angle:", nullptr));
        viewingAngleLabel->setText(tr2i18n("###\302\260", nullptr));
        label_8->setText(tr2i18n("Telescopes with the eyepiece at the bottom", nullptr));
        label_7->setText(tr2i18n("Telescopes with the eyepiece at the top", nullptr));
        label_6->setText(tr2i18n("The human silhouette indicates on which side of the telescope the observer is assumed to stand.", nullptr));
        viewingAnglePreviewBottom->setText(QString());
        viewingAnglePreviewTop->setText(QString());
        label_9->setText(tr2i18n("(Preview shows view down a Newtonian's tube)", nullptr));
        label_10->setText(tr2i18n("(Preview shows view of the back of an SCT)", nullptr));
        disableErectObserverCheckBox->setText(tr2i18n("Display mounted on the telescope (also check this if using a camera instead of visual observation)", nullptr));
        fieldOfViewCheckBox->setText(tr2i18n("Also set the field of view", nullptr));
    } // retranslateUi

};

namespace Ui {
    class NewView: public Ui_NewView {};
} // namespace Ui

QT_END_NAMESPACE

#endif // NEWVIEW_H

