/********************************************************************************
** Form generated from reading UI file 'focusadvisorhelp.ui'
**
** Created by: Qt User Interface Compiler version 6.11.1
**
** WARNING! All changes made in this file will be lost when recompiling UI file!
********************************************************************************/

#ifndef UI_FOCUSADVISORHELP_H
#define UI_FOCUSADVISORHELP_H

#include <QtCore/QVariant>
#include <QtWidgets/QAbstractButton>
#include <QtWidgets/QApplication>
#include <QtWidgets/QCheckBox>
#include <QtWidgets/QDialog>
#include <QtWidgets/QDialogButtonBox>
#include <QtWidgets/QHBoxLayout>
#include <QtWidgets/QHeaderView>
#include <QtWidgets/QLabel>
#include <QtWidgets/QTableWidget>
#include <QtWidgets/QVBoxLayout>
#include <klocalizedstring.h>

QT_BEGIN_NAMESPACE

class Ui_focusAdvisorHelpDialog
{
public:
    QVBoxLayout *verticalLayout;
    QLabel *helpLabel;
    QTableWidget *table;
    QHBoxLayout *horizontalLayout;
    QCheckBox *focusAdvHelpOnlyChanges;
    QDialogButtonBox *buttonBox;

    void setupUi(QDialog *focusAdvisorHelpDialog)
    {
        if (focusAdvisorHelpDialog->objectName().isEmpty())
            focusAdvisorHelpDialog->setObjectName("focusAdvisorHelpDialog");
        focusAdvisorHelpDialog->resize(444, 263);
        verticalLayout = new QVBoxLayout(focusAdvisorHelpDialog);
        verticalLayout->setObjectName("verticalLayout");
        helpLabel = new QLabel(focusAdvisorHelpDialog);
        helpLabel->setObjectName("helpLabel");
        QSizePolicy sizePolicy(QSizePolicy::Policy::Preferred, QSizePolicy::Policy::Fixed);
        sizePolicy.setHorizontalStretch(0);
        sizePolicy.setVerticalStretch(0);
        sizePolicy.setHeightForWidth(helpLabel->sizePolicy().hasHeightForWidth());
        helpLabel->setSizePolicy(sizePolicy);

        verticalLayout->addWidget(helpLabel);

        table = new QTableWidget(focusAdvisorHelpDialog);
        if (table->columnCount() < 3)
            table->setColumnCount(3);
        if (table->rowCount() < 2)
            table->setRowCount(2);
        table->setObjectName("table");
        table->setSizeAdjustPolicy(QAbstractScrollArea::AdjustToContents);
        table->setEditTriggers(QAbstractItemView::NoEditTriggers);
        table->setAlternatingRowColors(true);
        table->setRowCount(2);
        table->setColumnCount(3);
        table->horizontalHeader()->setCascadingSectionResizes(false);

        verticalLayout->addWidget(table);

        horizontalLayout = new QHBoxLayout();
        horizontalLayout->setObjectName("horizontalLayout");
        focusAdvHelpOnlyChanges = new QCheckBox(focusAdvisorHelpDialog);
        focusAdvHelpOnlyChanges->setObjectName("focusAdvHelpOnlyChanges");
        sizePolicy.setHeightForWidth(focusAdvHelpOnlyChanges->sizePolicy().hasHeightForWidth());
        focusAdvHelpOnlyChanges->setSizePolicy(sizePolicy);
        focusAdvHelpOnlyChanges->setChecked(true);

        horizontalLayout->addWidget(focusAdvHelpOnlyChanges);

        buttonBox = new QDialogButtonBox(focusAdvisorHelpDialog);
        buttonBox->setObjectName("buttonBox");
        buttonBox->setOrientation(Qt::Horizontal);
        buttonBox->setStandardButtons(QDialogButtonBox::Close);

        horizontalLayout->addWidget(buttonBox);


        verticalLayout->addLayout(horizontalLayout);


        retranslateUi(focusAdvisorHelpDialog);
        QObject::connect(buttonBox, &QDialogButtonBox::accepted, focusAdvisorHelpDialog, qOverload<>(&QDialog::accept));
        QObject::connect(buttonBox, &QDialogButtonBox::rejected, focusAdvisorHelpDialog, qOverload<>(&QDialog::reject));

        QMetaObject::connectSlotsByName(focusAdvisorHelpDialog);
    } // setupUi

    void retranslateUi(QDialog *focusAdvisorHelpDialog)
    {
        focusAdvisorHelpDialog->setWindowTitle(tr2i18n("Focus Advisor Help", nullptr));
        helpLabel->setText(tr2i18n("Recommendations:", nullptr));
#if QT_CONFIG(tooltip)
        focusAdvHelpOnlyChanges->setToolTip(tr2i18n("Check to display only recommended changes", nullptr));
#endif // QT_CONFIG(tooltip)
        focusAdvHelpOnlyChanges->setText(tr2i18n("Show Only Changes", nullptr));
    } // retranslateUi

};

namespace Ui {
    class focusAdvisorHelpDialog: public Ui_focusAdvisorHelpDialog {};
} // namespace Ui

QT_END_NAMESPACE

#endif // FOCUSADVISORHELP_H

