/********************************************************************************
** Form generated from reading UI file 'focusdialog.ui'
**
** Created by: Qt User Interface Compiler version 6.11.1
**
** WARNING! All changes made in this file will be lost when recompiling UI file!
********************************************************************************/

#ifndef UI_FOCUSDIALOG_H
#define UI_FOCUSDIALOG_H

#include <QtCore/QVariant>
#include <QtWidgets/QApplication>
#include <QtWidgets/QGridLayout>
#include <QtWidgets/QLabel>
#include <QtWidgets/QLineEdit>
#include <QtWidgets/QPushButton>
#include <QtWidgets/QSpacerItem>
#include <QtWidgets/QTabWidget>
#include <QtWidgets/QVBoxLayout>
#include <QtWidgets/QWidget>
#include <klocalizedstring.h>
#include "widgets/dmsbox.h"

QT_BEGIN_NAMESPACE

class Ui_FocusDialog
{
public:
    QVBoxLayout *vboxLayout;
    QTabWidget *fdTab;
    QWidget *rdTab;
    QGridLayout *gridLayout;
    QSpacerItem *verticalSpacer_2;
    QLabel *decLabel;
    QPushButton *JNowB;
    QPushButton *J2000B;
    dmsBox *raBox;
    QLabel *raLabel;
    QLabel *epochLabel;
    QLineEdit *epochBox;
    dmsBox *decBox;
    QWidget *aaTab;
    QGridLayout *gridLayout_2;
    QLabel *label;
    QLabel *label_2;
    dmsBox *altBox;
    QSpacerItem *verticalSpacer;
    dmsBox *azBox;
    QSpacerItem *horizontalSpacer;

    void setupUi(QWidget *FocusDialog)
    {
        if (FocusDialog->objectName().isEmpty())
            FocusDialog->setObjectName("FocusDialog");
        FocusDialog->resize(306, 172);
        vboxLayout = new QVBoxLayout(FocusDialog);
        vboxLayout->setSpacing(3);
        vboxLayout->setObjectName("vboxLayout");
        vboxLayout->setContentsMargins(3, 3, 3, 3);
        fdTab = new QTabWidget(FocusDialog);
        fdTab->setObjectName("fdTab");
        rdTab = new QWidget();
        rdTab->setObjectName("rdTab");
        gridLayout = new QGridLayout(rdTab);
        gridLayout->setObjectName("gridLayout");
        verticalSpacer_2 = new QSpacerItem(20, 40, QSizePolicy::Policy::Minimum, QSizePolicy::Policy::Expanding);

        gridLayout->addItem(verticalSpacer_2, 3, 0, 1, 1);

        decLabel = new QLabel(rdTab);
        decLabel->setObjectName("decLabel");
        QSizePolicy sizePolicy(QSizePolicy::Policy::Preferred, QSizePolicy::Policy::Preferred);
        sizePolicy.setHorizontalStretch(0);
        sizePolicy.setVerticalStretch(0);
        sizePolicy.setHeightForWidth(decLabel->sizePolicy().hasHeightForWidth());
        decLabel->setSizePolicy(sizePolicy);

        gridLayout->addWidget(decLabel, 1, 0, 1, 1);

        JNowB = new QPushButton(rdTab);
        JNowB->setObjectName("JNowB");

        gridLayout->addWidget(JNowB, 2, 2, 1, 1);

        J2000B = new QPushButton(rdTab);
        J2000B->setObjectName("J2000B");

        gridLayout->addWidget(J2000B, 2, 3, 1, 1);

        raBox = new dmsBox(rdTab);
        raBox->setObjectName("raBox");
        raBox->setClearButtonEnabled(true);

        gridLayout->addWidget(raBox, 0, 1, 1, 3);

        raLabel = new QLabel(rdTab);
        raLabel->setObjectName("raLabel");
        sizePolicy.setHeightForWidth(raLabel->sizePolicy().hasHeightForWidth());
        raLabel->setSizePolicy(sizePolicy);

        gridLayout->addWidget(raLabel, 0, 0, 1, 1);

        epochLabel = new QLabel(rdTab);
        epochLabel->setObjectName("epochLabel");

        gridLayout->addWidget(epochLabel, 2, 0, 1, 1);

        epochBox = new QLineEdit(rdTab);
        epochBox->setObjectName("epochBox");

        gridLayout->addWidget(epochBox, 2, 1, 1, 1);

        decBox = new dmsBox(rdTab);
        decBox->setObjectName("decBox");
        decBox->setClearButtonEnabled(true);

        gridLayout->addWidget(decBox, 1, 1, 1, 3);

        fdTab->addTab(rdTab, QString());
        aaTab = new QWidget();
        aaTab->setObjectName("aaTab");
        gridLayout_2 = new QGridLayout(aaTab);
        gridLayout_2->setObjectName("gridLayout_2");
        label = new QLabel(aaTab);
        label->setObjectName("label");
        sizePolicy.setHeightForWidth(label->sizePolicy().hasHeightForWidth());
        label->setSizePolicy(sizePolicy);

        gridLayout_2->addWidget(label, 0, 0, 1, 1);

        label_2 = new QLabel(aaTab);
        label_2->setObjectName("label_2");
        sizePolicy.setHeightForWidth(label_2->sizePolicy().hasHeightForWidth());
        label_2->setSizePolicy(sizePolicy);

        gridLayout_2->addWidget(label_2, 1, 0, 1, 1);

        altBox = new dmsBox(aaTab);
        altBox->setObjectName("altBox");
        QSizePolicy sizePolicy1(QSizePolicy::Policy::Expanding, QSizePolicy::Policy::Fixed);
        sizePolicy1.setHorizontalStretch(0);
        sizePolicy1.setVerticalStretch(0);
        sizePolicy1.setHeightForWidth(altBox->sizePolicy().hasHeightForWidth());
        altBox->setSizePolicy(sizePolicy1);
        altBox->setClearButtonEnabled(true);

        gridLayout_2->addWidget(altBox, 1, 1, 1, 1);

        verticalSpacer = new QSpacerItem(20, 40, QSizePolicy::Policy::Minimum, QSizePolicy::Policy::Expanding);

        gridLayout_2->addItem(verticalSpacer, 2, 1, 1, 1);

        azBox = new dmsBox(aaTab);
        azBox->setObjectName("azBox");
        sizePolicy1.setHeightForWidth(azBox->sizePolicy().hasHeightForWidth());
        azBox->setSizePolicy(sizePolicy1);
        azBox->setClearButtonEnabled(true);

        gridLayout_2->addWidget(azBox, 0, 1, 1, 1);

        horizontalSpacer = new QSpacerItem(40, 20, QSizePolicy::Policy::Expanding, QSizePolicy::Policy::Minimum);

        gridLayout_2->addItem(horizontalSpacer, 0, 2, 1, 1);

        fdTab->addTab(aaTab, QString());

        vboxLayout->addWidget(fdTab);

        QWidget::setTabOrder(fdTab, raBox);
        QWidget::setTabOrder(raBox, decBox);
        QWidget::setTabOrder(decBox, epochBox);
        QWidget::setTabOrder(epochBox, JNowB);
        QWidget::setTabOrder(JNowB, J2000B);
        QWidget::setTabOrder(J2000B, azBox);
        QWidget::setTabOrder(azBox, altBox);

        retranslateUi(FocusDialog);

        fdTab->setCurrentIndex(0);


        QMetaObject::connectSlotsByName(FocusDialog);
    } // setupUi

    void retranslateUi(QWidget *FocusDialog)
    {
#if QT_CONFIG(tooltip)
        decLabel->setToolTip(tr2i18n("Declination", nullptr));
#endif // QT_CONFIG(tooltip)
        decLabel->setText(tr2i18n("DE:", nullptr));
#if QT_CONFIG(tooltip)
        JNowB->setToolTip(tr2i18n("Set Epoch to now", nullptr));
#endif // QT_CONFIG(tooltip)
        JNowB->setText(tr2i18n("JNow", nullptr));
#if QT_CONFIG(tooltip)
        J2000B->setToolTip(tr2i18n("Set Epoch to J2000", nullptr));
#endif // QT_CONFIG(tooltip)
        J2000B->setText(tr2i18n("J2000", nullptr));
#if QT_CONFIG(tooltip)
        raLabel->setToolTip(tr2i18n("Right Ascension", nullptr));
#endif // QT_CONFIG(tooltip)
        raLabel->setText(tr2i18n("RA:", nullptr));
        epochLabel->setText(tr2i18n("Epoch:", nullptr));
        epochBox->setText(tr2i18n("2000.0", nullptr));
        fdTab->setTabText(fdTab->indexOf(rdTab), tr2i18n("RA/Dec", nullptr));
#if QT_CONFIG(tooltip)
        label->setToolTip(tr2i18n("Azimuth", nullptr));
#endif // QT_CONFIG(tooltip)
        label->setText(tr2i18n("Az:", nullptr));
#if QT_CONFIG(tooltip)
        label_2->setToolTip(tr2i18n("Altitude. Interpreted as the apparent altitude when refraction corrections are enabled.", nullptr));
#endif // QT_CONFIG(tooltip)
        label_2->setText(tr2i18n("Alt (apparent):", nullptr));
        fdTab->setTabText(fdTab->indexOf(aaTab), tr2i18n("Az/Alt", nullptr));
        (void)FocusDialog;
    } // retranslateUi

};

namespace Ui {
    class FocusDialog: public Ui_FocusDialog {};
} // namespace Ui

QT_END_NAMESPACE

#endif // FOCUSDIALOG_H

