/********************************************************************************
** Form generated from reading UI file 'modcalcvlsr.ui'
**
** Created by: Qt User Interface Compiler version 6.11.1
**
** WARNING! All changes made in this file will be lost when recompiling UI file!
********************************************************************************/

#ifndef UI_MODCALCVLSR_H
#define UI_MODCALCVLSR_H

#include <QtCore/QVariant>
#include <QtWidgets/QApplication>
#include <QtWidgets/QCheckBox>
#include <QtWidgets/QComboBox>
#include <QtWidgets/QDateEdit>
#include <QtWidgets/QDateTimeEdit>
#include <QtWidgets/QGridLayout>
#include <QtWidgets/QGroupBox>
#include <QtWidgets/QHBoxLayout>
#include <QtWidgets/QLabel>
#include <QtWidgets/QLineEdit>
#include <QtWidgets/QPushButton>
#include <QtWidgets/QRadioButton>
#include <QtWidgets/QSpacerItem>
#include <QtWidgets/QTabWidget>
#include <QtWidgets/QTextBrowser>
#include <QtWidgets/QTimeEdit>
#include <QtWidgets/QVBoxLayout>
#include <QtWidgets/QWidget>
#include <klocalizedstring.h>
#include "KUrlRequester"
#include "widgets/dmsbox.h"

QT_BEGIN_NAMESPACE

class Ui_modCalcVlsrDlg
{
public:
    QVBoxLayout *vboxLayout;
    QTabWidget *tabWidget;
    QWidget *interact;
    QVBoxLayout *vboxLayout1;
    QGridLayout *gridLayout;
    QLabel *label_2;
    QHBoxLayout *hboxLayout;
    QDateTimeEdit *Date;
    QPushButton *NowButton;
    QLabel *label_3;
    QPushButton *LocationButton;
    QSpacerItem *spacerItem;
    QLabel *label_4;
    QGridLayout *gridLayout1;
    QSpacerItem *spacerItem1;
    QSpacerItem *spacerItem2;
    QPushButton *ObjectButton;
    QSpacerItem *spacerItem3;
    QSpacerItem *spacerItem4;
    QLabel *label_6;
    dmsBox *RA;
    QSpacerItem *spacerItem5;
    QSpacerItem *spacerItem6;
    QLabel *label_7;
    dmsBox *Dec;
    QSpacerItem *spacerItem7;
    QSpacerItem *spacerItem8;
    QLabel *label_5;
    QSpacerItem *spacerItem9;
    QLabel *azLabel;
    QLineEdit *VLSR;
    QSpacerItem *spacerItem10;
    QSpacerItem *spacerItem11;
    QLabel *textLabel1;
    QLineEdit *VHelio;
    QSpacerItem *spacerItem12;
    QSpacerItem *spacerItem13;
    QLabel *textLabel2;
    QLineEdit *VGeo;
    QSpacerItem *spacerItem14;
    QSpacerItem *spacerItem15;
    QLabel *textLabel3;
    QLineEdit *VTopo;
    QSpacerItem *spacerItem16;
    QSpacerItem *spacerItem17;
    QWidget *batch;
    QVBoxLayout *vboxLayout2;
    QGroupBox *groupBox_5;
    QVBoxLayout *vboxLayout3;
    QGridLayout *gridLayout2;
    QCheckBox *DecCheckBatch;
    QLineEdit *EpochBoxBatch;
    QCheckBox *ElevationCheckBatch;
    QCheckBox *RACheckBatch;
    dmsBox *LongitudeBoxBatch;
    QCheckBox *EpochCheckBatch;
    QCheckBox *LongCheckBatch;
    QLineEdit *ElevationBoxBatch;
    QCheckBox *LatCheckBatch;
    QTimeEdit *UTBoxBatch;
    dmsBox *RABoxBatch;
    dmsBox *DecBoxBatch;
    QCheckBox *UTCheckBatch;
    dmsBox *LatitudeBoxBatch;
    QCheckBox *DateCheckBatch;
    QDateEdit *DateBoxBatch;
    QHBoxLayout *hboxLayout1;
    QCheckBox *InputVelocityCheckBatch;
    QComboBox *InputVelocityComboBatch;
    QLineEdit *InputVelocityBoxBatch;
    QSpacerItem *spacerItem18;
    QGroupBox *groupBox_6;
    QHBoxLayout *hboxLayout2;
    QRadioButton *AllRadioBatch;
    QRadioButton *InputRadioBatch;
    QGroupBox *groupBox_7;
    QGridLayout *gridLayout3;
    KUrlRequester *OutputFileBoxBatch;
    KUrlRequester *InputFileBoxBatch;
    QLabel *label_10;
    QLabel *label_9;
    QHBoxLayout *hboxLayout3;
    QSpacerItem *spacerItem19;
    QPushButton *RunButtonBatch;
    QSpacerItem *spacerItem20;
    QSpacerItem *spacerItem21;
    QWidget *overview;
    QVBoxLayout *vboxLayout4;
    QTextBrowser *OverviewBox;

    void setupUi(QWidget *modCalcVlsrDlg)
    {
        if (modCalcVlsrDlg->objectName().isEmpty())
            modCalcVlsrDlg->setObjectName("modCalcVlsrDlg");
        modCalcVlsrDlg->resize(488, 548);
        vboxLayout = new QVBoxLayout(modCalcVlsrDlg);
#ifndef UI_Q_OS_MAC
        vboxLayout->setSpacing(6);
#endif
#ifndef UI_Q_OS_MAC
        vboxLayout->setContentsMargins(9, 9, 9, 9);
#endif
        vboxLayout->setObjectName("vboxLayout");
        tabWidget = new QTabWidget(modCalcVlsrDlg);
        tabWidget->setObjectName("tabWidget");
        interact = new QWidget();
        interact->setObjectName("interact");
        interact->setGeometry(QRect(0, 0, 458, 492));
        vboxLayout1 = new QVBoxLayout(interact);
#ifndef UI_Q_OS_MAC
        vboxLayout1->setSpacing(6);
#endif
#ifndef UI_Q_OS_MAC
        vboxLayout1->setContentsMargins(9, 9, 9, 9);
#endif
        vboxLayout1->setObjectName("vboxLayout1");
        gridLayout = new QGridLayout();
#ifndef UI_Q_OS_MAC
        gridLayout->setSpacing(6);
#endif
#ifndef UI_Q_OS_MAC
        gridLayout->setContentsMargins(0, 0, 0, 0);
#endif
        gridLayout->setObjectName("gridLayout");
        label_2 = new QLabel(interact);
        label_2->setObjectName("label_2");

        gridLayout->addWidget(label_2, 0, 0, 1, 1);

        hboxLayout = new QHBoxLayout();
#ifndef UI_Q_OS_MAC
        hboxLayout->setSpacing(6);
#endif
        hboxLayout->setContentsMargins(0, 0, 0, 0);
        hboxLayout->setObjectName("hboxLayout");
        Date = new QDateTimeEdit(interact);
        Date->setObjectName("Date");

        hboxLayout->addWidget(Date);

        NowButton = new QPushButton(interact);
        NowButton->setObjectName("NowButton");

        hboxLayout->addWidget(NowButton);


        gridLayout->addLayout(hboxLayout, 0, 1, 1, 1);

        label_3 = new QLabel(interact);
        label_3->setObjectName("label_3");

        gridLayout->addWidget(label_3, 1, 0, 1, 1);

        LocationButton = new QPushButton(interact);
        LocationButton->setObjectName("LocationButton");

        gridLayout->addWidget(LocationButton, 1, 1, 1, 1);


        vboxLayout1->addLayout(gridLayout);

        spacerItem = new QSpacerItem(331, 20, QSizePolicy::Policy::Expanding, QSizePolicy::Policy::Minimum);

        vboxLayout1->addItem(spacerItem);

        label_4 = new QLabel(interact);
        label_4->setObjectName("label_4");
        QFont font;
        font.setBold(true);
        label_4->setFont(font);

        vboxLayout1->addWidget(label_4);

        gridLayout1 = new QGridLayout();
#ifndef UI_Q_OS_MAC
        gridLayout1->setSpacing(6);
#endif
        gridLayout1->setContentsMargins(0, 0, 0, 0);
        gridLayout1->setObjectName("gridLayout1");
        spacerItem1 = new QSpacerItem(61, 20, QSizePolicy::Policy::Expanding, QSizePolicy::Policy::Minimum);

        gridLayout1->addItem(spacerItem1, 0, 0, 1, 1);

        spacerItem2 = new QSpacerItem(40, 20, QSizePolicy::Policy::Minimum, QSizePolicy::Policy::Minimum);

        gridLayout1->addItem(spacerItem2, 0, 1, 1, 1);

        ObjectButton = new QPushButton(interact);
        ObjectButton->setObjectName("ObjectButton");

        gridLayout1->addWidget(ObjectButton, 0, 2, 1, 1);

        spacerItem3 = new QSpacerItem(40, 20, QSizePolicy::Policy::Expanding, QSizePolicy::Policy::Minimum);

        gridLayout1->addItem(spacerItem3, 0, 3, 1, 1);

        spacerItem4 = new QSpacerItem(61, 20, QSizePolicy::Policy::Expanding, QSizePolicy::Policy::Minimum);

        gridLayout1->addItem(spacerItem4, 1, 0, 1, 1);

        label_6 = new QLabel(interact);
        label_6->setObjectName("label_6");

        gridLayout1->addWidget(label_6, 1, 1, 1, 1);

        RA = new dmsBox(interact);
        RA->setObjectName("RA");
        RA->setMinimumSize(QSize(120, 0));

        gridLayout1->addWidget(RA, 1, 2, 1, 1);

        spacerItem5 = new QSpacerItem(40, 20, QSizePolicy::Policy::Expanding, QSizePolicy::Policy::Minimum);

        gridLayout1->addItem(spacerItem5, 1, 3, 1, 1);

        spacerItem6 = new QSpacerItem(61, 20, QSizePolicy::Policy::Expanding, QSizePolicy::Policy::Minimum);

        gridLayout1->addItem(spacerItem6, 2, 0, 1, 1);

        label_7 = new QLabel(interact);
        label_7->setObjectName("label_7");

        gridLayout1->addWidget(label_7, 2, 1, 1, 1);

        Dec = new dmsBox(interact);
        Dec->setObjectName("Dec");

        gridLayout1->addWidget(Dec, 2, 2, 1, 1);

        spacerItem7 = new QSpacerItem(40, 20, QSizePolicy::Policy::Expanding, QSizePolicy::Policy::Minimum);

        gridLayout1->addItem(spacerItem7, 2, 3, 1, 1);

        spacerItem8 = new QSpacerItem(321, 20, QSizePolicy::Policy::Expanding, QSizePolicy::Policy::Minimum);

        gridLayout1->addItem(spacerItem8, 3, 0, 1, 4);

        label_5 = new QLabel(interact);
        label_5->setObjectName("label_5");
        label_5->setFont(font);

        gridLayout1->addWidget(label_5, 4, 0, 1, 4);

        spacerItem9 = new QSpacerItem(61, 20, QSizePolicy::Policy::Expanding, QSizePolicy::Policy::Minimum);

        gridLayout1->addItem(spacerItem9, 5, 0, 1, 1);

        azLabel = new QLabel(interact);
        azLabel->setObjectName("azLabel");

        gridLayout1->addWidget(azLabel, 5, 1, 1, 1);

        VLSR = new QLineEdit(interact);
        VLSR->setObjectName("VLSR");

        gridLayout1->addWidget(VLSR, 5, 2, 1, 1);

        spacerItem10 = new QSpacerItem(61, 20, QSizePolicy::Policy::Expanding, QSizePolicy::Policy::Minimum);

        gridLayout1->addItem(spacerItem10, 5, 3, 1, 1);

        spacerItem11 = new QSpacerItem(61, 20, QSizePolicy::Policy::Expanding, QSizePolicy::Policy::Minimum);

        gridLayout1->addItem(spacerItem11, 6, 0, 1, 1);

        textLabel1 = new QLabel(interact);
        textLabel1->setObjectName("textLabel1");

        gridLayout1->addWidget(textLabel1, 6, 1, 1, 1);

        VHelio = new QLineEdit(interact);
        VHelio->setObjectName("VHelio");

        gridLayout1->addWidget(VHelio, 6, 2, 1, 1);

        spacerItem12 = new QSpacerItem(61, 20, QSizePolicy::Policy::Expanding, QSizePolicy::Policy::Minimum);

        gridLayout1->addItem(spacerItem12, 6, 3, 1, 1);

        spacerItem13 = new QSpacerItem(61, 20, QSizePolicy::Policy::Expanding, QSizePolicy::Policy::Minimum);

        gridLayout1->addItem(spacerItem13, 7, 0, 1, 1);

        textLabel2 = new QLabel(interact);
        textLabel2->setObjectName("textLabel2");

        gridLayout1->addWidget(textLabel2, 7, 1, 1, 1);

        VGeo = new QLineEdit(interact);
        VGeo->setObjectName("VGeo");

        gridLayout1->addWidget(VGeo, 7, 2, 1, 1);

        spacerItem14 = new QSpacerItem(61, 20, QSizePolicy::Policy::Expanding, QSizePolicy::Policy::Minimum);

        gridLayout1->addItem(spacerItem14, 7, 3, 1, 1);

        spacerItem15 = new QSpacerItem(61, 20, QSizePolicy::Policy::Expanding, QSizePolicy::Policy::Minimum);

        gridLayout1->addItem(spacerItem15, 8, 0, 1, 1);

        textLabel3 = new QLabel(interact);
        textLabel3->setObjectName("textLabel3");

        gridLayout1->addWidget(textLabel3, 8, 1, 1, 1);

        VTopo = new QLineEdit(interact);
        VTopo->setObjectName("VTopo");

        gridLayout1->addWidget(VTopo, 8, 2, 1, 1);

        spacerItem16 = new QSpacerItem(61, 20, QSizePolicy::Policy::Expanding, QSizePolicy::Policy::Minimum);

        gridLayout1->addItem(spacerItem16, 8, 3, 1, 1);


        vboxLayout1->addLayout(gridLayout1);

        spacerItem17 = new QSpacerItem(20, 40, QSizePolicy::Policy::Minimum, QSizePolicy::Policy::Expanding);

        vboxLayout1->addItem(spacerItem17);

        tabWidget->addTab(interact, QString());
        batch = new QWidget();
        batch->setObjectName("batch");
        batch->setGeometry(QRect(0, 0, 100, 30));
        vboxLayout2 = new QVBoxLayout(batch);
#ifndef UI_Q_OS_MAC
        vboxLayout2->setSpacing(6);
#endif
#ifndef UI_Q_OS_MAC
        vboxLayout2->setContentsMargins(9, 9, 9, 9);
#endif
        vboxLayout2->setObjectName("vboxLayout2");
        groupBox_5 = new QGroupBox(batch);
        groupBox_5->setObjectName("groupBox_5");
        vboxLayout3 = new QVBoxLayout(groupBox_5);
#ifndef UI_Q_OS_MAC
        vboxLayout3->setSpacing(6);
#endif
#ifndef UI_Q_OS_MAC
        vboxLayout3->setContentsMargins(9, 9, 9, 9);
#endif
        vboxLayout3->setObjectName("vboxLayout3");
        gridLayout2 = new QGridLayout();
#ifndef UI_Q_OS_MAC
        gridLayout2->setSpacing(6);
#endif
#ifndef UI_Q_OS_MAC
        gridLayout2->setContentsMargins(0, 0, 0, 0);
#endif
        gridLayout2->setObjectName("gridLayout2");
        DecCheckBatch = new QCheckBox(groupBox_5);
        DecCheckBatch->setObjectName("DecCheckBatch");
        DecCheckBatch->setChecked(true);

        gridLayout2->addWidget(DecCheckBatch, 3, 0, 1, 1);

        EpochBoxBatch = new QLineEdit(groupBox_5);
        EpochBoxBatch->setObjectName("EpochBoxBatch");

        gridLayout2->addWidget(EpochBoxBatch, 3, 3, 1, 1);

        ElevationCheckBatch = new QCheckBox(groupBox_5);
        ElevationCheckBatch->setObjectName("ElevationCheckBatch");
        ElevationCheckBatch->setChecked(false);

        gridLayout2->addWidget(ElevationCheckBatch, 2, 2, 1, 1);

        RACheckBatch = new QCheckBox(groupBox_5);
        RACheckBatch->setObjectName("RACheckBatch");
        RACheckBatch->setChecked(true);

        gridLayout2->addWidget(RACheckBatch, 2, 0, 1, 1);

        LongitudeBoxBatch = new dmsBox(groupBox_5);
        LongitudeBoxBatch->setObjectName("LongitudeBoxBatch");

        gridLayout2->addWidget(LongitudeBoxBatch, 0, 3, 1, 1);

        EpochCheckBatch = new QCheckBox(groupBox_5);
        EpochCheckBatch->setObjectName("EpochCheckBatch");

        gridLayout2->addWidget(EpochCheckBatch, 3, 2, 1, 1);

        LongCheckBatch = new QCheckBox(groupBox_5);
        LongCheckBatch->setObjectName("LongCheckBatch");
        LongCheckBatch->setChecked(false);

        gridLayout2->addWidget(LongCheckBatch, 0, 2, 1, 1);

        ElevationBoxBatch = new QLineEdit(groupBox_5);
        ElevationBoxBatch->setObjectName("ElevationBoxBatch");

        gridLayout2->addWidget(ElevationBoxBatch, 2, 3, 1, 1);

        LatCheckBatch = new QCheckBox(groupBox_5);
        LatCheckBatch->setObjectName("LatCheckBatch");
        LatCheckBatch->setChecked(false);

        gridLayout2->addWidget(LatCheckBatch, 1, 2, 1, 1);

        UTBoxBatch = new QTimeEdit(groupBox_5);
        UTBoxBatch->setObjectName("UTBoxBatch");

        gridLayout2->addWidget(UTBoxBatch, 0, 1, 1, 1);

        RABoxBatch = new dmsBox(groupBox_5);
        RABoxBatch->setObjectName("RABoxBatch");
        RABoxBatch->setEnabled(false);

        gridLayout2->addWidget(RABoxBatch, 2, 1, 1, 1);

        DecBoxBatch = new dmsBox(groupBox_5);
        DecBoxBatch->setObjectName("DecBoxBatch");
        DecBoxBatch->setEnabled(false);

        gridLayout2->addWidget(DecBoxBatch, 3, 1, 1, 1);

        UTCheckBatch = new QCheckBox(groupBox_5);
        UTCheckBatch->setObjectName("UTCheckBatch");
        UTCheckBatch->setChecked(false);

        gridLayout2->addWidget(UTCheckBatch, 0, 0, 1, 1);

        LatitudeBoxBatch = new dmsBox(groupBox_5);
        LatitudeBoxBatch->setObjectName("LatitudeBoxBatch");

        gridLayout2->addWidget(LatitudeBoxBatch, 1, 3, 1, 1);

        DateCheckBatch = new QCheckBox(groupBox_5);
        DateCheckBatch->setObjectName("DateCheckBatch");
        DateCheckBatch->setChecked(false);

        gridLayout2->addWidget(DateCheckBatch, 1, 0, 1, 1);

        DateBoxBatch = new QDateEdit(groupBox_5);
        DateBoxBatch->setObjectName("DateBoxBatch");

        gridLayout2->addWidget(DateBoxBatch, 1, 1, 1, 1);


        vboxLayout3->addLayout(gridLayout2);

        hboxLayout1 = new QHBoxLayout();
#ifndef UI_Q_OS_MAC
        hboxLayout1->setSpacing(6);
#endif
        hboxLayout1->setContentsMargins(0, 0, 0, 0);
        hboxLayout1->setObjectName("hboxLayout1");
        InputVelocityCheckBatch = new QCheckBox(groupBox_5);
        InputVelocityCheckBatch->setObjectName("InputVelocityCheckBatch");

        hboxLayout1->addWidget(InputVelocityCheckBatch);

        InputVelocityComboBatch = new QComboBox(groupBox_5);
        InputVelocityComboBatch->addItem(QString());
        InputVelocityComboBatch->addItem(QString());
        InputVelocityComboBatch->addItem(QString());
        InputVelocityComboBatch->addItem(QString());
        InputVelocityComboBatch->setObjectName("InputVelocityComboBatch");

        hboxLayout1->addWidget(InputVelocityComboBatch);

        InputVelocityBoxBatch = new QLineEdit(groupBox_5);
        InputVelocityBoxBatch->setObjectName("InputVelocityBoxBatch");

        hboxLayout1->addWidget(InputVelocityBoxBatch);

        spacerItem18 = new QSpacerItem(40, 20, QSizePolicy::Policy::Expanding, QSizePolicy::Policy::Minimum);

        hboxLayout1->addItem(spacerItem18);


        vboxLayout3->addLayout(hboxLayout1);


        vboxLayout2->addWidget(groupBox_5);

        groupBox_6 = new QGroupBox(batch);
        groupBox_6->setObjectName("groupBox_6");
        hboxLayout2 = new QHBoxLayout(groupBox_6);
#ifndef UI_Q_OS_MAC
        hboxLayout2->setSpacing(6);
#endif
#ifndef UI_Q_OS_MAC
        hboxLayout2->setContentsMargins(9, 9, 9, 9);
#endif
        hboxLayout2->setObjectName("hboxLayout2");
        AllRadioBatch = new QRadioButton(groupBox_6);
        AllRadioBatch->setObjectName("AllRadioBatch");

        hboxLayout2->addWidget(AllRadioBatch);

        InputRadioBatch = new QRadioButton(groupBox_6);
        InputRadioBatch->setObjectName("InputRadioBatch");
        InputRadioBatch->setChecked(true);

        hboxLayout2->addWidget(InputRadioBatch);


        vboxLayout2->addWidget(groupBox_6);

        groupBox_7 = new QGroupBox(batch);
        groupBox_7->setObjectName("groupBox_7");
        gridLayout3 = new QGridLayout(groupBox_7);
#ifndef UI_Q_OS_MAC
        gridLayout3->setSpacing(6);
#endif
#ifndef UI_Q_OS_MAC
        gridLayout3->setContentsMargins(9, 9, 9, 9);
#endif
        gridLayout3->setObjectName("gridLayout3");
        OutputFileBoxBatch = new KUrlRequester(groupBox_7);
        OutputFileBoxBatch->setObjectName("OutputFileBoxBatch");

        gridLayout3->addWidget(OutputFileBoxBatch, 1, 1, 1, 1);

        InputFileBoxBatch = new KUrlRequester(groupBox_7);
        InputFileBoxBatch->setObjectName("InputFileBoxBatch");

        gridLayout3->addWidget(InputFileBoxBatch, 0, 1, 1, 1);

        label_10 = new QLabel(groupBox_7);
        label_10->setObjectName("label_10");

        gridLayout3->addWidget(label_10, 1, 0, 1, 1);

        label_9 = new QLabel(groupBox_7);
        label_9->setObjectName("label_9");

        gridLayout3->addWidget(label_9, 0, 0, 1, 1);


        vboxLayout2->addWidget(groupBox_7);

        hboxLayout3 = new QHBoxLayout();
#ifndef UI_Q_OS_MAC
        hboxLayout3->setSpacing(6);
#endif
        hboxLayout3->setContentsMargins(0, 0, 0, 0);
        hboxLayout3->setObjectName("hboxLayout3");
        spacerItem19 = new QSpacerItem(40, 20, QSizePolicy::Policy::Expanding, QSizePolicy::Policy::Minimum);

        hboxLayout3->addItem(spacerItem19);

        RunButtonBatch = new QPushButton(batch);
        RunButtonBatch->setObjectName("RunButtonBatch");
        QSizePolicy sizePolicy(QSizePolicy::Policy::Expanding, QSizePolicy::Policy::Preferred);
        sizePolicy.setHorizontalStretch(0);
        sizePolicy.setVerticalStretch(0);
        sizePolicy.setHeightForWidth(RunButtonBatch->sizePolicy().hasHeightForWidth());
        RunButtonBatch->setSizePolicy(sizePolicy);

        hboxLayout3->addWidget(RunButtonBatch);

        spacerItem20 = new QSpacerItem(40, 20, QSizePolicy::Policy::Expanding, QSizePolicy::Policy::Minimum);

        hboxLayout3->addItem(spacerItem20);


        vboxLayout2->addLayout(hboxLayout3);

        spacerItem21 = new QSpacerItem(20, 40, QSizePolicy::Policy::Minimum, QSizePolicy::Policy::Expanding);

        vboxLayout2->addItem(spacerItem21);

        tabWidget->addTab(batch, QString());
        overview = new QWidget();
        overview->setObjectName("overview");
        overview->setGeometry(QRect(0, 0, 100, 30));
        vboxLayout4 = new QVBoxLayout(overview);
#ifndef UI_Q_OS_MAC
        vboxLayout4->setSpacing(6);
#endif
#ifndef UI_Q_OS_MAC
        vboxLayout4->setContentsMargins(9, 9, 9, 9);
#endif
        vboxLayout4->setObjectName("vboxLayout4");
        OverviewBox = new QTextBrowser(overview);
        OverviewBox->setObjectName("OverviewBox");

        vboxLayout4->addWidget(OverviewBox);

        tabWidget->addTab(overview, QString());

        vboxLayout->addWidget(tabWidget);


        retranslateUi(modCalcVlsrDlg);

        tabWidget->setCurrentIndex(0);


        QMetaObject::connectSlotsByName(modCalcVlsrDlg);
    } // setupUi

    void retranslateUi(QWidget *modCalcVlsrDlg)
    {
        label_2->setText(tr2i18n("Date and time:", nullptr));
        NowButton->setText(tr2i18n("Now", nullptr));
        label_3->setText(tr2i18n("Location:", nullptr));
        LocationButton->setText(tr2i18n("Greenwich, United Kingdom", nullptr));
        label_4->setText(tr2i18n("Target position:", nullptr));
        ObjectButton->setText(tr2i18n("Select Object...", nullptr));
        label_6->setText(tr2i18n("Right ascension:", nullptr));
        label_7->setText(tr2i18n("Declination:", nullptr));
        label_5->setText(tr2i18n("Radial velocities:", nullptr));
        azLabel->setText(tr2i18n("V<sub>LSR</sub>:", nullptr));
        textLabel1->setText(tr2i18n("Heliocentric:", nullptr));
        textLabel2->setText(tr2i18n("Geocentric:", nullptr));
        textLabel3->setText(tr2i18n("Topocentric:", nullptr));
        tabWidget->setTabText(tabWidget->indexOf(interact), tr2i18n("Interactive Mode", nullptr));
        groupBox_5->setTitle(tr2i18n("Select Parameters in Input File", nullptr));
        DecCheckBatch->setText(tr2i18n("Dec:", nullptr));
        ElevationCheckBatch->setText(tr2i18n("Elevation (m):", nullptr));
        RACheckBatch->setText(tr2i18n("RA:", nullptr));
        EpochCheckBatch->setText(tr2i18n("Epoch:", nullptr));
        LongCheckBatch->setText(tr2i18n("Longitude:", nullptr));
        LatCheckBatch->setText(tr2i18n("Latitude:", nullptr));
        UTCheckBatch->setText(tr2i18n("UT:", nullptr));
        DateCheckBatch->setText(tr2i18n("Date:", nullptr));
        InputVelocityCheckBatch->setText(tr2i18n("Input velocity:", nullptr));
        InputVelocityComboBatch->setItemText(0, tr2i18n("Heliocentric", nullptr));
        InputVelocityComboBatch->setItemText(1, tr2i18n("Geocentric", nullptr));
        InputVelocityComboBatch->setItemText(2, tr2i18n("Topocentric", nullptr));
        InputVelocityComboBatch->setItemText(3, tr2i18n("LSR", nullptr));

        groupBox_6->setTitle(tr2i18n("Select Parameters for Output File", nullptr));
        AllRadioBatch->setText(tr2i18n("All parameters", nullptr));
        InputRadioBatch->setText(tr2i18n("Only parameters in input file", nullptr));
        groupBox_7->setTitle(tr2i18n("Select Filenames", nullptr));
        label_10->setText(tr2i18n("Output file:", nullptr));
        label_9->setText(tr2i18n("Input file:", nullptr));
        RunButtonBatch->setText(tr2i18n("Run", nullptr));
        tabWidget->setTabText(tabWidget->indexOf(batch), tr2i18n("Batch Mode", nullptr));
        tabWidget->setTabText(tabWidget->indexOf(overview), tr2i18n("Overview", nullptr));
        (void)modCalcVlsrDlg;
    } // retranslateUi

};

namespace Ui {
    class modCalcVlsrDlg: public Ui_modCalcVlsrDlg {};
} // namespace Ui

QT_END_NAMESPACE

#endif // MODCALCVLSR_H

