/*
 * This file was generated by qdbusxml2cpp version 0.8
 * Source file was org.kde.kstars.Ekos.Align.xml
 *
 * qdbusxml2cpp is Copyright (C) The Qt Company Ltd. and other contributors.
 *
 * This is an auto-generated file.
 * This file may have been hand-edited. Look for HAND-EDIT comments
 * before re-generating it.
 */

#ifndef ALIGNADAPTOR_H
#define ALIGNADAPTOR_H

#include <QtCore/QObject>
#include <QtDBus/QtDBus>
#include "ekos/align/align.h"
#include <QtCore/qcontainerfwd.h>

/*
 * Adaptor class for interface org.kde.kstars.Ekos.Align
 */
class AlignAdaptor: public QDBusAbstractAdaptor
{
    Q_OBJECT
    Q_CLASSINFO("D-Bus Interface", "org.kde.kstars.Ekos.Align")
    Q_CLASSINFO("D-Bus Introspection", ""
"  <interface name=\"org.kde.kstars.Ekos.Align\">\n"
"    <property access=\"readwrite\" type=\"s\" name=\"opticalTrain\"/>\n"
"    <property access=\"read\" type=\"s\" name=\"camera\"/>\n"
"    <property access=\"read\" type=\"s\" name=\"filterWheel\"/>\n"
"    <property access=\"readwrite\" type=\"s\" name=\"filter\"/>\n"
"    <property access=\"read\" type=\"as\" name=\"logText\"/>\n"
"    <property access=\"read\" type=\"i\" name=\"status\">\n"
"      <annotation value=\"Ekos::AlignState\" name=\"org.qtproject.QtDBus.QtTypeName\"/>\n"
"    </property>\n"
"    <property access=\"read\" type=\"ad\" name=\"fov\">\n"
"      <annotation value=\"QList&lt;double&gt;\" name=\"org.qtproject.QtDBus.QtTypeName\"/>\n"
"    </property>\n"
"    <property access=\"readwrite\" type=\"s\" name=\"solverArguments\"/>\n"
"    <method name=\"abort\">\n"
"      <annotation value=\"true\" name=\"org.freedesktop.DBus.Method.NoReply\"/>\n"
"    </method>\n"
"    <method name=\"captureAndSolve\">\n"
"      <arg direction=\"out\" type=\"b\"/>\n"
"    </method>\n"
"    <method name=\"loadAndSlew\">\n"
"      <arg direction=\"out\" type=\"b\"/>\n"
"      <arg direction=\"in\" type=\"s\" name=\"fileURL\"/>\n"
"    </method>\n"
"    <method name=\"setSolverMode\">\n"
"      <arg direction=\"in\" type=\"u\" name=\"mode\"/>\n"
"      <annotation value=\"true\" name=\"org.freedesktop.DBus.Method.NoReply\"/>\n"
"    </method>\n"
"    <method name=\"setSolverAction\">\n"
"      <arg direction=\"in\" type=\"i\" name=\"mode\"/>\n"
"      <annotation value=\"true\" name=\"org.freedesktop.DBus.Method.NoReply\"/>\n"
"    </method>\n"
"    <method name=\"cameraInfo\">\n"
"      <arg direction=\"out\" type=\"ad\"/>\n"
"      <annotation value=\"QList&lt;double&gt;\" name=\"org.qtproject.QtDBus.QtTypeName.In0\"/>\n"
"      <annotation value=\"QList&lt;double&gt;\" name=\"org.qtproject.QtDBus.QtTypeName.Out0\"/>\n"
"    </method>\n"
"    <method name=\"getSolutionResult\">\n"
"      <arg direction=\"out\" type=\"ad\"/>\n"
"      <annotation value=\"QList&lt;double&gt;\" name=\"org.qtproject.QtDBus.QtTypeName.In0\"/>\n"
"      <annotation value=\"QList&lt;double&gt;\" name=\"org.qtproject.QtDBus.QtTypeName.Out0\"/>\n"
"    </method>\n"
"    <method name=\"telescopeInfo\">\n"
"      <arg direction=\"out\" type=\"ad\"/>\n"
"      <annotation value=\"QList&lt;double&gt;\" name=\"org.qtproject.QtDBus.QtTypeName.In0\"/>\n"
"      <annotation value=\"QList&lt;double&gt;\" name=\"org.qtproject.QtDBus.QtTypeName.Out0\"/>\n"
"    </method>\n"
"    <method name=\"getLoadAndSlewStatus\">\n"
"      <arg direction=\"out\" type=\"i\"/>\n"
"    </method>\n"
"    <method name=\"setBinningIndex\">\n"
"      <arg direction=\"in\" type=\"i\" name=\"binningIndex\"/>\n"
"      <annotation value=\"true\" name=\"org.freedesktop.DBus.Method.NoReply\"/>\n"
"    </method>\n"
"    <method name=\"setTargetCoords\">\n"
"      <arg direction=\"in\" type=\"d\" name=\"ra\"/>\n"
"      <arg direction=\"in\" type=\"d\" name=\"de\"/>\n"
"      <annotation value=\"true\" name=\"org.freedesktop.DBus.Method.NoReply\"/>\n"
"    </method>\n"
"    <method name=\"getTargetCoords\">\n"
"      <arg direction=\"out\" type=\"ad\"/>\n"
"      <annotation value=\"QList&lt;double&gt;\" name=\"org.qtproject.QtDBus.QtTypeName.In0\"/>\n"
"      <annotation value=\"QList&lt;double&gt;\" name=\"org.qtproject.QtDBus.QtTypeName.Out0\"/>\n"
"    </method>\n"
"    <method name=\"setTargetPositionAngle\">\n"
"      <arg direction=\"in\" type=\"d\" name=\"value\"/>\n"
"      <annotation value=\"true\" name=\"org.freedesktop.DBus.Method.NoReply\"/>\n"
"    </method>\n"
"    <signal name=\"newStatus\">\n"
"      <arg direction=\"out\" type=\"(i)\" name=\"status\"/>\n"
"      <annotation value=\"Ekos::AlignState\" name=\"org.qtproject.QtDBus.QtTypeName.In0\"/>\n"
"      <annotation value=\"Ekos::AlignState\" name=\"org.qtproject.QtDBus.QtTypeName.Out0\"/>\n"
"    </signal>\n"
"    <signal name=\"newSolution\">\n"
"      <arg direction=\"out\" type=\"a{sv}\" name=\"solution\"/>\n"
"      <annotation value=\"QVariantMap\" name=\"org.qtproject.QtDBus.QtTypeName.In0\"/>\n"
"      <annotation value=\"QVariantMap\" name=\"org.qtproject.QtDBus.QtTypeName.Out0\"/>\n"
"    </signal>\n"
"    <signal name=\"newLog\">\n"
"      <arg direction=\"out\" type=\"s\" name=\"text\"/>\n"
"    </signal>\n"
"  </interface>\n"
        "")
public:
    AlignAdaptor(Ekos::Align *parent);
    ~AlignAdaptor() override;

    inline Ekos::Align *parent() const
    { return static_cast<Ekos::Align *>(QObject::parent()); }

public: // PROPERTIES
    Q_PROPERTY(QString camera READ camera)
    QString camera() const;

    Q_PROPERTY(QString filter READ filter WRITE setFilter)
    QString filter() const;
    void setFilter(const QString &value);

    Q_PROPERTY(QString filterWheel READ filterWheel)
    QString filterWheel() const;

    Q_PROPERTY(QList<double> fov READ fov)
    QList<double> fov() const;

    Q_PROPERTY(QStringList logText READ logText)
    QStringList logText() const;

    Q_PROPERTY(QString opticalTrain READ opticalTrain WRITE setOpticalTrain)
    QString opticalTrain() const;
    void setOpticalTrain(const QString &value);

    Q_PROPERTY(QString solverArguments READ solverArguments WRITE setSolverArguments)
    QString solverArguments() const;
    void setSolverArguments(const QString &value);

    Q_PROPERTY(int status READ status)
    int status() const;

public Q_SLOTS: // METHODS
    Q_NOREPLY void abort();
    QList<double> cameraInfo();
    bool captureAndSolve();
    int getLoadAndSlewStatus();
    QList<double> getSolutionResult();
    QList<double> getTargetCoords();
    bool loadAndSlew(const QString &fileURL);
    Q_NOREPLY void setBinningIndex(int binningIndex);
    Q_NOREPLY void setSolverAction(int mode);
    Q_NOREPLY void setSolverMode(uint mode);
    Q_NOREPLY void setTargetCoords(double ra, double de);
    Q_NOREPLY void setTargetPositionAngle(double value);
    QList<double> telescopeInfo();
Q_SIGNALS: // SIGNALS
    void newLog(const QString &text);
    void newSolution(const QVariantMap &solution);
    void newStatus(Ekos::AlignState status);
};

#endif
