/********************************************************************************
** Form generated from reading UI file 'pwizobjectselection.ui'
**
** Created by: Qt User Interface Compiler version 6.11.1
**
** WARNING! All changes made in this file will be lost when recompiling UI file!
********************************************************************************/

#ifndef UI_PWIZOBJECTSELECTION_H
#define UI_PWIZOBJECTSELECTION_H

#include <QtCore/QVariant>
#include <QtWidgets/QApplication>
#include <QtWidgets/QHBoxLayout>
#include <QtWidgets/QLabel>
#include <QtWidgets/QPushButton>
#include <QtWidgets/QSpacerItem>
#include <QtWidgets/QVBoxLayout>
#include <QtWidgets/QWidget>
#include <klocalizedstring.h>

QT_BEGIN_NAMESPACE

class Ui_PWizObjectSelection
{
public:
    QHBoxLayout *horizontalLayout;
    QLabel *banner;
    QSpacerItem *horSpacer6;
    QVBoxLayout *selectObjectLayout;
    QLabel *stepTitle;
    QSpacerItem *vertSpacer1;
    QLabel *stepText;
    QSpacerItem *vertSpacer2;
    QHBoxLayout *horLayout1;
    QSpacerItem *horSpacer1;
    QPushButton *fromListButton;
    QSpacerItem *horSpacer2;
    QPushButton *pointButton;
    QSpacerItem *horSpacer3;
    QSpacerItem *vertSpacer3;
    QLabel *selectedObjLabel;
    QLabel *objInfoLabel;
    QHBoxLayout *horLayout2;
    QSpacerItem *horSpacer4;
    QPushButton *detailsButton;
    QSpacerItem *horSpacer5;
    QSpacerItem *vertSpacer4;

    void setupUi(QWidget *PWizObjectSelection)
    {
        if (PWizObjectSelection->objectName().isEmpty())
            PWizObjectSelection->setObjectName("PWizObjectSelection");
        PWizObjectSelection->resize(586, 395);
        horizontalLayout = new QHBoxLayout(PWizObjectSelection);
        horizontalLayout->setObjectName("horizontalLayout");
        banner = new QLabel(PWizObjectSelection);
        banner->setObjectName("banner");
        QSizePolicy sizePolicy(QSizePolicy::Policy::Fixed, QSizePolicy::Policy::Fixed);
        sizePolicy.setHorizontalStretch(0);
        sizePolicy.setVerticalStretch(0);
        sizePolicy.setHeightForWidth(banner->sizePolicy().hasHeightForWidth());
        banner->setSizePolicy(sizePolicy);
        banner->setMinimumSize(QSize(120, 360));

        horizontalLayout->addWidget(banner);

        horSpacer6 = new QSpacerItem(5, 20, QSizePolicy::Policy::Fixed, QSizePolicy::Policy::Minimum);

        horizontalLayout->addItem(horSpacer6);

        selectObjectLayout = new QVBoxLayout();
#ifndef UI_Q_OS_MAC
        selectObjectLayout->setSpacing(6);
#endif
        selectObjectLayout->setContentsMargins(0, 0, 0, 0);
        selectObjectLayout->setObjectName("selectObjectLayout");
        stepTitle = new QLabel(PWizObjectSelection);
        stepTitle->setObjectName("stepTitle");
        QFont font;
        font.setFamilies({QString::fromUtf8("Sans Serif")});
        font.setPointSize(11);
        font.setBold(true);
        font.setItalic(false);
        font.setUnderline(false);
        font.setStrikeOut(false);
        stepTitle->setFont(font);

        selectObjectLayout->addWidget(stepTitle);

        vertSpacer1 = new QSpacerItem(20, 12, QSizePolicy::Policy::Minimum, QSizePolicy::Policy::Fixed);

        selectObjectLayout->addItem(vertSpacer1);

        stepText = new QLabel(PWizObjectSelection);
        stepText->setObjectName("stepText");
        stepText->setWordWrap(true);

        selectObjectLayout->addWidget(stepText);

        vertSpacer2 = new QSpacerItem(20, 12, QSizePolicy::Policy::Minimum, QSizePolicy::Policy::Minimum);

        selectObjectLayout->addItem(vertSpacer2);

        horLayout1 = new QHBoxLayout();
        horLayout1->setObjectName("horLayout1");
        horSpacer1 = new QSpacerItem(40, 20, QSizePolicy::Policy::Expanding, QSizePolicy::Policy::Minimum);

        horLayout1->addItem(horSpacer1);

        fromListButton = new QPushButton(PWizObjectSelection);
        fromListButton->setObjectName("fromListButton");

        horLayout1->addWidget(fromListButton);

        horSpacer2 = new QSpacerItem(40, 20, QSizePolicy::Policy::Expanding, QSizePolicy::Policy::Minimum);

        horLayout1->addItem(horSpacer2);

        pointButton = new QPushButton(PWizObjectSelection);
        pointButton->setObjectName("pointButton");

        horLayout1->addWidget(pointButton);

        horSpacer3 = new QSpacerItem(40, 20, QSizePolicy::Policy::Expanding, QSizePolicy::Policy::Minimum);

        horLayout1->addItem(horSpacer3);


        selectObjectLayout->addLayout(horLayout1);

        vertSpacer3 = new QSpacerItem(20, 12, QSizePolicy::Policy::Minimum, QSizePolicy::Policy::Fixed);

        selectObjectLayout->addItem(vertSpacer3);

        selectedObjLabel = new QLabel(PWizObjectSelection);
        selectedObjLabel->setObjectName("selectedObjLabel");
        QFont font1;
        font1.setBold(true);
        selectedObjLabel->setFont(font1);

        selectObjectLayout->addWidget(selectedObjLabel);

        objInfoLabel = new QLabel(PWizObjectSelection);
        objInfoLabel->setObjectName("objInfoLabel");
        objInfoLabel->setAlignment(Qt::AlignCenter);

        selectObjectLayout->addWidget(objInfoLabel);

        horLayout2 = new QHBoxLayout();
        horLayout2->setObjectName("horLayout2");
        horSpacer4 = new QSpacerItem(40, 20, QSizePolicy::Policy::Expanding, QSizePolicy::Policy::Minimum);

        horLayout2->addItem(horSpacer4);

        detailsButton = new QPushButton(PWizObjectSelection);
        detailsButton->setObjectName("detailsButton");

        horLayout2->addWidget(detailsButton);

        horSpacer5 = new QSpacerItem(40, 20, QSizePolicy::Policy::Expanding, QSizePolicy::Policy::Minimum);

        horLayout2->addItem(horSpacer5);


        selectObjectLayout->addLayout(horLayout2);

        vertSpacer4 = new QSpacerItem(20, 40, QSizePolicy::Policy::Minimum, QSizePolicy::Policy::Expanding);

        selectObjectLayout->addItem(vertSpacer4);


        horizontalLayout->addLayout(selectObjectLayout);


        retranslateUi(PWizObjectSelection);

        QMetaObject::connectSlotsByName(PWizObjectSelection);
    } // setupUi

    void retranslateUi(QWidget *PWizObjectSelection)
    {
        banner->setText(QString());
        stepTitle->setText(tr2i18n("Select Sky Object", nullptr));
        stepText->setText(tr2i18n("<p>Select observed sky object. You can select it from object list, by clicking <b>Select object from list</b> button or point it on sky map by pressing <b>Point object on sky map</b>. After object is located, press it with right mouse button and select <b>Select this object</b> option from context menu.</p>\n"
"<p>When done, press <b>Next</b> button.</p>", nullptr));
        fromListButton->setText(tr2i18n("Select object from list", nullptr));
        pointButton->setText(tr2i18n("Point object on sky map", nullptr));
        selectedObjLabel->setText(tr2i18n("Selected object:", nullptr));
        objInfoLabel->setText(QString());
        detailsButton->setText(tr2i18n("Show details...", nullptr));
        (void)PWizObjectSelection;
    } // retranslateUi

};

namespace Ui {
    class PWizObjectSelection: public Ui_PWizObjectSelection {};
} // namespace Ui

QT_END_NAMESPACE

#endif // PWIZOBJECTSELECTION_H

