/********************************************************************************
** Form generated from reading UI file 'polaralignwidget.ui'
**
** Created by: Qt User Interface Compiler version 6.11.1
**
** WARNING! All changes made in this file will be lost when recompiling UI file!
********************************************************************************/

#ifndef UI_POLARALIGNWIDGET_H
#define UI_POLARALIGNWIDGET_H

#include <QtCore/QVariant>
#include <QtWidgets/QApplication>
#include <QtWidgets/QGridLayout>
#include <QtWidgets/QLabel>
#include <QtWidgets/QWidget>
#include <kled.h>
#include <klocalizedstring.h>

QT_BEGIN_NAMESPACE

class Ui_PolarAlignWidget
{
public:
    QGridLayout *PAStateLayout;
    QLabel *PAc1;
    KLed *PAcapture1Led;
    QLabel *PAso1;
    KLed *PAsolve1Led;
    QLabel *PAs1;
    KLed *PAslew1Led;
    QLabel *PAc2;
    KLed *PAcapture2Led;
    QLabel *PAso2;
    KLed *PAsolve2Led;
    QLabel *PAs2;
    KLed *PAslew2Led;
    QLabel *PAc3;
    KLed *PAcapture3Led;
    QLabel *PAso3;
    KLed *PAsolve3Led;
    QLabel *PAsetup;
    KLed *PAsetupLed;
    QLabel *PAadjust;
    KLed *PAadjustLed;

    void setupUi(QWidget *PolarAlignWidget)
    {
        if (PolarAlignWidget->objectName().isEmpty())
            PolarAlignWidget->setObjectName("PolarAlignWidget");
        PolarAlignWidget->resize(303, 25);
        PAStateLayout = new QGridLayout(PolarAlignWidget);
        PAStateLayout->setObjectName("PAStateLayout");
        PAStateLayout->setSizeConstraint(QLayout::SetFixedSize);
        PAc1 = new QLabel(PolarAlignWidget);
        PAc1->setObjectName("PAc1");
        QSizePolicy sizePolicy(QSizePolicy::Policy::Fixed, QSizePolicy::Policy::Preferred);
        sizePolicy.setHorizontalStretch(0);
        sizePolicy.setVerticalStretch(0);
        sizePolicy.setHeightForWidth(PAc1->sizePolicy().hasHeightForWidth());
        PAc1->setSizePolicy(sizePolicy);
        PAc1->setMaximumSize(QSize(50, 20));
        QFont font;
        font.setPointSize(9);
        PAc1->setFont(font);

        PAStateLayout->addWidget(PAc1, 0, 0, 1, 1, Qt::AlignHCenter);

        PAcapture1Led = new KLed(PolarAlignWidget);
        PAcapture1Led->setObjectName("PAcapture1Led");
        PAcapture1Led->setMinimumSize(QSize(0, 0));
        PAcapture1Led->setMaximumSize(QSize(20, 20));

        PAStateLayout->addWidget(PAcapture1Led, 1, 0, 1, 1, Qt::AlignHCenter);

        PAso1 = new QLabel(PolarAlignWidget);
        PAso1->setObjectName("PAso1");
        sizePolicy.setHeightForWidth(PAso1->sizePolicy().hasHeightForWidth());
        PAso1->setSizePolicy(sizePolicy);
        PAso1->setMaximumSize(QSize(50, 20));
        PAso1->setFont(font);

        PAStateLayout->addWidget(PAso1, 0, 1, 1, 1, Qt::AlignHCenter);

        PAsolve1Led = new KLed(PolarAlignWidget);
        PAsolve1Led->setObjectName("PAsolve1Led");
        PAsolve1Led->setMinimumSize(QSize(0, 0));
        PAsolve1Led->setMaximumSize(QSize(20, 20));

        PAStateLayout->addWidget(PAsolve1Led, 1, 1, 1, 1, Qt::AlignHCenter);

        PAs1 = new QLabel(PolarAlignWidget);
        PAs1->setObjectName("PAs1");
        sizePolicy.setHeightForWidth(PAs1->sizePolicy().hasHeightForWidth());
        PAs1->setSizePolicy(sizePolicy);
        PAs1->setMaximumSize(QSize(50, 20));
        PAs1->setFont(font);

        PAStateLayout->addWidget(PAs1, 0, 2, 1, 1, Qt::AlignHCenter);

        PAslew1Led = new KLed(PolarAlignWidget);
        PAslew1Led->setObjectName("PAslew1Led");
        PAslew1Led->setMinimumSize(QSize(0, 0));
        PAslew1Led->setMaximumSize(QSize(20, 20));

        PAStateLayout->addWidget(PAslew1Led, 1, 2, 1, 1, Qt::AlignHCenter);

        PAc2 = new QLabel(PolarAlignWidget);
        PAc2->setObjectName("PAc2");
        sizePolicy.setHeightForWidth(PAc2->sizePolicy().hasHeightForWidth());
        PAc2->setSizePolicy(sizePolicy);
        PAc2->setMaximumSize(QSize(50, 20));
        PAc2->setFont(font);

        PAStateLayout->addWidget(PAc2, 0, 3, 1, 1, Qt::AlignHCenter);

        PAcapture2Led = new KLed(PolarAlignWidget);
        PAcapture2Led->setObjectName("PAcapture2Led");
        PAcapture2Led->setMinimumSize(QSize(0, 0));
        PAcapture2Led->setMaximumSize(QSize(20, 20));

        PAStateLayout->addWidget(PAcapture2Led, 1, 3, 1, 1, Qt::AlignHCenter);

        PAso2 = new QLabel(PolarAlignWidget);
        PAso2->setObjectName("PAso2");
        sizePolicy.setHeightForWidth(PAso2->sizePolicy().hasHeightForWidth());
        PAso2->setSizePolicy(sizePolicy);
        PAso2->setMaximumSize(QSize(50, 20));
        PAso2->setFont(font);

        PAStateLayout->addWidget(PAso2, 0, 4, 1, 1, Qt::AlignHCenter);

        PAsolve2Led = new KLed(PolarAlignWidget);
        PAsolve2Led->setObjectName("PAsolve2Led");
        PAsolve2Led->setMinimumSize(QSize(0, 0));
        PAsolve2Led->setMaximumSize(QSize(20, 20));

        PAStateLayout->addWidget(PAsolve2Led, 1, 4, 1, 1, Qt::AlignHCenter);

        PAs2 = new QLabel(PolarAlignWidget);
        PAs2->setObjectName("PAs2");
        sizePolicy.setHeightForWidth(PAs2->sizePolicy().hasHeightForWidth());
        PAs2->setSizePolicy(sizePolicy);
        PAs2->setMaximumSize(QSize(50, 20));
        PAs2->setFont(font);

        PAStateLayout->addWidget(PAs2, 0, 5, 1, 1, Qt::AlignHCenter);

        PAslew2Led = new KLed(PolarAlignWidget);
        PAslew2Led->setObjectName("PAslew2Led");
        PAslew2Led->setMinimumSize(QSize(0, 0));
        PAslew2Led->setMaximumSize(QSize(20, 20));

        PAStateLayout->addWidget(PAslew2Led, 1, 5, 1, 1, Qt::AlignHCenter);

        PAc3 = new QLabel(PolarAlignWidget);
        PAc3->setObjectName("PAc3");
        sizePolicy.setHeightForWidth(PAc3->sizePolicy().hasHeightForWidth());
        PAc3->setSizePolicy(sizePolicy);
        PAc3->setMaximumSize(QSize(50, 20));
        PAc3->setFont(font);

        PAStateLayout->addWidget(PAc3, 0, 6, 1, 1, Qt::AlignHCenter);

        PAcapture3Led = new KLed(PolarAlignWidget);
        PAcapture3Led->setObjectName("PAcapture3Led");
        PAcapture3Led->setMinimumSize(QSize(0, 0));
        PAcapture3Led->setMaximumSize(QSize(20, 20));

        PAStateLayout->addWidget(PAcapture3Led, 1, 6, 1, 1, Qt::AlignHCenter);

        PAso3 = new QLabel(PolarAlignWidget);
        PAso3->setObjectName("PAso3");
        sizePolicy.setHeightForWidth(PAso3->sizePolicy().hasHeightForWidth());
        PAso3->setSizePolicy(sizePolicy);
        PAso3->setMaximumSize(QSize(50, 20));
        PAso3->setFont(font);

        PAStateLayout->addWidget(PAso3, 0, 7, 1, 1, Qt::AlignHCenter);

        PAsolve3Led = new KLed(PolarAlignWidget);
        PAsolve3Led->setObjectName("PAsolve3Led");
        PAsolve3Led->setMinimumSize(QSize(0, 0));
        PAsolve3Led->setMaximumSize(QSize(20, 20));

        PAStateLayout->addWidget(PAsolve3Led, 1, 7, 1, 1, Qt::AlignHCenter);

        PAsetup = new QLabel(PolarAlignWidget);
        PAsetup->setObjectName("PAsetup");
        sizePolicy.setHeightForWidth(PAsetup->sizePolicy().hasHeightForWidth());
        PAsetup->setSizePolicy(sizePolicy);
        PAsetup->setMaximumSize(QSize(50, 20));
        PAsetup->setFont(font);

        PAStateLayout->addWidget(PAsetup, 0, 8, 1, 1, Qt::AlignHCenter);

        PAsetupLed = new KLed(PolarAlignWidget);
        PAsetupLed->setObjectName("PAsetupLed");
        PAsetupLed->setMinimumSize(QSize(0, 0));
        PAsetupLed->setMaximumSize(QSize(20, 20));

        PAStateLayout->addWidget(PAsetupLed, 1, 8, 1, 1, Qt::AlignHCenter);

        PAadjust = new QLabel(PolarAlignWidget);
        PAadjust->setObjectName("PAadjust");
        sizePolicy.setHeightForWidth(PAadjust->sizePolicy().hasHeightForWidth());
        PAadjust->setSizePolicy(sizePolicy);
        PAadjust->setMaximumSize(QSize(50, 20));
        PAadjust->setFont(font);

        PAStateLayout->addWidget(PAadjust, 0, 9, 1, 1, Qt::AlignHCenter);

        PAadjustLed = new KLed(PolarAlignWidget);
        PAadjustLed->setObjectName("PAadjustLed");
        PAadjustLed->setMinimumSize(QSize(0, 0));
        PAadjustLed->setMaximumSize(QSize(20, 20));

        PAStateLayout->addWidget(PAadjustLed, 1, 9, 1, 1, Qt::AlignHCenter);


        retranslateUi(PolarAlignWidget);

        QMetaObject::connectSlotsByName(PolarAlignWidget);
    } // setupUi

    void retranslateUi(QWidget *PolarAlignWidget)
    {
        PAc1->setText(tr2i18n("Capture", nullptr));
        PAso1->setText(tr2i18n("Solve", nullptr));
        PAs1->setText(tr2i18n("Slew", nullptr));
        PAc2->setText(tr2i18n("Capture", nullptr));
        PAso2->setText(tr2i18n("Solve", nullptr));
        PAs2->setText(tr2i18n("Slew", nullptr));
        PAc3->setText(tr2i18n("Capture", nullptr));
        PAso3->setText(tr2i18n("Solve", nullptr));
        PAsetup->setText(tr2i18n("Setup", nullptr));
        PAadjust->setText(tr2i18n("Adjust", nullptr));
        (void)PolarAlignWidget;
    } // retranslateUi

};

namespace Ui {
    class PolarAlignWidget: public Ui_PolarAlignWidget {};
} // namespace Ui

QT_END_NAMESPACE

#endif // POLARALIGNWIDGET_H

