/********************************************************************************
** Form generated from reading UI file 'equipmentwriter.ui'
**
** Created by: Qt User Interface Compiler version 6.11.1
**
** WARNING! All changes made in this file will be lost when recompiling UI file!
********************************************************************************/

#ifndef UI_EQUIPMENTWRITER_H
#define UI_EQUIPMENTWRITER_H

#include <QtCore/QDate>
#include <QtCore/QVariant>
#include <QtGui/QIcon>
#include <QtWidgets/QApplication>
#include <QtWidgets/QCheckBox>
#include <QtWidgets/QComboBox>
#include <QtWidgets/QDateTimeEdit>
#include <QtWidgets/QDoubleSpinBox>
#include <QtWidgets/QFormLayout>
#include <QtWidgets/QGridLayout>
#include <QtWidgets/QHBoxLayout>
#include <QtWidgets/QLabel>
#include <QtWidgets/QLineEdit>
#include <QtWidgets/QListWidget>
#include <QtWidgets/QPushButton>
#include <QtWidgets/QSpacerItem>
#include <QtWidgets/QSpinBox>
#include <QtWidgets/QTabWidget>
#include <QtWidgets/QVBoxLayout>
#include <QtWidgets/QWidget>
#include <klocalizedstring.h>

QT_BEGIN_NAMESPACE

class Ui_EquipmentWriter
{
public:
    QGridLayout *gridLayout_3;
    QTabWidget *tabWidget;
    QWidget *Scope;
    QHBoxLayout *horizontalLayout_9;
    QListWidget *ScopeList;
    QVBoxLayout *verticalLayout;
    QGridLayout *gridLayout;
    QLineEdit *Model;
    QLabel *label;
    QComboBox *Type;
    QLabel *label_2;
    QLabel *label_5;
    QLabel *label_3;
    QLineEdit *Vendor;
    QHBoxLayout *horizontalLayout_4;
    QDoubleSpinBox *FocalLength;
    QLabel *label_14;
    QSpacerItem *horizontalSpacer_5;
    QLabel *label_4;
    QHBoxLayout *horizontalLayout_5;
    QDoubleSpinBox *Aperture;
    QLabel *label_15;
    QSpacerItem *horizontalSpacer_4;
    QLabel *label_13;
    QLineEdit *Id;
    QSpacerItem *verticalSpacer_2;
    QHBoxLayout *horizontalLayout;
    QPushButton *AddScope;
    QSpacerItem *horizontalSpacer;
    QPushButton *NewScope;
    QPushButton *RemoveScope;
    QWidget *Eyepiece;
    QGridLayout *gridLayout_4;
    QLabel *label_11;
    QLabel *label_6;
    QLabel *label_8;
    QLabel *label_7;
    QListWidget *EyepieceList;
    QHBoxLayout *horizontalLayout_2;
    QSpacerItem *horizontalSpacer_2;
    QPushButton *NewEyepiece;
    QPushButton *AddEyepiece;
    QPushButton *RemoveEyepiece;
    QLabel *label_9;
    QLabel *label_17;
    QLineEdit *e_Id;
    QLabel *label_10;
    QDoubleSpinBox *Fov;
    QDoubleSpinBox *e_focalLength;
    QLineEdit *e_Model;
    QLineEdit *e_Vendor;
    QComboBox *FovUnit;
    QSpacerItem *verticalSpacer;
    QWidget *DSLRLens;
    QHBoxLayout *horizontalLayout_14;
    QListWidget *DSLRLensList;
    QVBoxLayout *verticalLayout_4;
    QLabel *label_25;
    QGridLayout *gridLayout_2;
    QLineEdit *DSLR_model;
    QLabel *label3_3;
    QLabel *label2_2;
    QLabel *label_29;
    QLabel *label_24;
    QLabel *label31_2;
    QLabel *label51_2;
    QDoubleSpinBox *DSLRFocalRatio;
    QLineEdit *DSLR_id;
    QLineEdit *DSLR_vendor;
    QDoubleSpinBox *DSLRFocalLength;
    QSpacerItem *horizontalSpacer_6;
    QSpacerItem *verticalSpacer_3;
    QHBoxLayout *horizontalLayout_13;
    QPushButton *AddDSLRLens;
    QSpacerItem *horizontalSpacer_3;
    QPushButton *NewDSLRLens;
    QPushButton *RemoveDSLRLens;
    QWidget *ScopeLens;
    QHBoxLayout *_4;
    QListWidget *LensList;
    QVBoxLayout *verticalLayout3;
    QLabel *label_16;
    QFormLayout *formLayout3;
    QLabel *label3_2;
    QLineEdit *l_Id;
    QLabel *label31;
    QLineEdit *l_Vendor;
    QLabel *label51;
    QDoubleSpinBox *l_Factor;
    QLineEdit *l_Model;
    QLabel *label2;
    QHBoxLayout *horizontalLayout3;
    QSpacerItem *horizontalSpacer31;
    QPushButton *NewLens;
    QPushButton *AddLens;
    QPushButton *RemoveLens;
    QWidget *Filter;
    QHBoxLayout *horizontalLayout_7;
    QListWidget *FilterList;
    QVBoxLayout *verticalLayout_3;
    QFormLayout *formLayout_3;
    QLabel *label4;
    QLineEdit *f_Id;
    QLabel *label5;
    QLineEdit *f_Vendor;
    QLabel *label3;
    QLineEdit *f_Model;
    QLabel *label6;
    QLineEdit *f_Type;
    QLabel *label_12;
    QLineEdit *f_Color;
    QLabel *label_19;
    QDoubleSpinBox *f_Exposure;
    QLabel *label_18;
    QSpinBox *f_Offset;
    QLabel *label_22;
    QSpinBox *f_AbsoluteFocusPosition;
    QLabel *label_28;
    QDoubleSpinBox *f_FocusAltitude;
    QLabel *label_30;
    QDoubleSpinBox *f_FocusTicksPerTemp;
    QLabel *label_31;
    QDoubleSpinBox *f_FocusTicksPerAlt;
    QLabel *label_23;
    QLabel *label_21;
    QCheckBox *f_UseAutoFocus;
    QLabel *label_20;
    QLineEdit *f_LockedFilter;
    QDoubleSpinBox *f_FocusTemperature;
    QLabel *label_26;
    QDoubleSpinBox *f_Wavelength;
    QLabel *label_27;
    QDateTimeEdit *f_FocusDatetime;
    QHBoxLayout *horizontalLayout7;
    QSpacerItem *horizontalSpacer3;
    QPushButton *NewFilter;
    QPushButton *AddFilter;
    QPushButton *RemoveFilter;

    void setupUi(QWidget *EquipmentWriter)
    {
        if (EquipmentWriter->objectName().isEmpty())
            EquipmentWriter->setObjectName("EquipmentWriter");
        EquipmentWriter->resize(426, 655);
        gridLayout_3 = new QGridLayout(EquipmentWriter);
        gridLayout_3->setObjectName("gridLayout_3");
        gridLayout_3->setContentsMargins(3, 3, 3, 3);
        tabWidget = new QTabWidget(EquipmentWriter);
        tabWidget->setObjectName("tabWidget");
        tabWidget->setMinimumSize(QSize(252, 0));
        tabWidget->setDocumentMode(false);
        Scope = new QWidget();
        Scope->setObjectName("Scope");
        horizontalLayout_9 = new QHBoxLayout(Scope);
        horizontalLayout_9->setSpacing(3);
        horizontalLayout_9->setObjectName("horizontalLayout_9");
        horizontalLayout_9->setContentsMargins(3, 3, 3, 3);
        ScopeList = new QListWidget(Scope);
        ScopeList->setObjectName("ScopeList");

        horizontalLayout_9->addWidget(ScopeList);

        verticalLayout = new QVBoxLayout();
        verticalLayout->setObjectName("verticalLayout");
        gridLayout = new QGridLayout();
        gridLayout->setObjectName("gridLayout");
        Model = new QLineEdit(Scope);
        Model->setObjectName("Model");

        gridLayout->addWidget(Model, 2, 1, 1, 1);

        label = new QLabel(Scope);
        label->setObjectName("label");

        gridLayout->addWidget(label, 0, 0, 1, 1);

        Type = new QComboBox(Scope);
        Type->addItem(QString());
        Type->addItem(QString());
        Type->addItem(QString());
        Type->addItem(QString());
        Type->addItem(QString());
        Type->addItem(QString());
        Type->addItem(QString());
        Type->setObjectName("Type");
        Type->setFocusPolicy(Qt::StrongFocus);

        gridLayout->addWidget(Type, 3, 1, 1, 1);

        label_2 = new QLabel(Scope);
        label_2->setObjectName("label_2");

        gridLayout->addWidget(label_2, 2, 0, 1, 1);

        label_5 = new QLabel(Scope);
        label_5->setObjectName("label_5");

        gridLayout->addWidget(label_5, 5, 0, 1, 1);

        label_3 = new QLabel(Scope);
        label_3->setObjectName("label_3");

        gridLayout->addWidget(label_3, 1, 0, 1, 1);

        Vendor = new QLineEdit(Scope);
        Vendor->setObjectName("Vendor");

        gridLayout->addWidget(Vendor, 1, 1, 1, 1);

        horizontalLayout_4 = new QHBoxLayout();
        horizontalLayout_4->setObjectName("horizontalLayout_4");
        FocalLength = new QDoubleSpinBox(Scope);
        FocalLength->setObjectName("FocalLength");
        QSizePolicy sizePolicy(QSizePolicy::Policy::Minimum, QSizePolicy::Policy::Fixed);
        sizePolicy.setHorizontalStretch(0);
        sizePolicy.setVerticalStretch(0);
        sizePolicy.setHeightForWidth(FocalLength->sizePolicy().hasHeightForWidth());
        FocalLength->setSizePolicy(sizePolicy);
        FocalLength->setFocusPolicy(Qt::StrongFocus);
        FocalLength->setMinimum(0.000000000000000);
        FocalLength->setMaximum(40000.000000000000000);
        FocalLength->setSingleStep(10.000000000000000);
        FocalLength->setValue(0.000000000000000);

        horizontalLayout_4->addWidget(FocalLength);

        label_14 = new QLabel(Scope);
        label_14->setObjectName("label_14");

        horizontalLayout_4->addWidget(label_14);

        horizontalSpacer_5 = new QSpacerItem(40, 20, QSizePolicy::Policy::Expanding, QSizePolicy::Policy::Minimum);

        horizontalLayout_4->addItem(horizontalSpacer_5);


        gridLayout->addLayout(horizontalLayout_4, 5, 1, 1, 1);

        label_4 = new QLabel(Scope);
        label_4->setObjectName("label_4");

        gridLayout->addWidget(label_4, 3, 0, 1, 1);

        horizontalLayout_5 = new QHBoxLayout();
        horizontalLayout_5->setObjectName("horizontalLayout_5");
        Aperture = new QDoubleSpinBox(Scope);
        Aperture->setObjectName("Aperture");
        sizePolicy.setHeightForWidth(Aperture->sizePolicy().hasHeightForWidth());
        Aperture->setSizePolicy(sizePolicy);
        Aperture->setFocusPolicy(Qt::StrongFocus);
        Aperture->setMinimum(0.000000000000000);
        Aperture->setMaximum(10000.000000000000000);
        Aperture->setSingleStep(10.000000000000000);
        Aperture->setValue(0.000000000000000);

        horizontalLayout_5->addWidget(Aperture);

        label_15 = new QLabel(Scope);
        label_15->setObjectName("label_15");

        horizontalLayout_5->addWidget(label_15);

        horizontalSpacer_4 = new QSpacerItem(40, 20, QSizePolicy::Policy::Expanding, QSizePolicy::Policy::Minimum);

        horizontalLayout_5->addItem(horizontalSpacer_4);


        gridLayout->addLayout(horizontalLayout_5, 4, 1, 1, 1);

        label_13 = new QLabel(Scope);
        label_13->setObjectName("label_13");

        gridLayout->addWidget(label_13, 4, 0, 1, 1);

        Id = new QLineEdit(Scope);
        Id->setObjectName("Id");
        Id->setFocusPolicy(Qt::NoFocus);
        Id->setReadOnly(true);

        gridLayout->addWidget(Id, 0, 1, 1, 1);


        verticalLayout->addLayout(gridLayout);

        verticalSpacer_2 = new QSpacerItem(20, 40, QSizePolicy::Policy::Minimum, QSizePolicy::Policy::Expanding);

        verticalLayout->addItem(verticalSpacer_2);

        horizontalLayout = new QHBoxLayout();
        horizontalLayout->setObjectName("horizontalLayout");
        AddScope = new QPushButton(Scope);
        AddScope->setObjectName("AddScope");
        QIcon icon(QIcon::fromTheme(QString::fromUtf8("list-add")));
        AddScope->setIcon(icon);
        AddScope->setIconSize(QSize(22, 22));

        horizontalLayout->addWidget(AddScope);

        horizontalSpacer = new QSpacerItem(40, 20, QSizePolicy::Policy::Expanding, QSizePolicy::Policy::Minimum);

        horizontalLayout->addItem(horizontalSpacer);

        NewScope = new QPushButton(Scope);
        NewScope->setObjectName("NewScope");
        QIcon icon1(QIcon::fromTheme(QString::fromUtf8("edit-clear")));
        NewScope->setIcon(icon1);
        NewScope->setIconSize(QSize(22, 22));

        horizontalLayout->addWidget(NewScope);

        RemoveScope = new QPushButton(Scope);
        RemoveScope->setObjectName("RemoveScope");
        QIcon icon2(QIcon::fromTheme(QString::fromUtf8("list-remove")));
        RemoveScope->setIcon(icon2);
        RemoveScope->setIconSize(QSize(22, 22));

        horizontalLayout->addWidget(RemoveScope);


        verticalLayout->addLayout(horizontalLayout);


        horizontalLayout_9->addLayout(verticalLayout);

        horizontalLayout_9->setStretch(0, 1);
        horizontalLayout_9->setStretch(1, 2);
        tabWidget->addTab(Scope, QString());
        Eyepiece = new QWidget();
        Eyepiece->setObjectName("Eyepiece");
        gridLayout_4 = new QGridLayout(Eyepiece);
        gridLayout_4->setObjectName("gridLayout_4");
        label_11 = new QLabel(Eyepiece);
        label_11->setObjectName("label_11");

        gridLayout_4->addWidget(label_11, 4, 4, 1, 1);

        label_6 = new QLabel(Eyepiece);
        label_6->setObjectName("label_6");

        gridLayout_4->addWidget(label_6, 0, 1, 1, 1);

        label_8 = new QLabel(Eyepiece);
        label_8->setObjectName("label_8");

        gridLayout_4->addWidget(label_8, 1, 1, 1, 1);

        label_7 = new QLabel(Eyepiece);
        label_7->setObjectName("label_7");

        gridLayout_4->addWidget(label_7, 2, 1, 1, 1);

        EyepieceList = new QListWidget(Eyepiece);
        EyepieceList->setObjectName("EyepieceList");

        gridLayout_4->addWidget(EyepieceList, 0, 0, 7, 1);

        horizontalLayout_2 = new QHBoxLayout();
        horizontalLayout_2->setObjectName("horizontalLayout_2");
        horizontalSpacer_2 = new QSpacerItem(40, 0, QSizePolicy::Policy::Expanding, QSizePolicy::Policy::Minimum);

        horizontalLayout_2->addItem(horizontalSpacer_2);

        NewEyepiece = new QPushButton(Eyepiece);
        NewEyepiece->setObjectName("NewEyepiece");

        horizontalLayout_2->addWidget(NewEyepiece);

        AddEyepiece = new QPushButton(Eyepiece);
        AddEyepiece->setObjectName("AddEyepiece");

        horizontalLayout_2->addWidget(AddEyepiece);

        RemoveEyepiece = new QPushButton(Eyepiece);
        RemoveEyepiece->setObjectName("RemoveEyepiece");

        horizontalLayout_2->addWidget(RemoveEyepiece);


        gridLayout_4->addLayout(horizontalLayout_2, 6, 1, 1, 6);

        label_9 = new QLabel(Eyepiece);
        label_9->setObjectName("label_9");

        gridLayout_4->addWidget(label_9, 4, 1, 1, 1);

        label_17 = new QLabel(Eyepiece);
        label_17->setObjectName("label_17");

        gridLayout_4->addWidget(label_17, 3, 4, 1, 2);

        e_Id = new QLineEdit(Eyepiece);
        e_Id->setObjectName("e_Id");
        e_Id->setFocusPolicy(Qt::NoFocus);
        e_Id->setReadOnly(true);

        gridLayout_4->addWidget(e_Id, 0, 2, 1, 5);

        label_10 = new QLabel(Eyepiece);
        label_10->setObjectName("label_10");

        gridLayout_4->addWidget(label_10, 3, 1, 1, 1);

        Fov = new QDoubleSpinBox(Eyepiece);
        Fov->setObjectName("Fov");
        Fov->setFocusPolicy(Qt::StrongFocus);
        Fov->setMaximum(180.000000000000000);
        Fov->setSingleStep(0.100000000000000);

        gridLayout_4->addWidget(Fov, 4, 2, 1, 2);

        e_focalLength = new QDoubleSpinBox(Eyepiece);
        e_focalLength->setObjectName("e_focalLength");
        e_focalLength->setFocusPolicy(Qt::StrongFocus);
        e_focalLength->setSingleStep(0.100000000000000);

        gridLayout_4->addWidget(e_focalLength, 3, 2, 1, 2);

        e_Model = new QLineEdit(Eyepiece);
        e_Model->setObjectName("e_Model");

        gridLayout_4->addWidget(e_Model, 2, 2, 1, 5);

        e_Vendor = new QLineEdit(Eyepiece);
        e_Vendor->setObjectName("e_Vendor");

        gridLayout_4->addWidget(e_Vendor, 1, 2, 1, 5);

        FovUnit = new QComboBox(Eyepiece);
        FovUnit->addItem(QString());
        FovUnit->addItem(QString());
        FovUnit->setObjectName("FovUnit");

        gridLayout_4->addWidget(FovUnit, 4, 5, 1, 2);

        verticalSpacer = new QSpacerItem(20, 40, QSizePolicy::Policy::Minimum, QSizePolicy::Policy::Expanding);

        gridLayout_4->addItem(verticalSpacer, 5, 2, 1, 1);

        tabWidget->addTab(Eyepiece, QString());
        DSLRLens = new QWidget();
        DSLRLens->setObjectName("DSLRLens");
        horizontalLayout_14 = new QHBoxLayout(DSLRLens);
        horizontalLayout_14->setSpacing(3);
        horizontalLayout_14->setObjectName("horizontalLayout_14");
        horizontalLayout_14->setContentsMargins(3, 3, 3, 3);
        DSLRLensList = new QListWidget(DSLRLens);
        DSLRLensList->setObjectName("DSLRLensList");

        horizontalLayout_14->addWidget(DSLRLensList);

        verticalLayout_4 = new QVBoxLayout();
        verticalLayout_4->setObjectName("verticalLayout_4");
        label_25 = new QLabel(DSLRLens);
        label_25->setObjectName("label_25");
        QSizePolicy sizePolicy1(QSizePolicy::Policy::Preferred, QSizePolicy::Policy::Fixed);
        sizePolicy1.setHorizontalStretch(0);
        sizePolicy1.setVerticalStretch(0);
        sizePolicy1.setHeightForWidth(label_25->sizePolicy().hasHeightForWidth());
        label_25->setSizePolicy(sizePolicy1);

        verticalLayout_4->addWidget(label_25);

        gridLayout_2 = new QGridLayout();
        gridLayout_2->setObjectName("gridLayout_2");
        DSLR_model = new QLineEdit(DSLRLens);
        DSLR_model->setObjectName("DSLR_model");

        gridLayout_2->addWidget(DSLR_model, 2, 1, 1, 4);

        label3_3 = new QLabel(DSLRLens);
        label3_3->setObjectName("label3_3");

        gridLayout_2->addWidget(label3_3, 0, 0, 1, 1);

        label2_2 = new QLabel(DSLRLens);
        label2_2->setObjectName("label2_2");

        gridLayout_2->addWidget(label2_2, 2, 0, 1, 1);

        label_29 = new QLabel(DSLRLens);
        label_29->setObjectName("label_29");

        gridLayout_2->addWidget(label_29, 3, 2, 1, 1);

        label_24 = new QLabel(DSLRLens);
        label_24->setObjectName("label_24");

        gridLayout_2->addWidget(label_24, 3, 0, 1, 1);

        label31_2 = new QLabel(DSLRLens);
        label31_2->setObjectName("label31_2");

        gridLayout_2->addWidget(label31_2, 1, 0, 1, 1);

        label51_2 = new QLabel(DSLRLens);
        label51_2->setObjectName("label51_2");

        gridLayout_2->addWidget(label51_2, 4, 0, 1, 1);

        DSLRFocalRatio = new QDoubleSpinBox(DSLRLens);
        DSLRFocalRatio->setObjectName("DSLRFocalRatio");
        DSLRFocalRatio->setFocusPolicy(Qt::StrongFocus);
        DSLRFocalRatio->setDecimals(1);
        DSLRFocalRatio->setMinimum(0.900000000000000);
        DSLRFocalRatio->setMaximum(22.000000000000000);
        DSLRFocalRatio->setSingleStep(10.000000000000000);
        DSLRFocalRatio->setValue(2.800000000000000);

        gridLayout_2->addWidget(DSLRFocalRatio, 4, 1, 1, 1);

        DSLR_id = new QLineEdit(DSLRLens);
        DSLR_id->setObjectName("DSLR_id");
        DSLR_id->setFocusPolicy(Qt::NoFocus);
        DSLR_id->setReadOnly(true);

        gridLayout_2->addWidget(DSLR_id, 0, 1, 1, 4);

        DSLR_vendor = new QLineEdit(DSLRLens);
        DSLR_vendor->setObjectName("DSLR_vendor");

        gridLayout_2->addWidget(DSLR_vendor, 1, 1, 1, 4);

        DSLRFocalLength = new QDoubleSpinBox(DSLRLens);
        DSLRFocalLength->setObjectName("DSLRFocalLength");
        DSLRFocalLength->setMinimum(10.000000000000000);
        DSLRFocalLength->setMaximum(3000.000000000000000);
        DSLRFocalLength->setSingleStep(50.000000000000000);
        DSLRFocalLength->setValue(24.000000000000000);

        gridLayout_2->addWidget(DSLRFocalLength, 3, 1, 1, 1);

        horizontalSpacer_6 = new QSpacerItem(40, 20, QSizePolicy::Policy::Expanding, QSizePolicy::Policy::Minimum);

        gridLayout_2->addItem(horizontalSpacer_6, 3, 3, 1, 1);


        verticalLayout_4->addLayout(gridLayout_2);

        verticalSpacer_3 = new QSpacerItem(20, 40, QSizePolicy::Policy::Minimum, QSizePolicy::Policy::Expanding);

        verticalLayout_4->addItem(verticalSpacer_3);

        horizontalLayout_13 = new QHBoxLayout();
        horizontalLayout_13->setObjectName("horizontalLayout_13");
        AddDSLRLens = new QPushButton(DSLRLens);
        AddDSLRLens->setObjectName("AddDSLRLens");
        AddDSLRLens->setIcon(icon);
        AddDSLRLens->setIconSize(QSize(22, 22));

        horizontalLayout_13->addWidget(AddDSLRLens);

        horizontalSpacer_3 = new QSpacerItem(40, 20, QSizePolicy::Policy::Expanding, QSizePolicy::Policy::Minimum);

        horizontalLayout_13->addItem(horizontalSpacer_3);

        NewDSLRLens = new QPushButton(DSLRLens);
        NewDSLRLens->setObjectName("NewDSLRLens");
        NewDSLRLens->setIcon(icon1);
        NewDSLRLens->setIconSize(QSize(22, 22));

        horizontalLayout_13->addWidget(NewDSLRLens);

        RemoveDSLRLens = new QPushButton(DSLRLens);
        RemoveDSLRLens->setObjectName("RemoveDSLRLens");
        RemoveDSLRLens->setIcon(icon2);
        RemoveDSLRLens->setIconSize(QSize(22, 22));

        horizontalLayout_13->addWidget(RemoveDSLRLens);


        verticalLayout_4->addLayout(horizontalLayout_13);


        horizontalLayout_14->addLayout(verticalLayout_4);

        horizontalLayout_14->setStretch(0, 1);
        horizontalLayout_14->setStretch(1, 2);
        tabWidget->addTab(DSLRLens, QString());
        ScopeLens = new QWidget();
        ScopeLens->setObjectName("ScopeLens");
        _4 = new QHBoxLayout(ScopeLens);
        _4->setSpacing(3);
        _4->setObjectName("_4");
        _4->setContentsMargins(3, 3, 3, 3);
        LensList = new QListWidget(ScopeLens);
        LensList->setObjectName("LensList");

        _4->addWidget(LensList);

        verticalLayout3 = new QVBoxLayout();
        verticalLayout3->setObjectName("verticalLayout3");
        label_16 = new QLabel(ScopeLens);
        label_16->setObjectName("label_16");
        sizePolicy1.setHeightForWidth(label_16->sizePolicy().hasHeightForWidth());
        label_16->setSizePolicy(sizePolicy1);

        verticalLayout3->addWidget(label_16);

        formLayout3 = new QFormLayout();
        formLayout3->setObjectName("formLayout3");
        formLayout3->setFieldGrowthPolicy(QFormLayout::ExpandingFieldsGrow);
        label3_2 = new QLabel(ScopeLens);
        label3_2->setObjectName("label3_2");

        formLayout3->setWidget(0, QFormLayout::ItemRole::LabelRole, label3_2);

        l_Id = new QLineEdit(ScopeLens);
        l_Id->setObjectName("l_Id");
        l_Id->setFocusPolicy(Qt::NoFocus);
        l_Id->setReadOnly(true);

        formLayout3->setWidget(0, QFormLayout::ItemRole::FieldRole, l_Id);

        label31 = new QLabel(ScopeLens);
        label31->setObjectName("label31");

        formLayout3->setWidget(2, QFormLayout::ItemRole::LabelRole, label31);

        l_Vendor = new QLineEdit(ScopeLens);
        l_Vendor->setObjectName("l_Vendor");

        formLayout3->setWidget(2, QFormLayout::ItemRole::FieldRole, l_Vendor);

        label51 = new QLabel(ScopeLens);
        label51->setObjectName("label51");

        formLayout3->setWidget(4, QFormLayout::ItemRole::LabelRole, label51);

        l_Factor = new QDoubleSpinBox(ScopeLens);
        l_Factor->setObjectName("l_Factor");
        l_Factor->setFocusPolicy(Qt::StrongFocus);

        formLayout3->setWidget(4, QFormLayout::ItemRole::FieldRole, l_Factor);

        l_Model = new QLineEdit(ScopeLens);
        l_Model->setObjectName("l_Model");

        formLayout3->setWidget(3, QFormLayout::ItemRole::FieldRole, l_Model);

        label2 = new QLabel(ScopeLens);
        label2->setObjectName("label2");

        formLayout3->setWidget(3, QFormLayout::ItemRole::LabelRole, label2);


        verticalLayout3->addLayout(formLayout3);

        horizontalLayout3 = new QHBoxLayout();
        horizontalLayout3->setObjectName("horizontalLayout3");
        horizontalSpacer31 = new QSpacerItem(40, 20, QSizePolicy::Policy::Expanding, QSizePolicy::Policy::Minimum);

        horizontalLayout3->addItem(horizontalSpacer31);

        NewLens = new QPushButton(ScopeLens);
        NewLens->setObjectName("NewLens");

        horizontalLayout3->addWidget(NewLens);

        AddLens = new QPushButton(ScopeLens);
        AddLens->setObjectName("AddLens");

        horizontalLayout3->addWidget(AddLens);

        RemoveLens = new QPushButton(ScopeLens);
        RemoveLens->setObjectName("RemoveLens");

        horizontalLayout3->addWidget(RemoveLens);


        verticalLayout3->addLayout(horizontalLayout3);


        _4->addLayout(verticalLayout3);

        _4->setStretch(0, 1);
        _4->setStretch(1, 2);
        tabWidget->addTab(ScopeLens, QString());
        Filter = new QWidget();
        Filter->setObjectName("Filter");
        horizontalLayout_7 = new QHBoxLayout(Filter);
        horizontalLayout_7->setSpacing(3);
        horizontalLayout_7->setObjectName("horizontalLayout_7");
        horizontalLayout_7->setContentsMargins(3, 3, 3, 3);
        FilterList = new QListWidget(Filter);
        FilterList->setObjectName("FilterList");

        horizontalLayout_7->addWidget(FilterList);

        verticalLayout_3 = new QVBoxLayout();
        verticalLayout_3->setObjectName("verticalLayout_3");
        formLayout_3 = new QFormLayout();
        formLayout_3->setObjectName("formLayout_3");
        label4 = new QLabel(Filter);
        label4->setObjectName("label4");

        formLayout_3->setWidget(0, QFormLayout::ItemRole::LabelRole, label4);

        f_Id = new QLineEdit(Filter);
        f_Id->setObjectName("f_Id");
        f_Id->setFocusPolicy(Qt::NoFocus);
        f_Id->setReadOnly(true);

        formLayout_3->setWidget(0, QFormLayout::ItemRole::FieldRole, f_Id);

        label5 = new QLabel(Filter);
        label5->setObjectName("label5");

        formLayout_3->setWidget(1, QFormLayout::ItemRole::LabelRole, label5);

        f_Vendor = new QLineEdit(Filter);
        f_Vendor->setObjectName("f_Vendor");

        formLayout_3->setWidget(1, QFormLayout::ItemRole::FieldRole, f_Vendor);

        label3 = new QLabel(Filter);
        label3->setObjectName("label3");

        formLayout_3->setWidget(2, QFormLayout::ItemRole::LabelRole, label3);

        f_Model = new QLineEdit(Filter);
        f_Model->setObjectName("f_Model");

        formLayout_3->setWidget(2, QFormLayout::ItemRole::FieldRole, f_Model);

        label6 = new QLabel(Filter);
        label6->setObjectName("label6");

        formLayout_3->setWidget(3, QFormLayout::ItemRole::LabelRole, label6);

        f_Type = new QLineEdit(Filter);
        f_Type->setObjectName("f_Type");

        formLayout_3->setWidget(3, QFormLayout::ItemRole::FieldRole, f_Type);

        label_12 = new QLabel(Filter);
        label_12->setObjectName("label_12");

        formLayout_3->setWidget(4, QFormLayout::ItemRole::LabelRole, label_12);

        f_Color = new QLineEdit(Filter);
        f_Color->setObjectName("f_Color");

        formLayout_3->setWidget(4, QFormLayout::ItemRole::FieldRole, f_Color);

        label_19 = new QLabel(Filter);
        label_19->setObjectName("label_19");

        formLayout_3->setWidget(5, QFormLayout::ItemRole::LabelRole, label_19);

        f_Exposure = new QDoubleSpinBox(Filter);
        f_Exposure->setObjectName("f_Exposure");
        QSizePolicy sizePolicy2(QSizePolicy::Policy::MinimumExpanding, QSizePolicy::Policy::Fixed);
        sizePolicy2.setHorizontalStretch(0);
        sizePolicy2.setVerticalStretch(0);
        sizePolicy2.setHeightForWidth(f_Exposure->sizePolicy().hasHeightForWidth());
        f_Exposure->setSizePolicy(sizePolicy2);
        f_Exposure->setMinimum(0.010000000000000);
        f_Exposure->setMaximum(120.000000000000000);
        f_Exposure->setValue(1.000000000000000);

        formLayout_3->setWidget(5, QFormLayout::ItemRole::FieldRole, f_Exposure);

        label_18 = new QLabel(Filter);
        label_18->setObjectName("label_18");

        formLayout_3->setWidget(6, QFormLayout::ItemRole::LabelRole, label_18);

        f_Offset = new QSpinBox(Filter);
        f_Offset->setObjectName("f_Offset");
        sizePolicy2.setHeightForWidth(f_Offset->sizePolicy().hasHeightForWidth());
        f_Offset->setSizePolicy(sizePolicy2);
        f_Offset->setMinimum(-10000);
        f_Offset->setMaximum(10000);
        f_Offset->setSingleStep(100);

        formLayout_3->setWidget(6, QFormLayout::ItemRole::FieldRole, f_Offset);

        label_22 = new QLabel(Filter);
        label_22->setObjectName("label_22");

        formLayout_3->setWidget(7, QFormLayout::ItemRole::LabelRole, label_22);

        f_AbsoluteFocusPosition = new QSpinBox(Filter);
        f_AbsoluteFocusPosition->setObjectName("f_AbsoluteFocusPosition");
        f_AbsoluteFocusPosition->setReadOnly(false);
        f_AbsoluteFocusPosition->setMaximum(1000000);
        f_AbsoluteFocusPosition->setSingleStep(1);

        formLayout_3->setWidget(7, QFormLayout::ItemRole::FieldRole, f_AbsoluteFocusPosition);

        label_28 = new QLabel(Filter);
        label_28->setObjectName("label_28");

        formLayout_3->setWidget(9, QFormLayout::ItemRole::LabelRole, label_28);

        f_FocusAltitude = new QDoubleSpinBox(Filter);
        f_FocusAltitude->setObjectName("f_FocusAltitude");
        f_FocusAltitude->setReadOnly(false);
        f_FocusAltitude->setMinimum(-1000000.000000000000000);
        f_FocusAltitude->setMaximum(90.000000000000000);
        f_FocusAltitude->setValue(-1000000.000000000000000);

        formLayout_3->setWidget(9, QFormLayout::ItemRole::FieldRole, f_FocusAltitude);

        label_30 = new QLabel(Filter);
        label_30->setObjectName("label_30");

        formLayout_3->setWidget(11, QFormLayout::ItemRole::LabelRole, label_30);

        f_FocusTicksPerTemp = new QDoubleSpinBox(Filter);
        f_FocusTicksPerTemp->setObjectName("f_FocusTicksPerTemp");
        f_FocusTicksPerTemp->setMinimum(-10000.000000000000000);
        f_FocusTicksPerTemp->setMaximum(10000.000000000000000);

        formLayout_3->setWidget(11, QFormLayout::ItemRole::FieldRole, f_FocusTicksPerTemp);

        label_31 = new QLabel(Filter);
        label_31->setObjectName("label_31");

        formLayout_3->setWidget(12, QFormLayout::ItemRole::LabelRole, label_31);

        f_FocusTicksPerAlt = new QDoubleSpinBox(Filter);
        f_FocusTicksPerAlt->setObjectName("f_FocusTicksPerAlt");
        f_FocusTicksPerAlt->setMinimum(-10000.000000000000000);
        f_FocusTicksPerAlt->setMaximum(10000.000000000000000);

        formLayout_3->setWidget(12, QFormLayout::ItemRole::FieldRole, f_FocusTicksPerAlt);

        label_23 = new QLabel(Filter);
        label_23->setObjectName("label_23");

        formLayout_3->setWidget(13, QFormLayout::ItemRole::LabelRole, label_23);

        label_21 = new QLabel(Filter);
        label_21->setObjectName("label_21");

        formLayout_3->setWidget(14, QFormLayout::ItemRole::LabelRole, label_21);

        f_UseAutoFocus = new QCheckBox(Filter);
        f_UseAutoFocus->setObjectName("f_UseAutoFocus");

        formLayout_3->setWidget(14, QFormLayout::ItemRole::FieldRole, f_UseAutoFocus);

        label_20 = new QLabel(Filter);
        label_20->setObjectName("label_20");

        formLayout_3->setWidget(15, QFormLayout::ItemRole::LabelRole, label_20);

        f_LockedFilter = new QLineEdit(Filter);
        f_LockedFilter->setObjectName("f_LockedFilter");

        formLayout_3->setWidget(15, QFormLayout::ItemRole::FieldRole, f_LockedFilter);

        f_FocusTemperature = new QDoubleSpinBox(Filter);
        f_FocusTemperature->setObjectName("f_FocusTemperature");
        f_FocusTemperature->setEnabled(true);
        f_FocusTemperature->setReadOnly(false);
        f_FocusTemperature->setMinimum(-1000000.000000000000000);
        f_FocusTemperature->setMaximum(70.000000000000000);
        f_FocusTemperature->setValue(-1000000.000000000000000);

        formLayout_3->setWidget(8, QFormLayout::ItemRole::FieldRole, f_FocusTemperature);

        label_26 = new QLabel(Filter);
        label_26->setObjectName("label_26");

        formLayout_3->setWidget(8, QFormLayout::ItemRole::LabelRole, label_26);

        f_Wavelength = new QDoubleSpinBox(Filter);
        f_Wavelength->setObjectName("f_Wavelength");
        f_Wavelength->setDecimals(0);
        f_Wavelength->setMinimum(200.000000000000000);
        f_Wavelength->setMaximum(1000.000000000000000);
        f_Wavelength->setValue(500.000000000000000);

        formLayout_3->setWidget(13, QFormLayout::ItemRole::FieldRole, f_Wavelength);

        label_27 = new QLabel(Filter);
        label_27->setObjectName("label_27");

        formLayout_3->setWidget(10, QFormLayout::ItemRole::LabelRole, label_27);

        f_FocusDatetime = new QDateTimeEdit(Filter);
        f_FocusDatetime->setObjectName("f_FocusDatetime");
        f_FocusDatetime->setDateTime(QDateTime(QDate(2025, 1, 1), QTime(0, 0, 0)));
        f_FocusDatetime->setMaximumDateTime(QDateTime(QDate(2100, 1, 1), QTime(0, 0, 0)));
        f_FocusDatetime->setMinimumDateTime(QDateTime(QDate(2025, 1, 1), QTime(0, 0, 0)));
        f_FocusDatetime->setMinimumDate(QDate(2025, 1, 1));
        f_FocusDatetime->setCalendarPopup(false);

        formLayout_3->setWidget(10, QFormLayout::ItemRole::FieldRole, f_FocusDatetime);


        verticalLayout_3->addLayout(formLayout_3);

        horizontalLayout7 = new QHBoxLayout();
        horizontalLayout7->setObjectName("horizontalLayout7");
        horizontalSpacer3 = new QSpacerItem(40, 20, QSizePolicy::Policy::Expanding, QSizePolicy::Policy::Minimum);

        horizontalLayout7->addItem(horizontalSpacer3);

        NewFilter = new QPushButton(Filter);
        NewFilter->setObjectName("NewFilter");

        horizontalLayout7->addWidget(NewFilter);

        AddFilter = new QPushButton(Filter);
        AddFilter->setObjectName("AddFilter");

        horizontalLayout7->addWidget(AddFilter);

        RemoveFilter = new QPushButton(Filter);
        RemoveFilter->setObjectName("RemoveFilter");

        horizontalLayout7->addWidget(RemoveFilter);


        verticalLayout_3->addLayout(horizontalLayout7);


        horizontalLayout_7->addLayout(verticalLayout_3);

        horizontalLayout_7->setStretch(0, 1);
        horizontalLayout_7->setStretch(1, 2);
        tabWidget->addTab(Filter, QString());

        gridLayout_3->addWidget(tabWidget, 0, 0, 1, 1);

        QWidget::setTabOrder(tabWidget, Vendor);
        QWidget::setTabOrder(Vendor, Model);
        QWidget::setTabOrder(Model, Type);
        QWidget::setTabOrder(Type, Aperture);
        QWidget::setTabOrder(Aperture, FocalLength);
        QWidget::setTabOrder(FocalLength, AddScope);
        QWidget::setTabOrder(AddScope, NewScope);
        QWidget::setTabOrder(NewScope, RemoveScope);
        QWidget::setTabOrder(RemoveScope, ScopeList);
        QWidget::setTabOrder(ScopeList, EyepieceList);
        QWidget::setTabOrder(EyepieceList, e_Vendor);
        QWidget::setTabOrder(e_Vendor, e_Model);
        QWidget::setTabOrder(e_Model, e_focalLength);
        QWidget::setTabOrder(e_focalLength, NewEyepiece);
        QWidget::setTabOrder(NewEyepiece, AddEyepiece);
        QWidget::setTabOrder(AddEyepiece, RemoveEyepiece);
        QWidget::setTabOrder(RemoveEyepiece, DSLRLensList);
        QWidget::setTabOrder(DSLRLensList, DSLR_vendor);
        QWidget::setTabOrder(DSLR_vendor, DSLR_model);
        QWidget::setTabOrder(DSLR_model, DSLRFocalLength);
        QWidget::setTabOrder(DSLRFocalLength, DSLRFocalRatio);
        QWidget::setTabOrder(DSLRFocalRatio, AddDSLRLens);
        QWidget::setTabOrder(AddDSLRLens, NewDSLRLens);
        QWidget::setTabOrder(NewDSLRLens, RemoveDSLRLens);
        QWidget::setTabOrder(RemoveDSLRLens, l_Vendor);
        QWidget::setTabOrder(l_Vendor, l_Model);
        QWidget::setTabOrder(l_Model, l_Factor);
        QWidget::setTabOrder(l_Factor, NewLens);
        QWidget::setTabOrder(NewLens, AddLens);
        QWidget::setTabOrder(AddLens, RemoveLens);
        QWidget::setTabOrder(RemoveLens, FilterList);
        QWidget::setTabOrder(FilterList, f_Vendor);
        QWidget::setTabOrder(f_Vendor, f_Model);
        QWidget::setTabOrder(f_Model, f_Type);
        QWidget::setTabOrder(f_Type, f_Color);
        QWidget::setTabOrder(f_Color, f_Exposure);
        QWidget::setTabOrder(f_Exposure, f_Offset);
        QWidget::setTabOrder(f_Offset, f_AbsoluteFocusPosition);
        QWidget::setTabOrder(f_AbsoluteFocusPosition, f_UseAutoFocus);
        QWidget::setTabOrder(f_UseAutoFocus, f_LockedFilter);
        QWidget::setTabOrder(f_LockedFilter, NewFilter);
        QWidget::setTabOrder(NewFilter, AddFilter);
        QWidget::setTabOrder(AddFilter, RemoveFilter);
        QWidget::setTabOrder(RemoveFilter, LensList);

        retranslateUi(EquipmentWriter);

        tabWidget->setCurrentIndex(4);


        QMetaObject::connectSlotsByName(EquipmentWriter);
    } // setupUi

    void retranslateUi(QWidget *EquipmentWriter)
    {
        label->setText(tr2i18n("Id:", nullptr));
        Type->setItemText(0, tr2i18n("Refractor", nullptr));
        Type->setItemText(1, tr2i18n("Newtonian", nullptr));
        Type->setItemText(2, tr2i18n("Maksutov", nullptr));
        Type->setItemText(3, tr2i18n("Schmidt-Cassegrain", nullptr));
        Type->setItemText(4, tr2i18n("Kutter (Schiefspiegler)", nullptr));
        Type->setItemText(5, tr2i18n("Cassegrain", nullptr));
        Type->setItemText(6, tr2i18n("Ritchey-Chretien", nullptr));

        label_2->setText(tr2i18n("Model:", nullptr));
        label_5->setText(tr2i18n("Focal length:", nullptr));
        label_3->setText(tr2i18n("Vendor:", nullptr));
#if QT_CONFIG(tooltip)
        FocalLength->setToolTip(tr2i18n("Official telescope focal length in millimeters without any reducers or barlows", nullptr));
#endif // QT_CONFIG(tooltip)
        label_14->setText(tr2i18n("mm", nullptr));
        label_4->setText(tr2i18n("Type:", nullptr));
        label_15->setText(tr2i18n("mm", nullptr));
        label_13->setText(tr2i18n("Aperture:", nullptr));
#if QT_CONFIG(tooltip)
        AddScope->setToolTip(tr2i18n("Save telescope information", nullptr));
#endif // QT_CONFIG(tooltip)
        AddScope->setText(tr2i18n("Save", nullptr));
#if QT_CONFIG(tooltip)
        NewScope->setToolTip(tr2i18n("Clear data and add a new telescope", nullptr));
#endif // QT_CONFIG(tooltip)
        NewScope->setText(QString());
#if QT_CONFIG(tooltip)
        RemoveScope->setToolTip(tr2i18n("Remove current telescope", nullptr));
#endif // QT_CONFIG(tooltip)
        RemoveScope->setText(QString());
        tabWidget->setTabText(tabWidget->indexOf(Scope), tr2i18n("Telescope", nullptr));
        label_11->setText(tr2i18n("Unit:", nullptr));
        label_6->setText(tr2i18n("Id:", nullptr));
        label_8->setText(tr2i18n("Vendor:", nullptr));
        label_7->setText(tr2i18n("Model:", nullptr));
        NewEyepiece->setText(tr2i18n("Add New", nullptr));
        AddEyepiece->setText(tr2i18n("Save Eyepiece", nullptr));
        RemoveEyepiece->setText(tr2i18n("Remove", nullptr));
        label_9->setText(tr2i18n("Apparent FOV:", nullptr));
        label_17->setText(tr2i18n("mm", nullptr));
        label_10->setText(tr2i18n("Focal length:", nullptr));
        FovUnit->setItemText(0, tr2i18n("deg", nullptr));
        FovUnit->setItemText(1, tr2i18n("rad", nullptr));

        tabWidget->setTabText(tabWidget->indexOf(Eyepiece), tr2i18n("Eyepiece", nullptr));
        label_25->setText(tr2i18n("DSLR Lens", nullptr));
        label3_3->setText(tr2i18n("Id:", nullptr));
        label2_2->setText(tr2i18n("Model:", nullptr));
        label_29->setText(tr2i18n("mm", nullptr));
        label_24->setText(tr2i18n("Focal Length", nullptr));
        label31_2->setText(tr2i18n("Vendor:", nullptr));
#if QT_CONFIG(tooltip)
        label51_2->setToolTip(tr2i18n("<html><head/><body><p>Lens Focal Ratio or F-Number</p></body></html>", nullptr));
#endif // QT_CONFIG(tooltip)
        label51_2->setText(tr2i18n("Focal Ratio", nullptr));
#if QT_CONFIG(tooltip)
        AddDSLRLens->setToolTip(tr2i18n("<html><head/><body><p>Save DSLR lens information</p></body></html>", nullptr));
#endif // QT_CONFIG(tooltip)
        AddDSLRLens->setText(tr2i18n("Save", nullptr));
#if QT_CONFIG(tooltip)
        NewDSLRLens->setToolTip(tr2i18n("<html><head/><body><p>Clear data and add a new DSLR lens</p></body></html>", nullptr));
#endif // QT_CONFIG(tooltip)
        NewDSLRLens->setText(QString());
#if QT_CONFIG(tooltip)
        RemoveDSLRLens->setToolTip(tr2i18n("<html><head/><body><p>Remove current DSLR lens</p></body></html>", nullptr));
#endif // QT_CONFIG(tooltip)
        RemoveDSLRLens->setText(QString());
        tabWidget->setTabText(tabWidget->indexOf(DSLRLens), tr2i18n("DSLR Lens", nullptr));
        label_16->setText(tr2i18n("Enter Details of Barlow/Shapley Lenses", nullptr));
        label3_2->setText(tr2i18n("Id:", nullptr));
        label31->setText(tr2i18n("Vendor:", nullptr));
#if QT_CONFIG(tooltip)
        label51->setToolTip(tr2i18n("Magnification factor of the Barlow/Shapley lens", nullptr));
#endif // QT_CONFIG(tooltip)
        label51->setText(tr2i18n("Factor:", nullptr));
        label2->setText(tr2i18n("Model:", nullptr));
        NewLens->setText(tr2i18n("Add New", nullptr));
        AddLens->setText(tr2i18n("Save Lens", nullptr));
        RemoveLens->setText(tr2i18n("Remove", nullptr));
        tabWidget->setTabText(tabWidget->indexOf(ScopeLens), tr2i18n("Barlow Lens", nullptr));
        label4->setText(tr2i18n("Id:", nullptr));
        label5->setText(tr2i18n("Vendor:", nullptr));
        label3->setText(tr2i18n("Model:", nullptr));
        label6->setText(tr2i18n("Type:", nullptr));
        label_12->setText(tr2i18n("Color:", nullptr));
        label_19->setText(tr2i18n("Exposure:", nullptr));
#if QT_CONFIG(tooltip)
        label_18->setToolTip(tr2i18n("Filter focus offset", nullptr));
#endif // QT_CONFIG(tooltip)
        label_18->setText(tr2i18n("Offset:", nullptr));
        label_22->setText(tr2i18n("Abs. position:", nullptr));
        label_28->setText(tr2i18n("Focus alt:", nullptr));
        label_30->setText(tr2i18n("Ticks per C:", nullptr));
        label_31->setText(tr2i18n("Ticks per Alt:", nullptr));
        label_23->setText(tr2i18n("Wavelength:", nullptr));
        label_21->setText(tr2i18n("Auto focus:", nullptr));
        f_UseAutoFocus->setText(tr2i18n("Enable", nullptr));
        label_20->setText(tr2i18n("Locked filter:", nullptr));
        f_LockedFilter->setText(tr2i18n("--", nullptr));
        label_26->setText(tr2i18n("Focus temp:", nullptr));
        label_27->setText(tr2i18n("Focus DT:", nullptr));
        f_FocusDatetime->setDisplayFormat(tr2i18n("yyyy-MM-dd hh:mm:ss", nullptr));
        NewFilter->setText(tr2i18n("Add New", nullptr));
        AddFilter->setText(tr2i18n("Save Filter", nullptr));
        RemoveFilter->setText(tr2i18n("Remove", nullptr));
        tabWidget->setTabText(tabWidget->indexOf(Filter), tr2i18n("Filter", nullptr));
        (void)EquipmentWriter;
    } // retranslateUi

};

namespace Ui {
    class EquipmentWriter: public Ui_EquipmentWriter {};
} // namespace Ui

QT_END_NAMESPACE

#endif // EQUIPMENTWRITER_H

