/********************************************************************************
** Form generated from reading UI file 'argsetaltaz.ui'
**
** Created by: Qt User Interface Compiler version 6.11.1
**
** WARNING! All changes made in this file will be lost when recompiling UI file!
********************************************************************************/

#ifndef UI_ARGSETALTAZ_H
#define UI_ARGSETALTAZ_H

#include <QtCore/QVariant>
#include <QtWidgets/QApplication>
#include <QtWidgets/QGridLayout>
#include <QtWidgets/QLabel>
#include <QtWidgets/QSpacerItem>
#include <QtWidgets/QVBoxLayout>
#include <QtWidgets/QWidget>
#include <klocalizedstring.h>
#include "widgets/dmsbox.h"

QT_BEGIN_NAMESPACE

class Ui_ArgSetAltAz
{
public:
    QVBoxLayout *vboxLayout;
    QGridLayout *gridLayout;
    QLabel *textLabel1;
    QLabel *textLabel1_2;
    dmsBox *AzBox;
    dmsBox *AltBox;
    QSpacerItem *spacerItem;

    void setupUi(QWidget *ArgSetAltAz)
    {
        if (ArgSetAltAz->objectName().isEmpty())
            ArgSetAltAz->setObjectName("ArgSetAltAz");
        ArgSetAltAz->resize(285, 96);
        vboxLayout = new QVBoxLayout(ArgSetAltAz);
#ifndef UI_Q_OS_MAC
        vboxLayout->setSpacing(6);
#endif
        vboxLayout->setContentsMargins(8, 8, 8, 8);
        vboxLayout->setObjectName("vboxLayout");
        gridLayout = new QGridLayout();
#ifndef UI_Q_OS_MAC
        gridLayout->setSpacing(6);
#endif
#ifndef UI_Q_OS_MAC
        gridLayout->setContentsMargins(0, 0, 0, 0);
#endif
        gridLayout->setObjectName("gridLayout");
        textLabel1 = new QLabel(ArgSetAltAz);
        textLabel1->setObjectName("textLabel1");

        gridLayout->addWidget(textLabel1, 0, 0, 1, 1);

        textLabel1_2 = new QLabel(ArgSetAltAz);
        textLabel1_2->setObjectName("textLabel1_2");

        gridLayout->addWidget(textLabel1_2, 1, 0, 1, 1);

        AzBox = new dmsBox(ArgSetAltAz);
        AzBox->setObjectName("AzBox");

        gridLayout->addWidget(AzBox, 0, 1, 1, 1);

        AltBox = new dmsBox(ArgSetAltAz);
        AltBox->setObjectName("AltBox");

        gridLayout->addWidget(AltBox, 1, 1, 1, 1);


        vboxLayout->addLayout(gridLayout);

        spacerItem = new QSpacerItem(263, 16, QSizePolicy::Policy::Minimum, QSizePolicy::Policy::Expanding);

        vboxLayout->addItem(spacerItem);


        retranslateUi(ArgSetAltAz);

        QMetaObject::connectSlotsByName(ArgSetAltAz);
    } // setupUi

    void retranslateUi(QWidget *ArgSetAltAz)
    {
        textLabel1->setText(tr2i18n("Az:", nullptr));
        textLabel1_2->setText(tr2i18n("Alt:", nullptr));
        (void)ArgSetAltAz;
    } // retranslateUi

};

namespace Ui {
    class ArgSetAltAz: public Ui_ArgSetAltAz {};
} // namespace Ui

QT_END_NAMESPACE

#endif // ARGSETALTAZ_H

