/****************************************************************************
** Meta object code from reading C++ file 'aiguideprotocol.h'
**
** Created by: The Qt Meta Object Compiler version 69 (Qt 6.11.1)
**
** WARNING! All changes made in this file will be lost!
*****************************************************************************/

#include "../../../../kstars-3.8.4.1/kstars/ekos/guide/aiguideprotocol.h"
#include <QtCore/qmetatype.h>

#include <QtCore/qtmochelpers.h>

#include <memory>


#include <QtCore/qxptype_traits.h>
#if !defined(Q_MOC_OUTPUT_REVISION)
#error "The header file 'aiguideprotocol.h' doesn't include <QObject>."
#elif Q_MOC_OUTPUT_REVISION != 69
#error "This file was generated using the moc from 6.11.1. It"
#error "cannot be used with the include files from this version of Qt."
#error "(The moc has changed too much.)"
#endif

#ifndef Q_CONSTINIT
#define Q_CONSTINIT
#endif

QT_WARNING_PUSH
QT_WARNING_DISABLE_DEPRECATED
QT_WARNING_DISABLE_GCC("-Wuseless-cast")
namespace {
struct qt_meta_tag_ZN4Ekos15AIGuideProtocolE_t {};
} // unnamed namespace

template <> constexpr inline auto Ekos::AIGuideProtocol::qt_create_metaobjectdata<qt_meta_tag_ZN4Ekos15AIGuideProtocolE_t>()
{
    namespace QMC = QtMocConstants;
    QtMocHelpers::StringRefStorage qt_stringData {
        "Ekos::AIGuideProtocol",
        "protocolLog",
        "",
        "message",
        "protocolProgress",
        "current",
        "total",
        "status",
        "protocolComplete",
        "protocolStopped",
        "trainingRequested",
        "QJsonObject",
        "sysidData",
        "trainingProgress",
        "trainingComplete",
        "trainingError",
        "error",
        "start",
        "mountType",
        "stop",
        "requestTraining",
        "loadAndComplete",
        "jsonFilePath",
        "onTrainingResult",
        "success",
        "processProtocol",
        "onGuideStats",
        "raErr",
        "decErr",
        "raPulse",
        "decPulse",
        "snr",
        "skyBg",
        "numStars",
        "ProtocolState",
        "STATE_IDLE",
        "STATE_PRECHECK",
        "STATE_HORIZON_SCAN",
        "STATE_SLEWING",
        "STATE_SETTLING",
        "STATE_CAPTURING_DATA",
        "STATE_DRIFT_RECENTER",
        "STATE_PULSE_RESPONSE_INIT",
        "STATE_PULSE_SENDING",
        "STATE_PULSE_RECORDING",
        "STATE_PULSE_SETTLING",
        "STATE_DONE",
        "STATE_TRAINING",
        "STATE_TRAINING_DONE",
        "STATE_ERROR"
    };

    QtMocHelpers::UintData qt_methods {
        // Signal 'protocolLog'
        QtMocHelpers::SignalData<void(const QString &)>(1, 2, QMC::AccessPublic, QMetaType::Void, {{
            { QMetaType::QString, 3 },
        }}),
        // Signal 'protocolProgress'
        QtMocHelpers::SignalData<void(int, int, const QString &)>(4, 2, QMC::AccessPublic, QMetaType::Void, {{
            { QMetaType::Int, 5 }, { QMetaType::Int, 6 }, { QMetaType::QString, 7 },
        }}),
        // Signal 'protocolComplete'
        QtMocHelpers::SignalData<void()>(8, 2, QMC::AccessPublic, QMetaType::Void),
        // Signal 'protocolStopped'
        QtMocHelpers::SignalData<void()>(9, 2, QMC::AccessPublic, QMetaType::Void),
        // Signal 'trainingRequested'
        QtMocHelpers::SignalData<void(const QJsonObject &)>(10, 2, QMC::AccessPublic, QMetaType::Void, {{
            { 0x80000000 | 11, 12 },
        }}),
        // Signal 'trainingProgress'
        QtMocHelpers::SignalData<void(const QString &)>(13, 2, QMC::AccessPublic, QMetaType::Void, {{
            { QMetaType::QString, 3 },
        }}),
        // Signal 'trainingComplete'
        QtMocHelpers::SignalData<void()>(14, 2, QMC::AccessPublic, QMetaType::Void),
        // Signal 'trainingError'
        QtMocHelpers::SignalData<void(const QString &)>(15, 2, QMC::AccessPublic, QMetaType::Void, {{
            { QMetaType::QString, 16 },
        }}),
        // Slot 'start'
        QtMocHelpers::SlotData<void(const QString &)>(17, 2, QMC::AccessPublic, QMetaType::Void, {{
            { QMetaType::QString, 18 },
        }}),
        // Slot 'stop'
        QtMocHelpers::SlotData<void()>(19, 2, QMC::AccessPublic, QMetaType::Void),
        // Slot 'requestTraining'
        QtMocHelpers::SlotData<void()>(20, 2, QMC::AccessPublic, QMetaType::Void),
        // Slot 'loadAndComplete'
        QtMocHelpers::SlotData<void(const QString &)>(21, 2, QMC::AccessPublic, QMetaType::Void, {{
            { QMetaType::QString, 22 },
        }}),
        // Slot 'onTrainingResult'
        QtMocHelpers::SlotData<void(bool, const QString &)>(23, 2, QMC::AccessPublic, QMetaType::Void, {{
            { QMetaType::Bool, 24 }, { QMetaType::QString, 3 },
        }}),
        // Slot 'processProtocol'
        QtMocHelpers::SlotData<void()>(25, 2, QMC::AccessPrivate, QMetaType::Void),
        // Slot 'onGuideStats'
        QtMocHelpers::SlotData<void(double, double, int, int, double, double, int)>(26, 2, QMC::AccessPrivate, QMetaType::Void, {{
            { QMetaType::Double, 27 }, { QMetaType::Double, 28 }, { QMetaType::Int, 29 }, { QMetaType::Int, 30 },
            { QMetaType::Double, 31 }, { QMetaType::Double, 32 }, { QMetaType::Int, 33 },
        }}),
    };
    QtMocHelpers::UintData qt_properties {
    };
    QtMocHelpers::UintData qt_enums {
        // enum 'ProtocolState'
        QtMocHelpers::EnumData<enum ProtocolState>(34, 34, QMC::EnumFlags{}).add({
            {   35, ProtocolState::STATE_IDLE },
            {   36, ProtocolState::STATE_PRECHECK },
            {   37, ProtocolState::STATE_HORIZON_SCAN },
            {   38, ProtocolState::STATE_SLEWING },
            {   39, ProtocolState::STATE_SETTLING },
            {   40, ProtocolState::STATE_CAPTURING_DATA },
            {   41, ProtocolState::STATE_DRIFT_RECENTER },
            {   42, ProtocolState::STATE_PULSE_RESPONSE_INIT },
            {   43, ProtocolState::STATE_PULSE_SENDING },
            {   44, ProtocolState::STATE_PULSE_RECORDING },
            {   45, ProtocolState::STATE_PULSE_SETTLING },
            {   46, ProtocolState::STATE_DONE },
            {   47, ProtocolState::STATE_TRAINING },
            {   48, ProtocolState::STATE_TRAINING_DONE },
            {   49, ProtocolState::STATE_ERROR },
        }),
    };
    return QtMocHelpers::metaObjectData<AIGuideProtocol, qt_meta_tag_ZN4Ekos15AIGuideProtocolE_t>(QMC::MetaObjectFlag{}, qt_stringData,
            qt_methods, qt_properties, qt_enums);
}
Q_CONSTINIT const QMetaObject Ekos::AIGuideProtocol::staticMetaObject = { {
    QMetaObject::SuperData::link<QObject::staticMetaObject>(),
    qt_staticMetaObjectStaticContent<qt_meta_tag_ZN4Ekos15AIGuideProtocolE_t>.stringdata,
    qt_staticMetaObjectStaticContent<qt_meta_tag_ZN4Ekos15AIGuideProtocolE_t>.data,
    qt_static_metacall,
    nullptr,
    qt_staticMetaObjectRelocatingContent<qt_meta_tag_ZN4Ekos15AIGuideProtocolE_t>.metaTypes,
    nullptr
} };

void Ekos::AIGuideProtocol::qt_static_metacall(QObject *_o, QMetaObject::Call _c, int _id, void **_a)
{
    auto *_t = static_cast<AIGuideProtocol *>(_o);
    if (_c == QMetaObject::InvokeMetaMethod) {
        switch (_id) {
        case 0: _t->protocolLog((*reinterpret_cast<std::add_pointer_t<QString>>(_a[1]))); break;
        case 1: _t->protocolProgress((*reinterpret_cast<std::add_pointer_t<int>>(_a[1])),(*reinterpret_cast<std::add_pointer_t<int>>(_a[2])),(*reinterpret_cast<std::add_pointer_t<QString>>(_a[3]))); break;
        case 2: _t->protocolComplete(); break;
        case 3: _t->protocolStopped(); break;
        case 4: _t->trainingRequested((*reinterpret_cast<std::add_pointer_t<QJsonObject>>(_a[1]))); break;
        case 5: _t->trainingProgress((*reinterpret_cast<std::add_pointer_t<QString>>(_a[1]))); break;
        case 6: _t->trainingComplete(); break;
        case 7: _t->trainingError((*reinterpret_cast<std::add_pointer_t<QString>>(_a[1]))); break;
        case 8: _t->start((*reinterpret_cast<std::add_pointer_t<QString>>(_a[1]))); break;
        case 9: _t->stop(); break;
        case 10: _t->requestTraining(); break;
        case 11: _t->loadAndComplete((*reinterpret_cast<std::add_pointer_t<QString>>(_a[1]))); break;
        case 12: _t->onTrainingResult((*reinterpret_cast<std::add_pointer_t<bool>>(_a[1])),(*reinterpret_cast<std::add_pointer_t<QString>>(_a[2]))); break;
        case 13: _t->processProtocol(); break;
        case 14: _t->onGuideStats((*reinterpret_cast<std::add_pointer_t<double>>(_a[1])),(*reinterpret_cast<std::add_pointer_t<double>>(_a[2])),(*reinterpret_cast<std::add_pointer_t<int>>(_a[3])),(*reinterpret_cast<std::add_pointer_t<int>>(_a[4])),(*reinterpret_cast<std::add_pointer_t<double>>(_a[5])),(*reinterpret_cast<std::add_pointer_t<double>>(_a[6])),(*reinterpret_cast<std::add_pointer_t<int>>(_a[7]))); break;
        default: ;
        }
    }
    if (_c == QMetaObject::IndexOfMethod) {
        if (QtMocHelpers::indexOfMethod<void (AIGuideProtocol::*)(const QString & )>(_a, &AIGuideProtocol::protocolLog, 0))
            return;
        if (QtMocHelpers::indexOfMethod<void (AIGuideProtocol::*)(int , int , const QString & )>(_a, &AIGuideProtocol::protocolProgress, 1))
            return;
        if (QtMocHelpers::indexOfMethod<void (AIGuideProtocol::*)()>(_a, &AIGuideProtocol::protocolComplete, 2))
            return;
        if (QtMocHelpers::indexOfMethod<void (AIGuideProtocol::*)()>(_a, &AIGuideProtocol::protocolStopped, 3))
            return;
        if (QtMocHelpers::indexOfMethod<void (AIGuideProtocol::*)(const QJsonObject & )>(_a, &AIGuideProtocol::trainingRequested, 4))
            return;
        if (QtMocHelpers::indexOfMethod<void (AIGuideProtocol::*)(const QString & )>(_a, &AIGuideProtocol::trainingProgress, 5))
            return;
        if (QtMocHelpers::indexOfMethod<void (AIGuideProtocol::*)()>(_a, &AIGuideProtocol::trainingComplete, 6))
            return;
        if (QtMocHelpers::indexOfMethod<void (AIGuideProtocol::*)(const QString & )>(_a, &AIGuideProtocol::trainingError, 7))
            return;
    }
}

const QMetaObject *Ekos::AIGuideProtocol::metaObject() const
{
    return QObject::d_ptr->metaObject ? QObject::d_ptr->dynamicMetaObject() : &staticMetaObject;
}

void *Ekos::AIGuideProtocol::qt_metacast(const char *_clname)
{
    if (!_clname) return nullptr;
    if (!strcmp(_clname, qt_staticMetaObjectStaticContent<qt_meta_tag_ZN4Ekos15AIGuideProtocolE_t>.strings))
        return static_cast<void*>(this);
    return QObject::qt_metacast(_clname);
}

int Ekos::AIGuideProtocol::qt_metacall(QMetaObject::Call _c, int _id, void **_a)
{
    _id = QObject::qt_metacall(_c, _id, _a);
    if (_id < 0)
        return _id;
    if (_c == QMetaObject::InvokeMetaMethod) {
        if (_id < 15)
            qt_static_metacall(this, _c, _id, _a);
        _id -= 15;
    }
    if (_c == QMetaObject::RegisterMethodArgumentMetaType) {
        if (_id < 15)
            *reinterpret_cast<QMetaType *>(_a[0]) = QMetaType();
        _id -= 15;
    }
    return _id;
}

// SIGNAL 0
void Ekos::AIGuideProtocol::protocolLog(const QString & _t1)
{
    QMetaObject::activate<void>(this, &staticMetaObject, 0, nullptr, _t1);
}

// SIGNAL 1
void Ekos::AIGuideProtocol::protocolProgress(int _t1, int _t2, const QString & _t3)
{
    QMetaObject::activate<void>(this, &staticMetaObject, 1, nullptr, _t1, _t2, _t3);
}

// SIGNAL 2
void Ekos::AIGuideProtocol::protocolComplete()
{
    QMetaObject::activate(this, &staticMetaObject, 2, nullptr);
}

// SIGNAL 3
void Ekos::AIGuideProtocol::protocolStopped()
{
    QMetaObject::activate(this, &staticMetaObject, 3, nullptr);
}

// SIGNAL 4
void Ekos::AIGuideProtocol::trainingRequested(const QJsonObject & _t1)
{
    QMetaObject::activate<void>(this, &staticMetaObject, 4, nullptr, _t1);
}

// SIGNAL 5
void Ekos::AIGuideProtocol::trainingProgress(const QString & _t1)
{
    QMetaObject::activate<void>(this, &staticMetaObject, 5, nullptr, _t1);
}

// SIGNAL 6
void Ekos::AIGuideProtocol::trainingComplete()
{
    QMetaObject::activate(this, &staticMetaObject, 6, nullptr);
}

// SIGNAL 7
void Ekos::AIGuideProtocol::trainingError(const QString & _t1)
{
    QMetaObject::activate<void>(this, &staticMetaObject, 7, nullptr, _t1);
}
QT_WARNING_POP
