/*
 * This file was generated by qdbusxml2cpp version 0.8
 * Source file was org.kde.kstars.INDI.Weather.xml
 *
 * qdbusxml2cpp is Copyright (C) The Qt Company Ltd. and other contributors.
 *
 * This is an auto-generated file.
 * Do not edit! All changes made to it will be lost.
 */

#include "weatheradaptor.h"
#include <QtCore/QMetaObject>
#include <QtCore/QByteArray>
#include <QtCore/QList>
#include <QtCore/QMap>
#include <QtCore/QString>
#include <QtCore/QStringList>
#include <QtCore/QVariant>

/*
 * Implementation of adaptor class WeatherAdaptor
 */

WeatherAdaptor::WeatherAdaptor(ISD::Weather *parent)
    : QDBusAbstractAdaptor(parent)
{
    // constructor
    setAutoRelaySignals(true);
}

WeatherAdaptor::~WeatherAdaptor()
{
    // destructor
}

bool WeatherAdaptor::connected() const
{
    // get the value of property connected
    return qvariant_cast< bool >(parent()->property("connected"));
}

QString WeatherAdaptor::data() const
{
    // get the value of property data
    return qvariant_cast< QString >(parent()->property("data"));
}

QString WeatherAdaptor::name() const
{
    // get the value of property name
    return qvariant_cast< QString >(parent()->property("name"));
}

int WeatherAdaptor::refreshPeriod() const
{
    // get the value of property refreshPeriod
    return qvariant_cast< int >(parent()->property("refreshPeriod"));
}

int WeatherAdaptor::status() const
{
    // get the value of property status
    return qvariant_cast< int >(parent()->property("status"));
}

void WeatherAdaptor::Connect()
{
    // handle method call org.kde.kstars.INDI.Weather.Connect
    parent()->Connect();
}

void WeatherAdaptor::Disconnect()
{
    // handle method call org.kde.kstars.INDI.Weather.Disconnect
    parent()->Disconnect();
}


#include "moc_weatheradaptor.cpp"
