/****************************************************************************
** Meta object code from reading C++ file 'simclock.h'
**
** Created by: The Qt Meta Object Compiler version 69 (Qt 6.11.1)
**
** WARNING! All changes made in this file will be lost!
*****************************************************************************/

#include "../../../../kstars-3.8.4.1/kstars/time/simclock.h"
#include <QtCore/qmetatype.h>

#include <QtCore/qtmochelpers.h>

#include <memory>


#include <QtCore/qxptype_traits.h>
#if !defined(Q_MOC_OUTPUT_REVISION)
#error "The header file 'simclock.h' doesn't include <QObject>."
#elif Q_MOC_OUTPUT_REVISION != 69
#error "This file was generated using the moc from 6.11.1. It"
#error "cannot be used with the include files from this version of Qt."
#error "(The moc has changed too much.)"
#endif

#ifndef Q_CONSTINIT
#define Q_CONSTINIT
#endif

QT_WARNING_PUSH
QT_WARNING_DISABLE_DEPRECATED
QT_WARNING_DISABLE_GCC("-Wuseless-cast")
namespace {
struct qt_meta_tag_ZN8SimClockE_t {};
} // unnamed namespace

template <> constexpr inline auto SimClock::qt_create_metaobjectdata<qt_meta_tag_ZN8SimClockE_t>()
{
    namespace QMC = QtMocConstants;
    QtMocHelpers::StringRefStorage qt_stringData {
        "SimClock",
        "D-Bus Interface",
        "org.kde.kstars.SimClock",
        "timeChanged",
        "",
        "timeAdvanced",
        "scaleChanged",
        "clockToggled",
        "realtimeToogled",
        "stop",
        "Q_NOREPLY",
        "start",
        "setUTC",
        "KStarsDateTime",
        "newtime",
        "setNow",
        "setClockScale",
        "scale",
        "tick",
        "manualTick",
        "force",
        "backward",
        "setRealTime",
        "on",
        "isActive"
    };

    QtMocHelpers::UintData qt_methods {
        // Signal 'timeChanged'
        QtMocHelpers::SignalData<void()>(3, 4, QMC::AccessPublic, QMetaType::Void),
        // Signal 'timeAdvanced'
        QtMocHelpers::SignalData<void()>(5, 4, QMC::AccessPublic, QMetaType::Void),
        // Signal 'scaleChanged'
        QtMocHelpers::SignalData<void(float)>(6, 4, QMC::AccessPublic, QMetaType::Void, {{
            { QMetaType::Float, 4 },
        }}),
        // Signal 'clockToggled'
        QtMocHelpers::SignalData<void(bool)>(7, 4, QMC::AccessPublic, QMetaType::Void, {{
            { QMetaType::Bool, 4 },
        }}),
        // Signal 'realtimeToogled'
        QtMocHelpers::SignalData<void(bool)>(8, 4, QMC::AccessPublic, QMetaType::Void, {{
            { QMetaType::Bool, 4 },
        }}),
        // Slot 'stop'
        QtMocHelpers::SlotData<void()>(9, 10, QMC::AccessPublic | QMC::MethodScriptable, QMetaType::Void),
        // Slot 'start'
        QtMocHelpers::SlotData<void()>(11, 10, QMC::AccessPublic | QMC::MethodScriptable, QMetaType::Void),
        // Slot 'setUTC'
        QtMocHelpers::SlotData<void(const KStarsDateTime &)>(12, 10, QMC::AccessPublic | QMC::MethodScriptable, QMetaType::Void, {{
            { 0x80000000 | 13, 14 },
        }}),
        // Slot 'setNow'
        QtMocHelpers::SlotData<void()>(15, 10, QMC::AccessPublic | QMC::MethodScriptable, QMetaType::Void),
        // Slot 'setClockScale'
        QtMocHelpers::SlotData<void(double)>(16, 10, QMC::AccessPublic | QMC::MethodScriptable, QMetaType::Void, {{
            { QMetaType::Double, 17 },
        }}),
        // Slot 'tick'
        QtMocHelpers::SlotData<void()>(18, 4, QMC::AccessPublic, QMetaType::Void),
        // Slot 'manualTick'
        QtMocHelpers::SlotData<void(bool, bool)>(19, 4, QMC::AccessPublic, QMetaType::Void, {{
            { QMetaType::Bool, 20 }, { QMetaType::Bool, 21 },
        }}),
        // Slot 'manualTick'
        QtMocHelpers::SlotData<void(bool)>(19, 4, QMC::AccessPublic | QMC::MethodCloned, QMetaType::Void, {{
            { QMetaType::Bool, 20 },
        }}),
        // Slot 'manualTick'
        QtMocHelpers::SlotData<void()>(19, 4, QMC::AccessPublic | QMC::MethodCloned, QMetaType::Void),
        // Slot 'setRealTime'
        QtMocHelpers::SlotData<void(bool)>(22, 4, QMC::AccessPublic, QMetaType::Void, {{
            { QMetaType::Bool, 23 },
        }}),
        // Slot 'setRealTime'
        QtMocHelpers::SlotData<void()>(22, 4, QMC::AccessPublic | QMC::MethodCloned, QMetaType::Void),
        // Method 'isActive'
        QtMocHelpers::MethodData<bool()>(24, 4, QMC::AccessPublic, QMetaType::Bool),
    };
    QtMocHelpers::UintData qt_properties {
    };
    QtMocHelpers::UintData qt_enums {
    };
    QtMocHelpers::UintData qt_constructors {};
    QtMocHelpers::ClassInfos qt_classinfo({
            {    1,    2 },
    });
    return QtMocHelpers::metaObjectData<SimClock, qt_meta_tag_ZN8SimClockE_t>(QMC::MetaObjectFlag{}, qt_stringData,
            qt_methods, qt_properties, qt_enums, qt_constructors, qt_classinfo);
}
Q_CONSTINIT const QMetaObject SimClock::staticMetaObject = { {
    QMetaObject::SuperData::link<QObject::staticMetaObject>(),
    qt_staticMetaObjectStaticContent<qt_meta_tag_ZN8SimClockE_t>.stringdata,
    qt_staticMetaObjectStaticContent<qt_meta_tag_ZN8SimClockE_t>.data,
    qt_static_metacall,
    nullptr,
    qt_staticMetaObjectRelocatingContent<qt_meta_tag_ZN8SimClockE_t>.metaTypes,
    nullptr
} };

void SimClock::qt_static_metacall(QObject *_o, QMetaObject::Call _c, int _id, void **_a)
{
    auto *_t = static_cast<SimClock *>(_o);
    if (_c == QMetaObject::InvokeMetaMethod) {
        switch (_id) {
        case 0: _t->timeChanged(); break;
        case 1: _t->timeAdvanced(); break;
        case 2: _t->scaleChanged((*reinterpret_cast<std::add_pointer_t<float>>(_a[1]))); break;
        case 3: _t->clockToggled((*reinterpret_cast<std::add_pointer_t<bool>>(_a[1]))); break;
        case 4: _t->realtimeToogled((*reinterpret_cast<std::add_pointer_t<bool>>(_a[1]))); break;
        case 5: _t->stop(); break;
        case 6: _t->start(); break;
        case 7: _t->setUTC((*reinterpret_cast<std::add_pointer_t<KStarsDateTime>>(_a[1]))); break;
        case 8: _t->setNow(); break;
        case 9: _t->setClockScale((*reinterpret_cast<std::add_pointer_t<double>>(_a[1]))); break;
        case 10: _t->tick(); break;
        case 11: _t->manualTick((*reinterpret_cast<std::add_pointer_t<bool>>(_a[1])),(*reinterpret_cast<std::add_pointer_t<bool>>(_a[2]))); break;
        case 12: _t->manualTick((*reinterpret_cast<std::add_pointer_t<bool>>(_a[1]))); break;
        case 13: _t->manualTick(); break;
        case 14: _t->setRealTime((*reinterpret_cast<std::add_pointer_t<bool>>(_a[1]))); break;
        case 15: _t->setRealTime(); break;
        case 16: { bool _r = _t->isActive();
            if (_a[0]) *reinterpret_cast<bool*>(_a[0]) = std::move(_r); }  break;
        default: ;
        }
    }
    if (_c == QMetaObject::IndexOfMethod) {
        if (QtMocHelpers::indexOfMethod<void (SimClock::*)()>(_a, &SimClock::timeChanged, 0))
            return;
        if (QtMocHelpers::indexOfMethod<void (SimClock::*)()>(_a, &SimClock::timeAdvanced, 1))
            return;
        if (QtMocHelpers::indexOfMethod<void (SimClock::*)(float )>(_a, &SimClock::scaleChanged, 2))
            return;
        if (QtMocHelpers::indexOfMethod<void (SimClock::*)(bool )>(_a, &SimClock::clockToggled, 3))
            return;
        if (QtMocHelpers::indexOfMethod<void (SimClock::*)(bool )>(_a, &SimClock::realtimeToogled, 4))
            return;
    }
}

const QMetaObject *SimClock::metaObject() const
{
    return QObject::d_ptr->metaObject ? QObject::d_ptr->dynamicMetaObject() : &staticMetaObject;
}

void *SimClock::qt_metacast(const char *_clname)
{
    if (!_clname) return nullptr;
    if (!strcmp(_clname, qt_staticMetaObjectStaticContent<qt_meta_tag_ZN8SimClockE_t>.strings))
        return static_cast<void*>(this);
    return QObject::qt_metacast(_clname);
}

int SimClock::qt_metacall(QMetaObject::Call _c, int _id, void **_a)
{
    _id = QObject::qt_metacall(_c, _id, _a);
    if (_id < 0)
        return _id;
    if (_c == QMetaObject::InvokeMetaMethod) {
        if (_id < 17)
            qt_static_metacall(this, _c, _id, _a);
        _id -= 17;
    }
    if (_c == QMetaObject::RegisterMethodArgumentMetaType) {
        if (_id < 17)
            *reinterpret_cast<QMetaType *>(_a[0]) = QMetaType();
        _id -= 17;
    }
    return _id;
}

// SIGNAL 0
void SimClock::timeChanged()
{
    QMetaObject::activate(this, &staticMetaObject, 0, nullptr);
}

// SIGNAL 1
void SimClock::timeAdvanced()
{
    QMetaObject::activate(this, &staticMetaObject, 1, nullptr);
}

// SIGNAL 2
void SimClock::scaleChanged(float _t1)
{
    QMetaObject::activate<void>(this, &staticMetaObject, 2, nullptr, _t1);
}

// SIGNAL 3
void SimClock::clockToggled(bool _t1)
{
    QMetaObject::activate<void>(this, &staticMetaObject, 3, nullptr, _t1);
}

// SIGNAL 4
void SimClock::realtimeToogled(bool _t1)
{
    QMetaObject::activate<void>(this, &staticMetaObject, 4, nullptr, _t1);
}
QT_WARNING_POP
