/********************************************************************************
** Form generated from reading UI file 'modcalcdaylength.ui'
**
** Created by: Qt User Interface Compiler version 6.11.1
**
** WARNING! All changes made in this file will be lost when recompiling UI file!
********************************************************************************/

#ifndef UI_MODCALCDAYLENGTH_H
#define UI_MODCALCDAYLENGTH_H

#include <QtCore/QVariant>
#include <QtWidgets/QApplication>
#include <QtWidgets/QDateEdit>
#include <QtWidgets/QGridLayout>
#include <QtWidgets/QGroupBox>
#include <QtWidgets/QHBoxLayout>
#include <QtWidgets/QLabel>
#include <QtWidgets/QPushButton>
#include <QtWidgets/QSpacerItem>
#include <QtWidgets/QTabWidget>
#include <QtWidgets/QVBoxLayout>
#include <QtWidgets/QWidget>
#include <klocalizedstring.h>
#include "kurlrequester.h"

QT_BEGIN_NAMESPACE

class Ui_modCalcDayLengthDlg
{
public:
    QVBoxLayout *vboxLayout;
    QTabWidget *tabWidget;
    QWidget *tab;
    QVBoxLayout *vboxLayout1;
    QGridLayout *gridLayout;
    QLabel *LocationLabel;
    QLabel *DateLabel;
    QPushButton *Location;
    QSpacerItem *spacerItem;
    QSpacerItem *spacerItem1;
    QSpacerItem *spacerItem2;
    QDateEdit *Date;
    QGroupBox *SunBox;
    QVBoxLayout *vboxLayout2;
    QGridLayout *gridLayout1;
    QLabel *SunTransitAltLabel;
    QSpacerItem *spacerItem3;
    QLabel *SunTransitAlt;
    QSpacerItem *spacerItem4;
    QLabel *DayLength;
    QSpacerItem *spacerItem5;
    QSpacerItem *spacerItem6;
    QLabel *SunSetLabel;
    QLabel *DayLengthLabel;
    QLabel *SunRiseAz;
    QLabel *SunRiseAzLabel;
    QLabel *SunRiseLabel;
    QLabel *SunTransitLabel;
    QLabel *SunSetAz;
    QSpacerItem *spacerItem7;
    QLabel *SunSet;
    QLabel *SunSetAzLabel;
    QLabel *SunRise;
    QLabel *SunTransit;
    QSpacerItem *spacerItem8;
    QGroupBox *MoonBox;
    QVBoxLayout *vboxLayout3;
    QHBoxLayout *hboxLayout;
    QGridLayout *gridLayout2;
    QLabel *MoonRiseLabel;
    QSpacerItem *spacerItem9;
    QLabel *MoonRise;
    QSpacerItem *spacerItem10;
    QLabel *MoonTransitAltLabel;
    QLabel *MoonSet;
    QSpacerItem *spacerItem11;
    QLabel *MoonRiseAzLabel;
    QLabel *MoonRiseAz;
    QLabel *MoonSetAz;
    QLabel *MoonTransitAlt;
    QLabel *MoonTransitLabel;
    QLabel *MoonSetLabel;
    QLabel *MoonSetAzLabel;
    QLabel *MoonTransit;
    QHBoxLayout *hboxLayout1;
    QLabel *LunarPhaseLabel;
    QLabel *LunarPhase;
    QSpacerItem *spacerItem12;
    QSpacerItem *spacerItem13;
    QWidget *tab_2;
    QVBoxLayout *vboxLayout4;
    QHBoxLayout *hboxLayout2;
    QLabel *LocationLabelBatch;
    QPushButton *LocationBatch;
    QSpacerItem *spacerItem14;
    QSpacerItem *spacerItem15;
    QLabel *label;
    QGridLayout *gridLayout3;
    QLabel *label_5;
    KUrlRequester *InputFileBatch;
    QLabel *label_6;
    KUrlRequester *OutputFileBatch;
    QSpacerItem *spacerItem16;
    QHBoxLayout *hboxLayout3;
    QSpacerItem *spacerItem17;
    QVBoxLayout *vboxLayout5;
    QPushButton *RunButtonBatch;
    QPushButton *ViewButtonBatch;
    QSpacerItem *spacerItem18;
    QSpacerItem *spacerItem19;

    void setupUi(QWidget *modCalcDayLengthDlg)
    {
        if (modCalcDayLengthDlg->objectName().isEmpty())
            modCalcDayLengthDlg->setObjectName("modCalcDayLengthDlg");
        modCalcDayLengthDlg->resize(415, 465);
        vboxLayout = new QVBoxLayout(modCalcDayLengthDlg);
        vboxLayout->setObjectName("vboxLayout");
        tabWidget = new QTabWidget(modCalcDayLengthDlg);
        tabWidget->setObjectName("tabWidget");
        tab = new QWidget();
        tab->setObjectName("tab");
        vboxLayout1 = new QVBoxLayout(tab);
        vboxLayout1->setObjectName("vboxLayout1");
        gridLayout = new QGridLayout();
#ifndef UI_Q_OS_MAC
        gridLayout->setSpacing(6);
#endif
#ifndef UI_Q_OS_MAC
        gridLayout->setContentsMargins(0, 0, 0, 0);
#endif
        gridLayout->setObjectName("gridLayout");
        LocationLabel = new QLabel(tab);
        LocationLabel->setObjectName("LocationLabel");

        gridLayout->addWidget(LocationLabel, 1, 0, 1, 1);

        DateLabel = new QLabel(tab);
        DateLabel->setObjectName("DateLabel");

        gridLayout->addWidget(DateLabel, 0, 0, 1, 1);

        Location = new QPushButton(tab);
        Location->setObjectName("Location");
        QSizePolicy sizePolicy(QSizePolicy::Policy::Minimum, QSizePolicy::Policy::Minimum);
        sizePolicy.setHorizontalStretch(0);
        sizePolicy.setVerticalStretch(0);
        sizePolicy.setHeightForWidth(Location->sizePolicy().hasHeightForWidth());
        Location->setSizePolicy(sizePolicy);

        gridLayout->addWidget(Location, 1, 1, 1, 2);

        spacerItem = new QSpacerItem(40, 20, QSizePolicy::Policy::Expanding, QSizePolicy::Policy::Minimum);

        gridLayout->addItem(spacerItem, 0, 2, 1, 1);

        spacerItem1 = new QSpacerItem(40, 20, QSizePolicy::Policy::Expanding, QSizePolicy::Policy::Minimum);

        gridLayout->addItem(spacerItem1, 0, 3, 1, 1);

        spacerItem2 = new QSpacerItem(40, 20, QSizePolicy::Policy::Expanding, QSizePolicy::Policy::Minimum);

        gridLayout->addItem(spacerItem2, 1, 3, 1, 1);

        Date = new QDateEdit(tab);
        Date->setObjectName("Date");

        gridLayout->addWidget(Date, 0, 1, 1, 1);


        vboxLayout1->addLayout(gridLayout);

        SunBox = new QGroupBox(tab);
        SunBox->setObjectName("SunBox");
        vboxLayout2 = new QVBoxLayout(SunBox);
#ifndef UI_Q_OS_MAC
        vboxLayout2->setSpacing(6);
#endif
#ifndef UI_Q_OS_MAC
        vboxLayout2->setContentsMargins(9, 9, 9, 9);
#endif
        vboxLayout2->setObjectName("vboxLayout2");
        gridLayout1 = new QGridLayout();
#ifndef UI_Q_OS_MAC
        gridLayout1->setSpacing(6);
#endif
#ifndef UI_Q_OS_MAC
        gridLayout1->setContentsMargins(0, 0, 0, 0);
#endif
        gridLayout1->setObjectName("gridLayout1");
        SunTransitAltLabel = new QLabel(SunBox);
        SunTransitAltLabel->setObjectName("SunTransitAltLabel");

        gridLayout1->addWidget(SunTransitAltLabel, 1, 3, 1, 1);

        spacerItem3 = new QSpacerItem(12, 12, QSizePolicy::Policy::Fixed, QSizePolicy::Policy::Minimum);

        gridLayout1->addItem(spacerItem3, 1, 2, 1, 1);

        SunTransitAlt = new QLabel(SunBox);
        SunTransitAlt->setObjectName("SunTransitAlt");
        QFont font;
        font.setFamilies({QString::fromUtf8("Monospace")});
        font.setPointSize(12);
        font.setBold(true);
        SunTransitAlt->setFont(font);
        SunTransitAlt->setIndent(5);
        SunTransitAlt->setTextInteractionFlags(Qt::TextSelectableByMouse);

        gridLayout1->addWidget(SunTransitAlt, 1, 4, 1, 1);

        spacerItem4 = new QSpacerItem(12, 12, QSizePolicy::Policy::Fixed, QSizePolicy::Policy::Minimum);

        gridLayout1->addItem(spacerItem4, 3, 2, 1, 1);

        DayLength = new QLabel(SunBox);
        DayLength->setObjectName("DayLength");
        DayLength->setFont(font);
        DayLength->setIndent(5);
        DayLength->setTextInteractionFlags(Qt::TextSelectableByMouse);

        gridLayout1->addWidget(DayLength, 3, 1, 1, 1);

        spacerItem5 = new QSpacerItem(163, 16, QSizePolicy::Policy::Expanding, QSizePolicy::Policy::Minimum);

        gridLayout1->addItem(spacerItem5, 3, 3, 1, 2);

        spacerItem6 = new QSpacerItem(12, 12, QSizePolicy::Policy::Fixed, QSizePolicy::Policy::Minimum);

        gridLayout1->addItem(spacerItem6, 2, 2, 1, 1);

        SunSetLabel = new QLabel(SunBox);
        SunSetLabel->setObjectName("SunSetLabel");
        QSizePolicy sizePolicy1(QSizePolicy::Policy::Minimum, QSizePolicy::Policy::Preferred);
        sizePolicy1.setHorizontalStretch(0);
        sizePolicy1.setVerticalStretch(0);
        sizePolicy1.setHeightForWidth(SunSetLabel->sizePolicy().hasHeightForWidth());
        SunSetLabel->setSizePolicy(sizePolicy1);

        gridLayout1->addWidget(SunSetLabel, 2, 0, 1, 1);

        DayLengthLabel = new QLabel(SunBox);
        DayLengthLabel->setObjectName("DayLengthLabel");
        QSizePolicy sizePolicy2(QSizePolicy::Policy::Fixed, QSizePolicy::Policy::Preferred);
        sizePolicy2.setHorizontalStretch(0);
        sizePolicy2.setVerticalStretch(0);
        sizePolicy2.setHeightForWidth(DayLengthLabel->sizePolicy().hasHeightForWidth());
        DayLengthLabel->setSizePolicy(sizePolicy2);

        gridLayout1->addWidget(DayLengthLabel, 3, 0, 1, 1);

        SunRiseAz = new QLabel(SunBox);
        SunRiseAz->setObjectName("SunRiseAz");
        SunRiseAz->setFont(font);
        SunRiseAz->setIndent(5);
        SunRiseAz->setTextInteractionFlags(Qt::TextSelectableByMouse);

        gridLayout1->addWidget(SunRiseAz, 0, 4, 1, 1);

        SunRiseAzLabel = new QLabel(SunBox);
        SunRiseAzLabel->setObjectName("SunRiseAzLabel");

        gridLayout1->addWidget(SunRiseAzLabel, 0, 3, 1, 1);

        SunRiseLabel = new QLabel(SunBox);
        SunRiseLabel->setObjectName("SunRiseLabel");
        sizePolicy1.setHeightForWidth(SunRiseLabel->sizePolicy().hasHeightForWidth());
        SunRiseLabel->setSizePolicy(sizePolicy1);

        gridLayout1->addWidget(SunRiseLabel, 0, 0, 1, 1);

        SunTransitLabel = new QLabel(SunBox);
        SunTransitLabel->setObjectName("SunTransitLabel");
        sizePolicy1.setHeightForWidth(SunTransitLabel->sizePolicy().hasHeightForWidth());
        SunTransitLabel->setSizePolicy(sizePolicy1);

        gridLayout1->addWidget(SunTransitLabel, 1, 0, 1, 1);

        SunSetAz = new QLabel(SunBox);
        SunSetAz->setObjectName("SunSetAz");
        SunSetAz->setFont(font);
        SunSetAz->setIndent(5);
        SunSetAz->setTextInteractionFlags(Qt::TextSelectableByMouse);

        gridLayout1->addWidget(SunSetAz, 2, 4, 1, 1);

        spacerItem7 = new QSpacerItem(12, 12, QSizePolicy::Policy::Fixed, QSizePolicy::Policy::Minimum);

        gridLayout1->addItem(spacerItem7, 0, 2, 1, 1);

        SunSet = new QLabel(SunBox);
        SunSet->setObjectName("SunSet");
        SunSet->setFont(font);
        SunSet->setIndent(5);
        SunSet->setTextInteractionFlags(Qt::TextSelectableByMouse);

        gridLayout1->addWidget(SunSet, 2, 1, 1, 1);

        SunSetAzLabel = new QLabel(SunBox);
        SunSetAzLabel->setObjectName("SunSetAzLabel");
        sizePolicy2.setHeightForWidth(SunSetAzLabel->sizePolicy().hasHeightForWidth());
        SunSetAzLabel->setSizePolicy(sizePolicy2);

        gridLayout1->addWidget(SunSetAzLabel, 2, 3, 1, 1);

        SunRise = new QLabel(SunBox);
        SunRise->setObjectName("SunRise");
        SunRise->setFont(font);
        SunRise->setIndent(5);
        SunRise->setTextInteractionFlags(Qt::TextSelectableByMouse);

        gridLayout1->addWidget(SunRise, 0, 1, 1, 1);

        SunTransit = new QLabel(SunBox);
        SunTransit->setObjectName("SunTransit");
        SunTransit->setFont(font);
        SunTransit->setIndent(5);
        SunTransit->setTextInteractionFlags(Qt::TextSelectableByMouse);

        gridLayout1->addWidget(SunTransit, 1, 1, 1, 1);


        vboxLayout2->addLayout(gridLayout1);

        spacerItem8 = new QSpacerItem(20, 10, QSizePolicy::Policy::Minimum, QSizePolicy::Policy::Expanding);

        vboxLayout2->addItem(spacerItem8);


        vboxLayout1->addWidget(SunBox);

        MoonBox = new QGroupBox(tab);
        MoonBox->setObjectName("MoonBox");
        vboxLayout3 = new QVBoxLayout(MoonBox);
#ifndef UI_Q_OS_MAC
        vboxLayout3->setSpacing(6);
#endif
#ifndef UI_Q_OS_MAC
        vboxLayout3->setContentsMargins(9, 9, 9, 9);
#endif
        vboxLayout3->setObjectName("vboxLayout3");
        hboxLayout = new QHBoxLayout();
#ifndef UI_Q_OS_MAC
        hboxLayout->setSpacing(6);
#endif
#ifndef UI_Q_OS_MAC
        hboxLayout->setContentsMargins(0, 0, 0, 0);
#endif
        hboxLayout->setObjectName("hboxLayout");
        gridLayout2 = new QGridLayout();
#ifndef UI_Q_OS_MAC
        gridLayout2->setSpacing(6);
#endif
#ifndef UI_Q_OS_MAC
        gridLayout2->setContentsMargins(0, 0, 0, 0);
#endif
        gridLayout2->setObjectName("gridLayout2");
        MoonRiseLabel = new QLabel(MoonBox);
        MoonRiseLabel->setObjectName("MoonRiseLabel");

        gridLayout2->addWidget(MoonRiseLabel, 0, 0, 1, 1);

        spacerItem9 = new QSpacerItem(12, 12, QSizePolicy::Policy::Fixed, QSizePolicy::Policy::Minimum);

        gridLayout2->addItem(spacerItem9, 2, 2, 1, 1);

        MoonRise = new QLabel(MoonBox);
        MoonRise->setObjectName("MoonRise");
        MoonRise->setFont(font);
        MoonRise->setIndent(5);
        MoonRise->setTextInteractionFlags(Qt::TextSelectableByMouse);

        gridLayout2->addWidget(MoonRise, 0, 1, 1, 1);

        spacerItem10 = new QSpacerItem(12, 12, QSizePolicy::Policy::Fixed, QSizePolicy::Policy::Minimum);

        gridLayout2->addItem(spacerItem10, 1, 2, 1, 1);

        MoonTransitAltLabel = new QLabel(MoonBox);
        MoonTransitAltLabel->setObjectName("MoonTransitAltLabel");

        gridLayout2->addWidget(MoonTransitAltLabel, 1, 3, 1, 1);

        MoonSet = new QLabel(MoonBox);
        MoonSet->setObjectName("MoonSet");
        MoonSet->setFont(font);
        MoonSet->setIndent(5);
        MoonSet->setTextInteractionFlags(Qt::TextSelectableByMouse);

        gridLayout2->addWidget(MoonSet, 2, 1, 1, 1);

        spacerItem11 = new QSpacerItem(12, 12, QSizePolicy::Policy::Fixed, QSizePolicy::Policy::Minimum);

        gridLayout2->addItem(spacerItem11, 0, 2, 1, 1);

        MoonRiseAzLabel = new QLabel(MoonBox);
        MoonRiseAzLabel->setObjectName("MoonRiseAzLabel");
        sizePolicy2.setHeightForWidth(MoonRiseAzLabel->sizePolicy().hasHeightForWidth());
        MoonRiseAzLabel->setSizePolicy(sizePolicy2);

        gridLayout2->addWidget(MoonRiseAzLabel, 0, 3, 1, 1);

        MoonRiseAz = new QLabel(MoonBox);
        MoonRiseAz->setObjectName("MoonRiseAz");
        MoonRiseAz->setFont(font);
        MoonRiseAz->setIndent(5);
        MoonRiseAz->setTextInteractionFlags(Qt::TextSelectableByMouse);

        gridLayout2->addWidget(MoonRiseAz, 0, 4, 1, 1);

        MoonSetAz = new QLabel(MoonBox);
        MoonSetAz->setObjectName("MoonSetAz");
        MoonSetAz->setFont(font);
        MoonSetAz->setIndent(5);
        MoonSetAz->setTextInteractionFlags(Qt::TextSelectableByMouse);

        gridLayout2->addWidget(MoonSetAz, 2, 4, 1, 1);

        MoonTransitAlt = new QLabel(MoonBox);
        MoonTransitAlt->setObjectName("MoonTransitAlt");
        MoonTransitAlt->setFont(font);
        MoonTransitAlt->setIndent(5);
        MoonTransitAlt->setTextInteractionFlags(Qt::TextSelectableByMouse);

        gridLayout2->addWidget(MoonTransitAlt, 1, 4, 1, 1);

        MoonTransitLabel = new QLabel(MoonBox);
        MoonTransitLabel->setObjectName("MoonTransitLabel");
        sizePolicy2.setHeightForWidth(MoonTransitLabel->sizePolicy().hasHeightForWidth());
        MoonTransitLabel->setSizePolicy(sizePolicy2);

        gridLayout2->addWidget(MoonTransitLabel, 1, 0, 1, 1);

        MoonSetLabel = new QLabel(MoonBox);
        MoonSetLabel->setObjectName("MoonSetLabel");

        gridLayout2->addWidget(MoonSetLabel, 2, 0, 1, 1);

        MoonSetAzLabel = new QLabel(MoonBox);
        MoonSetAzLabel->setObjectName("MoonSetAzLabel");

        gridLayout2->addWidget(MoonSetAzLabel, 2, 3, 1, 1);

        MoonTransit = new QLabel(MoonBox);
        MoonTransit->setObjectName("MoonTransit");
        MoonTransit->setFont(font);
        MoonTransit->setIndent(5);
        MoonTransit->setTextInteractionFlags(Qt::TextSelectableByMouse);

        gridLayout2->addWidget(MoonTransit, 1, 1, 1, 1);


        hboxLayout->addLayout(gridLayout2);


        vboxLayout3->addLayout(hboxLayout);

        hboxLayout1 = new QHBoxLayout();
#ifndef UI_Q_OS_MAC
        hboxLayout1->setSpacing(6);
#endif
        hboxLayout1->setContentsMargins(0, 0, 0, 0);
        hboxLayout1->setObjectName("hboxLayout1");
        LunarPhaseLabel = new QLabel(MoonBox);
        LunarPhaseLabel->setObjectName("LunarPhaseLabel");

        hboxLayout1->addWidget(LunarPhaseLabel);

        LunarPhase = new QLabel(MoonBox);
        LunarPhase->setObjectName("LunarPhase");
        LunarPhase->setFont(font);
        LunarPhase->setIndent(5);
        LunarPhase->setTextInteractionFlags(Qt::TextSelectableByMouse);

        hboxLayout1->addWidget(LunarPhase);

        spacerItem12 = new QSpacerItem(20, 12, QSizePolicy::Policy::Expanding, QSizePolicy::Policy::Minimum);

        hboxLayout1->addItem(spacerItem12);


        vboxLayout3->addLayout(hboxLayout1);

        spacerItem13 = new QSpacerItem(20, 10, QSizePolicy::Policy::Minimum, QSizePolicy::Policy::Expanding);

        vboxLayout3->addItem(spacerItem13);


        vboxLayout1->addWidget(MoonBox);

        tabWidget->addTab(tab, QString());
        tab_2 = new QWidget();
        tab_2->setObjectName("tab_2");
        vboxLayout4 = new QVBoxLayout(tab_2);
        vboxLayout4->setObjectName("vboxLayout4");
        hboxLayout2 = new QHBoxLayout();
        hboxLayout2->setObjectName("hboxLayout2");
        LocationLabelBatch = new QLabel(tab_2);
        LocationLabelBatch->setObjectName("LocationLabelBatch");

        hboxLayout2->addWidget(LocationLabelBatch);

        LocationBatch = new QPushButton(tab_2);
        LocationBatch->setObjectName("LocationBatch");
        sizePolicy.setHeightForWidth(LocationBatch->sizePolicy().hasHeightForWidth());
        LocationBatch->setSizePolicy(sizePolicy);

        hboxLayout2->addWidget(LocationBatch);

        spacerItem14 = new QSpacerItem(40, 20, QSizePolicy::Policy::Expanding, QSizePolicy::Policy::Minimum);

        hboxLayout2->addItem(spacerItem14);


        vboxLayout4->addLayout(hboxLayout2);

        spacerItem15 = new QSpacerItem(20, 16, QSizePolicy::Policy::Minimum, QSizePolicy::Policy::Minimum);

        vboxLayout4->addItem(spacerItem15);

        label = new QLabel(tab_2);
        label->setObjectName("label");

        vboxLayout4->addWidget(label);

        gridLayout3 = new QGridLayout();
        gridLayout3->setObjectName("gridLayout3");
        label_5 = new QLabel(tab_2);
        label_5->setObjectName("label_5");

        gridLayout3->addWidget(label_5, 0, 0, 1, 1);

        InputFileBatch = new KUrlRequester(tab_2);
        InputFileBatch->setObjectName("InputFileBatch");

        gridLayout3->addWidget(InputFileBatch, 0, 1, 1, 1);

        label_6 = new QLabel(tab_2);
        label_6->setObjectName("label_6");

        gridLayout3->addWidget(label_6, 1, 0, 1, 1);

        OutputFileBatch = new KUrlRequester(tab_2);
        OutputFileBatch->setObjectName("OutputFileBatch");

        gridLayout3->addWidget(OutputFileBatch, 1, 1, 1, 1);


        vboxLayout4->addLayout(gridLayout3);

        spacerItem16 = new QSpacerItem(20, 20, QSizePolicy::Policy::Minimum, QSizePolicy::Policy::Minimum);

        vboxLayout4->addItem(spacerItem16);

        hboxLayout3 = new QHBoxLayout();
        hboxLayout3->setObjectName("hboxLayout3");
        spacerItem17 = new QSpacerItem(40, 20, QSizePolicy::Policy::Expanding, QSizePolicy::Policy::Minimum);

        hboxLayout3->addItem(spacerItem17);

        vboxLayout5 = new QVBoxLayout();
        vboxLayout5->setObjectName("vboxLayout5");
        RunButtonBatch = new QPushButton(tab_2);
        RunButtonBatch->setObjectName("RunButtonBatch");

        vboxLayout5->addWidget(RunButtonBatch);

        ViewButtonBatch = new QPushButton(tab_2);
        ViewButtonBatch->setObjectName("ViewButtonBatch");

        vboxLayout5->addWidget(ViewButtonBatch);


        hboxLayout3->addLayout(vboxLayout5);

        spacerItem18 = new QSpacerItem(40, 20, QSizePolicy::Policy::Expanding, QSizePolicy::Policy::Minimum);

        hboxLayout3->addItem(spacerItem18);


        vboxLayout4->addLayout(hboxLayout3);

        spacerItem19 = new QSpacerItem(20, 20, QSizePolicy::Policy::Minimum, QSizePolicy::Policy::Expanding);

        vboxLayout4->addItem(spacerItem19);

        tabWidget->addTab(tab_2, QString());

        vboxLayout->addWidget(tabWidget);

        QWidget::setTabOrder(tabWidget, Date);
        QWidget::setTabOrder(Date, Location);
        QWidget::setTabOrder(Location, LocationBatch);
        QWidget::setTabOrder(LocationBatch, InputFileBatch);
        QWidget::setTabOrder(InputFileBatch, OutputFileBatch);
        QWidget::setTabOrder(OutputFileBatch, RunButtonBatch);
        QWidget::setTabOrder(RunButtonBatch, ViewButtonBatch);

        retranslateUi(modCalcDayLengthDlg);

        tabWidget->setCurrentIndex(0);


        QMetaObject::connectSlotsByName(modCalcDayLengthDlg);
    } // setupUi

    void retranslateUi(QWidget *modCalcDayLengthDlg)
    {
        modCalcDayLengthDlg->setWindowTitle(tr2i18n("Almanac", nullptr));
        LocationLabel->setText(tr2i18n("Location:", nullptr));
        DateLabel->setText(tr2i18n("Date:", nullptr));
        Location->setText(tr2i18n("Greenwich, United Kingdom", nullptr));
        SunBox->setTitle(tr2i18n("Sun", nullptr));
        SunTransitAltLabel->setText(tr2i18n("Altitude at noon:", nullptr));
        SunTransitAlt->setText(tr2i18n("00:00", nullptr));
        DayLength->setText(tr2i18n("00:00", nullptr));
        SunSetLabel->setText(tr2i18n("Set:", "Sky object passing below the horizon"));
        DayLengthLabel->setText(tr2i18n("Day length:", nullptr));
        SunRiseAz->setText(tr2i18n("00:00", nullptr));
        SunRiseAzLabel->setText(tr2i18n("Sunrise azimuth:", nullptr));
        SunRiseLabel->setText(tr2i18n("Rise:", nullptr));
        SunTransitLabel->setText(tr2i18n("Noon:", nullptr));
        SunSetAz->setText(tr2i18n("00:00", nullptr));
        SunSet->setText(tr2i18n("00:00", nullptr));
        SunSetAzLabel->setText(tr2i18n("Sunset azimuth:", nullptr));
        SunRise->setText(tr2i18n("00:00", nullptr));
        SunTransit->setText(tr2i18n("00:00", nullptr));
        MoonBox->setTitle(tr2i18n("Moon", nullptr));
        MoonRiseLabel->setText(tr2i18n("Rise:", nullptr));
        MoonRise->setText(tr2i18n("00:00", nullptr));
        MoonTransitAltLabel->setText(tr2i18n("Transit altitude:", nullptr));
        MoonSet->setText(tr2i18n("00:00", nullptr));
        MoonRiseAzLabel->setText(tr2i18n("Moon rise azimuth:", nullptr));
        MoonRiseAz->setText(tr2i18n("00:00", nullptr));
        MoonSetAz->setText(tr2i18n("00:00", nullptr));
        MoonTransitAlt->setText(tr2i18n("00:00", nullptr));
        MoonTransitLabel->setText(tr2i18n("Transit:", nullptr));
        MoonSetLabel->setText(tr2i18n("Set:", "Sky object passing below the horizon"));
        MoonSetAzLabel->setText(tr2i18n("Moon set azimuth:", nullptr));
        MoonTransit->setText(tr2i18n("00:00", nullptr));
        LunarPhaseLabel->setText(tr2i18n("Phase:", nullptr));
        LunarPhase->setText(tr2i18n("Waxing gibbous (75%)", nullptr));
        tabWidget->setTabText(tabWidget->indexOf(tab), tr2i18n("Interactive Mode", nullptr));
        LocationLabelBatch->setText(tr2i18n("Location:", nullptr));
        LocationBatch->setText(tr2i18n("Greenwich, United Kingdom", nullptr));
        label->setText(tr2i18n("Specify Dates for the Calculation in the Input File", nullptr));
        label_5->setText(tr2i18n("Input file: ", nullptr));
        label_6->setText(tr2i18n("Output file: ", nullptr));
        RunButtonBatch->setText(tr2i18n("Compute", nullptr));
        ViewButtonBatch->setText(tr2i18n("View Output...", nullptr));
        tabWidget->setTabText(tabWidget->indexOf(tab_2), tr2i18n("Batch mode", nullptr));
    } // retranslateUi

};

namespace Ui {
    class modCalcDayLengthDlg: public Ui_modCalcDayLengthDlg {};
} // namespace Ui

QT_END_NAMESPACE

#endif // MODCALCDAYLENGTH_H

