/********************************************************************************
** Form generated from reading UI file 'recordingoptions.ui'
**
** Created by: Qt User Interface Compiler version 6.11.1
**
** WARNING! All changes made in this file will be lost when recompiling UI file!
********************************************************************************/

#ifndef UI_RECORDINGOPTIONS_H
#define UI_RECORDINGOPTIONS_H

#include <QtCore/QVariant>
#include <QtWidgets/QAbstractButton>
#include <QtWidgets/QApplication>
#include <QtWidgets/QComboBox>
#include <QtWidgets/QDialog>
#include <QtWidgets/QDialogButtonBox>
#include <QtWidgets/QDoubleSpinBox>
#include <QtWidgets/QFrame>
#include <QtWidgets/QGridLayout>
#include <QtWidgets/QGroupBox>
#include <QtWidgets/QHBoxLayout>
#include <QtWidgets/QLabel>
#include <QtWidgets/QLineEdit>
#include <QtWidgets/QPushButton>
#include <QtWidgets/QRadioButton>
#include <QtWidgets/QSpinBox>
#include <klocalizedstring.h>

QT_BEGIN_NAMESPACE

class Ui_recordingOptions
{
public:
    QGridLayout *gridLayout;
    QDialogButtonBox *buttonBox;
    QHBoxLayout *horizontalLayout;
    QLineEdit *recordDirectoryEdit;
    QPushButton *selectDirB;
    QLabel *label;
    QLabel *label_3;
    QRadioButton *recordUntilStoppedR;
    QFrame *line;
    QLabel *label_2;
    QHBoxLayout *horizontalLayout_3;
    QRadioButton *recordFramesR;
    QSpinBox *framesSpin;
    QHBoxLayout *horizontalLayout_2;
    QRadioButton *recordDurationR;
    QDoubleSpinBox *durationSpin;
    QLineEdit *recordFilenameEdit;
    QGroupBox *debayerOptions;
    QLabel *label_4;
    QComboBox *engineCombo;
    QLabel *label_5;
    QComboBox *methodCombo;

    void setupUi(QDialog *recordingOptions)
    {
        if (recordingOptions->objectName().isEmpty())
            recordingOptions->setObjectName("recordingOptions");
        recordingOptions->resize(304, 289);
        gridLayout = new QGridLayout(recordingOptions);
        gridLayout->setSpacing(3);
        gridLayout->setObjectName("gridLayout");
        gridLayout->setContentsMargins(3, 3, 3, 3);
        buttonBox = new QDialogButtonBox(recordingOptions);
        buttonBox->setObjectName("buttonBox");
        buttonBox->setOrientation(Qt::Horizontal);
        buttonBox->setStandardButtons(QDialogButtonBox::Close);

        gridLayout->addWidget(buttonBox, 7, 0, 1, 2);

        horizontalLayout = new QHBoxLayout();
        horizontalLayout->setSpacing(3);
        horizontalLayout->setObjectName("horizontalLayout");
        recordDirectoryEdit = new QLineEdit(recordingOptions);
        recordDirectoryEdit->setObjectName("recordDirectoryEdit");

        horizontalLayout->addWidget(recordDirectoryEdit);

        selectDirB = new QPushButton(recordingOptions);
        selectDirB->setObjectName("selectDirB");
        selectDirB->setMinimumSize(QSize(32, 32));
        selectDirB->setMaximumSize(QSize(32, 32));

        horizontalLayout->addWidget(selectDirB);


        gridLayout->addLayout(horizontalLayout, 1, 1, 1, 1);

        label = new QLabel(recordingOptions);
        label->setObjectName("label");

        gridLayout->addWidget(label, 0, 0, 1, 1);

        label_3 = new QLabel(recordingOptions);
        label_3->setObjectName("label_3");

        gridLayout->addWidget(label_3, 3, 0, 1, 1);

        recordUntilStoppedR = new QRadioButton(recordingOptions);
        recordUntilStoppedR->setObjectName("recordUntilStoppedR");
        recordUntilStoppedR->setChecked(true);

        gridLayout->addWidget(recordUntilStoppedR, 3, 1, 1, 1);

        line = new QFrame(recordingOptions);
        line->setObjectName("line");
        line->setFrameShape(QFrame::Shape::HLine);
        line->setFrameShadow(QFrame::Shadow::Sunken);

        gridLayout->addWidget(line, 2, 0, 1, 2);

        label_2 = new QLabel(recordingOptions);
        label_2->setObjectName("label_2");

        gridLayout->addWidget(label_2, 1, 0, 1, 1);

        horizontalLayout_3 = new QHBoxLayout();
        horizontalLayout_3->setObjectName("horizontalLayout_3");
        recordFramesR = new QRadioButton(recordingOptions);
        recordFramesR->setObjectName("recordFramesR");

        horizontalLayout_3->addWidget(recordFramesR);

        framesSpin = new QSpinBox(recordingOptions);
        framesSpin->setObjectName("framesSpin");
        framesSpin->setMinimum(1);
        framesSpin->setMaximum(1000);
        framesSpin->setValue(30);

        horizontalLayout_3->addWidget(framesSpin);


        gridLayout->addLayout(horizontalLayout_3, 5, 1, 1, 1);

        horizontalLayout_2 = new QHBoxLayout();
        horizontalLayout_2->setObjectName("horizontalLayout_2");
        recordDurationR = new QRadioButton(recordingOptions);
        recordDurationR->setObjectName("recordDurationR");

        horizontalLayout_2->addWidget(recordDurationR);

        durationSpin = new QDoubleSpinBox(recordingOptions);
        durationSpin->setObjectName("durationSpin");
        durationSpin->setMaximum(3600.000000000000000);
        durationSpin->setSingleStep(60.000000000000000);
        durationSpin->setValue(30.000000000000000);

        horizontalLayout_2->addWidget(durationSpin);


        gridLayout->addLayout(horizontalLayout_2, 4, 1, 1, 1);

        recordFilenameEdit = new QLineEdit(recordingOptions);
        recordFilenameEdit->setObjectName("recordFilenameEdit");

        gridLayout->addWidget(recordFilenameEdit, 0, 1, 1, 1);

        debayerOptions = new QGroupBox(recordingOptions);
        debayerOptions->setObjectName("debayerOptions");
        QSizePolicy sizePolicy(QSizePolicy::Policy::Preferred, QSizePolicy::Policy::Fixed);
        sizePolicy.setHorizontalStretch(0);
        sizePolicy.setVerticalStretch(0);
        sizePolicy.setHeightForWidth(debayerOptions->sizePolicy().hasHeightForWidth());
        debayerOptions->setSizePolicy(sizePolicy);
        debayerOptions->setMinimumSize(QSize(0, 80));
        label_4 = new QLabel(debayerOptions);
        label_4->setObjectName("label_4");
        label_4->setGeometry(QRect(0, 20, 83, 29));
        engineCombo = new QComboBox(debayerOptions);
        engineCombo->setObjectName("engineCombo");
        engineCombo->setGeometry(QRect(80, 20, 212, 29));
        QSizePolicy sizePolicy1(QSizePolicy::Policy::Expanding, QSizePolicy::Policy::Fixed);
        sizePolicy1.setHorizontalStretch(0);
        sizePolicy1.setVerticalStretch(0);
        sizePolicy1.setHeightForWidth(engineCombo->sizePolicy().hasHeightForWidth());
        engineCombo->setSizePolicy(sizePolicy1);
        label_5 = new QLabel(debayerOptions);
        label_5->setObjectName("label_5");
        label_5->setGeometry(QRect(0, 60, 81, 21));
        methodCombo = new QComboBox(debayerOptions);
        methodCombo->setObjectName("methodCombo");
        methodCombo->setGeometry(QRect(80, 50, 211, 29));
        sizePolicy1.setHeightForWidth(methodCombo->sizePolicy().hasHeightForWidth());
        methodCombo->setSizePolicy(sizePolicy1);

        gridLayout->addWidget(debayerOptions, 6, 0, 1, 2);


        retranslateUi(recordingOptions);
        QObject::connect(buttonBox, &QDialogButtonBox::accepted, recordingOptions, qOverload<>(&QDialog::accept));
        QObject::connect(buttonBox, &QDialogButtonBox::rejected, recordingOptions, qOverload<>(&QDialog::reject));

        QMetaObject::connectSlotsByName(recordingOptions);
    } // setupUi

    void retranslateUi(QDialog *recordingOptions)
    {
        recordingOptions->setWindowTitle(tr2i18n("Recording Options", nullptr));
#if QT_CONFIG(tooltip)
        recordDirectoryEdit->setToolTip(tr2i18n("<html><head/><body>\n"
"<p>Set SER video <b>remote</b> directory name. If INDI server is running locally, then a local directory can be selected. However, if you are connected to a remote INDI server, then the directory must be a valid directory on the remote file system where it is saved.</p>\n"
"<p>Record directories may contain some patterns to make them dynamic:</p>\n"
"<ul>\n"
"<li><b>_D_</b> for the date in YYYY-MM-DD.</li>\n"
"<li><b>_H_</b> for time in HH:MM:SS.</li>\n"
"<li><b>_T_</b> for ISO8601 time stamp.</li>\n"
"<li><b>_F_</b> for filter name, if any.</li>\n"
"</ul>\n"
"</body></html>", nullptr));
#endif // QT_CONFIG(tooltip)
#if QT_CONFIG(tooltip)
        selectDirB->setToolTip(tr2i18n("Play/Pause", nullptr));
#endif // QT_CONFIG(tooltip)
#if QT_CONFIG(whatsthis)
        selectDirB->setWhatsThis(QString());
#endif // QT_CONFIG(whatsthis)
#if QT_CONFIG(tooltip)
        label->setToolTip(tr2i18n("<html><head/><body>\n"
"<p>Set SER video file name. Record files may contain some patterns to make them dynamic:</p>\n"
"<ul>\n"
"<li><b>_D_</b> for the date in YYYY-MM-DD.</li>\n"
"<li><b>_H_</b> for time in HH:MM:SS.</li>\n"
"<li><b>_T_</b> for ISO8601 time stamp.</li>\n"
"<li><b>_F_</b> for filter name, if any.</li>\n"
"</ul>\n"
"</body></html>", nullptr));
#endif // QT_CONFIG(tooltip)
        label->setText(tr2i18n("File name:", nullptr));
        label_3->setText(tr2i18n("Record:", nullptr));
#if QT_CONFIG(tooltip)
        recordUntilStoppedR->setToolTip(tr2i18n("Record stream until manually stopped", nullptr));
#endif // QT_CONFIG(tooltip)
        recordUntilStoppedR->setText(tr2i18n("Until stopped", nullptr));
#if QT_CONFIG(tooltip)
        label_2->setToolTip(tr2i18n("<html><head/><body>\n"
"<p>Set SER video <b>remote</b> directory name. If INDI server is running locally, then a local directory can be selected. However, if you are connected to a remote INDI server, then the directory must be a valid directory on the remote file system where it is saved.</p>\n"
"<p>Record directories may contain some patterns to make them dynamic:</p>\n"
"<ul>\n"
"<li><b>_D_</b> for the date in YYYY-MM-DD.</li>\n"
"<li><b>_H_</b> for time in HH:MM:SS.</li>\n"
"<li><b>_T_</b> for ISO8601 time stamp.</li>\n"
"<li><b>_F_</b> for filter name, if any.</li>\n"
"</ul>\n"
"</body></html>", nullptr));
#endif // QT_CONFIG(tooltip)
        label_2->setText(tr2i18n("Directory:", nullptr));
#if QT_CONFIG(tooltip)
        recordFramesR->setToolTip(tr2i18n("Record stream until this many frames are captured", nullptr));
#endif // QT_CONFIG(tooltip)
        recordFramesR->setText(tr2i18n("Frames:", nullptr));
#if QT_CONFIG(tooltip)
        framesSpin->setToolTip(tr2i18n("Record stream until this many frames are captured", nullptr));
#endif // QT_CONFIG(tooltip)
#if QT_CONFIG(tooltip)
        recordDurationR->setToolTip(tr2i18n("Record stream for specified duration in seconds", nullptr));
#endif // QT_CONFIG(tooltip)
        recordDurationR->setText(tr2i18n("Duration:", nullptr));
#if QT_CONFIG(tooltip)
        durationSpin->setToolTip(tr2i18n("Record stream for specified duration in seconds", nullptr));
#endif // QT_CONFIG(tooltip)
#if QT_CONFIG(tooltip)
        recordFilenameEdit->setToolTip(tr2i18n("<html><head/><body>\n"
"<p>Set SER video file name. Record files may contain some patterns to make them dynamic:</p>\n"
"<ul>\n"
"<li><b>_D_</b> for the date in YYYY-MM-DD.</li>\n"
"<li><b>_H_</b> for time in HH:MM:SS.</li>\n"
"<li><b>_T_</b> for ISO8601 time stamp.</li>\n"
"<li><b>_F_</b> for filter name, if any.</li>\n"
"</ul>\n"
"</body></html>", nullptr));
#endif // QT_CONFIG(tooltip)
        debayerOptions->setTitle(tr2i18n("Debayer Options:", nullptr));
        label_4->setText(tr2i18n("Engine:", nullptr));
        label_5->setText(tr2i18n("Method:", nullptr));
    } // retranslateUi

};

namespace Ui {
    class recordingOptions: public Ui_recordingOptions {};
} // namespace Ui

QT_END_NAMESPACE

#endif // RECORDINGOPTIONS_H

