/********************************************************************************
** Form generated from reading UI file 'conjunctions.ui'
**
** Created by: Qt User Interface Compiler version 6.11.1
**
** WARNING! All changes made in this file will be lost when recompiling UI file!
********************************************************************************/

#ifndef UI_CONJUNCTIONS_H
#define UI_CONJUNCTIONS_H

#include <QtCore/QVariant>
#include <QtWidgets/QApplication>
#include <QtWidgets/QComboBox>
#include <QtWidgets/QDateTimeEdit>
#include <QtWidgets/QGridLayout>
#include <QtWidgets/QGroupBox>
#include <QtWidgets/QHBoxLayout>
#include <QtWidgets/QHeaderView>
#include <QtWidgets/QLabel>
#include <QtWidgets/QLineEdit>
#include <QtWidgets/QProgressBar>
#include <QtWidgets/QPushButton>
#include <QtWidgets/QSpacerItem>
#include <QtWidgets/QStackedWidget>
#include <QtWidgets/QTableView>
#include <QtWidgets/QVBoxLayout>
#include <QtWidgets/QWidget>
#include <klocalizedstring.h>
#include "widgets/dmsbox.h"

QT_BEGIN_NAMESPACE

class Ui_ConjunctionsDlg
{
public:
    QVBoxLayout *verticalLayout_2;
    QGridLayout *gridLayout;
    QPushButton *LocationButton;
    QDateTimeEdit *startDate;
    QLabel *label_2;
    QDateTimeEdit *stopDate;
    QHBoxLayout *horizontalLayout;
    QComboBox *FilterTypeComboBox;
    QPushButton *Obj1FindButton;
    QLabel *label_4;
    QComboBox *Obj2ComboBox;
    QLabel *label;
    QLabel *label_3;
    QLabel *textLabel1;
    QLabel *label_5;
    QHBoxLayout *horizontalLayout_5;
    dmsBox *maxSeparationBox;
    QSpacerItem *horizontalSpacer_3;
    QStackedWidget *ComputeStack;
    QWidget *page;
    QHBoxLayout *horizontalLayout_4;
    QHBoxLayout *horizontalLayout_2;
    QComboBox *ModeSelector;
    QPushButton *ComputeButton;
    QSpacerItem *horizontalSpacer_2;
    QPushButton *ExportButton;
    QPushButton *ClearButton;
    QWidget *page_2;
    QHBoxLayout *horizontalLayout_3;
    QProgressBar *progress;
    QGroupBox *groupBox_2;
    QVBoxLayout *verticalLayout;
    QTableView *OutputList;
    QHBoxLayout *horizontalLayout_7;
    QPushButton *ClearFilterButton;
    QLineEdit *FilterEdit;

    void setupUi(QWidget *ConjunctionsDlg)
    {
        if (ConjunctionsDlg->objectName().isEmpty())
            ConjunctionsDlg->setObjectName("ConjunctionsDlg");
        ConjunctionsDlg->resize(549, 445);
        verticalLayout_2 = new QVBoxLayout(ConjunctionsDlg);
        verticalLayout_2->setObjectName("verticalLayout_2");
        gridLayout = new QGridLayout();
        gridLayout->setObjectName("gridLayout");
        LocationButton = new QPushButton(ConjunctionsDlg);
        LocationButton->setObjectName("LocationButton");

        gridLayout->addWidget(LocationButton, 0, 1, 1, 1);

        startDate = new QDateTimeEdit(ConjunctionsDlg);
        startDate->setObjectName("startDate");
        startDate->setCalendarPopup(true);

        gridLayout->addWidget(startDate, 1, 1, 1, 1);

        label_2 = new QLabel(ConjunctionsDlg);
        label_2->setObjectName("label_2");

        gridLayout->addWidget(label_2, 2, 0, 1, 1);

        stopDate = new QDateTimeEdit(ConjunctionsDlg);
        stopDate->setObjectName("stopDate");
        stopDate->setCalendarPopup(true);

        gridLayout->addWidget(stopDate, 2, 1, 1, 1);

        horizontalLayout = new QHBoxLayout();
        horizontalLayout->setObjectName("horizontalLayout");
        FilterTypeComboBox = new QComboBox(ConjunctionsDlg);
        FilterTypeComboBox->setObjectName("FilterTypeComboBox");

        horizontalLayout->addWidget(FilterTypeComboBox);

        Obj1FindButton = new QPushButton(ConjunctionsDlg);
        Obj1FindButton->setObjectName("Obj1FindButton");

        horizontalLayout->addWidget(Obj1FindButton);

        label_4 = new QLabel(ConjunctionsDlg);
        label_4->setObjectName("label_4");
        label_4->setAlignment(Qt::AlignRight|Qt::AlignTrailing|Qt::AlignVCenter);

        horizontalLayout->addWidget(label_4);

        Obj2ComboBox = new QComboBox(ConjunctionsDlg);
        Obj2ComboBox->setObjectName("Obj2ComboBox");
        QSizePolicy sizePolicy(QSizePolicy::Policy::Preferred, QSizePolicy::Policy::Fixed);
        sizePolicy.setHorizontalStretch(0);
        sizePolicy.setVerticalStretch(0);
        sizePolicy.setHeightForWidth(Obj2ComboBox->sizePolicy().hasHeightForWidth());
        Obj2ComboBox->setSizePolicy(sizePolicy);

        horizontalLayout->addWidget(Obj2ComboBox);


        gridLayout->addLayout(horizontalLayout, 3, 1, 1, 1);

        label = new QLabel(ConjunctionsDlg);
        label->setObjectName("label");

        gridLayout->addWidget(label, 1, 0, 1, 1);

        label_3 = new QLabel(ConjunctionsDlg);
        label_3->setObjectName("label_3");

        gridLayout->addWidget(label_3, 0, 0, 1, 1);

        textLabel1 = new QLabel(ConjunctionsDlg);
        textLabel1->setObjectName("textLabel1");
        QSizePolicy sizePolicy1(QSizePolicy::Policy::Minimum, QSizePolicy::Policy::Preferred);
        sizePolicy1.setHorizontalStretch(0);
        sizePolicy1.setVerticalStretch(0);
        sizePolicy1.setHeightForWidth(textLabel1->sizePolicy().hasHeightForWidth());
        textLabel1->setSizePolicy(sizePolicy1);

        gridLayout->addWidget(textLabel1, 3, 0, 1, 1);

        label_5 = new QLabel(ConjunctionsDlg);
        label_5->setObjectName("label_5");

        gridLayout->addWidget(label_5, 4, 0, 1, 1);

        horizontalLayout_5 = new QHBoxLayout();
        horizontalLayout_5->setObjectName("horizontalLayout_5");
        maxSeparationBox = new dmsBox(ConjunctionsDlg);
        maxSeparationBox->setObjectName("maxSeparationBox");

        horizontalLayout_5->addWidget(maxSeparationBox);

        horizontalSpacer_3 = new QSpacerItem(40, 20, QSizePolicy::Policy::Expanding, QSizePolicy::Policy::Minimum);

        horizontalLayout_5->addItem(horizontalSpacer_3);


        gridLayout->addLayout(horizontalLayout_5, 4, 1, 1, 1);


        verticalLayout_2->addLayout(gridLayout);

        ComputeStack = new QStackedWidget(ConjunctionsDlg);
        ComputeStack->setObjectName("ComputeStack");
        sizePolicy.setHeightForWidth(ComputeStack->sizePolicy().hasHeightForWidth());
        ComputeStack->setSizePolicy(sizePolicy);
        page = new QWidget();
        page->setObjectName("page");
        QSizePolicy sizePolicy2(QSizePolicy::Policy::Preferred, QSizePolicy::Policy::Minimum);
        sizePolicy2.setHorizontalStretch(0);
        sizePolicy2.setVerticalStretch(0);
        sizePolicy2.setHeightForWidth(page->sizePolicy().hasHeightForWidth());
        page->setSizePolicy(sizePolicy2);
        horizontalLayout_4 = new QHBoxLayout(page);
        horizontalLayout_4->setObjectName("horizontalLayout_4");
        horizontalLayout_2 = new QHBoxLayout();
        horizontalLayout_2->setObjectName("horizontalLayout_2");
        ModeSelector = new QComboBox(page);
        ModeSelector->addItem(QString());
        ModeSelector->addItem(QString());
        ModeSelector->setObjectName("ModeSelector");
        sizePolicy.setHeightForWidth(ModeSelector->sizePolicy().hasHeightForWidth());
        ModeSelector->setSizePolicy(sizePolicy);

        horizontalLayout_2->addWidget(ModeSelector);

        ComputeButton = new QPushButton(page);
        ComputeButton->setObjectName("ComputeButton");

        horizontalLayout_2->addWidget(ComputeButton);

        horizontalSpacer_2 = new QSpacerItem(40, 20, QSizePolicy::Policy::Expanding, QSizePolicy::Policy::Minimum);

        horizontalLayout_2->addItem(horizontalSpacer_2);

        ExportButton = new QPushButton(page);
        ExportButton->setObjectName("ExportButton");

        horizontalLayout_2->addWidget(ExportButton);

        ClearButton = new QPushButton(page);
        ClearButton->setObjectName("ClearButton");

        horizontalLayout_2->addWidget(ClearButton);


        horizontalLayout_4->addLayout(horizontalLayout_2);

        ComputeStack->addWidget(page);
        page_2 = new QWidget();
        page_2->setObjectName("page_2");
        sizePolicy2.setHeightForWidth(page_2->sizePolicy().hasHeightForWidth());
        page_2->setSizePolicy(sizePolicy2);
        horizontalLayout_3 = new QHBoxLayout(page_2);
        horizontalLayout_3->setObjectName("horizontalLayout_3");
        progress = new QProgressBar(page_2);
        progress->setObjectName("progress");
        progress->setValue(0);

        horizontalLayout_3->addWidget(progress);

        ComputeStack->addWidget(page_2);

        verticalLayout_2->addWidget(ComputeStack);

        groupBox_2 = new QGroupBox(ConjunctionsDlg);
        groupBox_2->setObjectName("groupBox_2");
        verticalLayout = new QVBoxLayout(groupBox_2);
        verticalLayout->setObjectName("verticalLayout");
        OutputList = new QTableView(groupBox_2);
        OutputList->setObjectName("OutputList");
        OutputList->setEditTriggers(QAbstractItemView::NoEditTriggers);
        OutputList->setProperty("showDropIndicator", QVariant(false));
        OutputList->setAlternatingRowColors(true);
        OutputList->setSelectionMode(QAbstractItemView::SingleSelection);
        OutputList->setSelectionBehavior(QAbstractItemView::SelectRows);
        OutputList->horizontalHeader()->setCascadingSectionResizes(true);
        OutputList->horizontalHeader()->setMinimumSectionSize(100);
        OutputList->horizontalHeader()->setDefaultSectionSize(160);
        OutputList->horizontalHeader()->setProperty("showSortIndicator", QVariant(false));
        OutputList->horizontalHeader()->setStretchLastSection(true);

        verticalLayout->addWidget(OutputList);

        horizontalLayout_7 = new QHBoxLayout();
        horizontalLayout_7->setObjectName("horizontalLayout_7");
        ClearFilterButton = new QPushButton(groupBox_2);
        ClearFilterButton->setObjectName("ClearFilterButton");

        horizontalLayout_7->addWidget(ClearFilterButton);

        FilterEdit = new QLineEdit(groupBox_2);
        FilterEdit->setObjectName("FilterEdit");

        horizontalLayout_7->addWidget(FilterEdit);


        verticalLayout->addLayout(horizontalLayout_7);


        verticalLayout_2->addWidget(groupBox_2);


        retranslateUi(ConjunctionsDlg);

        ComputeStack->setCurrentIndex(1);


        QMetaObject::connectSlotsByName(ConjunctionsDlg);
    } // setupUi

    void retranslateUi(QWidget *ConjunctionsDlg)
    {
        LocationButton->setText(tr2i18n("Greenwich, United Kingdom", nullptr));
        label_2->setText(tr2i18n("Ending on:", nullptr));
        Obj1FindButton->setText(tr2i18n("Find Object...", nullptr));
        label_4->setText(tr2i18n("and", nullptr));
        label->setText(tr2i18n("Starting on:", nullptr));
        label_3->setText(tr2i18n("Show conjunctions/oppositions for:", nullptr));
        textLabel1->setText(tr2i18n("Between objects:", nullptr));
        label_5->setText(tr2i18n("Maximum allowed separation:", nullptr));
        ModeSelector->setItemText(0, tr2i18n("Conjunction", nullptr));
        ModeSelector->setItemText(1, tr2i18n("Opposition", nullptr));

        ComputeButton->setText(tr2i18n("Compute", nullptr));
        ExportButton->setText(tr2i18n("Export...", nullptr));
        ClearButton->setText(tr2i18n("Clear", nullptr));
        progress->setFormat(tr2i18n("%p%", nullptr));
        groupBox_2->setTitle(tr2i18n("Conjunctions / Oppositions", nullptr));
        ClearFilterButton->setText(QString());
        (void)ConjunctionsDlg;
    } // retranslateUi

};

namespace Ui {
    class ConjunctionsDlg: public Ui_ConjunctionsDlg {};
} // namespace Ui

QT_END_NAMESPACE

#endif // CONJUNCTIONS_H

