/****************************************************************************
** Meta object code from reading C++ file 'xplanetimageviewer.h'
**
** Created by: The Qt Meta Object Compiler version 69 (Qt 6.11.1)
**
** WARNING! All changes made in this file will be lost!
*****************************************************************************/

#include "../../../../kstars-3.8.4.1/kstars/auxiliary/xplanetimageviewer.h"
#include <QtNetwork/QSslError>
#include <QtGui/qtextcursor.h>
#include <QtCore/qmetatype.h>

#include <QtCore/qtmochelpers.h>

#include <memory>


#include <QtCore/qxptype_traits.h>
#if !defined(Q_MOC_OUTPUT_REVISION)
#error "The header file 'xplanetimageviewer.h' doesn't include <QObject>."
#elif Q_MOC_OUTPUT_REVISION != 69
#error "This file was generated using the moc from 6.11.1. It"
#error "cannot be used with the include files from this version of Qt."
#error "(The moc has changed too much.)"
#endif

#ifndef Q_CONSTINIT
#define Q_CONSTINIT
#endif

QT_WARNING_PUSH
QT_WARNING_DISABLE_DEPRECATED
QT_WARNING_DISABLE_GCC("-Wuseless-cast")
namespace {
struct qt_meta_tag_ZN17XPlanetImageLabelE_t {};
} // unnamed namespace

template <> constexpr inline auto XPlanetImageLabel::qt_create_metaobjectdata<qt_meta_tag_ZN17XPlanetImageLabelE_t>()
{
    namespace QMC = QtMocConstants;
    QtMocHelpers::StringRefStorage qt_stringData {
        "XPlanetImageLabel",
        "zoomIn",
        "",
        "zoomOut",
        "changePosition",
        "QPoint",
        "changeLocation",
        "wheelEvent",
        "QWheelEvent*",
        "e",
        "mousePressEvent",
        "QMouseEvent*",
        "mouseReleaseEvent",
        "mouseMoveEvent"
    };

    QtMocHelpers::UintData qt_methods {
        // Signal 'zoomIn'
        QtMocHelpers::SignalData<void()>(1, 2, QMC::AccessPublic, QMetaType::Void),
        // Signal 'zoomOut'
        QtMocHelpers::SignalData<void()>(3, 2, QMC::AccessPublic, QMetaType::Void),
        // Signal 'changePosition'
        QtMocHelpers::SignalData<void(QPoint)>(4, 2, QMC::AccessPublic, QMetaType::Void, {{
            { 0x80000000 | 5, 2 },
        }}),
        // Signal 'changeLocation'
        QtMocHelpers::SignalData<void(QPoint)>(6, 2, QMC::AccessPublic, QMetaType::Void, {{
            { 0x80000000 | 5, 2 },
        }}),
        // Slot 'wheelEvent'
        QtMocHelpers::SlotData<void(QWheelEvent *)>(7, 2, QMC::AccessPublic, QMetaType::Void, {{
            { 0x80000000 | 8, 9 },
        }}),
        // Slot 'mousePressEvent'
        QtMocHelpers::SlotData<void(QMouseEvent *)>(10, 2, QMC::AccessPublic, QMetaType::Void, {{
            { 0x80000000 | 11, 9 },
        }}),
        // Slot 'mouseReleaseEvent'
        QtMocHelpers::SlotData<void(QMouseEvent *)>(12, 2, QMC::AccessPublic, QMetaType::Void, {{
            { 0x80000000 | 11, 9 },
        }}),
        // Slot 'mouseMoveEvent'
        QtMocHelpers::SlotData<void(QMouseEvent *)>(13, 2, QMC::AccessPublic, QMetaType::Void, {{
            { 0x80000000 | 11, 9 },
        }}),
    };
    QtMocHelpers::UintData qt_properties {
    };
    QtMocHelpers::UintData qt_enums {
    };
    return QtMocHelpers::metaObjectData<XPlanetImageLabel, qt_meta_tag_ZN17XPlanetImageLabelE_t>(QMC::MetaObjectFlag{}, qt_stringData,
            qt_methods, qt_properties, qt_enums);
}
Q_CONSTINIT const QMetaObject XPlanetImageLabel::staticMetaObject = { {
    QMetaObject::SuperData::link<QFrame::staticMetaObject>(),
    qt_staticMetaObjectStaticContent<qt_meta_tag_ZN17XPlanetImageLabelE_t>.stringdata,
    qt_staticMetaObjectStaticContent<qt_meta_tag_ZN17XPlanetImageLabelE_t>.data,
    qt_static_metacall,
    nullptr,
    qt_staticMetaObjectRelocatingContent<qt_meta_tag_ZN17XPlanetImageLabelE_t>.metaTypes,
    nullptr
} };

void XPlanetImageLabel::qt_static_metacall(QObject *_o, QMetaObject::Call _c, int _id, void **_a)
{
    auto *_t = static_cast<XPlanetImageLabel *>(_o);
    if (_c == QMetaObject::InvokeMetaMethod) {
        switch (_id) {
        case 0: _t->zoomIn(); break;
        case 1: _t->zoomOut(); break;
        case 2: _t->changePosition((*reinterpret_cast<std::add_pointer_t<QPoint>>(_a[1]))); break;
        case 3: _t->changeLocation((*reinterpret_cast<std::add_pointer_t<QPoint>>(_a[1]))); break;
        case 4: _t->wheelEvent((*reinterpret_cast<std::add_pointer_t<QWheelEvent*>>(_a[1]))); break;
        case 5: _t->mousePressEvent((*reinterpret_cast<std::add_pointer_t<QMouseEvent*>>(_a[1]))); break;
        case 6: _t->mouseReleaseEvent((*reinterpret_cast<std::add_pointer_t<QMouseEvent*>>(_a[1]))); break;
        case 7: _t->mouseMoveEvent((*reinterpret_cast<std::add_pointer_t<QMouseEvent*>>(_a[1]))); break;
        default: ;
        }
    }
    if (_c == QMetaObject::IndexOfMethod) {
        if (QtMocHelpers::indexOfMethod<void (XPlanetImageLabel::*)()>(_a, &XPlanetImageLabel::zoomIn, 0))
            return;
        if (QtMocHelpers::indexOfMethod<void (XPlanetImageLabel::*)()>(_a, &XPlanetImageLabel::zoomOut, 1))
            return;
        if (QtMocHelpers::indexOfMethod<void (XPlanetImageLabel::*)(QPoint )>(_a, &XPlanetImageLabel::changePosition, 2))
            return;
        if (QtMocHelpers::indexOfMethod<void (XPlanetImageLabel::*)(QPoint )>(_a, &XPlanetImageLabel::changeLocation, 3))
            return;
    }
}

const QMetaObject *XPlanetImageLabel::metaObject() const
{
    return QObject::d_ptr->metaObject ? QObject::d_ptr->dynamicMetaObject() : &staticMetaObject;
}

void *XPlanetImageLabel::qt_metacast(const char *_clname)
{
    if (!_clname) return nullptr;
    if (!strcmp(_clname, qt_staticMetaObjectStaticContent<qt_meta_tag_ZN17XPlanetImageLabelE_t>.strings))
        return static_cast<void*>(this);
    return QFrame::qt_metacast(_clname);
}

int XPlanetImageLabel::qt_metacall(QMetaObject::Call _c, int _id, void **_a)
{
    _id = QFrame::qt_metacall(_c, _id, _a);
    if (_id < 0)
        return _id;
    if (_c == QMetaObject::InvokeMetaMethod) {
        if (_id < 8)
            qt_static_metacall(this, _c, _id, _a);
        _id -= 8;
    }
    if (_c == QMetaObject::RegisterMethodArgumentMetaType) {
        if (_id < 8)
            *reinterpret_cast<QMetaType *>(_a[0]) = QMetaType();
        _id -= 8;
    }
    return _id;
}

// SIGNAL 0
void XPlanetImageLabel::zoomIn()
{
    QMetaObject::activate(this, &staticMetaObject, 0, nullptr);
}

// SIGNAL 1
void XPlanetImageLabel::zoomOut()
{
    QMetaObject::activate(this, &staticMetaObject, 1, nullptr);
}

// SIGNAL 2
void XPlanetImageLabel::changePosition(QPoint _t1)
{
    QMetaObject::activate<void>(this, &staticMetaObject, 2, nullptr, _t1);
}

// SIGNAL 3
void XPlanetImageLabel::changeLocation(QPoint _t1)
{
    QMetaObject::activate<void>(this, &staticMetaObject, 3, nullptr, _t1);
}
namespace {
struct qt_meta_tag_ZN18XPlanetImageViewerE_t {};
} // unnamed namespace

template <> constexpr inline auto XPlanetImageViewer::qt_create_metaobjectdata<qt_meta_tag_ZN18XPlanetImageViewerE_t>()
{
    namespace QMC = QtMocConstants;
    QtMocHelpers::StringRefStorage qt_stringData {
        "XPlanetImageViewer",
        "showImage",
        "",
        "saveFileToDisk",
        "invertColors",
        "updateXPlanetRotationEdit",
        "resetXPlanetRotation",
        "invertXPlanetRotation",
        "reCenterXPlanet",
        "changeXPlanetPosition",
        "QPoint",
        "delta",
        "changeXPlanetLocation",
        "slotFreeRotate",
        "updateStates",
        "updatePositionDisplay",
        "resetLocation",
        "zoomInXPlanetFOV",
        "zoomOutXPlanetFOV",
        "updateXPlanetFOVEdit",
        "resetXPlanetFOV",
        "setKStarsXPlanetFOV",
        "setFOVfromList",
        "updateXPlanetTime",
        "timeShift",
        "updateXPlanetObject",
        "objectIndex",
        "updateXPlanetOrigin",
        "originIndex",
        "updateXPlanetTimeUnits",
        "units",
        "updateXPlanetTimeEdit",
        "setXPlanetTime",
        "setXPlanetTimetoKStarsTime",
        "resetXPlanetTime",
        "incrementXPlanetTime",
        "toggleXPlanetRun",
        "timeSliderDisplay"
    };

    QtMocHelpers::UintData qt_methods {
        // Slot 'showImage'
        QtMocHelpers::SlotData<bool()>(1, 2, QMC::AccessPrivate, QMetaType::Bool),
        // Slot 'saveFileToDisk'
        QtMocHelpers::SlotData<void()>(3, 2, QMC::AccessPrivate, QMetaType::Void),
        // Slot 'invertColors'
        QtMocHelpers::SlotData<void()>(4, 2, QMC::AccessPrivate, QMetaType::Void),
        // Slot 'updateXPlanetRotationEdit'
        QtMocHelpers::SlotData<void()>(5, 2, QMC::AccessPrivate, QMetaType::Void),
        // Slot 'resetXPlanetRotation'
        QtMocHelpers::SlotData<void()>(6, 2, QMC::AccessPrivate, QMetaType::Void),
        // Slot 'invertXPlanetRotation'
        QtMocHelpers::SlotData<void()>(7, 2, QMC::AccessPrivate, QMetaType::Void),
        // Slot 'reCenterXPlanet'
        QtMocHelpers::SlotData<void()>(8, 2, QMC::AccessPrivate, QMetaType::Void),
        // Slot 'changeXPlanetPosition'
        QtMocHelpers::SlotData<void(QPoint)>(9, 2, QMC::AccessPrivate, QMetaType::Void, {{
            { 0x80000000 | 10, 11 },
        }}),
        // Slot 'changeXPlanetLocation'
        QtMocHelpers::SlotData<void(QPoint)>(12, 2, QMC::AccessPrivate, QMetaType::Void, {{
            { 0x80000000 | 10, 11 },
        }}),
        // Slot 'slotFreeRotate'
        QtMocHelpers::SlotData<void()>(13, 2, QMC::AccessPrivate, QMetaType::Void),
        // Slot 'updateStates'
        QtMocHelpers::SlotData<void()>(14, 2, QMC::AccessPrivate, QMetaType::Void),
        // Slot 'updatePositionDisplay'
        QtMocHelpers::SlotData<void()>(15, 2, QMC::AccessPrivate, QMetaType::Void),
        // Slot 'resetLocation'
        QtMocHelpers::SlotData<void()>(16, 2, QMC::AccessPrivate, QMetaType::Void),
        // Slot 'zoomInXPlanetFOV'
        QtMocHelpers::SlotData<void()>(17, 2, QMC::AccessPrivate, QMetaType::Void),
        // Slot 'zoomOutXPlanetFOV'
        QtMocHelpers::SlotData<void()>(18, 2, QMC::AccessPrivate, QMetaType::Void),
        // Slot 'updateXPlanetFOVEdit'
        QtMocHelpers::SlotData<void()>(19, 2, QMC::AccessPrivate, QMetaType::Void),
        // Slot 'resetXPlanetFOV'
        QtMocHelpers::SlotData<void()>(20, 2, QMC::AccessPrivate, QMetaType::Void),
        // Slot 'setKStarsXPlanetFOV'
        QtMocHelpers::SlotData<void()>(21, 2, QMC::AccessPrivate, QMetaType::Void),
        // Slot 'setFOVfromList'
        QtMocHelpers::SlotData<void()>(22, 2, QMC::AccessPrivate, QMetaType::Void),
        // Slot 'updateXPlanetTime'
        QtMocHelpers::SlotData<void(int)>(23, 2, QMC::AccessPrivate, QMetaType::Void, {{
            { QMetaType::Int, 24 },
        }}),
        // Slot 'updateXPlanetObject'
        QtMocHelpers::SlotData<void(int)>(25, 2, QMC::AccessPrivate, QMetaType::Void, {{
            { QMetaType::Int, 26 },
        }}),
        // Slot 'updateXPlanetOrigin'
        QtMocHelpers::SlotData<void(int)>(27, 2, QMC::AccessPrivate, QMetaType::Void, {{
            { QMetaType::Int, 28 },
        }}),
        // Slot 'updateXPlanetTimeUnits'
        QtMocHelpers::SlotData<void(int)>(29, 2, QMC::AccessPrivate, QMetaType::Void, {{
            { QMetaType::Int, 30 },
        }}),
        // Slot 'updateXPlanetTimeEdit'
        QtMocHelpers::SlotData<void()>(31, 2, QMC::AccessPrivate, QMetaType::Void),
        // Slot 'setXPlanetTime'
        QtMocHelpers::SlotData<void()>(32, 2, QMC::AccessPrivate, QMetaType::Void),
        // Slot 'setXPlanetTimetoKStarsTime'
        QtMocHelpers::SlotData<void()>(33, 2, QMC::AccessPrivate, QMetaType::Void),
        // Slot 'resetXPlanetTime'
        QtMocHelpers::SlotData<void()>(34, 2, QMC::AccessPrivate, QMetaType::Void),
        // Slot 'incrementXPlanetTime'
        QtMocHelpers::SlotData<void()>(35, 2, QMC::AccessPrivate, QMetaType::Void),
        // Slot 'toggleXPlanetRun'
        QtMocHelpers::SlotData<void()>(36, 2, QMC::AccessPrivate, QMetaType::Void),
        // Slot 'timeSliderDisplay'
        QtMocHelpers::SlotData<void(int)>(37, 2, QMC::AccessPrivate, QMetaType::Void, {{
            { QMetaType::Int, 24 },
        }}),
    };
    QtMocHelpers::UintData qt_properties {
    };
    QtMocHelpers::UintData qt_enums {
    };
    return QtMocHelpers::metaObjectData<XPlanetImageViewer, qt_meta_tag_ZN18XPlanetImageViewerE_t>(QMC::MetaObjectFlag{}, qt_stringData,
            qt_methods, qt_properties, qt_enums);
}
Q_CONSTINIT const QMetaObject XPlanetImageViewer::staticMetaObject = { {
    QMetaObject::SuperData::link<QDialog::staticMetaObject>(),
    qt_staticMetaObjectStaticContent<qt_meta_tag_ZN18XPlanetImageViewerE_t>.stringdata,
    qt_staticMetaObjectStaticContent<qt_meta_tag_ZN18XPlanetImageViewerE_t>.data,
    qt_static_metacall,
    nullptr,
    qt_staticMetaObjectRelocatingContent<qt_meta_tag_ZN18XPlanetImageViewerE_t>.metaTypes,
    nullptr
} };

void XPlanetImageViewer::qt_static_metacall(QObject *_o, QMetaObject::Call _c, int _id, void **_a)
{
    auto *_t = static_cast<XPlanetImageViewer *>(_o);
    if (_c == QMetaObject::InvokeMetaMethod) {
        switch (_id) {
        case 0: { bool _r = _t->showImage();
            if (_a[0]) *reinterpret_cast<bool*>(_a[0]) = std::move(_r); }  break;
        case 1: _t->saveFileToDisk(); break;
        case 2: _t->invertColors(); break;
        case 3: _t->updateXPlanetRotationEdit(); break;
        case 4: _t->resetXPlanetRotation(); break;
        case 5: _t->invertXPlanetRotation(); break;
        case 6: _t->reCenterXPlanet(); break;
        case 7: _t->changeXPlanetPosition((*reinterpret_cast<std::add_pointer_t<QPoint>>(_a[1]))); break;
        case 8: _t->changeXPlanetLocation((*reinterpret_cast<std::add_pointer_t<QPoint>>(_a[1]))); break;
        case 9: _t->slotFreeRotate(); break;
        case 10: _t->updateStates(); break;
        case 11: _t->updatePositionDisplay(); break;
        case 12: _t->resetLocation(); break;
        case 13: _t->zoomInXPlanetFOV(); break;
        case 14: _t->zoomOutXPlanetFOV(); break;
        case 15: _t->updateXPlanetFOVEdit(); break;
        case 16: _t->resetXPlanetFOV(); break;
        case 17: _t->setKStarsXPlanetFOV(); break;
        case 18: _t->setFOVfromList(); break;
        case 19: _t->updateXPlanetTime((*reinterpret_cast<std::add_pointer_t<int>>(_a[1]))); break;
        case 20: _t->updateXPlanetObject((*reinterpret_cast<std::add_pointer_t<int>>(_a[1]))); break;
        case 21: _t->updateXPlanetOrigin((*reinterpret_cast<std::add_pointer_t<int>>(_a[1]))); break;
        case 22: _t->updateXPlanetTimeUnits((*reinterpret_cast<std::add_pointer_t<int>>(_a[1]))); break;
        case 23: _t->updateXPlanetTimeEdit(); break;
        case 24: _t->setXPlanetTime(); break;
        case 25: _t->setXPlanetTimetoKStarsTime(); break;
        case 26: _t->resetXPlanetTime(); break;
        case 27: _t->incrementXPlanetTime(); break;
        case 28: _t->toggleXPlanetRun(); break;
        case 29: _t->timeSliderDisplay((*reinterpret_cast<std::add_pointer_t<int>>(_a[1]))); break;
        default: ;
        }
    }
}

const QMetaObject *XPlanetImageViewer::metaObject() const
{
    return QObject::d_ptr->metaObject ? QObject::d_ptr->dynamicMetaObject() : &staticMetaObject;
}

void *XPlanetImageViewer::qt_metacast(const char *_clname)
{
    if (!_clname) return nullptr;
    if (!strcmp(_clname, qt_staticMetaObjectStaticContent<qt_meta_tag_ZN18XPlanetImageViewerE_t>.strings))
        return static_cast<void*>(this);
    return QDialog::qt_metacast(_clname);
}

int XPlanetImageViewer::qt_metacall(QMetaObject::Call _c, int _id, void **_a)
{
    _id = QDialog::qt_metacall(_c, _id, _a);
    if (_id < 0)
        return _id;
    if (_c == QMetaObject::InvokeMetaMethod) {
        if (_id < 30)
            qt_static_metacall(this, _c, _id, _a);
        _id -= 30;
    }
    if (_c == QMetaObject::RegisterMethodArgumentMetaType) {
        if (_id < 30)
            *reinterpret_cast<QMetaType *>(_a[0]) = QMetaType();
        _id -= 30;
    }
    return _id;
}
QT_WARNING_POP
