/****************************************************************************
** Meta object code from reading C++ file 'polaralignmentassistant.h'
**
** Created by: The Qt Meta Object Compiler version 69 (Qt 6.11.1)
**
** WARNING! All changes made in this file will be lost!
*****************************************************************************/

#include "../../../../kstars-3.8.4.1/kstars/ekos/align/polaralignmentassistant.h"
#include <QtNetwork/QSslError>
#include <QtDataVisualization/qbar3dseries.h>
#include <QtDataVisualization/q3dscene.h>
#include <QtGui/qtextcursor.h>
#include <QtCore/qmetatype.h>
#include <QtCore/QSharedPointer>

#include <QtCore/qtmochelpers.h>

#include <memory>


#include <QtCore/qxptype_traits.h>
#if !defined(Q_MOC_OUTPUT_REVISION)
#error "The header file 'polaralignmentassistant.h' doesn't include <QObject>."
#elif Q_MOC_OUTPUT_REVISION != 69
#error "This file was generated using the moc from 6.11.1. It"
#error "cannot be used with the include files from this version of Qt."
#error "(The moc has changed too much.)"
#endif

#ifndef Q_CONSTINIT
#define Q_CONSTINIT
#endif

QT_WARNING_PUSH
QT_WARNING_DISABLE_DEPRECATED
QT_WARNING_DISABLE_GCC("-Wuseless-cast")
namespace {
struct qt_meta_tag_ZN4Ekos23PolarAlignmentAssistantE_t {};
} // unnamed namespace

template <> constexpr inline auto Ekos::PolarAlignmentAssistant::qt_create_metaobjectdata<qt_meta_tag_ZN4Ekos23PolarAlignmentAssistantE_t>()
{
    namespace QMC = QtMocConstants;
    QtMocHelpers::StringRefStorage qt_stringData {
        "Ekos::PolarAlignmentAssistant",
        "newLog",
        "",
        "captureAndSolve",
        "polarResultUpdated",
        "QLineF",
        "correctionVector",
        "polarError",
        "azError",
        "altError",
        "updatedErrorsChanged",
        "total",
        "az",
        "alt",
        "newCorrectionVector",
        "newPAHStage",
        "Stage",
        "stage",
        "newPAHMessage",
        "message",
        "PAHEnabled",
        "newAlignTableResult",
        "Align::AlignResult",
        "result",
        "newFrame",
        "QSharedPointer<FITSView>",
        "view",
        "onPACStatusChanged",
        "ISD::PAC::Status",
        "status"
    };

    QtMocHelpers::UintData qt_methods {
        // Signal 'newLog'
        QtMocHelpers::SignalData<void(const QString &)>(1, 2, QMC::AccessPublic, QMetaType::Void, {{
            { QMetaType::QString, 2 },
        }}),
        // Signal 'captureAndSolve'
        QtMocHelpers::SignalData<void()>(3, 2, QMC::AccessPublic, QMetaType::Void),
        // Signal 'polarResultUpdated'
        QtMocHelpers::SignalData<void(QLineF, double, double, double)>(4, 2, QMC::AccessPublic, QMetaType::Void, {{
            { 0x80000000 | 5, 6 }, { QMetaType::Double, 7 }, { QMetaType::Double, 8 }, { QMetaType::Double, 9 },
        }}),
        // Signal 'updatedErrorsChanged'
        QtMocHelpers::SignalData<void(double, double, double)>(10, 2, QMC::AccessPublic, QMetaType::Void, {{
            { QMetaType::Double, 11 }, { QMetaType::Double, 12 }, { QMetaType::Double, 13 },
        }}),
        // Signal 'newCorrectionVector'
        QtMocHelpers::SignalData<void(QLineF)>(14, 2, QMC::AccessPublic, QMetaType::Void, {{
            { 0x80000000 | 5, 6 },
        }}),
        // Signal 'newPAHStage'
        QtMocHelpers::SignalData<void(Stage)>(15, 2, QMC::AccessPublic, QMetaType::Void, {{
            { 0x80000000 | 16, 17 },
        }}),
        // Signal 'newPAHMessage'
        QtMocHelpers::SignalData<void(const QString &)>(18, 2, QMC::AccessPublic, QMetaType::Void, {{
            { QMetaType::QString, 19 },
        }}),
        // Signal 'PAHEnabled'
        QtMocHelpers::SignalData<void(bool)>(20, 2, QMC::AccessPublic, QMetaType::Void, {{
            { QMetaType::Bool, 2 },
        }}),
        // Signal 'newAlignTableResult'
        QtMocHelpers::SignalData<void(Align::AlignResult)>(21, 2, QMC::AccessPublic, QMetaType::Void, {{
            { 0x80000000 | 22, 23 },
        }}),
        // Signal 'newFrame'
        QtMocHelpers::SignalData<void(const QSharedPointer<FITSView> &)>(24, 2, QMC::AccessPublic, QMetaType::Void, {{
            { 0x80000000 | 25, 26 },
        }}),
        // Slot 'onPACStatusChanged'
        QtMocHelpers::SlotData<void(ISD::PAC::Status)>(27, 2, QMC::AccessPrivate, QMetaType::Void, {{
            { 0x80000000 | 28, 29 },
        }}),
    };
    QtMocHelpers::UintData qt_properties {
    };
    QtMocHelpers::UintData qt_enums {
    };
    return QtMocHelpers::metaObjectData<PolarAlignmentAssistant, qt_meta_tag_ZN4Ekos23PolarAlignmentAssistantE_t>(QMC::MetaObjectFlag{}, qt_stringData,
            qt_methods, qt_properties, qt_enums);
}
Q_CONSTINIT const QMetaObject Ekos::PolarAlignmentAssistant::staticMetaObject = { {
    QMetaObject::SuperData::link<QWidget::staticMetaObject>(),
    qt_staticMetaObjectStaticContent<qt_meta_tag_ZN4Ekos23PolarAlignmentAssistantE_t>.stringdata,
    qt_staticMetaObjectStaticContent<qt_meta_tag_ZN4Ekos23PolarAlignmentAssistantE_t>.data,
    qt_static_metacall,
    nullptr,
    qt_staticMetaObjectRelocatingContent<qt_meta_tag_ZN4Ekos23PolarAlignmentAssistantE_t>.metaTypes,
    nullptr
} };

void Ekos::PolarAlignmentAssistant::qt_static_metacall(QObject *_o, QMetaObject::Call _c, int _id, void **_a)
{
    auto *_t = static_cast<PolarAlignmentAssistant *>(_o);
    if (_c == QMetaObject::InvokeMetaMethod) {
        switch (_id) {
        case 0: _t->newLog((*reinterpret_cast<std::add_pointer_t<QString>>(_a[1]))); break;
        case 1: _t->captureAndSolve(); break;
        case 2: _t->polarResultUpdated((*reinterpret_cast<std::add_pointer_t<QLineF>>(_a[1])),(*reinterpret_cast<std::add_pointer_t<double>>(_a[2])),(*reinterpret_cast<std::add_pointer_t<double>>(_a[3])),(*reinterpret_cast<std::add_pointer_t<double>>(_a[4]))); break;
        case 3: _t->updatedErrorsChanged((*reinterpret_cast<std::add_pointer_t<double>>(_a[1])),(*reinterpret_cast<std::add_pointer_t<double>>(_a[2])),(*reinterpret_cast<std::add_pointer_t<double>>(_a[3]))); break;
        case 4: _t->newCorrectionVector((*reinterpret_cast<std::add_pointer_t<QLineF>>(_a[1]))); break;
        case 5: _t->newPAHStage((*reinterpret_cast<std::add_pointer_t<Stage>>(_a[1]))); break;
        case 6: _t->newPAHMessage((*reinterpret_cast<std::add_pointer_t<QString>>(_a[1]))); break;
        case 7: _t->PAHEnabled((*reinterpret_cast<std::add_pointer_t<bool>>(_a[1]))); break;
        case 8: _t->newAlignTableResult((*reinterpret_cast<std::add_pointer_t<Align::AlignResult>>(_a[1]))); break;
        case 9: _t->newFrame((*reinterpret_cast<std::add_pointer_t<QSharedPointer<FITSView>>>(_a[1]))); break;
        case 10: _t->onPACStatusChanged((*reinterpret_cast<std::add_pointer_t<ISD::PAC::Status>>(_a[1]))); break;
        default: ;
        }
    }
    if (_c == QMetaObject::RegisterMethodArgumentMetaType) {
        switch (_id) {
        default: *reinterpret_cast<QMetaType *>(_a[0]) = QMetaType(); break;
        case 9:
            switch (*reinterpret_cast<int*>(_a[1])) {
            default: *reinterpret_cast<QMetaType *>(_a[0]) = QMetaType(); break;
            case 0:
                *reinterpret_cast<QMetaType *>(_a[0]) = QMetaType::fromType< QSharedPointer<FITSView> >(); break;
            }
            break;
        case 10:
            switch (*reinterpret_cast<int*>(_a[1])) {
            default: *reinterpret_cast<QMetaType *>(_a[0]) = QMetaType(); break;
            case 0:
                *reinterpret_cast<QMetaType *>(_a[0]) = QMetaType::fromType< ISD::PAC::Status >(); break;
            }
            break;
        }
    }
    if (_c == QMetaObject::IndexOfMethod) {
        if (QtMocHelpers::indexOfMethod<void (PolarAlignmentAssistant::*)(const QString & )>(_a, &PolarAlignmentAssistant::newLog, 0))
            return;
        if (QtMocHelpers::indexOfMethod<void (PolarAlignmentAssistant::*)()>(_a, &PolarAlignmentAssistant::captureAndSolve, 1))
            return;
        if (QtMocHelpers::indexOfMethod<void (PolarAlignmentAssistant::*)(QLineF , double , double , double )>(_a, &PolarAlignmentAssistant::polarResultUpdated, 2))
            return;
        if (QtMocHelpers::indexOfMethod<void (PolarAlignmentAssistant::*)(double , double , double )>(_a, &PolarAlignmentAssistant::updatedErrorsChanged, 3))
            return;
        if (QtMocHelpers::indexOfMethod<void (PolarAlignmentAssistant::*)(QLineF )>(_a, &PolarAlignmentAssistant::newCorrectionVector, 4))
            return;
        if (QtMocHelpers::indexOfMethod<void (PolarAlignmentAssistant::*)(Stage )>(_a, &PolarAlignmentAssistant::newPAHStage, 5))
            return;
        if (QtMocHelpers::indexOfMethod<void (PolarAlignmentAssistant::*)(const QString & )>(_a, &PolarAlignmentAssistant::newPAHMessage, 6))
            return;
        if (QtMocHelpers::indexOfMethod<void (PolarAlignmentAssistant::*)(bool )>(_a, &PolarAlignmentAssistant::PAHEnabled, 7))
            return;
        if (QtMocHelpers::indexOfMethod<void (PolarAlignmentAssistant::*)(Align::AlignResult )>(_a, &PolarAlignmentAssistant::newAlignTableResult, 8))
            return;
        if (QtMocHelpers::indexOfMethod<void (PolarAlignmentAssistant::*)(const QSharedPointer<FITSView> & )>(_a, &PolarAlignmentAssistant::newFrame, 9))
            return;
    }
}

const QMetaObject *Ekos::PolarAlignmentAssistant::metaObject() const
{
    return QObject::d_ptr->metaObject ? QObject::d_ptr->dynamicMetaObject() : &staticMetaObject;
}

void *Ekos::PolarAlignmentAssistant::qt_metacast(const char *_clname)
{
    if (!_clname) return nullptr;
    if (!strcmp(_clname, qt_staticMetaObjectStaticContent<qt_meta_tag_ZN4Ekos23PolarAlignmentAssistantE_t>.strings))
        return static_cast<void*>(this);
    if (!strcmp(_clname, "Ui::PolarAlignmentAssistant"))
        return static_cast< Ui::PolarAlignmentAssistant*>(this);
    return QWidget::qt_metacast(_clname);
}

int Ekos::PolarAlignmentAssistant::qt_metacall(QMetaObject::Call _c, int _id, void **_a)
{
    _id = QWidget::qt_metacall(_c, _id, _a);
    if (_id < 0)
        return _id;
    if (_c == QMetaObject::InvokeMetaMethod) {
        if (_id < 11)
            qt_static_metacall(this, _c, _id, _a);
        _id -= 11;
    }
    if (_c == QMetaObject::RegisterMethodArgumentMetaType) {
        if (_id < 11)
            qt_static_metacall(this, _c, _id, _a);
        _id -= 11;
    }
    return _id;
}

// SIGNAL 0
void Ekos::PolarAlignmentAssistant::newLog(const QString & _t1)
{
    QMetaObject::activate<void>(this, &staticMetaObject, 0, nullptr, _t1);
}

// SIGNAL 1
void Ekos::PolarAlignmentAssistant::captureAndSolve()
{
    QMetaObject::activate(this, &staticMetaObject, 1, nullptr);
}

// SIGNAL 2
void Ekos::PolarAlignmentAssistant::polarResultUpdated(QLineF _t1, double _t2, double _t3, double _t4)
{
    QMetaObject::activate<void>(this, &staticMetaObject, 2, nullptr, _t1, _t2, _t3, _t4);
}

// SIGNAL 3
void Ekos::PolarAlignmentAssistant::updatedErrorsChanged(double _t1, double _t2, double _t3)
{
    QMetaObject::activate<void>(this, &staticMetaObject, 3, nullptr, _t1, _t2, _t3);
}

// SIGNAL 4
void Ekos::PolarAlignmentAssistant::newCorrectionVector(QLineF _t1)
{
    QMetaObject::activate<void>(this, &staticMetaObject, 4, nullptr, _t1);
}

// SIGNAL 5
void Ekos::PolarAlignmentAssistant::newPAHStage(Stage _t1)
{
    QMetaObject::activate<void>(this, &staticMetaObject, 5, nullptr, _t1);
}

// SIGNAL 6
void Ekos::PolarAlignmentAssistant::newPAHMessage(const QString & _t1)
{
    QMetaObject::activate<void>(this, &staticMetaObject, 6, nullptr, _t1);
}

// SIGNAL 7
void Ekos::PolarAlignmentAssistant::PAHEnabled(bool _t1)
{
    QMetaObject::activate<void>(this, &staticMetaObject, 7, nullptr, _t1);
}

// SIGNAL 8
void Ekos::PolarAlignmentAssistant::newAlignTableResult(Align::AlignResult _t1)
{
    QMetaObject::activate<void>(this, &staticMetaObject, 8, nullptr, _t1);
}

// SIGNAL 9
void Ekos::PolarAlignmentAssistant::newFrame(const QSharedPointer<FITSView> & _t1)
{
    QMetaObject::activate<void>(this, &staticMetaObject, 9, nullptr, _t1);
}
QT_WARNING_POP
