/*
 * This file was generated by qdbusxml2cpp version 0.8
 * Source file was org.kde.kstars.INDI.LightBox.xml
 *
 * qdbusxml2cpp is Copyright (C) The Qt Company Ltd. and other contributors.
 *
 * This is an auto-generated file.
 * Do not edit! All changes made to it will be lost.
 */

#include "lightboxadaptor.h"
#include <QtCore/QMetaObject>
#include <QtCore/QByteArray>
#include <QtCore/QList>
#include <QtCore/QMap>
#include <QtCore/QString>
#include <QtCore/QStringList>
#include <QtCore/QVariant>

/*
 * Implementation of adaptor class LightBoxAdaptor
 */

LightBoxAdaptor::LightBoxAdaptor(ISD::LightBox *parent)
    : QDBusAbstractAdaptor(parent)
{
    // constructor
    setAutoRelaySignals(true);
}

LightBoxAdaptor::~LightBoxAdaptor()
{
    // destructor
}

ushort LightBoxAdaptor::brightness() const
{
    // get the value of property brightness
    return qvariant_cast< ushort >(parent()->property("brightness"));
}

bool LightBoxAdaptor::connected() const
{
    // get the value of property connected
    return qvariant_cast< bool >(parent()->property("connected"));
}

QString LightBoxAdaptor::name() const
{
    // get the value of property name
    return qvariant_cast< QString >(parent()->property("name"));
}

int LightBoxAdaptor::status() const
{
    // get the value of property status
    return qvariant_cast< int >(parent()->property("status"));
}

bool LightBoxAdaptor::isLightOn()
{
    // handle method call org.kde.kstars.INDI.LightBox.isLightOn
    return parent()->isLightOn();
}

bool LightBoxAdaptor::setBrightness(ushort val)
{
    // handle method call org.kde.kstars.INDI.LightBox.setBrightness
    return parent()->setBrightness(val);
}

bool LightBoxAdaptor::setLightEnabled(bool enable)
{
    // handle method call org.kde.kstars.INDI.LightBox.setLightEnabled
    return parent()->setLightEnabled(enable);
}


#include "moc_lightboxadaptor.cpp"
