/*
 * This file was generated by qdbusxml2cpp version 0.8
 * Source file was org.kde.kstars.INDI.PAC.xml
 *
 * qdbusxml2cpp is Copyright (C) The Qt Company Ltd. and other contributors.
 *
 * This is an auto-generated file.
 * This file may have been hand-edited. Look for HAND-EDIT comments
 * before re-generating it.
 */

#ifndef PACADAPTOR_H
#define PACADAPTOR_H

#include <QtCore/QObject>
#include <QtDBus/QtDBus>
#include "indi/indipac.h"
#include <QtCore/qcontainerfwd.h>

/*
 * Adaptor class for interface org.kde.kstars.INDI.PAC
 */
class PACAdaptor: public QDBusAbstractAdaptor
{
    Q_OBJECT
    Q_CLASSINFO("D-Bus Interface", "org.kde.kstars.INDI.PAC")
    Q_CLASSINFO("D-Bus Introspection", ""
"  <interface name=\"org.kde.kstars.INDI.PAC\">\n"
"    <property access=\"read\" type=\"s\" name=\"name\"/>\n"
"    <property access=\"read\" type=\"b\" name=\"connected\"/>\n"
"    <property access=\"read\" type=\"i\" name=\"status\">\n"
"      <annotation value=\"ISD::PAC::Status\" name=\"org.qtproject.QtDBus.QtTypeName\"/>\n"
"    </property>\n"
"    <method name=\"startCorrection\">\n"
"      <arg direction=\"in\" type=\"d\" name=\"azError\"/>\n"
"      <arg direction=\"in\" type=\"d\" name=\"altError\"/>\n"
"      <arg direction=\"out\" type=\"b\"/>\n"
"    </method>\n"
"    <method name=\"abortCorrection\">\n"
"      <arg direction=\"out\" type=\"b\"/>\n"
"    </method>\n"
"    <method name=\"moveAZ\">\n"
"      <arg direction=\"in\" type=\"d\" name=\"degrees\"/>\n"
"      <arg direction=\"out\" type=\"b\"/>\n"
"    </method>\n"
"    <method name=\"moveALT\">\n"
"      <arg direction=\"in\" type=\"d\" name=\"degrees\"/>\n"
"      <arg direction=\"out\" type=\"b\"/>\n"
"    </method>\n"
"    <signal name=\"Connected\"/>\n"
"    <signal name=\"Disconnected\"/>\n"
"    <signal name=\"ready\"/>\n"
"    <signal name=\"newStatus\">\n"
"      <arg direction=\"out\" type=\"(i)\" name=\"status\"/>\n"
"      <annotation value=\"ISD::PAC::Status\" name=\"org.qtproject.QtDBus.QtTypeName.In0\"/>\n"
"      <annotation value=\"ISD::PAC::Status\" name=\"org.qtproject.QtDBus.QtTypeName.Out0\"/>\n"
"    </signal>\n"
"  </interface>\n"
        "")
public:
    PACAdaptor(ISD::PAC *parent);
    ~PACAdaptor() override;

    inline ISD::PAC *parent() const
    { return static_cast<ISD::PAC *>(QObject::parent()); }

public: // PROPERTIES
    Q_PROPERTY(bool connected READ connected)
    bool connected() const;

    Q_PROPERTY(QString name READ name)
    QString name() const;

    Q_PROPERTY(int status READ status)
    int status() const;

public Q_SLOTS: // METHODS
    bool abortCorrection();
    bool moveALT(double degrees);
    bool moveAZ(double degrees);
    bool startCorrection(double azError, double altError);
Q_SIGNALS: // SIGNALS
    void Connected();
    void Disconnected();
    void newStatus(ISD::PAC::Status status);
    void ready();
};

#endif
