/********************************************************************************
** Form generated from reading UI file 'limits.ui'
**
** Created by: Qt User Interface Compiler version 6.11.1
**
** WARNING! All changes made in this file will be lost when recompiling UI file!
********************************************************************************/

#ifndef UI_LIMITS_H
#define UI_LIMITS_H

#include <QtCore/QVariant>
#include <QtWidgets/QAbstractButton>
#include <QtWidgets/QApplication>
#include <QtWidgets/QCheckBox>
#include <QtWidgets/QComboBox>
#include <QtWidgets/QDialog>
#include <QtWidgets/QDialogButtonBox>
#include <QtWidgets/QDoubleSpinBox>
#include <QtWidgets/QGridLayout>
#include <QtWidgets/QGroupBox>
#include <QtWidgets/QLabel>
#include <QtWidgets/QSpacerItem>
#include <QtWidgets/QSpinBox>
#include <QtWidgets/QVBoxLayout>
#include <klocalizedstring.h>

QT_BEGIN_NAMESPACE

class Ui_Limits
{
public:
    QVBoxLayout *verticalLayout;
    QGroupBox *guideGroupBox;
    QGridLayout *gridLayout;
    QDoubleSpinBox *guideDeviation;
    QSpinBox *guideDeviationReps;
    QSpinBox *guideDitherPerJobFrequency;
    QDoubleSpinBox *startGuideDeviation;
    QLabel *textLabel1_2_4;
    QCheckBox *enforceGuideDeviation;
    QCheckBox *enforceStartGuiderDrift;
    QLabel *startGuiderDriftLabel;
    QLabel *limitGuideDeviationLabel;
    QCheckBox *enableDitherPerJob;
    QLabel *label;
    QGroupBox *focusGroupBox;
    QGridLayout *gridLayout_2;
    QComboBox *hFRCheckAlgorithm;
    QSpinBox *refocusEveryN;
    QDoubleSpinBox *maxFocusTemperatureDelta;
    QCheckBox *enforceAutofocusOnTemperature;
    QCheckBox *refocusAfterMeridianFlip;
    QCheckBox *enforceRefocusEveryN;
    QCheckBox *enforceAutofocusHFR;
    QLabel *label_11;
    QSpinBox *inSequenceCheckFrames;
    QDoubleSpinBox *hFRThresholdPercentage;
    QLabel *limitFocusHFRThresholdLabel;
    QLabel *textLabel_1_2_7;
    QLabel *label_9;
    QLabel *limitFocusHFRPercentLabel;
    QLabel *textLabel1_2_5;
    QDoubleSpinBox *hFRDeviation;
    QLabel *label_4;
    QSpacerItem *verticalSpacer;
    QDialogButtonBox *buttonBox;

    void setupUi(QDialog *Limits)
    {
        if (Limits->objectName().isEmpty())
            Limits->setObjectName("Limits");
        Limits->resize(538, 369);
        verticalLayout = new QVBoxLayout(Limits);
        verticalLayout->setSpacing(3);
        verticalLayout->setObjectName("verticalLayout");
        verticalLayout->setContentsMargins(3, 3, 3, 3);
        guideGroupBox = new QGroupBox(Limits);
        guideGroupBox->setObjectName("guideGroupBox");
        gridLayout = new QGridLayout(guideGroupBox);
        gridLayout->setObjectName("gridLayout");
        guideDeviation = new QDoubleSpinBox(guideGroupBox);
        guideDeviation->setObjectName("guideDeviation");
        guideDeviation->setEnabled(true);
        guideDeviation->setDecimals(2);
        guideDeviation->setMaximum(30.000000000000000);
        guideDeviation->setSingleStep(0.500000000000000);

        gridLayout->addWidget(guideDeviation, 1, 2, 1, 1);

        guideDeviationReps = new QSpinBox(guideGroupBox);
        guideDeviationReps->setObjectName("guideDeviationReps");
        guideDeviationReps->setEnabled(true);
        guideDeviationReps->setMaximum(20);
        guideDeviationReps->setSingleStep(1);
        guideDeviationReps->setValue(3);

        gridLayout->addWidget(guideDeviationReps, 1, 4, 1, 1);

        guideDitherPerJobFrequency = new QSpinBox(guideGroupBox);
        guideDitherPerJobFrequency->setObjectName("guideDitherPerJobFrequency");
        guideDitherPerJobFrequency->setMinimum(0);
        guideDitherPerJobFrequency->setMaximum(60);

        gridLayout->addWidget(guideDitherPerJobFrequency, 2, 2, 1, 1);

        startGuideDeviation = new QDoubleSpinBox(guideGroupBox);
        startGuideDeviation->setObjectName("startGuideDeviation");
        startGuideDeviation->setEnabled(true);
        startGuideDeviation->setDecimals(2);
        startGuideDeviation->setMaximum(30.000000000000000);
        startGuideDeviation->setSingleStep(0.500000000000000);
        startGuideDeviation->setValue(2.000000000000000);

        gridLayout->addWidget(startGuideDeviation, 0, 2, 1, 1);

        textLabel1_2_4 = new QLabel(guideGroupBox);
        textLabel1_2_4->setObjectName("textLabel1_2_4");

        gridLayout->addWidget(textLabel1_2_4, 1, 3, 1, 1);

        enforceGuideDeviation = new QCheckBox(guideGroupBox);
        enforceGuideDeviation->setObjectName("enforceGuideDeviation");
        enforceGuideDeviation->setEnabled(true);
        enforceGuideDeviation->setChecked(false);

        gridLayout->addWidget(enforceGuideDeviation, 1, 0, 1, 1);

        enforceStartGuiderDrift = new QCheckBox(guideGroupBox);
        enforceStartGuiderDrift->setObjectName("enforceStartGuiderDrift");
        enforceStartGuiderDrift->setEnabled(true);

        gridLayout->addWidget(enforceStartGuiderDrift, 0, 0, 1, 1);

        startGuiderDriftLabel = new QLabel(guideGroupBox);
        startGuiderDriftLabel->setObjectName("startGuiderDriftLabel");

        gridLayout->addWidget(startGuiderDriftLabel, 0, 3, 1, 1);

        limitGuideDeviationLabel = new QLabel(guideGroupBox);
        limitGuideDeviationLabel->setObjectName("limitGuideDeviationLabel");
        limitGuideDeviationLabel->setEnabled(true);

        gridLayout->addWidget(limitGuideDeviationLabel, 1, 5, 1, 1);

        enableDitherPerJob = new QCheckBox(guideGroupBox);
        enableDitherPerJob->setObjectName("enableDitherPerJob");
        enableDitherPerJob->setChecked(true);

        gridLayout->addWidget(enableDitherPerJob, 2, 0, 1, 1);

        label = new QLabel(guideGroupBox);
        label->setObjectName("label");

        gridLayout->addWidget(label, 2, 3, 1, 3);


        verticalLayout->addWidget(guideGroupBox);

        focusGroupBox = new QGroupBox(Limits);
        focusGroupBox->setObjectName("focusGroupBox");
        gridLayout_2 = new QGridLayout(focusGroupBox);
        gridLayout_2->setObjectName("gridLayout_2");
        hFRCheckAlgorithm = new QComboBox(focusGroupBox);
        hFRCheckAlgorithm->addItem(QString());
        hFRCheckAlgorithm->addItem(QString());
        hFRCheckAlgorithm->addItem(QString());
        hFRCheckAlgorithm->setObjectName("hFRCheckAlgorithm");
        hFRCheckAlgorithm->setEditable(false);

        gridLayout_2->addWidget(hFRCheckAlgorithm, 5, 1, 1, 1);

        refocusEveryN = new QSpinBox(focusGroupBox);
        refocusEveryN->setObjectName("refocusEveryN");
        refocusEveryN->setEnabled(true);
        refocusEveryN->setMinimum(1);
        refocusEveryN->setMaximum(999);
        refocusEveryN->setValue(60);

        gridLayout_2->addWidget(refocusEveryN, 3, 1, 1, 1);

        maxFocusTemperatureDelta = new QDoubleSpinBox(focusGroupBox);
        maxFocusTemperatureDelta->setObjectName("maxFocusTemperatureDelta");
        maxFocusTemperatureDelta->setEnabled(true);
        maxFocusTemperatureDelta->setDecimals(2);
        maxFocusTemperatureDelta->setMinimum(0.100000000000000);
        maxFocusTemperatureDelta->setMaximum(10.000000000000000);
        maxFocusTemperatureDelta->setSingleStep(0.100000000000000);
        maxFocusTemperatureDelta->setValue(1.000000000000000);

        gridLayout_2->addWidget(maxFocusTemperatureDelta, 4, 1, 1, 1);

        enforceAutofocusOnTemperature = new QCheckBox(focusGroupBox);
        enforceAutofocusOnTemperature->setObjectName("enforceAutofocusOnTemperature");
        enforceAutofocusOnTemperature->setEnabled(true);

        gridLayout_2->addWidget(enforceAutofocusOnTemperature, 4, 0, 1, 1);

        refocusAfterMeridianFlip = new QCheckBox(focusGroupBox);
        refocusAfterMeridianFlip->setObjectName("refocusAfterMeridianFlip");

        gridLayout_2->addWidget(refocusAfterMeridianFlip, 11, 0, 1, 2);

        enforceRefocusEveryN = new QCheckBox(focusGroupBox);
        enforceRefocusEveryN->setObjectName("enforceRefocusEveryN");
        enforceRefocusEveryN->setEnabled(true);

        gridLayout_2->addWidget(enforceRefocusEveryN, 3, 0, 1, 1);

        enforceAutofocusHFR = new QCheckBox(focusGroupBox);
        enforceAutofocusHFR->setObjectName("enforceAutofocusHFR");
        enforceAutofocusHFR->setEnabled(true);

        gridLayout_2->addWidget(enforceAutofocusHFR, 5, 0, 1, 1);

        label_11 = new QLabel(focusGroupBox);
        label_11->setObjectName("label_11");
        label_11->setAlignment(Qt::AlignRight|Qt::AlignTrailing|Qt::AlignVCenter);

        gridLayout_2->addWidget(label_11, 6, 0, 1, 1);

        inSequenceCheckFrames = new QSpinBox(focusGroupBox);
        inSequenceCheckFrames->setObjectName("inSequenceCheckFrames");
        inSequenceCheckFrames->setMinimum(1);
        inSequenceCheckFrames->setMaximum(30);

        gridLayout_2->addWidget(inSequenceCheckFrames, 6, 1, 1, 1);

        hFRThresholdPercentage = new QDoubleSpinBox(focusGroupBox);
        hFRThresholdPercentage->setObjectName("hFRThresholdPercentage");
        hFRThresholdPercentage->setMaximum(50.000000000000000);
        hFRThresholdPercentage->setValue(10.000000000000000);

        gridLayout_2->addWidget(hFRThresholdPercentage, 5, 3, 1, 1);

        limitFocusHFRThresholdLabel = new QLabel(focusGroupBox);
        limitFocusHFRThresholdLabel->setObjectName("limitFocusHFRThresholdLabel");
        limitFocusHFRThresholdLabel->setAlignment(Qt::AlignRight|Qt::AlignTrailing|Qt::AlignVCenter);

        gridLayout_2->addWidget(limitFocusHFRThresholdLabel, 5, 2, 1, 1);

        textLabel_1_2_7 = new QLabel(focusGroupBox);
        textLabel_1_2_7->setObjectName("textLabel_1_2_7");

        gridLayout_2->addWidget(textLabel_1_2_7, 3, 2, 1, 1);

        label_9 = new QLabel(focusGroupBox);
        label_9->setObjectName("label_9");

        gridLayout_2->addWidget(label_9, 4, 2, 1, 1);

        limitFocusHFRPercentLabel = new QLabel(focusGroupBox);
        limitFocusHFRPercentLabel->setObjectName("limitFocusHFRPercentLabel");

        gridLayout_2->addWidget(limitFocusHFRPercentLabel, 5, 4, 1, 1);

        textLabel1_2_5 = new QLabel(focusGroupBox);
        textLabel1_2_5->setObjectName("textLabel1_2_5");

        gridLayout_2->addWidget(textLabel1_2_5, 6, 4, 1, 1);

        hFRDeviation = new QDoubleSpinBox(focusGroupBox);
        hFRDeviation->setObjectName("hFRDeviation");
        hFRDeviation->setEnabled(true);
        hFRDeviation->setDecimals(2);
        hFRDeviation->setMinimum(0.000000000000000);
        hFRDeviation->setMaximum(10.000000000000000);
        hFRDeviation->setSingleStep(0.100000000000000);
        hFRDeviation->setValue(0.000000000000000);

        gridLayout_2->addWidget(hFRDeviation, 6, 3, 1, 1);

        label_4 = new QLabel(focusGroupBox);
        label_4->setObjectName("label_4");

        gridLayout_2->addWidget(label_4, 6, 2, 1, 1);


        verticalLayout->addWidget(focusGroupBox);

        verticalSpacer = new QSpacerItem(20, 40, QSizePolicy::Policy::Minimum, QSizePolicy::Policy::Expanding);

        verticalLayout->addItem(verticalSpacer);

        buttonBox = new QDialogButtonBox(Limits);
        buttonBox->setObjectName("buttonBox");
        buttonBox->setOrientation(Qt::Horizontal);
        buttonBox->setStandardButtons(QDialogButtonBox::Close);

        verticalLayout->addWidget(buttonBox);

        QWidget::setTabOrder(enforceStartGuiderDrift, startGuideDeviation);
        QWidget::setTabOrder(startGuideDeviation, enforceGuideDeviation);
        QWidget::setTabOrder(enforceGuideDeviation, guideDeviation);
        QWidget::setTabOrder(guideDeviation, guideDeviationReps);
        QWidget::setTabOrder(guideDeviationReps, guideDitherPerJobFrequency);
        QWidget::setTabOrder(guideDitherPerJobFrequency, enforceRefocusEveryN);
        QWidget::setTabOrder(enforceRefocusEveryN, refocusEveryN);
        QWidget::setTabOrder(refocusEveryN, enforceAutofocusOnTemperature);
        QWidget::setTabOrder(enforceAutofocusOnTemperature, maxFocusTemperatureDelta);
        QWidget::setTabOrder(maxFocusTemperatureDelta, enforceAutofocusHFR);
        QWidget::setTabOrder(enforceAutofocusHFR, hFRCheckAlgorithm);
        QWidget::setTabOrder(hFRCheckAlgorithm, hFRThresholdPercentage);
        QWidget::setTabOrder(hFRThresholdPercentage, inSequenceCheckFrames);
        QWidget::setTabOrder(inSequenceCheckFrames, hFRDeviation);
        QWidget::setTabOrder(hFRDeviation, refocusAfterMeridianFlip);

        retranslateUi(Limits);
        QObject::connect(buttonBox, &QDialogButtonBox::accepted, Limits, qOverload<>(&QDialog::accept));
        QObject::connect(buttonBox, &QDialogButtonBox::rejected, Limits, qOverload<>(&QDialog::reject));

        QMetaObject::connectSlotsByName(Limits);
    } // setupUi

    void retranslateUi(QDialog *Limits)
    {
        Limits->setWindowTitle(tr2i18n("Guide & Focus Limits", nullptr));
        guideGroupBox->setTitle(tr2i18n("Guide Limits", nullptr));
#if QT_CONFIG(tooltip)
        guideDeviationReps->setToolTip(tr2i18n("Abort sequence if guiding deviation exceed this value N consecutive times", nullptr));
#endif // QT_CONFIG(tooltip)
#if QT_CONFIG(tooltip)
        guideDitherPerJobFrequency->setToolTip(tr2i18n("<html><head/><body><p>If global dither is enabled, then dither every N number of frames for this job. Set to 0 to use global dither frequency.</p></body></html>", nullptr));
#endif // QT_CONFIG(tooltip)
#if QT_CONFIG(tooltip)
        textLabel1_2_4->setToolTip(tr2i18n("Number of images to capture", nullptr));
#endif // QT_CONFIG(tooltip)
#if QT_CONFIG(whatsthis)
        textLabel1_2_4->setWhatsThis(QString());
#endif // QT_CONFIG(whatsthis)
        textLabel1_2_4->setText(tr2i18n("\"", nullptr));
#if QT_CONFIG(tooltip)
        enforceGuideDeviation->setToolTip(tr2i18n("Abort sequence if guiding deviation exceed this value N consecutive times", nullptr));
#endif // QT_CONFIG(tooltip)
        enforceGuideDeviation->setText(tr2i18n("Abort if guide deviation >:", nullptr));
#if QT_CONFIG(tooltip)
        enforceStartGuiderDrift->setToolTip(tr2i18n("Start capturing only if guide deviation is below the given threshold (ignored for previews)", nullptr));
#endif // QT_CONFIG(tooltip)
        enforceStartGuiderDrift->setText(tr2i18n("Only start if guide deviation <:", nullptr));
        startGuiderDriftLabel->setText(tr2i18n("\"", nullptr));
#if QT_CONFIG(tooltip)
        limitGuideDeviationLabel->setToolTip(tr2i18n("Abort sequence if guiding deviation exceed this value N consecutive times", nullptr));
#endif // QT_CONFIG(tooltip)
        limitGuideDeviationLabel->setText(tr2i18n("consecutive times", nullptr));
        enableDitherPerJob->setText(tr2i18n("Dither per job every:", nullptr));
        label->setText(tr2i18n("frames", nullptr));
        focusGroupBox->setTitle(tr2i18n("Focus Limits", nullptr));
        hFRCheckAlgorithm->setItemText(0, tr2i18n("Last Autofocus", nullptr));
        hFRCheckAlgorithm->setItemText(1, tr2i18n("Fixed", nullptr));
        hFRCheckAlgorithm->setItemText(2, tr2i18n("Median Measure", nullptr));

#if QT_CONFIG(tooltip)
        hFRCheckAlgorithm->setToolTip(tr2i18n("<html><head/><body><p>The HFR Check algorithm:</p><ul style=\"margin-top: 0px; margin-bottom: 0px; margin-left: 0px; margin-right: 0px; -qt-list-indent: 1;\"><li style=\" margin-top:12px; margin-bottom:0px; margin-left:0px; margin-right:0px; -qt-block-indent:0; text-indent:0px;\"><span style=\" font-weight:600;\">Last Autofocus</span>: This is the default algorithm and uses the HFR value from the most recent Autofocus run as the reference for the check.</li></ul><ul style=\"margin-top: 0px; margin-bottom: 0px; margin-left: 0px; margin-right: 0px; -qt-list-indent: 1;\"><li style=\" margin-top:0px; margin-bottom:0px; margin-left:0px; margin-right:0px; -qt-block-indent:0; text-indent:0px;\"><span style=\" font-weight:600;\">Fixed</span>: This algorithm lets the user specify a fixed HFR to use in the check.</li><li style=\" margin-top:0px; margin-bottom:0px; margin-left:0px; margin-right:0px; -qt-block-indent:0; text-indent:0px;\"><span style=\" font-weight:600;\">Relative Measure</span>: This algorithm collects d"
                        "atapoints from Autofocus and HFR Checks, maintains the data in a sequenced list and uses the median value as the reference for the next HFR Check.</li></ul></body></html>", nullptr));
#endif // QT_CONFIG(tooltip)
#if QT_CONFIG(tooltip)
        enforceAutofocusOnTemperature->setToolTip(tr2i18n("<html><head/><body><p>Check to force an Autofocus when the change in temperature since last focus exceeded this value.  Reference temperature is reset at each Autofocus.</p></body></html>", nullptr));
#endif // QT_CONFIG(tooltip)
        enforceAutofocusOnTemperature->setText(tr2i18n("Refocus if \316\224T\302\260  >:", nullptr));
#if QT_CONFIG(tooltip)
        refocusAfterMeridianFlip->setToolTip(tr2i18n("<html><head/><body><p>Check to force an Autofocus after a Meridian Flip.</p></body></html>", nullptr));
#endif // QT_CONFIG(tooltip)
        refocusAfterMeridianFlip->setText(tr2i18n("Refocus after meridian flip", nullptr));
#if QT_CONFIG(tooltip)
        enforceRefocusEveryN->setToolTip(tr2i18n("<html><head/><body><p>Check to force an Autofocus every N minutes.  Timer is reset at each Autofocus.</p></body></html>", nullptr));
#endif // QT_CONFIG(tooltip)
        enforceRefocusEveryN->setText(tr2i18n("Refocus every:", nullptr));
#if QT_CONFIG(tooltip)
        enforceAutofocusHFR->setToolTip(tr2i18n("<html><head/><body><p>Check to perform an HFR Check between Subframes.  The Check may result in an Autofocus.</p></body></html>", nullptr));
#endif // QT_CONFIG(tooltip)
        enforceAutofocusHFR->setText(tr2i18n("Refocus on \316\224HFR.  Use:", nullptr));
#if QT_CONFIG(tooltip)
        label_11->setToolTip(tr2i18n("Run in-sequence HFR check after this many frames.", nullptr));
#endif // QT_CONFIG(tooltip)
        label_11->setText(tr2i18n("Check every:", nullptr));
#if QT_CONFIG(tooltip)
        inSequenceCheckFrames->setToolTip(tr2i18n("<html><head/><body><p>Run HFR check after this many sub-frames.</p></body></html>", nullptr));
#endif // QT_CONFIG(tooltip)
#if QT_CONFIG(tooltip)
        hFRThresholdPercentage->setToolTip(tr2i18n("<html><head/><body><p>Specify the % to apply to the HFR Check value appropriate to the selected algorithm, to use as the threshold to perform the HFR Check.</p></body></html>", nullptr));
#endif // QT_CONFIG(tooltip)
        limitFocusHFRThresholdLabel->setText(tr2i18n("Threshold:", nullptr));
        textLabel_1_2_7->setText(tr2i18n("minutes", nullptr));
        label_9->setText(tr2i18n("\302\260C", nullptr));
        limitFocusHFRPercentLabel->setText(tr2i18n("%", nullptr));
#if QT_CONFIG(tooltip)
        textLabel1_2_5->setToolTip(tr2i18n("Number of images to capture", nullptr));
#endif // QT_CONFIG(tooltip)
#if QT_CONFIG(whatsthis)
        textLabel1_2_5->setWhatsThis(QString());
#endif // QT_CONFIG(whatsthis)
        textLabel1_2_5->setText(tr2i18n("pixels", nullptr));
#if QT_CONFIG(tooltip)
        hFRDeviation->setToolTip(tr2i18n("<html><head/><body><p>The HFR Check value in pixels. This is an output field when Last Autofocus or Relative Measure is selected, and an input field for Fixed.  In all cases,  the user can override the system generated value.</p></body></html>", nullptr));
#endif // QT_CONFIG(tooltip)
        label_4->setText(tr2i18n("frames.   HFR:", nullptr));
    } // retranslateUi

};

namespace Ui {
    class Limits: public Ui_Limits {};
} // namespace Ui

QT_END_NAMESPACE

#endif // LIMITS_H

