/********************************************************************************
** Form generated from reading UI file 'livestackmonitor.ui'
**
** Created by: Qt User Interface Compiler version 6.11.1
**
** WARNING! All changes made in this file will be lost when recompiling UI file!
********************************************************************************/

#ifndef UI_LIVESTACKMONITOR_H
#define UI_LIVESTACKMONITOR_H

#include <QtCore/QVariant>
#include <QtWidgets/QAbstractButton>
#include <QtWidgets/QApplication>
#include <QtWidgets/QCheckBox>
#include <QtWidgets/QDialogButtonBox>
#include <QtWidgets/QGridLayout>
#include <QtWidgets/QHeaderView>
#include <QtWidgets/QProgressBar>
#include <QtWidgets/QStatusBar>
#include <QtWidgets/QTableView>
#include <QtWidgets/QWidget>
#include <klocalizedstring.h>

QT_BEGIN_NAMESPACE

class Ui_StackMonitorDialog
{
public:
    QGridLayout *gridLayout;
    QTableView *StackMonitorTableView;
    QCheckBox *StackMonitorHighlight;
    QDialogButtonBox *StackMonitorButtonBox;
    QProgressBar *StackMonitorProgressBar;
    QStatusBar *StackMonitorStatusBar;

    void setupUi(QWidget *StackMonitorDialog)
    {
        if (StackMonitorDialog->objectName().isEmpty())
            StackMonitorDialog->setObjectName("StackMonitorDialog");
        StackMonitorDialog->setProperty("modal", QVariant(false));
        StackMonitorDialog->setWindowModality(Qt::NonModal);
        StackMonitorDialog->resize(436, 315);
        QSizePolicy sizePolicy(QSizePolicy::Policy::MinimumExpanding, QSizePolicy::Policy::MinimumExpanding);
        sizePolicy.setHorizontalStretch(0);
        sizePolicy.setVerticalStretch(0);
        sizePolicy.setHeightForWidth(StackMonitorDialog->sizePolicy().hasHeightForWidth());
        StackMonitorDialog->setSizePolicy(sizePolicy);
        StackMonitorDialog->setProperty("sizeGripEnabled", QVariant(false));
        gridLayout = new QGridLayout(StackMonitorDialog);
        gridLayout->setObjectName("gridLayout");
        StackMonitorTableView = new QTableView(StackMonitorDialog);
        StackMonitorTableView->setObjectName("StackMonitorTableView");
        StackMonitorTableView->setSizeAdjustPolicy(QAbstractScrollArea::AdjustToContents);
        StackMonitorTableView->setDragEnabled(false);
        StackMonitorTableView->setSelectionMode(QAbstractItemView::SingleSelection);
        StackMonitorTableView->setTextElideMode(Qt::ElideLeft);
        StackMonitorTableView->setSortingEnabled(true);
        StackMonitorTableView->horizontalHeader()->setProperty("showSortIndicator", QVariant(true));
        StackMonitorTableView->verticalHeader()->setVisible(false);

        gridLayout->addWidget(StackMonitorTableView, 0, 0, 1, 2);

        StackMonitorHighlight = new QCheckBox(StackMonitorDialog);
        StackMonitorHighlight->setObjectName("StackMonitorHighlight");
        StackMonitorHighlight->setChecked(true);

        gridLayout->addWidget(StackMonitorHighlight, 1, 0, 1, 1);

        StackMonitorButtonBox = new QDialogButtonBox(StackMonitorDialog);
        StackMonitorButtonBox->setObjectName("StackMonitorButtonBox");
        StackMonitorButtonBox->setStandardButtons(QDialogButtonBox::Close);

        gridLayout->addWidget(StackMonitorButtonBox, 1, 1, 1, 1);

        StackMonitorProgressBar = new QProgressBar(StackMonitorDialog);
        StackMonitorProgressBar->setObjectName("StackMonitorProgressBar");
        StackMonitorProgressBar->setValue(0);

        gridLayout->addWidget(StackMonitorProgressBar, 2, 0, 1, 2);

        StackMonitorStatusBar = new QStatusBar(StackMonitorDialog);
        StackMonitorStatusBar->setObjectName("StackMonitorStatusBar");

        gridLayout->addWidget(StackMonitorStatusBar, 3, 0, 1, 2);


        retranslateUi(StackMonitorDialog);

        QMetaObject::connectSlotsByName(StackMonitorDialog);
    } // setupUi

    void retranslateUi(QWidget *StackMonitorDialog)
    {
        StackMonitorDialog->setWindowTitle(tr2i18n("Live Stacking Monitor", nullptr));
#if QT_CONFIG(tooltip)
        StackMonitorHighlight->setToolTip(tr2i18n("<html><head/><body><p>Check to enable highlighting of data changes</p></body></html>", nullptr));
#endif // QT_CONFIG(tooltip)
        StackMonitorHighlight->setText(tr2i18n(" Highlighting", nullptr));
        StackMonitorProgressBar->setFormat(tr2i18n("%p%", nullptr));
    } // retranslateUi

};

namespace Ui {
    class StackMonitorDialog: public Ui_StackMonitorDialog {};
} // namespace Ui

QT_END_NAMESPACE

#endif // LIVESTACKMONITOR_H

