/*
 * This file was generated by qdbusxml2cpp version 0.8
 * Source file was org.kde.kstars.INDI.PAC.xml
 *
 * qdbusxml2cpp is Copyright (C) The Qt Company Ltd. and other contributors.
 *
 * This is an auto-generated file.
 * Do not edit! All changes made to it will be lost.
 */

#include "pacadaptor.h"
#include <QtCore/QMetaObject>
#include <QtCore/QByteArray>
#include <QtCore/QList>
#include <QtCore/QMap>
#include <QtCore/QString>
#include <QtCore/QStringList>
#include <QtCore/QVariant>

/*
 * Implementation of adaptor class PACAdaptor
 */

PACAdaptor::PACAdaptor(ISD::PAC *parent)
    : QDBusAbstractAdaptor(parent)
{
    // constructor
    setAutoRelaySignals(true);
}

PACAdaptor::~PACAdaptor()
{
    // destructor
}

bool PACAdaptor::connected() const
{
    // get the value of property connected
    return qvariant_cast< bool >(parent()->property("connected"));
}

QString PACAdaptor::name() const
{
    // get the value of property name
    return qvariant_cast< QString >(parent()->property("name"));
}

int PACAdaptor::status() const
{
    // get the value of property status
    return qvariant_cast< int >(parent()->property("status"));
}

bool PACAdaptor::abortCorrection()
{
    // handle method call org.kde.kstars.INDI.PAC.abortCorrection
    return parent()->abortCorrection();
}

bool PACAdaptor::moveALT(double degrees)
{
    // handle method call org.kde.kstars.INDI.PAC.moveALT
    return parent()->moveALT(degrees);
}

bool PACAdaptor::moveAZ(double degrees)
{
    // handle method call org.kde.kstars.INDI.PAC.moveAZ
    return parent()->moveAZ(degrees);
}

bool PACAdaptor::startCorrection(double azError, double altError)
{
    // handle method call org.kde.kstars.INDI.PAC.startCorrection
    return parent()->startCorrection(azError, altError);
}


#include "moc_pacadaptor.cpp"
