/********************************************************************************
** Form generated from reading UI file 'eclipsetool.ui'
**
** Created by: Qt User Interface Compiler version 6.11.1
**
** WARNING! All changes made in this file will be lost when recompiling UI file!
********************************************************************************/

#ifndef UI_ECLIPSETOOL_H
#define UI_ECLIPSETOOL_H

#include <QtCore/QVariant>
#include <QtWidgets/QApplication>
#include <QtWidgets/QComboBox>
#include <QtWidgets/QDateTimeEdit>
#include <QtWidgets/QFrame>
#include <QtWidgets/QGridLayout>
#include <QtWidgets/QGroupBox>
#include <QtWidgets/QHBoxLayout>
#include <QtWidgets/QHeaderView>
#include <QtWidgets/QLabel>
#include <QtWidgets/QProgressBar>
#include <QtWidgets/QPushButton>
#include <QtWidgets/QSpacerItem>
#include <QtWidgets/QStackedWidget>
#include <QtWidgets/QTableView>
#include <QtWidgets/QVBoxLayout>
#include <QtWidgets/QWidget>
#include <klocalizedstring.h>

QT_BEGIN_NAMESPACE

class Ui_EclipseTool
{
public:
    QVBoxLayout *verticalLayout;
    QGridLayout *gridLayout;
    QLabel *label_2;
    QLabel *textLabel1;
    QDateTimeEdit *startDate;
    QHBoxLayout *horizontalLayout;
    QComboBox *Obj1ComboBox;
    QLabel *label_4;
    QComboBox *Obj2ComboBox;
    QSpacerItem *horizontalSpacer;
    QLabel *label_3;
    QLabel *label;
    QPushButton *LocationButton;
    QDateTimeEdit *stopDate;
    QStackedWidget *computeStack;
    QWidget *buttonPage;
    QVBoxLayout *verticalLayout_3;
    QHBoxLayout *horizontalLayout_2;
    QPushButton *ComputeButton;
    QSpacerItem *horizontalSpacer_2;
    QPushButton *ExportButton;
    QPushButton *ClearButton;
    QWidget *progressPage;
    QVBoxLayout *verticalLayout_4;
    QProgressBar *progressBar;
    QGroupBox *groupBox;
    QVBoxLayout *verticalLayout_2;
    QTableView *tableView;

    void setupUi(QFrame *EclipseTool)
    {
        if (EclipseTool->objectName().isEmpty())
            EclipseTool->setObjectName("EclipseTool");
        EclipseTool->resize(681, 445);
        verticalLayout = new QVBoxLayout(EclipseTool);
        verticalLayout->setObjectName("verticalLayout");
        gridLayout = new QGridLayout();
        gridLayout->setObjectName("gridLayout");
        gridLayout->setSizeConstraint(QLayout::SetMinimumSize);
        label_2 = new QLabel(EclipseTool);
        label_2->setObjectName("label_2");

        gridLayout->addWidget(label_2, 2, 0, 1, 1);

        textLabel1 = new QLabel(EclipseTool);
        textLabel1->setObjectName("textLabel1");
        QSizePolicy sizePolicy(QSizePolicy::Policy::Minimum, QSizePolicy::Policy::Preferred);
        sizePolicy.setHorizontalStretch(0);
        sizePolicy.setVerticalStretch(0);
        sizePolicy.setHeightForWidth(textLabel1->sizePolicy().hasHeightForWidth());
        textLabel1->setSizePolicy(sizePolicy);

        gridLayout->addWidget(textLabel1, 3, 0, 1, 1);

        startDate = new QDateTimeEdit(EclipseTool);
        startDate->setObjectName("startDate");
        startDate->setCalendarPopup(true);

        gridLayout->addWidget(startDate, 1, 1, 1, 1);

        horizontalLayout = new QHBoxLayout();
        horizontalLayout->setObjectName("horizontalLayout");
        Obj1ComboBox = new QComboBox(EclipseTool);
        Obj1ComboBox->setObjectName("Obj1ComboBox");

        horizontalLayout->addWidget(Obj1ComboBox);

        label_4 = new QLabel(EclipseTool);
        label_4->setObjectName("label_4");
        label_4->setAlignment(Qt::AlignCenter);

        horizontalLayout->addWidget(label_4);

        Obj2ComboBox = new QComboBox(EclipseTool);
        Obj2ComboBox->setObjectName("Obj2ComboBox");
        QSizePolicy sizePolicy1(QSizePolicy::Policy::Preferred, QSizePolicy::Policy::Fixed);
        sizePolicy1.setHorizontalStretch(0);
        sizePolicy1.setVerticalStretch(0);
        sizePolicy1.setHeightForWidth(Obj2ComboBox->sizePolicy().hasHeightForWidth());
        Obj2ComboBox->setSizePolicy(sizePolicy1);

        horizontalLayout->addWidget(Obj2ComboBox);

        horizontalSpacer = new QSpacerItem(40, 20, QSizePolicy::Policy::Expanding, QSizePolicy::Policy::Minimum);

        horizontalLayout->addItem(horizontalSpacer);


        gridLayout->addLayout(horizontalLayout, 3, 1, 1, 1);

        label_3 = new QLabel(EclipseTool);
        label_3->setObjectName("label_3");

        gridLayout->addWidget(label_3, 0, 0, 1, 1);

        label = new QLabel(EclipseTool);
        label->setObjectName("label");

        gridLayout->addWidget(label, 1, 0, 1, 1);

        LocationButton = new QPushButton(EclipseTool);
        LocationButton->setObjectName("LocationButton");

        gridLayout->addWidget(LocationButton, 0, 1, 1, 1);

        stopDate = new QDateTimeEdit(EclipseTool);
        stopDate->setObjectName("stopDate");
        stopDate->setCalendarPopup(true);

        gridLayout->addWidget(stopDate, 2, 1, 1, 1);


        verticalLayout->addLayout(gridLayout);

        computeStack = new QStackedWidget(EclipseTool);
        computeStack->setObjectName("computeStack");
        computeStack->setMaximumSize(QSize(16777215, 43));
        buttonPage = new QWidget();
        buttonPage->setObjectName("buttonPage");
        verticalLayout_3 = new QVBoxLayout(buttonPage);
        verticalLayout_3->setObjectName("verticalLayout_3");
        horizontalLayout_2 = new QHBoxLayout();
        horizontalLayout_2->setSpacing(6);
        horizontalLayout_2->setObjectName("horizontalLayout_2");
        horizontalLayout_2->setSizeConstraint(QLayout::SetMinimumSize);
        ComputeButton = new QPushButton(buttonPage);
        ComputeButton->setObjectName("ComputeButton");

        horizontalLayout_2->addWidget(ComputeButton);

        horizontalSpacer_2 = new QSpacerItem(40, 20, QSizePolicy::Policy::Expanding, QSizePolicy::Policy::Minimum);

        horizontalLayout_2->addItem(horizontalSpacer_2);

        ExportButton = new QPushButton(buttonPage);
        ExportButton->setObjectName("ExportButton");

        horizontalLayout_2->addWidget(ExportButton);

        ClearButton = new QPushButton(buttonPage);
        ClearButton->setObjectName("ClearButton");

        horizontalLayout_2->addWidget(ClearButton);


        verticalLayout_3->addLayout(horizontalLayout_2);

        computeStack->addWidget(buttonPage);
        progressPage = new QWidget();
        progressPage->setObjectName("progressPage");
        verticalLayout_4 = new QVBoxLayout(progressPage);
        verticalLayout_4->setObjectName("verticalLayout_4");
        progressBar = new QProgressBar(progressPage);
        progressBar->setObjectName("progressBar");
        progressBar->setValue(24);

        verticalLayout_4->addWidget(progressBar);

        computeStack->addWidget(progressPage);

        verticalLayout->addWidget(computeStack);

        groupBox = new QGroupBox(EclipseTool);
        groupBox->setObjectName("groupBox");
        verticalLayout_2 = new QVBoxLayout(groupBox);
        verticalLayout_2->setObjectName("verticalLayout_2");
        tableView = new QTableView(groupBox);
        tableView->setObjectName("tableView");

        verticalLayout_2->addWidget(tableView);


        verticalLayout->addWidget(groupBox);


        retranslateUi(EclipseTool);

        computeStack->setCurrentIndex(1);


        QMetaObject::connectSlotsByName(EclipseTool);
    } // setupUi

    void retranslateUi(QFrame *EclipseTool)
    {
        label_2->setText(tr2i18n("Ending on:", nullptr));
        textLabel1->setText(tr2i18n("Between objects:", nullptr));
        label_4->setText(tr2i18n("and", nullptr));
        label_3->setText(tr2i18n("Show eclipses for:", nullptr));
        label->setText(tr2i18n("Starting on:", nullptr));
        LocationButton->setText(tr2i18n("Greenwich, United Kingdom", nullptr));
        ComputeButton->setText(tr2i18n("Compute", nullptr));
        ExportButton->setText(tr2i18n("Export...", nullptr));
        ClearButton->setText(tr2i18n("Clear", nullptr));
        progressBar->setFormat(tr2i18n("%p%", nullptr));
        groupBox->setTitle(tr2i18n("Results", nullptr));
        (void)EclipseTool;
    } // retranslateUi

};

namespace Ui {
    class EclipseTool: public Ui_EclipseTool {};
} // namespace Ui

QT_END_NAMESPACE

#endif // ECLIPSETOOL_H

