/********************************************************************************
** Form generated from reading UI file 'wutdialog.ui'
**
** Created by: Qt User Interface Compiler version 6.11.1
**
** WARNING! All changes made in this file will be lost when recompiling UI file!
********************************************************************************/

#ifndef UI_WUTDIALOG_H
#define UI_WUTDIALOG_H

#include <QtCore/QVariant>
#include <QtWidgets/QApplication>
#include <QtWidgets/QComboBox>
#include <QtWidgets/QDoubleSpinBox>
#include <QtWidgets/QGridLayout>
#include <QtWidgets/QGroupBox>
#include <QtWidgets/QHBoxLayout>
#include <QtWidgets/QLabel>
#include <QtWidgets/QListWidget>
#include <QtWidgets/QPushButton>
#include <QtWidgets/QSpacerItem>
#include <QtWidgets/QVBoxLayout>
#include <QtWidgets/QWidget>
#include <klocalizedstring.h>

QT_BEGIN_NAMESPACE

class Ui_WUTDialog
{
public:
    QVBoxLayout *vboxLayout;
    QGridLayout *gridLayout;
    QLabel *DateLabel;
    QPushButton *DateButton;
    QLabel *LocationLabel;
    QPushButton *LocationButton;
    QLabel *textLabel14;
    QComboBox *EveningMorningBox;
    QLabel *label;
    QHBoxLayout *horizontalLayout;
    QDoubleSpinBox *MagnitudeEdit;
    QGroupBox *groupBox;
    QGridLayout *gridLayout1;
    QLabel *MoonRiseLabel;
    QLabel *NightDurationLabel;
    QLabel *SunSetLabel;
    QLabel *MoonSetLabel;
    QLabel *SunRiseLabel;
    QLabel *MoonIllumLabel;
    QGridLayout *gridLayout2;
    QLabel *textLabel15;
    QLabel *textLabel16;
    QSpacerItem *spacerItem;
    QGroupBox *ObjectBox;
    QVBoxLayout *vboxLayout1;
    QLabel *ObjectRiseLabel;
    QLabel *ObjectTransitLabel;
    QLabel *ObjectSetLabel;
    QSpacerItem *spacerItem1;
    QPushButton *CenterButton;
    QPushButton *DetailButton;
    QPushButton *ObslistButton;
    QListWidget *CategoryListWidget;
    QListWidget *ObjectListWidget;

    void setupUi(QWidget *WUTDialog)
    {
        if (WUTDialog->objectName().isEmpty())
            WUTDialog->setObjectName("WUTDialog");
        WUTDialog->resize(458, 520);
        vboxLayout = new QVBoxLayout(WUTDialog);
        vboxLayout->setObjectName("vboxLayout");
        gridLayout = new QGridLayout();
        gridLayout->setObjectName("gridLayout");
        DateLabel = new QLabel(WUTDialog);
        DateLabel->setObjectName("DateLabel");
        DateLabel->setMinimumSize(QSize(200, 0));
        QFont font;
        font.setFamilies({QString::fromUtf8("Sans Serif")});
        font.setPointSize(9);
        font.setBold(true);
        font.setItalic(false);
        font.setUnderline(false);
        font.setStrikeOut(false);
        DateLabel->setFont(font);

        gridLayout->addWidget(DateLabel, 0, 0, 1, 1);

        DateButton = new QPushButton(WUTDialog);
        DateButton->setObjectName("DateButton");

        gridLayout->addWidget(DateButton, 0, 1, 1, 1);

        LocationLabel = new QLabel(WUTDialog);
        LocationLabel->setObjectName("LocationLabel");
        LocationLabel->setMinimumSize(QSize(200, 0));
        LocationLabel->setFont(font);
        LocationLabel->setFrameShape(QFrame::NoFrame);
        LocationLabel->setFrameShadow(QFrame::Plain);

        gridLayout->addWidget(LocationLabel, 1, 0, 1, 1);

        LocationButton = new QPushButton(WUTDialog);
        LocationButton->setObjectName("LocationButton");

        gridLayout->addWidget(LocationButton, 1, 1, 1, 1);

        textLabel14 = new QLabel(WUTDialog);
        textLabel14->setObjectName("textLabel14");
        QSizePolicy sizePolicy(QSizePolicy::Policy::MinimumExpanding, QSizePolicy::Policy::Preferred);
        sizePolicy.setHorizontalStretch(0);
        sizePolicy.setVerticalStretch(0);
        sizePolicy.setHeightForWidth(textLabel14->sizePolicy().hasHeightForWidth());
        textLabel14->setSizePolicy(sizePolicy);
        textLabel14->setAlignment(Qt::AlignRight|Qt::AlignTrailing|Qt::AlignVCenter);

        gridLayout->addWidget(textLabel14, 2, 0, 1, 1);

        EveningMorningBox = new QComboBox(WUTDialog);
        EveningMorningBox->addItem(QString());
        EveningMorningBox->addItem(QString());
        EveningMorningBox->addItem(QString());
        EveningMorningBox->setObjectName("EveningMorningBox");
        QSizePolicy sizePolicy1(QSizePolicy::Policy::Preferred, QSizePolicy::Policy::Minimum);
        sizePolicy1.setHorizontalStretch(0);
        sizePolicy1.setVerticalStretch(0);
        sizePolicy1.setHeightForWidth(EveningMorningBox->sizePolicy().hasHeightForWidth());
        EveningMorningBox->setSizePolicy(sizePolicy1);

        gridLayout->addWidget(EveningMorningBox, 2, 1, 1, 1);

        label = new QLabel(WUTDialog);
        label->setObjectName("label");
        label->setAlignment(Qt::AlignRight|Qt::AlignTrailing|Qt::AlignVCenter);

        gridLayout->addWidget(label, 3, 0, 1, 1);

        horizontalLayout = new QHBoxLayout();
        horizontalLayout->setObjectName("horizontalLayout");
        MagnitudeEdit = new QDoubleSpinBox(WUTDialog);
        MagnitudeEdit->setObjectName("MagnitudeEdit");
        MagnitudeEdit->setMinimum(-30.000000000000000);
        MagnitudeEdit->setMaximum(30.000000000000000);

        horizontalLayout->addWidget(MagnitudeEdit);


        gridLayout->addLayout(horizontalLayout, 3, 1, 1, 1);


        vboxLayout->addLayout(gridLayout);

        groupBox = new QGroupBox(WUTDialog);
        groupBox->setObjectName("groupBox");
        QSizePolicy sizePolicy2(QSizePolicy::Policy::Preferred, QSizePolicy::Policy::Preferred);
        sizePolicy2.setHorizontalStretch(0);
        sizePolicy2.setVerticalStretch(0);
        sizePolicy2.setHeightForWidth(groupBox->sizePolicy().hasHeightForWidth());
        groupBox->setSizePolicy(sizePolicy2);
        gridLayout1 = new QGridLayout(groupBox);
#ifndef UI_Q_OS_MAC
        gridLayout1->setSpacing(6);
#endif
#ifndef UI_Q_OS_MAC
        gridLayout1->setContentsMargins(9, 9, 9, 9);
#endif
        gridLayout1->setObjectName("gridLayout1");
        MoonRiseLabel = new QLabel(groupBox);
        MoonRiseLabel->setObjectName("MoonRiseLabel");
        sizePolicy2.setHeightForWidth(MoonRiseLabel->sizePolicy().hasHeightForWidth());
        MoonRiseLabel->setSizePolicy(sizePolicy2);
        MoonRiseLabel->setMinimumSize(QSize(0, 20));

        gridLayout1->addWidget(MoonRiseLabel, 0, 1, 1, 1);

        NightDurationLabel = new QLabel(groupBox);
        NightDurationLabel->setObjectName("NightDurationLabel");
        sizePolicy2.setHeightForWidth(NightDurationLabel->sizePolicy().hasHeightForWidth());
        NightDurationLabel->setSizePolicy(sizePolicy2);
        NightDurationLabel->setMinimumSize(QSize(0, 20));

        gridLayout1->addWidget(NightDurationLabel, 2, 0, 1, 1);

        SunSetLabel = new QLabel(groupBox);
        SunSetLabel->setObjectName("SunSetLabel");
        sizePolicy2.setHeightForWidth(SunSetLabel->sizePolicy().hasHeightForWidth());
        SunSetLabel->setSizePolicy(sizePolicy2);
        SunSetLabel->setMinimumSize(QSize(0, 20));

        gridLayout1->addWidget(SunSetLabel, 1, 0, 1, 1);

        MoonSetLabel = new QLabel(groupBox);
        MoonSetLabel->setObjectName("MoonSetLabel");
        sizePolicy2.setHeightForWidth(MoonSetLabel->sizePolicy().hasHeightForWidth());
        MoonSetLabel->setSizePolicy(sizePolicy2);
        MoonSetLabel->setMinimumSize(QSize(0, 20));

        gridLayout1->addWidget(MoonSetLabel, 1, 1, 1, 1);

        SunRiseLabel = new QLabel(groupBox);
        SunRiseLabel->setObjectName("SunRiseLabel");
        sizePolicy2.setHeightForWidth(SunRiseLabel->sizePolicy().hasHeightForWidth());
        SunRiseLabel->setSizePolicy(sizePolicy2);
        SunRiseLabel->setMinimumSize(QSize(0, 20));

        gridLayout1->addWidget(SunRiseLabel, 0, 0, 1, 1);

        MoonIllumLabel = new QLabel(groupBox);
        MoonIllumLabel->setObjectName("MoonIllumLabel");
        sizePolicy2.setHeightForWidth(MoonIllumLabel->sizePolicy().hasHeightForWidth());
        MoonIllumLabel->setSizePolicy(sizePolicy2);
        MoonIllumLabel->setMinimumSize(QSize(0, 20));

        gridLayout1->addWidget(MoonIllumLabel, 2, 1, 1, 1);


        vboxLayout->addWidget(groupBox);

        gridLayout2 = new QGridLayout();
        gridLayout2->setObjectName("gridLayout2");
        textLabel15 = new QLabel(WUTDialog);
        textLabel15->setObjectName("textLabel15");
        QFont font1;
        font1.setFamilies({QString::fromUtf8("Sans Serif")});
        font1.setPointSize(10);
        font1.setBold(true);
        font1.setItalic(false);
        font1.setUnderline(false);
        font1.setStrikeOut(false);
        textLabel15->setFont(font1);

        gridLayout2->addWidget(textLabel15, 0, 0, 1, 1);

        textLabel16 = new QLabel(WUTDialog);
        textLabel16->setObjectName("textLabel16");
        textLabel16->setFont(font1);

        gridLayout2->addWidget(textLabel16, 0, 1, 1, 1);

        spacerItem = new QSpacerItem(191, 21, QSizePolicy::Policy::Expanding, QSizePolicy::Policy::Minimum);

        gridLayout2->addItem(spacerItem, 0, 2, 1, 1);

        ObjectBox = new QGroupBox(WUTDialog);
        ObjectBox->setObjectName("ObjectBox");
        vboxLayout1 = new QVBoxLayout(ObjectBox);
#ifndef UI_Q_OS_MAC
        vboxLayout1->setSpacing(6);
#endif
#ifndef UI_Q_OS_MAC
        vboxLayout1->setContentsMargins(9, 9, 9, 9);
#endif
        vboxLayout1->setObjectName("vboxLayout1");
        ObjectRiseLabel = new QLabel(ObjectBox);
        ObjectRiseLabel->setObjectName("ObjectRiseLabel");
        ObjectRiseLabel->setAlignment(Qt::AlignVCenter);

        vboxLayout1->addWidget(ObjectRiseLabel);

        ObjectTransitLabel = new QLabel(ObjectBox);
        ObjectTransitLabel->setObjectName("ObjectTransitLabel");
        ObjectTransitLabel->setAlignment(Qt::AlignVCenter);

        vboxLayout1->addWidget(ObjectTransitLabel);

        ObjectSetLabel = new QLabel(ObjectBox);
        ObjectSetLabel->setObjectName("ObjectSetLabel");
        ObjectSetLabel->setAlignment(Qt::AlignVCenter);

        vboxLayout1->addWidget(ObjectSetLabel);

        spacerItem1 = new QSpacerItem(20, 20, QSizePolicy::Policy::Minimum, QSizePolicy::Policy::Expanding);

        vboxLayout1->addItem(spacerItem1);

        CenterButton = new QPushButton(ObjectBox);
        CenterButton->setObjectName("CenterButton");

        vboxLayout1->addWidget(CenterButton);

        DetailButton = new QPushButton(ObjectBox);
        DetailButton->setObjectName("DetailButton");

        vboxLayout1->addWidget(DetailButton);

        ObslistButton = new QPushButton(ObjectBox);
        ObslistButton->setObjectName("ObslistButton");

        vboxLayout1->addWidget(ObslistButton);


        gridLayout2->addWidget(ObjectBox, 1, 2, 1, 1);

        CategoryListWidget = new QListWidget(WUTDialog);
        CategoryListWidget->setObjectName("CategoryListWidget");
        sizePolicy2.setHeightForWidth(CategoryListWidget->sizePolicy().hasHeightForWidth());
        CategoryListWidget->setSizePolicy(sizePolicy2);

        gridLayout2->addWidget(CategoryListWidget, 1, 0, 1, 1);

        ObjectListWidget = new QListWidget(WUTDialog);
        ObjectListWidget->setObjectName("ObjectListWidget");
        sizePolicy2.setHeightForWidth(ObjectListWidget->sizePolicy().hasHeightForWidth());
        ObjectListWidget->setSizePolicy(sizePolicy2);

        gridLayout2->addWidget(ObjectListWidget, 1, 1, 1, 1);


        vboxLayout->addLayout(gridLayout2);


        retranslateUi(WUTDialog);

        QMetaObject::connectSlotsByName(WUTDialog);
    } // setupUi

    void retranslateUi(QWidget *WUTDialog)
    {
        DateLabel->setText(tr2i18n("The night of DATE", nullptr));
#if QT_CONFIG(tooltip)
        DateButton->setToolTip(tr2i18n("Choose a new date", nullptr));
#endif // QT_CONFIG(tooltip)
#if QT_CONFIG(whatsthis)
        DateButton->setWhatsThis(tr2i18n("Press this button to select a new date for the \"What's up Tonight\" tool.  Note that the date of the main window is not changed.", nullptr));
#endif // QT_CONFIG(whatsthis)
        DateButton->setText(tr2i18n("Change Date...", nullptr));
        LocationLabel->setText(tr2i18n("at LOCATION", nullptr));
#if QT_CONFIG(tooltip)
        LocationButton->setToolTip(tr2i18n("Choose a new geographic location", nullptr));
#endif // QT_CONFIG(tooltip)
#if QT_CONFIG(whatsthis)
        LocationButton->setWhatsThis(tr2i18n("Press this button to select a new geographic location for the \"What's up Tonight\" tool.  Note that the location of the main window is not changed.", nullptr));
#endif // QT_CONFIG(whatsthis)
        LocationButton->setText(tr2i18n("Change Location...", nullptr));
        textLabel14->setText(tr2i18n("Show objects which are up:", nullptr));
        EveningMorningBox->setItemText(0, tr2i18n("In the Evening", nullptr));
        EveningMorningBox->setItemText(1, tr2i18n("In the Morning", nullptr));
        EveningMorningBox->setItemText(2, tr2i18n("Any Time Tonight", nullptr));

#if QT_CONFIG(tooltip)
        EveningMorningBox->setToolTip(tr2i18n("Choose time interval", nullptr));
#endif // QT_CONFIG(tooltip)
#if QT_CONFIG(whatsthis)
        EveningMorningBox->setWhatsThis(tr2i18n("By default, the \"What's up Tonight\" tool displays all objects which are above the horizon between sunset and midnight (i.e., \"in the evening\").  You can also choose to show objects which are up between midnight and dawn (i.e., \"in the morning\"), or objects which are up at any time between sunset and sunrise (i.e., \"any time tonight\")", nullptr));
#endif // QT_CONFIG(whatsthis)
        label->setText(tr2i18n("Show objects brighter than magnitude:", nullptr));
        groupBox->setTitle(tr2i18n("Almanac", nullptr));
#if QT_CONFIG(tooltip)
        MoonRiseLabel->setToolTip(tr2i18n("Time of moon rise", nullptr));
#endif // QT_CONFIG(tooltip)
#if QT_CONFIG(whatsthis)
        MoonRiseLabel->setWhatsThis(tr2i18n("Displays the time at which the moon rises on the selected date.", nullptr));
#endif // QT_CONFIG(whatsthis)
        MoonRiseLabel->setText(tr2i18n("Moon rise:  13:19", nullptr));
#if QT_CONFIG(tooltip)
        NightDurationLabel->setToolTip(tr2i18n("Duration of night for selected date", nullptr));
#endif // QT_CONFIG(tooltip)
#if QT_CONFIG(whatsthis)
        NightDurationLabel->setWhatsThis(tr2i18n("Displays the duration between sunset and sunrise for the selected date.", nullptr));
#endif // QT_CONFIG(whatsthis)
        NightDurationLabel->setText(tr2i18n("Night duration: 11:00 hours", nullptr));
#if QT_CONFIG(tooltip)
        SunSetLabel->setToolTip(tr2i18n("Time of sunset", nullptr));
#endif // QT_CONFIG(tooltip)
#if QT_CONFIG(whatsthis)
        SunSetLabel->setWhatsThis(tr2i18n("Displays the time of sunset for the selected date.", nullptr));
#endif // QT_CONFIG(whatsthis)
        SunSetLabel->setText(tr2i18n("Sunset:  19:15", nullptr));
#if QT_CONFIG(tooltip)
        MoonSetLabel->setToolTip(tr2i18n("Time of moon set", nullptr));
#endif // QT_CONFIG(tooltip)
#if QT_CONFIG(whatsthis)
        MoonSetLabel->setWhatsThis(tr2i18n("Displays the time at which the moon sets on the selected date.", nullptr));
#endif // QT_CONFIG(whatsthis)
        MoonSetLabel->setText(tr2i18n("Moon set: 04:27 ", nullptr));
#if QT_CONFIG(tooltip)
        SunRiseLabel->setToolTip(tr2i18n("Time of sunrise", nullptr));
#endif // QT_CONFIG(tooltip)
#if QT_CONFIG(whatsthis)
        SunRiseLabel->setWhatsThis(tr2i18n("Displays the time of sunrise for the selected date.", nullptr));
#endif // QT_CONFIG(whatsthis)
        SunRiseLabel->setText(tr2i18n("Sunrise:  07:15", nullptr));
#if QT_CONFIG(tooltip)
        MoonIllumLabel->setToolTip(tr2i18n("Moon's illumination fraction", nullptr));
#endif // QT_CONFIG(tooltip)
#if QT_CONFIG(whatsthis)
        MoonIllumLabel->setWhatsThis(tr2i18n("Displays the illumination fraction of the Moon for the selected date.", nullptr));
#endif // QT_CONFIG(whatsthis)
        MoonIllumLabel->setText(tr2i18n("Moon illum: 42%", nullptr));
        textLabel15->setText(tr2i18n("Select a category:", nullptr));
        textLabel16->setText(tr2i18n("Matching objects:", nullptr));
        ObjectBox->setTitle(tr2i18n("Object Name", nullptr));
#if QT_CONFIG(whatsthis)
        ObjectRiseLabel->setWhatsThis(tr2i18n("Displays the time at which the highlighted object rises above the horizon on the selected date.", nullptr));
#endif // QT_CONFIG(whatsthis)
        ObjectRiseLabel->setText(tr2i18n("Rises at:  22:12", nullptr));
#if QT_CONFIG(whatsthis)
        ObjectTransitLabel->setWhatsThis(tr2i18n("Displays the time at which the highlighted object transits across the local meridian on the selected date.", nullptr));
#endif // QT_CONFIG(whatsthis)
        ObjectTransitLabel->setText(tr2i18n("Transits at:  03:45", nullptr));
#if QT_CONFIG(whatsthis)
        ObjectSetLabel->setWhatsThis(tr2i18n("Displays the time at which the highlighted object sets below the horizon on the selected date.", nullptr));
#endif // QT_CONFIG(whatsthis)
        ObjectSetLabel->setText(tr2i18n("Sets at:  08:22", nullptr));
#if QT_CONFIG(tooltip)
        CenterButton->setToolTip(tr2i18n("Center this object in the sky display", nullptr));
#endif // QT_CONFIG(tooltip)
#if QT_CONFIG(whatsthis)
        CenterButton->setWhatsThis(tr2i18n("Center the sky display on this object, and begin tracking it.  Equivalent to the \"Center and Track\" item in the popup menu.", nullptr));
#endif // QT_CONFIG(whatsthis)
        CenterButton->setText(tr2i18n("Center Object", nullptr));
#if QT_CONFIG(tooltip)
        DetailButton->setToolTip(tr2i18n("Open the Object Details window", nullptr));
#endif // QT_CONFIG(tooltip)
#if QT_CONFIG(whatsthis)
        DetailButton->setWhatsThis(tr2i18n("Open the Details window for the highlighted object.", nullptr));
#endif // QT_CONFIG(whatsthis)
        DetailButton->setText(tr2i18n("Object Details...", nullptr));
#if QT_CONFIG(tooltip)
        ObslistButton->setToolTip(tr2i18n("Adds the selected object to the Observing list", nullptr));
#endif // QT_CONFIG(tooltip)
#if QT_CONFIG(whatsthis)
        ObslistButton->setWhatsThis(tr2i18n("Open the Details window for the highlighted object.", nullptr));
#endif // QT_CONFIG(whatsthis)
        ObslistButton->setText(tr2i18n("Add to List", nullptr));
        (void)WUTDialog;
    } // retranslateUi

};

namespace Ui {
    class WUTDialog: public Ui_WUTDialog {};
} // namespace Ui

QT_END_NAMESPACE

#endif // WUTDIALOG_H

