/********************************************************************************
** Form generated from reading UI file 'opships.ui'
**
** Created by: Qt User Interface Compiler version 6.11.1
**
** WARNING! All changes made in this file will be lost when recompiling UI file!
********************************************************************************/

#ifndef UI_OPSHIPS_H
#define UI_OPSHIPS_H

#include <QtCore/QVariant>
#include <QtWidgets/QApplication>
#include <QtWidgets/QHBoxLayout>
#include <QtWidgets/QLabel>
#include <QtWidgets/QLineEdit>
#include <QtWidgets/QListWidget>
#include <QtWidgets/QPushButton>
#include <QtWidgets/QSpacerItem>
#include <QtWidgets/QTextEdit>
#include <QtWidgets/QVBoxLayout>
#include <QtWidgets/QWidget>
#include <klocalizedstring.h>

QT_BEGIN_NAMESPACE

class Ui_OpsHIPS
{
public:
    QVBoxLayout *verticalLayout;
    QHBoxLayout *horizontalLayout_3;
    QVBoxLayout *verticalLayout_3;
    QLineEdit *filterEdit;
    QListWidget *sourcesList;
    QVBoxLayout *verticalLayout_2;
    QHBoxLayout *horizontalLayout;
    QLabel *sourceImage;
    QTextEdit *sourceDescription;
    QHBoxLayout *horizontalLayout_2;
    QSpacerItem *horizontalSpacer;
    QPushButton *refreshSourceB;

    void setupUi(QWidget *OpsHIPS)
    {
        if (OpsHIPS->objectName().isEmpty())
            OpsHIPS->setObjectName("OpsHIPS");
        OpsHIPS->resize(787, 504);
        OpsHIPS->setAutoFillBackground(false);
        OpsHIPS->setStyleSheet(QString::fromUtf8(""));
        verticalLayout = new QVBoxLayout(OpsHIPS);
        verticalLayout->setSpacing(3);
        verticalLayout->setObjectName("verticalLayout");
        verticalLayout->setContentsMargins(3, 3, 3, 3);
        horizontalLayout_3 = new QHBoxLayout();
        horizontalLayout_3->setSpacing(3);
        horizontalLayout_3->setObjectName("horizontalLayout_3");
        verticalLayout_3 = new QVBoxLayout();
        verticalLayout_3->setSpacing(3);
        verticalLayout_3->setObjectName("verticalLayout_3");
        filterEdit = new QLineEdit(OpsHIPS);
        filterEdit->setObjectName("filterEdit");
        filterEdit->setClearButtonEnabled(true);

        verticalLayout_3->addWidget(filterEdit);

        sourcesList = new QListWidget(OpsHIPS);
        sourcesList->setObjectName("sourcesList");

        verticalLayout_3->addWidget(sourcesList);


        horizontalLayout_3->addLayout(verticalLayout_3);

        verticalLayout_2 = new QVBoxLayout();
        verticalLayout_2->setSpacing(3);
        verticalLayout_2->setObjectName("verticalLayout_2");
        horizontalLayout = new QHBoxLayout();
        horizontalLayout->setSpacing(3);
        horizontalLayout->setObjectName("horizontalLayout");
        sourceImage = new QLabel(OpsHIPS);
        sourceImage->setObjectName("sourceImage");
        sourceImage->setMinimumSize(QSize(256, 256));
        sourceImage->setAutoFillBackground(false);
        sourceImage->setStyleSheet(QString::fromUtf8("background-color: qlineargradient(x1: 0, y1: 0, x2: 0, y2: 1,\n"
"                                      stop: 0 rgba(128, 128, 128, 128), stop: 1 rgba(0, 0,0, 128));"));
        sourceImage->setFrameShape(QFrame::Box);
        sourceImage->setPixmap(QPixmap(QString::fromUtf8(":/images/noimage.png")));
        sourceImage->setScaledContents(false);
        sourceImage->setAlignment(Qt::AlignCenter);

        horizontalLayout->addWidget(sourceImage);


        verticalLayout_2->addLayout(horizontalLayout);

        sourceDescription = new QTextEdit(OpsHIPS);
        sourceDescription->setObjectName("sourceDescription");
        sourceDescription->setReadOnly(true);

        verticalLayout_2->addWidget(sourceDescription);


        horizontalLayout_3->addLayout(verticalLayout_2);

        horizontalLayout_3->setStretch(0, 2);
        horizontalLayout_3->setStretch(1, 3);

        verticalLayout->addLayout(horizontalLayout_3);

        horizontalLayout_2 = new QHBoxLayout();
        horizontalLayout_2->setObjectName("horizontalLayout_2");
        horizontalSpacer = new QSpacerItem(40, 20, QSizePolicy::Policy::Expanding, QSizePolicy::Policy::Minimum);

        horizontalLayout_2->addItem(horizontalSpacer);

        refreshSourceB = new QPushButton(OpsHIPS);
        refreshSourceB->setObjectName("refreshSourceB");

        horizontalLayout_2->addWidget(refreshSourceB);


        verticalLayout->addLayout(horizontalLayout_2);


        retranslateUi(OpsHIPS);

        QMetaObject::connectSlotsByName(OpsHIPS);
    } // setupUi

    void retranslateUi(QWidget *OpsHIPS)
    {
        filterEdit->setPlaceholderText(tr2i18n("Search...", nullptr));
        sourceImage->setText(QString());
        refreshSourceB->setText(tr2i18n("Refresh", nullptr));
        (void)OpsHIPS;
    } // retranslateUi

};

namespace Ui {
    class OpsHIPS: public Ui_OpsHIPS {};
} // namespace Ui

QT_END_NAMESPACE

#endif // OPSHIPS_H

