/********************************************************************************
** Form generated from reading UI file 'streamform.ui'
**
** Created by: Qt User Interface Compiler version 6.11.1
**
** WARNING! All changes made in this file will be lost when recompiling UI file!
********************************************************************************/

#ifndef UI_STREAMFORM_H
#define UI_STREAMFORM_H

#include <QtCore/QVariant>
#include <QtGui/QIcon>
#include <QtWidgets/QApplication>
#include <QtWidgets/QComboBox>
#include <QtWidgets/QDoubleSpinBox>
#include <QtWidgets/QFrame>
#include <QtWidgets/QGridLayout>
#include <QtWidgets/QHBoxLayout>
#include <QtWidgets/QLabel>
#include <QtWidgets/QPushButton>
#include <QtWidgets/QSlider>
#include <QtWidgets/QSpacerItem>
#include <QtWidgets/QVBoxLayout>
#include <QtWidgets/QWidget>
#include <klocalizedstring.h>
#include "indi/videowg.h"

QT_BEGIN_NAMESPACE

class Ui_streamForm
{
public:
    QVBoxLayout *verticalLayout;
    QHBoxLayout *horizontalLayout;
    QPushButton *recordB;
    QPushButton *optionsB;
    QPushButton *resetFrameB;
    QFrame *line;
    QPushButton *debayerB;
    QPushButton *collimationB;
    QPushButton *collimationOptionsB;
    QComboBox *zoomLevelCombo;
    QGridLayout *zoomViewGridLayout;
    QSlider *NSSlider;
    QSlider *WESlider;
    QLabel *handLabel;
    QSpacerItem *horizontalSpacer;
    QLabel *label_2;
    QDoubleSpinBox *targetFrameDurationSpin;
    QPushButton *changeFPSB;
    QLabel *label;
    QLabel *avgFPS;
    VideoWG *videoFrame;

    void setupUi(QWidget *streamForm)
    {
        if (streamForm->objectName().isEmpty())
            streamForm->setObjectName("streamForm");
        streamForm->resize(565, 285);
        QSizePolicy sizePolicy(QSizePolicy::Policy::Expanding, QSizePolicy::Policy::Expanding);
        sizePolicy.setHorizontalStretch(0);
        sizePolicy.setVerticalStretch(0);
        sizePolicy.setHeightForWidth(streamForm->sizePolicy().hasHeightForWidth());
        streamForm->setSizePolicy(sizePolicy);
        verticalLayout = new QVBoxLayout(streamForm);
        verticalLayout->setSpacing(3);
        verticalLayout->setObjectName("verticalLayout");
        verticalLayout->setContentsMargins(3, 3, 3, 3);
        horizontalLayout = new QHBoxLayout();
        horizontalLayout->setSpacing(3);
        horizontalLayout->setObjectName("horizontalLayout");
        recordB = new QPushButton(streamForm);
        recordB->setObjectName("recordB");
        recordB->setMinimumSize(QSize(32, 32));
        recordB->setMaximumSize(QSize(64, 64));
        recordB->setIconSize(QSize(32, 32));

        horizontalLayout->addWidget(recordB);

        optionsB = new QPushButton(streamForm);
        optionsB->setObjectName("optionsB");
        optionsB->setMinimumSize(QSize(32, 32));
        optionsB->setMaximumSize(QSize(64, 64));
        optionsB->setIconSize(QSize(32, 32));

        horizontalLayout->addWidget(optionsB);

        resetFrameB = new QPushButton(streamForm);
        resetFrameB->setObjectName("resetFrameB");
        resetFrameB->setMinimumSize(QSize(32, 32));
        resetFrameB->setMaximumSize(QSize(64, 64));
        resetFrameB->setIconSize(QSize(32, 32));

        horizontalLayout->addWidget(resetFrameB);

        line = new QFrame(streamForm);
        line->setObjectName("line");
        line->setFrameShape(QFrame::Shape::VLine);
        line->setFrameShadow(QFrame::Shadow::Sunken);

        horizontalLayout->addWidget(line);

        debayerB = new QPushButton(streamForm);
        debayerB->setObjectName("debayerB");
        debayerB->setMinimumSize(QSize(32, 32));
        debayerB->setIconSize(QSize(32, 32));

        horizontalLayout->addWidget(debayerB);

        collimationB = new QPushButton(streamForm);
        collimationB->setObjectName("collimationB");
        collimationB->setMinimumSize(QSize(32, 32));
        collimationB->setIconSize(QSize(32, 32));

        horizontalLayout->addWidget(collimationB);

        collimationOptionsB = new QPushButton(streamForm);
        collimationOptionsB->setObjectName("collimationOptionsB");
        collimationOptionsB->setMinimumSize(QSize(32, 32));
        collimationOptionsB->setMaximumSize(QSize(64, 64));
        collimationOptionsB->setIconSize(QSize(32, 32));

        horizontalLayout->addWidget(collimationOptionsB);

        zoomLevelCombo = new QComboBox(streamForm);
        zoomLevelCombo->addItem(QString());
        zoomLevelCombo->addItem(QString());
        zoomLevelCombo->addItem(QString());
        zoomLevelCombo->setObjectName("zoomLevelCombo");
        QSizePolicy sizePolicy1(QSizePolicy::Policy::Minimum, QSizePolicy::Policy::Preferred);
        sizePolicy1.setHorizontalStretch(0);
        sizePolicy1.setVerticalStretch(0);
        sizePolicy1.setHeightForWidth(zoomLevelCombo->sizePolicy().hasHeightForWidth());
        zoomLevelCombo->setSizePolicy(sizePolicy1);

        horizontalLayout->addWidget(zoomLevelCombo);

        zoomViewGridLayout = new QGridLayout();
        zoomViewGridLayout->setSpacing(3);
        zoomViewGridLayout->setObjectName("zoomViewGridLayout");
        NSSlider = new QSlider(streamForm);
        NSSlider->setObjectName("NSSlider");
        NSSlider->setEnabled(false);
        QSizePolicy sizePolicy2(QSizePolicy::Policy::Expanding, QSizePolicy::Policy::Fixed);
        sizePolicy2.setHorizontalStretch(0);
        sizePolicy2.setVerticalStretch(0);
        sizePolicy2.setHeightForWidth(NSSlider->sizePolicy().hasHeightForWidth());
        NSSlider->setSizePolicy(sizePolicy2);
        NSSlider->setMinimumSize(QSize(100, 0));
        NSSlider->setOrientation(Qt::Horizontal);

        zoomViewGridLayout->addWidget(NSSlider, 1, 1, 1, 1);

        WESlider = new QSlider(streamForm);
        WESlider->setObjectName("WESlider");
        WESlider->setEnabled(false);
        sizePolicy2.setHeightForWidth(WESlider->sizePolicy().hasHeightForWidth());
        WESlider->setSizePolicy(sizePolicy2);
        WESlider->setMinimumSize(QSize(100, 0));
        WESlider->setOrientation(Qt::Horizontal);

        zoomViewGridLayout->addWidget(WESlider, 0, 1, 1, 1);

        handLabel = new QLabel(streamForm);
        handLabel->setObjectName("handLabel");
        handLabel->setEnabled(false);
        handLabel->setMinimumSize(QSize(32, 32));

        zoomViewGridLayout->addWidget(handLabel, 0, 0, 2, 1);


        horizontalLayout->addLayout(zoomViewGridLayout);

        horizontalSpacer = new QSpacerItem(40, 20, QSizePolicy::Policy::Preferred, QSizePolicy::Policy::Minimum);

        horizontalLayout->addItem(horizontalSpacer);

        label_2 = new QLabel(streamForm);
        label_2->setObjectName("label_2");

        horizontalLayout->addWidget(label_2);

        targetFrameDurationSpin = new QDoubleSpinBox(streamForm);
        targetFrameDurationSpin->setObjectName("targetFrameDurationSpin");
        targetFrameDurationSpin->setMinimumSize(QSize(0, 32));
        targetFrameDurationSpin->setDecimals(6);
        targetFrameDurationSpin->setMinimum(0.000001000000000);
        targetFrameDurationSpin->setMaximum(5.000000000000000);
        targetFrameDurationSpin->setSingleStep(0.001000000000000);
        targetFrameDurationSpin->setValue(0.100000000000000);

        horizontalLayout->addWidget(targetFrameDurationSpin);

        changeFPSB = new QPushButton(streamForm);
        changeFPSB->setObjectName("changeFPSB");
        changeFPSB->setMinimumSize(QSize(32, 32));
        QIcon icon;
        QString iconThemeName = QString::fromUtf8("view-refresh");
        if (QIcon::hasThemeIcon(iconThemeName)) {
            icon = QIcon::fromTheme(iconThemeName);
        } else {
            icon.addFile(QString::fromUtf8("."), QSize(), QIcon::Mode::Normal, QIcon::State::Off);
        }
        changeFPSB->setIcon(icon);
        changeFPSB->setIconSize(QSize(24, 24));

        horizontalLayout->addWidget(changeFPSB);

        label = new QLabel(streamForm);
        label->setObjectName("label");

        horizontalLayout->addWidget(label);

        avgFPS = new QLabel(streamForm);
        avgFPS->setObjectName("avgFPS");
        avgFPS->setMinimumSize(QSize(50, 0));
        avgFPS->setStyleSheet(QString::fromUtf8("font-weight:bold;"));
        avgFPS->setFrameShape(QFrame::NoFrame);
        avgFPS->setFrameShadow(QFrame::Plain);
        avgFPS->setAlignment(Qt::AlignCenter);

        horizontalLayout->addWidget(avgFPS);


        verticalLayout->addLayout(horizontalLayout);

        videoFrame = new VideoWG(streamForm);
        videoFrame->setObjectName("videoFrame");
        sizePolicy.setHeightForWidth(videoFrame->sizePolicy().hasHeightForWidth());
        videoFrame->setSizePolicy(sizePolicy);
        videoFrame->setMinimumSize(QSize(320, 240));
        videoFrame->setAutoFillBackground(false);
        videoFrame->setStyleSheet(QString::fromUtf8("background-color:black;"));
        videoFrame->setAlignment(Qt::AlignCenter);

        verticalLayout->addWidget(videoFrame);

        QWidget::setTabOrder(recordB, optionsB);
        QWidget::setTabOrder(optionsB, resetFrameB);
        QWidget::setTabOrder(resetFrameB, debayerB);
        QWidget::setTabOrder(debayerB, zoomLevelCombo);
        QWidget::setTabOrder(zoomLevelCombo, WESlider);
        QWidget::setTabOrder(WESlider, NSSlider);
        QWidget::setTabOrder(NSSlider, targetFrameDurationSpin);
        QWidget::setTabOrder(targetFrameDurationSpin, changeFPSB);

        retranslateUi(streamForm);

        changeFPSB->setDefault(true);


        QMetaObject::connectSlotsByName(streamForm);
    } // setupUi

    void retranslateUi(QWidget *streamForm)
    {
        streamForm->setWindowTitle(tr2i18n("Video Stream", nullptr));
#if QT_CONFIG(tooltip)
        recordB->setToolTip(tr2i18n("Start Recording", nullptr));
#endif // QT_CONFIG(tooltip)
#if QT_CONFIG(whatsthis)
        recordB->setWhatsThis(QString());
#endif // QT_CONFIG(whatsthis)
#if QT_CONFIG(tooltip)
        optionsB->setToolTip(tr2i18n("Recording Options...", nullptr));
#endif // QT_CONFIG(tooltip)
#if QT_CONFIG(whatsthis)
        optionsB->setWhatsThis(QString());
#endif // QT_CONFIG(whatsthis)
#if QT_CONFIG(tooltip)
        resetFrameB->setToolTip(tr2i18n("Reset Frame", nullptr));
#endif // QT_CONFIG(tooltip)
#if QT_CONFIG(whatsthis)
        resetFrameB->setWhatsThis(QString());
#endif // QT_CONFIG(whatsthis)
#if QT_CONFIG(tooltip)
        debayerB->setToolTip(tr2i18n("Toggle Debayer", nullptr));
#endif // QT_CONFIG(tooltip)
        debayerB->setText(QString());
#if QT_CONFIG(tooltip)
        collimationB->setToolTip(tr2i18n("Toggle Collimation Overlay", nullptr));
#endif // QT_CONFIG(tooltip)
        collimationB->setText(QString());
#if QT_CONFIG(tooltip)
        collimationOptionsB->setToolTip(tr2i18n("Collimation Overlay Options...", nullptr));
#endif // QT_CONFIG(tooltip)
#if QT_CONFIG(whatsthis)
        collimationOptionsB->setWhatsThis(QString());
#endif // QT_CONFIG(whatsthis)
        zoomLevelCombo->setItemText(0, tr2i18n("1x", nullptr));
        zoomLevelCombo->setItemText(1, tr2i18n("5x", nullptr));
        zoomLevelCombo->setItemText(2, tr2i18n("10x", nullptr));

#if QT_CONFIG(tooltip)
        zoomLevelCombo->setToolTip(tr2i18n("Zoom level", nullptr));
#endif // QT_CONFIG(tooltip)
#if QT_CONFIG(tooltip)
        NSSlider->setToolTip(tr2i18n("Move zoomed view Up/Down", nullptr));
#endif // QT_CONFIG(tooltip)
#if QT_CONFIG(tooltip)
        WESlider->setToolTip(tr2i18n("Move zoomed view Left/Right", nullptr));
#endif // QT_CONFIG(tooltip)
        handLabel->setText(QString());
#if QT_CONFIG(tooltip)
        label_2->setToolTip(tr2i18n("Video frame duration in seconds", nullptr));
#endif // QT_CONFIG(tooltip)
        label_2->setText(tr2i18n("Frame(s):", nullptr));
#if QT_CONFIG(tooltip)
        targetFrameDurationSpin->setToolTip(tr2i18n("Video frame duration in seconds", nullptr));
#endif // QT_CONFIG(tooltip)
#if QT_CONFIG(tooltip)
        changeFPSB->setToolTip(tr2i18n("Apply FPS and restart stream", nullptr));
#endif // QT_CONFIG(tooltip)
        changeFPSB->setText(QString());
        label->setText(tr2i18n("FPS:", nullptr));
#if QT_CONFIG(tooltip)
        avgFPS->setToolTip(tr2i18n("Average FPS", nullptr));
#endif // QT_CONFIG(tooltip)
        avgFPS->setText(tr2i18n("--", nullptr));
    } // retranslateUi

};

namespace Ui {
    class streamForm: public Ui_streamForm {};
} // namespace Ui

QT_END_NAMESPACE

#endif // STREAMFORM_H

