/********************************************************************************
** Form generated from reading UI file 'modcalcgalcoord.ui'
**
** Created by: Qt User Interface Compiler version 6.11.1
**
** WARNING! All changes made in this file will be lost when recompiling UI file!
********************************************************************************/

#ifndef UI_MODCALCGALCOORD_H
#define UI_MODCALCGALCOORD_H

#include <QtCore/QVariant>
#include <QtWidgets/QApplication>
#include <QtWidgets/QCheckBox>
#include <QtWidgets/QGridLayout>
#include <QtWidgets/QGroupBox>
#include <QtWidgets/QHBoxLayout>
#include <QtWidgets/QLabel>
#include <QtWidgets/QLineEdit>
#include <QtWidgets/QPushButton>
#include <QtWidgets/QRadioButton>
#include <QtWidgets/QSpacerItem>
#include <QtWidgets/QTabWidget>
#include <QtWidgets/QVBoxLayout>
#include <QtWidgets/QWidget>
#include <klocalizedstring.h>
#include "kurlrequester.h"
#include "widgets/dmsbox.h"

QT_BEGIN_NAMESPACE

class Ui_modCalcGalCoordDlg
{
public:
    QVBoxLayout *vboxLayout;
    QTabWidget *tabWidget;
    QWidget *interact;
    QVBoxLayout *vboxLayout1;
    QHBoxLayout *hboxLayout;
    QGroupBox *groupBox_2;
    QGridLayout *gridLayout;
    QLabel *decLabel;
    QLabel *raLabel;
    dmsBox *RA;
    dmsBox *Dec;
    QPushButton *ObjectButton;
    QGroupBox *groupBox_3alactic;
    QGridLayout *gridLayout1;
    QSpacerItem *spacerItem;
    QLabel *label_2;
    QLabel *label;
    dmsBox *GalLongitude;
    dmsBox *GalLatitude;
    QSpacerItem *spacerItem1;
    QWidget *batch;
    QVBoxLayout *vboxLayout2;
    QGroupBox *groupBox_3;
    QGridLayout *gridLayout2;
    QSpacerItem *spacerItem2;
    QCheckBox *epochCheckBatch;
    QLineEdit *epochBoxBatch;
    QCheckBox *galLongCheckBatch;
    QCheckBox *galLatCheckBatch;
    QCheckBox *decCheckBatch;
    QCheckBox *raCheckBatch;
    dmsBox *raBoxBatch;
    dmsBox *decBoxBatch;
    dmsBox *galLongBoxBatch;
    dmsBox *galLatBoxBatch;
    QGroupBox *groupBox_4;
    QHBoxLayout *hboxLayout1;
    QRadioButton *allRadioBatch;
    QRadioButton *inputRadioBatch;
    QGroupBox *groupBox_5;
    QGridLayout *gridLayout3;
    KUrlRequester *OutputFileBoxBatch;
    KUrlRequester *InputFileBoxBatch;
    QLabel *label_4;
    QLabel *label_3;
    QHBoxLayout *hboxLayout2;
    QSpacerItem *spacerItem3;
    QPushButton *runButtonBatch;
    QSpacerItem *spacerItem4;
    QSpacerItem *spacerItem5;

    void setupUi(QWidget *modCalcGalCoordDlg)
    {
        if (modCalcGalCoordDlg->objectName().isEmpty())
            modCalcGalCoordDlg->setObjectName("modCalcGalCoordDlg");
        modCalcGalCoordDlg->resize(576, 487);
        vboxLayout = new QVBoxLayout(modCalcGalCoordDlg);
#ifndef UI_Q_OS_MAC
        vboxLayout->setSpacing(6);
#endif
#ifndef UI_Q_OS_MAC
        vboxLayout->setContentsMargins(9, 9, 9, 9);
#endif
        vboxLayout->setObjectName("vboxLayout");
        tabWidget = new QTabWidget(modCalcGalCoordDlg);
        tabWidget->setObjectName("tabWidget");
        interact = new QWidget();
        interact->setObjectName("interact");
        interact->setGeometry(QRect(0, 0, 546, 431));
        vboxLayout1 = new QVBoxLayout(interact);
#ifndef UI_Q_OS_MAC
        vboxLayout1->setSpacing(6);
#endif
        vboxLayout1->setContentsMargins(8, 8, 8, 8);
        vboxLayout1->setObjectName("vboxLayout1");
        hboxLayout = new QHBoxLayout();
#ifndef UI_Q_OS_MAC
        hboxLayout->setSpacing(6);
#endif
#ifndef UI_Q_OS_MAC
        hboxLayout->setContentsMargins(0, 0, 0, 0);
#endif
        hboxLayout->setObjectName("hboxLayout");
        groupBox_2 = new QGroupBox(interact);
        groupBox_2->setObjectName("groupBox_2");
        gridLayout = new QGridLayout(groupBox_2);
#ifndef UI_Q_OS_MAC
        gridLayout->setSpacing(6);
#endif
        gridLayout->setContentsMargins(8, 8, 8, 8);
        gridLayout->setObjectName("gridLayout");
        decLabel = new QLabel(groupBox_2);
        decLabel->setObjectName("decLabel");

        gridLayout->addWidget(decLabel, 1, 0, 1, 1);

        raLabel = new QLabel(groupBox_2);
        raLabel->setObjectName("raLabel");

        gridLayout->addWidget(raLabel, 0, 0, 1, 1);

        RA = new dmsBox(groupBox_2);
        RA->setObjectName("RA");

        gridLayout->addWidget(RA, 0, 1, 1, 1);

        Dec = new dmsBox(groupBox_2);
        Dec->setObjectName("Dec");

        gridLayout->addWidget(Dec, 1, 1, 1, 1);

        ObjectButton = new QPushButton(groupBox_2);
        ObjectButton->setObjectName("ObjectButton");

        gridLayout->addWidget(ObjectButton, 2, 1, 1, 1);


        hboxLayout->addWidget(groupBox_2);

        groupBox_3alactic = new QGroupBox(interact);
        groupBox_3alactic->setObjectName("groupBox_3alactic");
        gridLayout1 = new QGridLayout(groupBox_3alactic);
#ifndef UI_Q_OS_MAC
        gridLayout1->setSpacing(6);
#endif
        gridLayout1->setContentsMargins(8, 8, 8, 8);
        gridLayout1->setObjectName("gridLayout1");
        spacerItem = new QSpacerItem(40, 20, QSizePolicy::Policy::Expanding, QSizePolicy::Policy::Minimum);

        gridLayout1->addItem(spacerItem, 2, 1, 1, 1);

        label_2 = new QLabel(groupBox_3alactic);
        label_2->setObjectName("label_2");

        gridLayout1->addWidget(label_2, 1, 0, 1, 1);

        label = new QLabel(groupBox_3alactic);
        label->setObjectName("label");

        gridLayout1->addWidget(label, 0, 0, 1, 1);

        GalLongitude = new dmsBox(groupBox_3alactic);
        GalLongitude->setObjectName("GalLongitude");

        gridLayout1->addWidget(GalLongitude, 0, 1, 1, 1);

        GalLatitude = new dmsBox(groupBox_3alactic);
        GalLatitude->setObjectName("GalLatitude");

        gridLayout1->addWidget(GalLatitude, 1, 1, 1, 1);


        hboxLayout->addWidget(groupBox_3alactic);


        vboxLayout1->addLayout(hboxLayout);

        spacerItem1 = new QSpacerItem(507, 25, QSizePolicy::Policy::Minimum, QSizePolicy::Policy::Expanding);

        vboxLayout1->addItem(spacerItem1);

        tabWidget->addTab(interact, QString());
        batch = new QWidget();
        batch->setObjectName("batch");
        batch->setGeometry(QRect(0, 0, 100, 30));
        vboxLayout2 = new QVBoxLayout(batch);
#ifndef UI_Q_OS_MAC
        vboxLayout2->setSpacing(6);
#endif
        vboxLayout2->setContentsMargins(8, 8, 8, 8);
        vboxLayout2->setObjectName("vboxLayout2");
        groupBox_3 = new QGroupBox(batch);
        groupBox_3->setObjectName("groupBox_3");
        gridLayout2 = new QGridLayout(groupBox_3);
#ifndef UI_Q_OS_MAC
        gridLayout2->setSpacing(6);
#endif
        gridLayout2->setContentsMargins(8, 8, 8, 8);
        gridLayout2->setObjectName("gridLayout2");
        spacerItem2 = new QSpacerItem(40, 20, QSizePolicy::Policy::Expanding, QSizePolicy::Policy::Minimum);

        gridLayout2->addItem(spacerItem2, 2, 2, 1, 2);

        epochCheckBatch = new QCheckBox(groupBox_3);
        epochCheckBatch->setObjectName("epochCheckBatch");
        epochCheckBatch->setEnabled(true);
        epochCheckBatch->setChecked(false);

        gridLayout2->addWidget(epochCheckBatch, 2, 0, 1, 1);

        epochBoxBatch = new QLineEdit(groupBox_3);
        epochBoxBatch->setObjectName("epochBoxBatch");
        epochBoxBatch->setEnabled(true);
        QSizePolicy sizePolicy(QSizePolicy::Policy::Expanding, QSizePolicy::Policy::Fixed);
        sizePolicy.setHorizontalStretch(0);
        sizePolicy.setVerticalStretch(0);
        sizePolicy.setHeightForWidth(epochBoxBatch->sizePolicy().hasHeightForWidth());
        epochBoxBatch->setSizePolicy(sizePolicy);

        gridLayout2->addWidget(epochBoxBatch, 2, 1, 1, 1);

        galLongCheckBatch = new QCheckBox(groupBox_3);
        galLongCheckBatch->setObjectName("galLongCheckBatch");
        galLongCheckBatch->setEnabled(true);
        galLongCheckBatch->setChecked(false);

        gridLayout2->addWidget(galLongCheckBatch, 0, 2, 1, 1);

        galLatCheckBatch = new QCheckBox(groupBox_3);
        galLatCheckBatch->setObjectName("galLatCheckBatch");
        galLatCheckBatch->setEnabled(true);
        galLatCheckBatch->setChecked(false);

        gridLayout2->addWidget(galLatCheckBatch, 1, 2, 1, 1);

        decCheckBatch = new QCheckBox(groupBox_3);
        decCheckBatch->setObjectName("decCheckBatch");
        decCheckBatch->setChecked(true);

        gridLayout2->addWidget(decCheckBatch, 1, 0, 1, 1);

        raCheckBatch = new QCheckBox(groupBox_3);
        raCheckBatch->setObjectName("raCheckBatch");
        raCheckBatch->setChecked(true);

        gridLayout2->addWidget(raCheckBatch, 0, 0, 1, 1);

        raBoxBatch = new dmsBox(groupBox_3);
        raBoxBatch->setObjectName("raBoxBatch");
        raBoxBatch->setEnabled(false);

        gridLayout2->addWidget(raBoxBatch, 0, 1, 1, 1);

        decBoxBatch = new dmsBox(groupBox_3);
        decBoxBatch->setObjectName("decBoxBatch");
        decBoxBatch->setEnabled(false);

        gridLayout2->addWidget(decBoxBatch, 1, 1, 1, 1);

        galLongBoxBatch = new dmsBox(groupBox_3);
        galLongBoxBatch->setObjectName("galLongBoxBatch");

        gridLayout2->addWidget(galLongBoxBatch, 0, 3, 1, 1);

        galLatBoxBatch = new dmsBox(groupBox_3);
        galLatBoxBatch->setObjectName("galLatBoxBatch");

        gridLayout2->addWidget(galLatBoxBatch, 1, 3, 1, 1);


        vboxLayout2->addWidget(groupBox_3);

        groupBox_4 = new QGroupBox(batch);
        groupBox_4->setObjectName("groupBox_4");
        hboxLayout1 = new QHBoxLayout(groupBox_4);
#ifndef UI_Q_OS_MAC
        hboxLayout1->setSpacing(6);
#endif
        hboxLayout1->setContentsMargins(8, 8, 8, 8);
        hboxLayout1->setObjectName("hboxLayout1");
        allRadioBatch = new QRadioButton(groupBox_4);
        allRadioBatch->setObjectName("allRadioBatch");

        hboxLayout1->addWidget(allRadioBatch);

        inputRadioBatch = new QRadioButton(groupBox_4);
        inputRadioBatch->setObjectName("inputRadioBatch");
        inputRadioBatch->setChecked(true);

        hboxLayout1->addWidget(inputRadioBatch);


        vboxLayout2->addWidget(groupBox_4);

        groupBox_5 = new QGroupBox(batch);
        groupBox_5->setObjectName("groupBox_5");
        gridLayout3 = new QGridLayout(groupBox_5);
#ifndef UI_Q_OS_MAC
        gridLayout3->setSpacing(6);
#endif
        gridLayout3->setContentsMargins(8, 8, 8, 8);
        gridLayout3->setObjectName("gridLayout3");
        OutputFileBoxBatch = new KUrlRequester(groupBox_5);
        OutputFileBoxBatch->setObjectName("OutputFileBoxBatch");

        gridLayout3->addWidget(OutputFileBoxBatch, 1, 1, 1, 1);

        InputFileBoxBatch = new KUrlRequester(groupBox_5);
        InputFileBoxBatch->setObjectName("InputFileBoxBatch");

        gridLayout3->addWidget(InputFileBoxBatch, 0, 1, 1, 1);

        label_4 = new QLabel(groupBox_5);
        label_4->setObjectName("label_4");

        gridLayout3->addWidget(label_4, 1, 0, 1, 1);

        label_3 = new QLabel(groupBox_5);
        label_3->setObjectName("label_3");

        gridLayout3->addWidget(label_3, 0, 0, 1, 1);


        vboxLayout2->addWidget(groupBox_5);

        hboxLayout2 = new QHBoxLayout();
#ifndef UI_Q_OS_MAC
        hboxLayout2->setSpacing(6);
#endif
        hboxLayout2->setContentsMargins(0, 0, 0, 0);
        hboxLayout2->setObjectName("hboxLayout2");
        spacerItem3 = new QSpacerItem(151, 21, QSizePolicy::Policy::Expanding, QSizePolicy::Policy::Minimum);

        hboxLayout2->addItem(spacerItem3);

        runButtonBatch = new QPushButton(batch);
        runButtonBatch->setObjectName("runButtonBatch");
        QSizePolicy sizePolicy1(QSizePolicy::Policy::Expanding, QSizePolicy::Policy::Preferred);
        sizePolicy1.setHorizontalStretch(0);
        sizePolicy1.setVerticalStretch(0);
        sizePolicy1.setHeightForWidth(runButtonBatch->sizePolicy().hasHeightForWidth());
        runButtonBatch->setSizePolicy(sizePolicy1);

        hboxLayout2->addWidget(runButtonBatch);

        spacerItem4 = new QSpacerItem(131, 21, QSizePolicy::Policy::Expanding, QSizePolicy::Policy::Minimum);

        hboxLayout2->addItem(spacerItem4);


        vboxLayout2->addLayout(hboxLayout2);

        spacerItem5 = new QSpacerItem(511, 16, QSizePolicy::Policy::Minimum, QSizePolicy::Policy::Expanding);

        vboxLayout2->addItem(spacerItem5);

        tabWidget->addTab(batch, QString());

        vboxLayout->addWidget(tabWidget);

        QWidget::setTabOrder(tabWidget, RA);
        QWidget::setTabOrder(RA, Dec);
        QWidget::setTabOrder(Dec, ObjectButton);
        QWidget::setTabOrder(ObjectButton, GalLongitude);
        QWidget::setTabOrder(GalLongitude, GalLatitude);
        QWidget::setTabOrder(GalLatitude, raCheckBatch);
        QWidget::setTabOrder(raCheckBatch, raBoxBatch);
        QWidget::setTabOrder(raBoxBatch, decCheckBatch);
        QWidget::setTabOrder(decCheckBatch, decBoxBatch);
        QWidget::setTabOrder(decBoxBatch, epochCheckBatch);
        QWidget::setTabOrder(epochCheckBatch, epochBoxBatch);
        QWidget::setTabOrder(epochBoxBatch, galLongCheckBatch);
        QWidget::setTabOrder(galLongCheckBatch, galLongBoxBatch);
        QWidget::setTabOrder(galLongBoxBatch, galLatCheckBatch);
        QWidget::setTabOrder(galLatCheckBatch, galLatBoxBatch);
        QWidget::setTabOrder(galLatBoxBatch, allRadioBatch);
        QWidget::setTabOrder(allRadioBatch, inputRadioBatch);
        QWidget::setTabOrder(inputRadioBatch, InputFileBoxBatch);
        QWidget::setTabOrder(InputFileBoxBatch, OutputFileBoxBatch);
        QWidget::setTabOrder(OutputFileBoxBatch, runButtonBatch);

        retranslateUi(modCalcGalCoordDlg);

        tabWidget->setCurrentIndex(0);


        QMetaObject::connectSlotsByName(modCalcGalCoordDlg);
    } // setupUi

    void retranslateUi(QWidget *modCalcGalCoordDlg)
    {
        groupBox_2->setTitle(tr2i18n("Equatorial Coordinates (J2000)", nullptr));
        decLabel->setText(tr2i18n("Declination:", nullptr));
        raLabel->setText(tr2i18n("Right ascension:", nullptr));
        ObjectButton->setText(tr2i18n("Select Object...", nullptr));
        groupBox_3alactic->setTitle(tr2i18n("Galactic Coordinates", nullptr));
        label_2->setText(tr2i18n("Latitude:", nullptr));
        label->setText(tr2i18n("Longitude:", nullptr));
        tabWidget->setTabText(tabWidget->indexOf(interact), tr2i18n("Interactive Mode", nullptr));
        groupBox_3->setTitle(tr2i18n("Select Parameters in Input File", nullptr));
#if QT_CONFIG(tooltip)
        epochCheckBatch->setToolTip(tr2i18n("If checked, value will be read from input file. If not, value will be read from adjacent box", nullptr));
#endif // QT_CONFIG(tooltip)
        epochCheckBatch->setText(tr2i18n("Epoch:", nullptr));
        epochBoxBatch->setText(tr2i18n("1950.0", nullptr));
#if QT_CONFIG(tooltip)
        galLongCheckBatch->setToolTip(tr2i18n("If checked, value will be read from input file. If not, value will be read from adjacent box", nullptr));
#endif // QT_CONFIG(tooltip)
        galLongCheckBatch->setText(tr2i18n("Gal. long.:", nullptr));
#if QT_CONFIG(tooltip)
        galLatCheckBatch->setToolTip(tr2i18n("If checked, value will be read from input file. If not, value will be read from adjacent box", nullptr));
#endif // QT_CONFIG(tooltip)
        galLatCheckBatch->setText(tr2i18n("Gal. lat.:", nullptr));
#if QT_CONFIG(tooltip)
        decCheckBatch->setToolTip(tr2i18n("If checked, value will be read from input file. If not, value will be read from adjacent box", nullptr));
#endif // QT_CONFIG(tooltip)
        decCheckBatch->setText(tr2i18n("Dec:", nullptr));
#if QT_CONFIG(tooltip)
        raCheckBatch->setToolTip(tr2i18n("If checked, value will be read from input file. If not, value will be read from adjacent box", nullptr));
#endif // QT_CONFIG(tooltip)
        raCheckBatch->setText(tr2i18n("RA:", nullptr));
        groupBox_4->setTitle(tr2i18n("Select Parameters for Output File", nullptr));
        allRadioBatch->setText(tr2i18n("All parameters", nullptr));
        inputRadioBatch->setText(tr2i18n("Only parameters in input file", nullptr));
        groupBox_5->setTitle(tr2i18n("Select Filenames", nullptr));
        label_4->setText(tr2i18n("Output file:", nullptr));
        label_3->setText(tr2i18n("Input file:", nullptr));
        runButtonBatch->setText(tr2i18n("Run", nullptr));
        tabWidget->setTabText(tabWidget->indexOf(batch), tr2i18n("Batch Mode", nullptr));
        (void)modCalcGalCoordDlg;
    } // retranslateUi

};

namespace Ui {
    class modCalcGalCoordDlg: public Ui_modCalcGalCoordDlg {};
} // namespace Ui

QT_END_NAMESPACE

#endif // MODCALCGALCOORD_H

