/********************************************************************************
** Form generated from reading UI file 'opshipscache.ui'
**
** Created by: Qt User Interface Compiler version 6.11.1
**
** WARNING! All changes made in this file will be lost when recompiling UI file!
********************************************************************************/

#ifndef UI_OPSHIPSCACHE_H
#define UI_OPSHIPSCACHE_H

#include <QtCore/QVariant>
#include <QtGui/QIcon>
#include <QtWidgets/QApplication>
#include <QtWidgets/QCheckBox>
#include <QtWidgets/QGridLayout>
#include <QtWidgets/QHBoxLayout>
#include <QtWidgets/QLabel>
#include <QtWidgets/QLineEdit>
#include <QtWidgets/QPushButton>
#include <QtWidgets/QSpacerItem>
#include <QtWidgets/QSpinBox>
#include <QtWidgets/QVBoxLayout>
#include <QtWidgets/QWidget>
#include <klocalizedstring.h>

QT_BEGIN_NAMESPACE

class Ui_OpsHIPSCache
{
public:
    QVBoxLayout *verticalLayout;
    QHBoxLayout *horizontalLayout;
    QGridLayout *gridLayout;
    QLabel *label_4;
    QSpinBox *kcfg_HIPSNetCache;
    QLabel *label_3;
    QLabel *label;
    QSpinBox *kcfg_HIPSMemoryCache;
    QLabel *label_2;
    QSpacerItem *horizontalSpacer;
    QHBoxLayout *horizontalLayout_2;
    QCheckBox *kcfg_HIPSUseOfflineSource;
    QLineEdit *kcfg_HIPSOfflinePath;
    QPushButton *selectDirectoryB;
    QSpacerItem *verticalSpacer;

    void setupUi(QWidget *OpsHIPSCache)
    {
        if (OpsHIPSCache->objectName().isEmpty())
            OpsHIPSCache->setObjectName("OpsHIPSCache");
        OpsHIPSCache->resize(419, 105);
        verticalLayout = new QVBoxLayout(OpsHIPSCache);
        verticalLayout->setSpacing(3);
        verticalLayout->setObjectName("verticalLayout");
        verticalLayout->setContentsMargins(3, 3, 3, 3);
        horizontalLayout = new QHBoxLayout();
        horizontalLayout->setSpacing(3);
        horizontalLayout->setObjectName("horizontalLayout");
        gridLayout = new QGridLayout();
        gridLayout->setSpacing(3);
        gridLayout->setObjectName("gridLayout");
        label_4 = new QLabel(OpsHIPSCache);
        label_4->setObjectName("label_4");

        gridLayout->addWidget(label_4, 0, 0, 1, 1);

        kcfg_HIPSNetCache = new QSpinBox(OpsHIPSCache);
        kcfg_HIPSNetCache->setObjectName("kcfg_HIPSNetCache");
        kcfg_HIPSNetCache->setMinimum(10);
        kcfg_HIPSNetCache->setMaximum(100000);
        kcfg_HIPSNetCache->setValue(1000);

        gridLayout->addWidget(kcfg_HIPSNetCache, 0, 1, 1, 1);

        label_3 = new QLabel(OpsHIPSCache);
        label_3->setObjectName("label_3");

        gridLayout->addWidget(label_3, 0, 2, 1, 1);

        label = new QLabel(OpsHIPSCache);
        label->setObjectName("label");

        gridLayout->addWidget(label, 1, 0, 1, 1);

        kcfg_HIPSMemoryCache = new QSpinBox(OpsHIPSCache);
        kcfg_HIPSMemoryCache->setObjectName("kcfg_HIPSMemoryCache");
        kcfg_HIPSMemoryCache->setMinimum(10);
        kcfg_HIPSMemoryCache->setMaximum(4096);
        kcfg_HIPSMemoryCache->setValue(300);

        gridLayout->addWidget(kcfg_HIPSMemoryCache, 1, 1, 1, 1);

        label_2 = new QLabel(OpsHIPSCache);
        label_2->setObjectName("label_2");

        gridLayout->addWidget(label_2, 1, 2, 1, 1);


        horizontalLayout->addLayout(gridLayout);

        horizontalSpacer = new QSpacerItem(40, 20, QSizePolicy::Policy::Expanding, QSizePolicy::Policy::Minimum);

        horizontalLayout->addItem(horizontalSpacer);


        verticalLayout->addLayout(horizontalLayout);

        horizontalLayout_2 = new QHBoxLayout();
        horizontalLayout_2->setSpacing(3);
        horizontalLayout_2->setObjectName("horizontalLayout_2");
        kcfg_HIPSUseOfflineSource = new QCheckBox(OpsHIPSCache);
        kcfg_HIPSUseOfflineSource->setObjectName("kcfg_HIPSUseOfflineSource");

        horizontalLayout_2->addWidget(kcfg_HIPSUseOfflineSource);

        kcfg_HIPSOfflinePath = new QLineEdit(OpsHIPSCache);
        kcfg_HIPSOfflinePath->setObjectName("kcfg_HIPSOfflinePath");
        kcfg_HIPSOfflinePath->setMaximumSize(QSize(16777215, 32));
        kcfg_HIPSOfflinePath->setClearButtonEnabled(true);

        horizontalLayout_2->addWidget(kcfg_HIPSOfflinePath);

        selectDirectoryB = new QPushButton(OpsHIPSCache);
        selectDirectoryB->setObjectName("selectDirectoryB");
        selectDirectoryB->setMaximumSize(QSize(32, 32));
        QIcon icon(QIcon::fromTheme(QString::fromUtf8("folder-open")));
        selectDirectoryB->setIcon(icon);
        selectDirectoryB->setIconSize(QSize(28, 28));

        horizontalLayout_2->addWidget(selectDirectoryB);


        verticalLayout->addLayout(horizontalLayout_2);

        verticalSpacer = new QSpacerItem(20, 40, QSizePolicy::Policy::Minimum, QSizePolicy::Policy::Expanding);

        verticalLayout->addItem(verticalSpacer);


        retranslateUi(OpsHIPSCache);

        QMetaObject::connectSlotsByName(OpsHIPSCache);
    } // setupUi

    void retranslateUi(QWidget *OpsHIPSCache)
    {
#if QT_CONFIG(tooltip)
        label_4->setToolTip(tr2i18n("Cache space on hard disk used to store HiPS images.", nullptr));
#endif // QT_CONFIG(tooltip)
        label_4->setText(tr2i18n("Disk:", nullptr));
#if QT_CONFIG(tooltip)
        kcfg_HIPSNetCache->setToolTip(tr2i18n("Cache space on hard disk used to store HiPS images.", nullptr));
#endif // QT_CONFIG(tooltip)
        label_3->setText(tr2i18n("MB", nullptr));
#if QT_CONFIG(tooltip)
        label->setToolTip(tr2i18n("Cache space in RAM used to store HiPS images.", nullptr));
#endif // QT_CONFIG(tooltip)
        label->setText(tr2i18n("Memory:", nullptr));
#if QT_CONFIG(tooltip)
        kcfg_HIPSMemoryCache->setToolTip(tr2i18n("Cache space in RAM used to store HiPS images.", nullptr));
#endif // QT_CONFIG(tooltip)
        label_2->setText(tr2i18n("MB", nullptr));
#if QT_CONFIG(tooltip)
        kcfg_HIPSUseOfflineSource->setToolTip(tr2i18n("Do not download HiPS from Internet. Use DSS offline storage path to load all data.", nullptr));
#endif // QT_CONFIG(tooltip)
        kcfg_HIPSUseOfflineSource->setText(tr2i18n("DSS Offline Source", nullptr));
        selectDirectoryB->setText(QString());
        (void)OpsHIPSCache;
    } // retranslateUi

};

namespace Ui {
    class OpsHIPSCache: public Ui_OpsHIPSCache {};
} // namespace Ui

QT_END_NAMESPACE

#endif // OPSHIPSCACHE_H

