/****************************************************************************
** Meta object code from reading C++ file 'indimount.h'
**
** Created by: The Qt Meta Object Compiler version 69 (Qt 6.11.1)
**
** WARNING! All changes made in this file will be lost!
*****************************************************************************/

#include "../../../../kstars-3.8.4.1/kstars/indi/indimount.h"
#include <QtCore/qmetatype.h>

#include <QtCore/qtmochelpers.h>

#include <memory>


#include <QtCore/qxptype_traits.h>
#if !defined(Q_MOC_OUTPUT_REVISION)
#error "The header file 'indimount.h' doesn't include <QObject>."
#elif Q_MOC_OUTPUT_REVISION != 69
#error "This file was generated using the moc from 6.11.1. It"
#error "cannot be used with the include files from this version of Qt."
#error "(The moc has changed too much.)"
#endif

#ifndef Q_CONSTINIT
#define Q_CONSTINIT
#endif

QT_WARNING_PUSH
QT_WARNING_DISABLE_DEPRECATED
QT_WARNING_DISABLE_GCC("-Wuseless-cast")
namespace {
struct qt_meta_tag_ZN3ISD5MountE_t {};
} // unnamed namespace

template <> constexpr inline auto ISD::Mount::qt_create_metaobjectdata<qt_meta_tag_ZN3ISD5MountE_t>()
{
    namespace QMC = QtMocConstants;
    QtMocHelpers::StringRefStorage qt_stringData {
        "ISD::Mount",
        "newTarget",
        "",
        "SkyPoint&",
        "currentCoords",
        "newTargetName",
        "name",
        "newStatus",
        "ISD::Mount::Status",
        "status",
        "newCoords",
        "SkyPoint",
        "position",
        "PierSide",
        "pierside",
        "dms",
        "ha",
        "newParkStatus",
        "ISD::ParkStatus",
        "slewRateChanged",
        "rate",
        "pierSideChanged",
        "side",
        "axisReversed",
        "INDI_EQ_AXIS",
        "axis",
        "reversed",
        "newHomeStatus",
        "IPState",
        "abort",
        "park",
        "unpark",
        "setSlewRate",
        "index",
        "setTrackEnabled",
        "enable",
        "setCustomTrackRate",
        "raRate",
        "deRate",
        "setTrackMode",
        "uint8_t"
    };

    QtMocHelpers::UintData qt_methods {
        // Signal 'newTarget'
        QtMocHelpers::SignalData<void(SkyPoint &)>(1, 2, QMC::AccessPublic, QMetaType::Void, {{
            { 0x80000000 | 3, 4 },
        }}),
        // Signal 'newTargetName'
        QtMocHelpers::SignalData<void(const QString &)>(5, 2, QMC::AccessPublic, QMetaType::Void, {{
            { QMetaType::QString, 6 },
        }}),
        // Signal 'newStatus'
        QtMocHelpers::SignalData<void(ISD::Mount::Status)>(7, 2, QMC::AccessPublic, QMetaType::Void, {{
            { 0x80000000 | 8, 9 },
        }}),
        // Signal 'newCoords'
        QtMocHelpers::SignalData<void(const SkyPoint &, const PierSide, const dms &)>(10, 2, QMC::AccessPublic, QMetaType::Void, {{
            { 0x80000000 | 11, 12 }, { 0x80000000 | 13, 14 }, { 0x80000000 | 15, 16 },
        }}),
        // Signal 'newParkStatus'
        QtMocHelpers::SignalData<void(ISD::ParkStatus)>(17, 2, QMC::AccessPublic, QMetaType::Void, {{
            { 0x80000000 | 18, 9 },
        }}),
        // Signal 'slewRateChanged'
        QtMocHelpers::SignalData<void(int)>(19, 2, QMC::AccessPublic, QMetaType::Void, {{
            { QMetaType::Int, 20 },
        }}),
        // Signal 'pierSideChanged'
        QtMocHelpers::SignalData<void(PierSide)>(21, 2, QMC::AccessPublic, QMetaType::Void, {{
            { 0x80000000 | 13, 22 },
        }}),
        // Signal 'axisReversed'
        QtMocHelpers::SignalData<void(INDI_EQ_AXIS, bool)>(23, 2, QMC::AccessPublic, QMetaType::Void, {{
            { 0x80000000 | 24, 25 }, { QMetaType::Bool, 26 },
        }}),
        // Signal 'newHomeStatus'
        QtMocHelpers::SignalData<void(IPState)>(27, 2, QMC::AccessPublic, QMetaType::Void, {{
            { 0x80000000 | 28, 9 },
        }}),
        // Slot 'abort'
        QtMocHelpers::SlotData<bool()>(29, 2, QMC::AccessPublic, QMetaType::Bool),
        // Slot 'park'
        QtMocHelpers::SlotData<bool()>(30, 2, QMC::AccessPublic, QMetaType::Bool),
        // Slot 'unpark'
        QtMocHelpers::SlotData<bool()>(31, 2, QMC::AccessPublic, QMetaType::Bool),
        // Slot 'setSlewRate'
        QtMocHelpers::SlotData<bool(int)>(32, 2, QMC::AccessPublic, QMetaType::Bool, {{
            { QMetaType::Int, 33 },
        }}),
        // Slot 'setTrackEnabled'
        QtMocHelpers::SlotData<bool(bool)>(34, 2, QMC::AccessPublic, QMetaType::Bool, {{
            { QMetaType::Bool, 35 },
        }}),
        // Slot 'setCustomTrackRate'
        QtMocHelpers::SlotData<bool(double, double)>(36, 2, QMC::AccessPublic, QMetaType::Bool, {{
            { QMetaType::Double, 37 }, { QMetaType::Double, 38 },
        }}),
        // Slot 'setTrackMode'
        QtMocHelpers::SlotData<bool(uint8_t)>(39, 2, QMC::AccessPublic, QMetaType::Bool, {{
            { 0x80000000 | 40, 33 },
        }}),
    };
    QtMocHelpers::UintData qt_properties {
    };
    QtMocHelpers::UintData qt_enums {
    };
    return QtMocHelpers::metaObjectData<Mount, qt_meta_tag_ZN3ISD5MountE_t>(QMC::MetaObjectFlag{}, qt_stringData,
            qt_methods, qt_properties, qt_enums);
}
Q_CONSTINIT const QMetaObject ISD::Mount::staticMetaObject = { {
    QMetaObject::SuperData::link<ConcreteDevice::staticMetaObject>(),
    qt_staticMetaObjectStaticContent<qt_meta_tag_ZN3ISD5MountE_t>.stringdata,
    qt_staticMetaObjectStaticContent<qt_meta_tag_ZN3ISD5MountE_t>.data,
    qt_static_metacall,
    nullptr,
    qt_staticMetaObjectRelocatingContent<qt_meta_tag_ZN3ISD5MountE_t>.metaTypes,
    nullptr
} };

void ISD::Mount::qt_static_metacall(QObject *_o, QMetaObject::Call _c, int _id, void **_a)
{
    auto *_t = static_cast<Mount *>(_o);
    if (_c == QMetaObject::InvokeMetaMethod) {
        switch (_id) {
        case 0: _t->newTarget((*reinterpret_cast<std::add_pointer_t<SkyPoint&>>(_a[1]))); break;
        case 1: _t->newTargetName((*reinterpret_cast<std::add_pointer_t<QString>>(_a[1]))); break;
        case 2: _t->newStatus((*reinterpret_cast<std::add_pointer_t<ISD::Mount::Status>>(_a[1]))); break;
        case 3: _t->newCoords((*reinterpret_cast<std::add_pointer_t<SkyPoint>>(_a[1])),(*reinterpret_cast<std::add_pointer_t<PierSide>>(_a[2])),(*reinterpret_cast<std::add_pointer_t<dms>>(_a[3]))); break;
        case 4: _t->newParkStatus((*reinterpret_cast<std::add_pointer_t<ISD::ParkStatus>>(_a[1]))); break;
        case 5: _t->slewRateChanged((*reinterpret_cast<std::add_pointer_t<int>>(_a[1]))); break;
        case 6: _t->pierSideChanged((*reinterpret_cast<std::add_pointer_t<PierSide>>(_a[1]))); break;
        case 7: _t->axisReversed((*reinterpret_cast<std::add_pointer_t<INDI_EQ_AXIS>>(_a[1])),(*reinterpret_cast<std::add_pointer_t<bool>>(_a[2]))); break;
        case 8: _t->newHomeStatus((*reinterpret_cast<std::add_pointer_t<IPState>>(_a[1]))); break;
        case 9: { bool _r = _t->abort();
            if (_a[0]) *reinterpret_cast<bool*>(_a[0]) = std::move(_r); }  break;
        case 10: { bool _r = _t->park();
            if (_a[0]) *reinterpret_cast<bool*>(_a[0]) = std::move(_r); }  break;
        case 11: { bool _r = _t->unpark();
            if (_a[0]) *reinterpret_cast<bool*>(_a[0]) = std::move(_r); }  break;
        case 12: { bool _r = _t->setSlewRate((*reinterpret_cast<std::add_pointer_t<int>>(_a[1])));
            if (_a[0]) *reinterpret_cast<bool*>(_a[0]) = std::move(_r); }  break;
        case 13: { bool _r = _t->setTrackEnabled((*reinterpret_cast<std::add_pointer_t<bool>>(_a[1])));
            if (_a[0]) *reinterpret_cast<bool*>(_a[0]) = std::move(_r); }  break;
        case 14: { bool _r = _t->setCustomTrackRate((*reinterpret_cast<std::add_pointer_t<double>>(_a[1])),(*reinterpret_cast<std::add_pointer_t<double>>(_a[2])));
            if (_a[0]) *reinterpret_cast<bool*>(_a[0]) = std::move(_r); }  break;
        case 15: { bool _r = _t->setTrackMode((*reinterpret_cast<std::add_pointer_t<uint8_t>>(_a[1])));
            if (_a[0]) *reinterpret_cast<bool*>(_a[0]) = std::move(_r); }  break;
        default: ;
        }
    }
    if (_c == QMetaObject::RegisterMethodArgumentMetaType) {
        switch (_id) {
        default: *reinterpret_cast<QMetaType *>(_a[0]) = QMetaType(); break;
        case 2:
            switch (*reinterpret_cast<int*>(_a[1])) {
            default: *reinterpret_cast<QMetaType *>(_a[0]) = QMetaType(); break;
            case 0:
                *reinterpret_cast<QMetaType *>(_a[0]) = QMetaType::fromType< ISD::Mount::Status >(); break;
            }
            break;
        case 3:
            switch (*reinterpret_cast<int*>(_a[1])) {
            default: *reinterpret_cast<QMetaType *>(_a[0]) = QMetaType(); break;
            case 0:
                *reinterpret_cast<QMetaType *>(_a[0]) = QMetaType::fromType< SkyPoint >(); break;
            }
            break;
        case 4:
            switch (*reinterpret_cast<int*>(_a[1])) {
            default: *reinterpret_cast<QMetaType *>(_a[0]) = QMetaType(); break;
            case 0:
                *reinterpret_cast<QMetaType *>(_a[0]) = QMetaType::fromType< ISD::ParkStatus >(); break;
            }
            break;
        }
    }
    if (_c == QMetaObject::IndexOfMethod) {
        if (QtMocHelpers::indexOfMethod<void (Mount::*)(SkyPoint & )>(_a, &Mount::newTarget, 0))
            return;
        if (QtMocHelpers::indexOfMethod<void (Mount::*)(const QString & )>(_a, &Mount::newTargetName, 1))
            return;
        if (QtMocHelpers::indexOfMethod<void (Mount::*)(ISD::Mount::Status )>(_a, &Mount::newStatus, 2))
            return;
        if (QtMocHelpers::indexOfMethod<void (Mount::*)(const SkyPoint & , const PierSide , const dms & )>(_a, &Mount::newCoords, 3))
            return;
        if (QtMocHelpers::indexOfMethod<void (Mount::*)(ISD::ParkStatus )>(_a, &Mount::newParkStatus, 4))
            return;
        if (QtMocHelpers::indexOfMethod<void (Mount::*)(int )>(_a, &Mount::slewRateChanged, 5))
            return;
        if (QtMocHelpers::indexOfMethod<void (Mount::*)(PierSide )>(_a, &Mount::pierSideChanged, 6))
            return;
        if (QtMocHelpers::indexOfMethod<void (Mount::*)(INDI_EQ_AXIS , bool )>(_a, &Mount::axisReversed, 7))
            return;
        if (QtMocHelpers::indexOfMethod<void (Mount::*)(IPState )>(_a, &Mount::newHomeStatus, 8))
            return;
    }
}

const QMetaObject *ISD::Mount::metaObject() const
{
    return QObject::d_ptr->metaObject ? QObject::d_ptr->dynamicMetaObject() : &staticMetaObject;
}

void *ISD::Mount::qt_metacast(const char *_clname)
{
    if (!_clname) return nullptr;
    if (!strcmp(_clname, qt_staticMetaObjectStaticContent<qt_meta_tag_ZN3ISD5MountE_t>.strings))
        return static_cast<void*>(this);
    return ConcreteDevice::qt_metacast(_clname);
}

int ISD::Mount::qt_metacall(QMetaObject::Call _c, int _id, void **_a)
{
    _id = ConcreteDevice::qt_metacall(_c, _id, _a);
    if (_id < 0)
        return _id;
    if (_c == QMetaObject::InvokeMetaMethod) {
        if (_id < 16)
            qt_static_metacall(this, _c, _id, _a);
        _id -= 16;
    }
    if (_c == QMetaObject::RegisterMethodArgumentMetaType) {
        if (_id < 16)
            qt_static_metacall(this, _c, _id, _a);
        _id -= 16;
    }
    return _id;
}

// SIGNAL 0
void ISD::Mount::newTarget(SkyPoint & _t1)
{
    QMetaObject::activate<void>(this, &staticMetaObject, 0, nullptr, _t1);
}

// SIGNAL 1
void ISD::Mount::newTargetName(const QString & _t1)
{
    QMetaObject::activate<void>(this, &staticMetaObject, 1, nullptr, _t1);
}

// SIGNAL 2
void ISD::Mount::newStatus(ISD::Mount::Status _t1)
{
    QMetaObject::activate<void>(this, &staticMetaObject, 2, nullptr, _t1);
}

// SIGNAL 3
void ISD::Mount::newCoords(const SkyPoint & _t1, const PierSide _t2, const dms & _t3)
{
    QMetaObject::activate<void>(this, &staticMetaObject, 3, nullptr, _t1, _t2, _t3);
}

// SIGNAL 4
void ISD::Mount::newParkStatus(ISD::ParkStatus _t1)
{
    QMetaObject::activate<void>(this, &staticMetaObject, 4, nullptr, _t1);
}

// SIGNAL 5
void ISD::Mount::slewRateChanged(int _t1)
{
    QMetaObject::activate<void>(this, &staticMetaObject, 5, nullptr, _t1);
}

// SIGNAL 6
void ISD::Mount::pierSideChanged(PierSide _t1)
{
    QMetaObject::activate<void>(this, &staticMetaObject, 6, nullptr, _t1);
}

// SIGNAL 7
void ISD::Mount::axisReversed(INDI_EQ_AXIS _t1, bool _t2)
{
    QMetaObject::activate<void>(this, &staticMetaObject, 7, nullptr, _t1, _t2);
}

// SIGNAL 8
void ISD::Mount::newHomeStatus(IPState _t1)
{
    QMetaObject::activate<void>(this, &staticMetaObject, 8, nullptr, _t1);
}
QT_WARNING_POP
