/****************************************************************************
** Meta object code from reading C++ file 'profilescript.h'
**
** Created by: The Qt Meta Object Compiler version 69 (Qt 6.11.1)
**
** WARNING! All changes made in this file will be lost!
*****************************************************************************/

#include "../../../../kstars-3.8.4.1/kstars/ekos/profilescript.h"
#include <QtCore/qmetatype.h>

#include <QtCore/qtmochelpers.h>

#include <memory>


#include <QtCore/qxptype_traits.h>
#if !defined(Q_MOC_OUTPUT_REVISION)
#error "The header file 'profilescript.h' doesn't include <QObject>."
#elif Q_MOC_OUTPUT_REVISION != 69
#error "This file was generated using the moc from 6.11.1. It"
#error "cannot be used with the include files from this version of Qt."
#error "(The moc has changed too much.)"
#endif

#ifndef Q_CONSTINIT
#define Q_CONSTINIT
#endif

QT_WARNING_PUSH
QT_WARNING_DISABLE_DEPRECATED
QT_WARNING_DISABLE_GCC("-Wuseless-cast")
namespace {
struct qt_meta_tag_ZN13ProfileScriptE_t {};
} // unnamed namespace

template <> constexpr inline auto ProfileScript::qt_create_metaobjectdata<qt_meta_tag_ZN13ProfileScriptE_t>()
{
    namespace QMC = QtMocConstants;
    QtMocHelpers::StringRefStorage qt_stringData {
        "ProfileScript",
        "removedRequested",
        "",
        "PreDelay",
        "PreScript",
        "Driver",
        "PostDelay",
        "PostScript",
        "StoppingDelay",
        "StoppingScript",
        "StoppedDelay",
        "StoppedScript"
    };

    QtMocHelpers::UintData qt_methods {
        // Signal 'removedRequested'
        QtMocHelpers::SignalData<void()>(1, 2, QMC::AccessPublic, QMetaType::Void),
    };
    QtMocHelpers::UintData qt_properties {
        // property 'PreDelay'
        QtMocHelpers::PropertyData<uint>(3, QMetaType::UInt, QMC::DefaultPropertyFlags | QMC::Writable),
        // property 'PreScript'
        QtMocHelpers::PropertyData<QString>(4, QMetaType::QString, QMC::DefaultPropertyFlags | QMC::Writable),
        // property 'Driver'
        QtMocHelpers::PropertyData<QString>(5, QMetaType::QString, QMC::DefaultPropertyFlags | QMC::Writable),
        // property 'PostDelay'
        QtMocHelpers::PropertyData<uint>(6, QMetaType::UInt, QMC::DefaultPropertyFlags | QMC::Writable),
        // property 'PostScript'
        QtMocHelpers::PropertyData<QString>(7, QMetaType::QString, QMC::DefaultPropertyFlags | QMC::Writable),
        // property 'StoppingDelay'
        QtMocHelpers::PropertyData<uint>(8, QMetaType::UInt, QMC::DefaultPropertyFlags | QMC::Writable),
        // property 'StoppingScript'
        QtMocHelpers::PropertyData<QString>(9, QMetaType::QString, QMC::DefaultPropertyFlags | QMC::Writable),
        // property 'StoppedDelay'
        QtMocHelpers::PropertyData<uint>(10, QMetaType::UInt, QMC::DefaultPropertyFlags | QMC::Writable),
        // property 'StoppedScript'
        QtMocHelpers::PropertyData<QString>(11, QMetaType::QString, QMC::DefaultPropertyFlags | QMC::Writable),
    };
    QtMocHelpers::UintData qt_enums {
    };
    return QtMocHelpers::metaObjectData<ProfileScript, qt_meta_tag_ZN13ProfileScriptE_t>(QMC::MetaObjectFlag{}, qt_stringData,
            qt_methods, qt_properties, qt_enums);
}
Q_CONSTINIT const QMetaObject ProfileScript::staticMetaObject = { {
    QMetaObject::SuperData::link<QWidget::staticMetaObject>(),
    qt_staticMetaObjectStaticContent<qt_meta_tag_ZN13ProfileScriptE_t>.stringdata,
    qt_staticMetaObjectStaticContent<qt_meta_tag_ZN13ProfileScriptE_t>.data,
    qt_static_metacall,
    nullptr,
    qt_staticMetaObjectRelocatingContent<qt_meta_tag_ZN13ProfileScriptE_t>.metaTypes,
    nullptr
} };

void ProfileScript::qt_static_metacall(QObject *_o, QMetaObject::Call _c, int _id, void **_a)
{
    auto *_t = static_cast<ProfileScript *>(_o);
    if (_c == QMetaObject::InvokeMetaMethod) {
        switch (_id) {
        case 0: _t->removedRequested(); break;
        default: ;
        }
    }
    if (_c == QMetaObject::IndexOfMethod) {
        if (QtMocHelpers::indexOfMethod<void (ProfileScript::*)()>(_a, &ProfileScript::removedRequested, 0))
            return;
    }
    if (_c == QMetaObject::ReadProperty) {
        void *_v = _a[0];
        switch (_id) {
        case 0: *reinterpret_cast<uint*>(_v) = _t->m_PreDelay; break;
        case 1: *reinterpret_cast<QString*>(_v) = _t->m_PreScript; break;
        case 2: *reinterpret_cast<QString*>(_v) = _t->m_Driver; break;
        case 3: *reinterpret_cast<uint*>(_v) = _t->m_PostDelay; break;
        case 4: *reinterpret_cast<QString*>(_v) = _t->m_PostScript; break;
        case 5: *reinterpret_cast<uint*>(_v) = _t->m_StoppingDelay; break;
        case 6: *reinterpret_cast<QString*>(_v) = _t->m_StoppingScript; break;
        case 7: *reinterpret_cast<uint*>(_v) = _t->m_StoppedDelay; break;
        case 8: *reinterpret_cast<QString*>(_v) = _t->m_StoppedScript; break;
        default: break;
        }
    }
    if (_c == QMetaObject::WriteProperty) {
        void *_v = _a[0];
        switch (_id) {
        case 0: QtMocHelpers::setProperty(_t->m_PreDelay, *reinterpret_cast<uint*>(_v)); break;
        case 1: QtMocHelpers::setProperty(_t->m_PreScript, *reinterpret_cast<QString*>(_v)); break;
        case 2: QtMocHelpers::setProperty(_t->m_Driver, *reinterpret_cast<QString*>(_v)); break;
        case 3: QtMocHelpers::setProperty(_t->m_PostDelay, *reinterpret_cast<uint*>(_v)); break;
        case 4: QtMocHelpers::setProperty(_t->m_PostScript, *reinterpret_cast<QString*>(_v)); break;
        case 5: QtMocHelpers::setProperty(_t->m_StoppingDelay, *reinterpret_cast<uint*>(_v)); break;
        case 6: QtMocHelpers::setProperty(_t->m_StoppingScript, *reinterpret_cast<QString*>(_v)); break;
        case 7: QtMocHelpers::setProperty(_t->m_StoppedDelay, *reinterpret_cast<uint*>(_v)); break;
        case 8: QtMocHelpers::setProperty(_t->m_StoppedScript, *reinterpret_cast<QString*>(_v)); break;
        default: break;
        }
    }
}

const QMetaObject *ProfileScript::metaObject() const
{
    return QObject::d_ptr->metaObject ? QObject::d_ptr->dynamicMetaObject() : &staticMetaObject;
}

void *ProfileScript::qt_metacast(const char *_clname)
{
    if (!_clname) return nullptr;
    if (!strcmp(_clname, qt_staticMetaObjectStaticContent<qt_meta_tag_ZN13ProfileScriptE_t>.strings))
        return static_cast<void*>(this);
    return QWidget::qt_metacast(_clname);
}

int ProfileScript::qt_metacall(QMetaObject::Call _c, int _id, void **_a)
{
    _id = QWidget::qt_metacall(_c, _id, _a);
    if (_id < 0)
        return _id;
    if (_c == QMetaObject::InvokeMetaMethod) {
        if (_id < 1)
            qt_static_metacall(this, _c, _id, _a);
        _id -= 1;
    }
    if (_c == QMetaObject::RegisterMethodArgumentMetaType) {
        if (_id < 1)
            *reinterpret_cast<QMetaType *>(_a[0]) = QMetaType();
        _id -= 1;
    }
    if (_c == QMetaObject::ReadProperty || _c == QMetaObject::WriteProperty
            || _c == QMetaObject::ResetProperty || _c == QMetaObject::BindableProperty
            || _c == QMetaObject::RegisterPropertyMetaType) {
        qt_static_metacall(this, _c, _id, _a);
        _id -= 9;
    }
    return _id;
}

// SIGNAL 0
void ProfileScript::removedRequested()
{
    QMetaObject::activate(this, &staticMetaObject, 0, nullptr);
}
QT_WARNING_POP
