/********************************************************************************
** Form generated from reading UI file 'opsgpg.ui'
**
** Created by: Qt User Interface Compiler version 6.11.1
**
** WARNING! All changes made in this file will be lost when recompiling UI file!
********************************************************************************/

#ifndef UI_OPSGPG_H
#define UI_OPSGPG_H

#include <QtCore/QVariant>
#include <QtWidgets/QApplication>
#include <QtWidgets/QCheckBox>
#include <QtWidgets/QDoubleSpinBox>
#include <QtWidgets/QGridLayout>
#include <QtWidgets/QGroupBox>
#include <QtWidgets/QLabel>
#include <QtWidgets/QSpinBox>
#include <QtWidgets/QVBoxLayout>
#include <QtWidgets/QWidget>
#include <klocalizedstring.h>

QT_BEGIN_NAMESPACE

class Ui_OpsGPG
{
public:
    QVBoxLayout *verticalLayout_2;
    QGroupBox *copyrightGroupBox;
    QVBoxLayout *verticalLayout_3;
    QLabel *label;
    QGridLayout *gridLayout;
    QLabel *label_gpg0;
    QGroupBox *settingsGroupBox;
    QVBoxLayout *verticalLayout_4;
    QGridLayout *gridLayout2;
    QLabel *label_4;
    QLabel *label_gpgs0c;
    QLabel *label_gpgs0a;
    QLabel *label_gpgs2a;
    QLabel *label_gpgsDarkGuiding;
    QLabel *label_gpgs2b;
    QDoubleSpinBox *kcfg_GPGPeriod;
    QLabel *label_gpgs1a;
    QLabel *label_gpgs1b;
    QLabel *label_2;
    QCheckBox *kcfg_GPGEstimatePeriod;
    QLabel *label_gpgs4a;
    QLabel *label_3;
    QCheckBox *kcfg_GPGDarkGuiding;
    QLabel *label_gpgs3a;
    QDoubleSpinBox *kcfg_GPGpWeight;
    QDoubleSpinBox *kcfg_GPGDarkGuidingInterval;
    QLabel *label_5;
    QGroupBox *expertGroupBox;
    QVBoxLayout *verticalLayout_5;
    QGridLayout *gridLayout3;
    QLabel *label_gpgas0a;
    QSpinBox *kcfg_GPGSE0KLengthScale;
    QLabel *label_gpgas0c;
    QLabel *label_gpgas1a;
    QDoubleSpinBox *kcfg_GPGSE0KSignalVariance;
    QLabel *label_gpgas1c;
    QLabel *label_gpgas2a;
    QSpinBox *kcfg_GPGPKLengthScale;
    QLabel *label_gpgas2c;
    QLabel *label_gpgas3a;
    QDoubleSpinBox *kcfg_GPGPKSignalVariance;
    QLabel *label_gpgas3c;
    QLabel *label_gpgas4a;
    QSpinBox *kcfg_GPGSE1KLengthScale;
    QLabel *label_gpgas4c;
    QLabel *label_gpgas5a;
    QDoubleSpinBox *kcfg_GPGSE1KSignalVariance;
    QLabel *label_gpgas5c;
    QLabel *label_gpgas6a;
    QSpinBox *kcfg_GPGPointsForApproximation;
    QLabel *label_gpgas6c;
    QLabel *label_gpgas7a;
    QSpinBox *kcfg_GPGMinPeriodsForInference;
    QLabel *label_gpgas7c;
    QLabel *label_gpgas8a;
    QSpinBox *kcfg_GPGMinPeriodsForPeriodEstimate;
    QLabel *label_gpgas8c;

    void setupUi(QWidget *OpsGPG)
    {
        if (OpsGPG->objectName().isEmpty())
            OpsGPG->setObjectName("OpsGPG");
        OpsGPG->resize(471, 582);
        verticalLayout_2 = new QVBoxLayout(OpsGPG);
        verticalLayout_2->setSpacing(3);
        verticalLayout_2->setObjectName("verticalLayout_2");
        verticalLayout_2->setContentsMargins(3, 3, 3, 3);
        copyrightGroupBox = new QGroupBox(OpsGPG);
        copyrightGroupBox->setObjectName("copyrightGroupBox");
        copyrightGroupBox->setMaximumSize(QSize(16777215, 16777215));
        QFont font;
        font.setPointSize(8);
        copyrightGroupBox->setFont(font);
        verticalLayout_3 = new QVBoxLayout(copyrightGroupBox);
        verticalLayout_3->setSpacing(3);
        verticalLayout_3->setObjectName("verticalLayout_3");
        verticalLayout_3->setContentsMargins(3, 3, 3, 3);
        label = new QLabel(copyrightGroupBox);
        label->setObjectName("label");

        verticalLayout_3->addWidget(label);

        gridLayout = new QGridLayout();
        gridLayout->setSpacing(3);
        gridLayout->setObjectName("gridLayout");
        label_gpg0 = new QLabel(copyrightGroupBox);
        label_gpg0->setObjectName("label_gpg0");
        QFont font1;
        font1.setPointSize(11);
        label_gpg0->setFont(font1);

        gridLayout->addWidget(label_gpg0, 0, 0, 1, 2);


        verticalLayout_3->addLayout(gridLayout);


        verticalLayout_2->addWidget(copyrightGroupBox);

        settingsGroupBox = new QGroupBox(OpsGPG);
        settingsGroupBox->setObjectName("settingsGroupBox");
        verticalLayout_4 = new QVBoxLayout(settingsGroupBox);
        verticalLayout_4->setSpacing(3);
        verticalLayout_4->setObjectName("verticalLayout_4");
        verticalLayout_4->setContentsMargins(3, 3, 3, 3);
        gridLayout2 = new QGridLayout();
        gridLayout2->setSpacing(3);
        gridLayout2->setObjectName("gridLayout2");
        label_4 = new QLabel(settingsGroupBox);
        label_4->setObjectName("label_4");

        gridLayout2->addWidget(label_4, 4, 0, 1, 1);

        label_gpgs0c = new QLabel(settingsGroupBox);
        label_gpgs0c->setObjectName("label_gpgs0c");

        gridLayout2->addWidget(label_gpgs0c, 0, 2, 1, 1);

        label_gpgs0a = new QLabel(settingsGroupBox);
        label_gpgs0a->setObjectName("label_gpgs0a");

        gridLayout2->addWidget(label_gpgs0a, 0, 0, 1, 1);

        label_gpgs2a = new QLabel(settingsGroupBox);
        label_gpgs2a->setObjectName("label_gpgs2a");

        gridLayout2->addWidget(label_gpgs2a, 2, 0, 1, 1);

        label_gpgsDarkGuiding = new QLabel(settingsGroupBox);
        label_gpgsDarkGuiding->setObjectName("label_gpgsDarkGuiding");

        gridLayout2->addWidget(label_gpgsDarkGuiding, 3, 0, 1, 1);

        label_gpgs2b = new QLabel(settingsGroupBox);
        label_gpgs2b->setObjectName("label_gpgs2b");

        gridLayout2->addWidget(label_gpgs2b, 2, 2, 1, 1);

        kcfg_GPGPeriod = new QDoubleSpinBox(settingsGroupBox);
        kcfg_GPGPeriod->setObjectName("kcfg_GPGPeriod");
        kcfg_GPGPeriod->setMinimum(0.000000000000000);
        kcfg_GPGPeriod->setMaximum(3600.000000000000000);

        gridLayout2->addWidget(kcfg_GPGPeriod, 0, 1, 1, 1);

        label_gpgs1a = new QLabel(settingsGroupBox);
        label_gpgs1a->setObjectName("label_gpgs1a");

        gridLayout2->addWidget(label_gpgs1a, 1, 0, 1, 1);

        label_gpgs1b = new QLabel(settingsGroupBox);
        label_gpgs1b->setObjectName("label_gpgs1b");

        gridLayout2->addWidget(label_gpgs1b, 1, 2, 1, 1);

        label_2 = new QLabel(settingsGroupBox);
        label_2->setObjectName("label_2");
        QFont font2;
        font2.setPointSize(9);
        label_2->setFont(font2);

        gridLayout2->addWidget(label_2, 5, 1, 1, 2);

        kcfg_GPGEstimatePeriod = new QCheckBox(settingsGroupBox);
        kcfg_GPGEstimatePeriod->setObjectName("kcfg_GPGEstimatePeriod");

        gridLayout2->addWidget(kcfg_GPGEstimatePeriod, 1, 1, 1, 1);

        label_gpgs4a = new QLabel(settingsGroupBox);
        label_gpgs4a->setObjectName("label_gpgs4a");

        gridLayout2->addWidget(label_gpgs4a, 6, 0, 1, 1);

        label_3 = new QLabel(settingsGroupBox);
        label_3->setObjectName("label_3");
        label_3->setFont(font2);

        gridLayout2->addWidget(label_3, 6, 1, 1, 2);

        kcfg_GPGDarkGuiding = new QCheckBox(settingsGroupBox);
        kcfg_GPGDarkGuiding->setObjectName("kcfg_GPGDarkGuiding");

        gridLayout2->addWidget(kcfg_GPGDarkGuiding, 3, 1, 1, 1);

        label_gpgs3a = new QLabel(settingsGroupBox);
        label_gpgs3a->setObjectName("label_gpgs3a");

        gridLayout2->addWidget(label_gpgs3a, 5, 0, 1, 1);

        kcfg_GPGpWeight = new QDoubleSpinBox(settingsGroupBox);
        kcfg_GPGpWeight->setObjectName("kcfg_GPGpWeight");
        kcfg_GPGpWeight->setMinimum(0.000000000000000);
        kcfg_GPGpWeight->setMaximum(1.000000000000000);
        kcfg_GPGpWeight->setSingleStep(0.100000000000000);

        gridLayout2->addWidget(kcfg_GPGpWeight, 2, 1, 1, 1);

        kcfg_GPGDarkGuidingInterval = new QDoubleSpinBox(settingsGroupBox);
        kcfg_GPGDarkGuidingInterval->setObjectName("kcfg_GPGDarkGuidingInterval");
        kcfg_GPGDarkGuidingInterval->setMinimum(0.500000000000000);
        kcfg_GPGDarkGuidingInterval->setMaximum(3600.000000000000000);
        kcfg_GPGDarkGuidingInterval->setValue(1.000000000000000);

        gridLayout2->addWidget(kcfg_GPGDarkGuidingInterval, 4, 1, 1, 1);

        label_5 = new QLabel(settingsGroupBox);
        label_5->setObjectName("label_5");

        gridLayout2->addWidget(label_5, 4, 2, 1, 1);


        verticalLayout_4->addLayout(gridLayout2);


        verticalLayout_2->addWidget(settingsGroupBox);

        expertGroupBox = new QGroupBox(OpsGPG);
        expertGroupBox->setObjectName("expertGroupBox");
        verticalLayout_5 = new QVBoxLayout(expertGroupBox);
        verticalLayout_5->setSpacing(3);
        verticalLayout_5->setObjectName("verticalLayout_5");
        verticalLayout_5->setContentsMargins(3, 3, 3, 3);
        gridLayout3 = new QGridLayout();
        gridLayout3->setSpacing(3);
        gridLayout3->setObjectName("gridLayout3");
        label_gpgas0a = new QLabel(expertGroupBox);
        label_gpgas0a->setObjectName("label_gpgas0a");

        gridLayout3->addWidget(label_gpgas0a, 0, 0, 1, 1);

        kcfg_GPGSE0KLengthScale = new QSpinBox(expertGroupBox);
        kcfg_GPGSE0KLengthScale->setObjectName("kcfg_GPGSE0KLengthScale");
        kcfg_GPGSE0KLengthScale->setMinimum(0);
        kcfg_GPGSE0KLengthScale->setMaximum(10000);

        gridLayout3->addWidget(kcfg_GPGSE0KLengthScale, 0, 1, 1, 1);

        label_gpgas0c = new QLabel(expertGroupBox);
        label_gpgas0c->setObjectName("label_gpgas0c");

        gridLayout3->addWidget(label_gpgas0c, 0, 2, 1, 1);

        label_gpgas1a = new QLabel(expertGroupBox);
        label_gpgas1a->setObjectName("label_gpgas1a");

        gridLayout3->addWidget(label_gpgas1a, 1, 0, 1, 1);

        kcfg_GPGSE0KSignalVariance = new QDoubleSpinBox(expertGroupBox);
        kcfg_GPGSE0KSignalVariance->setObjectName("kcfg_GPGSE0KSignalVariance");
        kcfg_GPGSE0KSignalVariance->setMinimum(0.000000000000000);
        kcfg_GPGSE0KSignalVariance->setMaximum(1000.000000000000000);
        kcfg_GPGSE0KSignalVariance->setSingleStep(1.000000000000000);

        gridLayout3->addWidget(kcfg_GPGSE0KSignalVariance, 1, 1, 1, 1);

        label_gpgas1c = new QLabel(expertGroupBox);
        label_gpgas1c->setObjectName("label_gpgas1c");

        gridLayout3->addWidget(label_gpgas1c, 1, 2, 1, 1);

        label_gpgas2a = new QLabel(expertGroupBox);
        label_gpgas2a->setObjectName("label_gpgas2a");

        gridLayout3->addWidget(label_gpgas2a, 2, 0, 1, 1);

        kcfg_GPGPKLengthScale = new QSpinBox(expertGroupBox);
        kcfg_GPGPKLengthScale->setObjectName("kcfg_GPGPKLengthScale");
        kcfg_GPGPKLengthScale->setMinimum(0);
        kcfg_GPGPKLengthScale->setMaximum(10000);

        gridLayout3->addWidget(kcfg_GPGPKLengthScale, 2, 1, 1, 1);

        label_gpgas2c = new QLabel(expertGroupBox);
        label_gpgas2c->setObjectName("label_gpgas2c");

        gridLayout3->addWidget(label_gpgas2c, 2, 2, 1, 1);

        label_gpgas3a = new QLabel(expertGroupBox);
        label_gpgas3a->setObjectName("label_gpgas3a");

        gridLayout3->addWidget(label_gpgas3a, 3, 0, 1, 1);

        kcfg_GPGPKSignalVariance = new QDoubleSpinBox(expertGroupBox);
        kcfg_GPGPKSignalVariance->setObjectName("kcfg_GPGPKSignalVariance");
        kcfg_GPGPKSignalVariance->setMinimum(0.000000000000000);
        kcfg_GPGPKSignalVariance->setMaximum(1000.000000000000000);
        kcfg_GPGPKSignalVariance->setSingleStep(1.000000000000000);

        gridLayout3->addWidget(kcfg_GPGPKSignalVariance, 3, 1, 1, 1);

        label_gpgas3c = new QLabel(expertGroupBox);
        label_gpgas3c->setObjectName("label_gpgas3c");

        gridLayout3->addWidget(label_gpgas3c, 3, 2, 1, 1);

        label_gpgas4a = new QLabel(expertGroupBox);
        label_gpgas4a->setObjectName("label_gpgas4a");

        gridLayout3->addWidget(label_gpgas4a, 4, 0, 1, 1);

        kcfg_GPGSE1KLengthScale = new QSpinBox(expertGroupBox);
        kcfg_GPGSE1KLengthScale->setObjectName("kcfg_GPGSE1KLengthScale");
        kcfg_GPGSE1KLengthScale->setMinimum(0);
        kcfg_GPGSE1KLengthScale->setMaximum(1000);

        gridLayout3->addWidget(kcfg_GPGSE1KLengthScale, 4, 1, 1, 1);

        label_gpgas4c = new QLabel(expertGroupBox);
        label_gpgas4c->setObjectName("label_gpgas4c");

        gridLayout3->addWidget(label_gpgas4c, 4, 2, 1, 1);

        label_gpgas5a = new QLabel(expertGroupBox);
        label_gpgas5a->setObjectName("label_gpgas5a");

        gridLayout3->addWidget(label_gpgas5a, 5, 0, 1, 1);

        kcfg_GPGSE1KSignalVariance = new QDoubleSpinBox(expertGroupBox);
        kcfg_GPGSE1KSignalVariance->setObjectName("kcfg_GPGSE1KSignalVariance");
        kcfg_GPGSE1KSignalVariance->setMinimum(0.000000000000000);
        kcfg_GPGSE1KSignalVariance->setMaximum(1000.000000000000000);
        kcfg_GPGSE1KSignalVariance->setSingleStep(1.000000000000000);

        gridLayout3->addWidget(kcfg_GPGSE1KSignalVariance, 5, 1, 1, 1);

        label_gpgas5c = new QLabel(expertGroupBox);
        label_gpgas5c->setObjectName("label_gpgas5c");

        gridLayout3->addWidget(label_gpgas5c, 5, 2, 1, 1);

        label_gpgas6a = new QLabel(expertGroupBox);
        label_gpgas6a->setObjectName("label_gpgas6a");

        gridLayout3->addWidget(label_gpgas6a, 6, 0, 1, 1);

        kcfg_GPGPointsForApproximation = new QSpinBox(expertGroupBox);
        kcfg_GPGPointsForApproximation->setObjectName("kcfg_GPGPointsForApproximation");
        kcfg_GPGPointsForApproximation->setMinimum(0);
        kcfg_GPGPointsForApproximation->setMaximum(3600);

        gridLayout3->addWidget(kcfg_GPGPointsForApproximation, 6, 1, 1, 1);

        label_gpgas6c = new QLabel(expertGroupBox);
        label_gpgas6c->setObjectName("label_gpgas6c");

        gridLayout3->addWidget(label_gpgas6c, 6, 2, 1, 1);

        label_gpgas7a = new QLabel(expertGroupBox);
        label_gpgas7a->setObjectName("label_gpgas7a");

        gridLayout3->addWidget(label_gpgas7a, 7, 0, 1, 1);

        kcfg_GPGMinPeriodsForInference = new QSpinBox(expertGroupBox);
        kcfg_GPGMinPeriodsForInference->setObjectName("kcfg_GPGMinPeriodsForInference");
        kcfg_GPGMinPeriodsForInference->setMinimum(0);

        gridLayout3->addWidget(kcfg_GPGMinPeriodsForInference, 7, 1, 1, 1);

        label_gpgas7c = new QLabel(expertGroupBox);
        label_gpgas7c->setObjectName("label_gpgas7c");

        gridLayout3->addWidget(label_gpgas7c, 7, 2, 1, 1);

        label_gpgas8a = new QLabel(expertGroupBox);
        label_gpgas8a->setObjectName("label_gpgas8a");

        gridLayout3->addWidget(label_gpgas8a, 8, 0, 1, 1);

        kcfg_GPGMinPeriodsForPeriodEstimate = new QSpinBox(expertGroupBox);
        kcfg_GPGMinPeriodsForPeriodEstimate->setObjectName("kcfg_GPGMinPeriodsForPeriodEstimate");
        kcfg_GPGMinPeriodsForPeriodEstimate->setMinimum(0);

        gridLayout3->addWidget(kcfg_GPGMinPeriodsForPeriodEstimate, 8, 1, 1, 1);

        label_gpgas8c = new QLabel(expertGroupBox);
        label_gpgas8c->setObjectName("label_gpgas8c");

        gridLayout3->addWidget(label_gpgas8c, 8, 2, 1, 1);


        verticalLayout_5->addLayout(gridLayout3);


        verticalLayout_2->addWidget(expertGroupBox);


        retranslateUi(OpsGPG);

        QMetaObject::connectSlotsByName(OpsGPG);
    } // setupUi

    void retranslateUi(QWidget *OpsGPG)
    {
        copyrightGroupBox->setTitle(QString());
        label->setText(tr2i18n("<html><head/><body><p><a href=\"https://ieeexplore.ieee.org/document/7105398\"><span style=\" text-decoration: underline; color:#007af4;\">The Gaussian Process Guider</span></a>, <span style=\" font-style:italic;\">(c) 2014-2017 Max Planck Society</span>, is used for RA guiding only. Most parameters <br/>can stay at their defaults. <span style=\" font-weight:600; color:#8ae234;\">Enable GPG</span> with the checkbox below. It can be used with all Guide star-detection<br/>algorithms but has been tested most and is recommended with <span style=\" font-weight:600; color:#8ae234;\">SEP MultiStar</span>. It combines a reactive<br/>correction whose aggressiveness is controlled with <span style=\" font-weight:600; color:#8ae234;\">Control Gain</span> and <span style=\" font-weight:600; color:#8ae234;\">Minimum Move</span>, with a predictive<br/>correction controlled by <span style=\" font-weight:600; color:#8ae234;\">Prediction Gain</span>.</p><p>The most important parameter is <span style=\" font-weight:600; color:#8"
                        "ae234;\">Major Period</span>. If you can determine it for your mount, it's much <br/>better to set it yourself and uncheck <span style=\" font-weight:600; color:#8ae234;\">Estimate Period.</span></p><hr/></body></html>", nullptr));
        label_gpg0->setText(tr2i18n("Enable GPG on the Guide tab, using the RA Guiding Algorithm pulldown", nullptr));
        settingsGroupBox->setTitle(tr2i18n("Settings", nullptr));
#if QT_CONFIG(tooltip)
        label_4->setToolTip(tr2i18n("Maximum time between emitting predictive corrections while capturing guide images. This might be on the order of 1 second or less, with the guide exposure much longer. The exact values and the ratio between them will depend greatly on your mount and environmental conditions; but generally, the worse periodic error of your mount, the greater the ratio between guide exposure and dark guiding interval.", nullptr));
#endif // QT_CONFIG(tooltip)
        label_4->setText(tr2i18n("Dark guiding interval", nullptr));
        label_gpgs0c->setText(tr2i18n("seconds", nullptr));
#if QT_CONFIG(tooltip)
        label_gpgs0a->setToolTip(tr2i18n("The length in seconds of the mount's major period (that's being corrected).", nullptr));
#endif // QT_CONFIG(tooltip)
        label_gpgs0a->setText(tr2i18n("Major Period", nullptr));
#if QT_CONFIG(tooltip)
        label_gpgs2a->setToolTip(tr2i18n("The fraction of its prediction the GPG uses to move the mount.", nullptr));
#endif // QT_CONFIG(tooltip)
        label_gpgs2a->setText(tr2i18n("Prediction Gain", nullptr));
#if QT_CONFIG(tooltip)
        label_gpgsDarkGuiding->setToolTip(tr2i18n("Enable predictive corrections during acquisition of guide camera images", nullptr));
#endif // QT_CONFIG(tooltip)
        label_gpgsDarkGuiding->setText(tr2i18n("Intra-frame dark guiding", nullptr));
        label_gpgs2b->setText(QString());
#if QT_CONFIG(tooltip)
        kcfg_GPGPeriod->setToolTip(tr2i18n("The length in seconds of the mount's major period (that's being corrected).", nullptr));
#endif // QT_CONFIG(tooltip)
#if QT_CONFIG(tooltip)
        label_gpgs1a->setToolTip(tr2i18n("If checked, the GPG estimates the mount's major period. Otherwise, it uses the entry above.", nullptr));
#endif // QT_CONFIG(tooltip)
        label_gpgs1a->setText(tr2i18n("Estimate Period", nullptr));
        label_gpgs1b->setText(QString());
        label_2->setText(tr2i18n("Uses RA \"Aggressiveness\" from Guide controls", nullptr));
#if QT_CONFIG(tooltip)
        kcfg_GPGEstimatePeriod->setToolTip(tr2i18n("If checked, the GPG estimates the mount's major period. Otherwise, it uses the entry above.", nullptr));
#endif // QT_CONFIG(tooltip)
#if QT_CONFIG(tooltip)
        label_gpgs4a->setToolTip(tr2i18n("The min-move parameter the GPG uses to move the mount when it uses its backoff proportional guider.", nullptr));
#endif // QT_CONFIG(tooltip)
        label_gpgs4a->setText(tr2i18n("Minimum Move", nullptr));
        label_3->setText(tr2i18n("Uses RA \"Min error\" from Guide controls", nullptr));
#if QT_CONFIG(tooltip)
        kcfg_GPGDarkGuiding->setToolTip(tr2i18n("Enable predictive corrections during acquisition of guide camera images", nullptr));
#endif // QT_CONFIG(tooltip)
        kcfg_GPGDarkGuiding->setText(QString());
#if QT_CONFIG(tooltip)
        label_gpgs3a->setToolTip(tr2i18n("The fraction of the guide-star drift that the GPG uses to move the mount.", nullptr));
#endif // QT_CONFIG(tooltip)
        label_gpgs3a->setText(tr2i18n("Control Gain", nullptr));
#if QT_CONFIG(tooltip)
        kcfg_GPGpWeight->setToolTip(tr2i18n("The fraction of its prediction the GPG uses to move the mount.", nullptr));
#endif // QT_CONFIG(tooltip)
#if QT_CONFIG(tooltip)
        kcfg_GPGDarkGuidingInterval->setToolTip(tr2i18n("Maximum time between emitting predictive corrections while capturing guide images. This might be on the order of 1 second or less, with the guide exposure much longer. The exact values and the ratio between them will depend greatly on your mount and environmental conditions; but generally, the worse periodic error of your mount, the greater the ratio between guide exposure and dark guiding interval.", nullptr));
#endif // QT_CONFIG(tooltip)
        label_5->setText(tr2i18n("seconds", nullptr));
        expertGroupBox->setTitle(tr2i18n("Expert Settings", nullptr));
#if QT_CONFIG(tooltip)
        label_gpgas0a->setToolTip(tr2i18n("<html><head/><body><p>Length scale of the long range kernel in seconds.</p><p>This \n"
"          parameter accounts for the long-term drift in periodic error, on the scale of several major periods. This might be due to, for\n"
"          example:</p><ul style=\"margin-top: 0px; margin-bottom: 0px; margin-left: 0px; margin-right: 0px; -qt-list-indent:\n"
"          1;\"><li style=\" margin-top:12px; margin-bottom:0px; margin-left:0px; margin-right:0px; -qt-block-indent:0;\n"
"          text-indent:0px;\">Harmonic interaction between the gears in the whole gear train,</li><li style=\"\n"
"          margin-top:12px; margin-bottom:0px; margin-left:0px; margin-right:0px; -qt-block-indent:0; text-indent:0px;\">Change in\n"
"          loading due to gravity,</li><li style=\" margin-top:12px; margin-bottom:0px; margin-left:0px; margin-right:0px;\n"
"          -qt-block-indent:0; text-indent:0px;\">Thermal variations.</li></ul><p>This should probably be several\n"
"          times larger than the major period.</p></bo"
                        "dy></html>", nullptr));
#endif // QT_CONFIG(tooltip)
        label_gpgas0a->setText(tr2i18n("Long-range Length Scale", nullptr));
#if QT_CONFIG(tooltip)
        kcfg_GPGSE0KLengthScale->setToolTip(tr2i18n("<html><head/><body><p>Length scale of the long range kernel in seconds.</p><p>This \n"
"          parameter accounts for the long-term drift in periodic error, on the scale of several major periods. This might be due to, for\n"
"          example:</p><ul style=\"margin-top: 0px; margin-bottom: 0px; margin-left: 0px; margin-right: 0px; -qt-list-indent:\n"
"          1;\"><li style=\" margin-top:12px; margin-bottom:0px; margin-left:0px; margin-right:0px; -qt-block-indent:0;\n"
"          text-indent:0px;\">Harmonic interaction between the gears in the whole gear train,</li><li style=\"\n"
"          margin-top:12px; margin-bottom:0px; margin-left:0px; margin-right:0px; -qt-block-indent:0; text-indent:0px;\">Change in\n"
"          loading due to gravity,</li><li style=\" margin-top:12px; margin-bottom:0px; margin-left:0px; margin-right:0px;\n"
"          -qt-block-indent:0; text-indent:0px;\">Thermal variations.</li></ul><p>This should probably be several\n"
"          times larger than the major period.</p></bo"
                        "dy></html>", nullptr));
#endif // QT_CONFIG(tooltip)
        label_gpgas0c->setText(tr2i18n("seconds", nullptr));
#if QT_CONFIG(tooltip)
        label_gpgas1a->setToolTip(tr2i18n("<html><head/><body><p>Long-range kernel signal variance.</p><p>This describes how \n"
"          much the error changes over the long-term time scale. A higher variance means a larger change in error, on\n"
"          average.</p></body></html>", nullptr));
#endif // QT_CONFIG(tooltip)
        label_gpgas1a->setText(tr2i18n("Long-range Variance", nullptr));
#if QT_CONFIG(tooltip)
        kcfg_GPGSE0KSignalVariance->setToolTip(tr2i18n("<html><head/><body><p>Long-range kernel signal variance.</p><p>This describes how \n"
"          much the error changes over the long-term time scale. A higher variance means a larger change in error, on\n"
"          average.</p></body></html>", nullptr));
#endif // QT_CONFIG(tooltip)
        label_gpgas1c->setText(QString());
#if QT_CONFIG(tooltip)
        label_gpgas2a->setToolTip(tr2i18n("<html><head/><body><p>Periodic Kernel length scale, in seconds.</p><p>This \n"
"          describes how quickly the error changes within a single period. It can be thought of as the wavelength of the noise component\n"
"          above which the noise becomes unpredictable. A higher length scale means the predictable error has less high-frequency\n"
"          components; a shorter length-scale means it has more.</p></body></html>", nullptr));
#endif // QT_CONFIG(tooltip)
        label_gpgas2a->setText(tr2i18n("Periodic Length Scale", nullptr));
#if QT_CONFIG(tooltip)
        kcfg_GPGPKLengthScale->setToolTip(tr2i18n("<html><head/><body><p>Periodic Kernel length scale, in seconds.</p><p>This \n"
"          describes how quickly the error changes within a single period. It can be thought of as the wavelength of the noise component\n"
"          above which the noise becomes unpredictable. A higher length scale means the predictable error has less high-frequency\n"
"          components; a shorter length-scale means it has more.</p></body></html>", nullptr));
#endif // QT_CONFIG(tooltip)
        label_gpgas2c->setText(tr2i18n("seconds", nullptr));
#if QT_CONFIG(tooltip)
        label_gpgas3a->setToolTip(tr2i18n("<html><head/><body><p>Periodic kernel signal variance.</p><p>This describes how \n"
"          much the error changes during the periodic length scale.</p></body></html>", nullptr));
#endif // QT_CONFIG(tooltip)
        label_gpgas3a->setText(tr2i18n("Periodic Variance", nullptr));
#if QT_CONFIG(tooltip)
        kcfg_GPGPKSignalVariance->setToolTip(tr2i18n("<html><head/><body><p>Periodic kernel signal variance.</p><p>This describes how \n"
"          much the error changes during the periodic length scale.</p></body></html>", nullptr));
#endif // QT_CONFIG(tooltip)
        label_gpgas3c->setText(QString());
#if QT_CONFIG(tooltip)
        label_gpgas4a->setToolTip(tr2i18n("<html><head/><body><p>Length scale of the short-range kernel in \n"
"          seconds.</p><p>This is a measure of the scale of the non-periodic short-term noise, caused by things such\n"
"          as:</p><ul style=\"margin-top: 0px; margin-bottom: 0px; margin-left: 0px; margin-right: 0px; -qt-list-indent:\n"
"          1;\"><li style=\" margin-top:12px; margin-bottom:12px; margin-left:0px; margin-right:0px; -qt-block-indent:0;\n"
"          text-indent:0px;\">Grit in the gearchain,</li><li style=\" margin-top:12px; margin-bottom:12px;\n"
"          margin-left:0px; margin-right:0px; -qt-block-indent:0; text-indent:0px;\">Wind gusts,</li><li style=\"\n"
"          margin-top:12px; margin-bottom:12px; margin-left:0px; margin-right:0px; -qt-block-indent:0;\n"
"          text-indent:0px;\">Structural vibrations, such as footsteps or traffic,</li><li style=\" margin-top:12px;\n"
"          margin-bottom:12px; margin-left:0px; margin-right:0px; -qt-block-indent:0; text-indent:0px;\">Swinging or dragging\n"
"      "
                        "    cables.</li></ul></body></html>", nullptr));
#endif // QT_CONFIG(tooltip)
        label_gpgas4a->setText(tr2i18n("Short-range Length Scale", nullptr));
#if QT_CONFIG(tooltip)
        kcfg_GPGSE1KLengthScale->setToolTip(tr2i18n("<html><head/><body><p>Length scale of the short-range kernel in \n"
"          seconds.</p><p>This is a measure of the scale of the non-periodic short-term noise, caused by things such\n"
"          as:</p><ul style=\"margin-top: 0px; margin-bottom: 0px; margin-left: 0px; margin-right: 0px; -qt-list-indent:\n"
"          1;\"><li style=\" margin-top:12px; margin-bottom:12px; margin-left:0px; margin-right:0px; -qt-block-indent:0;\n"
"          text-indent:0px;\">Grit in the gearchain,</li><li style=\" margin-top:12px; margin-bottom:12px;\n"
"          margin-left:0px; margin-right:0px; -qt-block-indent:0; text-indent:0px;\">Wind gusts,</li><li style=\"\n"
"          margin-top:12px; margin-bottom:12px; margin-left:0px; margin-right:0px; -qt-block-indent:0;\n"
"          text-indent:0px;\">Structural vibrations, such as footsteps or traffic,</li><li style=\" margin-top:12px;\n"
"          margin-bottom:12px; margin-left:0px; margin-right:0px; -qt-block-indent:0; text-indent:0px;\">Swinging or dragging\n"
"      "
                        "    cables.</li></ul></body></html>", nullptr));
#endif // QT_CONFIG(tooltip)
        label_gpgas4c->setText(tr2i18n("seconds", nullptr));
#if QT_CONFIG(tooltip)
        label_gpgas5a->setToolTip(tr2i18n("<html><head/><body><p>Short-range kernel signal \n"
"          variance.</p><p><br/></p><p>How much the short-range noise changes in the short-term length\n"
"          scale.</p></body></html>", nullptr));
#endif // QT_CONFIG(tooltip)
        label_gpgas5a->setText(tr2i18n("Short-range Variance", nullptr));
#if QT_CONFIG(tooltip)
        kcfg_GPGSE1KSignalVariance->setToolTip(tr2i18n("<html><head/><body><p>Short-range kernel signal \n"
"          variance.</p><p><br/></p><p>How much the short-range noise changes in the short-term length\n"
"          scale.</p></body></html>", nullptr));
#endif // QT_CONFIG(tooltip)
        label_gpgas5c->setText(QString());
#if QT_CONFIG(tooltip)
        label_gpgas6a->setToolTip(tr2i18n("Number of points used in the Gaussian Process approximation", nullptr));
#endif // QT_CONFIG(tooltip)
        label_gpgas6a->setText(tr2i18n("Approximation Points", nullptr));
#if QT_CONFIG(tooltip)
        kcfg_GPGPointsForApproximation->setToolTip(tr2i18n("Number of points used in the Gaussian Process approximation", nullptr));
#endif // QT_CONFIG(tooltip)
        label_gpgas6c->setText(QString());
#if QT_CONFIG(tooltip)
        label_gpgas7a->setToolTip(tr2i18n("The min number of periods that must be sampled before prediction is fully used. Before that, it is mixed with the control/proportional guider.", nullptr));
#endif // QT_CONFIG(tooltip)
        label_gpgas7a->setText(tr2i18n("Num Periods for Inference", nullptr));
#if QT_CONFIG(tooltip)
        kcfg_GPGMinPeriodsForInference->setToolTip(tr2i18n("The min number of periods that must be sampled before prediction is fully used. Before that, it is mixed with the control/proportional guider.", nullptr));
#endif // QT_CONFIG(tooltip)
        label_gpgas7c->setText(QString());
#if QT_CONFIG(tooltip)
        label_gpgas8a->setToolTip(tr2i18n("The min number of periods that must be sampled before GPG fully estimates the period.", nullptr));
#endif // QT_CONFIG(tooltip)
        label_gpgas8a->setText(tr2i18n("Num Periods for Period Estimate", nullptr));
#if QT_CONFIG(tooltip)
        kcfg_GPGMinPeriodsForPeriodEstimate->setToolTip(tr2i18n("The min number of periods that must be sampled before GPG fully estimates the period.", nullptr));
#endif // QT_CONFIG(tooltip)
        label_gpgas8c->setText(QString());
        (void)OpsGPG;
    } // retranslateUi

};

namespace Ui {
    class OpsGPG: public Ui_OpsGPG {};
} // namespace Ui

QT_END_NAMESPACE

#endif // OPSGPG_H

