/********************************************************************************
** Form generated from reading UI file 'argzoom.ui'
**
** Created by: Qt User Interface Compiler version 6.11.1
**
** WARNING! All changes made in this file will be lost when recompiling UI file!
********************************************************************************/

#ifndef UI_ARGZOOM_H
#define UI_ARGZOOM_H

#include <QtCore/QVariant>
#include <QtWidgets/QApplication>
#include <QtWidgets/QHBoxLayout>
#include <QtWidgets/QLabel>
#include <QtWidgets/QLineEdit>
#include <QtWidgets/QSpacerItem>
#include <QtWidgets/QVBoxLayout>
#include <QtWidgets/QWidget>
#include <klocalizedstring.h>

QT_BEGIN_NAMESPACE

class Ui_ArgZoom
{
public:
    QVBoxLayout *vboxLayout;
    QHBoxLayout *hboxLayout;
    QLabel *textLabel1;
    QLineEdit *ZoomBox;
    QSpacerItem *spacerItem;
    QSpacerItem *spacerItem1;

    void setupUi(QWidget *ArgZoom)
    {
        if (ArgZoom->objectName().isEmpty())
            ArgZoom->setObjectName("ArgZoom");
        ArgZoom->resize(295, 69);
        vboxLayout = new QVBoxLayout(ArgZoom);
#ifndef UI_Q_OS_MAC
        vboxLayout->setSpacing(6);
#endif
        vboxLayout->setContentsMargins(10, 10, 10, 10);
        vboxLayout->setObjectName("vboxLayout");
        hboxLayout = new QHBoxLayout();
#ifndef UI_Q_OS_MAC
        hboxLayout->setSpacing(6);
#endif
#ifndef UI_Q_OS_MAC
        hboxLayout->setContentsMargins(0, 0, 0, 0);
#endif
        hboxLayout->setObjectName("hboxLayout");
        textLabel1 = new QLabel(ArgZoom);
        textLabel1->setObjectName("textLabel1");

        hboxLayout->addWidget(textLabel1);

        ZoomBox = new QLineEdit(ArgZoom);
        ZoomBox->setObjectName("ZoomBox");

        hboxLayout->addWidget(ZoomBox);

        spacerItem = new QSpacerItem(30, 20, QSizePolicy::Policy::Expanding, QSizePolicy::Policy::Minimum);

        hboxLayout->addItem(spacerItem);


        vboxLayout->addLayout(hboxLayout);

        spacerItem1 = new QSpacerItem(20, 40, QSizePolicy::Policy::Minimum, QSizePolicy::Policy::Expanding);

        vboxLayout->addItem(spacerItem1);


        retranslateUi(ArgZoom);

        QMetaObject::connectSlotsByName(ArgZoom);
    } // setupUi

    void retranslateUi(QWidget *ArgZoom)
    {
        textLabel1->setText(tr2i18n("Zoom level:", nullptr));
#if QT_CONFIG(tooltip)
        ZoomBox->setToolTip(tr2i18n("New Zoom level", nullptr));
#endif // QT_CONFIG(tooltip)
#if QT_CONFIG(whatsthis)
        ZoomBox->setWhatsThis(tr2i18n("Set the Zoom level for the display.  You can incrementally change this value using \"ZoomIn\" and \"ZoomOut\".  \n"
"\n"
"The Zoom level specifies the number of pixels which span one radian of arc.  Reasonable values should be between 300 and 10,000,000.\n"
"", nullptr));
#endif // QT_CONFIG(whatsthis)
        (void)ArgZoom;
    } // retranslateUi

};

namespace Ui {
    class ArgZoom: public Ui_ArgZoom {};
} // namespace Ui

QT_END_NAMESPACE

#endif // ARGZOOM_H

