/****************************************************************************
** Meta object code from reading C++ file 'schedulermodulestate.h'
**
** Created by: The Qt Meta Object Compiler version 69 (Qt 6.11.1)
**
** WARNING! All changes made in this file will be lost!
*****************************************************************************/

#include "../../../../kstars-3.8.4.1/kstars/ekos/scheduler/schedulermodulestate.h"
#include <QtCore/qmetatype.h>

#include <QtCore/qtmochelpers.h>

#include <memory>


#include <QtCore/qxptype_traits.h>
#if !defined(Q_MOC_OUTPUT_REVISION)
#error "The header file 'schedulermodulestate.h' doesn't include <QObject>."
#elif Q_MOC_OUTPUT_REVISION != 69
#error "This file was generated using the moc from 6.11.1. It"
#error "cannot be used with the include files from this version of Qt."
#error "(The moc has changed too much.)"
#endif

#ifndef Q_CONSTINIT
#define Q_CONSTINIT
#endif

QT_WARNING_PUSH
QT_WARNING_DISABLE_DEPRECATED
QT_WARNING_DISABLE_GCC("-Wuseless-cast")
namespace {
struct qt_meta_tag_ZN4Ekos20SchedulerModuleStateE_t {};
} // unnamed namespace

template <> constexpr inline auto Ekos::SchedulerModuleState::qt_create_metaobjectdata<qt_meta_tag_ZN4Ekos20SchedulerModuleStateE_t>()
{
    namespace QMC = QtMocConstants;
    QtMocHelpers::StringRefStorage qt_stringData {
        "Ekos::SchedulerModuleState",
        "ekosStateChanged",
        "",
        "EkosState",
        "state",
        "indiStateChanged",
        "INDIState",
        "indiCommunicationStatusChanged",
        "CommunicationStatus",
        "status",
        "schedulerStateChanged",
        "SchedulerState",
        "startupStateChanged",
        "StartupState",
        "shutdownStateChanged",
        "ShutdownState",
        "parkWaitStateChanged",
        "ParkWaitState",
        "profilesChanged",
        "currentProfileChanged",
        "scriptsChanged",
        "newLog",
        "text",
        "currentPositionChanged",
        "pos",
        "jobStageChanged",
        "SchedulerJobStage",
        "stage",
        "updateNightTime",
        "const SchedulerJob*",
        "job"
    };

    QtMocHelpers::UintData qt_methods {
        // Signal 'ekosStateChanged'
        QtMocHelpers::SignalData<void(EkosState)>(1, 2, QMC::AccessPublic, QMetaType::Void, {{
            { 0x80000000 | 3, 4 },
        }}),
        // Signal 'indiStateChanged'
        QtMocHelpers::SignalData<void(INDIState)>(5, 2, QMC::AccessPublic, QMetaType::Void, {{
            { 0x80000000 | 6, 4 },
        }}),
        // Signal 'indiCommunicationStatusChanged'
        QtMocHelpers::SignalData<void(CommunicationStatus)>(7, 2, QMC::AccessPublic, QMetaType::Void, {{
            { 0x80000000 | 8, 9 },
        }}),
        // Signal 'schedulerStateChanged'
        QtMocHelpers::SignalData<void(SchedulerState)>(10, 2, QMC::AccessPublic, QMetaType::Void, {{
            { 0x80000000 | 11, 4 },
        }}),
        // Signal 'startupStateChanged'
        QtMocHelpers::SignalData<void(StartupState)>(12, 2, QMC::AccessPublic, QMetaType::Void, {{
            { 0x80000000 | 13, 4 },
        }}),
        // Signal 'shutdownStateChanged'
        QtMocHelpers::SignalData<void(ShutdownState)>(14, 2, QMC::AccessPublic, QMetaType::Void, {{
            { 0x80000000 | 15, 4 },
        }}),
        // Signal 'parkWaitStateChanged'
        QtMocHelpers::SignalData<void(ParkWaitState)>(16, 2, QMC::AccessPublic, QMetaType::Void, {{
            { 0x80000000 | 17, 4 },
        }}),
        // Signal 'profilesChanged'
        QtMocHelpers::SignalData<void()>(18, 2, QMC::AccessPublic, QMetaType::Void),
        // Signal 'currentProfileChanged'
        QtMocHelpers::SignalData<void()>(19, 2, QMC::AccessPublic, QMetaType::Void),
        // Signal 'scriptsChanged'
        QtMocHelpers::SignalData<void()>(20, 2, QMC::AccessPublic, QMetaType::Void),
        // Signal 'newLog'
        QtMocHelpers::SignalData<void(const QString &)>(21, 2, QMC::AccessPublic, QMetaType::Void, {{
            { QMetaType::QString, 22 },
        }}),
        // Signal 'currentPositionChanged'
        QtMocHelpers::SignalData<void(int)>(23, 2, QMC::AccessPublic, QMetaType::Void, {{
            { QMetaType::Int, 24 },
        }}),
        // Signal 'jobStageChanged'
        QtMocHelpers::SignalData<void(SchedulerJobStage)>(25, 2, QMC::AccessPublic, QMetaType::Void, {{
            { 0x80000000 | 26, 27 },
        }}),
        // Signal 'updateNightTime'
        QtMocHelpers::SignalData<void(SchedulerJob const *)>(28, 2, QMC::AccessPublic, QMetaType::Void, {{
            { 0x80000000 | 29, 30 },
        }}),
        // Signal 'updateNightTime'
        QtMocHelpers::SignalData<void()>(28, 2, QMC::AccessPublic | QMC::MethodCloned, QMetaType::Void),
    };
    QtMocHelpers::UintData qt_properties {
    };
    QtMocHelpers::UintData qt_enums {
    };
    return QtMocHelpers::metaObjectData<SchedulerModuleState, qt_meta_tag_ZN4Ekos20SchedulerModuleStateE_t>(QMC::MetaObjectFlag{}, qt_stringData,
            qt_methods, qt_properties, qt_enums);
}
Q_CONSTINIT const QMetaObject Ekos::SchedulerModuleState::staticMetaObject = { {
    QMetaObject::SuperData::link<QObject::staticMetaObject>(),
    qt_staticMetaObjectStaticContent<qt_meta_tag_ZN4Ekos20SchedulerModuleStateE_t>.stringdata,
    qt_staticMetaObjectStaticContent<qt_meta_tag_ZN4Ekos20SchedulerModuleStateE_t>.data,
    qt_static_metacall,
    nullptr,
    qt_staticMetaObjectRelocatingContent<qt_meta_tag_ZN4Ekos20SchedulerModuleStateE_t>.metaTypes,
    nullptr
} };

void Ekos::SchedulerModuleState::qt_static_metacall(QObject *_o, QMetaObject::Call _c, int _id, void **_a)
{
    auto *_t = static_cast<SchedulerModuleState *>(_o);
    if (_c == QMetaObject::InvokeMetaMethod) {
        switch (_id) {
        case 0: _t->ekosStateChanged((*reinterpret_cast<std::add_pointer_t<EkosState>>(_a[1]))); break;
        case 1: _t->indiStateChanged((*reinterpret_cast<std::add_pointer_t<INDIState>>(_a[1]))); break;
        case 2: _t->indiCommunicationStatusChanged((*reinterpret_cast<std::add_pointer_t<CommunicationStatus>>(_a[1]))); break;
        case 3: _t->schedulerStateChanged((*reinterpret_cast<std::add_pointer_t<SchedulerState>>(_a[1]))); break;
        case 4: _t->startupStateChanged((*reinterpret_cast<std::add_pointer_t<StartupState>>(_a[1]))); break;
        case 5: _t->shutdownStateChanged((*reinterpret_cast<std::add_pointer_t<ShutdownState>>(_a[1]))); break;
        case 6: _t->parkWaitStateChanged((*reinterpret_cast<std::add_pointer_t<ParkWaitState>>(_a[1]))); break;
        case 7: _t->profilesChanged(); break;
        case 8: _t->currentProfileChanged(); break;
        case 9: _t->scriptsChanged(); break;
        case 10: _t->newLog((*reinterpret_cast<std::add_pointer_t<QString>>(_a[1]))); break;
        case 11: _t->currentPositionChanged((*reinterpret_cast<std::add_pointer_t<int>>(_a[1]))); break;
        case 12: _t->jobStageChanged((*reinterpret_cast<std::add_pointer_t<SchedulerJobStage>>(_a[1]))); break;
        case 13: _t->updateNightTime((*reinterpret_cast<std::add_pointer_t<const SchedulerJob*>>(_a[1]))); break;
        case 14: _t->updateNightTime(); break;
        default: ;
        }
    }
    if (_c == QMetaObject::IndexOfMethod) {
        if (QtMocHelpers::indexOfMethod<void (SchedulerModuleState::*)(EkosState )>(_a, &SchedulerModuleState::ekosStateChanged, 0))
            return;
        if (QtMocHelpers::indexOfMethod<void (SchedulerModuleState::*)(INDIState )>(_a, &SchedulerModuleState::indiStateChanged, 1))
            return;
        if (QtMocHelpers::indexOfMethod<void (SchedulerModuleState::*)(CommunicationStatus )>(_a, &SchedulerModuleState::indiCommunicationStatusChanged, 2))
            return;
        if (QtMocHelpers::indexOfMethod<void (SchedulerModuleState::*)(SchedulerState )>(_a, &SchedulerModuleState::schedulerStateChanged, 3))
            return;
        if (QtMocHelpers::indexOfMethod<void (SchedulerModuleState::*)(StartupState )>(_a, &SchedulerModuleState::startupStateChanged, 4))
            return;
        if (QtMocHelpers::indexOfMethod<void (SchedulerModuleState::*)(ShutdownState )>(_a, &SchedulerModuleState::shutdownStateChanged, 5))
            return;
        if (QtMocHelpers::indexOfMethod<void (SchedulerModuleState::*)(ParkWaitState )>(_a, &SchedulerModuleState::parkWaitStateChanged, 6))
            return;
        if (QtMocHelpers::indexOfMethod<void (SchedulerModuleState::*)()>(_a, &SchedulerModuleState::profilesChanged, 7))
            return;
        if (QtMocHelpers::indexOfMethod<void (SchedulerModuleState::*)()>(_a, &SchedulerModuleState::currentProfileChanged, 8))
            return;
        if (QtMocHelpers::indexOfMethod<void (SchedulerModuleState::*)()>(_a, &SchedulerModuleState::scriptsChanged, 9))
            return;
        if (QtMocHelpers::indexOfMethod<void (SchedulerModuleState::*)(const QString & )>(_a, &SchedulerModuleState::newLog, 10))
            return;
        if (QtMocHelpers::indexOfMethod<void (SchedulerModuleState::*)(int )>(_a, &SchedulerModuleState::currentPositionChanged, 11))
            return;
        if (QtMocHelpers::indexOfMethod<void (SchedulerModuleState::*)(SchedulerJobStage )>(_a, &SchedulerModuleState::jobStageChanged, 12))
            return;
        if (QtMocHelpers::indexOfMethod<void (SchedulerModuleState::*)(SchedulerJob const * )>(_a, &SchedulerModuleState::updateNightTime, 13))
            return;
    }
}

const QMetaObject *Ekos::SchedulerModuleState::metaObject() const
{
    return QObject::d_ptr->metaObject ? QObject::d_ptr->dynamicMetaObject() : &staticMetaObject;
}

void *Ekos::SchedulerModuleState::qt_metacast(const char *_clname)
{
    if (!_clname) return nullptr;
    if (!strcmp(_clname, qt_staticMetaObjectStaticContent<qt_meta_tag_ZN4Ekos20SchedulerModuleStateE_t>.strings))
        return static_cast<void*>(this);
    return QObject::qt_metacast(_clname);
}

int Ekos::SchedulerModuleState::qt_metacall(QMetaObject::Call _c, int _id, void **_a)
{
    _id = QObject::qt_metacall(_c, _id, _a);
    if (_id < 0)
        return _id;
    if (_c == QMetaObject::InvokeMetaMethod) {
        if (_id < 15)
            qt_static_metacall(this, _c, _id, _a);
        _id -= 15;
    }
    if (_c == QMetaObject::RegisterMethodArgumentMetaType) {
        if (_id < 15)
            *reinterpret_cast<QMetaType *>(_a[0]) = QMetaType();
        _id -= 15;
    }
    return _id;
}

// SIGNAL 0
void Ekos::SchedulerModuleState::ekosStateChanged(EkosState _t1)
{
    QMetaObject::activate<void>(this, &staticMetaObject, 0, nullptr, _t1);
}

// SIGNAL 1
void Ekos::SchedulerModuleState::indiStateChanged(INDIState _t1)
{
    QMetaObject::activate<void>(this, &staticMetaObject, 1, nullptr, _t1);
}

// SIGNAL 2
void Ekos::SchedulerModuleState::indiCommunicationStatusChanged(CommunicationStatus _t1)
{
    QMetaObject::activate<void>(this, &staticMetaObject, 2, nullptr, _t1);
}

// SIGNAL 3
void Ekos::SchedulerModuleState::schedulerStateChanged(SchedulerState _t1)
{
    QMetaObject::activate<void>(this, &staticMetaObject, 3, nullptr, _t1);
}

// SIGNAL 4
void Ekos::SchedulerModuleState::startupStateChanged(StartupState _t1)
{
    QMetaObject::activate<void>(this, &staticMetaObject, 4, nullptr, _t1);
}

// SIGNAL 5
void Ekos::SchedulerModuleState::shutdownStateChanged(ShutdownState _t1)
{
    QMetaObject::activate<void>(this, &staticMetaObject, 5, nullptr, _t1);
}

// SIGNAL 6
void Ekos::SchedulerModuleState::parkWaitStateChanged(ParkWaitState _t1)
{
    QMetaObject::activate<void>(this, &staticMetaObject, 6, nullptr, _t1);
}

// SIGNAL 7
void Ekos::SchedulerModuleState::profilesChanged()
{
    QMetaObject::activate(this, &staticMetaObject, 7, nullptr);
}

// SIGNAL 8
void Ekos::SchedulerModuleState::currentProfileChanged()
{
    QMetaObject::activate(this, &staticMetaObject, 8, nullptr);
}

// SIGNAL 9
void Ekos::SchedulerModuleState::scriptsChanged()
{
    QMetaObject::activate(this, &staticMetaObject, 9, nullptr);
}

// SIGNAL 10
void Ekos::SchedulerModuleState::newLog(const QString & _t1)
{
    QMetaObject::activate<void>(this, &staticMetaObject, 10, nullptr, _t1);
}

// SIGNAL 11
void Ekos::SchedulerModuleState::currentPositionChanged(int _t1)
{
    QMetaObject::activate<void>(this, &staticMetaObject, 11, nullptr, _t1);
}

// SIGNAL 12
void Ekos::SchedulerModuleState::jobStageChanged(SchedulerJobStage _t1)
{
    QMetaObject::activate<void>(this, &staticMetaObject, 12, nullptr, _t1);
}

// SIGNAL 13
void Ekos::SchedulerModuleState::updateNightTime(SchedulerJob const * _t1)
{
    QMetaObject::activate<void>(this, &staticMetaObject, 13, nullptr, _t1);
}
QT_WARNING_POP
