/********************************************************************************
** Form generated from reading UI file 'capturehistorynavigation.ui'
**
** Created by: Qt User Interface Compiler version 6.11.1
**
** WARNING! All changes made in this file will be lost when recompiling UI file!
********************************************************************************/

#ifndef UI_CAPTUREHISTORYNAVIGATION_H
#define UI_CAPTUREHISTORYNAVIGATION_H

#include <QtCore/QVariant>
#include <QtGui/QIcon>
#include <QtWidgets/QApplication>
#include <QtWidgets/QHBoxLayout>
#include <QtWidgets/QLabel>
#include <QtWidgets/QPushButton>
#include <QtWidgets/QSpacerItem>
#include <QtWidgets/QVBoxLayout>
#include <QtWidgets/QWidget>
#include <klocalizedstring.h>

QT_BEGIN_NAMESPACE

class Ui_CaptureHistoryNavigation
{
public:
    QVBoxLayout *verticalLayout;
    QLabel *filenameValue;
    QHBoxLayout *horizontalLayout_4;
    QSpacerItem *horizontalSpacer_3;
    QPushButton *historyPreviousRunB;
    QPushButton *historyFirstB;
    QPushButton *historyBackwardB;
    QLabel *iterOut;
    QPushButton *historyForwardB;
    QPushButton *historyLastB;
    QPushButton *historyNextRunB;
    QSpacerItem *horizontalSpacer_4;

    void setupUi(QWidget *CaptureHistoryNavigation)
    {
        if (CaptureHistoryNavigation->objectName().isEmpty())
            CaptureHistoryNavigation->setObjectName("CaptureHistoryNavigation");
        CaptureHistoryNavigation->resize(400, 49);
        CaptureHistoryNavigation->setStyleSheet(QString::fromUtf8(""));
        verticalLayout = new QVBoxLayout(CaptureHistoryNavigation);
        verticalLayout->setSpacing(2);
        verticalLayout->setObjectName("verticalLayout");
        verticalLayout->setContentsMargins(0, 0, 0, 0);
        filenameValue = new QLabel(CaptureHistoryNavigation);
        filenameValue->setObjectName("filenameValue");
        QFont font;
        font.setPointSize(8);
        filenameValue->setFont(font);

        verticalLayout->addWidget(filenameValue);

        horizontalLayout_4 = new QHBoxLayout();
        horizontalLayout_4->setObjectName("horizontalLayout_4");
        horizontalSpacer_3 = new QSpacerItem(3, 10, QSizePolicy::Policy::Expanding, QSizePolicy::Policy::Minimum);

        horizontalLayout_4->addItem(horizontalSpacer_3);

        historyPreviousRunB = new QPushButton(CaptureHistoryNavigation);
        historyPreviousRunB->setObjectName("historyPreviousRunB");
        QIcon icon;
        QString iconThemeName = QString::fromUtf8("media-skip-backward");
        if (QIcon::hasThemeIcon(iconThemeName)) {
            icon = QIcon::fromTheme(iconThemeName);
        } else {
            icon.addFile(QString::fromUtf8("."), QSize(), QIcon::Mode::Normal, QIcon::State::Off);
        }
        historyPreviousRunB->setIcon(icon);
        historyPreviousRunB->setIconSize(QSize(20, 20));

        horizontalLayout_4->addWidget(historyPreviousRunB);

        historyFirstB = new QPushButton(CaptureHistoryNavigation);
        historyFirstB->setObjectName("historyFirstB");
        QIcon icon1;
        iconThemeName = QString::fromUtf8("media-seek-backward");
        if (QIcon::hasThemeIcon(iconThemeName)) {
            icon1 = QIcon::fromTheme(iconThemeName);
        } else {
            icon1.addFile(QString::fromUtf8("."), QSize(), QIcon::Mode::Normal, QIcon::State::Off);
        }
        historyFirstB->setIcon(icon1);
        historyFirstB->setIconSize(QSize(20, 20));

        horizontalLayout_4->addWidget(historyFirstB);

        historyBackwardB = new QPushButton(CaptureHistoryNavigation);
        historyBackwardB->setObjectName("historyBackwardB");
        QIcon icon2;
        iconThemeName = QString::fromUtf8("go-previous");
        if (QIcon::hasThemeIcon(iconThemeName)) {
            icon2 = QIcon::fromTheme(iconThemeName);
        } else {
            icon2.addFile(QString::fromUtf8("."), QSize(), QIcon::Mode::Normal, QIcon::State::Off);
        }
        historyBackwardB->setIcon(icon2);
        historyBackwardB->setIconSize(QSize(20, 20));

        horizontalLayout_4->addWidget(historyBackwardB);

        iterOut = new QLabel(CaptureHistoryNavigation);
        iterOut->setObjectName("iterOut");

        horizontalLayout_4->addWidget(iterOut);

        historyForwardB = new QPushButton(CaptureHistoryNavigation);
        historyForwardB->setObjectName("historyForwardB");
        QIcon icon3;
        iconThemeName = QString::fromUtf8("go-next");
        if (QIcon::hasThemeIcon(iconThemeName)) {
            icon3 = QIcon::fromTheme(iconThemeName);
        } else {
            icon3.addFile(QString::fromUtf8("."), QSize(), QIcon::Mode::Normal, QIcon::State::Off);
        }
        historyForwardB->setIcon(icon3);
        historyForwardB->setIconSize(QSize(20, 20));

        horizontalLayout_4->addWidget(historyForwardB);

        historyLastB = new QPushButton(CaptureHistoryNavigation);
        historyLastB->setObjectName("historyLastB");
        QIcon icon4;
        iconThemeName = QString::fromUtf8("media-seek-forward");
        if (QIcon::hasThemeIcon(iconThemeName)) {
            icon4 = QIcon::fromTheme(iconThemeName);
        } else {
            icon4.addFile(QString::fromUtf8("."), QSize(), QIcon::Mode::Normal, QIcon::State::Off);
        }
        historyLastB->setIcon(icon4);
        historyLastB->setIconSize(QSize(20, 20));

        horizontalLayout_4->addWidget(historyLastB);

        historyNextRunB = new QPushButton(CaptureHistoryNavigation);
        historyNextRunB->setObjectName("historyNextRunB");
        QIcon icon5;
        iconThemeName = QString::fromUtf8("media-skip-forward");
        if (QIcon::hasThemeIcon(iconThemeName)) {
            icon5 = QIcon::fromTheme(iconThemeName);
        } else {
            icon5.addFile(QString::fromUtf8("."), QSize(), QIcon::Mode::Normal, QIcon::State::Off);
        }
        historyNextRunB->setIcon(icon5);
        historyNextRunB->setIconSize(QSize(20, 20));

        horizontalLayout_4->addWidget(historyNextRunB);

        horizontalSpacer_4 = new QSpacerItem(3, 10, QSizePolicy::Policy::Expanding, QSizePolicy::Policy::Minimum);

        horizontalLayout_4->addItem(horizontalSpacer_4);


        verticalLayout->addLayout(horizontalLayout_4);


        retranslateUi(CaptureHistoryNavigation);

        QMetaObject::connectSlotsByName(CaptureHistoryNavigation);
    } // setupUi

    void retranslateUi(QWidget *CaptureHistoryNavigation)
    {
        CaptureHistoryNavigation->setWindowTitle(QString());
        filenameValue->setText(tr2i18n("<Filename>", nullptr));
#if QT_CONFIG(tooltip)
        historyPreviousRunB->setToolTip(tr2i18n("Previous autofocus run", nullptr));
#endif // QT_CONFIG(tooltip)
        historyPreviousRunB->setText(QString());
#if QT_CONFIG(tooltip)
        historyFirstB->setToolTip(tr2i18n("First focusing frame", nullptr));
#endif // QT_CONFIG(tooltip)
        historyFirstB->setText(QString());
#if QT_CONFIG(tooltip)
        historyBackwardB->setToolTip(tr2i18n("Previous focusing frame", nullptr));
#endif // QT_CONFIG(tooltip)
        historyBackwardB->setText(QString());
#if QT_CONFIG(tooltip)
        iterOut->setToolTip(tr2i18n("<html><body><p>Focuser iteration.</p></body></html>", nullptr));
#endif // QT_CONFIG(tooltip)
        iterOut->setText(tr2i18n("--", nullptr));
#if QT_CONFIG(tooltip)
        historyForwardB->setToolTip(tr2i18n("Next focusing frame", nullptr));
#endif // QT_CONFIG(tooltip)
        historyForwardB->setText(QString());
#if QT_CONFIG(tooltip)
        historyLastB->setToolTip(tr2i18n("Last focusing frame", nullptr));
#endif // QT_CONFIG(tooltip)
        historyLastB->setText(QString());
#if QT_CONFIG(tooltip)
        historyNextRunB->setToolTip(tr2i18n("Next autofocus run", nullptr));
#endif // QT_CONFIG(tooltip)
        historyNextRunB->setText(QString());
    } // retranslateUi

};

namespace Ui {
    class CaptureHistoryNavigation: public Ui_CaptureHistoryNavigation {};
} // namespace Ui

QT_END_NAMESPACE

#endif // CAPTUREHISTORYNAVIGATION_H

