/********************************************************************************
** Form generated from reading UI file 'buildfilteroffsets.ui'
**
** Created by: Qt User Interface Compiler version 6.11.1
**
** WARNING! All changes made in this file will be lost when recompiling UI file!
********************************************************************************/

#ifndef UI_BUILDFILTEROFFSETS_H
#define UI_BUILDFILTEROFFSETS_H

#include <QtCore/QVariant>
#include <QtWidgets/QAbstractButton>
#include <QtWidgets/QApplication>
#include <QtWidgets/QCheckBox>
#include <QtWidgets/QDialog>
#include <QtWidgets/QDialogButtonBox>
#include <QtWidgets/QGridLayout>
#include <QtWidgets/QHeaderView>
#include <QtWidgets/QProgressBar>
#include <QtWidgets/QStatusBar>
#include <QtWidgets/QTableView>
#include <klocalizedstring.h>

QT_BEGIN_NAMESPACE

class Ui_buildOffsetsDialog
{
public:
    QGridLayout *gridLayout;
    QTableView *buildOffsetsTableView;
    QCheckBox *buildOffsetsAdaptFocus;
    QDialogButtonBox *buildOffsetsButtonBox;
    QProgressBar *buildOffsetsProgressBar;
    QStatusBar *buildOffsetsStatusBar;

    void setupUi(QDialog *buildOffsetsDialog)
    {
        if (buildOffsetsDialog->objectName().isEmpty())
            buildOffsetsDialog->setObjectName("buildOffsetsDialog");
        buildOffsetsDialog->setWindowModality(Qt::ApplicationModal);
        buildOffsetsDialog->resize(436, 315);
        QSizePolicy sizePolicy(QSizePolicy::Policy::MinimumExpanding, QSizePolicy::Policy::MinimumExpanding);
        sizePolicy.setHorizontalStretch(0);
        sizePolicy.setVerticalStretch(0);
        sizePolicy.setHeightForWidth(buildOffsetsDialog->sizePolicy().hasHeightForWidth());
        buildOffsetsDialog->setSizePolicy(sizePolicy);
        buildOffsetsDialog->setModal(true);
        gridLayout = new QGridLayout(buildOffsetsDialog);
        gridLayout->setObjectName("gridLayout");
        buildOffsetsTableView = new QTableView(buildOffsetsDialog);
        buildOffsetsTableView->setObjectName("buildOffsetsTableView");
        buildOffsetsTableView->setSizeAdjustPolicy(QAbstractScrollArea::AdjustToContents);
        buildOffsetsTableView->setDragEnabled(false);
        buildOffsetsTableView->setSelectionMode(QAbstractItemView::SingleSelection);

        gridLayout->addWidget(buildOffsetsTableView, 0, 0, 1, 2);

        buildOffsetsAdaptFocus = new QCheckBox(buildOffsetsDialog);
        buildOffsetsAdaptFocus->setObjectName("buildOffsetsAdaptFocus");

        gridLayout->addWidget(buildOffsetsAdaptFocus, 1, 0, 1, 1);

        buildOffsetsButtonBox = new QDialogButtonBox(buildOffsetsDialog);
        buildOffsetsButtonBox->setObjectName("buildOffsetsButtonBox");
        buildOffsetsButtonBox->setStandardButtons(QDialogButtonBox::Close|QDialogButtonBox::Save);

        gridLayout->addWidget(buildOffsetsButtonBox, 1, 1, 1, 1);

        buildOffsetsProgressBar = new QProgressBar(buildOffsetsDialog);
        buildOffsetsProgressBar->setObjectName("buildOffsetsProgressBar");
        buildOffsetsProgressBar->setValue(0);

        gridLayout->addWidget(buildOffsetsProgressBar, 2, 0, 1, 2);

        buildOffsetsStatusBar = new QStatusBar(buildOffsetsDialog);
        buildOffsetsStatusBar->setObjectName("buildOffsetsStatusBar");

        gridLayout->addWidget(buildOffsetsStatusBar, 3, 0, 1, 2);


        retranslateUi(buildOffsetsDialog);

        QMetaObject::connectSlotsByName(buildOffsetsDialog);
    } // setupUi

    void retranslateUi(QDialog *buildOffsetsDialog)
    {
        buildOffsetsDialog->setWindowTitle(tr2i18n("Build Filter Offsets", nullptr));
#if QT_CONFIG(tooltip)
        buildOffsetsAdaptFocus->setToolTip(tr2i18n("<html><head/><body><p>Check to apply Adaptive focus to Autofocus runs.</p></body></html>", nullptr));
#endif // QT_CONFIG(tooltip)
        buildOffsetsAdaptFocus->setText(tr2i18n("Adapt Focus", nullptr));
        buildOffsetsProgressBar->setFormat(tr2i18n("%p%", nullptr));
    } // retranslateUi

};

namespace Ui {
    class buildOffsetsDialog: public Ui_buildOffsetsDialog {};
} // namespace Ui

QT_END_NAMESPACE

#endif // BUILDFILTEROFFSETS_H

