/****************************************************************************
** Meta object code from reading C++ file 'cameraprocess.h'
**
** Created by: The Qt Meta Object Compiler version 69 (Qt 6.11.1)
**
** WARNING! All changes made in this file will be lost!
*****************************************************************************/

#include "../../../../kstars-3.8.4.1/kstars/ekos/capture/cameraprocess.h"
#include <QtNetwork/QSslError>
#include <QtDataVisualization/qbar3dseries.h>
#include <QtDataVisualization/q3dscene.h>
#include <QtGui/qtextcursor.h>
#include <QtCore/qmetatype.h>
#include <QtCore/QSharedPointer>

#include <QtCore/qtmochelpers.h>

#include <memory>


#include <QtCore/qxptype_traits.h>
#if !defined(Q_MOC_OUTPUT_REVISION)
#error "The header file 'cameraprocess.h' doesn't include <QObject>."
#elif Q_MOC_OUTPUT_REVISION != 69
#error "This file was generated using the moc from 6.11.1. It"
#error "cannot be used with the include files from this version of Qt."
#error "(The moc has changed too much.)"
#endif

#ifndef Q_CONSTINIT
#define Q_CONSTINIT
#endif

QT_WARNING_PUSH
QT_WARNING_DISABLE_DEPRECATED
QT_WARNING_DISABLE_GCC("-Wuseless-cast")
namespace {
struct qt_meta_tag_ZN4Ekos13CameraProcessE_t {};
} // unnamed namespace

template <> constexpr inline auto Ekos::CameraProcess::qt_create_metaobjectdata<qt_meta_tag_ZN4Ekos13CameraProcessE_t>()
{
    namespace QMC = QtMocConstants;
    QtMocHelpers::StringRefStorage qt_stringData {
        "Ekos::CameraProcess",
        "addJob",
        "",
        "QSharedPointer<SequenceJob>",
        "job",
        "createJob",
        "SequenceJob::SequenceJobType",
        "jobtype",
        "jobStarting",
        "stopCapture",
        "CaptureState",
        "targetState",
        "captureAborted",
        "exposureSeconds",
        "captureStopped",
        "requestAction",
        "CaptureWorkflowActionType",
        "action",
        "syncGUIToJob",
        "updateFrameProperties",
        "reset",
        "updateJobTable",
        "full",
        "jobExecutionPreparationStarted",
        "jobPrepared",
        "captureImageStarted",
        "captureTarget",
        "targetName",
        "captureRunning",
        "newExposureProgress",
        "newDownloadProgress",
        "downloadTimeLeft",
        "downloadingFrame",
        "updateCaptureCountDown",
        "deltaMS",
        "darkFrameCompleted",
        "updateMeridianFlipStage",
        "MeridianFlipState::MFStage",
        "stage",
        "cameraReady",
        "refreshCamera",
        "isValid",
        "refreshCameraSettings",
        "refreshFilterSettings",
        "processingFITSfinished",
        "success",
        "rotatorReverseToggled",
        "enabled",
        "newImage",
        "QSharedPointer<FITSData>",
        "data",
        "newView",
        "QSharedPointer<FITSView>",
        "view",
        "suspendGuiding",
        "resumeGuiding",
        "abortFocus",
        "captureComplete",
        "QVariantMap",
        "metadata",
        "sequenceChanged",
        "QJsonArray",
        "sequence",
        "driverTimedout",
        "deviceName",
        "newLog",
        "text",
        "toggleSequence",
        "pauseCapturing",
        "executeJob",
        "resetFrame"
    };

    QtMocHelpers::UintData qt_methods {
        // Signal 'addJob'
        QtMocHelpers::SignalData<void(const QSharedPointer<SequenceJob> &)>(1, 2, QMC::AccessPublic, QMetaType::Void, {{
            { 0x80000000 | 3, 4 },
        }}),
        // Signal 'createJob'
        QtMocHelpers::SignalData<void(SequenceJob::SequenceJobType)>(5, 2, QMC::AccessPublic, QMetaType::Void, {{
            { 0x80000000 | 6, 7 },
        }}),
        // Signal 'createJob'
        QtMocHelpers::SignalData<void()>(5, 2, QMC::AccessPublic | QMC::MethodCloned, QMetaType::Void),
        // Signal 'jobStarting'
        QtMocHelpers::SignalData<void()>(8, 2, QMC::AccessPublic, QMetaType::Void),
        // Signal 'stopCapture'
        QtMocHelpers::SignalData<void(CaptureState)>(9, 2, QMC::AccessPublic, QMetaType::Void, {{
            { 0x80000000 | 10, 11 },
        }}),
        // Signal 'stopCapture'
        QtMocHelpers::SignalData<void()>(9, 2, QMC::AccessPublic | QMC::MethodCloned, QMetaType::Void),
        // Signal 'captureAborted'
        QtMocHelpers::SignalData<void(double)>(12, 2, QMC::AccessPublic, QMetaType::Void, {{
            { QMetaType::Double, 13 },
        }}),
        // Signal 'captureStopped'
        QtMocHelpers::SignalData<void()>(14, 2, QMC::AccessPublic, QMetaType::Void),
        // Signal 'requestAction'
        QtMocHelpers::SignalData<void(CaptureWorkflowActionType)>(15, 2, QMC::AccessPublic, QMetaType::Void, {{
            { 0x80000000 | 16, 17 },
        }}),
        // Signal 'syncGUIToJob'
        QtMocHelpers::SignalData<void(const QSharedPointer<SequenceJob> &)>(18, 2, QMC::AccessPublic, QMetaType::Void, {{
            { 0x80000000 | 3, 4 },
        }}),
        // Signal 'updateFrameProperties'
        QtMocHelpers::SignalData<void(int)>(19, 2, QMC::AccessPublic, QMetaType::Void, {{
            { QMetaType::Int, 20 },
        }}),
        // Signal 'updateJobTable'
        QtMocHelpers::SignalData<void(const QSharedPointer<SequenceJob> &, bool)>(21, 2, QMC::AccessPublic, QMetaType::Void, {{
            { 0x80000000 | 3, 4 }, { QMetaType::Bool, 22 },
        }}),
        // Signal 'updateJobTable'
        QtMocHelpers::SignalData<void(const QSharedPointer<SequenceJob> &)>(21, 2, QMC::AccessPublic | QMC::MethodCloned, QMetaType::Void, {{
            { 0x80000000 | 3, 4 },
        }}),
        // Signal 'jobExecutionPreparationStarted'
        QtMocHelpers::SignalData<void()>(23, 2, QMC::AccessPublic, QMetaType::Void),
        // Signal 'jobPrepared'
        QtMocHelpers::SignalData<void(const QSharedPointer<SequenceJob> &)>(24, 2, QMC::AccessPublic, QMetaType::Void, {{
            { 0x80000000 | 3, 4 },
        }}),
        // Signal 'captureImageStarted'
        QtMocHelpers::SignalData<void()>(25, 2, QMC::AccessPublic, QMetaType::Void),
        // Signal 'captureTarget'
        QtMocHelpers::SignalData<void(QString)>(26, 2, QMC::AccessPublic, QMetaType::Void, {{
            { QMetaType::QString, 27 },
        }}),
        // Signal 'captureRunning'
        QtMocHelpers::SignalData<void()>(28, 2, QMC::AccessPublic, QMetaType::Void),
        // Signal 'newExposureProgress'
        QtMocHelpers::SignalData<void(const QSharedPointer<SequenceJob> &)>(29, 2, QMC::AccessPublic, QMetaType::Void, {{
            { 0x80000000 | 3, 4 },
        }}),
        // Signal 'newDownloadProgress'
        QtMocHelpers::SignalData<void(double)>(30, 2, QMC::AccessPublic, QMetaType::Void, {{
            { QMetaType::Double, 31 },
        }}),
        // Signal 'downloadingFrame'
        QtMocHelpers::SignalData<void()>(32, 2, QMC::AccessPublic, QMetaType::Void),
        // Signal 'updateCaptureCountDown'
        QtMocHelpers::SignalData<void(int)>(33, 2, QMC::AccessPublic, QMetaType::Void, {{
            { QMetaType::Int, 34 },
        }}),
        // Signal 'darkFrameCompleted'
        QtMocHelpers::SignalData<void()>(35, 2, QMC::AccessPublic, QMetaType::Void),
        // Signal 'updateMeridianFlipStage'
        QtMocHelpers::SignalData<void(MeridianFlipState::MFStage)>(36, 2, QMC::AccessPublic, QMetaType::Void, {{
            { 0x80000000 | 37, 38 },
        }}),
        // Signal 'cameraReady'
        QtMocHelpers::SignalData<void()>(39, 2, QMC::AccessPublic, QMetaType::Void),
        // Signal 'refreshCamera'
        QtMocHelpers::SignalData<void(bool)>(40, 2, QMC::AccessPublic, QMetaType::Void, {{
            { QMetaType::Bool, 41 },
        }}),
        // Signal 'refreshCameraSettings'
        QtMocHelpers::SignalData<void()>(42, 2, QMC::AccessPublic, QMetaType::Void),
        // Signal 'refreshFilterSettings'
        QtMocHelpers::SignalData<void()>(43, 2, QMC::AccessPublic, QMetaType::Void),
        // Signal 'processingFITSfinished'
        QtMocHelpers::SignalData<void(bool)>(44, 2, QMC::AccessPublic, QMetaType::Void, {{
            { QMetaType::Bool, 45 },
        }}),
        // Signal 'rotatorReverseToggled'
        QtMocHelpers::SignalData<void(bool)>(46, 2, QMC::AccessPublic, QMetaType::Void, {{
            { QMetaType::Bool, 47 },
        }}),
        // Signal 'newImage'
        QtMocHelpers::SignalData<void(const QSharedPointer<SequenceJob> &, const QSharedPointer<FITSData> &)>(48, 2, QMC::AccessPublic, QMetaType::Void, {{
            { 0x80000000 | 3, 4 }, { 0x80000000 | 49, 50 },
        }}),
        // Signal 'newView'
        QtMocHelpers::SignalData<void(const QSharedPointer<FITSView> &)>(51, 2, QMC::AccessPublic, QMetaType::Void, {{
            { 0x80000000 | 52, 53 },
        }}),
        // Signal 'suspendGuiding'
        QtMocHelpers::SignalData<void()>(54, 2, QMC::AccessPublic, QMetaType::Void),
        // Signal 'resumeGuiding'
        QtMocHelpers::SignalData<void()>(55, 2, QMC::AccessPublic, QMetaType::Void),
        // Signal 'abortFocus'
        QtMocHelpers::SignalData<void()>(56, 2, QMC::AccessPublic, QMetaType::Void),
        // Signal 'captureComplete'
        QtMocHelpers::SignalData<void(const QVariantMap &)>(57, 2, QMC::AccessPublic, QMetaType::Void, {{
            { 0x80000000 | 58, 59 },
        }}),
        // Signal 'sequenceChanged'
        QtMocHelpers::SignalData<void(const QJsonArray &)>(60, 2, QMC::AccessPublic, QMetaType::Void, {{
            { 0x80000000 | 61, 62 },
        }}),
        // Signal 'driverTimedout'
        QtMocHelpers::SignalData<void(const QString &)>(63, 2, QMC::AccessPublic, QMetaType::Void, {{
            { QMetaType::QString, 64 },
        }}),
        // Signal 'newLog'
        QtMocHelpers::SignalData<void(const QString &)>(65, 2, QMC::AccessPublic, QMetaType::Void, {{
            { QMetaType::QString, 66 },
        }}),
        // Method 'toggleSequence'
        QtMocHelpers::MethodData<void()>(67, 2, QMC::AccessPublic | QMC::MethodScriptable, QMetaType::Void),
        // Method 'pauseCapturing'
        QtMocHelpers::MethodData<void()>(68, 2, QMC::AccessPublic | QMC::MethodScriptable, QMetaType::Void),
        // Method 'executeJob'
        QtMocHelpers::MethodData<void()>(69, 2, QMC::AccessPublic | QMC::MethodScriptable, QMetaType::Void),
        // Method 'resetFrame'
        QtMocHelpers::MethodData<void()>(70, 2, QMC::AccessPublic | QMC::MethodScriptable, QMetaType::Void),
    };
    QtMocHelpers::UintData qt_properties {
    };
    QtMocHelpers::UintData qt_enums {
    };
    return QtMocHelpers::metaObjectData<CameraProcess, qt_meta_tag_ZN4Ekos13CameraProcessE_t>(QMC::MetaObjectFlag{}, qt_stringData,
            qt_methods, qt_properties, qt_enums);
}
Q_CONSTINIT const QMetaObject Ekos::CameraProcess::staticMetaObject = { {
    QMetaObject::SuperData::link<QObject::staticMetaObject>(),
    qt_staticMetaObjectStaticContent<qt_meta_tag_ZN4Ekos13CameraProcessE_t>.stringdata,
    qt_staticMetaObjectStaticContent<qt_meta_tag_ZN4Ekos13CameraProcessE_t>.data,
    qt_static_metacall,
    nullptr,
    qt_staticMetaObjectRelocatingContent<qt_meta_tag_ZN4Ekos13CameraProcessE_t>.metaTypes,
    nullptr
} };

void Ekos::CameraProcess::qt_static_metacall(QObject *_o, QMetaObject::Call _c, int _id, void **_a)
{
    auto *_t = static_cast<CameraProcess *>(_o);
    if (_c == QMetaObject::InvokeMetaMethod) {
        switch (_id) {
        case 0: _t->addJob((*reinterpret_cast<std::add_pointer_t<QSharedPointer<SequenceJob>>>(_a[1]))); break;
        case 1: _t->createJob((*reinterpret_cast<std::add_pointer_t<SequenceJob::SequenceJobType>>(_a[1]))); break;
        case 2: _t->createJob(); break;
        case 3: _t->jobStarting(); break;
        case 4: _t->stopCapture((*reinterpret_cast<std::add_pointer_t<CaptureState>>(_a[1]))); break;
        case 5: _t->stopCapture(); break;
        case 6: _t->captureAborted((*reinterpret_cast<std::add_pointer_t<double>>(_a[1]))); break;
        case 7: _t->captureStopped(); break;
        case 8: _t->requestAction((*reinterpret_cast<std::add_pointer_t<CaptureWorkflowActionType>>(_a[1]))); break;
        case 9: _t->syncGUIToJob((*reinterpret_cast<std::add_pointer_t<QSharedPointer<SequenceJob>>>(_a[1]))); break;
        case 10: _t->updateFrameProperties((*reinterpret_cast<std::add_pointer_t<int>>(_a[1]))); break;
        case 11: _t->updateJobTable((*reinterpret_cast<std::add_pointer_t<QSharedPointer<SequenceJob>>>(_a[1])),(*reinterpret_cast<std::add_pointer_t<bool>>(_a[2]))); break;
        case 12: _t->updateJobTable((*reinterpret_cast<std::add_pointer_t<QSharedPointer<SequenceJob>>>(_a[1]))); break;
        case 13: _t->jobExecutionPreparationStarted(); break;
        case 14: _t->jobPrepared((*reinterpret_cast<std::add_pointer_t<QSharedPointer<SequenceJob>>>(_a[1]))); break;
        case 15: _t->captureImageStarted(); break;
        case 16: _t->captureTarget((*reinterpret_cast<std::add_pointer_t<QString>>(_a[1]))); break;
        case 17: _t->captureRunning(); break;
        case 18: _t->newExposureProgress((*reinterpret_cast<std::add_pointer_t<QSharedPointer<SequenceJob>>>(_a[1]))); break;
        case 19: _t->newDownloadProgress((*reinterpret_cast<std::add_pointer_t<double>>(_a[1]))); break;
        case 20: _t->downloadingFrame(); break;
        case 21: _t->updateCaptureCountDown((*reinterpret_cast<std::add_pointer_t<int>>(_a[1]))); break;
        case 22: _t->darkFrameCompleted(); break;
        case 23: _t->updateMeridianFlipStage((*reinterpret_cast<std::add_pointer_t<MeridianFlipState::MFStage>>(_a[1]))); break;
        case 24: _t->cameraReady(); break;
        case 25: _t->refreshCamera((*reinterpret_cast<std::add_pointer_t<bool>>(_a[1]))); break;
        case 26: _t->refreshCameraSettings(); break;
        case 27: _t->refreshFilterSettings(); break;
        case 28: _t->processingFITSfinished((*reinterpret_cast<std::add_pointer_t<bool>>(_a[1]))); break;
        case 29: _t->rotatorReverseToggled((*reinterpret_cast<std::add_pointer_t<bool>>(_a[1]))); break;
        case 30: _t->newImage((*reinterpret_cast<std::add_pointer_t<QSharedPointer<SequenceJob>>>(_a[1])),(*reinterpret_cast<std::add_pointer_t<QSharedPointer<FITSData>>>(_a[2]))); break;
        case 31: _t->newView((*reinterpret_cast<std::add_pointer_t<QSharedPointer<FITSView>>>(_a[1]))); break;
        case 32: _t->suspendGuiding(); break;
        case 33: _t->resumeGuiding(); break;
        case 34: _t->abortFocus(); break;
        case 35: _t->captureComplete((*reinterpret_cast<std::add_pointer_t<QVariantMap>>(_a[1]))); break;
        case 36: _t->sequenceChanged((*reinterpret_cast<std::add_pointer_t<QJsonArray>>(_a[1]))); break;
        case 37: _t->driverTimedout((*reinterpret_cast<std::add_pointer_t<QString>>(_a[1]))); break;
        case 38: _t->newLog((*reinterpret_cast<std::add_pointer_t<QString>>(_a[1]))); break;
        case 39: _t->toggleSequence(); break;
        case 40: _t->pauseCapturing(); break;
        case 41: _t->executeJob(); break;
        case 42: _t->resetFrame(); break;
        default: ;
        }
    }
    if (_c == QMetaObject::RegisterMethodArgumentMetaType) {
        switch (_id) {
        default: *reinterpret_cast<QMetaType *>(_a[0]) = QMetaType(); break;
        case 0:
            switch (*reinterpret_cast<int*>(_a[1])) {
            default: *reinterpret_cast<QMetaType *>(_a[0]) = QMetaType(); break;
            case 0:
                *reinterpret_cast<QMetaType *>(_a[0]) = QMetaType::fromType< QSharedPointer<SequenceJob> >(); break;
            }
            break;
        case 9:
            switch (*reinterpret_cast<int*>(_a[1])) {
            default: *reinterpret_cast<QMetaType *>(_a[0]) = QMetaType(); break;
            case 0:
                *reinterpret_cast<QMetaType *>(_a[0]) = QMetaType::fromType< QSharedPointer<SequenceJob> >(); break;
            }
            break;
        case 11:
            switch (*reinterpret_cast<int*>(_a[1])) {
            default: *reinterpret_cast<QMetaType *>(_a[0]) = QMetaType(); break;
            case 0:
                *reinterpret_cast<QMetaType *>(_a[0]) = QMetaType::fromType< QSharedPointer<SequenceJob> >(); break;
            }
            break;
        case 12:
            switch (*reinterpret_cast<int*>(_a[1])) {
            default: *reinterpret_cast<QMetaType *>(_a[0]) = QMetaType(); break;
            case 0:
                *reinterpret_cast<QMetaType *>(_a[0]) = QMetaType::fromType< QSharedPointer<SequenceJob> >(); break;
            }
            break;
        case 14:
            switch (*reinterpret_cast<int*>(_a[1])) {
            default: *reinterpret_cast<QMetaType *>(_a[0]) = QMetaType(); break;
            case 0:
                *reinterpret_cast<QMetaType *>(_a[0]) = QMetaType::fromType< QSharedPointer<SequenceJob> >(); break;
            }
            break;
        case 18:
            switch (*reinterpret_cast<int*>(_a[1])) {
            default: *reinterpret_cast<QMetaType *>(_a[0]) = QMetaType(); break;
            case 0:
                *reinterpret_cast<QMetaType *>(_a[0]) = QMetaType::fromType< QSharedPointer<SequenceJob> >(); break;
            }
            break;
        case 30:
            switch (*reinterpret_cast<int*>(_a[1])) {
            default: *reinterpret_cast<QMetaType *>(_a[0]) = QMetaType(); break;
            case 1:
                *reinterpret_cast<QMetaType *>(_a[0]) = QMetaType::fromType< QSharedPointer<FITSData> >(); break;
            case 0:
                *reinterpret_cast<QMetaType *>(_a[0]) = QMetaType::fromType< QSharedPointer<SequenceJob> >(); break;
            }
            break;
        case 31:
            switch (*reinterpret_cast<int*>(_a[1])) {
            default: *reinterpret_cast<QMetaType *>(_a[0]) = QMetaType(); break;
            case 0:
                *reinterpret_cast<QMetaType *>(_a[0]) = QMetaType::fromType< QSharedPointer<FITSView> >(); break;
            }
            break;
        }
    }
    if (_c == QMetaObject::IndexOfMethod) {
        if (QtMocHelpers::indexOfMethod<void (CameraProcess::*)(const QSharedPointer<SequenceJob> & )>(_a, &CameraProcess::addJob, 0))
            return;
        if (QtMocHelpers::indexOfMethod<void (CameraProcess::*)(SequenceJob::SequenceJobType )>(_a, &CameraProcess::createJob, 1))
            return;
        if (QtMocHelpers::indexOfMethod<void (CameraProcess::*)()>(_a, &CameraProcess::jobStarting, 3))
            return;
        if (QtMocHelpers::indexOfMethod<void (CameraProcess::*)(CaptureState )>(_a, &CameraProcess::stopCapture, 4))
            return;
        if (QtMocHelpers::indexOfMethod<void (CameraProcess::*)(double )>(_a, &CameraProcess::captureAborted, 6))
            return;
        if (QtMocHelpers::indexOfMethod<void (CameraProcess::*)()>(_a, &CameraProcess::captureStopped, 7))
            return;
        if (QtMocHelpers::indexOfMethod<void (CameraProcess::*)(CaptureWorkflowActionType )>(_a, &CameraProcess::requestAction, 8))
            return;
        if (QtMocHelpers::indexOfMethod<void (CameraProcess::*)(const QSharedPointer<SequenceJob> & )>(_a, &CameraProcess::syncGUIToJob, 9))
            return;
        if (QtMocHelpers::indexOfMethod<void (CameraProcess::*)(int )>(_a, &CameraProcess::updateFrameProperties, 10))
            return;
        if (QtMocHelpers::indexOfMethod<void (CameraProcess::*)(const QSharedPointer<SequenceJob> & , bool )>(_a, &CameraProcess::updateJobTable, 11))
            return;
        if (QtMocHelpers::indexOfMethod<void (CameraProcess::*)()>(_a, &CameraProcess::jobExecutionPreparationStarted, 13))
            return;
        if (QtMocHelpers::indexOfMethod<void (CameraProcess::*)(const QSharedPointer<SequenceJob> & )>(_a, &CameraProcess::jobPrepared, 14))
            return;
        if (QtMocHelpers::indexOfMethod<void (CameraProcess::*)()>(_a, &CameraProcess::captureImageStarted, 15))
            return;
        if (QtMocHelpers::indexOfMethod<void (CameraProcess::*)(QString )>(_a, &CameraProcess::captureTarget, 16))
            return;
        if (QtMocHelpers::indexOfMethod<void (CameraProcess::*)()>(_a, &CameraProcess::captureRunning, 17))
            return;
        if (QtMocHelpers::indexOfMethod<void (CameraProcess::*)(const QSharedPointer<SequenceJob> & )>(_a, &CameraProcess::newExposureProgress, 18))
            return;
        if (QtMocHelpers::indexOfMethod<void (CameraProcess::*)(double )>(_a, &CameraProcess::newDownloadProgress, 19))
            return;
        if (QtMocHelpers::indexOfMethod<void (CameraProcess::*)()>(_a, &CameraProcess::downloadingFrame, 20))
            return;
        if (QtMocHelpers::indexOfMethod<void (CameraProcess::*)(int )>(_a, &CameraProcess::updateCaptureCountDown, 21))
            return;
        if (QtMocHelpers::indexOfMethod<void (CameraProcess::*)()>(_a, &CameraProcess::darkFrameCompleted, 22))
            return;
        if (QtMocHelpers::indexOfMethod<void (CameraProcess::*)(MeridianFlipState::MFStage )>(_a, &CameraProcess::updateMeridianFlipStage, 23))
            return;
        if (QtMocHelpers::indexOfMethod<void (CameraProcess::*)()>(_a, &CameraProcess::cameraReady, 24))
            return;
        if (QtMocHelpers::indexOfMethod<void (CameraProcess::*)(bool )>(_a, &CameraProcess::refreshCamera, 25))
            return;
        if (QtMocHelpers::indexOfMethod<void (CameraProcess::*)()>(_a, &CameraProcess::refreshCameraSettings, 26))
            return;
        if (QtMocHelpers::indexOfMethod<void (CameraProcess::*)()>(_a, &CameraProcess::refreshFilterSettings, 27))
            return;
        if (QtMocHelpers::indexOfMethod<void (CameraProcess::*)(bool )>(_a, &CameraProcess::processingFITSfinished, 28))
            return;
        if (QtMocHelpers::indexOfMethod<void (CameraProcess::*)(bool )>(_a, &CameraProcess::rotatorReverseToggled, 29))
            return;
        if (QtMocHelpers::indexOfMethod<void (CameraProcess::*)(const QSharedPointer<SequenceJob> & , const QSharedPointer<FITSData> & )>(_a, &CameraProcess::newImage, 30))
            return;
        if (QtMocHelpers::indexOfMethod<void (CameraProcess::*)(const QSharedPointer<FITSView> & )>(_a, &CameraProcess::newView, 31))
            return;
        if (QtMocHelpers::indexOfMethod<void (CameraProcess::*)()>(_a, &CameraProcess::suspendGuiding, 32))
            return;
        if (QtMocHelpers::indexOfMethod<void (CameraProcess::*)()>(_a, &CameraProcess::resumeGuiding, 33))
            return;
        if (QtMocHelpers::indexOfMethod<void (CameraProcess::*)()>(_a, &CameraProcess::abortFocus, 34))
            return;
        if (QtMocHelpers::indexOfMethod<void (CameraProcess::*)(const QVariantMap & )>(_a, &CameraProcess::captureComplete, 35))
            return;
        if (QtMocHelpers::indexOfMethod<void (CameraProcess::*)(const QJsonArray & )>(_a, &CameraProcess::sequenceChanged, 36))
            return;
        if (QtMocHelpers::indexOfMethod<void (CameraProcess::*)(const QString & )>(_a, &CameraProcess::driverTimedout, 37))
            return;
        if (QtMocHelpers::indexOfMethod<void (CameraProcess::*)(const QString & )>(_a, &CameraProcess::newLog, 38))
            return;
    }
}

const QMetaObject *Ekos::CameraProcess::metaObject() const
{
    return QObject::d_ptr->metaObject ? QObject::d_ptr->dynamicMetaObject() : &staticMetaObject;
}

void *Ekos::CameraProcess::qt_metacast(const char *_clname)
{
    if (!_clname) return nullptr;
    if (!strcmp(_clname, qt_staticMetaObjectStaticContent<qt_meta_tag_ZN4Ekos13CameraProcessE_t>.strings))
        return static_cast<void*>(this);
    return QObject::qt_metacast(_clname);
}

int Ekos::CameraProcess::qt_metacall(QMetaObject::Call _c, int _id, void **_a)
{
    _id = QObject::qt_metacall(_c, _id, _a);
    if (_id < 0)
        return _id;
    if (_c == QMetaObject::InvokeMetaMethod) {
        if (_id < 43)
            qt_static_metacall(this, _c, _id, _a);
        _id -= 43;
    }
    if (_c == QMetaObject::RegisterMethodArgumentMetaType) {
        if (_id < 43)
            qt_static_metacall(this, _c, _id, _a);
        _id -= 43;
    }
    return _id;
}

// SIGNAL 0
void Ekos::CameraProcess::addJob(const QSharedPointer<SequenceJob> & _t1)
{
    QMetaObject::activate<void>(this, &staticMetaObject, 0, nullptr, _t1);
}

// SIGNAL 1
void Ekos::CameraProcess::createJob(SequenceJob::SequenceJobType _t1)
{
    QMetaObject::activate<void>(this, &staticMetaObject, 1, nullptr, _t1);
}

// SIGNAL 3
void Ekos::CameraProcess::jobStarting()
{
    QMetaObject::activate(this, &staticMetaObject, 3, nullptr);
}

// SIGNAL 4
void Ekos::CameraProcess::stopCapture(CaptureState _t1)
{
    QMetaObject::activate<void>(this, &staticMetaObject, 4, nullptr, _t1);
}

// SIGNAL 6
void Ekos::CameraProcess::captureAborted(double _t1)
{
    QMetaObject::activate<void>(this, &staticMetaObject, 6, nullptr, _t1);
}

// SIGNAL 7
void Ekos::CameraProcess::captureStopped()
{
    QMetaObject::activate(this, &staticMetaObject, 7, nullptr);
}

// SIGNAL 8
void Ekos::CameraProcess::requestAction(CaptureWorkflowActionType _t1)
{
    QMetaObject::activate<void>(this, &staticMetaObject, 8, nullptr, _t1);
}

// SIGNAL 9
void Ekos::CameraProcess::syncGUIToJob(const QSharedPointer<SequenceJob> & _t1)
{
    QMetaObject::activate<void>(this, &staticMetaObject, 9, nullptr, _t1);
}

// SIGNAL 10
void Ekos::CameraProcess::updateFrameProperties(int _t1)
{
    QMetaObject::activate<void>(this, &staticMetaObject, 10, nullptr, _t1);
}

// SIGNAL 11
void Ekos::CameraProcess::updateJobTable(const QSharedPointer<SequenceJob> & _t1, bool _t2)
{
    QMetaObject::activate<void>(this, &staticMetaObject, 11, nullptr, _t1, _t2);
}

// SIGNAL 13
void Ekos::CameraProcess::jobExecutionPreparationStarted()
{
    QMetaObject::activate(this, &staticMetaObject, 13, nullptr);
}

// SIGNAL 14
void Ekos::CameraProcess::jobPrepared(const QSharedPointer<SequenceJob> & _t1)
{
    QMetaObject::activate<void>(this, &staticMetaObject, 14, nullptr, _t1);
}

// SIGNAL 15
void Ekos::CameraProcess::captureImageStarted()
{
    QMetaObject::activate(this, &staticMetaObject, 15, nullptr);
}

// SIGNAL 16
void Ekos::CameraProcess::captureTarget(QString _t1)
{
    QMetaObject::activate<void>(this, &staticMetaObject, 16, nullptr, _t1);
}

// SIGNAL 17
void Ekos::CameraProcess::captureRunning()
{
    QMetaObject::activate(this, &staticMetaObject, 17, nullptr);
}

// SIGNAL 18
void Ekos::CameraProcess::newExposureProgress(const QSharedPointer<SequenceJob> & _t1)
{
    QMetaObject::activate<void>(this, &staticMetaObject, 18, nullptr, _t1);
}

// SIGNAL 19
void Ekos::CameraProcess::newDownloadProgress(double _t1)
{
    QMetaObject::activate<void>(this, &staticMetaObject, 19, nullptr, _t1);
}

// SIGNAL 20
void Ekos::CameraProcess::downloadingFrame()
{
    QMetaObject::activate(this, &staticMetaObject, 20, nullptr);
}

// SIGNAL 21
void Ekos::CameraProcess::updateCaptureCountDown(int _t1)
{
    QMetaObject::activate<void>(this, &staticMetaObject, 21, nullptr, _t1);
}

// SIGNAL 22
void Ekos::CameraProcess::darkFrameCompleted()
{
    QMetaObject::activate(this, &staticMetaObject, 22, nullptr);
}

// SIGNAL 23
void Ekos::CameraProcess::updateMeridianFlipStage(MeridianFlipState::MFStage _t1)
{
    QMetaObject::activate<void>(this, &staticMetaObject, 23, nullptr, _t1);
}

// SIGNAL 24
void Ekos::CameraProcess::cameraReady()
{
    QMetaObject::activate(this, &staticMetaObject, 24, nullptr);
}

// SIGNAL 25
void Ekos::CameraProcess::refreshCamera(bool _t1)
{
    QMetaObject::activate<void>(this, &staticMetaObject, 25, nullptr, _t1);
}

// SIGNAL 26
void Ekos::CameraProcess::refreshCameraSettings()
{
    QMetaObject::activate(this, &staticMetaObject, 26, nullptr);
}

// SIGNAL 27
void Ekos::CameraProcess::refreshFilterSettings()
{
    QMetaObject::activate(this, &staticMetaObject, 27, nullptr);
}

// SIGNAL 28
void Ekos::CameraProcess::processingFITSfinished(bool _t1)
{
    QMetaObject::activate<void>(this, &staticMetaObject, 28, nullptr, _t1);
}

// SIGNAL 29
void Ekos::CameraProcess::rotatorReverseToggled(bool _t1)
{
    QMetaObject::activate<void>(this, &staticMetaObject, 29, nullptr, _t1);
}

// SIGNAL 30
void Ekos::CameraProcess::newImage(const QSharedPointer<SequenceJob> & _t1, const QSharedPointer<FITSData> & _t2)
{
    QMetaObject::activate<void>(this, &staticMetaObject, 30, nullptr, _t1, _t2);
}

// SIGNAL 31
void Ekos::CameraProcess::newView(const QSharedPointer<FITSView> & _t1)
{
    QMetaObject::activate<void>(this, &staticMetaObject, 31, nullptr, _t1);
}

// SIGNAL 32
void Ekos::CameraProcess::suspendGuiding()
{
    QMetaObject::activate(this, &staticMetaObject, 32, nullptr);
}

// SIGNAL 33
void Ekos::CameraProcess::resumeGuiding()
{
    QMetaObject::activate(this, &staticMetaObject, 33, nullptr);
}

// SIGNAL 34
void Ekos::CameraProcess::abortFocus()
{
    QMetaObject::activate(this, &staticMetaObject, 34, nullptr);
}

// SIGNAL 35
void Ekos::CameraProcess::captureComplete(const QVariantMap & _t1)
{
    QMetaObject::activate<void>(this, &staticMetaObject, 35, nullptr, _t1);
}

// SIGNAL 36
void Ekos::CameraProcess::sequenceChanged(const QJsonArray & _t1)
{
    QMetaObject::activate<void>(this, &staticMetaObject, 36, nullptr, _t1);
}

// SIGNAL 37
void Ekos::CameraProcess::driverTimedout(const QString & _t1)
{
    QMetaObject::activate<void>(this, &staticMetaObject, 37, nullptr, _t1);
}

// SIGNAL 38
void Ekos::CameraProcess::newLog(const QString & _t1)
{
    QMetaObject::activate<void>(this, &staticMetaObject, 38, nullptr, _t1);
}
QT_WARNING_POP
