/********************************************************************************
** Form generated from reading UI file 'opsindi.ui'
**
** Created by: Qt User Interface Compiler version 6.11.1
**
** WARNING! All changes made in this file will be lost when recompiling UI file!
********************************************************************************/

#ifndef UI_OPSINDI_H
#define UI_OPSINDI_H

#include <QtCore/QVariant>
#include <QtWidgets/QApplication>
#include <QtWidgets/QCheckBox>
#include <QtWidgets/QGroupBox>
#include <QtWidgets/QHBoxLayout>
#include <QtWidgets/QLabel>
#include <QtWidgets/QLineEdit>
#include <QtWidgets/QPushButton>
#include <QtWidgets/QSpacerItem>
#include <QtWidgets/QSpinBox>
#include <QtWidgets/QVBoxLayout>
#include <QtWidgets/QWidget>
#include <klocalizedstring.h>

QT_BEGIN_NAMESPACE

class Ui_OpsINDI
{
public:
    QVBoxLayout *verticalLayout_5;
    QGroupBox *generalGroup;
    QVBoxLayout *verticalLayout;
    QHBoxLayout *horizontalLayout_3;
    QCheckBox *kcfg_indiServerIsInternal;
    QLabel *videoLabel_2;
    QLineEdit *kcfg_indiServer;
    QHBoxLayout *horizontalLayout_6;
    QCheckBox *kcfg_indiDriversAreInternal;
    QLabel *videoLabel_3;
    QLineEdit *kcfg_indiDriversDir;
    QPushButton *selectDriversDirB;
    QHBoxLayout *horizontalLayout_5;
    QHBoxLayout *horizontalLayout_4;
    QLabel *fitsLabel;
    QLineEdit *kcfg_fitsDir;
    QPushButton *selectFITSDirB;
    QHBoxLayout *horizontalLayout;
    QVBoxLayout *verticalLayout_3;
    QGroupBox *skymapGroup;
    QVBoxLayout *verticalLayout_6;
    QCheckBox *kcfg_useExternalSkyMap;
    QSpacerItem *verticalSpacer_2;
    QGroupBox *indiServerGroup;
    QHBoxLayout *horizontalLayout_2;
    QVBoxLayout *vboxLayout;
    QLabel *label_4;
    QLabel *label;
    QLabel *label_2;
    QVBoxLayout *vboxLayout1;
    QSpinBox *kcfg_serverTransferBufferSize;
    QSpinBox *kcfg_serverPortStart;
    QSpinBox *kcfg_serverPortEnd;
    QSpacerItem *spacerItem;
    QGroupBox *displayGroup;
    QVBoxLayout *verticalLayout_4;
    QCheckBox *kcfg_showTargetCrosshair;
    QCheckBox *kcfg_showINDIMessages;
    QCheckBox *kcfg_showINDIwindowInitially;
    QCheckBox *kcfg_independentWindowINDI;
    QCheckBox *kcfg_messageNotificationINDI;
    QSpacerItem *verticalSpacer;
    QPushButton *showLogsB;

    void setupUi(QWidget *OpsINDI)
    {
        if (OpsINDI->objectName().isEmpty())
            OpsINDI->setObjectName("OpsINDI");
        OpsINDI->resize(484, 398);
        verticalLayout_5 = new QVBoxLayout(OpsINDI);
        verticalLayout_5->setSpacing(3);
        verticalLayout_5->setObjectName("verticalLayout_5");
        verticalLayout_5->setContentsMargins(3, 3, 3, 3);
        generalGroup = new QGroupBox(OpsINDI);
        generalGroup->setObjectName("generalGroup");
        verticalLayout = new QVBoxLayout(generalGroup);
        verticalLayout->setSpacing(3);
        verticalLayout->setObjectName("verticalLayout");
        verticalLayout->setContentsMargins(3, 3, 3, 3);
        horizontalLayout_3 = new QHBoxLayout();
        horizontalLayout_3->setObjectName("horizontalLayout_3");
        kcfg_indiServerIsInternal = new QCheckBox(generalGroup);
        kcfg_indiServerIsInternal->setObjectName("kcfg_indiServerIsInternal");

        horizontalLayout_3->addWidget(kcfg_indiServerIsInternal);

        videoLabel_2 = new QLabel(generalGroup);
        videoLabel_2->setObjectName("videoLabel_2");

        horizontalLayout_3->addWidget(videoLabel_2);

        kcfg_indiServer = new QLineEdit(generalGroup);
        kcfg_indiServer->setObjectName("kcfg_indiServer");
        kcfg_indiServer->setText(QString::fromUtf8("/usr/bin/indiserver"));

        horizontalLayout_3->addWidget(kcfg_indiServer);


        verticalLayout->addLayout(horizontalLayout_3);

        horizontalLayout_6 = new QHBoxLayout();
        horizontalLayout_6->setSpacing(5);
        horizontalLayout_6->setObjectName("horizontalLayout_6");
        kcfg_indiDriversAreInternal = new QCheckBox(generalGroup);
        kcfg_indiDriversAreInternal->setObjectName("kcfg_indiDriversAreInternal");

        horizontalLayout_6->addWidget(kcfg_indiDriversAreInternal);

        videoLabel_3 = new QLabel(generalGroup);
        videoLabel_3->setObjectName("videoLabel_3");

        horizontalLayout_6->addWidget(videoLabel_3);

        kcfg_indiDriversDir = new QLineEdit(generalGroup);
        kcfg_indiDriversDir->setObjectName("kcfg_indiDriversDir");
        kcfg_indiDriversDir->setText(QString::fromUtf8("/usr/share/indi"));
        kcfg_indiDriversDir->setReadOnly(true);

        horizontalLayout_6->addWidget(kcfg_indiDriversDir);

        selectDriversDirB = new QPushButton(generalGroup);
        selectDriversDirB->setObjectName("selectDriversDirB");
        QSizePolicy sizePolicy(QSizePolicy::Policy::Fixed, QSizePolicy::Policy::Fixed);
        sizePolicy.setHorizontalStretch(0);
        sizePolicy.setVerticalStretch(0);
        sizePolicy.setHeightForWidth(selectDriversDirB->sizePolicy().hasHeightForWidth());
        selectDriversDirB->setSizePolicy(sizePolicy);
        selectDriversDirB->setMinimumSize(QSize(28, 28));
        selectDriversDirB->setMaximumSize(QSize(28, 28));

        horizontalLayout_6->addWidget(selectDriversDirB);


        verticalLayout->addLayout(horizontalLayout_6);

        horizontalLayout_5 = new QHBoxLayout();
        horizontalLayout_5->setObjectName("horizontalLayout_5");

        verticalLayout->addLayout(horizontalLayout_5);

        horizontalLayout_4 = new QHBoxLayout();
        horizontalLayout_4->setObjectName("horizontalLayout_4");
        fitsLabel = new QLabel(generalGroup);
        fitsLabel->setObjectName("fitsLabel");

        horizontalLayout_4->addWidget(fitsLabel);

        kcfg_fitsDir = new QLineEdit(generalGroup);
        kcfg_fitsDir->setObjectName("kcfg_fitsDir");

        horizontalLayout_4->addWidget(kcfg_fitsDir);

        selectFITSDirB = new QPushButton(generalGroup);
        selectFITSDirB->setObjectName("selectFITSDirB");
        sizePolicy.setHeightForWidth(selectFITSDirB->sizePolicy().hasHeightForWidth());
        selectFITSDirB->setSizePolicy(sizePolicy);
        selectFITSDirB->setMinimumSize(QSize(28, 28));
        selectFITSDirB->setMaximumSize(QSize(28, 28));

        horizontalLayout_4->addWidget(selectFITSDirB);


        verticalLayout->addLayout(horizontalLayout_4);


        verticalLayout_5->addWidget(generalGroup);

        horizontalLayout = new QHBoxLayout();
        horizontalLayout->setObjectName("horizontalLayout");
        verticalLayout_3 = new QVBoxLayout();
        verticalLayout_3->setObjectName("verticalLayout_3");
        skymapGroup = new QGroupBox(OpsINDI);
        skymapGroup->setObjectName("skymapGroup");
        verticalLayout_6 = new QVBoxLayout(skymapGroup);
        verticalLayout_6->setObjectName("verticalLayout_6");
        verticalLayout_6->setContentsMargins(9, 9, 9, 9);
        kcfg_useExternalSkyMap = new QCheckBox(skymapGroup);
        kcfg_useExternalSkyMap->setObjectName("kcfg_useExternalSkyMap");

        verticalLayout_6->addWidget(kcfg_useExternalSkyMap);


        verticalLayout_3->addWidget(skymapGroup);

        verticalSpacer_2 = new QSpacerItem(20, 40, QSizePolicy::Policy::Minimum, QSizePolicy::Policy::Expanding);

        verticalLayout_3->addItem(verticalSpacer_2);

        indiServerGroup = new QGroupBox(OpsINDI);
        indiServerGroup->setObjectName("indiServerGroup");
        horizontalLayout_2 = new QHBoxLayout(indiServerGroup);
        horizontalLayout_2->setObjectName("horizontalLayout_2");
        vboxLayout = new QVBoxLayout();
        vboxLayout->setSpacing(6);
        vboxLayout->setObjectName("vboxLayout");
        vboxLayout->setContentsMargins(0, 0, 0, 0);
        label_4 = new QLabel(indiServerGroup);
        label_4->setObjectName("label_4");

        vboxLayout->addWidget(label_4);

        label = new QLabel(indiServerGroup);
        label->setObjectName("label");

        vboxLayout->addWidget(label);

        label_2 = new QLabel(indiServerGroup);
        label_2->setObjectName("label_2");

        vboxLayout->addWidget(label_2);


        horizontalLayout_2->addLayout(vboxLayout);

        vboxLayout1 = new QVBoxLayout();
        vboxLayout1->setSpacing(6);
        vboxLayout1->setObjectName("vboxLayout1");
        vboxLayout1->setContentsMargins(0, 0, 0, 0);
        kcfg_serverTransferBufferSize = new QSpinBox(indiServerGroup);
        kcfg_serverTransferBufferSize->setObjectName("kcfg_serverTransferBufferSize");
        kcfg_serverTransferBufferSize->setMinimum(256);
        kcfg_serverTransferBufferSize->setMaximum(10000);
        kcfg_serverTransferBufferSize->setSingleStep(256);
        kcfg_serverTransferBufferSize->setValue(1024);

        vboxLayout1->addWidget(kcfg_serverTransferBufferSize);

        kcfg_serverPortStart = new QSpinBox(indiServerGroup);
        kcfg_serverPortStart->setObjectName("kcfg_serverPortStart");
        kcfg_serverPortStart->setMinimum(7624);
        kcfg_serverPortStart->setMaximum(8623);

        vboxLayout1->addWidget(kcfg_serverPortStart);

        kcfg_serverPortEnd = new QSpinBox(indiServerGroup);
        kcfg_serverPortEnd->setObjectName("kcfg_serverPortEnd");
        kcfg_serverPortEnd->setMinimum(7625);
        kcfg_serverPortEnd->setMaximum(8623);
        kcfg_serverPortEnd->setValue(8623);

        vboxLayout1->addWidget(kcfg_serverPortEnd);


        horizontalLayout_2->addLayout(vboxLayout1);

        spacerItem = new QSpacerItem(40, 20, QSizePolicy::Policy::Expanding, QSizePolicy::Policy::Minimum);

        horizontalLayout_2->addItem(spacerItem);


        verticalLayout_3->addWidget(indiServerGroup);


        horizontalLayout->addLayout(verticalLayout_3);

        displayGroup = new QGroupBox(OpsINDI);
        displayGroup->setObjectName("displayGroup");
        verticalLayout_4 = new QVBoxLayout(displayGroup);
        verticalLayout_4->setObjectName("verticalLayout_4");
        kcfg_showTargetCrosshair = new QCheckBox(displayGroup);
        kcfg_showTargetCrosshair->setObjectName("kcfg_showTargetCrosshair");
        kcfg_showTargetCrosshair->setChecked(true);

        verticalLayout_4->addWidget(kcfg_showTargetCrosshair);

        kcfg_showINDIMessages = new QCheckBox(displayGroup);
        kcfg_showINDIMessages->setObjectName("kcfg_showINDIMessages");
        kcfg_showINDIMessages->setChecked(true);

        verticalLayout_4->addWidget(kcfg_showINDIMessages);

        kcfg_showINDIwindowInitially = new QCheckBox(displayGroup);
        kcfg_showINDIwindowInitially->setObjectName("kcfg_showINDIwindowInitially");
        kcfg_showINDIwindowInitially->setChecked(true);

        verticalLayout_4->addWidget(kcfg_showINDIwindowInitially);

        kcfg_independentWindowINDI = new QCheckBox(displayGroup);
        kcfg_independentWindowINDI->setObjectName("kcfg_independentWindowINDI");

        verticalLayout_4->addWidget(kcfg_independentWindowINDI);

        kcfg_messageNotificationINDI = new QCheckBox(displayGroup);
        kcfg_messageNotificationINDI->setObjectName("kcfg_messageNotificationINDI");

        verticalLayout_4->addWidget(kcfg_messageNotificationINDI);

        verticalSpacer = new QSpacerItem(20, 28, QSizePolicy::Policy::Minimum, QSizePolicy::Policy::MinimumExpanding);

        verticalLayout_4->addItem(verticalSpacer);

        showLogsB = new QPushButton(displayGroup);
        showLogsB->setObjectName("showLogsB");

        verticalLayout_4->addWidget(showLogsB);


        horizontalLayout->addWidget(displayGroup);


        verticalLayout_5->addLayout(horizontalLayout);

        QWidget::setTabOrder(kcfg_showTargetCrosshair, kcfg_showINDIMessages);

        retranslateUi(OpsINDI);

        QMetaObject::connectSlotsByName(OpsINDI);
    } // setupUi

    void retranslateUi(QWidget *OpsINDI)
    {
        generalGroup->setTitle(tr2i18n("General", nullptr));
#if QT_CONFIG(tooltip)
        kcfg_indiServerIsInternal->setToolTip(tr2i18n("INDI Server binary is internal to the application bundle", nullptr));
#endif // QT_CONFIG(tooltip)
        kcfg_indiServerIsInternal->setText(QString());
#if QT_CONFIG(tooltip)
        videoLabel_2->setToolTip(tr2i18n("Default INDI video port", nullptr));
#endif // QT_CONFIG(tooltip)
        videoLabel_2->setText(tr2i18n("INDI server:", nullptr));
#if QT_CONFIG(tooltip)
        kcfg_indiServer->setToolTip(tr2i18n("Path to the indiserver binary", nullptr));
#endif // QT_CONFIG(tooltip)
#if QT_CONFIG(tooltip)
        kcfg_indiDriversAreInternal->setToolTip(tr2i18n("INDI Drivers are internal to the application bundle", nullptr));
#endif // QT_CONFIG(tooltip)
        kcfg_indiDriversAreInternal->setText(QString());
#if QT_CONFIG(tooltip)
        videoLabel_3->setToolTip(tr2i18n("Default INDI video port", nullptr));
#endif // QT_CONFIG(tooltip)
        videoLabel_3->setText(tr2i18n("INDI drivers XML directory:", nullptr));
#if QT_CONFIG(tooltip)
        kcfg_indiDriversDir->setToolTip(tr2i18n("Path to the INDI drivers XML directory", nullptr));
#endif // QT_CONFIG(tooltip)
        selectDriversDirB->setText(QString());
#if QT_CONFIG(whatsthis)
        fitsLabel->setWhatsThis(tr2i18n("Specify where new FITS images are saved once captured and downloaded", nullptr));
#endif // QT_CONFIG(whatsthis)
        fitsLabel->setText(tr2i18n("Default FITS directory:", nullptr));
        selectFITSDirB->setText(QString());
        skymapGroup->setTitle(tr2i18n("Sky Map", nullptr));
        kcfg_useExternalSkyMap->setText(tr2i18n("External Sky Map (experimental)", nullptr));
#if QT_CONFIG(whatsthis)
        indiServerGroup->setWhatsThis(tr2i18n("Specify range of ports that INDI Server will bind to when starting new drivers", nullptr));
#endif // QT_CONFIG(whatsthis)
        indiServerGroup->setTitle(tr2i18n("INDI Server", nullptr));
        label_4->setText(tr2i18n("Transfer buffer (MB):", nullptr));
        label->setText(tr2i18n("Port from:", nullptr));
        label_2->setText(tr2i18n("Port to:", nullptr));
        displayGroup->setTitle(tr2i18n("Display", nullptr));
#if QT_CONFIG(tooltip)
        kcfg_showTargetCrosshair->setToolTip(tr2i18n("Display the telescope position on the sky map", nullptr));
#endif // QT_CONFIG(tooltip)
#if QT_CONFIG(statustip)
        kcfg_showTargetCrosshair->setStatusTip(tr2i18n("Display a telescope marker on the sky map in order to track the telescope motion across the sky.", nullptr));
#endif // QT_CONFIG(statustip)
#if QT_CONFIG(whatsthis)
        kcfg_showTargetCrosshair->setWhatsThis(tr2i18n("Display a telescope marker on the sky map in order to track the telescope motion across the sky.", nullptr));
#endif // QT_CONFIG(whatsthis)
        kcfg_showTargetCrosshair->setText(tr2i18n("&Telescope crosshair", nullptr));
#if QT_CONFIG(tooltip)
        kcfg_showINDIMessages->setToolTip(tr2i18n("Display INDI status messages in the status bar", nullptr));
#endif // QT_CONFIG(tooltip)
#if QT_CONFIG(statustip)
        kcfg_showINDIMessages->setStatusTip(tr2i18n("Display incoming INDI status messages in KStars status bar", nullptr));
#endif // QT_CONFIG(statustip)
#if QT_CONFIG(whatsthis)
        kcfg_showINDIMessages->setWhatsThis(tr2i18n("Display incoming INDI status messages in KStars status bar", nullptr));
#endif // QT_CONFIG(whatsthis)
        kcfg_showINDIMessages->setText(tr2i18n("INDI messages in status &bar", nullptr));
#if QT_CONFIG(tooltip)
        kcfg_showINDIwindowInitially->setToolTip(tr2i18n("Open INDI window on EKOS startup", nullptr));
#endif // QT_CONFIG(tooltip)
        kcfg_showINDIwindowInitially->setText(tr2i18n("INDI window on startup", nullptr));
        kcfg_independentWindowINDI->setText(tr2i18n("Independent window", nullptr));
#if QT_CONFIG(tooltip)
        kcfg_messageNotificationINDI->setToolTip(tr2i18n("Show INDI messages as desktop notifications instead of dialogs.", nullptr));
#endif // QT_CONFIG(tooltip)
        kcfg_messageNotificationINDI->setText(tr2i18n("Message notifications", nullptr));
        showLogsB->setText(tr2i18n("Show INDI Logs...", nullptr));
        (void)OpsINDI;
    } // retranslateUi

};

namespace Ui {
    class OpsINDI: public Ui_OpsINDI {};
} // namespace Ui

QT_END_NAMESPACE

#endif // OPSINDI_H

