/*
 * This file was generated by qdbusxml2cpp version 0.8
 * Source file was org.kde.kstars.SimClock.xml
 *
 * qdbusxml2cpp is Copyright (C) The Qt Company Ltd. and other contributors.
 *
 * This is an auto-generated file.
 * This file may have been hand-edited. Look for HAND-EDIT comments
 * before re-generating it.
 */

#ifndef SIMCLOCKADAPTOR_H
#define SIMCLOCKADAPTOR_H

#include <QtCore/QObject>
#include <QtDBus/QtDBus>
#include "simclock.h"
#include <QtCore/qcontainerfwd.h>

/*
 * Adaptor class for interface org.kde.kstars.SimClock
 */
class SimClockAdaptor: public QDBusAbstractAdaptor
{
    Q_OBJECT
    Q_CLASSINFO("D-Bus Interface", "org.kde.kstars.SimClock")
    Q_CLASSINFO("D-Bus Introspection", ""
"  <interface name=\"org.kde.kstars.SimClock\">\n"
"    <method name=\"stop\">\n"
"      <annotation value=\"true\" name=\"org.freedesktop.DBus.Method.NoReply\"/>\n"
"    </method>\n"
"    <method name=\"start\">\n"
"      <annotation value=\"true\" name=\"org.freedesktop.DBus.Method.NoReply\"/>\n"
"    </method>\n"
"    <method name=\"setClockScale\">\n"
"      <arg direction=\"in\" type=\"d\" name=\"scale\"/>\n"
"      <annotation value=\"true\" name=\"org.freedesktop.DBus.Method.NoReply\"/>\n"
"    </method>\n"
"    <method name=\"setNow\">\n"
"      <annotation value=\"true\" name=\"org.freedesktop.DBus.Method.NoReply\"/>\n"
"    </method>\n"
"  </interface>\n"
        "")
public:
    SimClockAdaptor(SimClock *parent);
    ~SimClockAdaptor() override;

    inline SimClock *parent() const
    { return static_cast<SimClock *>(QObject::parent()); }

public: // PROPERTIES
public Q_SLOTS: // METHODS
    Q_NOREPLY void setClockScale(double scale);
    Q_NOREPLY void setNow();
    Q_NOREPLY void start();
    Q_NOREPLY void stop();
Q_SIGNALS: // SIGNALS
};

#endif
