/****************************************************************************
** Meta object code from reading C++ file 'drivermanager.h'
**
** Created by: The Qt Meta Object Compiler version 69 (Qt 6.11.1)
**
** WARNING! All changes made in this file will be lost!
*****************************************************************************/

#include "../../../../kstars-3.8.4.1/kstars/indi/drivermanager.h"
#include <QtCore/qmetatype.h>
#include <QtCore/QSharedPointer>

#include <QtCore/qtmochelpers.h>

#include <memory>


#include <QtCore/qxptype_traits.h>
#if !defined(Q_MOC_OUTPUT_REVISION)
#error "The header file 'drivermanager.h' doesn't include <QObject>."
#elif Q_MOC_OUTPUT_REVISION != 69
#error "This file was generated using the moc from 6.11.1. It"
#error "cannot be used with the include files from this version of Qt."
#error "(The moc has changed too much.)"
#endif

#ifndef Q_CONSTINIT
#define Q_CONSTINIT
#endif

QT_WARNING_PUSH
QT_WARNING_DISABLE_DEPRECATED
QT_WARNING_DISABLE_GCC("-Wuseless-cast")
namespace {
struct qt_meta_tag_ZN15DriverManagerUIE_t {};
} // unnamed namespace

template <> constexpr inline auto DriverManagerUI::qt_create_metaobjectdata<qt_meta_tag_ZN15DriverManagerUIE_t>()
{
    namespace QMC = QtMocConstants;
    QtMocHelpers::StringRefStorage qt_stringData {
        "DriverManagerUI",
        "makePortEditable",
        "",
        "QTreeWidgetItem*",
        "selectedItem",
        "column"
    };

    QtMocHelpers::UintData qt_methods {
        // Slot 'makePortEditable'
        QtMocHelpers::SlotData<void(QTreeWidgetItem *, int)>(1, 2, QMC::AccessPublic, QMetaType::Void, {{
            { 0x80000000 | 3, 4 }, { QMetaType::Int, 5 },
        }}),
    };
    QtMocHelpers::UintData qt_properties {
    };
    QtMocHelpers::UintData qt_enums {
    };
    return QtMocHelpers::metaObjectData<DriverManagerUI, qt_meta_tag_ZN15DriverManagerUIE_t>(QMC::MetaObjectFlag{}, qt_stringData,
            qt_methods, qt_properties, qt_enums);
}
Q_CONSTINIT const QMetaObject DriverManagerUI::staticMetaObject = { {
    QMetaObject::SuperData::link<QFrame::staticMetaObject>(),
    qt_staticMetaObjectStaticContent<qt_meta_tag_ZN15DriverManagerUIE_t>.stringdata,
    qt_staticMetaObjectStaticContent<qt_meta_tag_ZN15DriverManagerUIE_t>.data,
    qt_static_metacall,
    nullptr,
    qt_staticMetaObjectRelocatingContent<qt_meta_tag_ZN15DriverManagerUIE_t>.metaTypes,
    nullptr
} };

void DriverManagerUI::qt_static_metacall(QObject *_o, QMetaObject::Call _c, int _id, void **_a)
{
    auto *_t = static_cast<DriverManagerUI *>(_o);
    if (_c == QMetaObject::InvokeMetaMethod) {
        switch (_id) {
        case 0: _t->makePortEditable((*reinterpret_cast<std::add_pointer_t<QTreeWidgetItem*>>(_a[1])),(*reinterpret_cast<std::add_pointer_t<int>>(_a[2]))); break;
        default: ;
        }
    }
}

const QMetaObject *DriverManagerUI::metaObject() const
{
    return QObject::d_ptr->metaObject ? QObject::d_ptr->dynamicMetaObject() : &staticMetaObject;
}

void *DriverManagerUI::qt_metacast(const char *_clname)
{
    if (!_clname) return nullptr;
    if (!strcmp(_clname, qt_staticMetaObjectStaticContent<qt_meta_tag_ZN15DriverManagerUIE_t>.strings))
        return static_cast<void*>(this);
    if (!strcmp(_clname, "Ui::DriverManager"))
        return static_cast< Ui::DriverManager*>(this);
    return QFrame::qt_metacast(_clname);
}

int DriverManagerUI::qt_metacall(QMetaObject::Call _c, int _id, void **_a)
{
    _id = QFrame::qt_metacall(_c, _id, _a);
    if (_id < 0)
        return _id;
    if (_c == QMetaObject::InvokeMetaMethod) {
        if (_id < 1)
            qt_static_metacall(this, _c, _id, _a);
        _id -= 1;
    }
    if (_c == QMetaObject::RegisterMethodArgumentMetaType) {
        if (_id < 1)
            *reinterpret_cast<QMetaType *>(_a[0]) = QMetaType();
        _id -= 1;
    }
    return _id;
}
namespace {
struct qt_meta_tag_ZN13DriverManagerE_t {};
} // unnamed namespace

template <> constexpr inline auto DriverManager::qt_create_metaobjectdata<qt_meta_tag_ZN13DriverManagerE_t>()
{
    namespace QMC = QtMocConstants;
    QtMocHelpers::StringRefStorage qt_stringData {
        "DriverManager",
        "serverStarted",
        "",
        "host",
        "port",
        "serverFailed",
        "message",
        "serverTerminated",
        "clientStarted",
        "clientFailed",
        "clientTerminated",
        "driverStarted",
        "QSharedPointer<DriverInfo>",
        "driver",
        "driverFailed",
        "driverStopped",
        "driverRestarted",
        "resizeDeviceColumn",
        "updateLocalTab",
        "updateClientTab",
        "updateMenuActions",
        "addINDIHost",
        "modifyINDIHost",
        "removeINDIHost",
        "activateRunService",
        "activateStopService",
        "activateHostConnection",
        "activateHostDisconnection",
        "updateCustomDrivers",
        "setClientStarted",
        "setClientFailed",
        "setClientTerminated",
        "setServerStarted",
        "setServerFailed",
        "setServerTerminated",
        "processDeviceStatus",
        "showCustomDrivers"
    };

    QtMocHelpers::UintData qt_methods {
        // Signal 'serverStarted'
        QtMocHelpers::SignalData<void(const QString &, int)>(1, 2, QMC::AccessPublic, QMetaType::Void, {{
            { QMetaType::QString, 3 }, { QMetaType::Int, 4 },
        }}),
        // Signal 'serverFailed'
        QtMocHelpers::SignalData<void(const QString &, int, const QString &)>(5, 2, QMC::AccessPublic, QMetaType::Void, {{
            { QMetaType::QString, 3 }, { QMetaType::Int, 4 }, { QMetaType::QString, 6 },
        }}),
        // Signal 'serverTerminated'
        QtMocHelpers::SignalData<void(const QString &, int, const QString &)>(7, 2, QMC::AccessPublic, QMetaType::Void, {{
            { QMetaType::QString, 3 }, { QMetaType::Int, 4 }, { QMetaType::QString, 6 },
        }}),
        // Signal 'clientStarted'
        QtMocHelpers::SignalData<void(const QString &, int)>(8, 2, QMC::AccessPublic, QMetaType::Void, {{
            { QMetaType::QString, 3 }, { QMetaType::Int, 4 },
        }}),
        // Signal 'clientFailed'
        QtMocHelpers::SignalData<void(const QString &, int, const QString &)>(9, 2, QMC::AccessPublic, QMetaType::Void, {{
            { QMetaType::QString, 3 }, { QMetaType::Int, 4 }, { QMetaType::QString, 6 },
        }}),
        // Signal 'clientTerminated'
        QtMocHelpers::SignalData<void(const QString &, int, const QString &)>(10, 2, QMC::AccessPublic, QMetaType::Void, {{
            { QMetaType::QString, 3 }, { QMetaType::Int, 4 }, { QMetaType::QString, 6 },
        }}),
        // Signal 'driverStarted'
        QtMocHelpers::SignalData<void(const QSharedPointer<DriverInfo> &)>(11, 2, QMC::AccessPublic, QMetaType::Void, {{
            { 0x80000000 | 12, 13 },
        }}),
        // Signal 'driverFailed'
        QtMocHelpers::SignalData<void(const QSharedPointer<DriverInfo> &, const QString &)>(14, 2, QMC::AccessPublic, QMetaType::Void, {{
            { 0x80000000 | 12, 13 }, { QMetaType::QString, 6 },
        }}),
        // Signal 'driverStopped'
        QtMocHelpers::SignalData<void(const QSharedPointer<DriverInfo> &)>(15, 2, QMC::AccessPublic, QMetaType::Void, {{
            { 0x80000000 | 12, 13 },
        }}),
        // Signal 'driverRestarted'
        QtMocHelpers::SignalData<void(const QSharedPointer<DriverInfo> &)>(16, 2, QMC::AccessPublic, QMetaType::Void, {{
            { 0x80000000 | 12, 13 },
        }}),
        // Slot 'resizeDeviceColumn'
        QtMocHelpers::SlotData<void()>(17, 2, QMC::AccessPublic, QMetaType::Void),
        // Slot 'updateLocalTab'
        QtMocHelpers::SlotData<void()>(18, 2, QMC::AccessPublic, QMetaType::Void),
        // Slot 'updateClientTab'
        QtMocHelpers::SlotData<void()>(19, 2, QMC::AccessPublic, QMetaType::Void),
        // Slot 'updateMenuActions'
        QtMocHelpers::SlotData<void()>(20, 2, QMC::AccessPublic, QMetaType::Void),
        // Slot 'addINDIHost'
        QtMocHelpers::SlotData<void()>(21, 2, QMC::AccessPublic, QMetaType::Void),
        // Slot 'modifyINDIHost'
        QtMocHelpers::SlotData<void()>(22, 2, QMC::AccessPublic, QMetaType::Void),
        // Slot 'removeINDIHost'
        QtMocHelpers::SlotData<void()>(23, 2, QMC::AccessPublic, QMetaType::Void),
        // Slot 'activateRunService'
        QtMocHelpers::SlotData<void()>(24, 2, QMC::AccessPublic, QMetaType::Void),
        // Slot 'activateStopService'
        QtMocHelpers::SlotData<void()>(25, 2, QMC::AccessPublic, QMetaType::Void),
        // Slot 'activateHostConnection'
        QtMocHelpers::SlotData<void()>(26, 2, QMC::AccessPublic, QMetaType::Void),
        // Slot 'activateHostDisconnection'
        QtMocHelpers::SlotData<void()>(27, 2, QMC::AccessPublic, QMetaType::Void),
        // Slot 'updateCustomDrivers'
        QtMocHelpers::SlotData<void()>(28, 2, QMC::AccessPublic, QMetaType::Void),
        // Slot 'setClientStarted'
        QtMocHelpers::SlotData<void()>(29, 2, QMC::AccessPublic, QMetaType::Void),
        // Slot 'setClientFailed'
        QtMocHelpers::SlotData<void(const QString &)>(30, 2, QMC::AccessPublic, QMetaType::Void, {{
            { QMetaType::QString, 6 },
        }}),
        // Slot 'setClientTerminated'
        QtMocHelpers::SlotData<void(const QString &)>(31, 2, QMC::AccessPublic, QMetaType::Void, {{
            { QMetaType::QString, 6 },
        }}),
        // Slot 'setServerStarted'
        QtMocHelpers::SlotData<void()>(32, 2, QMC::AccessPublic, QMetaType::Void),
        // Slot 'setServerFailed'
        QtMocHelpers::SlotData<void(const QString &)>(33, 2, QMC::AccessPublic, QMetaType::Void, {{
            { QMetaType::QString, 6 },
        }}),
        // Slot 'setServerTerminated'
        QtMocHelpers::SlotData<void(const QString &)>(34, 2, QMC::AccessPublic, QMetaType::Void, {{
            { QMetaType::QString, 6 },
        }}),
        // Slot 'processDeviceStatus'
        QtMocHelpers::SlotData<void(const QSharedPointer<DriverInfo> &)>(35, 2, QMC::AccessPublic, QMetaType::Void, {{
            { 0x80000000 | 12, 13 },
        }}),
        // Slot 'showCustomDrivers'
        QtMocHelpers::SlotData<void()>(36, 2, QMC::AccessPublic, QMetaType::Void),
    };
    QtMocHelpers::UintData qt_properties {
    };
    QtMocHelpers::UintData qt_enums {
    };
    return QtMocHelpers::metaObjectData<DriverManager, qt_meta_tag_ZN13DriverManagerE_t>(QMC::MetaObjectFlag{}, qt_stringData,
            qt_methods, qt_properties, qt_enums);
}
Q_CONSTINIT const QMetaObject DriverManager::staticMetaObject = { {
    QMetaObject::SuperData::link<QDialog::staticMetaObject>(),
    qt_staticMetaObjectStaticContent<qt_meta_tag_ZN13DriverManagerE_t>.stringdata,
    qt_staticMetaObjectStaticContent<qt_meta_tag_ZN13DriverManagerE_t>.data,
    qt_static_metacall,
    nullptr,
    qt_staticMetaObjectRelocatingContent<qt_meta_tag_ZN13DriverManagerE_t>.metaTypes,
    nullptr
} };

void DriverManager::qt_static_metacall(QObject *_o, QMetaObject::Call _c, int _id, void **_a)
{
    auto *_t = static_cast<DriverManager *>(_o);
    if (_c == QMetaObject::InvokeMetaMethod) {
        switch (_id) {
        case 0: _t->serverStarted((*reinterpret_cast<std::add_pointer_t<QString>>(_a[1])),(*reinterpret_cast<std::add_pointer_t<int>>(_a[2]))); break;
        case 1: _t->serverFailed((*reinterpret_cast<std::add_pointer_t<QString>>(_a[1])),(*reinterpret_cast<std::add_pointer_t<int>>(_a[2])),(*reinterpret_cast<std::add_pointer_t<QString>>(_a[3]))); break;
        case 2: _t->serverTerminated((*reinterpret_cast<std::add_pointer_t<QString>>(_a[1])),(*reinterpret_cast<std::add_pointer_t<int>>(_a[2])),(*reinterpret_cast<std::add_pointer_t<QString>>(_a[3]))); break;
        case 3: _t->clientStarted((*reinterpret_cast<std::add_pointer_t<QString>>(_a[1])),(*reinterpret_cast<std::add_pointer_t<int>>(_a[2]))); break;
        case 4: _t->clientFailed((*reinterpret_cast<std::add_pointer_t<QString>>(_a[1])),(*reinterpret_cast<std::add_pointer_t<int>>(_a[2])),(*reinterpret_cast<std::add_pointer_t<QString>>(_a[3]))); break;
        case 5: _t->clientTerminated((*reinterpret_cast<std::add_pointer_t<QString>>(_a[1])),(*reinterpret_cast<std::add_pointer_t<int>>(_a[2])),(*reinterpret_cast<std::add_pointer_t<QString>>(_a[3]))); break;
        case 6: _t->driverStarted((*reinterpret_cast<std::add_pointer_t<QSharedPointer<DriverInfo>>>(_a[1]))); break;
        case 7: _t->driverFailed((*reinterpret_cast<std::add_pointer_t<QSharedPointer<DriverInfo>>>(_a[1])),(*reinterpret_cast<std::add_pointer_t<QString>>(_a[2]))); break;
        case 8: _t->driverStopped((*reinterpret_cast<std::add_pointer_t<QSharedPointer<DriverInfo>>>(_a[1]))); break;
        case 9: _t->driverRestarted((*reinterpret_cast<std::add_pointer_t<QSharedPointer<DriverInfo>>>(_a[1]))); break;
        case 10: _t->resizeDeviceColumn(); break;
        case 11: _t->updateLocalTab(); break;
        case 12: _t->updateClientTab(); break;
        case 13: _t->updateMenuActions(); break;
        case 14: _t->addINDIHost(); break;
        case 15: _t->modifyINDIHost(); break;
        case 16: _t->removeINDIHost(); break;
        case 17: _t->activateRunService(); break;
        case 18: _t->activateStopService(); break;
        case 19: _t->activateHostConnection(); break;
        case 20: _t->activateHostDisconnection(); break;
        case 21: _t->updateCustomDrivers(); break;
        case 22: _t->setClientStarted(); break;
        case 23: _t->setClientFailed((*reinterpret_cast<std::add_pointer_t<QString>>(_a[1]))); break;
        case 24: _t->setClientTerminated((*reinterpret_cast<std::add_pointer_t<QString>>(_a[1]))); break;
        case 25: _t->setServerStarted(); break;
        case 26: _t->setServerFailed((*reinterpret_cast<std::add_pointer_t<QString>>(_a[1]))); break;
        case 27: _t->setServerTerminated((*reinterpret_cast<std::add_pointer_t<QString>>(_a[1]))); break;
        case 28: _t->processDeviceStatus((*reinterpret_cast<std::add_pointer_t<QSharedPointer<DriverInfo>>>(_a[1]))); break;
        case 29: _t->showCustomDrivers(); break;
        default: ;
        }
    }
    if (_c == QMetaObject::IndexOfMethod) {
        if (QtMocHelpers::indexOfMethod<void (DriverManager::*)(const QString & , int )>(_a, &DriverManager::serverStarted, 0))
            return;
        if (QtMocHelpers::indexOfMethod<void (DriverManager::*)(const QString & , int , const QString & )>(_a, &DriverManager::serverFailed, 1))
            return;
        if (QtMocHelpers::indexOfMethod<void (DriverManager::*)(const QString & , int , const QString & )>(_a, &DriverManager::serverTerminated, 2))
            return;
        if (QtMocHelpers::indexOfMethod<void (DriverManager::*)(const QString & , int )>(_a, &DriverManager::clientStarted, 3))
            return;
        if (QtMocHelpers::indexOfMethod<void (DriverManager::*)(const QString & , int , const QString & )>(_a, &DriverManager::clientFailed, 4))
            return;
        if (QtMocHelpers::indexOfMethod<void (DriverManager::*)(const QString & , int , const QString & )>(_a, &DriverManager::clientTerminated, 5))
            return;
        if (QtMocHelpers::indexOfMethod<void (DriverManager::*)(const QSharedPointer<DriverInfo> & )>(_a, &DriverManager::driverStarted, 6))
            return;
        if (QtMocHelpers::indexOfMethod<void (DriverManager::*)(const QSharedPointer<DriverInfo> & , const QString & )>(_a, &DriverManager::driverFailed, 7))
            return;
        if (QtMocHelpers::indexOfMethod<void (DriverManager::*)(const QSharedPointer<DriverInfo> & )>(_a, &DriverManager::driverStopped, 8))
            return;
        if (QtMocHelpers::indexOfMethod<void (DriverManager::*)(const QSharedPointer<DriverInfo> & )>(_a, &DriverManager::driverRestarted, 9))
            return;
    }
}

const QMetaObject *DriverManager::metaObject() const
{
    return QObject::d_ptr->metaObject ? QObject::d_ptr->dynamicMetaObject() : &staticMetaObject;
}

void *DriverManager::qt_metacast(const char *_clname)
{
    if (!_clname) return nullptr;
    if (!strcmp(_clname, qt_staticMetaObjectStaticContent<qt_meta_tag_ZN13DriverManagerE_t>.strings))
        return static_cast<void*>(this);
    return QDialog::qt_metacast(_clname);
}

int DriverManager::qt_metacall(QMetaObject::Call _c, int _id, void **_a)
{
    _id = QDialog::qt_metacall(_c, _id, _a);
    if (_id < 0)
        return _id;
    if (_c == QMetaObject::InvokeMetaMethod) {
        if (_id < 30)
            qt_static_metacall(this, _c, _id, _a);
        _id -= 30;
    }
    if (_c == QMetaObject::RegisterMethodArgumentMetaType) {
        if (_id < 30)
            *reinterpret_cast<QMetaType *>(_a[0]) = QMetaType();
        _id -= 30;
    }
    return _id;
}

// SIGNAL 0
void DriverManager::serverStarted(const QString & _t1, int _t2)
{
    QMetaObject::activate<void>(this, &staticMetaObject, 0, nullptr, _t1, _t2);
}

// SIGNAL 1
void DriverManager::serverFailed(const QString & _t1, int _t2, const QString & _t3)
{
    QMetaObject::activate<void>(this, &staticMetaObject, 1, nullptr, _t1, _t2, _t3);
}

// SIGNAL 2
void DriverManager::serverTerminated(const QString & _t1, int _t2, const QString & _t3)
{
    QMetaObject::activate<void>(this, &staticMetaObject, 2, nullptr, _t1, _t2, _t3);
}

// SIGNAL 3
void DriverManager::clientStarted(const QString & _t1, int _t2)
{
    QMetaObject::activate<void>(this, &staticMetaObject, 3, nullptr, _t1, _t2);
}

// SIGNAL 4
void DriverManager::clientFailed(const QString & _t1, int _t2, const QString & _t3)
{
    QMetaObject::activate<void>(this, &staticMetaObject, 4, nullptr, _t1, _t2, _t3);
}

// SIGNAL 5
void DriverManager::clientTerminated(const QString & _t1, int _t2, const QString & _t3)
{
    QMetaObject::activate<void>(this, &staticMetaObject, 5, nullptr, _t1, _t2, _t3);
}

// SIGNAL 6
void DriverManager::driverStarted(const QSharedPointer<DriverInfo> & _t1)
{
    QMetaObject::activate<void>(this, &staticMetaObject, 6, nullptr, _t1);
}

// SIGNAL 7
void DriverManager::driverFailed(const QSharedPointer<DriverInfo> & _t1, const QString & _t2)
{
    QMetaObject::activate<void>(this, &staticMetaObject, 7, nullptr, _t1, _t2);
}

// SIGNAL 8
void DriverManager::driverStopped(const QSharedPointer<DriverInfo> & _t1)
{
    QMetaObject::activate<void>(this, &staticMetaObject, 8, nullptr, _t1);
}

// SIGNAL 9
void DriverManager::driverRestarted(const QSharedPointer<DriverInfo> & _t1)
{
    QMetaObject::activate<void>(this, &staticMetaObject, 9, nullptr, _t1);
}
QT_WARNING_POP
