/*
 * This file was generated by qdbusxml2cpp version 0.8
 * Source file was org.kde.kstars.Ekos.Mount.xml
 *
 * qdbusxml2cpp is Copyright (C) The Qt Company Ltd. and other contributors.
 *
 * This is an auto-generated file.
 * This file may have been hand-edited. Look for HAND-EDIT comments
 * before re-generating it.
 */

#ifndef MOUNTADAPTOR_H
#define MOUNTADAPTOR_H

#include <QtCore/QObject>
#include <QtDBus/QtDBus>
#include "ekos/mount/mount.h"
#include <QtCore/qcontainerfwd.h>

/*
 * Adaptor class for interface org.kde.kstars.Ekos.Mount
 */
class MountAdaptor: public QDBusAbstractAdaptor
{
    Q_OBJECT
    Q_CLASSINFO("D-Bus Interface", "org.kde.kstars.Ekos.Mount")
    Q_CLASSINFO("D-Bus Introspection", ""
"  <interface name=\"org.kde.kstars.Ekos.Mount\">\n"
"    <property access=\"readwrite\" type=\"s\" name=\"opticalTrain\"/>\n"
"    <property access=\"read\" type=\"as\" name=\"logText\"/>\n"
"    <property access=\"read\" type=\"b\" name=\"canPark\"/>\n"
"    <property access=\"read\" type=\"i\" name=\"slewStatus\"/>\n"
"    <property access=\"readwrite\" type=\"ad\" name=\"altitudeLimits\">\n"
"      <annotation value=\"QList&lt;double&gt;\" name=\"org.qtproject.QtDBus.QtTypeName\"/>\n"
"    </property>\n"
"    <property access=\"readwrite\" type=\"b\" name=\"altitudeLimitsEnabled\"/>\n"
"    <property access=\"readwrite\" type=\"d\" name=\"hourAngleLimit\"/>\n"
"    <property access=\"readwrite\" type=\"b\" name=\"hourAngleLimitEnabled\"/>\n"
"    <property access=\"read\" type=\"ad\" name=\"equatorialCoords\">\n"
"      <annotation value=\"QList&lt;double&gt;\" name=\"org.qtproject.QtDBus.QtTypeName\"/>\n"
"    </property>\n"
"    <property access=\"read\" type=\"ad\" name=\"horizontalCoords\">\n"
"      <annotation value=\"QList&lt;double&gt;\" name=\"org.qtproject.QtDBus.QtTypeName\"/>\n"
"    </property>\n"
"    <property access=\"readwrite\" type=\"i\" name=\"slewRate\"/>\n"
"    <property access=\"read\" type=\"d\" name=\"hourAngle\"/>\n"
"    <property access=\"read\" type=\"i\" name=\"status\">\n"
"      <annotation value=\"ISD::Mount::Status\" name=\"org.qtproject.QtDBus.QtTypeName\"/>\n"
"    </property>\n"
"    <property access=\"read\" type=\"i\" name=\"parkStatus\">\n"
"      <annotation value=\"ISD::ParkStatus\" name=\"org.qtproject.QtDBus.QtTypeName\"/>\n"
"    </property>\n"
"    <property access=\"read\" type=\"i\" name=\"pierSide\">\n"
"      <annotation value=\"ISD::Mount::PierSide\" name=\"org.qtproject.QtDBus.QtTypeName\"/>\n"
"    </property>\n"
"    <method name=\"slew\">\n"
"      <arg direction=\"out\" type=\"b\"/>\n"
"      <arg direction=\"in\" type=\"d\" name=\"RA\"/>\n"
"      <arg direction=\"in\" type=\"d\" name=\"DEC\"/>\n"
"    </method>\n"
"    <method name=\"sync\">\n"
"      <arg direction=\"out\" type=\"b\"/>\n"
"      <arg direction=\"in\" type=\"d\" name=\"RA\"/>\n"
"      <arg direction=\"in\" type=\"d\" name=\"DEC\"/>\n"
"    </method>\n"
"    <method name=\"gotoTarget\">\n"
"      <arg direction=\"out\" type=\"b\"/>\n"
"      <arg direction=\"in\" type=\"s\" name=\"target\"/>\n"
"    </method>\n"
"    <method name=\"syncTarget\">\n"
"      <arg direction=\"out\" type=\"b\"/>\n"
"      <arg direction=\"in\" type=\"s\" name=\"target\"/>\n"
"    </method>\n"
"    <method name=\"abort\">\n"
"      <arg direction=\"out\" type=\"b\"/>\n"
"    </method>\n"
"    <method name=\"park\">\n"
"      <arg direction=\"out\" type=\"b\"/>\n"
"    </method>\n"
"    <method name=\"unpark\">\n"
"      <arg direction=\"out\" type=\"b\"/>\n"
"    </method>\n"
"    <method name=\"resetModel\">\n"
"      <arg direction=\"out\" type=\"b\"/>\n"
"    </method>\n"
"    <method name=\"setMeridianFlipValues\">\n"
"      <arg direction=\"in\" type=\"b\" name=\"activate\"/>\n"
"      <arg direction=\"in\" type=\"d\" name=\"hours\"/>\n"
"      <annotation value=\"true\" name=\"org.freedesktop.DBus.Method.NoReply\"/>\n"
"    </method>\n"
"    <signal name=\"newStatus\">\n"
"      <arg direction=\"out\" type=\"(i)\" name=\"status\"/>\n"
"      <annotation value=\"ISD::Mount::Status\" name=\"org.qtproject.QtDBus.QtTypeName.In0\"/>\n"
"      <annotation value=\"ISD::Mount::Status\" name=\"org.qtproject.QtDBus.QtTypeName.Out0\"/>\n"
"    </signal>\n"
"    <signal name=\"newParkStatus\">\n"
"      <arg direction=\"out\" type=\"(i)\" name=\"status\"/>\n"
"      <annotation value=\"ISD::ParkStatus\" name=\"org.qtproject.QtDBus.QtTypeName.In0\"/>\n"
"      <annotation value=\"ISD::ParkStatus\" name=\"org.qtproject.QtDBus.QtTypeName.Out0\"/>\n"
"    </signal>\n"
"    <signal name=\"pierSideChanged\">\n"
"      <arg direction=\"out\" type=\"(i)\" name=\"side\"/>\n"
"      <annotation value=\"ISD::Mount::PierSide\" name=\"org.qtproject.QtDBus.QtTypeName.In0\"/>\n"
"      <annotation value=\"ISD::Mount::PierSide\" name=\"org.qtproject.QtDBus.QtTypeName.Out0\"/>\n"
"    </signal>\n"
"    <signal name=\"newMeridianFlipSetup\">\n"
"    </signal>\n"
"    <signal name=\"ready\"/>\n"
"  </interface>\n"
        "")
public:
    MountAdaptor(Ekos::Mount *parent);
    ~MountAdaptor() override;

    inline Ekos::Mount *parent() const
    { return static_cast<Ekos::Mount *>(QObject::parent()); }

public: // PROPERTIES
    Q_PROPERTY(QList<double> altitudeLimits READ altitudeLimits WRITE setAltitudeLimits)
    QList<double> altitudeLimits() const;
    void setAltitudeLimits(const QList<double> &value);

    Q_PROPERTY(bool altitudeLimitsEnabled READ altitudeLimitsEnabled WRITE setAltitudeLimitsEnabled)
    bool altitudeLimitsEnabled() const;
    void setAltitudeLimitsEnabled(bool value);

    Q_PROPERTY(bool canPark READ canPark)
    bool canPark() const;

    Q_PROPERTY(QList<double> equatorialCoords READ equatorialCoords)
    QList<double> equatorialCoords() const;

    Q_PROPERTY(QList<double> horizontalCoords READ horizontalCoords)
    QList<double> horizontalCoords() const;

    Q_PROPERTY(double hourAngle READ hourAngle)
    double hourAngle() const;

    Q_PROPERTY(double hourAngleLimit READ hourAngleLimit WRITE setHourAngleLimit)
    double hourAngleLimit() const;
    void setHourAngleLimit(double value);

    Q_PROPERTY(bool hourAngleLimitEnabled READ hourAngleLimitEnabled WRITE setHourAngleLimitEnabled)
    bool hourAngleLimitEnabled() const;
    void setHourAngleLimitEnabled(bool value);

    Q_PROPERTY(QStringList logText READ logText)
    QStringList logText() const;

    Q_PROPERTY(QString opticalTrain READ opticalTrain WRITE setOpticalTrain)
    QString opticalTrain() const;
    void setOpticalTrain(const QString &value);

    Q_PROPERTY(int parkStatus READ parkStatus)
    int parkStatus() const;

    Q_PROPERTY(int pierSide READ pierSide)
    int pierSide() const;

    Q_PROPERTY(int slewRate READ slewRate WRITE setSlewRate)
    int slewRate() const;
    void setSlewRate(int value);

    Q_PROPERTY(int slewStatus READ slewStatus)
    int slewStatus() const;

    Q_PROPERTY(int status READ status)
    int status() const;

public Q_SLOTS: // METHODS
    bool abort();
    bool gotoTarget(const QString &target);
    bool park();
    bool resetModel();
    Q_NOREPLY void setMeridianFlipValues(bool activate, double hours);
    bool slew(double RA, double DEC);
    bool sync(double RA, double DEC);
    bool syncTarget(const QString &target);
    bool unpark();
Q_SIGNALS: // SIGNALS
    void newMeridianFlipSetup();
    void newParkStatus(ISD::ParkStatus status);
    void newStatus(ISD::Mount::Status status);
    void pierSideChanged(ISD::Mount::PierSide side);
    void ready();
};

#endif
