/********************************************************************************
** Form generated from reading UI file 'argwaitforkey.ui'
**
** Created by: Qt User Interface Compiler version 6.11.1
**
** WARNING! All changes made in this file will be lost when recompiling UI file!
********************************************************************************/

#ifndef UI_ARGWAITFORKEY_H
#define UI_ARGWAITFORKEY_H

#include <QtCore/QVariant>
#include <QtWidgets/QApplication>
#include <QtWidgets/QHBoxLayout>
#include <QtWidgets/QLabel>
#include <QtWidgets/QLineEdit>
#include <QtWidgets/QSpacerItem>
#include <QtWidgets/QVBoxLayout>
#include <QtWidgets/QWidget>
#include <klocalizedstring.h>

QT_BEGIN_NAMESPACE

class Ui_ArgWaitForKey
{
public:
    QVBoxLayout *vboxLayout;
    QHBoxLayout *hboxLayout;
    QLabel *textLabel1;
    QLineEdit *WaitKeyEdit;
    QSpacerItem *spacerItem;
    QSpacerItem *spacerItem1;

    void setupUi(QWidget *ArgWaitForKey)
    {
        if (ArgWaitForKey->objectName().isEmpty())
            ArgWaitForKey->setObjectName("ArgWaitForKey");
        ArgWaitForKey->resize(288, 124);
        vboxLayout = new QVBoxLayout(ArgWaitForKey);
#ifndef UI_Q_OS_MAC
        vboxLayout->setSpacing(6);
#endif
        vboxLayout->setContentsMargins(10, 10, 10, 10);
        vboxLayout->setObjectName("vboxLayout");
        hboxLayout = new QHBoxLayout();
#ifndef UI_Q_OS_MAC
        hboxLayout->setSpacing(6);
#endif
#ifndef UI_Q_OS_MAC
        hboxLayout->setContentsMargins(0, 0, 0, 0);
#endif
        hboxLayout->setObjectName("hboxLayout");
        textLabel1 = new QLabel(ArgWaitForKey);
        textLabel1->setObjectName("textLabel1");

        hboxLayout->addWidget(textLabel1);

        WaitKeyEdit = new QLineEdit(ArgWaitForKey);
        WaitKeyEdit->setObjectName("WaitKeyEdit");

        hboxLayout->addWidget(WaitKeyEdit);

        spacerItem = new QSpacerItem(40, 20, QSizePolicy::Policy::Expanding, QSizePolicy::Policy::Minimum);

        hboxLayout->addItem(spacerItem);


        vboxLayout->addLayout(hboxLayout);

        spacerItem1 = new QSpacerItem(20, 40, QSizePolicy::Policy::Minimum, QSizePolicy::Policy::Expanding);

        vboxLayout->addItem(spacerItem1);


        retranslateUi(ArgWaitForKey);

        QMetaObject::connectSlotsByName(ArgWaitForKey);
    } // setupUi

    void retranslateUi(QWidget *ArgWaitForKey)
    {
        textLabel1->setText(tr2i18n("Key:", nullptr));
#if QT_CONFIG(tooltip)
        WaitKeyEdit->setToolTip(tr2i18n("Wait for this key to be pressed", nullptr));
#endif // QT_CONFIG(tooltip)
#if QT_CONFIG(whatsthis)
        WaitKeyEdit->setWhatsThis(tr2i18n("The script execution will pause until the user presses the key specified here.  \n"
"\n"
"Only simple keys can currently be used; you cannot use modifier keys such as Ctrl or Shift.  Type \"space\" to specify the spacebar, otherwise use the key itself.", nullptr));
#endif // QT_CONFIG(whatsthis)
        (void)ArgWaitForKey;
    } // retranslateUi

};

namespace Ui {
    class ArgWaitForKey: public Ui_ArgWaitForKey {};
} // namespace Ui

QT_END_NAMESPACE

#endif // ARGWAITFORKEY_H

