/********************************************************************************
** Form generated from reading UI file 'observinglist.ui'
**
** Created by: Qt User Interface Compiler version 6.11.1
**
** WARNING! All changes made in this file will be lost when recompiling UI file!
********************************************************************************/

#ifndef UI_OBSERVINGLIST_H
#define UI_OBSERVINGLIST_H

#include <QtCore/QVariant>
#include <QtWidgets/QApplication>
#include <QtWidgets/QDateEdit>
#include <QtWidgets/QHBoxLayout>
#include <QtWidgets/QHeaderView>
#include <QtWidgets/QLabel>
#include <QtWidgets/QPushButton>
#include <QtWidgets/QSpacerItem>
#include <QtWidgets/QSplitter>
#include <QtWidgets/QTabWidget>
#include <QtWidgets/QTableView>
#include <QtWidgets/QTextEdit>
#include <QtWidgets/QTimeEdit>
#include <QtWidgets/QVBoxLayout>
#include <QtWidgets/QWidget>
#include <klocalizedstring.h>
#include "kplotwidget.h"
#include "tools/avtplotwidget.h"

QT_BEGIN_NAMESPACE

class Ui_ObservingList
{
public:
    QVBoxLayout *verticalLayout_2;
    QSplitter *mainSplitter;
    QWidget *layoutWidget;
    QVBoxLayout *topLayout;
    QHBoxLayout *toolLayout;
    QPushButton *OpenButton;
    QPushButton *SaveButton;
    QPushButton *SaveAsButton;
    QPushButton *OALExport;
    QSpacerItem *Spacer1;
    QHBoxLayout *LocationTimeLayout;
    QLabel *locationLabel;
    QPushButton *SetLocation;
    QLabel *dateLabel;
    QDateEdit *DateEdit;
    QPushButton *Update;
    QSpacerItem *horizontalSpacer_2;
    QLabel *refLabel;
    QPushButton *saveImages;
    QPushButton *DeleteAllImages;
    QHBoxLayout *addingObjectsLayout;
    QLabel *addLabel;
    QPushButton *WizardButton;
    QPushButton *FindButton;
    QPushButton *WUTButton;
    QPushButton *batchAddButton;
    QSpacerItem *horizontalSpacer_5;
    QPushButton *clearListB;
    QSplitter *WishObjectInfoSplitter;
    QTabWidget *tabWidget;
    QWidget *WishList;
    QVBoxLayout *vboxLayout;
    QTableView *WishListView;
    QWidget *Session;
    QVBoxLayout *verticalLayout_5;
    QTableView *SessionView;
    QHBoxLayout *horizontalLayout_5;
    QLabel *scheduledTimeLabel;
    QTimeEdit *TimeEdit;
    QPushButton *SetTime;
    QWidget *layoutWidget2;
    QVBoxLayout *objectInfoLayout;
    QLabel *quickInfoLabel;
    AVTPlotWidget *avt;
    QHBoxLayout *horizontalLayout_4;
    QLabel *ImagePreview;
    QVBoxLayout *verticalLayout_3;
    QLabel *dssMetadataLabel;
    QVBoxLayout *verticalLayout;
    QPushButton *SearchImage;
    QPushButton *DeleteImage;
    QTextEdit *NotesEdit;

    void setupUi(QWidget *ObservingList)
    {
        if (ObservingList->objectName().isEmpty())
            ObservingList->setObjectName("ObservingList");
        ObservingList->resize(777, 641);
        verticalLayout_2 = new QVBoxLayout(ObservingList);
        verticalLayout_2->setSpacing(3);
        verticalLayout_2->setObjectName("verticalLayout_2");
        verticalLayout_2->setContentsMargins(3, 3, 3, 3);
        mainSplitter = new QSplitter(ObservingList);
        mainSplitter->setObjectName("mainSplitter");
        mainSplitter->setOrientation(Qt::Vertical);
        layoutWidget = new QWidget(mainSplitter);
        layoutWidget->setObjectName("layoutWidget");
        topLayout = new QVBoxLayout(layoutWidget);
        topLayout->setSpacing(3);
        topLayout->setObjectName("topLayout");
        topLayout->setContentsMargins(0, 0, 0, 0);
        toolLayout = new QHBoxLayout();
        toolLayout->setSpacing(3);
        toolLayout->setObjectName("toolLayout");
        toolLayout->setContentsMargins(0, 0, 0, 0);
        OpenButton = new QPushButton(layoutWidget);
        OpenButton->setObjectName("OpenButton");
        QSizePolicy sizePolicy(QSizePolicy::Policy::Fixed, QSizePolicy::Policy::Fixed);
        sizePolicy.setHorizontalStretch(0);
        sizePolicy.setVerticalStretch(0);
        sizePolicy.setHeightForWidth(OpenButton->sizePolicy().hasHeightForWidth());
        OpenButton->setSizePolicy(sizePolicy);
        OpenButton->setMinimumSize(QSize(32, 32));
        OpenButton->setMaximumSize(QSize(32, 32));

        toolLayout->addWidget(OpenButton);

        SaveButton = new QPushButton(layoutWidget);
        SaveButton->setObjectName("SaveButton");
        sizePolicy.setHeightForWidth(SaveButton->sizePolicy().hasHeightForWidth());
        SaveButton->setSizePolicy(sizePolicy);
        SaveButton->setMinimumSize(QSize(32, 32));
        SaveButton->setMaximumSize(QSize(32, 32));

        toolLayout->addWidget(SaveButton);

        SaveAsButton = new QPushButton(layoutWidget);
        SaveAsButton->setObjectName("SaveAsButton");
        sizePolicy.setHeightForWidth(SaveAsButton->sizePolicy().hasHeightForWidth());
        SaveAsButton->setSizePolicy(sizePolicy);
        SaveAsButton->setMinimumSize(QSize(32, 32));
        SaveAsButton->setMaximumSize(QSize(32, 32));

        toolLayout->addWidget(SaveAsButton);

        OALExport = new QPushButton(layoutWidget);
        OALExport->setObjectName("OALExport");

        toolLayout->addWidget(OALExport);

        Spacer1 = new QSpacerItem(40, 20, QSizePolicy::Policy::Expanding, QSizePolicy::Policy::Minimum);

        toolLayout->addItem(Spacer1);


        topLayout->addLayout(toolLayout);

        LocationTimeLayout = new QHBoxLayout();
        LocationTimeLayout->setSpacing(3);
        LocationTimeLayout->setObjectName("LocationTimeLayout");
        LocationTimeLayout->setContentsMargins(-1, 0, -1, -1);
        locationLabel = new QLabel(layoutWidget);
        locationLabel->setObjectName("locationLabel");

        LocationTimeLayout->addWidget(locationLabel);

        SetLocation = new QPushButton(layoutWidget);
        SetLocation->setObjectName("SetLocation");

        LocationTimeLayout->addWidget(SetLocation);

        dateLabel = new QLabel(layoutWidget);
        dateLabel->setObjectName("dateLabel");

        LocationTimeLayout->addWidget(dateLabel);

        DateEdit = new QDateEdit(layoutWidget);
        DateEdit->setObjectName("DateEdit");
        DateEdit->setProperty("showGroupSeparator", QVariant(false));
        DateEdit->setCalendarPopup(true);

        LocationTimeLayout->addWidget(DateEdit);

        Update = new QPushButton(layoutWidget);
        Update->setObjectName("Update");

        LocationTimeLayout->addWidget(Update);

        horizontalSpacer_2 = new QSpacerItem(40, 20, QSizePolicy::Policy::Expanding, QSizePolicy::Policy::Minimum);

        LocationTimeLayout->addItem(horizontalSpacer_2);

        refLabel = new QLabel(layoutWidget);
        refLabel->setObjectName("refLabel");

        LocationTimeLayout->addWidget(refLabel);

        saveImages = new QPushButton(layoutWidget);
        saveImages->setObjectName("saveImages");

        LocationTimeLayout->addWidget(saveImages);

        DeleteAllImages = new QPushButton(layoutWidget);
        DeleteAllImages->setObjectName("DeleteAllImages");

        LocationTimeLayout->addWidget(DeleteAllImages);


        topLayout->addLayout(LocationTimeLayout);

        addingObjectsLayout = new QHBoxLayout();
        addingObjectsLayout->setSpacing(3);
        addingObjectsLayout->setObjectName("addingObjectsLayout");
        addingObjectsLayout->setContentsMargins(-1, 0, -1, -1);
        addLabel = new QLabel(layoutWidget);
        addLabel->setObjectName("addLabel");

        addingObjectsLayout->addWidget(addLabel);

        WizardButton = new QPushButton(layoutWidget);
        WizardButton->setObjectName("WizardButton");
        sizePolicy.setHeightForWidth(WizardButton->sizePolicy().hasHeightForWidth());
        WizardButton->setSizePolicy(sizePolicy);
        WizardButton->setMinimumSize(QSize(0, 0));
        WizardButton->setMaximumSize(QSize(16777215, 16777215));

        addingObjectsLayout->addWidget(WizardButton);

        FindButton = new QPushButton(layoutWidget);
        FindButton->setObjectName("FindButton");
        QSizePolicy sizePolicy1(QSizePolicy::Policy::Minimum, QSizePolicy::Policy::Fixed);
        sizePolicy1.setHorizontalStretch(0);
        sizePolicy1.setVerticalStretch(0);
        sizePolicy1.setHeightForWidth(FindButton->sizePolicy().hasHeightForWidth());
        FindButton->setSizePolicy(sizePolicy1);

        addingObjectsLayout->addWidget(FindButton);

        WUTButton = new QPushButton(layoutWidget);
        WUTButton->setObjectName("WUTButton");
        sizePolicy1.setHeightForWidth(WUTButton->sizePolicy().hasHeightForWidth());
        WUTButton->setSizePolicy(sizePolicy1);

        addingObjectsLayout->addWidget(WUTButton);

        batchAddButton = new QPushButton(layoutWidget);
        batchAddButton->setObjectName("batchAddButton");

        addingObjectsLayout->addWidget(batchAddButton);

        horizontalSpacer_5 = new QSpacerItem(40, 20, QSizePolicy::Policy::Expanding, QSizePolicy::Policy::Minimum);

        addingObjectsLayout->addItem(horizontalSpacer_5);

        clearListB = new QPushButton(layoutWidget);
        clearListB->setObjectName("clearListB");

        addingObjectsLayout->addWidget(clearListB);


        topLayout->addLayout(addingObjectsLayout);

        WishObjectInfoSplitter = new QSplitter(layoutWidget);
        WishObjectInfoSplitter->setObjectName("WishObjectInfoSplitter");
        WishObjectInfoSplitter->setOrientation(Qt::Horizontal);
        tabWidget = new QTabWidget(WishObjectInfoSplitter);
        tabWidget->setObjectName("tabWidget");
        QSizePolicy sizePolicy2(QSizePolicy::Policy::Expanding, QSizePolicy::Policy::Expanding);
        sizePolicy2.setHorizontalStretch(0);
        sizePolicy2.setVerticalStretch(0);
        sizePolicy2.setHeightForWidth(tabWidget->sizePolicy().hasHeightForWidth());
        tabWidget->setSizePolicy(sizePolicy2);
        tabWidget->setMinimumSize(QSize(0, 202));
        WishList = new QWidget();
        WishList->setObjectName("WishList");
        vboxLayout = new QVBoxLayout(WishList);
        vboxLayout->setSpacing(3);
        vboxLayout->setObjectName("vboxLayout");
        vboxLayout->setContentsMargins(3, 3, 3, 3);
        WishListView = new QTableView(WishList);
        WishListView->setObjectName("WishListView");
        QSizePolicy sizePolicy3(QSizePolicy::Policy::Expanding, QSizePolicy::Policy::MinimumExpanding);
        sizePolicy3.setHorizontalStretch(0);
        sizePolicy3.setVerticalStretch(0);
        sizePolicy3.setHeightForWidth(WishListView->sizePolicy().hasHeightForWidth());
        WishListView->setSizePolicy(sizePolicy3);
        WishListView->setEditTriggers(QAbstractItemView::NoEditTriggers);
        WishListView->setAlternatingRowColors(true);
        WishListView->setSelectionBehavior(QAbstractItemView::SelectRows);
        WishListView->setShowGrid(false);
        WishListView->setSortingEnabled(true);

        vboxLayout->addWidget(WishListView);

        tabWidget->addTab(WishList, QString());
        Session = new QWidget();
        Session->setObjectName("Session");
        verticalLayout_5 = new QVBoxLayout(Session);
        verticalLayout_5->setSpacing(3);
        verticalLayout_5->setObjectName("verticalLayout_5");
        verticalLayout_5->setContentsMargins(3, 3, 3, 3);
        SessionView = new QTableView(Session);
        SessionView->setObjectName("SessionView");
        sizePolicy2.setHeightForWidth(SessionView->sizePolicy().hasHeightForWidth());
        SessionView->setSizePolicy(sizePolicy2);
        SessionView->setEditTriggers(QAbstractItemView::NoEditTriggers);
        SessionView->setAlternatingRowColors(true);
        SessionView->setSelectionBehavior(QAbstractItemView::SelectRows);
        SessionView->setShowGrid(false);
        SessionView->setSortingEnabled(true);

        verticalLayout_5->addWidget(SessionView);

        horizontalLayout_5 = new QHBoxLayout();
        horizontalLayout_5->setSpacing(3);
        horizontalLayout_5->setObjectName("horizontalLayout_5");
        scheduledTimeLabel = new QLabel(Session);
        scheduledTimeLabel->setObjectName("scheduledTimeLabel");

        horizontalLayout_5->addWidget(scheduledTimeLabel);

        TimeEdit = new QTimeEdit(Session);
        TimeEdit->setObjectName("TimeEdit");
        QSizePolicy sizePolicy4(QSizePolicy::Policy::Preferred, QSizePolicy::Policy::Preferred);
        sizePolicy4.setHorizontalStretch(0);
        sizePolicy4.setVerticalStretch(0);
        sizePolicy4.setHeightForWidth(TimeEdit->sizePolicy().hasHeightForWidth());
        TimeEdit->setSizePolicy(sizePolicy4);
        TimeEdit->setMaximumSize(QSize(100, 30));

        horizontalLayout_5->addWidget(TimeEdit);

        SetTime = new QPushButton(Session);
        SetTime->setObjectName("SetTime");

        horizontalLayout_5->addWidget(SetTime);


        verticalLayout_5->addLayout(horizontalLayout_5);

        tabWidget->addTab(Session, QString());
        WishObjectInfoSplitter->addWidget(tabWidget);
        layoutWidget2 = new QWidget(WishObjectInfoSplitter);
        layoutWidget2->setObjectName("layoutWidget2");
        objectInfoLayout = new QVBoxLayout(layoutWidget2);
        objectInfoLayout->setSpacing(3);
        objectInfoLayout->setObjectName("objectInfoLayout");
        objectInfoLayout->setSizeConstraint(QLayout::SetDefaultConstraint);
        objectInfoLayout->setContentsMargins(0, 0, 0, 0);
        quickInfoLabel = new QLabel(layoutWidget2);
        quickInfoLabel->setObjectName("quickInfoLabel");

        objectInfoLayout->addWidget(quickInfoLabel);

        avt = new AVTPlotWidget(layoutWidget2);
        avt->setObjectName("avt");
        avt->setEnabled(true);
        QSizePolicy sizePolicy5(QSizePolicy::Policy::Fixed, QSizePolicy::Policy::Preferred);
        sizePolicy5.setHorizontalStretch(0);
        sizePolicy5.setVerticalStretch(0);
        sizePolicy5.setHeightForWidth(avt->sizePolicy().hasHeightForWidth());
        avt->setSizePolicy(sizePolicy5);
        avt->setMinimumSize(QSize(350, 200));
        avt->setMaximumSize(QSize(350, 200));
        avt->setCursor(QCursor(Qt::CursorShape::CrossCursor));

        objectInfoLayout->addWidget(avt);

        horizontalLayout_4 = new QHBoxLayout();
        horizontalLayout_4->setSpacing(3);
        horizontalLayout_4->setObjectName("horizontalLayout_4");
        ImagePreview = new QLabel(layoutWidget2);
        ImagePreview->setObjectName("ImagePreview");
        ImagePreview->setMinimumSize(QSize(200, 200));
        ImagePreview->setMaximumSize(QSize(200, 200));

        horizontalLayout_4->addWidget(ImagePreview);

        verticalLayout_3 = new QVBoxLayout();
        verticalLayout_3->setSpacing(2);
        verticalLayout_3->setObjectName("verticalLayout_3");
        dssMetadataLabel = new QLabel(layoutWidget2);
        dssMetadataLabel->setObjectName("dssMetadataLabel");
        sizePolicy4.setHeightForWidth(dssMetadataLabel->sizePolicy().hasHeightForWidth());
        dssMetadataLabel->setSizePolicy(sizePolicy4);
        dssMetadataLabel->setMinimumSize(QSize(145, 0));
        dssMetadataLabel->setAlignment(Qt::AlignLeading|Qt::AlignLeft|Qt::AlignTop);
        dssMetadataLabel->setWordWrap(true);

        verticalLayout_3->addWidget(dssMetadataLabel);

        verticalLayout = new QVBoxLayout();
        verticalLayout->setSpacing(3);
        verticalLayout->setObjectName("verticalLayout");
        verticalLayout->setContentsMargins(-1, -1, 12, -1);
        SearchImage = new QPushButton(layoutWidget2);
        SearchImage->setObjectName("SearchImage");
        QSizePolicy sizePolicy6(QSizePolicy::Policy::Preferred, QSizePolicy::Policy::Fixed);
        sizePolicy6.setHorizontalStretch(0);
        sizePolicy6.setVerticalStretch(0);
        sizePolicy6.setHeightForWidth(SearchImage->sizePolicy().hasHeightForWidth());
        SearchImage->setSizePolicy(sizePolicy6);

        verticalLayout->addWidget(SearchImage);

        DeleteImage = new QPushButton(layoutWidget2);
        DeleteImage->setObjectName("DeleteImage");
        sizePolicy6.setHeightForWidth(DeleteImage->sizePolicy().hasHeightForWidth());
        DeleteImage->setSizePolicy(sizePolicy6);

        verticalLayout->addWidget(DeleteImage);


        verticalLayout_3->addLayout(verticalLayout);


        horizontalLayout_4->addLayout(verticalLayout_3);


        objectInfoLayout->addLayout(horizontalLayout_4);

        WishObjectInfoSplitter->addWidget(layoutWidget2);

        topLayout->addWidget(WishObjectInfoSplitter);

        mainSplitter->addWidget(layoutWidget);
        NotesEdit = new QTextEdit(mainSplitter);
        NotesEdit->setObjectName("NotesEdit");
        sizePolicy4.setHeightForWidth(NotesEdit->sizePolicy().hasHeightForWidth());
        NotesEdit->setSizePolicy(sizePolicy4);
        mainSplitter->addWidget(NotesEdit);

        verticalLayout_2->addWidget(mainSplitter);


        retranslateUi(ObservingList);

        tabWidget->setCurrentIndex(0);


        QMetaObject::connectSlotsByName(ObservingList);
    } // setupUi

    void retranslateUi(QWidget *ObservingList)
    {
#if QT_CONFIG(tooltip)
        OpenButton->setToolTip(tr2i18n("Open an observation session list", nullptr));
#endif // QT_CONFIG(tooltip)
#if QT_CONFIG(whatsthis)
        OpenButton->setWhatsThis(tr2i18n("Load an observing list from disk", nullptr));
#endif // QT_CONFIG(whatsthis)
        OpenButton->setText(QString());
#if QT_CONFIG(tooltip)
        SaveButton->setToolTip(tr2i18n("Save the observing session", nullptr));
#endif // QT_CONFIG(tooltip)
#if QT_CONFIG(whatsthis)
        SaveButton->setWhatsThis(tr2i18n("Save the current observing list to disk", nullptr));
#endif // QT_CONFIG(whatsthis)
        SaveButton->setText(QString());
#if QT_CONFIG(tooltip)
        SaveAsButton->setToolTip(tr2i18n("Save observing session as...", nullptr));
#endif // QT_CONFIG(tooltip)
#if QT_CONFIG(whatsthis)
        SaveAsButton->setWhatsThis(tr2i18n("Save the current observing list to disk, specifying the filename", nullptr));
#endif // QT_CONFIG(whatsthis)
        SaveAsButton->setText(QString());
        OALExport->setText(tr2i18n("Export to OAL...", nullptr));
        locationLabel->setText(tr2i18n("Location:", nullptr));
        SetLocation->setText(tr2i18n("Choose", nullptr));
        dateLabel->setText(tr2i18n("Date:", nullptr));
        DateEdit->setDisplayFormat(tr2i18n("dd/MM/yyyy", nullptr));
#if QT_CONFIG(tooltip)
        Update->setToolTip(tr2i18n("Update the table and the plot for the new date and location.", nullptr));
#endif // QT_CONFIG(tooltip)
        Update->setText(tr2i18n("Update", nullptr));
        refLabel->setText(tr2i18n("Reference images:", nullptr));
#if QT_CONFIG(tooltip)
        saveImages->setToolTip(tr2i18n("Download the SDSS/DSS images of all the objects in the current list.", nullptr));
#endif // QT_CONFIG(tooltip)
        saveImages->setText(tr2i18n("Download all Images", nullptr));
#if QT_CONFIG(tooltip)
        DeleteAllImages->setToolTip(tr2i18n("Deletes all the stored DSS/SDSS images", nullptr));
#endif // QT_CONFIG(tooltip)
        DeleteAllImages->setText(tr2i18n("Delete all Images", nullptr));
        addLabel->setText(tr2i18n("Adding objects:", nullptr));
#if QT_CONFIG(tooltip)
        WizardButton->setToolTip(tr2i18n("Observing List Wizard", nullptr));
#endif // QT_CONFIG(tooltip)
#if QT_CONFIG(whatsthis)
        WizardButton->setWhatsThis(tr2i18n("The list wizard helps you construct observing lists based on filtering by object type, position on the sky, and magnitude.", nullptr));
#endif // QT_CONFIG(whatsthis)
        WizardButton->setText(tr2i18n("Wizard...", nullptr));
#if QT_CONFIG(tooltip)
        FindButton->setToolTip(tr2i18n("Open Find Dialog", nullptr));
#endif // QT_CONFIG(tooltip)
#if QT_CONFIG(whatsthis)
        FindButton->setWhatsThis(tr2i18n("Open the Find Dialog for adding objects to the list", nullptr));
#endif // QT_CONFIG(whatsthis)
        FindButton->setText(tr2i18n("Find Object...", nullptr));
#if QT_CONFIG(tooltip)
        WUTButton->setToolTip(tr2i18n("Open the WUT dialog", nullptr));
#endif // QT_CONFIG(tooltip)
#if QT_CONFIG(whatsthis)
        WUTButton->setWhatsThis(tr2i18n("Opens the What's up Tonight dialog, from which objects can be added to the list", nullptr));
#endif // QT_CONFIG(whatsthis)
        WUTButton->setText(tr2i18n("What's up Tonight...", nullptr));
        batchAddButton->setText(tr2i18n("Batch add", nullptr));
        clearListB->setText(tr2i18n("Clear List", nullptr));
        tabWidget->setTabText(tabWidget->indexOf(WishList), tr2i18n("Wish List", nullptr));
        scheduledTimeLabel->setText(tr2i18n("Scheduled Time", nullptr));
        SetTime->setText(tr2i18n("Set Time", nullptr));
        tabWidget->setTabText(tabWidget->indexOf(Session), tr2i18n("Session Plan", nullptr));
        quickInfoLabel->setText(tr2i18n("Select an Object to View Information here", nullptr));
        ImagePreview->setText(tr2i18n("(No Image)", nullptr));
        dssMetadataLabel->setText(tr2i18n("Image Metadata Info", nullptr));
        SearchImage->setText(tr2i18n("Replace from Internet...", nullptr));
        DeleteImage->setText(tr2i18n("Delete Image", nullptr));
        NotesEdit->setPlaceholderText(tr2i18n("Record object notes here.", nullptr));
        (void)ObservingList;
    } // retranslateUi

};

namespace Ui {
    class ObservingList: public Ui_ObservingList {};
} // namespace Ui

QT_END_NAMESPACE

#endif // OBSERVINGLIST_H

