/********************************************************************************
** Form generated from reading UI file 'fileutilitycameradatadialog.ui'
**
** Created by: Qt User Interface Compiler version 6.11.1
**
** WARNING! All changes made in this file will be lost when recompiling UI file!
********************************************************************************/

#ifndef UI_FILEUTILITYCAMERADATADIALOG_H
#define UI_FILEUTILITYCAMERADATADIALOG_H

#include <QtCore/QVariant>
#include <QtWidgets/QAbstractButton>
#include <QtWidgets/QApplication>
#include <QtWidgets/QDialog>
#include <QtWidgets/QDialogButtonBox>
#include <QtWidgets/QGridLayout>
#include <QtWidgets/QLabel>
#include <QtWidgets/QListWidget>
#include <QtWidgets/QPushButton>
#include <QtWidgets/QSpacerItem>
#include <klocalizedstring.h>

QT_BEGIN_NAMESPACE

class Ui_FileUtilityCameraDataDialog
{
public:
    QGridLayout *gridLayout;
    QListWidget *availableRemoteCameraList;
    QPushButton *downloadB;
    QSpacerItem *horizontalSpacer;
    QDialogButtonBox *buttonBox;
    QLabel *resultLable;
    QLabel *counter;

    void setupUi(QDialog *FileUtilityCameraDataDialog)
    {
        if (FileUtilityCameraDataDialog->objectName().isEmpty())
            FileUtilityCameraDataDialog->setObjectName("FileUtilityCameraDataDialog");
        FileUtilityCameraDataDialog->setWindowModality(Qt::WindowModal);
        FileUtilityCameraDataDialog->resize(320, 292);
        QSizePolicy sizePolicy(QSizePolicy::Policy::Expanding, QSizePolicy::Policy::Expanding);
        sizePolicy.setHorizontalStretch(0);
        sizePolicy.setVerticalStretch(0);
        sizePolicy.setHeightForWidth(FileUtilityCameraDataDialog->sizePolicy().hasHeightForWidth());
        FileUtilityCameraDataDialog->setSizePolicy(sizePolicy);
        FileUtilityCameraDataDialog->setMinimumSize(QSize(320, 290));
        FileUtilityCameraDataDialog->setMaximumSize(QSize(16777215, 16777215));
        FileUtilityCameraDataDialog->setSizeGripEnabled(true);
        gridLayout = new QGridLayout(FileUtilityCameraDataDialog);
        gridLayout->setObjectName("gridLayout");
        availableRemoteCameraList = new QListWidget(FileUtilityCameraDataDialog);
        availableRemoteCameraList->setObjectName("availableRemoteCameraList");

        gridLayout->addWidget(availableRemoteCameraList, 1, 0, 1, 4);

        downloadB = new QPushButton(FileUtilityCameraDataDialog);
        downloadB->setObjectName("downloadB");
        QSizePolicy sizePolicy1(QSizePolicy::Policy::Preferred, QSizePolicy::Policy::Fixed);
        sizePolicy1.setHorizontalStretch(0);
        sizePolicy1.setVerticalStretch(0);
        sizePolicy1.setHeightForWidth(downloadB->sizePolicy().hasHeightForWidth());
        downloadB->setSizePolicy(sizePolicy1);
        downloadB->setMinimumSize(QSize(100, 0));

        gridLayout->addWidget(downloadB, 4, 2, 1, 1);

        horizontalSpacer = new QSpacerItem(93, 20, QSizePolicy::Policy::Expanding, QSizePolicy::Policy::Minimum);

        gridLayout->addItem(horizontalSpacer, 4, 1, 1, 1);

        buttonBox = new QDialogButtonBox(FileUtilityCameraDataDialog);
        buttonBox->setObjectName("buttonBox");
        QSizePolicy sizePolicy2(QSizePolicy::Policy::MinimumExpanding, QSizePolicy::Policy::Fixed);
        sizePolicy2.setHorizontalStretch(0);
        sizePolicy2.setVerticalStretch(0);
        sizePolicy2.setHeightForWidth(buttonBox->sizePolicy().hasHeightForWidth());
        buttonBox->setSizePolicy(sizePolicy2);
        buttonBox->setMinimumSize(QSize(100, 3));
        buttonBox->setOrientation(Qt::Horizontal);
        buttonBox->setStandardButtons(QDialogButtonBox::Cancel);

        gridLayout->addWidget(buttonBox, 4, 3, 1, 1);

        resultLable = new QLabel(FileUtilityCameraDataDialog);
        resultLable->setObjectName("resultLable");

        gridLayout->addWidget(resultLable, 0, 0, 1, 4);

        counter = new QLabel(FileUtilityCameraDataDialog);
        counter->setObjectName("counter");
        counter->setMinimumSize(QSize(60, 0));

        gridLayout->addWidget(counter, 4, 0, 1, 1);


        retranslateUi(FileUtilityCameraDataDialog);
        QObject::connect(buttonBox, &QDialogButtonBox::accepted, FileUtilityCameraDataDialog, qOverload<>(&QDialog::accept));
        QObject::connect(buttonBox, &QDialogButtonBox::rejected, FileUtilityCameraDataDialog, qOverload<>(&QDialog::reject));

        QMetaObject::connectSlotsByName(FileUtilityCameraDataDialog);
    } // setupUi

    void retranslateUi(QDialog *FileUtilityCameraDataDialog)
    {
        FileUtilityCameraDataDialog->setWindowTitle(tr2i18n("Camera Data Download", nullptr));
        downloadB->setText(tr2i18n("Download", nullptr));
        resultLable->setText(tr2i18n("Select all cameras you wish to use:", nullptr));
        counter->setText(QString());
    } // retranslateUi

};

namespace Ui {
    class FileUtilityCameraDataDialog: public Ui_FileUtilityCameraDataDialog {};
} // namespace Ui

QT_END_NAMESPACE

#endif // FILEUTILITYCAMERADATADIALOG_H

