/*
 * This file was generated by qdbusxml2cpp version 0.8
 * Source file was org.kde.kstars.xml
 *
 * qdbusxml2cpp is Copyright (C) The Qt Company Ltd. and other contributors.
 *
 * This is an auto-generated file.
 * This file may have been hand-edited. Look for HAND-EDIT comments
 * before re-generating it.
 */

#ifndef KSTARSADAPTOR_H
#define KSTARSADAPTOR_H

#include <QtCore/QObject>
#include <QtDBus/QtDBus>
#include "kstars.h"
#include <QtCore/qcontainerfwd.h>

/*
 * Adaptor class for interface org.kde.kstars
 */
class KstarsAdaptor: public QDBusAbstractAdaptor
{
    Q_OBJECT
    Q_CLASSINFO("D-Bus Interface", "org.kde.kstars")
    Q_CLASSINFO("D-Bus Introspection", ""
"  <interface name=\"org.kde.kstars\">\n"
"    <property access=\"readwrite\" type=\"s\" name=\"colorScheme\"/>\n"
"    <property access=\"read\" type=\"s\" name=\"version\"/>\n"
"    <property access=\"read\" type=\"s\" name=\"release\"/>\n"
"    <method name=\"setRaDec\">\n"
"      <arg direction=\"in\" type=\"d\" name=\"ra\"/>\n"
"      <arg direction=\"in\" type=\"d\" name=\"dec\"/>\n"
"      <annotation value=\"true\" name=\"org.freedesktop.DBus.Method.NoReply\"/>\n"
"    </method>\n"
"    <method name=\"setRaDecJ2000\">\n"
"      <arg direction=\"in\" type=\"d\" name=\"ra0\"/>\n"
"      <arg direction=\"in\" type=\"d\" name=\"dec0\"/>\n"
"      <annotation value=\"true\" name=\"org.freedesktop.DBus.Method.NoReply\"/>\n"
"    </method>\n"
"    <method name=\"setAltAz\">\n"
"      <arg direction=\"in\" type=\"d\" name=\"alt\"/>\n"
"      <arg direction=\"in\" type=\"d\" name=\"az\"/>\n"
"      <arg direction=\"in\" type=\"b\" name=\"altIsRefracted\"/>\n"
"      <annotation value=\"true\" name=\"org.freedesktop.DBus.Method.NoReply\"/>\n"
"    </method>\n"
"    <method name=\"setAltAz\">\n"
"      <arg direction=\"in\" type=\"d\" name=\"alt\"/>\n"
"      <arg direction=\"in\" type=\"d\" name=\"az\"/>\n"
"      <annotation value=\"true\" name=\"org.freedesktop.DBus.Method.NoReply\"/>\n"
"    </method>\n"
"    <method name=\"lookTowards\">\n"
"      <arg direction=\"in\" type=\"s\" name=\"direction\"/>\n"
"      <annotation value=\"true\" name=\"org.freedesktop.DBus.Method.NoReply\"/>\n"
"    </method>\n"
"    <method name=\"addLabel\">\n"
"      <arg direction=\"in\" type=\"s\" name=\"name\"/>\n"
"      <annotation value=\"true\" name=\"org.freedesktop.DBus.Method.NoReply\"/>\n"
"    </method>\n"
"    <method name=\"removeLabel\">\n"
"      <arg direction=\"in\" type=\"s\" name=\"name\"/>\n"
"      <annotation value=\"true\" name=\"org.freedesktop.DBus.Method.NoReply\"/>\n"
"    </method>\n"
"    <method name=\"addTrail\">\n"
"      <arg direction=\"in\" type=\"s\" name=\"name\"/>\n"
"      <annotation value=\"true\" name=\"org.freedesktop.DBus.Method.NoReply\"/>\n"
"    </method>\n"
"    <method name=\"removeTrail\">\n"
"      <arg direction=\"in\" type=\"s\" name=\"name\"/>\n"
"      <annotation value=\"true\" name=\"org.freedesktop.DBus.Method.NoReply\"/>\n"
"    </method>\n"
"    <method name=\"zoomIn\">\n"
"      <annotation value=\"true\" name=\"org.freedesktop.DBus.Method.NoReply\"/>\n"
"    </method>\n"
"    <method name=\"zoomOut\">\n"
"      <annotation value=\"true\" name=\"org.freedesktop.DBus.Method.NoReply\"/>\n"
"    </method>\n"
"    <method name=\"defaultZoom\">\n"
"      <annotation value=\"true\" name=\"org.freedesktop.DBus.Method.NoReply\"/>\n"
"    </method>\n"
"    <method name=\"zoom\">\n"
"      <arg direction=\"in\" type=\"d\" name=\"z\"/>\n"
"      <annotation value=\"true\" name=\"org.freedesktop.DBus.Method.NoReply\"/>\n"
"    </method>\n"
"    <method name=\"setLocalTime\">\n"
"      <arg direction=\"in\" type=\"i\" name=\"yr\"/>\n"
"      <arg direction=\"in\" type=\"i\" name=\"mth\"/>\n"
"      <arg direction=\"in\" type=\"i\" name=\"day\"/>\n"
"      <arg direction=\"in\" type=\"i\" name=\"hr\"/>\n"
"      <arg direction=\"in\" type=\"i\" name=\"min\"/>\n"
"      <arg direction=\"in\" type=\"i\" name=\"sec\"/>\n"
"      <annotation value=\"true\" name=\"org.freedesktop.DBus.Method.NoReply\"/>\n"
"    </method>\n"
"    <method name=\"setTimeToNow\">\n"
"      <annotation value=\"true\" name=\"org.freedesktop.DBus.Method.NoReply\"/>\n"
"    </method>\n"
"    <method name=\"waitFor\">\n"
"      <arg direction=\"in\" type=\"d\" name=\"t\"/>\n"
"      <annotation value=\"true\" name=\"org.freedesktop.DBus.Method.NoReply\"/>\n"
"    </method>\n"
"    <method name=\"waitForKey\">\n"
"      <arg direction=\"in\" type=\"s\" name=\"k\"/>\n"
"      <annotation value=\"true\" name=\"org.freedesktop.DBus.Method.NoReply\"/>\n"
"    </method>\n"
"    <method name=\"setTracking\">\n"
"      <arg direction=\"in\" type=\"b\" name=\"track\"/>\n"
"      <annotation value=\"true\" name=\"org.freedesktop.DBus.Method.NoReply\"/>\n"
"    </method>\n"
"    <method name=\"changeViewOption\">\n"
"      <arg direction=\"in\" type=\"s\" name=\"option\"/>\n"
"      <arg direction=\"in\" type=\"s\" name=\"value\"/>\n"
"      <annotation value=\"true\" name=\"org.freedesktop.DBus.Method.NoReply\"/>\n"
"    </method>\n"
"    <method name=\"getOption\">\n"
"      <arg direction=\"in\" type=\"s\" name=\"name\"/>\n"
"      <arg direction=\"out\" type=\"v\"/>\n"
"    </method>\n"
"    <method name=\"setOption\">\n"
"      <arg direction=\"in\" type=\"s\" name=\"name\"/>\n"
"      <arg direction=\"in\" type=\"v\" name=\"value\"/>\n"
"      <annotation value=\"true\" name=\"org.freedesktop.DBus.Method.NoReply\"/>\n"
"    </method>\n"
"    <method name=\"getFocusInformationXML\">\n"
"      <arg direction=\"out\" type=\"s\"/>\n"
"    </method>\n"
"    <method name=\"readConfig\">\n"
"      <annotation value=\"true\" name=\"org.freedesktop.DBus.Method.NoReply\"/>\n"
"    </method>\n"
"    <method name=\"writeConfig\">\n"
"      <annotation value=\"true\" name=\"org.freedesktop.DBus.Method.NoReply\"/>\n"
"    </method>\n"
"    <method name=\"popupMessage\">\n"
"      <arg direction=\"in\" type=\"i\" name=\"x\"/>\n"
"      <arg direction=\"in\" type=\"i\" name=\"y\"/>\n"
"      <arg direction=\"in\" type=\"s\" name=\"message\"/>\n"
"      <annotation value=\"true\" name=\"org.freedesktop.DBus.Method.NoReply\"/>\n"
"    </method>\n"
"    <method name=\"drawLine\">\n"
"      <arg direction=\"in\" type=\"i\" name=\"x1\"/>\n"
"      <arg direction=\"in\" type=\"i\" name=\"y1\"/>\n"
"      <arg direction=\"in\" type=\"i\" name=\"x2\"/>\n"
"      <arg direction=\"in\" type=\"i\" name=\"y2\"/>\n"
"      <arg direction=\"in\" type=\"i\" name=\"speed\"/>\n"
"      <annotation value=\"true\" name=\"org.freedesktop.DBus.Method.NoReply\"/>\n"
"    </method>\n"
"    <method name=\"setGeoLocation\">\n"
"      <arg direction=\"out\" type=\"b\"/>\n"
"      <arg direction=\"in\" type=\"s\" name=\"city\"/>\n"
"      <arg direction=\"in\" type=\"s\" name=\"province\"/>\n"
"      <arg direction=\"in\" type=\"s\" name=\"country\"/>\n"
"    </method>\n"
"    <method name=\"location\">\n"
"      <arg direction=\"out\" type=\"s\"/>\n"
"    </method>\n"
"    <method name=\"setGPSLocation\">\n"
"      <arg direction=\"out\" type=\"b\"/>\n"
"      <arg direction=\"in\" type=\"d\" name=\"longitude\"/>\n"
"      <arg direction=\"in\" type=\"d\" name=\"latitude\"/>\n"
"      <arg direction=\"in\" type=\"d\" name=\"elevation\"/>\n"
"      <arg direction=\"in\" type=\"d\" name=\"tz0\"/>\n"
"    </method>\n"
"    <method name=\"setColor\">\n"
"      <arg direction=\"in\" type=\"s\" name=\"colorName\"/>\n"
"      <arg direction=\"in\" type=\"s\" name=\"value\"/>\n"
"      <annotation value=\"true\" name=\"org.freedesktop.DBus.Method.NoReply\"/>\n"
"    </method>\n"
"    <method name=\"loadColorScheme\">\n"
"      <arg direction=\"in\" type=\"s\" name=\"name\"/>\n"
"      <annotation value=\"true\" name=\"org.freedesktop.DBus.Method.NoReply\"/>\n"
"    </method>\n"
"    <method name=\"exportImage\">\n"
"      <arg direction=\"in\" type=\"s\" name=\"filename\"/>\n"
"      <arg direction=\"in\" type=\"i\" name=\"width\"/>\n"
"      <arg direction=\"in\" type=\"i\" name=\"height\"/>\n"
"      <arg direction=\"in\" type=\"b\" name=\"includeLegend\"/>\n"
"      <annotation value=\"true\" name=\"org.freedesktop.DBus.Method.NoReply\"/>\n"
"    </method>\n"
"    <method name=\"exportImage\">\n"
"      <arg direction=\"in\" type=\"s\" name=\"filename\"/>\n"
"      <arg direction=\"in\" type=\"i\" name=\"width\"/>\n"
"      <arg direction=\"in\" type=\"i\" name=\"height\"/>\n"
"      <annotation value=\"true\" name=\"org.freedesktop.DBus.Method.NoReply\"/>\n"
"    </method>\n"
"    <method name=\"exportImage\">\n"
"      <arg direction=\"in\" type=\"s\" name=\"filename\"/>\n"
"      <arg direction=\"in\" type=\"i\" name=\"width\"/>\n"
"      <annotation value=\"true\" name=\"org.freedesktop.DBus.Method.NoReply\"/>\n"
"    </method>\n"
"    <method name=\"exportImage\">\n"
"      <arg direction=\"in\" type=\"s\" name=\"filename\"/>\n"
"      <annotation value=\"true\" name=\"org.freedesktop.DBus.Method.NoReply\"/>\n"
"    </method>\n"
"    <method name=\"getDSSURL\">\n"
"      <arg direction=\"out\" type=\"s\"/>\n"
"      <arg direction=\"in\" type=\"s\" name=\"objectName\"/>\n"
"    </method>\n"
"    <method name=\"getDSSURL\">\n"
"      <arg direction=\"out\" type=\"s\"/>\n"
"      <arg direction=\"in\" type=\"d\" name=\"RA_J2000\"/>\n"
"      <arg direction=\"in\" type=\"d\" name=\"Dec_J2000\"/>\n"
"      <arg direction=\"in\" type=\"d\" name=\"width\"/>\n"
"      <arg direction=\"in\" type=\"d\" name=\"height\"/>\n"
"    </method>\n"
"    <method name=\"getDSSURL\">\n"
"      <arg direction=\"out\" type=\"s\"/>\n"
"      <arg direction=\"in\" type=\"d\" name=\"RA_J2000\"/>\n"
"      <arg direction=\"in\" type=\"d\" name=\"Dec_J2000\"/>\n"
"    </method>\n"
"    <method name=\"getObjectDataXML\">\n"
"      <arg direction=\"out\" type=\"s\"/>\n"
"      <arg direction=\"in\" type=\"s\" name=\"objectName\"/>\n"
"      <arg direction=\"in\" type=\"b\" name=\"fallbackToInternet\"/>\n"
"      <arg direction=\"in\" type=\"b\" name=\"storeInternetResolved\"/>\n"
"    </method>\n"
"    <method name=\"getObjectDataXML\">\n"
"      <arg direction=\"out\" type=\"s\"/>\n"
"      <arg direction=\"in\" type=\"s\" name=\"objectName\"/>\n"
"      <arg direction=\"in\" type=\"b\" name=\"fallbackToInternet\"/>\n"
"    </method>\n"
"    <method name=\"getObjectDataXML\">\n"
"      <arg direction=\"out\" type=\"s\"/>\n"
"      <arg direction=\"in\" type=\"s\" name=\"objectName\"/>\n"
"    </method>\n"
"    <method name=\"getObjectPositionInfo\">\n"
"      <arg direction=\"out\" type=\"s\"/>\n"
"      <arg direction=\"in\" type=\"s\" name=\"objectName\"/>\n"
"    </method>\n"
"    <method name=\"renderEyepieceView\">\n"
"      <arg direction=\"in\" type=\"s\" name=\"objectName\"/>\n"
"      <arg direction=\"in\" type=\"s\" name=\"destPathChart\"/>\n"
"      <arg direction=\"in\" type=\"d\" name=\"fovWidth\"/>\n"
"      <arg direction=\"in\" type=\"d\" name=\"fovHeight\"/>\n"
"      <arg direction=\"in\" type=\"d\" name=\"rotation\"/>\n"
"      <arg direction=\"in\" type=\"d\" name=\"scale\"/>\n"
"      <arg direction=\"in\" type=\"b\" name=\"flip\"/>\n"
"      <arg direction=\"in\" type=\"b\" name=\"invert\"/>\n"
"      <arg direction=\"in\" type=\"s\" name=\"imagePath\"/>\n"
"      <arg direction=\"in\" type=\"s\" name=\"destPathImage\"/>\n"
"      <arg direction=\"in\" type=\"b\" name=\"overlay\"/>\n"
"      <arg direction=\"in\" type=\"b\" name=\"invertColors\"/>\n"
"      <annotation value=\"true\" name=\"org.freedesktop.DBus.Method.NoReply\"/>\n"
"    </method>\n"
"    <method name=\"setApproxFOV\">\n"
"      <arg direction=\"in\" type=\"d\" name=\"FOV_Degrees\"/>\n"
"      <annotation value=\"true\" name=\"org.freedesktop.DBus.Method.NoReply\"/>\n"
"    </method>\n"
"    <method name=\"getSkyMapDimensions\">\n"
"      <arg direction=\"out\" type=\"s\"/>\n"
"    </method>\n"
"    <method name=\"getObservingWishListObjectNames\">\n"
"      <arg direction=\"out\" type=\"s\"/>\n"
"    </method>\n"
"    <method name=\"getObservingSessionPlanObjectNames\">\n"
"      <arg direction=\"out\" type=\"s\"/>\n"
"    </method>\n"
"    <method name=\"printImage\">\n"
"      <arg direction=\"in\" type=\"b\" name=\"usePrintDialog\"/>\n"
"      <arg direction=\"in\" type=\"b\" name=\"useChartColors\"/>\n"
"      <annotation value=\"true\" name=\"org.freedesktop.DBus.Method.NoReply\"/>\n"
"    </method>\n"
"    <method name=\"openFITS\">\n"
"      <arg direction=\"in\" type=\"(i)\" name=\"imageURL\"/>\n"
"      <annotation value=\"QUrl\" name=\"org.qtproject.QtDBus.QtTypeName.In0\"/>\n"
"      <annotation value=\"QUrl\" name=\"org.qtproject.QtDBus.QtTypeName.Out0\"/>\n"
"      <annotation value=\"true\" name=\"org.freedesktop.DBus.Method.NoReply\"/>\n"
"    </method>\n"
"    <method name=\"listSkyMapViews\">\n"
"      <arg direction=\"out\" type=\"as\"/>\n"
"    </method>\n"
"    <method name=\"setSkyMapView\">\n"
"      <arg direction=\"out\" type=\"b\"/>\n"
"      <arg direction=\"in\" type=\"s\" name=\"viewName\"/>\n"
"    </method>\n"
"    <method name=\"setFOVIndicatorVisibility\">\n"
"      <arg direction=\"out\" type=\"b\"/>\n"
"      <arg direction=\"in\" type=\"s\" name=\"fovName\"/>\n"
"      <arg direction=\"in\" type=\"b\" name=\"visibility\"/>\n"
"    </method>\n"
"    <method name=\"getFOVIndicatorVisibility\">\n"
"      <arg direction=\"out\" type=\"b\"/>\n"
"      <arg direction=\"in\" type=\"s\" name=\"fovName\"/>\n"
"    </method>\n"
"    <method name=\"getFOVIndicators\">\n"
"      <arg direction=\"out\" type=\"as\"/>\n"
"    </method>\n"
"    <method name=\"setSkyMapRotation\">\n"
"      <arg direction=\"in\" type=\"d\" name=\"viewAngle\"/>\n"
"      <annotation value=\"true\" name=\"org.freedesktop.DBus.Method.NoReply\"/>\n"
"    </method>\n"
"    <method name=\"getSkyMapRotation\">\n"
"      <arg direction=\"out\" type=\"d\"/>\n"
"    </method>\n"
"    <method name=\"skyMapIsMirrored\">\n"
"      <arg direction=\"out\" type=\"b\"/>\n"
"    </method>\n"
"    <method name=\"setSkyMapMirrored\">\n"
"      <arg direction=\"in\" type=\"b\" name=\"mirrored\"/>\n"
"      <annotation value=\"true\" name=\"org.freedesktop.DBus.Method.NoReply\"/>\n"
"    </method>\n"
"    <signal name=\"colorSchemeChanged\"/>\n"
"    <method name=\"getToggleableActionStates\">\n"
"      <arg direction=\"out\" type=\"s\"/>\n"
"    </method>\n"
"    <method name=\"activateAction\">\n"
"      <arg direction=\"out\" type=\"b\"/>\n"
"      <arg direction=\"in\" type=\"s\" name=\"actionName\"/>\n"
"    </method>\n"
"    <method name=\"getActions\">\n"
"      <arg direction=\"out\" type=\"as\"/>\n"
"    </method>\n"
"    <method name=\"setToggleableActionState\">\n"
"      <arg direction=\"out\" type=\"b\"/>\n"
"      <arg direction=\"in\" type=\"s\" name=\"actionName\"/>\n"
"      <arg direction=\"in\" type=\"b\" name=\"state\"/>\n"
"    </method>\n"
"    <method name=\"colorScheme\">\n"
"      <arg direction=\"out\" type=\"s\"/>\n"
"    </method>\n"
"  </interface>\n"
        "")
public:
    KstarsAdaptor(KStars *parent);
    ~KstarsAdaptor() override;

    inline KStars *parent() const
    { return static_cast<KStars *>(QObject::parent()); }

public: // PROPERTIES
    Q_PROPERTY(QString colorScheme READ colorScheme WRITE setColorScheme)
    QString colorScheme() const;
    void setColorScheme(const QString &value);

    Q_PROPERTY(QString release READ release)
    QString release() const;

    Q_PROPERTY(QString version READ version)
    QString version() const;

public Q_SLOTS: // METHODS
    bool activateAction(const QString &actionName);
    Q_NOREPLY void addLabel(const QString &name);
    Q_NOREPLY void addTrail(const QString &name);
    Q_NOREPLY void changeViewOption(const QString &option, const QString &value);
    QString colorScheme();
    Q_NOREPLY void defaultZoom();
    Q_NOREPLY void drawLine(int x1, int y1, int x2, int y2, int speed);
    Q_NOREPLY void exportImage(const QString &filename);
    Q_NOREPLY void exportImage(const QString &filename, int width);
    Q_NOREPLY void exportImage(const QString &filename, int width, int height);
    Q_NOREPLY void exportImage(const QString &filename, int width, int height, bool includeLegend);
    QStringList getActions();
    QString getDSSURL(double RA_J2000, double Dec_J2000);
    QString getDSSURL(double RA_J2000, double Dec_J2000, double width, double height);
    QString getDSSURL(const QString &objectName);
    bool getFOVIndicatorVisibility(const QString &fovName);
    QStringList getFOVIndicators();
    QString getFocusInformationXML();
    QString getObjectDataXML(const QString &objectName);
    QString getObjectDataXML(const QString &objectName, bool fallbackToInternet);
    QString getObjectDataXML(const QString &objectName, bool fallbackToInternet, bool storeInternetResolved);
    QString getObjectPositionInfo(const QString &objectName);
    QString getObservingSessionPlanObjectNames();
    QString getObservingWishListObjectNames();
    QDBusVariant getOption(const QString &name);
    QString getSkyMapDimensions();
    double getSkyMapRotation();
    QString getToggleableActionStates();
    QStringList listSkyMapViews();
    Q_NOREPLY void loadColorScheme(const QString &name);
    QString location();
    Q_NOREPLY void lookTowards(const QString &direction);
    Q_NOREPLY void openFITS(const QUrl &imageURL);
    Q_NOREPLY void popupMessage(int x, int y, const QString &message);
    Q_NOREPLY void printImage(bool usePrintDialog, bool useChartColors);
    Q_NOREPLY void readConfig();
    Q_NOREPLY void removeLabel(const QString &name);
    Q_NOREPLY void removeTrail(const QString &name);
    Q_NOREPLY void renderEyepieceView(const QString &objectName, const QString &destPathChart, double fovWidth, double fovHeight, double rotation, double scale, bool flip, bool invert, const QString &imagePath, const QString &destPathImage, bool overlay, bool invertColors);
    Q_NOREPLY void setAltAz(double alt, double az);
    Q_NOREPLY void setAltAz(double alt, double az, bool altIsRefracted);
    Q_NOREPLY void setApproxFOV(double FOV_Degrees);
    Q_NOREPLY void setColor(const QString &colorName, const QString &value);
    bool setFOVIndicatorVisibility(const QString &fovName, bool visibility);
    bool setGPSLocation(double longitude, double latitude, double elevation, double tz0);
    bool setGeoLocation(const QString &city, const QString &province, const QString &country);
    Q_NOREPLY void setLocalTime(int yr, int mth, int day, int hr, int min, int sec);
    Q_NOREPLY void setOption(const QString &name, const QDBusVariant &value);
    Q_NOREPLY void setRaDec(double ra, double dec);
    Q_NOREPLY void setRaDecJ2000(double ra0, double dec0);
    Q_NOREPLY void setSkyMapMirrored(bool mirrored);
    Q_NOREPLY void setSkyMapRotation(double viewAngle);
    bool setSkyMapView(const QString &viewName);
    Q_NOREPLY void setTimeToNow();
    bool setToggleableActionState(const QString &actionName, bool state);
    Q_NOREPLY void setTracking(bool track);
    bool skyMapIsMirrored();
    Q_NOREPLY void waitFor(double t);
    Q_NOREPLY void waitForKey(const QString &k);
    Q_NOREPLY void writeConfig();
    Q_NOREPLY void zoom(double z);
    Q_NOREPLY void zoomIn();
    Q_NOREPLY void zoomOut();
Q_SIGNALS: // SIGNALS
    void colorSchemeChanged();
};

#endif
