/********************************************************************************
** Form generated from reading UI file 'finddialog.ui'
**
** Created by: Qt User Interface Compiler version 6.11.1
**
** WARNING! All changes made in this file will be lost when recompiling UI file!
********************************************************************************/

#ifndef UI_FINDDIALOG_H
#define UI_FINDDIALOG_H

#include <QtCore/QVariant>
#include <QtGui/QIcon>
#include <QtWidgets/QApplication>
#include <QtWidgets/QComboBox>
#include <QtWidgets/QHBoxLayout>
#include <QtWidgets/QLabel>
#include <QtWidgets/QLineEdit>
#include <QtWidgets/QListView>
#include <QtWidgets/QPushButton>
#include <QtWidgets/QVBoxLayout>
#include <QtWidgets/QWidget>
#include <klocalizedstring.h>

QT_BEGIN_NAMESPACE

class Ui_FindDialog
{
public:
    QVBoxLayout *vboxLayout;
    QHBoxLayout *hboxLayout;
    QLabel *SearchLabel;
    QLineEdit *SearchBox;
    QPushButton *showHistoryB;
    QPushButton *clearHistoryB;
    QHBoxLayout *hboxLayout1;
    QLabel *FilterTypeLabel;
    QComboBox *FilterType;
    QListView *SearchList;
    QPushButton *InternetSearchButton;

    void setupUi(QWidget *FindDialog)
    {
        if (FindDialog->objectName().isEmpty())
            FindDialog->setObjectName("FindDialog");
        FindDialog->resize(319, 435);
        vboxLayout = new QVBoxLayout(FindDialog);
        vboxLayout->setSpacing(6);
        vboxLayout->setObjectName("vboxLayout");
        vboxLayout->setContentsMargins(8, 8, 8, 8);
        hboxLayout = new QHBoxLayout();
        hboxLayout->setSpacing(6);
        hboxLayout->setObjectName("hboxLayout");
        hboxLayout->setContentsMargins(0, 0, 0, 0);
        SearchLabel = new QLabel(FindDialog);
        SearchLabel->setObjectName("SearchLabel");

        hboxLayout->addWidget(SearchLabel);

        SearchBox = new QLineEdit(FindDialog);
        SearchBox->setObjectName("SearchBox");
        SearchBox->setClearButtonEnabled(true);

        hboxLayout->addWidget(SearchBox);

        showHistoryB = new QPushButton(FindDialog);
        showHistoryB->setObjectName("showHistoryB");
        showHistoryB->setMinimumSize(QSize(24, 24));
        showHistoryB->setMaximumSize(QSize(24, 24));
        QIcon icon(QIcon::fromTheme(QString::fromUtf8("clock")));
        showHistoryB->setIcon(icon);
        showHistoryB->setIconSize(QSize(24, 24));

        hboxLayout->addWidget(showHistoryB);

        clearHistoryB = new QPushButton(FindDialog);
        clearHistoryB->setObjectName("clearHistoryB");
        clearHistoryB->setEnabled(false);
        clearHistoryB->setMinimumSize(QSize(24, 24));
        clearHistoryB->setMaximumSize(QSize(24, 24));
        QIcon icon1;
        QString iconThemeName = QString::fromUtf8("edit-clear-history");
        if (QIcon::hasThemeIcon(iconThemeName)) {
            icon1 = QIcon::fromTheme(iconThemeName);
        } else {
            icon1.addFile(QString::fromUtf8("."), QSize(), QIcon::Mode::Normal, QIcon::State::Off);
        }
        clearHistoryB->setIcon(icon1);
        clearHistoryB->setIconSize(QSize(24, 24));

        hboxLayout->addWidget(clearHistoryB);


        vboxLayout->addLayout(hboxLayout);

        hboxLayout1 = new QHBoxLayout();
        hboxLayout1->setSpacing(6);
        hboxLayout1->setObjectName("hboxLayout1");
        hboxLayout1->setContentsMargins(0, 0, 0, 0);
        FilterTypeLabel = new QLabel(FindDialog);
        FilterTypeLabel->setObjectName("FilterTypeLabel");

        hboxLayout1->addWidget(FilterTypeLabel);

        FilterType = new QComboBox(FindDialog);
        FilterType->setObjectName("FilterType");
        QSizePolicy sizePolicy(QSizePolicy::Policy::MinimumExpanding, QSizePolicy::Policy::Fixed);
        sizePolicy.setHorizontalStretch(0);
        sizePolicy.setVerticalStretch(0);
        sizePolicy.setHeightForWidth(FilterType->sizePolicy().hasHeightForWidth());
        FilterType->setSizePolicy(sizePolicy);

        hboxLayout1->addWidget(FilterType);


        vboxLayout->addLayout(hboxLayout1);

        SearchList = new QListView(FindDialog);
        SearchList->setObjectName("SearchList");

        vboxLayout->addWidget(SearchList);

        InternetSearchButton = new QPushButton(FindDialog);
        InternetSearchButton->setObjectName("InternetSearchButton");

        vboxLayout->addWidget(InternetSearchButton);

        QWidget::setTabOrder(FilterType, SearchList);

        retranslateUi(FindDialog);

        QMetaObject::connectSlotsByName(FindDialog);
    } // setupUi

    void retranslateUi(QWidget *FindDialog)
    {
        SearchLabel->setText(tr2i18n("Filter by name:", nullptr));
#if QT_CONFIG(tooltip)
        showHistoryB->setToolTip(tr2i18n("Find History", nullptr));
#endif // QT_CONFIG(tooltip)
        showHistoryB->setText(QString());
#if QT_CONFIG(tooltip)
        clearHistoryB->setToolTip(tr2i18n("Clear History", nullptr));
#endif // QT_CONFIG(tooltip)
        clearHistoryB->setText(QString());
        FilterTypeLabel->setText(tr2i18n("Filter by type:", nullptr));
        InternetSearchButton->setText(tr2i18n("Search the Internet for (nothing)", nullptr));
        (void)FindDialog;
    } // retranslateUi

};

namespace Ui {
    class FindDialog: public Ui_FindDialog {};
} // namespace Ui

QT_END_NAMESPACE

#endif // FINDDIALOG_H

