/****************************************************************************
** Meta object code from reading C++ file 'scheduleradaptor.h'
**
** Created by: The Qt Meta Object Compiler version 69 (Qt 6.11.1)
**
** WARNING! All changes made in this file will be lost!
*****************************************************************************/

#include "scheduleradaptor.h"
#include <QtCore/qmetatype.h>

#include <QtCore/qtmochelpers.h>

#include <memory>


#include <QtCore/qxptype_traits.h>
#if !defined(Q_MOC_OUTPUT_REVISION)
#error "The header file 'scheduleradaptor.h' doesn't include <QObject>."
#elif Q_MOC_OUTPUT_REVISION != 69
#error "This file was generated using the moc from 6.11.1. It"
#error "cannot be used with the include files from this version of Qt."
#error "(The moc has changed too much.)"
#endif

#ifndef Q_CONSTINIT
#define Q_CONSTINIT
#endif

QT_WARNING_PUSH
QT_WARNING_DISABLE_DEPRECATED
QT_WARNING_DISABLE_GCC("-Wuseless-cast")
namespace {
struct qt_meta_tag_ZN16SchedulerAdaptorE_t {};
} // unnamed namespace

template <> constexpr inline auto SchedulerAdaptor::qt_create_metaobjectdata<qt_meta_tag_ZN16SchedulerAdaptorE_t>()
{
    namespace QMC = QtMocConstants;
    QtMocHelpers::StringRefStorage qt_stringData {
        "SchedulerAdaptor",
        "D-Bus Interface",
        "org.kde.kstars.Ekos.Scheduler",
        "D-Bus Introspection",
        "  <interface name=\"org.kde.kstars.Ekos.Scheduler\">\n    <propert"
        "y access=\"readwrite\" type=\"s\" name=\"profile\"/>\n    <propert"
        "y access=\"read\" type=\"s\" name=\"currentJobName\"/>\n    <prope"
        "rty access=\"read\" type=\"s\" name=\"currentJobJson\"/>\n    <pro"
        "perty access=\"read\" type=\"s\" name=\"jsonJobs\"/>\n    <propert"
        "y access=\"read\" type=\"as\" name=\"logText\"/>\n    <property ac"
        "cess=\"read\" type=\"i\" name=\"status\">\n      <annotation value"
        "=\"Ekos::SchedulerState\" name=\"org.qtproject.QtDBus.QtTypeName\""
        "/>\n    </property>\n    <method name=\"start\">\n      <annotatio"
        "n value=\"true\" name=\"org.freedesktop.DBus.Method.NoReply\"/>\n "
        "   </method>\n    <method name=\"stop\">\n      <annotation value="
        "\"true\" name=\"org.freedesktop.DBus.Method.NoReply\"/>\n    </met"
        "hod>\n    <method name=\"removeAllJobs\">\n      <annotation value"
        "=\"true\" name=\"org.freedesktop.DBus.Method.NoReply\"/>\n    </me"
        "thod>\n    <method name=\"loadScheduler\">\n      <arg direction=\""
        "in\" type=\"s\" name=\"fileURL\"/>\n      <arg direction=\"out\" t"
        "ype=\"b\"/>\n      <annotation value=\"QUrl\" name=\"org.qtproject"
        ".QtDBus.QtTypeName.In0\"/>\n    </method>\n    <method name=\"setS"
        "equence\">\n      <annotation value=\"true\" name=\"org.freedeskto"
        "p.DBus.Method.NoReply\"/>\n      <arg direction=\"in\" type=\"s\" "
        "name=\"sequenceFileURL\"/>\n      <annotation value=\"QUrl\" name="
        "\"org.qtproject.QtDBus.QtTypeName.In0\"/>\n    </method>\n    <met"
        "hod name=\"resetAllJobs\">\n      <annotation value=\"true\" name="
        "\"org.freedesktop.DBus.Method.NoReply\"/>\n    </method>\n    <sig"
        "nal name=\"newStatus\">\n      <arg direction=\"out\" type=\"(i)\""
        " name=\"status\"/>\n      <annotation value=\"Ekos::SchedulerState"
        "\" name=\"org.qtproject.QtDBus.QtTypeName.In0\"/>\n      <annotati"
        "on value=\"Ekos::SchedulerState\" name=\"org.qtproject.QtDBus.QtTy"
        "peName.Out0\"/>\n    </signal>\n    <signal name=\"newLog\">\n    "
        "  <arg direction=\"out\" type=\"s\" name=\"text\"/>\n    </signal>"
        "\n  </interface>\n",
        "newLog",
        "",
        "text",
        "newStatus",
        "Ekos::SchedulerState",
        "status",
        "loadScheduler",
        "fileURL",
        "removeAllJobs",
        "Q_NOREPLY",
        "resetAllJobs",
        "setSequence",
        "sequenceFileURL",
        "start",
        "stop",
        "currentJobJson",
        "currentJobName",
        "jsonJobs",
        "logText",
        "profile"
    };

    QtMocHelpers::UintData qt_methods {
        // Signal 'newLog'
        QtMocHelpers::SignalData<void(const QString &)>(5, 6, QMC::AccessPublic, QMetaType::Void, {{
            { QMetaType::QString, 7 },
        }}),
        // Signal 'newStatus'
        QtMocHelpers::SignalData<void(Ekos::SchedulerState)>(8, 6, QMC::AccessPublic, QMetaType::Void, {{
            { 0x80000000 | 9, 10 },
        }}),
        // Slot 'loadScheduler'
        QtMocHelpers::SlotData<bool(const QString &)>(11, 6, QMC::AccessPublic, QMetaType::Bool, {{
            { QMetaType::QString, 12 },
        }}),
        // Slot 'removeAllJobs'
        QtMocHelpers::SlotData<void()>(13, 14, QMC::AccessPublic, QMetaType::Void),
        // Slot 'resetAllJobs'
        QtMocHelpers::SlotData<void()>(15, 14, QMC::AccessPublic, QMetaType::Void),
        // Slot 'setSequence'
        QtMocHelpers::SlotData<void(const QString &)>(16, 14, QMC::AccessPublic, QMetaType::Void, {{
            { QMetaType::QString, 17 },
        }}),
        // Slot 'start'
        QtMocHelpers::SlotData<void()>(18, 14, QMC::AccessPublic, QMetaType::Void),
        // Slot 'stop'
        QtMocHelpers::SlotData<void()>(19, 14, QMC::AccessPublic, QMetaType::Void),
    };
    QtMocHelpers::UintData qt_properties {
        // property 'currentJobJson'
        QtMocHelpers::PropertyData<QString>(20, QMetaType::QString, QMC::DefaultPropertyFlags),
        // property 'currentJobName'
        QtMocHelpers::PropertyData<QString>(21, QMetaType::QString, QMC::DefaultPropertyFlags),
        // property 'jsonJobs'
        QtMocHelpers::PropertyData<QString>(22, QMetaType::QString, QMC::DefaultPropertyFlags),
        // property 'logText'
        QtMocHelpers::PropertyData<QStringList>(23, QMetaType::QStringList, QMC::DefaultPropertyFlags),
        // property 'profile'
        QtMocHelpers::PropertyData<QString>(24, QMetaType::QString, QMC::DefaultPropertyFlags | QMC::Writable | QMC::StdCppSet),
        // property 'status'
        QtMocHelpers::PropertyData<int>(10, QMetaType::Int, QMC::DefaultPropertyFlags),
    };
    QtMocHelpers::UintData qt_enums {
    };
    QtMocHelpers::UintData qt_constructors {};
    QtMocHelpers::ClassInfos qt_classinfo({
            {    1,    2 },
            {    3,    4 },
    });
    return QtMocHelpers::metaObjectData<SchedulerAdaptor, qt_meta_tag_ZN16SchedulerAdaptorE_t>(QMC::MetaObjectFlag{}, qt_stringData,
            qt_methods, qt_properties, qt_enums, qt_constructors, qt_classinfo);
}
Q_CONSTINIT const QMetaObject SchedulerAdaptor::staticMetaObject = { {
    QMetaObject::SuperData::link<QDBusAbstractAdaptor::staticMetaObject>(),
    qt_staticMetaObjectStaticContent<qt_meta_tag_ZN16SchedulerAdaptorE_t>.stringdata,
    qt_staticMetaObjectStaticContent<qt_meta_tag_ZN16SchedulerAdaptorE_t>.data,
    qt_static_metacall,
    nullptr,
    qt_staticMetaObjectRelocatingContent<qt_meta_tag_ZN16SchedulerAdaptorE_t>.metaTypes,
    nullptr
} };

void SchedulerAdaptor::qt_static_metacall(QObject *_o, QMetaObject::Call _c, int _id, void **_a)
{
    auto *_t = static_cast<SchedulerAdaptor *>(_o);
    if (_c == QMetaObject::InvokeMetaMethod) {
        switch (_id) {
        case 0: _t->newLog((*reinterpret_cast<std::add_pointer_t<QString>>(_a[1]))); break;
        case 1: _t->newStatus((*reinterpret_cast<std::add_pointer_t<Ekos::SchedulerState>>(_a[1]))); break;
        case 2: { bool _r = _t->loadScheduler((*reinterpret_cast<std::add_pointer_t<QString>>(_a[1])));
            if (_a[0]) *reinterpret_cast<bool*>(_a[0]) = std::move(_r); }  break;
        case 3: _t->removeAllJobs(); break;
        case 4: _t->resetAllJobs(); break;
        case 5: _t->setSequence((*reinterpret_cast<std::add_pointer_t<QString>>(_a[1]))); break;
        case 6: _t->start(); break;
        case 7: _t->stop(); break;
        default: ;
        }
    }
    if (_c == QMetaObject::RegisterMethodArgumentMetaType) {
        switch (_id) {
        default: *reinterpret_cast<QMetaType *>(_a[0]) = QMetaType(); break;
        case 1:
            switch (*reinterpret_cast<int*>(_a[1])) {
            default: *reinterpret_cast<QMetaType *>(_a[0]) = QMetaType(); break;
            case 0:
                *reinterpret_cast<QMetaType *>(_a[0]) = QMetaType::fromType< Ekos::SchedulerState >(); break;
            }
            break;
        }
    }
    if (_c == QMetaObject::IndexOfMethod) {
        if (QtMocHelpers::indexOfMethod<void (SchedulerAdaptor::*)(const QString & )>(_a, &SchedulerAdaptor::newLog, 0))
            return;
        if (QtMocHelpers::indexOfMethod<void (SchedulerAdaptor::*)(Ekos::SchedulerState )>(_a, &SchedulerAdaptor::newStatus, 1))
            return;
    }
    if (_c == QMetaObject::ReadProperty) {
        void *_v = _a[0];
        switch (_id) {
        case 0: *reinterpret_cast<QString*>(_v) = _t->currentJobJson(); break;
        case 1: *reinterpret_cast<QString*>(_v) = _t->currentJobName(); break;
        case 2: *reinterpret_cast<QString*>(_v) = _t->jsonJobs(); break;
        case 3: *reinterpret_cast<QStringList*>(_v) = _t->logText(); break;
        case 4: *reinterpret_cast<QString*>(_v) = _t->profile(); break;
        case 5: *reinterpret_cast<int*>(_v) = _t->status(); break;
        default: break;
        }
    }
    if (_c == QMetaObject::WriteProperty) {
        void *_v = _a[0];
        switch (_id) {
        case 4: _t->setProfile(*reinterpret_cast<QString*>(_v)); break;
        default: break;
        }
    }
}

const QMetaObject *SchedulerAdaptor::metaObject() const
{
    return QObject::d_ptr->metaObject ? QObject::d_ptr->dynamicMetaObject() : &staticMetaObject;
}

void *SchedulerAdaptor::qt_metacast(const char *_clname)
{
    if (!_clname) return nullptr;
    if (!strcmp(_clname, qt_staticMetaObjectStaticContent<qt_meta_tag_ZN16SchedulerAdaptorE_t>.strings))
        return static_cast<void*>(this);
    return QDBusAbstractAdaptor::qt_metacast(_clname);
}

int SchedulerAdaptor::qt_metacall(QMetaObject::Call _c, int _id, void **_a)
{
    _id = QDBusAbstractAdaptor::qt_metacall(_c, _id, _a);
    if (_id < 0)
        return _id;
    if (_c == QMetaObject::InvokeMetaMethod) {
        if (_id < 8)
            qt_static_metacall(this, _c, _id, _a);
        _id -= 8;
    }
    if (_c == QMetaObject::RegisterMethodArgumentMetaType) {
        if (_id < 8)
            qt_static_metacall(this, _c, _id, _a);
        _id -= 8;
    }
    if (_c == QMetaObject::ReadProperty || _c == QMetaObject::WriteProperty
            || _c == QMetaObject::ResetProperty || _c == QMetaObject::BindableProperty
            || _c == QMetaObject::RegisterPropertyMetaType) {
        qt_static_metacall(this, _c, _id, _a);
        _id -= 6;
    }
    return _id;
}

// SIGNAL 0
void SchedulerAdaptor::newLog(const QString & _t1)
{
    QMetaObject::activate<void>(this, &staticMetaObject, 0, nullptr, _t1);
}

// SIGNAL 1
void SchedulerAdaptor::newStatus(Ekos::SchedulerState _t1)
{
    QMetaObject::activate<void>(this, &staticMetaObject, 1, nullptr, _t1);
}
QT_WARNING_POP
