/****************************************************************************
** Meta object code from reading C++ file 'message.h'
**
** Created by: The Qt Meta Object Compiler version 69 (Qt 6.11.1)
**
** WARNING! All changes made in this file will be lost!
*****************************************************************************/

#include "../../../../kstars-3.8.4.1/kstars/ekos/ekoslive/message.h"
#include <QtNetwork/QSslError>
#include <QtDataVisualization/qbar3dseries.h>
#include <QtDataVisualization/q3dscene.h>
#include <QtGui/qtextcursor.h>
#include <QtCore/qmetatype.h>
#include <QtCore/QSharedPointer>

#include <QtCore/qtmochelpers.h>

#include <memory>


#include <QtCore/qxptype_traits.h>
#if !defined(Q_MOC_OUTPUT_REVISION)
#error "The header file 'message.h' doesn't include <QObject>."
#elif Q_MOC_OUTPUT_REVISION != 69
#error "This file was generated using the moc from 6.11.1. It"
#error "cannot be used with the include files from this version of Qt."
#error "(The moc has changed too much.)"
#endif

#ifndef Q_CONSTINIT
#define Q_CONSTINIT
#endif

QT_WARNING_PUSH
QT_WARNING_DISABLE_DEPRECATED
QT_WARNING_DISABLE_GCC("-Wuseless-cast")
namespace {
struct qt_meta_tag_ZN8EkosLive7MessageE_t {};
} // unnamed namespace

template <> constexpr inline auto EkosLive::Message::qt_create_metaobjectdata<qt_meta_tag_ZN8EkosLive7MessageE_t>()
{
    namespace QMC = QtMocConstants;
    QtMocHelpers::StringRefStorage qt_stringData {
        "EkosLive::Message",
        "connected",
        "",
        "disconnected",
        "globalLogoutTriggered",
        "QUrl",
        "url",
        "optionsUpdated",
        "resetPolarView",
        "liveStackingActiveChanged",
        "active",
        "sendConnection",
        "sendModuleState",
        "name",
        "setPendingPropertiesEnabled",
        "enabled",
        "setEkosStatingStatus",
        "Ekos::CommunicationStatus",
        "status",
        "setINDIStatus",
        "setAlignStatus",
        "Ekos::AlignState",
        "newState",
        "setAlignSolution",
        "QVariantMap",
        "solution",
        "sendAlignSettings",
        "settings",
        "sendGuideSettings",
        "sendFocusSettings",
        "sendMountSettings",
        "sendMountModelSettings",
        "sendDarkLibrarySettings",
        "sendSchedulerSettings",
        "setPAHStage",
        "Ekos::PolarAlignmentAssistant::Stage",
        "stage",
        "setPAHMessage",
        "message",
        "setPolarResults",
        "QLineF",
        "correctionVector",
        "polarError",
        "azError",
        "altError",
        "setUpdatedErrors",
        "total",
        "az",
        "alt",
        "setPAHEnabled",
        "setBoundingRect",
        "QRect",
        "rect",
        "QSize",
        "view",
        "currentZoom",
        "sendCaptureSequence",
        "QJsonArray",
        "sequenceArray",
        "sendPreviewLabel",
        "preview",
        "sendCaptureSettings",
        "autofocusAborted",
        "requestDSLRInfo",
        "cameraName",
        "requestPortSelection",
        "show",
        "requestOpticalTrains",
        "sendDialog",
        "QJsonObject",
        "processDialogResponse",
        "payload",
        "sendMosaicTiles",
        "tiles",
        "processNewProperty",
        "INDI::Property",
        "prop",
        "processDeleteProperty",
        "processUpdateProperty",
        "processMessage",
        "QSharedPointer<ISD::GenericDevice>",
        "device",
        "sendStellarSolverProfiles",
        "sendManualRotatorStatus",
        "currentPA",
        "targetPA",
        "threshold",
        "sendFilterOffsetProgress",
        "current",
        "sendFilterOffsetCalculated",
        "filter",
        "newOffset",
        "average",
        "sendAIGuideProgress",
        "sendAIGuideLog",
        "sendAIGuideComplete",
        "sendAIGuideTrainingProgress",
        "sendAIGuideTrainingComplete",
        "sendAIGuideTrainingError",
        "error",
        "onConnected",
        "onDisconnected",
        "onTextReceived"
    };

    QtMocHelpers::UintData qt_methods {
        // Signal 'connected'
        QtMocHelpers::SignalData<void()>(1, 2, QMC::AccessPublic, QMetaType::Void),
        // Signal 'disconnected'
        QtMocHelpers::SignalData<void()>(3, 2, QMC::AccessPublic, QMetaType::Void),
        // Signal 'globalLogoutTriggered'
        QtMocHelpers::SignalData<void(const QUrl &)>(4, 2, QMC::AccessPublic, QMetaType::Void, {{
            { 0x80000000 | 5, 6 },
        }}),
        // Signal 'optionsUpdated'
        QtMocHelpers::SignalData<void()>(7, 2, QMC::AccessPublic, QMetaType::Void),
        // Signal 'resetPolarView'
        QtMocHelpers::SignalData<void()>(8, 2, QMC::AccessPublic, QMetaType::Void),
        // Signal 'liveStackingActiveChanged'
        QtMocHelpers::SignalData<void(bool)>(9, 2, QMC::AccessPublic, QMetaType::Void, {{
            { QMetaType::Bool, 10 },
        }}),
        // Slot 'sendConnection'
        QtMocHelpers::SlotData<void()>(11, 2, QMC::AccessPublic, QMetaType::Void),
        // Slot 'sendModuleState'
        QtMocHelpers::SlotData<void(const QString &)>(12, 2, QMC::AccessPublic, QMetaType::Void, {{
            { QMetaType::QString, 13 },
        }}),
        // Slot 'setPendingPropertiesEnabled'
        QtMocHelpers::SlotData<void(bool)>(14, 2, QMC::AccessPublic, QMetaType::Void, {{
            { QMetaType::Bool, 15 },
        }}),
        // Slot 'setEkosStatingStatus'
        QtMocHelpers::SlotData<void(Ekos::CommunicationStatus)>(16, 2, QMC::AccessPublic, QMetaType::Void, {{
            { 0x80000000 | 17, 18 },
        }}),
        // Slot 'setINDIStatus'
        QtMocHelpers::SlotData<void(Ekos::CommunicationStatus)>(19, 2, QMC::AccessPublic, QMetaType::Void, {{
            { 0x80000000 | 17, 18 },
        }}),
        // Slot 'setAlignStatus'
        QtMocHelpers::SlotData<void(Ekos::AlignState)>(20, 2, QMC::AccessPublic, QMetaType::Void, {{
            { 0x80000000 | 21, 22 },
        }}),
        // Slot 'setAlignSolution'
        QtMocHelpers::SlotData<void(const QVariantMap &)>(23, 2, QMC::AccessPublic, QMetaType::Void, {{
            { 0x80000000 | 24, 25 },
        }}),
        // Slot 'sendAlignSettings'
        QtMocHelpers::SlotData<void(const QVariantMap &)>(26, 2, QMC::AccessPublic, QMetaType::Void, {{
            { 0x80000000 | 24, 27 },
        }}),
        // Slot 'sendGuideSettings'
        QtMocHelpers::SlotData<void(const QVariantMap &)>(28, 2, QMC::AccessPublic, QMetaType::Void, {{
            { 0x80000000 | 24, 27 },
        }}),
        // Slot 'sendFocusSettings'
        QtMocHelpers::SlotData<void(const QVariantMap &)>(29, 2, QMC::AccessPublic, QMetaType::Void, {{
            { 0x80000000 | 24, 27 },
        }}),
        // Slot 'sendMountSettings'
        QtMocHelpers::SlotData<void(const QVariantMap &)>(30, 2, QMC::AccessPublic, QMetaType::Void, {{
            { 0x80000000 | 24, 27 },
        }}),
        // Slot 'sendMountModelSettings'
        QtMocHelpers::SlotData<void(const QVariantMap &)>(31, 2, QMC::AccessPublic, QMetaType::Void, {{
            { 0x80000000 | 24, 27 },
        }}),
        // Slot 'sendDarkLibrarySettings'
        QtMocHelpers::SlotData<void(const QVariantMap &)>(32, 2, QMC::AccessPublic, QMetaType::Void, {{
            { 0x80000000 | 24, 27 },
        }}),
        // Slot 'sendSchedulerSettings'
        QtMocHelpers::SlotData<void(const QVariantMap &)>(33, 2, QMC::AccessPublic, QMetaType::Void, {{
            { 0x80000000 | 24, 27 },
        }}),
        // Slot 'setPAHStage'
        QtMocHelpers::SlotData<void(Ekos::PolarAlignmentAssistant::Stage)>(34, 2, QMC::AccessPublic, QMetaType::Void, {{
            { 0x80000000 | 35, 36 },
        }}),
        // Slot 'setPAHMessage'
        QtMocHelpers::SlotData<void(const QString &)>(37, 2, QMC::AccessPublic, QMetaType::Void, {{
            { QMetaType::QString, 38 },
        }}),
        // Slot 'setPolarResults'
        QtMocHelpers::SlotData<void(QLineF, double, double, double)>(39, 2, QMC::AccessPublic, QMetaType::Void, {{
            { 0x80000000 | 40, 41 }, { QMetaType::Double, 42 }, { QMetaType::Double, 43 }, { QMetaType::Double, 44 },
        }}),
        // Slot 'setUpdatedErrors'
        QtMocHelpers::SlotData<void(double, double, double)>(45, 2, QMC::AccessPublic, QMetaType::Void, {{
            { QMetaType::Double, 46 }, { QMetaType::Double, 47 }, { QMetaType::Double, 48 },
        }}),
        // Slot 'setPAHEnabled'
        QtMocHelpers::SlotData<void(bool)>(49, 2, QMC::AccessPublic, QMetaType::Void, {{
            { QMetaType::Bool, 15 },
        }}),
        // Slot 'setBoundingRect'
        QtMocHelpers::SlotData<void(QRect, QSize, double)>(50, 2, QMC::AccessPublic, QMetaType::Void, {{
            { 0x80000000 | 51, 52 }, { 0x80000000 | 53, 54 }, { QMetaType::Double, 55 },
        }}),
        // Slot 'sendCaptureSequence'
        QtMocHelpers::SlotData<void(const QJsonArray &)>(56, 2, QMC::AccessPublic, QMetaType::Void, {{
            { 0x80000000 | 57, 58 },
        }}),
        // Slot 'sendPreviewLabel'
        QtMocHelpers::SlotData<void(const QString &)>(59, 2, QMC::AccessPublic, QMetaType::Void, {{
            { QMetaType::QString, 60 },
        }}),
        // Slot 'sendCaptureSettings'
        QtMocHelpers::SlotData<void(const QVariantMap &)>(61, 2, QMC::AccessPublic, QMetaType::Void, {{
            { 0x80000000 | 24, 27 },
        }}),
        // Slot 'autofocusAborted'
        QtMocHelpers::SlotData<void()>(62, 2, QMC::AccessPublic, QMetaType::Void),
        // Slot 'requestDSLRInfo'
        QtMocHelpers::SlotData<void(const QString &)>(63, 2, QMC::AccessPublic, QMetaType::Void, {{
            { QMetaType::QString, 64 },
        }}),
        // Slot 'requestPortSelection'
        QtMocHelpers::SlotData<void(bool)>(65, 2, QMC::AccessPublic, QMetaType::Void, {{
            { QMetaType::Bool, 66 },
        }}),
        // Slot 'requestOpticalTrains'
        QtMocHelpers::SlotData<void(bool)>(67, 2, QMC::AccessPublic, QMetaType::Void, {{
            { QMetaType::Bool, 66 },
        }}),
        // Slot 'sendDialog'
        QtMocHelpers::SlotData<void(const QJsonObject &)>(68, 2, QMC::AccessPublic, QMetaType::Void, {{
            { 0x80000000 | 69, 38 },
        }}),
        // Slot 'processDialogResponse'
        QtMocHelpers::SlotData<void(const QJsonObject &)>(70, 2, QMC::AccessPublic, QMetaType::Void, {{
            { 0x80000000 | 69, 71 },
        }}),
        // Slot 'sendMosaicTiles'
        QtMocHelpers::SlotData<void(const QJsonObject &)>(72, 2, QMC::AccessPublic, QMetaType::Void, {{
            { 0x80000000 | 69, 73 },
        }}),
        // Slot 'processNewProperty'
        QtMocHelpers::SlotData<void(INDI::Property)>(74, 2, QMC::AccessPublic, QMetaType::Void, {{
            { 0x80000000 | 75, 76 },
        }}),
        // Slot 'processDeleteProperty'
        QtMocHelpers::SlotData<void(INDI::Property)>(77, 2, QMC::AccessPublic, QMetaType::Void, {{
            { 0x80000000 | 75, 76 },
        }}),
        // Slot 'processUpdateProperty'
        QtMocHelpers::SlotData<void(INDI::Property)>(78, 2, QMC::AccessPublic, QMetaType::Void, {{
            { 0x80000000 | 75, 76 },
        }}),
        // Slot 'processMessage'
        QtMocHelpers::SlotData<void(const QSharedPointer<ISD::GenericDevice> &, const QString &)>(79, 2, QMC::AccessPublic, QMetaType::Void, {{
            { 0x80000000 | 80, 81 }, { QMetaType::QString, 38 },
        }}),
        // Slot 'sendStellarSolverProfiles'
        QtMocHelpers::SlotData<void()>(82, 2, QMC::AccessPublic, QMetaType::Void),
        // Slot 'sendManualRotatorStatus'
        QtMocHelpers::SlotData<void(double, double, double)>(83, 2, QMC::AccessPublic, QMetaType::Void, {{
            { QMetaType::Double, 84 }, { QMetaType::Double, 85 }, { QMetaType::Double, 86 },
        }}),
        // Slot 'sendFilterOffsetProgress'
        QtMocHelpers::SlotData<void(int, int, const QString &)>(87, 2, QMC::AccessPublic, QMetaType::Void, {{
            { QMetaType::Int, 88 }, { QMetaType::Int, 46 }, { QMetaType::QString, 18 },
        }}),
        // Slot 'sendFilterOffsetCalculated'
        QtMocHelpers::SlotData<void(const QString &, int, int)>(89, 2, QMC::AccessPublic, QMetaType::Void, {{
            { QMetaType::QString, 90 }, { QMetaType::Int, 91 }, { QMetaType::Int, 92 },
        }}),
        // Slot 'sendAIGuideProgress'
        QtMocHelpers::SlotData<void(int, int, const QString &)>(93, 2, QMC::AccessPublic, QMetaType::Void, {{
            { QMetaType::Int, 88 }, { QMetaType::Int, 46 }, { QMetaType::QString, 18 },
        }}),
        // Slot 'sendAIGuideLog'
        QtMocHelpers::SlotData<void(const QString &)>(94, 2, QMC::AccessPublic, QMetaType::Void, {{
            { QMetaType::QString, 38 },
        }}),
        // Slot 'sendAIGuideComplete'
        QtMocHelpers::SlotData<void()>(95, 2, QMC::AccessPublic, QMetaType::Void),
        // Slot 'sendAIGuideTrainingProgress'
        QtMocHelpers::SlotData<void(const QString &)>(96, 2, QMC::AccessPublic, QMetaType::Void, {{
            { QMetaType::QString, 38 },
        }}),
        // Slot 'sendAIGuideTrainingComplete'
        QtMocHelpers::SlotData<void()>(97, 2, QMC::AccessPublic, QMetaType::Void),
        // Slot 'sendAIGuideTrainingError'
        QtMocHelpers::SlotData<void(const QString &)>(98, 2, QMC::AccessPublic, QMetaType::Void, {{
            { QMetaType::QString, 99 },
        }}),
        // Slot 'onConnected'
        QtMocHelpers::SlotData<void()>(100, 2, QMC::AccessPrivate, QMetaType::Void),
        // Slot 'onDisconnected'
        QtMocHelpers::SlotData<void()>(101, 2, QMC::AccessPrivate, QMetaType::Void),
        // Slot 'onTextReceived'
        QtMocHelpers::SlotData<void(const QString &)>(102, 2, QMC::AccessPrivate, QMetaType::Void, {{
            { QMetaType::QString, 2 },
        }}),
    };
    QtMocHelpers::UintData qt_properties {
    };
    QtMocHelpers::UintData qt_enums {
    };
    return QtMocHelpers::metaObjectData<Message, qt_meta_tag_ZN8EkosLive7MessageE_t>(QMC::MetaObjectFlag{}, qt_stringData,
            qt_methods, qt_properties, qt_enums);
}
Q_CONSTINIT const QMetaObject EkosLive::Message::staticMetaObject = { {
    QMetaObject::SuperData::link<QObject::staticMetaObject>(),
    qt_staticMetaObjectStaticContent<qt_meta_tag_ZN8EkosLive7MessageE_t>.stringdata,
    qt_staticMetaObjectStaticContent<qt_meta_tag_ZN8EkosLive7MessageE_t>.data,
    qt_static_metacall,
    nullptr,
    qt_staticMetaObjectRelocatingContent<qt_meta_tag_ZN8EkosLive7MessageE_t>.metaTypes,
    nullptr
} };

void EkosLive::Message::qt_static_metacall(QObject *_o, QMetaObject::Call _c, int _id, void **_a)
{
    auto *_t = static_cast<Message *>(_o);
    if (_c == QMetaObject::InvokeMetaMethod) {
        switch (_id) {
        case 0: _t->connected(); break;
        case 1: _t->disconnected(); break;
        case 2: _t->globalLogoutTriggered((*reinterpret_cast<std::add_pointer_t<QUrl>>(_a[1]))); break;
        case 3: _t->optionsUpdated(); break;
        case 4: _t->resetPolarView(); break;
        case 5: _t->liveStackingActiveChanged((*reinterpret_cast<std::add_pointer_t<bool>>(_a[1]))); break;
        case 6: _t->sendConnection(); break;
        case 7: _t->sendModuleState((*reinterpret_cast<std::add_pointer_t<QString>>(_a[1]))); break;
        case 8: _t->setPendingPropertiesEnabled((*reinterpret_cast<std::add_pointer_t<bool>>(_a[1]))); break;
        case 9: _t->setEkosStatingStatus((*reinterpret_cast<std::add_pointer_t<Ekos::CommunicationStatus>>(_a[1]))); break;
        case 10: _t->setINDIStatus((*reinterpret_cast<std::add_pointer_t<Ekos::CommunicationStatus>>(_a[1]))); break;
        case 11: _t->setAlignStatus((*reinterpret_cast<std::add_pointer_t<Ekos::AlignState>>(_a[1]))); break;
        case 12: _t->setAlignSolution((*reinterpret_cast<std::add_pointer_t<QVariantMap>>(_a[1]))); break;
        case 13: _t->sendAlignSettings((*reinterpret_cast<std::add_pointer_t<QVariantMap>>(_a[1]))); break;
        case 14: _t->sendGuideSettings((*reinterpret_cast<std::add_pointer_t<QVariantMap>>(_a[1]))); break;
        case 15: _t->sendFocusSettings((*reinterpret_cast<std::add_pointer_t<QVariantMap>>(_a[1]))); break;
        case 16: _t->sendMountSettings((*reinterpret_cast<std::add_pointer_t<QVariantMap>>(_a[1]))); break;
        case 17: _t->sendMountModelSettings((*reinterpret_cast<std::add_pointer_t<QVariantMap>>(_a[1]))); break;
        case 18: _t->sendDarkLibrarySettings((*reinterpret_cast<std::add_pointer_t<QVariantMap>>(_a[1]))); break;
        case 19: _t->sendSchedulerSettings((*reinterpret_cast<std::add_pointer_t<QVariantMap>>(_a[1]))); break;
        case 20: _t->setPAHStage((*reinterpret_cast<std::add_pointer_t<Ekos::PolarAlignmentAssistant::Stage>>(_a[1]))); break;
        case 21: _t->setPAHMessage((*reinterpret_cast<std::add_pointer_t<QString>>(_a[1]))); break;
        case 22: _t->setPolarResults((*reinterpret_cast<std::add_pointer_t<QLineF>>(_a[1])),(*reinterpret_cast<std::add_pointer_t<double>>(_a[2])),(*reinterpret_cast<std::add_pointer_t<double>>(_a[3])),(*reinterpret_cast<std::add_pointer_t<double>>(_a[4]))); break;
        case 23: _t->setUpdatedErrors((*reinterpret_cast<std::add_pointer_t<double>>(_a[1])),(*reinterpret_cast<std::add_pointer_t<double>>(_a[2])),(*reinterpret_cast<std::add_pointer_t<double>>(_a[3]))); break;
        case 24: _t->setPAHEnabled((*reinterpret_cast<std::add_pointer_t<bool>>(_a[1]))); break;
        case 25: _t->setBoundingRect((*reinterpret_cast<std::add_pointer_t<QRect>>(_a[1])),(*reinterpret_cast<std::add_pointer_t<QSize>>(_a[2])),(*reinterpret_cast<std::add_pointer_t<double>>(_a[3]))); break;
        case 26: _t->sendCaptureSequence((*reinterpret_cast<std::add_pointer_t<QJsonArray>>(_a[1]))); break;
        case 27: _t->sendPreviewLabel((*reinterpret_cast<std::add_pointer_t<QString>>(_a[1]))); break;
        case 28: _t->sendCaptureSettings((*reinterpret_cast<std::add_pointer_t<QVariantMap>>(_a[1]))); break;
        case 29: _t->autofocusAborted(); break;
        case 30: _t->requestDSLRInfo((*reinterpret_cast<std::add_pointer_t<QString>>(_a[1]))); break;
        case 31: _t->requestPortSelection((*reinterpret_cast<std::add_pointer_t<bool>>(_a[1]))); break;
        case 32: _t->requestOpticalTrains((*reinterpret_cast<std::add_pointer_t<bool>>(_a[1]))); break;
        case 33: _t->sendDialog((*reinterpret_cast<std::add_pointer_t<QJsonObject>>(_a[1]))); break;
        case 34: _t->processDialogResponse((*reinterpret_cast<std::add_pointer_t<QJsonObject>>(_a[1]))); break;
        case 35: _t->sendMosaicTiles((*reinterpret_cast<std::add_pointer_t<QJsonObject>>(_a[1]))); break;
        case 36: _t->processNewProperty((*reinterpret_cast<std::add_pointer_t<INDI::Property>>(_a[1]))); break;
        case 37: _t->processDeleteProperty((*reinterpret_cast<std::add_pointer_t<INDI::Property>>(_a[1]))); break;
        case 38: _t->processUpdateProperty((*reinterpret_cast<std::add_pointer_t<INDI::Property>>(_a[1]))); break;
        case 39: _t->processMessage((*reinterpret_cast<std::add_pointer_t<QSharedPointer<ISD::GenericDevice>>>(_a[1])),(*reinterpret_cast<std::add_pointer_t<QString>>(_a[2]))); break;
        case 40: _t->sendStellarSolverProfiles(); break;
        case 41: _t->sendManualRotatorStatus((*reinterpret_cast<std::add_pointer_t<double>>(_a[1])),(*reinterpret_cast<std::add_pointer_t<double>>(_a[2])),(*reinterpret_cast<std::add_pointer_t<double>>(_a[3]))); break;
        case 42: _t->sendFilterOffsetProgress((*reinterpret_cast<std::add_pointer_t<int>>(_a[1])),(*reinterpret_cast<std::add_pointer_t<int>>(_a[2])),(*reinterpret_cast<std::add_pointer_t<QString>>(_a[3]))); break;
        case 43: _t->sendFilterOffsetCalculated((*reinterpret_cast<std::add_pointer_t<QString>>(_a[1])),(*reinterpret_cast<std::add_pointer_t<int>>(_a[2])),(*reinterpret_cast<std::add_pointer_t<int>>(_a[3]))); break;
        case 44: _t->sendAIGuideProgress((*reinterpret_cast<std::add_pointer_t<int>>(_a[1])),(*reinterpret_cast<std::add_pointer_t<int>>(_a[2])),(*reinterpret_cast<std::add_pointer_t<QString>>(_a[3]))); break;
        case 45: _t->sendAIGuideLog((*reinterpret_cast<std::add_pointer_t<QString>>(_a[1]))); break;
        case 46: _t->sendAIGuideComplete(); break;
        case 47: _t->sendAIGuideTrainingProgress((*reinterpret_cast<std::add_pointer_t<QString>>(_a[1]))); break;
        case 48: _t->sendAIGuideTrainingComplete(); break;
        case 49: _t->sendAIGuideTrainingError((*reinterpret_cast<std::add_pointer_t<QString>>(_a[1]))); break;
        case 50: _t->onConnected(); break;
        case 51: _t->onDisconnected(); break;
        case 52: _t->onTextReceived((*reinterpret_cast<std::add_pointer_t<QString>>(_a[1]))); break;
        default: ;
        }
    }
    if (_c == QMetaObject::RegisterMethodArgumentMetaType) {
        switch (_id) {
        default: *reinterpret_cast<QMetaType *>(_a[0]) = QMetaType(); break;
        case 9:
            switch (*reinterpret_cast<int*>(_a[1])) {
            default: *reinterpret_cast<QMetaType *>(_a[0]) = QMetaType(); break;
            case 0:
                *reinterpret_cast<QMetaType *>(_a[0]) = QMetaType::fromType< Ekos::CommunicationStatus >(); break;
            }
            break;
        case 10:
            switch (*reinterpret_cast<int*>(_a[1])) {
            default: *reinterpret_cast<QMetaType *>(_a[0]) = QMetaType(); break;
            case 0:
                *reinterpret_cast<QMetaType *>(_a[0]) = QMetaType::fromType< Ekos::CommunicationStatus >(); break;
            }
            break;
        case 11:
            switch (*reinterpret_cast<int*>(_a[1])) {
            default: *reinterpret_cast<QMetaType *>(_a[0]) = QMetaType(); break;
            case 0:
                *reinterpret_cast<QMetaType *>(_a[0]) = QMetaType::fromType< Ekos::AlignState >(); break;
            }
            break;
        case 36:
            switch (*reinterpret_cast<int*>(_a[1])) {
            default: *reinterpret_cast<QMetaType *>(_a[0]) = QMetaType(); break;
            case 0:
                *reinterpret_cast<QMetaType *>(_a[0]) = QMetaType::fromType< INDI::Property >(); break;
            }
            break;
        case 37:
            switch (*reinterpret_cast<int*>(_a[1])) {
            default: *reinterpret_cast<QMetaType *>(_a[0]) = QMetaType(); break;
            case 0:
                *reinterpret_cast<QMetaType *>(_a[0]) = QMetaType::fromType< INDI::Property >(); break;
            }
            break;
        case 38:
            switch (*reinterpret_cast<int*>(_a[1])) {
            default: *reinterpret_cast<QMetaType *>(_a[0]) = QMetaType(); break;
            case 0:
                *reinterpret_cast<QMetaType *>(_a[0]) = QMetaType::fromType< INDI::Property >(); break;
            }
            break;
        case 39:
            switch (*reinterpret_cast<int*>(_a[1])) {
            default: *reinterpret_cast<QMetaType *>(_a[0]) = QMetaType(); break;
            case 0:
                *reinterpret_cast<QMetaType *>(_a[0]) = QMetaType::fromType< QSharedPointer<ISD::GenericDevice> >(); break;
            }
            break;
        }
    }
    if (_c == QMetaObject::IndexOfMethod) {
        if (QtMocHelpers::indexOfMethod<void (Message::*)()>(_a, &Message::connected, 0))
            return;
        if (QtMocHelpers::indexOfMethod<void (Message::*)()>(_a, &Message::disconnected, 1))
            return;
        if (QtMocHelpers::indexOfMethod<void (Message::*)(const QUrl & )>(_a, &Message::globalLogoutTriggered, 2))
            return;
        if (QtMocHelpers::indexOfMethod<void (Message::*)()>(_a, &Message::optionsUpdated, 3))
            return;
        if (QtMocHelpers::indexOfMethod<void (Message::*)()>(_a, &Message::resetPolarView, 4))
            return;
        if (QtMocHelpers::indexOfMethod<void (Message::*)(bool )>(_a, &Message::liveStackingActiveChanged, 5))
            return;
    }
}

const QMetaObject *EkosLive::Message::metaObject() const
{
    return QObject::d_ptr->metaObject ? QObject::d_ptr->dynamicMetaObject() : &staticMetaObject;
}

void *EkosLive::Message::qt_metacast(const char *_clname)
{
    if (!_clname) return nullptr;
    if (!strcmp(_clname, qt_staticMetaObjectStaticContent<qt_meta_tag_ZN8EkosLive7MessageE_t>.strings))
        return static_cast<void*>(this);
    return QObject::qt_metacast(_clname);
}

int EkosLive::Message::qt_metacall(QMetaObject::Call _c, int _id, void **_a)
{
    _id = QObject::qt_metacall(_c, _id, _a);
    if (_id < 0)
        return _id;
    if (_c == QMetaObject::InvokeMetaMethod) {
        if (_id < 53)
            qt_static_metacall(this, _c, _id, _a);
        _id -= 53;
    }
    if (_c == QMetaObject::RegisterMethodArgumentMetaType) {
        if (_id < 53)
            qt_static_metacall(this, _c, _id, _a);
        _id -= 53;
    }
    return _id;
}

// SIGNAL 0
void EkosLive::Message::connected()
{
    QMetaObject::activate(this, &staticMetaObject, 0, nullptr);
}

// SIGNAL 1
void EkosLive::Message::disconnected()
{
    QMetaObject::activate(this, &staticMetaObject, 1, nullptr);
}

// SIGNAL 2
void EkosLive::Message::globalLogoutTriggered(const QUrl & _t1)
{
    QMetaObject::activate<void>(this, &staticMetaObject, 2, nullptr, _t1);
}

// SIGNAL 3
void EkosLive::Message::optionsUpdated()
{
    QMetaObject::activate(this, &staticMetaObject, 3, nullptr);
}

// SIGNAL 4
void EkosLive::Message::resetPolarView()
{
    QMetaObject::activate(this, &staticMetaObject, 4, nullptr);
}

// SIGNAL 5
void EkosLive::Message::liveStackingActiveChanged(bool _t1)
{
    QMetaObject::activate<void>(this, &staticMetaObject, 5, nullptr, _t1);
}
QT_WARNING_POP
