/********************************************************************************
** Form generated from reading UI file 'wizlocation.ui'
**
** Created by: Qt User Interface Compiler version 6.11.1
**
** WARNING! All changes made in this file will be lost when recompiling UI file!
********************************************************************************/

#ifndef UI_WIZLOCATION_H
#define UI_WIZLOCATION_H

#include <QtCore/QVariant>
#include <QtWidgets/QApplication>
#include <QtWidgets/QGridLayout>
#include <QtWidgets/QHBoxLayout>
#include <QtWidgets/QLabel>
#include <QtWidgets/QLineEdit>
#include <QtWidgets/QListWidget>
#include <QtWidgets/QSpacerItem>
#include <QtWidgets/QVBoxLayout>
#include <QtWidgets/QWidget>
#include <klocalizedstring.h>
#include "widgets/dmsbox.h"

QT_BEGIN_NAMESPACE

class Ui_WizLocation
{
public:
    QHBoxLayout *hboxLayout;
    QLabel *Banner;
    QVBoxLayout *vboxLayout;
    QLabel *GeoTitle;
    QSpacerItem *spacerItem;
    QLabel *WelcomeText;
    QSpacerItem *spacerItem1;
    QGridLayout *gridLayout;
    QLabel *CountryLabel;
    QLineEdit *CityFilter;
    QLabel *CityLabel;
    QLabel *ProvinceLabel;
    QLineEdit *CountryFilter;
    QLineEdit *ProvinceFilter;
    QSpacerItem *spacerItem2;
    QGridLayout *gridLayout1;
    dmsBox *LongBox;
    QLabel *LatLabel;
    QLabel *LongLabel;
    dmsBox *LatBox;
    QSpacerItem *spacerItem3;
    QListWidget *CityListBox;

    void setupUi(QWidget *WizLocation)
    {
        if (WizLocation->objectName().isEmpty())
            WizLocation->setObjectName("WizLocation");
        WizLocation->resize(703, 383);
        hboxLayout = new QHBoxLayout(WizLocation);
#ifndef UI_Q_OS_MAC
        hboxLayout->setSpacing(6);
#endif
        hboxLayout->setContentsMargins(8, 8, 8, 8);
        hboxLayout->setObjectName("hboxLayout");
        Banner = new QLabel(WizLocation);
        Banner->setObjectName("Banner");
        QSizePolicy sizePolicy(QSizePolicy::Policy::Fixed, QSizePolicy::Policy::Fixed);
        sizePolicy.setHorizontalStretch(0);
        sizePolicy.setVerticalStretch(0);
        sizePolicy.setHeightForWidth(Banner->sizePolicy().hasHeightForWidth());
        Banner->setSizePolicy(sizePolicy);
        Banner->setMinimumSize(QSize(120, 360));

        hboxLayout->addWidget(Banner);

        vboxLayout = new QVBoxLayout();
#ifndef UI_Q_OS_MAC
        vboxLayout->setSpacing(6);
#endif
        vboxLayout->setContentsMargins(0, 0, 0, 0);
        vboxLayout->setObjectName("vboxLayout");
        GeoTitle = new QLabel(WizLocation);
        GeoTitle->setObjectName("GeoTitle");
        QFont font;
        font.setFamilies({QString::fromUtf8("Sans Serif")});
        font.setPointSize(11);
        font.setBold(true);
        font.setItalic(false);
        font.setUnderline(false);
        font.setStrikeOut(false);
        GeoTitle->setFont(font);

        vboxLayout->addWidget(GeoTitle);

        spacerItem = new QSpacerItem(20, 12, QSizePolicy::Policy::Minimum, QSizePolicy::Policy::Fixed);

        vboxLayout->addItem(spacerItem);

        WelcomeText = new QLabel(WizLocation);
        WelcomeText->setObjectName("WelcomeText");
        WelcomeText->setWordWrap(true);

        vboxLayout->addWidget(WelcomeText);

        spacerItem1 = new QSpacerItem(20, 16, QSizePolicy::Policy::Minimum, QSizePolicy::Policy::Expanding);

        vboxLayout->addItem(spacerItem1);

        gridLayout = new QGridLayout();
#ifndef UI_Q_OS_MAC
        gridLayout->setSpacing(6);
#endif
        gridLayout->setContentsMargins(0, 0, 0, 0);
        gridLayout->setObjectName("gridLayout");
        CountryLabel = new QLabel(WizLocation);
        CountryLabel->setObjectName("CountryLabel");

        gridLayout->addWidget(CountryLabel, 2, 0, 1, 1);

        CityFilter = new QLineEdit(WizLocation);
        CityFilter->setObjectName("CityFilter");

        gridLayout->addWidget(CityFilter, 0, 1, 1, 1);

        CityLabel = new QLabel(WizLocation);
        CityLabel->setObjectName("CityLabel");

        gridLayout->addWidget(CityLabel, 0, 0, 1, 1);

        ProvinceLabel = new QLabel(WizLocation);
        ProvinceLabel->setObjectName("ProvinceLabel");

        gridLayout->addWidget(ProvinceLabel, 1, 0, 1, 1);

        CountryFilter = new QLineEdit(WizLocation);
        CountryFilter->setObjectName("CountryFilter");

        gridLayout->addWidget(CountryFilter, 2, 1, 1, 1);

        ProvinceFilter = new QLineEdit(WizLocation);
        ProvinceFilter->setObjectName("ProvinceFilter");

        gridLayout->addWidget(ProvinceFilter, 1, 1, 1, 1);


        vboxLayout->addLayout(gridLayout);

        spacerItem2 = new QSpacerItem(20, 16, QSizePolicy::Policy::Minimum, QSizePolicy::Policy::Expanding);

        vboxLayout->addItem(spacerItem2);

        gridLayout1 = new QGridLayout();
#ifndef UI_Q_OS_MAC
        gridLayout1->setSpacing(6);
#endif
        gridLayout1->setContentsMargins(0, 0, 0, 0);
        gridLayout1->setObjectName("gridLayout1");
        LongBox = new dmsBox(WizLocation);
        LongBox->setObjectName("LongBox");

        gridLayout1->addWidget(LongBox, 0, 1, 1, 1);

        LatLabel = new QLabel(WizLocation);
        LatLabel->setObjectName("LatLabel");

        gridLayout1->addWidget(LatLabel, 1, 0, 1, 1);

        LongLabel = new QLabel(WizLocation);
        LongLabel->setObjectName("LongLabel");

        gridLayout1->addWidget(LongLabel, 0, 0, 1, 1);

        LatBox = new dmsBox(WizLocation);
        LatBox->setObjectName("LatBox");

        gridLayout1->addWidget(LatBox, 1, 1, 1, 1);


        vboxLayout->addLayout(gridLayout1);

        spacerItem3 = new QSpacerItem(20, 16, QSizePolicy::Policy::Minimum, QSizePolicy::Policy::Expanding);

        vboxLayout->addItem(spacerItem3);


        hboxLayout->addLayout(vboxLayout);

        CityListBox = new QListWidget(WizLocation);
        CityListBox->setObjectName("CityListBox");
        CityListBox->setMinimumSize(QSize(180, 0));

        hboxLayout->addWidget(CityListBox);

        QWidget::setTabOrder(CityFilter, ProvinceFilter);
        QWidget::setTabOrder(ProvinceFilter, CountryFilter);
        QWidget::setTabOrder(CountryFilter, LongBox);
        QWidget::setTabOrder(LongBox, LatBox);

        retranslateUi(WizLocation);

        QMetaObject::connectSlotsByName(WizLocation);
    } // setupUi

    void retranslateUi(QWidget *WizLocation)
    {
        Banner->setText(QString());
        GeoTitle->setText(tr2i18n("Choose Your Home Location", nullptr));
        WelcomeText->setText(tr2i18n("<p>Select a City near your location from the list. You may filter the list by the name of your city, province, and country.</p><p>Once you have selected a City, press <b>Next</b>.</p>", nullptr));
        CountryLabel->setText(tr2i18n("Country:", nullptr));
#if QT_CONFIG(tooltip)
        CityFilter->setToolTip(tr2i18n("Filter the list by city name", nullptr));
#endif // QT_CONFIG(tooltip)
        CityLabel->setText(tr2i18n("City:", nullptr));
        ProvinceLabel->setText(tr2i18n("Province:", nullptr));
#if QT_CONFIG(tooltip)
        CountryFilter->setToolTip(tr2i18n("Filter the list by country name", nullptr));
#endif // QT_CONFIG(tooltip)
#if QT_CONFIG(tooltip)
        ProvinceFilter->setToolTip(tr2i18n("Filter the list by province name", nullptr));
#endif // QT_CONFIG(tooltip)
        LatLabel->setText(tr2i18n("Latitude:", nullptr));
        LongLabel->setText(tr2i18n("Longitude:", nullptr));
#if QT_CONFIG(tooltip)
        CityListBox->setToolTip(tr2i18n("The list of cities which match the present search filters.", nullptr));
#endif // QT_CONFIG(tooltip)
        (void)WizLocation;
    } // retranslateUi

};

namespace Ui {
    class WizLocation: public Ui_WizLocation {};
} // namespace Ui

QT_END_NAMESPACE

#endif // WIZLOCATION_H

