/********************************************************************************
** Form generated from reading UI file 'opscalibration.ui'
**
** Created by: Qt User Interface Compiler version 6.11.1
**
** WARNING! All changes made in this file will be lost when recompiling UI file!
********************************************************************************/

#ifndef UI_OPSCALIBRATION_H
#define UI_OPSCALIBRATION_H

#include <QtCore/QVariant>
#include <QtWidgets/QApplication>
#include <QtWidgets/QCheckBox>
#include <QtWidgets/QDoubleSpinBox>
#include <QtWidgets/QFormLayout>
#include <QtWidgets/QGridLayout>
#include <QtWidgets/QGroupBox>
#include <QtWidgets/QHBoxLayout>
#include <QtWidgets/QLabel>
#include <QtWidgets/QSpacerItem>
#include <QtWidgets/QSpinBox>
#include <QtWidgets/QVBoxLayout>
#include <QtWidgets/QWidget>
#include <klocalizedstring.h>

QT_BEGIN_NAMESPACE

class Ui_OpsCalibration
{
public:
    QVBoxLayout *verticalLayout_2;
    QHBoxLayout *horizontalLayout;
    QGroupBox *groupBox_2;
    QVBoxLayout *verticalLayout;
    QGridLayout *gridLayout;
    QLabel *l_29;
    QSpinBox *kcfg_AutoModeIterations;
    QSpinBox *kcfg_CalibrationPulseDuration;
    QLabel *label;
    QLabel *label1;
    QSpinBox *kcfg_CalibrationMaxMove;
    QCheckBox *kcfg_TwoAxisEnabled;
    QCheckBox *kcfg_GuideAutoSquareSizeEnabled;
    QGroupBox *groupBox;
    QFormLayout *formLayout_2;
    QLabel *l_26;
    QDoubleSpinBox *spinBox_ReticleX;
    QLabel *l_27;
    QDoubleSpinBox *spinBox_ReticleY;
    QGridLayout *gridLayout_2;
    QGroupBox *groupBox_3;
    QLabel *racal;
    QLabel *ra_cal_degrees;
    QLabel *label_4;
    QLabel *ra_cal_mspp;
    QLabel *label_6;
    QLabel *label_7;
    QLabel *dec_cal_degrees;
    QLabel *dec_cal_degrees_unit;
    QLabel *dec_cal_mspp;
    QLabel *label_11;
    QCheckBox *kcfg_GuideCalibrationBacklash;
    QCheckBox *kcfg_AssumeDecOrthogonal;
    QCheckBox *kcfg_ResetGuideCalibration;
    QCheckBox *kcfg_ReuseGuideCalibration;
    QCheckBox *kcfg_ReverseDecOnPierSideChange;
    QSpacerItem *verticalSpacer_2;

    void setupUi(QWidget *OpsCalibration)
    {
        if (OpsCalibration->objectName().isEmpty())
            OpsCalibration->setObjectName("OpsCalibration");
        OpsCalibration->resize(427, 383);
        verticalLayout_2 = new QVBoxLayout(OpsCalibration);
        verticalLayout_2->setSpacing(3);
        verticalLayout_2->setObjectName("verticalLayout_2");
        verticalLayout_2->setContentsMargins(3, 3, 3, 3);
        horizontalLayout = new QHBoxLayout();
        horizontalLayout->setObjectName("horizontalLayout");
        groupBox_2 = new QGroupBox(OpsCalibration);
        groupBox_2->setObjectName("groupBox_2");
        verticalLayout = new QVBoxLayout(groupBox_2);
        verticalLayout->setSpacing(3);
        verticalLayout->setObjectName("verticalLayout");
        verticalLayout->setContentsMargins(5, 5, 5, 5);
        gridLayout = new QGridLayout();
        gridLayout->setObjectName("gridLayout");
        l_29 = new QLabel(groupBox_2);
        l_29->setObjectName("l_29");

        gridLayout->addWidget(l_29, 0, 1, 1, 1);

        kcfg_AutoModeIterations = new QSpinBox(groupBox_2);
        kcfg_AutoModeIterations->setObjectName("kcfg_AutoModeIterations");
        kcfg_AutoModeIterations->setMinimum(3);
        kcfg_AutoModeIterations->setMaximum(10);
        kcfg_AutoModeIterations->setValue(5);

        gridLayout->addWidget(kcfg_AutoModeIterations, 1, 2, 1, 1);

        kcfg_CalibrationPulseDuration = new QSpinBox(groupBox_2);
        kcfg_CalibrationPulseDuration->setObjectName("kcfg_CalibrationPulseDuration");
        kcfg_CalibrationPulseDuration->setMinimum(100);
        kcfg_CalibrationPulseDuration->setMaximum(5000);
        kcfg_CalibrationPulseDuration->setSingleStep(100);
        kcfg_CalibrationPulseDuration->setValue(1000);

        gridLayout->addWidget(kcfg_CalibrationPulseDuration, 0, 2, 1, 1);

        label = new QLabel(groupBox_2);
        label->setObjectName("label");

        gridLayout->addWidget(label, 1, 1, 1, 1);

        label1 = new QLabel(groupBox_2);
        label1->setObjectName("label1");

        gridLayout->addWidget(label1, 2, 1, 1, 1);

        kcfg_CalibrationMaxMove = new QSpinBox(groupBox_2);
        kcfg_CalibrationMaxMove->setObjectName("kcfg_CalibrationMaxMove");
        kcfg_CalibrationMaxMove->setMinimum(5);
        kcfg_CalibrationMaxMove->setMaximum(100);
        kcfg_CalibrationMaxMove->setSingleStep(1);
        kcfg_CalibrationMaxMove->setValue(15);

        gridLayout->addWidget(kcfg_CalibrationMaxMove, 2, 2, 1, 1);


        verticalLayout->addLayout(gridLayout);

        kcfg_TwoAxisEnabled = new QCheckBox(groupBox_2);
        kcfg_TwoAxisEnabled->setObjectName("kcfg_TwoAxisEnabled");
        kcfg_TwoAxisEnabled->setChecked(true);

        verticalLayout->addWidget(kcfg_TwoAxisEnabled);

        kcfg_GuideAutoSquareSizeEnabled = new QCheckBox(groupBox_2);
        kcfg_GuideAutoSquareSizeEnabled->setObjectName("kcfg_GuideAutoSquareSizeEnabled");
        kcfg_GuideAutoSquareSizeEnabled->setEnabled(false);

        verticalLayout->addWidget(kcfg_GuideAutoSquareSizeEnabled);


        horizontalLayout->addWidget(groupBox_2);

        groupBox = new QGroupBox(OpsCalibration);
        groupBox->setObjectName("groupBox");
        formLayout_2 = new QFormLayout(groupBox);
        formLayout_2->setObjectName("formLayout_2");
        l_26 = new QLabel(groupBox);
        l_26->setObjectName("l_26");

        formLayout_2->setWidget(0, QFormLayout::ItemRole::LabelRole, l_26);

        spinBox_ReticleX = new QDoubleSpinBox(groupBox);
        spinBox_ReticleX->setObjectName("spinBox_ReticleX");
        spinBox_ReticleX->setMaximum(5000.000000000000000);

        formLayout_2->setWidget(0, QFormLayout::ItemRole::FieldRole, spinBox_ReticleX);

        l_27 = new QLabel(groupBox);
        l_27->setObjectName("l_27");

        formLayout_2->setWidget(1, QFormLayout::ItemRole::LabelRole, l_27);

        spinBox_ReticleY = new QDoubleSpinBox(groupBox);
        spinBox_ReticleY->setObjectName("spinBox_ReticleY");
        spinBox_ReticleY->setMaximum(5000.000000000000000);

        formLayout_2->setWidget(1, QFormLayout::ItemRole::FieldRole, spinBox_ReticleY);


        horizontalLayout->addWidget(groupBox);


        verticalLayout_2->addLayout(horizontalLayout);

        gridLayout_2 = new QGridLayout();
        gridLayout_2->setObjectName("gridLayout_2");

        verticalLayout_2->addLayout(gridLayout_2);

        groupBox_3 = new QGroupBox(OpsCalibration);
        groupBox_3->setObjectName("groupBox_3");
        groupBox_3->setMinimumSize(QSize(0, 80));
        racal = new QLabel(groupBox_3);
        racal->setObjectName("racal");
        racal->setGeometry(QRect(10, 30, 67, 17));
        ra_cal_degrees = new QLabel(groupBox_3);
        ra_cal_degrees->setObjectName("ra_cal_degrees");
        ra_cal_degrees->setGeometry(QRect(90, 30, 67, 17));
        label_4 = new QLabel(groupBox_3);
        label_4->setObjectName("label_4");
        label_4->setGeometry(QRect(130, 30, 67, 17));
        ra_cal_mspp = new QLabel(groupBox_3);
        ra_cal_mspp->setObjectName("ra_cal_mspp");
        ra_cal_mspp->setGeometry(QRect(280, 30, 51, 17));
        label_6 = new QLabel(groupBox_3);
        label_6->setObjectName("label_6");
        label_6->setGeometry(QRect(330, 30, 67, 17));
        label_7 = new QLabel(groupBox_3);
        label_7->setObjectName("label_7");
        label_7->setGeometry(QRect(10, 50, 67, 17));
        dec_cal_degrees = new QLabel(groupBox_3);
        dec_cal_degrees->setObjectName("dec_cal_degrees");
        dec_cal_degrees->setGeometry(QRect(90, 50, 67, 17));
        dec_cal_degrees_unit = new QLabel(groupBox_3);
        dec_cal_degrees_unit->setObjectName("dec_cal_degrees_unit");
        dec_cal_degrees_unit->setGeometry(QRect(130, 50, 141, 17));
        dec_cal_degrees_unit->setMaximumSize(QSize(16777215, 16777215));
        dec_cal_mspp = new QLabel(groupBox_3);
        dec_cal_mspp->setObjectName("dec_cal_mspp");
        dec_cal_mspp->setGeometry(QRect(280, 50, 51, 17));
        label_11 = new QLabel(groupBox_3);
        label_11->setObjectName("label_11");
        label_11->setGeometry(QRect(330, 50, 67, 17));

        verticalLayout_2->addWidget(groupBox_3);

        kcfg_GuideCalibrationBacklash = new QCheckBox(OpsCalibration);
        kcfg_GuideCalibrationBacklash->setObjectName("kcfg_GuideCalibrationBacklash");

        verticalLayout_2->addWidget(kcfg_GuideCalibrationBacklash);

        kcfg_AssumeDecOrthogonal = new QCheckBox(OpsCalibration);
        kcfg_AssumeDecOrthogonal->setObjectName("kcfg_AssumeDecOrthogonal");

        verticalLayout_2->addWidget(kcfg_AssumeDecOrthogonal);

        kcfg_ResetGuideCalibration = new QCheckBox(OpsCalibration);
        kcfg_ResetGuideCalibration->setObjectName("kcfg_ResetGuideCalibration");

        verticalLayout_2->addWidget(kcfg_ResetGuideCalibration);

        kcfg_ReuseGuideCalibration = new QCheckBox(OpsCalibration);
        kcfg_ReuseGuideCalibration->setObjectName("kcfg_ReuseGuideCalibration");

        verticalLayout_2->addWidget(kcfg_ReuseGuideCalibration);

        kcfg_ReverseDecOnPierSideChange = new QCheckBox(OpsCalibration);
        kcfg_ReverseDecOnPierSideChange->setObjectName("kcfg_ReverseDecOnPierSideChange");

        verticalLayout_2->addWidget(kcfg_ReverseDecOnPierSideChange);

        verticalSpacer_2 = new QSpacerItem(20, 40, QSizePolicy::Policy::Minimum, QSizePolicy::Policy::Expanding);

        verticalLayout_2->addItem(verticalSpacer_2);

        QWidget::setTabOrder(kcfg_CalibrationPulseDuration, kcfg_AutoModeIterations);
        QWidget::setTabOrder(kcfg_AutoModeIterations, kcfg_CalibrationMaxMove);
        QWidget::setTabOrder(kcfg_CalibrationMaxMove, kcfg_TwoAxisEnabled);
        QWidget::setTabOrder(kcfg_TwoAxisEnabled, kcfg_GuideAutoSquareSizeEnabled);
        QWidget::setTabOrder(kcfg_GuideAutoSquareSizeEnabled, kcfg_GuideCalibrationBacklash);
        QWidget::setTabOrder(kcfg_GuideCalibrationBacklash, kcfg_AssumeDecOrthogonal);
        QWidget::setTabOrder(kcfg_AssumeDecOrthogonal, kcfg_ResetGuideCalibration);
        QWidget::setTabOrder(kcfg_ResetGuideCalibration, kcfg_ReuseGuideCalibration);
        QWidget::setTabOrder(kcfg_ReuseGuideCalibration, kcfg_ReverseDecOnPierSideChange);
        QWidget::setTabOrder(kcfg_ReverseDecOnPierSideChange, spinBox_ReticleX);
        QWidget::setTabOrder(spinBox_ReticleX, spinBox_ReticleY);

        retranslateUi(OpsCalibration);

        QMetaObject::connectSlotsByName(OpsCalibration);
    } // setupUi

    void retranslateUi(QWidget *OpsCalibration)
    {
        groupBox_2->setTitle(tr2i18n("Settings", nullptr));
#if QT_CONFIG(tooltip)
        l_29->setToolTip(tr2i18n("Initial pulse size for calibration.", nullptr));
#endif // QT_CONFIG(tooltip)
        l_29->setText(tr2i18n("Pulse:", nullptr));
#if QT_CONFIG(tooltip)
        kcfg_AutoModeIterations->setToolTip(tr2i18n("Maximum number of iterations calibration should use per phase.", nullptr));
#endif // QT_CONFIG(tooltip)
#if QT_CONFIG(tooltip)
        kcfg_CalibrationPulseDuration->setToolTip(tr2i18n("Initial pulse size for calibration.", nullptr));
#endif // QT_CONFIG(tooltip)
#if QT_CONFIG(tooltip)
        label->setToolTip(tr2i18n("Maximum number of iterations calibration should use per phase. It may use fewer (if max move is reached).", nullptr));
#endif // QT_CONFIG(tooltip)
        label->setText(tr2i18n("Max Iterations:", nullptr));
#if QT_CONFIG(tooltip)
        label1->setToolTip(tr2i18n("Maximum number of pixels the calibration should move. Once it exceeds this amount, it will finish the calibration phase.  It may move less if  max iterations is reached.", nullptr));
#endif // QT_CONFIG(tooltip)
        label1->setText(tr2i18n("Max move (px):", nullptr));
#if QT_CONFIG(tooltip)
        kcfg_CalibrationMaxMove->setToolTip(tr2i18n("Maximum number of pixels the calibration should move (approximate).", nullptr));
#endif // QT_CONFIG(tooltip)
        kcfg_TwoAxisEnabled->setText(tr2i18n("Two axis", nullptr));
#if QT_CONFIG(tooltip)
        kcfg_GuideAutoSquareSizeEnabled->setToolTip(tr2i18n("Automatically select the square size based on the selected star width.", nullptr));
#endif // QT_CONFIG(tooltip)
        kcfg_GuideAutoSquareSizeEnabled->setText(tr2i18n("Auto Square Size", nullptr));
        groupBox->setTitle(tr2i18n("Reticle", nullptr));
#if QT_CONFIG(tooltip)
        l_26->setToolTip(tr2i18n("X position of the guide star", nullptr));
#endif // QT_CONFIG(tooltip)
        l_26->setText(tr2i18n("X:", nullptr));
#if QT_CONFIG(tooltip)
        l_27->setToolTip(tr2i18n("Y position of the guide star", nullptr));
#endif // QT_CONFIG(tooltip)
        l_27->setText(tr2i18n("Y:", nullptr));
        groupBox_3->setTitle(tr2i18n("Calibrated Values", nullptr));
        racal->setText(tr2i18n("RA", nullptr));
        ra_cal_degrees->setText(tr2i18n("xxxx", nullptr));
        label_4->setText(tr2i18n("degrees", nullptr));
        ra_cal_mspp->setText(tr2i18n("xxxx", nullptr));
        label_6->setText(tr2i18n("ms/arcsec", nullptr));
        label_7->setText(tr2i18n("DEC", nullptr));
        dec_cal_degrees->setText(tr2i18n("xxxx", nullptr));
        dec_cal_degrees_unit->setText(tr2i18n("degrees (swapped)", nullptr));
        dec_cal_mspp->setText(tr2i18n("xxxx", nullptr));
        label_11->setText(tr2i18n("ms/arcsec", nullptr));
#if QT_CONFIG(tooltip)
        kcfg_GuideCalibrationBacklash->setToolTip(tr2i18n("<html><head/><body><p>Remove the effect of DEC backlash when calibrating guider.</p></body></html>", nullptr));
#endif // QT_CONFIG(tooltip)
#if QT_CONFIG(statustip)
        kcfg_GuideCalibrationBacklash->setStatusTip(QString());
#endif // QT_CONFIG(statustip)
        kcfg_GuideCalibrationBacklash->setText(tr2i18n("Remove DEC backlash in guide calibration", nullptr));
#if QT_CONFIG(tooltip)
        kcfg_AssumeDecOrthogonal->setToolTip(tr2i18n("<html><head/><body><p>When enabled, the DEC axis angle is assumed to be exactly 90\302\260 from the measured RA angle instead of being independently measured. This helps when periodic error or backlash causes erratic DEC calibration datapoints. The DEC pulse rate (speed) is still measured normally.</p></body></html>", nullptr));
#endif // QT_CONFIG(tooltip)
#if QT_CONFIG(statustip)
        kcfg_AssumeDecOrthogonal->setStatusTip(QString());
#endif // QT_CONFIG(statustip)
        kcfg_AssumeDecOrthogonal->setText(tr2i18n("Assume DEC orthogonal to RA", nullptr));
#if QT_CONFIG(tooltip)
        kcfg_ResetGuideCalibration->setToolTip(tr2i18n("<html><head/><body><p>If checked,  always re-calibrate when guiding is started. This is often not necessary when a good quality calibration has previously been done and the guide camera has not been rotated or re-installed.</p></body></html>", nullptr));
#endif // QT_CONFIG(tooltip)
#if QT_CONFIG(statustip)
        kcfg_ResetGuideCalibration->setStatusTip(QString());
#endif // QT_CONFIG(statustip)
        kcfg_ResetGuideCalibration->setText(tr2i18n("Reset Guide Calibration After Each Mount Slew", nullptr));
#if QT_CONFIG(tooltip)
        kcfg_ReuseGuideCalibration->setToolTip(tr2i18n("<html><head/><body><p>Store and attempt to reuse calibrations. This only works on opposite sides of the meridian if the pier-side can be automatically determined from your mount. The \"Reset Guide on Slew\" option above must be unchecked for this to be attempted.</p></body></html>", nullptr));
#endif // QT_CONFIG(tooltip)
#if QT_CONFIG(statustip)
        kcfg_ReuseGuideCalibration->setStatusTip(QString());
#endif // QT_CONFIG(statustip)
        kcfg_ReuseGuideCalibration->setText(tr2i18n("Store and reuse guide calibration when possible.", nullptr));
#if QT_CONFIG(tooltip)
        kcfg_ReverseDecOnPierSideChange->setToolTip(tr2i18n("<html><head/><body><p>When re-using a calibration, reverse the DEC angle if the current pier side differs from the one at calibration. This only applies when re-using calibrations. The value you need is a property of your mount that should be researched. </p></body></html>", nullptr));
#endif // QT_CONFIG(tooltip)
#if QT_CONFIG(statustip)
        kcfg_ReverseDecOnPierSideChange->setStatusTip(QString());
#endif // QT_CONFIG(statustip)
        kcfg_ReverseDecOnPierSideChange->setText(tr2i18n("Reverse DEC guide pulses when changing pier-side and reusing calibration.", nullptr));
        (void)OpsCalibration;
    } // retranslateUi

};

namespace Ui {
    class OpsCalibration: public Ui_OpsCalibration {};
} // namespace Ui

QT_END_NAMESPACE

#endif // OPSCALIBRATION_H

