/********************************************************************************
** Form generated from reading UI file 'opsguides.ui'
**
** Created by: Qt User Interface Compiler version 6.11.1
**
** WARNING! All changes made in this file will be lost when recompiling UI file!
********************************************************************************/

#ifndef UI_OPSGUIDES_H
#define UI_OPSGUIDES_H

#include <QtCore/QVariant>
#include <QtWidgets/QApplication>
#include <QtWidgets/QButtonGroup>
#include <QtWidgets/QCheckBox>
#include <QtWidgets/QComboBox>
#include <QtWidgets/QGridLayout>
#include <QtWidgets/QGroupBox>
#include <QtWidgets/QHBoxLayout>
#include <QtWidgets/QLabel>
#include <QtWidgets/QRadioButton>
#include <QtWidgets/QSpacerItem>
#include <QtWidgets/QVBoxLayout>
#include <QtWidgets/QWidget>
#include <klocalizedstring.h>

QT_BEGIN_NAMESPACE

class Ui_OpsGuides
{
public:
    QVBoxLayout *verticalLayout_2;
    QHBoxLayout *horizontalLayout_2;
    QVBoxLayout *verticalLayout;
    QHBoxLayout *horizontalLayout;
    QCheckBox *kcfg_ShowCLines;
    QLabel *textLabelSkyCulture;
    QComboBox *SkyCultureComboBox;
    QCheckBox *kcfg_ShowCBounds;
    QCheckBox *kcfg_ShowConstellationArt;
    QCheckBox *kcfg_ShowHighlightedCBound;
    QCheckBox *kcfg_ShowCNames;
    QGroupBox *ConstellOptions;
    QVBoxLayout *vboxLayout;
    QRadioButton *kcfg_UseLatinConstellNames;
    QRadioButton *kcfg_UseLocalConstellNames;
    QRadioButton *kcfg_UseAbbrevConstellNames;
    QSpacerItem *spacerItem;
    QGridLayout *gridLayout;
    QCheckBox *kcfg_ShowEcliptic;
    QCheckBox *kcfg_FillMilkyWay;
    QCheckBox *kcfg_ShowHorizon;
    QCheckBox *kcfg_ShowMilkyWay;
    QCheckBox *kcfg_AutoSelectGrid;
    QCheckBox *kcfg_ShowFlags;
    QCheckBox *kcfg_SimulateDaytime;
    QCheckBox *kcfg_ShowEquatorialGrid;
    QCheckBox *kcfg_ShowHorizontalGrid;
    QCheckBox *kcfg_ShowGround;
    QCheckBox *kcfg_ShowEquator;
    QCheckBox *kcfg_ShowLocalMeridian;
    QSpacerItem *spacerItem1;
    QSpacerItem *spacerItem2;
    QButtonGroup *nameButtonGroup;
    QButtonGroup *constellationButtonGroup;

    void setupUi(QWidget *OpsGuides)
    {
        if (OpsGuides->objectName().isEmpty())
            OpsGuides->setObjectName("OpsGuides");
        OpsGuides->resize(579, 549);
        verticalLayout_2 = new QVBoxLayout(OpsGuides);
        verticalLayout_2->setObjectName("verticalLayout_2");
        horizontalLayout_2 = new QHBoxLayout();
        horizontalLayout_2->setObjectName("horizontalLayout_2");
        verticalLayout = new QVBoxLayout();
        verticalLayout->setObjectName("verticalLayout");
        horizontalLayout = new QHBoxLayout();
        horizontalLayout->setObjectName("horizontalLayout");
        kcfg_ShowCLines = new QCheckBox(OpsGuides);
        constellationButtonGroup = new QButtonGroup(OpsGuides);
        constellationButtonGroup->setObjectName("constellationButtonGroup");
        constellationButtonGroup->setExclusive(false);
        constellationButtonGroup->addButton(kcfg_ShowCLines);
        kcfg_ShowCLines->setObjectName("kcfg_ShowCLines");

        horizontalLayout->addWidget(kcfg_ShowCLines);

        textLabelSkyCulture = new QLabel(OpsGuides);
        textLabelSkyCulture->setObjectName("textLabelSkyCulture");

        horizontalLayout->addWidget(textLabelSkyCulture);

        SkyCultureComboBox = new QComboBox(OpsGuides);
        SkyCultureComboBox->setObjectName("SkyCultureComboBox");

        horizontalLayout->addWidget(SkyCultureComboBox);


        verticalLayout->addLayout(horizontalLayout);

        kcfg_ShowCBounds = new QCheckBox(OpsGuides);
        constellationButtonGroup->addButton(kcfg_ShowCBounds);
        kcfg_ShowCBounds->setObjectName("kcfg_ShowCBounds");

        verticalLayout->addWidget(kcfg_ShowCBounds);

        kcfg_ShowConstellationArt = new QCheckBox(OpsGuides);
        constellationButtonGroup->addButton(kcfg_ShowConstellationArt);
        kcfg_ShowConstellationArt->setObjectName("kcfg_ShowConstellationArt");

        verticalLayout->addWidget(kcfg_ShowConstellationArt);

        kcfg_ShowHighlightedCBound = new QCheckBox(OpsGuides);
        constellationButtonGroup->addButton(kcfg_ShowHighlightedCBound);
        kcfg_ShowHighlightedCBound->setObjectName("kcfg_ShowHighlightedCBound");

        verticalLayout->addWidget(kcfg_ShowHighlightedCBound);

        kcfg_ShowCNames = new QCheckBox(OpsGuides);
        constellationButtonGroup->addButton(kcfg_ShowCNames);
        kcfg_ShowCNames->setObjectName("kcfg_ShowCNames");

        verticalLayout->addWidget(kcfg_ShowCNames);


        horizontalLayout_2->addLayout(verticalLayout);

        ConstellOptions = new QGroupBox(OpsGuides);
        ConstellOptions->setObjectName("ConstellOptions");
        vboxLayout = new QVBoxLayout(ConstellOptions);
        vboxLayout->setSpacing(6);
        vboxLayout->setObjectName("vboxLayout");
        vboxLayout->setContentsMargins(8, 8, 8, 8);
        kcfg_UseLatinConstellNames = new QRadioButton(ConstellOptions);
        nameButtonGroup = new QButtonGroup(OpsGuides);
        nameButtonGroup->setObjectName("nameButtonGroup");
        nameButtonGroup->addButton(kcfg_UseLatinConstellNames);
        kcfg_UseLatinConstellNames->setObjectName("kcfg_UseLatinConstellNames");

        vboxLayout->addWidget(kcfg_UseLatinConstellNames);

        kcfg_UseLocalConstellNames = new QRadioButton(ConstellOptions);
        nameButtonGroup->addButton(kcfg_UseLocalConstellNames);
        kcfg_UseLocalConstellNames->setObjectName("kcfg_UseLocalConstellNames");

        vboxLayout->addWidget(kcfg_UseLocalConstellNames);

        kcfg_UseAbbrevConstellNames = new QRadioButton(ConstellOptions);
        nameButtonGroup->addButton(kcfg_UseAbbrevConstellNames);
        kcfg_UseAbbrevConstellNames->setObjectName("kcfg_UseAbbrevConstellNames");

        vboxLayout->addWidget(kcfg_UseAbbrevConstellNames);


        horizontalLayout_2->addWidget(ConstellOptions);


        verticalLayout_2->addLayout(horizontalLayout_2);

        spacerItem = new QSpacerItem(20, 16, QSizePolicy::Policy::Minimum, QSizePolicy::Policy::Fixed);

        verticalLayout_2->addItem(spacerItem);

        gridLayout = new QGridLayout();
        gridLayout->setObjectName("gridLayout");
        kcfg_ShowEcliptic = new QCheckBox(OpsGuides);
        constellationButtonGroup->addButton(kcfg_ShowEcliptic);
        kcfg_ShowEcliptic->setObjectName("kcfg_ShowEcliptic");

        gridLayout->addWidget(kcfg_ShowEcliptic, 4, 1, 1, 1);

        kcfg_FillMilkyWay = new QCheckBox(OpsGuides);
        constellationButtonGroup->addButton(kcfg_FillMilkyWay);
        kcfg_FillMilkyWay->setObjectName("kcfg_FillMilkyWay");

        gridLayout->addWidget(kcfg_FillMilkyWay, 2, 0, 1, 1);

        kcfg_ShowHorizon = new QCheckBox(OpsGuides);
        constellationButtonGroup->addButton(kcfg_ShowHorizon);
        kcfg_ShowHorizon->setObjectName("kcfg_ShowHorizon");

        gridLayout->addWidget(kcfg_ShowHorizon, 0, 1, 1, 1);

        kcfg_ShowMilkyWay = new QCheckBox(OpsGuides);
        constellationButtonGroup->addButton(kcfg_ShowMilkyWay);
        kcfg_ShowMilkyWay->setObjectName("kcfg_ShowMilkyWay");

        gridLayout->addWidget(kcfg_ShowMilkyWay, 0, 0, 1, 1);

        kcfg_AutoSelectGrid = new QCheckBox(OpsGuides);
        constellationButtonGroup->addButton(kcfg_AutoSelectGrid);
        kcfg_AutoSelectGrid->setObjectName("kcfg_AutoSelectGrid");

        gridLayout->addWidget(kcfg_AutoSelectGrid, 0, 2, 1, 1);

        kcfg_ShowFlags = new QCheckBox(OpsGuides);
        constellationButtonGroup->addButton(kcfg_ShowFlags);
        kcfg_ShowFlags->setObjectName("kcfg_ShowFlags");

        gridLayout->addWidget(kcfg_ShowFlags, 6, 0, 1, 1);

        kcfg_SimulateDaytime = new QCheckBox(OpsGuides);
        constellationButtonGroup->addButton(kcfg_SimulateDaytime);
        kcfg_SimulateDaytime->setObjectName("kcfg_SimulateDaytime");

        gridLayout->addWidget(kcfg_SimulateDaytime, 7, 0, 1, 1);

        kcfg_ShowEquatorialGrid = new QCheckBox(OpsGuides);
        constellationButtonGroup->addButton(kcfg_ShowEquatorialGrid);
        kcfg_ShowEquatorialGrid->setObjectName("kcfg_ShowEquatorialGrid");

        gridLayout->addWidget(kcfg_ShowEquatorialGrid, 2, 2, 1, 1);

        kcfg_ShowHorizontalGrid = new QCheckBox(OpsGuides);
        constellationButtonGroup->addButton(kcfg_ShowHorizontalGrid);
        kcfg_ShowHorizontalGrid->setObjectName("kcfg_ShowHorizontalGrid");

        gridLayout->addWidget(kcfg_ShowHorizontalGrid, 4, 2, 1, 1);

        kcfg_ShowGround = new QCheckBox(OpsGuides);
        constellationButtonGroup->addButton(kcfg_ShowGround);
        kcfg_ShowGround->setObjectName("kcfg_ShowGround");

        gridLayout->addWidget(kcfg_ShowGround, 2, 1, 1, 1);

        kcfg_ShowEquator = new QCheckBox(OpsGuides);
        constellationButtonGroup->addButton(kcfg_ShowEquator);
        kcfg_ShowEquator->setObjectName("kcfg_ShowEquator");

        gridLayout->addWidget(kcfg_ShowEquator, 4, 0, 1, 1);

        kcfg_ShowLocalMeridian = new QCheckBox(OpsGuides);
        constellationButtonGroup->addButton(kcfg_ShowLocalMeridian);
        kcfg_ShowLocalMeridian->setObjectName("kcfg_ShowLocalMeridian");

        gridLayout->addWidget(kcfg_ShowLocalMeridian, 6, 2, 1, 1);


        verticalLayout_2->addLayout(gridLayout);

        spacerItem1 = new QSpacerItem(389, 16, QSizePolicy::Policy::Minimum, QSizePolicy::Policy::Expanding);

        verticalLayout_2->addItem(spacerItem1);

        spacerItem2 = new QSpacerItem(389, 16, QSizePolicy::Policy::Minimum, QSizePolicy::Policy::Expanding);

        verticalLayout_2->addItem(spacerItem2);

        QWidget::setTabOrder(kcfg_ShowCLines, kcfg_ShowCBounds);
        QWidget::setTabOrder(kcfg_ShowCBounds, kcfg_ShowConstellationArt);
        QWidget::setTabOrder(kcfg_ShowConstellationArt, kcfg_ShowHighlightedCBound);
        QWidget::setTabOrder(kcfg_ShowHighlightedCBound, kcfg_ShowCNames);
        QWidget::setTabOrder(kcfg_ShowCNames, kcfg_UseLatinConstellNames);
        QWidget::setTabOrder(kcfg_UseLatinConstellNames, kcfg_UseLocalConstellNames);
        QWidget::setTabOrder(kcfg_UseLocalConstellNames, kcfg_UseAbbrevConstellNames);
        QWidget::setTabOrder(kcfg_UseAbbrevConstellNames, kcfg_ShowMilkyWay);
        QWidget::setTabOrder(kcfg_ShowMilkyWay, kcfg_FillMilkyWay);
        QWidget::setTabOrder(kcfg_FillMilkyWay, kcfg_ShowEquator);
        QWidget::setTabOrder(kcfg_ShowEquator, kcfg_ShowFlags);
        QWidget::setTabOrder(kcfg_ShowFlags, kcfg_ShowHorizon);
        QWidget::setTabOrder(kcfg_ShowHorizon, kcfg_ShowGround);
        QWidget::setTabOrder(kcfg_ShowGround, kcfg_ShowEcliptic);
        QWidget::setTabOrder(kcfg_ShowEcliptic, kcfg_AutoSelectGrid);
        QWidget::setTabOrder(kcfg_AutoSelectGrid, kcfg_ShowEquatorialGrid);
        QWidget::setTabOrder(kcfg_ShowEquatorialGrid, kcfg_ShowHorizontalGrid);
        QWidget::setTabOrder(kcfg_ShowHorizontalGrid, kcfg_ShowLocalMeridian);

        retranslateUi(OpsGuides);

        QMetaObject::connectSlotsByName(OpsGuides);
    } // setupUi

    void retranslateUi(QWidget *OpsGuides)
    {
#if QT_CONFIG(tooltip)
        kcfg_ShowCLines->setToolTip(tr2i18n("Show constellation lines?", nullptr));
#endif // QT_CONFIG(tooltip)
#if QT_CONFIG(whatsthis)
        kcfg_ShowCLines->setWhatsThis(tr2i18n("If checked, constellation lines will be drawn on the sky map.", nullptr));
#endif // QT_CONFIG(whatsthis)
        kcfg_ShowCLines->setText(tr2i18n("&Constellation lines", nullptr));
        textLabelSkyCulture->setText(tr2i18n("Sky culture:", nullptr));
#if QT_CONFIG(tooltip)
        SkyCultureComboBox->setToolTip(tr2i18n("Choose sky culture", nullptr));
#endif // QT_CONFIG(tooltip)
#if QT_CONFIG(whatsthis)
        SkyCultureComboBox->setWhatsThis(tr2i18n("Here, you can choose how constellations are represented", nullptr));
#endif // QT_CONFIG(whatsthis)
        kcfg_ShowCBounds->setText(tr2i18n("Constellation &boundaries", nullptr));
        kcfg_ShowConstellationArt->setText(tr2i18n("Constellation art", nullptr));
        kcfg_ShowHighlightedCBound->setText(tr2i18n("Highlight central constellation boundary", nullptr));
#if QT_CONFIG(tooltip)
        kcfg_ShowCNames->setToolTip(tr2i18n("Draw constellation names?", nullptr));
#endif // QT_CONFIG(tooltip)
#if QT_CONFIG(whatsthis)
        kcfg_ShowCNames->setWhatsThis(tr2i18n("If checked, constellation names will be drawn on the sky map.", nullptr));
#endif // QT_CONFIG(whatsthis)
        kcfg_ShowCNames->setText(tr2i18n("Constellation &names", nullptr));
        ConstellOptions->setTitle(tr2i18n("Constellation Name Options", nullptr));
#if QT_CONFIG(tooltip)
        kcfg_UseLatinConstellNames->setToolTip(tr2i18n("Use Latin constellation names", nullptr));
#endif // QT_CONFIG(tooltip)
#if QT_CONFIG(whatsthis)
        kcfg_UseLatinConstellNames->setWhatsThis(tr2i18n("Select this to use Latin constellation names on the sky map", nullptr));
#endif // QT_CONFIG(whatsthis)
        kcfg_UseLatinConstellNames->setText(tr2i18n("L&atin", nullptr));
#if QT_CONFIG(tooltip)
        kcfg_UseLocalConstellNames->setToolTip(tr2i18n("Use Localized constellation names", nullptr));
#endif // QT_CONFIG(tooltip)
#if QT_CONFIG(whatsthis)
        kcfg_UseLocalConstellNames->setWhatsThis(tr2i18n("Select this to use constellation names from your locality (if available)", nullptr));
#endif // QT_CONFIG(whatsthis)
        kcfg_UseLocalConstellNames->setText(tr2i18n("Localized", nullptr));
#if QT_CONFIG(tooltip)
        kcfg_UseAbbrevConstellNames->setToolTip(tr2i18n("Use IAU abbreviations", nullptr));
#endif // QT_CONFIG(tooltip)
#if QT_CONFIG(whatsthis)
        kcfg_UseAbbrevConstellNames->setWhatsThis(tr2i18n("Select this to use abbreviations from the International Astronomical Union as constellation labels", nullptr));
#endif // QT_CONFIG(whatsthis)
        kcfg_UseAbbrevConstellNames->setText(tr2i18n("Abbre&viated", nullptr));
#if QT_CONFIG(tooltip)
        kcfg_ShowEcliptic->setToolTip(tr2i18n("Draw Ecliptic?", nullptr));
#endif // QT_CONFIG(tooltip)
#if QT_CONFIG(whatsthis)
        kcfg_ShowEcliptic->setWhatsThis(tr2i18n("If checked, the ecliptic will be drawn on the sky map.  The ecliptic is a great circle on the sky that the Sun appears to follow over the course of one year.  All other solar system bodies roughly follow the ecliptic as well.", nullptr));
#endif // QT_CONFIG(whatsthis)
        kcfg_ShowEcliptic->setText(tr2i18n("Ecliptic", nullptr));
#if QT_CONFIG(tooltip)
        kcfg_FillMilkyWay->setToolTip(tr2i18n("Use filled Milky Way contour?", nullptr));
#endif // QT_CONFIG(tooltip)
#if QT_CONFIG(whatsthis)
        kcfg_FillMilkyWay->setWhatsThis(tr2i18n("If checked, the Milky Way contour will be shown filled.  Otherwise, only the outline will be drawn.", nullptr));
#endif // QT_CONFIG(whatsthis)
        kcfg_FillMilkyWay->setText(tr2i18n("Fill milk&y way", nullptr));
#if QT_CONFIG(tooltip)
        kcfg_ShowHorizon->setToolTip(tr2i18n("Draw horizon?", nullptr));
#endif // QT_CONFIG(tooltip)
#if QT_CONFIG(whatsthis)
        kcfg_ShowHorizon->setWhatsThis(tr2i18n("If checked, a line representing the local horizon will be drawn on the map.", nullptr));
#endif // QT_CONFIG(whatsthis)
        kcfg_ShowHorizon->setText(tr2i18n("Hori&zon (line)", nullptr));
#if QT_CONFIG(tooltip)
        kcfg_ShowMilkyWay->setToolTip(tr2i18n("Draw the Milky Way contour?", nullptr));
#endif // QT_CONFIG(tooltip)
#if QT_CONFIG(whatsthis)
        kcfg_ShowMilkyWay->setWhatsThis(tr2i18n("If checked, a contour representing the Milky Way will be drawn on the sky map", nullptr));
#endif // QT_CONFIG(whatsthis)
        kcfg_ShowMilkyWay->setText(tr2i18n("Mil&ky way", nullptr));
#if QT_CONFIG(tooltip)
        kcfg_AutoSelectGrid->setToolTip(tr2i18n("Draw grids according to active coordinate system?", nullptr));
#endif // QT_CONFIG(tooltip)
#if QT_CONFIG(whatsthis)
        kcfg_AutoSelectGrid->setWhatsThis(tr2i18n("If checked, coordinate grids will automatically change according to active coordinate system.", nullptr));
#endif // QT_CONFIG(whatsthis)
        kcfg_AutoSelectGrid->setText(tr2i18n("Automatically select coordinate grid", nullptr));
#if QT_CONFIG(tooltip)
        kcfg_ShowFlags->setToolTip(tr2i18n("Draw flags?", nullptr));
#endif // QT_CONFIG(tooltip)
#if QT_CONFIG(whatsthis)
        kcfg_ShowFlags->setWhatsThis(tr2i18n("If checked, flags will be drawn on the sky map", nullptr));
#endif // QT_CONFIG(whatsthis)
        kcfg_ShowFlags->setText(tr2i18n("Flags", nullptr));
#if QT_CONFIG(tooltip)
        kcfg_SimulateDaytime->setToolTip(tr2i18n("If checked, sky will be bright during the daytime", nullptr));
#endif // QT_CONFIG(tooltip)
#if QT_CONFIG(whatsthis)
        kcfg_SimulateDaytime->setWhatsThis(tr2i18n("If checked, sky will be bright during the daytime", nullptr));
#endif // QT_CONFIG(whatsthis)
        kcfg_SimulateDaytime->setText(tr2i18n("Simulate daytime", nullptr));
#if QT_CONFIG(tooltip)
        kcfg_ShowEquatorialGrid->setToolTip(tr2i18n("Draw equatorial coordinate grid?", nullptr));
#endif // QT_CONFIG(tooltip)
#if QT_CONFIG(whatsthis)
        kcfg_ShowEquatorialGrid->setWhatsThis(tr2i18n("If checked, a grid of lines will be drawn every 2 hours in Right Ascension and every 20 degrees in Declination.", nullptr));
#endif // QT_CONFIG(whatsthis)
        kcfg_ShowEquatorialGrid->setText(tr2i18n("Equatorial coordinate grid", nullptr));
#if QT_CONFIG(tooltip)
        kcfg_ShowHorizontalGrid->setToolTip(tr2i18n("Draw horizontal coordinate grid?", nullptr));
#endif // QT_CONFIG(tooltip)
#if QT_CONFIG(whatsthis)
        kcfg_ShowHorizontalGrid->setWhatsThis(tr2i18n("If checked, a grid of lines will be drawn every 30 degrees in Azimuth and every 20 degrees in Altitude.", nullptr));
#endif // QT_CONFIG(whatsthis)
        kcfg_ShowHorizontalGrid->setText(tr2i18n("Horizontal coor&dinate grid", nullptr));
#if QT_CONFIG(tooltip)
        kcfg_ShowGround->setToolTip(tr2i18n("Draw opaque ground?", nullptr));
#endif // QT_CONFIG(tooltip)
#if QT_CONFIG(whatsthis)
        kcfg_ShowGround->setWhatsThis(tr2i18n("If checked, the area below the horizon will be filled in, to simulate the ground beneath you.  Note that the ground is never drawn when using the Equatorial coordinate system.", nullptr));
#endif // QT_CONFIG(whatsthis)
        kcfg_ShowGround->setText(tr2i18n("Opaque &ground", nullptr));
#if QT_CONFIG(tooltip)
        kcfg_ShowEquator->setToolTip(tr2i18n("Draw Celestial equator?", nullptr));
#endif // QT_CONFIG(tooltip)
#if QT_CONFIG(whatsthis)
        kcfg_ShowEquator->setWhatsThis(tr2i18n("If checked, the celestial equator will be drawn in the sky map.", nullptr));
#endif // QT_CONFIG(whatsthis)
        kcfg_ShowEquator->setText(tr2i18n("Celestial e&quator", nullptr));
        kcfg_ShowLocalMeridian->setText(tr2i18n("Local meridian", nullptr));
        (void)OpsGuides;
    } // retranslateUi

};

namespace Ui {
    class OpsGuides: public Ui_OpsGuides {};
} // namespace Ui

QT_END_NAMESPACE

#endif // OPSGUIDES_H

