/********************************************************************************
** Form generated from reading UI file 'modcalcangdist.ui'
**
** Created by: Qt User Interface Compiler version 6.11.1
**
** WARNING! All changes made in this file will be lost when recompiling UI file!
********************************************************************************/

#ifndef UI_MODCALCANGDIST_H
#define UI_MODCALCANGDIST_H

#include <QtCore/QVariant>
#include <QtWidgets/QApplication>
#include <QtWidgets/QCheckBox>
#include <QtWidgets/QGridLayout>
#include <QtWidgets/QGroupBox>
#include <QtWidgets/QHBoxLayout>
#include <QtWidgets/QLabel>
#include <QtWidgets/QPushButton>
#include <QtWidgets/QRadioButton>
#include <QtWidgets/QSpacerItem>
#include <QtWidgets/QTabWidget>
#include <QtWidgets/QVBoxLayout>
#include <QtWidgets/QWidget>
#include <klocalizedstring.h>
#include "kurlrequester.h"
#include "widgets/dmsbox.h"

QT_BEGIN_NAMESPACE

class Ui_modCalcAngDistDlg
{
public:
    QVBoxLayout *vboxLayout;
    QTabWidget *tabWidget3;
    QWidget *interact;
    QVBoxLayout *verticalLayout;
    QHBoxLayout *topLayout;
    QGroupBox *FirstPositionBox;
    QGridLayout *gridLayout;
    QHBoxLayout *objectLayout;
    QSpacerItem *spacerItem;
    QPushButton *FirstObjectButton;
    QSpacerItem *spacerItem1;
    dmsBox *FirstDec;
    dmsBox *FirstRA;
    QLabel *dec0Label;
    QLabel *ra0Label;
    QGroupBox *SecondPositionBox;
    QGridLayout *gridLayout1;
    QHBoxLayout *objectLayout2;
    QSpacerItem *SP1;
    QPushButton *SecondObjectButton;
    QSpacerItem *SP2;
    dmsBox *SecondDec;
    dmsBox *SecondRA;
    QLabel *dec1Label;
    QLabel *ra1Label;
    QSpacerItem *spacerItem2;
    QHBoxLayout *horizontalLayout;
    QSpacerItem *LSP;
    QGridLayout *gridLayout_2;
    QLabel *AngDistLabel;
    QLabel *AngDist;
    QLabel *AngDistLabel_4;
    QLabel *AngDistLabel_2;
    QLabel *PositionAngle;
    QLabel *AngDistLabel_3;
    QSpacerItem *RSP;
    QSpacerItem *bottomSP;
    QWidget *batch;
    QVBoxLayout *vboxLayout1;
    QGroupBox *groupBox;
    QHBoxLayout *hboxLayout;
    QVBoxLayout *batchLeftLayout;
    QCheckBox *ra0CheckBatch;
    QCheckBox *dec0CheckBatch;
    QCheckBox *ra1CheckBatch;
    QCheckBox *dec1CheckBatch;
    QVBoxLayout *batchRightLayout;
    dmsBox *ra0BoxBatch;
    dmsBox *dec0BoxBatch;
    dmsBox *ra1BoxBatch;
    dmsBox *dec1BoxBatch;
    QGroupBox *groupBox_2;
    QHBoxLayout *hboxLayout1;
    QRadioButton *allRadioBatch;
    QRadioButton *inputRadioBatch;
    QGroupBox *groupBox_4;
    QGridLayout *gridLayout2;
    KUrlRequester *InputLineEditBatch;
    KUrlRequester *OutputLineEditBatch;
    QLabel *label_3;
    QLabel *label_4;
    QHBoxLayout *runLayout;
    QSpacerItem *LSP_2;
    QPushButton *runButtonBatch;
    QSpacerItem *RSP_2;
    QSpacerItem *bottomSP_2;

    void setupUi(QWidget *modCalcAngDistDlg)
    {
        if (modCalcAngDistDlg->objectName().isEmpty())
            modCalcAngDistDlg->setObjectName("modCalcAngDistDlg");
        modCalcAngDistDlg->resize(494, 503);
        vboxLayout = new QVBoxLayout(modCalcAngDistDlg);
        vboxLayout->setSpacing(6);
        vboxLayout->setObjectName("vboxLayout");
        vboxLayout->setContentsMargins(9, 9, 9, 9);
        tabWidget3 = new QTabWidget(modCalcAngDistDlg);
        tabWidget3->setObjectName("tabWidget3");
        interact = new QWidget();
        interact->setObjectName("interact");
        verticalLayout = new QVBoxLayout(interact);
        verticalLayout->setObjectName("verticalLayout");
        topLayout = new QHBoxLayout();
        topLayout->setSpacing(6);
        topLayout->setObjectName("topLayout");
        topLayout->setContentsMargins(0, 0, 0, 0);
        FirstPositionBox = new QGroupBox(interact);
        FirstPositionBox->setObjectName("FirstPositionBox");
        gridLayout = new QGridLayout(FirstPositionBox);
        gridLayout->setSpacing(6);
        gridLayout->setObjectName("gridLayout");
        gridLayout->setContentsMargins(9, 9, 9, 9);
        objectLayout = new QHBoxLayout();
        objectLayout->setSpacing(6);
        objectLayout->setObjectName("objectLayout");
        objectLayout->setContentsMargins(0, 0, 0, 0);
        spacerItem = new QSpacerItem(31, 20, QSizePolicy::Policy::Expanding, QSizePolicy::Policy::Minimum);

        objectLayout->addItem(spacerItem);

        FirstObjectButton = new QPushButton(FirstPositionBox);
        FirstObjectButton->setObjectName("FirstObjectButton");

        objectLayout->addWidget(FirstObjectButton);

        spacerItem1 = new QSpacerItem(40, 20, QSizePolicy::Policy::Expanding, QSizePolicy::Policy::Minimum);

        objectLayout->addItem(spacerItem1);


        gridLayout->addLayout(objectLayout, 2, 0, 1, 2);

        FirstDec = new dmsBox(FirstPositionBox);
        FirstDec->setObjectName("FirstDec");

        gridLayout->addWidget(FirstDec, 1, 1, 1, 1);

        FirstRA = new dmsBox(FirstPositionBox);
        FirstRA->setObjectName("FirstRA");
        FirstRA->setMinimumSize(QSize(90, 0));

        gridLayout->addWidget(FirstRA, 0, 1, 1, 1);

        dec0Label = new QLabel(FirstPositionBox);
        dec0Label->setObjectName("dec0Label");

        gridLayout->addWidget(dec0Label, 1, 0, 1, 1);

        ra0Label = new QLabel(FirstPositionBox);
        ra0Label->setObjectName("ra0Label");

        gridLayout->addWidget(ra0Label, 0, 0, 1, 1);


        topLayout->addWidget(FirstPositionBox);

        SecondPositionBox = new QGroupBox(interact);
        SecondPositionBox->setObjectName("SecondPositionBox");
        gridLayout1 = new QGridLayout(SecondPositionBox);
        gridLayout1->setSpacing(6);
        gridLayout1->setObjectName("gridLayout1");
        gridLayout1->setContentsMargins(9, 9, 9, 9);
        objectLayout2 = new QHBoxLayout();
        objectLayout2->setSpacing(6);
        objectLayout2->setObjectName("objectLayout2");
        objectLayout2->setContentsMargins(0, 0, 0, 0);
        SP1 = new QSpacerItem(40, 20, QSizePolicy::Policy::Expanding, QSizePolicy::Policy::Minimum);

        objectLayout2->addItem(SP1);

        SecondObjectButton = new QPushButton(SecondPositionBox);
        SecondObjectButton->setObjectName("SecondObjectButton");

        objectLayout2->addWidget(SecondObjectButton);

        SP2 = new QSpacerItem(40, 20, QSizePolicy::Policy::Expanding, QSizePolicy::Policy::Minimum);

        objectLayout2->addItem(SP2);


        gridLayout1->addLayout(objectLayout2, 2, 0, 1, 2);

        SecondDec = new dmsBox(SecondPositionBox);
        SecondDec->setObjectName("SecondDec");

        gridLayout1->addWidget(SecondDec, 1, 1, 1, 1);

        SecondRA = new dmsBox(SecondPositionBox);
        SecondRA->setObjectName("SecondRA");
        SecondRA->setMinimumSize(QSize(90, 0));

        gridLayout1->addWidget(SecondRA, 0, 1, 1, 1);

        dec1Label = new QLabel(SecondPositionBox);
        dec1Label->setObjectName("dec1Label");

        gridLayout1->addWidget(dec1Label, 1, 0, 1, 1);

        ra1Label = new QLabel(SecondPositionBox);
        ra1Label->setObjectName("ra1Label");

        gridLayout1->addWidget(ra1Label, 0, 0, 1, 1);


        topLayout->addWidget(SecondPositionBox);


        verticalLayout->addLayout(topLayout);

        spacerItem2 = new QSpacerItem(20, 20, QSizePolicy::Policy::Minimum, QSizePolicy::Policy::Fixed);

        verticalLayout->addItem(spacerItem2);

        horizontalLayout = new QHBoxLayout();
        horizontalLayout->setObjectName("horizontalLayout");
        LSP = new QSpacerItem(102, 20, QSizePolicy::Policy::Expanding, QSizePolicy::Policy::Minimum);

        horizontalLayout->addItem(LSP);

        gridLayout_2 = new QGridLayout();
        gridLayout_2->setObjectName("gridLayout_2");
        AngDistLabel = new QLabel(interact);
        AngDistLabel->setObjectName("AngDistLabel");

        gridLayout_2->addWidget(AngDistLabel, 0, 0, 1, 1);

        AngDist = new QLabel(interact);
        AngDist->setObjectName("AngDist");
        QFont font;
        font.setFamilies({QString::fromUtf8("Monospace")});
        font.setPointSize(12);
        font.setBold(true);
        AngDist->setFont(font);
        AngDist->setTextInteractionFlags(Qt::TextSelectableByMouse);

        gridLayout_2->addWidget(AngDist, 0, 1, 1, 1);

        AngDistLabel_4 = new QLabel(interact);
        AngDistLabel_4->setObjectName("AngDistLabel_4");

        gridLayout_2->addWidget(AngDistLabel_4, 0, 2, 1, 1);

        AngDistLabel_2 = new QLabel(interact);
        AngDistLabel_2->setObjectName("AngDistLabel_2");

        gridLayout_2->addWidget(AngDistLabel_2, 1, 0, 1, 1);

        PositionAngle = new QLabel(interact);
        PositionAngle->setObjectName("PositionAngle");
        PositionAngle->setFont(font);
        PositionAngle->setTextInteractionFlags(Qt::TextSelectableByMouse);

        gridLayout_2->addWidget(PositionAngle, 1, 1, 1, 1);

        AngDistLabel_3 = new QLabel(interact);
        AngDistLabel_3->setObjectName("AngDistLabel_3");

        gridLayout_2->addWidget(AngDistLabel_3, 1, 2, 1, 1);


        horizontalLayout->addLayout(gridLayout_2);

        RSP = new QSpacerItem(70, 20, QSizePolicy::Policy::Expanding, QSizePolicy::Policy::Minimum);

        horizontalLayout->addItem(RSP);


        verticalLayout->addLayout(horizontalLayout);

        bottomSP = new QSpacerItem(21, 171, QSizePolicy::Policy::Minimum, QSizePolicy::Policy::Expanding);

        verticalLayout->addItem(bottomSP);

        tabWidget3->addTab(interact, QString());
        batch = new QWidget();
        batch->setObjectName("batch");
        vboxLayout1 = new QVBoxLayout(batch);
        vboxLayout1->setSpacing(6);
        vboxLayout1->setObjectName("vboxLayout1");
        vboxLayout1->setContentsMargins(8, 8, 8, 8);
        groupBox = new QGroupBox(batch);
        groupBox->setObjectName("groupBox");
        hboxLayout = new QHBoxLayout(groupBox);
        hboxLayout->setSpacing(6);
        hboxLayout->setObjectName("hboxLayout");
        hboxLayout->setContentsMargins(8, 8, 8, 8);
        batchLeftLayout = new QVBoxLayout();
        batchLeftLayout->setSpacing(6);
        batchLeftLayout->setObjectName("batchLeftLayout");
        batchLeftLayout->setContentsMargins(0, 0, 0, 0);
        ra0CheckBatch = new QCheckBox(groupBox);
        ra0CheckBatch->setObjectName("ra0CheckBatch");
        ra0CheckBatch->setChecked(true);

        batchLeftLayout->addWidget(ra0CheckBatch);

        dec0CheckBatch = new QCheckBox(groupBox);
        dec0CheckBatch->setObjectName("dec0CheckBatch");
        dec0CheckBatch->setChecked(true);

        batchLeftLayout->addWidget(dec0CheckBatch);

        ra1CheckBatch = new QCheckBox(groupBox);
        ra1CheckBatch->setObjectName("ra1CheckBatch");
        ra1CheckBatch->setChecked(true);

        batchLeftLayout->addWidget(ra1CheckBatch);

        dec1CheckBatch = new QCheckBox(groupBox);
        dec1CheckBatch->setObjectName("dec1CheckBatch");
        dec1CheckBatch->setChecked(true);

        batchLeftLayout->addWidget(dec1CheckBatch);


        hboxLayout->addLayout(batchLeftLayout);

        batchRightLayout = new QVBoxLayout();
        batchRightLayout->setSpacing(6);
        batchRightLayout->setObjectName("batchRightLayout");
        batchRightLayout->setContentsMargins(0, 0, 0, 0);
        ra0BoxBatch = new dmsBox(groupBox);
        ra0BoxBatch->setObjectName("ra0BoxBatch");

        batchRightLayout->addWidget(ra0BoxBatch);

        dec0BoxBatch = new dmsBox(groupBox);
        dec0BoxBatch->setObjectName("dec0BoxBatch");

        batchRightLayout->addWidget(dec0BoxBatch);

        ra1BoxBatch = new dmsBox(groupBox);
        ra1BoxBatch->setObjectName("ra1BoxBatch");

        batchRightLayout->addWidget(ra1BoxBatch);

        dec1BoxBatch = new dmsBox(groupBox);
        dec1BoxBatch->setObjectName("dec1BoxBatch");

        batchRightLayout->addWidget(dec1BoxBatch);


        hboxLayout->addLayout(batchRightLayout);


        vboxLayout1->addWidget(groupBox);

        groupBox_2 = new QGroupBox(batch);
        groupBox_2->setObjectName("groupBox_2");
        hboxLayout1 = new QHBoxLayout(groupBox_2);
        hboxLayout1->setSpacing(6);
        hboxLayout1->setObjectName("hboxLayout1");
        hboxLayout1->setContentsMargins(8, 8, 8, 8);
        allRadioBatch = new QRadioButton(groupBox_2);
        allRadioBatch->setObjectName("allRadioBatch");

        hboxLayout1->addWidget(allRadioBatch);

        inputRadioBatch = new QRadioButton(groupBox_2);
        inputRadioBatch->setObjectName("inputRadioBatch");
        inputRadioBatch->setChecked(true);

        hboxLayout1->addWidget(inputRadioBatch);


        vboxLayout1->addWidget(groupBox_2);

        groupBox_4 = new QGroupBox(batch);
        groupBox_4->setObjectName("groupBox_4");
        gridLayout2 = new QGridLayout(groupBox_4);
        gridLayout2->setSpacing(6);
        gridLayout2->setObjectName("gridLayout2");
        gridLayout2->setContentsMargins(8, 8, 8, 8);
        InputLineEditBatch = new KUrlRequester(groupBox_4);
        InputLineEditBatch->setObjectName("InputLineEditBatch");

        gridLayout2->addWidget(InputLineEditBatch, 0, 1, 1, 1);

        OutputLineEditBatch = new KUrlRequester(groupBox_4);
        OutputLineEditBatch->setObjectName("OutputLineEditBatch");

        gridLayout2->addWidget(OutputLineEditBatch, 1, 1, 1, 1);

        label_3 = new QLabel(groupBox_4);
        label_3->setObjectName("label_3");

        gridLayout2->addWidget(label_3, 0, 0, 1, 1);

        label_4 = new QLabel(groupBox_4);
        label_4->setObjectName("label_4");

        gridLayout2->addWidget(label_4, 1, 0, 1, 1);


        vboxLayout1->addWidget(groupBox_4);

        runLayout = new QHBoxLayout();
        runLayout->setSpacing(6);
        runLayout->setObjectName("runLayout");
        runLayout->setContentsMargins(0, 0, 0, 0);
        LSP_2 = new QSpacerItem(151, 21, QSizePolicy::Policy::Expanding, QSizePolicy::Policy::Minimum);

        runLayout->addItem(LSP_2);

        runButtonBatch = new QPushButton(batch);
        runButtonBatch->setObjectName("runButtonBatch");
        QSizePolicy sizePolicy(QSizePolicy::Policy::Expanding, QSizePolicy::Policy::Preferred);
        sizePolicy.setHorizontalStretch(0);
        sizePolicy.setVerticalStretch(0);
        sizePolicy.setHeightForWidth(runButtonBatch->sizePolicy().hasHeightForWidth());
        runButtonBatch->setSizePolicy(sizePolicy);

        runLayout->addWidget(runButtonBatch);

        RSP_2 = new QSpacerItem(131, 21, QSizePolicy::Policy::Expanding, QSizePolicy::Policy::Minimum);

        runLayout->addItem(RSP_2);


        vboxLayout1->addLayout(runLayout);

        bottomSP_2 = new QSpacerItem(20, 21, QSizePolicy::Policy::Minimum, QSizePolicy::Policy::Expanding);

        vboxLayout1->addItem(bottomSP_2);

        tabWidget3->addTab(batch, QString());

        vboxLayout->addWidget(tabWidget3);

        QWidget::setTabOrder(FirstRA, FirstDec);
        QWidget::setTabOrder(FirstDec, FirstObjectButton);
        QWidget::setTabOrder(FirstObjectButton, SecondRA);
        QWidget::setTabOrder(SecondRA, SecondDec);
        QWidget::setTabOrder(SecondDec, SecondObjectButton);
        QWidget::setTabOrder(SecondObjectButton, ra0CheckBatch);
        QWidget::setTabOrder(ra0CheckBatch, ra0BoxBatch);
        QWidget::setTabOrder(ra0BoxBatch, dec0CheckBatch);
        QWidget::setTabOrder(dec0CheckBatch, dec0BoxBatch);
        QWidget::setTabOrder(dec0BoxBatch, ra1CheckBatch);
        QWidget::setTabOrder(ra1CheckBatch, ra1BoxBatch);
        QWidget::setTabOrder(ra1BoxBatch, dec1CheckBatch);
        QWidget::setTabOrder(dec1CheckBatch, dec1BoxBatch);
        QWidget::setTabOrder(dec1BoxBatch, allRadioBatch);
        QWidget::setTabOrder(allRadioBatch, inputRadioBatch);
        QWidget::setTabOrder(inputRadioBatch, InputLineEditBatch);
        QWidget::setTabOrder(InputLineEditBatch, OutputLineEditBatch);
        QWidget::setTabOrder(OutputLineEditBatch, runButtonBatch);

        retranslateUi(modCalcAngDistDlg);

        tabWidget3->setCurrentIndex(0);


        QMetaObject::connectSlotsByName(modCalcAngDistDlg);
    } // setupUi

    void retranslateUi(QWidget *modCalcAngDistDlg)
    {
        modCalcAngDistDlg->setWindowTitle(tr2i18n("Angular Distance", nullptr));
        FirstPositionBox->setTitle(tr2i18n("First position", nullptr));
        FirstObjectButton->setText(tr2i18n("Select Object...", nullptr));
        dec0Label->setText(tr2i18n("Declination:", nullptr));
        ra0Label->setText(tr2i18n("Right ascension:", nullptr));
        SecondPositionBox->setTitle(tr2i18n("Second position", nullptr));
        SecondObjectButton->setText(tr2i18n("Select Object...", nullptr));
        dec1Label->setText(tr2i18n("Declination:", nullptr));
        ra1Label->setText(tr2i18n("Right ascension:", nullptr));
        AngDistLabel->setText(tr2i18n("Angular distance:", nullptr));
        AngDist->setText(tr2i18n("00:00:00", nullptr));
        AngDistLabel_4->setText(tr2i18n("degrees", nullptr));
        AngDistLabel_2->setText(tr2i18n("Position angle:", nullptr));
        PositionAngle->setText(tr2i18n("0", nullptr));
        AngDistLabel_3->setText(tr2i18n("degrees E of N", nullptr));
        tabWidget3->setTabText(tabWidget3->indexOf(interact), tr2i18n("Interactive Mode", nullptr));
        groupBox->setTitle(tr2i18n("Select Fields in Input File", nullptr));
        ra0CheckBatch->setText(tr2i18n("Initial right ascension:", nullptr));
        dec0CheckBatch->setText(tr2i18n("Initial declination:", nullptr));
        ra1CheckBatch->setText(tr2i18n("Final right ascension:", nullptr));
        dec1CheckBatch->setText(tr2i18n("Final declination:", nullptr));
        groupBox_2->setTitle(tr2i18n("Fields in Output File Plus Result", nullptr));
        allRadioBatch->setText(tr2i18n("A&ll parameters", nullptr));
        inputRadioBatch->setText(tr2i18n("Onl&y parameters in input file", nullptr));
        groupBox_4->setTitle(tr2i18n("Files", nullptr));
        label_3->setText(tr2i18n("Input file:", nullptr));
        label_4->setText(tr2i18n("Output file:", nullptr));
        runButtonBatch->setText(tr2i18n("Run", nullptr));
        tabWidget3->setTabText(tabWidget3->indexOf(batch), tr2i18n("Batch Mode", nullptr));
    } // retranslateUi

};

namespace Ui {
    class modCalcAngDistDlg: public Ui_modCalcAngDistDlg {};
} // namespace Ui

QT_END_NAMESPACE

#endif // MODCALCANGDIST_H

