/********************************************************************************
** Form generated from reading UI file 'manualdither.ui'
**
** Created by: Qt User Interface Compiler version 6.11.1
**
** WARNING! All changes made in this file will be lost when recompiling UI file!
********************************************************************************/

#ifndef UI_MANUALDITHER_H
#define UI_MANUALDITHER_H

#include <QtCore/QVariant>
#include <QtWidgets/QAbstractButton>
#include <QtWidgets/QApplication>
#include <QtWidgets/QButtonGroup>
#include <QtWidgets/QDialog>
#include <QtWidgets/QDialogButtonBox>
#include <QtWidgets/QDoubleSpinBox>
#include <QtWidgets/QGridLayout>
#include <QtWidgets/QHBoxLayout>
#include <QtWidgets/QLabel>
#include <QtWidgets/QRadioButton>
#include <QtWidgets/QVBoxLayout>
#include <klocalizedstring.h>

QT_BEGIN_NAMESPACE

class Ui_ManualDither
{
public:
    QVBoxLayout *verticalLayout;
    QGridLayout *gridLayout;
    QRadioButton *magnitudeR;
    QDoubleSpinBox *magnitude;
    QLabel *label;
    QRadioButton *coordinatesR;
    QHBoxLayout *horizontalLayout_2;
    QLabel *label_3;
    QDoubleSpinBox *x;
    QHBoxLayout *horizontalLayout;
    QLabel *label_4;
    QDoubleSpinBox *y;
    QDialogButtonBox *dialogButtonBox;
    QButtonGroup *ditherActionGroup;

    void setupUi(QDialog *ManualDither)
    {
        if (ManualDither->objectName().isEmpty())
            ManualDither->setObjectName("ManualDither");
        ManualDither->resize(281, 92);
        verticalLayout = new QVBoxLayout(ManualDither);
        verticalLayout->setObjectName("verticalLayout");
        gridLayout = new QGridLayout();
        gridLayout->setObjectName("gridLayout");
        magnitudeR = new QRadioButton(ManualDither);
        ditherActionGroup = new QButtonGroup(ManualDither);
        ditherActionGroup->setObjectName("ditherActionGroup");
        ditherActionGroup->addButton(magnitudeR);
        magnitudeR->setObjectName("magnitudeR");
        magnitudeR->setChecked(true);

        gridLayout->addWidget(magnitudeR, 0, 0, 1, 1);

        magnitude = new QDoubleSpinBox(ManualDither);
        magnitude->setObjectName("magnitude");
        magnitude->setMinimum(0.500000000000000);
        magnitude->setMaximum(60.000000000000000);
        magnitude->setValue(3.000000000000000);

        gridLayout->addWidget(magnitude, 0, 1, 1, 1);

        label = new QLabel(ManualDither);
        label->setObjectName("label");

        gridLayout->addWidget(label, 0, 2, 1, 1);

        coordinatesR = new QRadioButton(ManualDither);
        ditherActionGroup->addButton(coordinatesR);
        coordinatesR->setObjectName("coordinatesR");

        gridLayout->addWidget(coordinatesR, 1, 0, 1, 1);

        horizontalLayout_2 = new QHBoxLayout();
        horizontalLayout_2->setObjectName("horizontalLayout_2");
        label_3 = new QLabel(ManualDither);
        label_3->setObjectName("label_3");

        horizontalLayout_2->addWidget(label_3);

        x = new QDoubleSpinBox(ManualDither);
        x->setObjectName("x");
        x->setMinimum(1.000000000000000);
        x->setMaximum(10000.000000000000000);

        horizontalLayout_2->addWidget(x);


        gridLayout->addLayout(horizontalLayout_2, 1, 1, 1, 1);

        horizontalLayout = new QHBoxLayout();
        horizontalLayout->setObjectName("horizontalLayout");
        label_4 = new QLabel(ManualDither);
        label_4->setObjectName("label_4");

        horizontalLayout->addWidget(label_4);

        y = new QDoubleSpinBox(ManualDither);
        y->setObjectName("y");
        y->setMinimum(1.000000000000000);
        y->setMaximum(10000.000000000000000);

        horizontalLayout->addWidget(y);


        gridLayout->addLayout(horizontalLayout, 1, 2, 1, 1);


        verticalLayout->addLayout(gridLayout);

        dialogButtonBox = new QDialogButtonBox(ManualDither);
        dialogButtonBox->setObjectName("dialogButtonBox");
        dialogButtonBox->setOrientation(Qt::Horizontal);
        dialogButtonBox->setStandardButtons(QDialogButtonBox::Cancel|QDialogButtonBox::Ok);

        verticalLayout->addWidget(dialogButtonBox);


        retranslateUi(ManualDither);
        QObject::connect(dialogButtonBox, &QDialogButtonBox::accepted, ManualDither, qOverload<>(&QDialog::accept));
        QObject::connect(dialogButtonBox, &QDialogButtonBox::rejected, ManualDither, qOverload<>(&QDialog::reject));

        QMetaObject::connectSlotsByName(ManualDither);
    } // setupUi

    void retranslateUi(QDialog *ManualDither)
    {
        ManualDither->setWindowTitle(tr2i18n("Manual Dithering", nullptr));
        magnitudeR->setText(tr2i18n("Magnitude", nullptr));
        label->setText(tr2i18n("pixels", nullptr));
        coordinatesR->setText(tr2i18n("Coordinates", nullptr));
        label_3->setText(tr2i18n("X:", nullptr));
        label_4->setText(tr2i18n("Y:", nullptr));
    } // retranslateUi

};

namespace Ui {
    class ManualDither: public Ui_ManualDither {};
} // namespace Ui

QT_END_NAMESPACE

#endif // MANUALDITHER_H

