/********************************************************************************
** Form generated from reading UI file 'newfov.ui'
**
** Created by: Qt User Interface Compiler version 6.11.1
**
** WARNING! All changes made in this file will be lost when recompiling UI file!
********************************************************************************/

#ifndef UI_NEWFOV_H
#define UI_NEWFOV_H

#include <QtCore/QVariant>
#include <QtWidgets/QApplication>
#include <QtWidgets/QCheckBox>
#include <QtWidgets/QComboBox>
#include <QtWidgets/QDoubleSpinBox>
#include <QtWidgets/QFormLayout>
#include <QtWidgets/QGridLayout>
#include <QtWidgets/QHBoxLayout>
#include <QtWidgets/QLabel>
#include <QtWidgets/QLineEdit>
#include <QtWidgets/QPushButton>
#include <QtWidgets/QSpacerItem>
#include <QtWidgets/QSpinBox>
#include <QtWidgets/QTabWidget>
#include <QtWidgets/QVBoxLayout>
#include <QtWidgets/QWidget>
#include <klocalizedstring.h>
#include "kcolorbutton.h"
#include "widgets/fovwidget.h"

QT_BEGIN_NAMESPACE

class Ui_NewFOV
{
public:
    QVBoxLayout *verticalLayout_2;
    QHBoxLayout *hboxLayout;
    QLabel *textLabel1;
    QLineEdit *FOVName;
    QTabWidget *tabWidget2;
    QWidget *tab1;
    QVBoxLayout *verticalLayout_7;
    QHBoxLayout *horizontalLayout_12;
    QFormLayout *formLayout_3;
    QLabel *textLabel5;
    QHBoxLayout *horizontalLayout;
    QDoubleSpinBox *TLength1;
    QLabel *textLabel6_2;
    QSpacerItem *horizontalSpacer_6;
    QLabel *textLabel7_2;
    QHBoxLayout *horizontalLayout_10;
    QDoubleSpinBox *EyeLength;
    QLabel *textLabel6_2_2;
    QSpacerItem *horizontalSpacer_7;
    QLabel *textLabel8_2;
    QHBoxLayout *horizontalLayout_11;
    QComboBox *EyepieceAFOV;
    QHBoxLayout *hboxLayout1;
    QDoubleSpinBox *EyeFOV;
    QLabel *textLabel6_2_2_2;
    QSpacerItem *horizontalSpacer;
    QVBoxLayout *verticalLayout;
    QPushButton *ComputeTLengthFromFNum1;
    QSpacerItem *verticalSpacer_3;
    QLabel *label_4;
    QSpacerItem *spacerItem;
    QHBoxLayout *hboxLayout2;
    QSpacerItem *spacerItem1;
    QPushButton *ComputeEyeFOV;
    QWidget *tab2;
    QVBoxLayout *verticalLayout_3;
    QHBoxLayout *horizontalLayout_2;
    QGridLayout *gridLayout_2;
    QLabel *textLabel5_2;
    QDoubleSpinBox *TLength2;
    QLabel *textLabel6_2_3;
    QLabel *label_8;
    QSpinBox *cameraWidth;
    QLabel *label_10;
    QSpinBox *cameraHeight;
    QLabel *label_9;
    QLabel *textLabel9;
    QDoubleSpinBox *cameraPixelSizeW;
    QLabel *label_11;
    QDoubleSpinBox *cameraPixelSizeH;
    QLabel *textLabel6_2_3_2;
    QSpacerItem *horizontalSpacer_2;
    QSpacerItem *verticalSpacer;
    QHBoxLayout *horizontalLayout_3;
    QPushButton *ComputeCameraFOV;
    QPushButton *DetectFromINDI;
    QSpacerItem *spacerItem2;
    QWidget *tab3;
    QVBoxLayout *verticalLayout_5;
    QHBoxLayout *horizontalLayout_6;
    QFormLayout *formLayout;
    QLabel *textLabel15_3;
    QHBoxLayout *horizontalLayout_4;
    QDoubleSpinBox *LinearFOV;
    QLabel *LabelUnits;
    QLabel *textLabel9_31;
    QComboBox *LinearFOVDistance;
    QSpacerItem *horizontalSpacer_4;
    QSpacerItem *verticalSpacer_2;
    QHBoxLayout *horizontalLayout_5;
    QSpacerItem *spacerItem3;
    QPushButton *ComputeBinocularFOV;
    QWidget *tab4;
    QVBoxLayout *verticalLayout_6;
    QHBoxLayout *horizontalLayout_9;
    QFormLayout *formLayout_2;
    QLabel *textLabel5_2_3;
    QHBoxLayout *horizontalLayout_7;
    QDoubleSpinBox *RTDiameter;
    QLabel *textLabel6_2_3_4;
    QLabel *textLabel9_3;
    QHBoxLayout *horizontalLayout_8;
    QDoubleSpinBox *WaveLength;
    QLabel *textLabel6_2_3_2_3;
    QSpacerItem *horizontalSpacer_5;
    QSpacerItem *spacerItem4;
    QHBoxLayout *hboxLayout3;
    QSpacerItem *spacerItem5;
    QPushButton *ComputeHPBW;
    QGridLayout *gridLayout;
    QLabel *label_3;
    QLineEdit *FOVEditY;
    QLabel *label_6;
    QLabel *label_5;
    QLabel *fieldoFviewLabel;
    QLineEdit *FOVEditRotation;
    QLabel *label_2;
    QLineEdit *FOVEditOffsetY;
    QLabel *fieldoFviewLabel_3;
    QLabel *label_7;
    QLabel *fieldoFviewLabel_4;
    QLineEdit *FOVEditX;
    QLabel *fieldoFviewLabel_2;
    QLabel *label;
    QLineEdit *FOVEditOffsetX;
    QCheckBox *FOVLockCP;
    QSpacerItem *spacerItem6;
    QHBoxLayout *hboxLayout4;
    QVBoxLayout *vboxLayout;
    QGridLayout *gridLayout1;
    KColorButton *ColorButton;
    QLabel *textLabel8;
    QComboBox *ShapeBox;
    QLabel *textLabel7;
    QVBoxLayout *vboxLayout1;
    FOVWidget *ViewBox;

    void setupUi(QWidget *NewFOV)
    {
        if (NewFOV->objectName().isEmpty())
            NewFOV->setObjectName("NewFOV");
        NewFOV->resize(720, 423);
        verticalLayout_2 = new QVBoxLayout(NewFOV);
        verticalLayout_2->setSpacing(3);
        verticalLayout_2->setObjectName("verticalLayout_2");
        verticalLayout_2->setContentsMargins(3, 3, 3, 3);
        hboxLayout = new QHBoxLayout();
        hboxLayout->setSpacing(6);
        hboxLayout->setObjectName("hboxLayout");
        hboxLayout->setContentsMargins(0, 0, 0, 0);
        textLabel1 = new QLabel(NewFOV);
        textLabel1->setObjectName("textLabel1");
        textLabel1->setFrameShape(QFrame::NoFrame);
        textLabel1->setFrameShadow(QFrame::Plain);

        hboxLayout->addWidget(textLabel1);

        FOVName = new QLineEdit(NewFOV);
        FOVName->setObjectName("FOVName");

        hboxLayout->addWidget(FOVName);


        verticalLayout_2->addLayout(hboxLayout);

        tabWidget2 = new QTabWidget(NewFOV);
        tabWidget2->setObjectName("tabWidget2");
        tab1 = new QWidget();
        tab1->setObjectName("tab1");
        verticalLayout_7 = new QVBoxLayout(tab1);
        verticalLayout_7->setObjectName("verticalLayout_7");
        horizontalLayout_12 = new QHBoxLayout();
        horizontalLayout_12->setObjectName("horizontalLayout_12");
        formLayout_3 = new QFormLayout();
        formLayout_3->setObjectName("formLayout_3");
        textLabel5 = new QLabel(tab1);
        textLabel5->setObjectName("textLabel5");

        formLayout_3->setWidget(0, QFormLayout::ItemRole::LabelRole, textLabel5);

        horizontalLayout = new QHBoxLayout();
        horizontalLayout->setObjectName("horizontalLayout");
        TLength1 = new QDoubleSpinBox(tab1);
        TLength1->setObjectName("TLength1");
        TLength1->setFocusPolicy(Qt::StrongFocus);
        TLength1->setDecimals(1);
        TLength1->setMaximum(100000.000000000000000);
        TLength1->setSingleStep(100.000000000000000);

        horizontalLayout->addWidget(TLength1);

        textLabel6_2 = new QLabel(tab1);
        textLabel6_2->setObjectName("textLabel6_2");
        QFont font;
        font.setPointSize(12);
        font.setBold(false);
        font.setItalic(false);
        font.setUnderline(false);
        font.setStrikeOut(false);
        textLabel6_2->setFont(font);

        horizontalLayout->addWidget(textLabel6_2);

        horizontalSpacer_6 = new QSpacerItem(40, 20, QSizePolicy::Policy::Minimum, QSizePolicy::Policy::Minimum);

        horizontalLayout->addItem(horizontalSpacer_6);


        formLayout_3->setLayout(0, QFormLayout::ItemRole::FieldRole, horizontalLayout);

        textLabel7_2 = new QLabel(tab1);
        textLabel7_2->setObjectName("textLabel7_2");

        formLayout_3->setWidget(1, QFormLayout::ItemRole::LabelRole, textLabel7_2);

        horizontalLayout_10 = new QHBoxLayout();
        horizontalLayout_10->setObjectName("horizontalLayout_10");
        EyeLength = new QDoubleSpinBox(tab1);
        EyeLength->setObjectName("EyeLength");
        EyeLength->setFocusPolicy(Qt::StrongFocus);

        horizontalLayout_10->addWidget(EyeLength);

        textLabel6_2_2 = new QLabel(tab1);
        textLabel6_2_2->setObjectName("textLabel6_2_2");
        textLabel6_2_2->setFont(font);

        horizontalLayout_10->addWidget(textLabel6_2_2);

        horizontalSpacer_7 = new QSpacerItem(40, 20, QSizePolicy::Policy::Minimum, QSizePolicy::Policy::Minimum);

        horizontalLayout_10->addItem(horizontalSpacer_7);


        formLayout_3->setLayout(1, QFormLayout::ItemRole::FieldRole, horizontalLayout_10);

        textLabel8_2 = new QLabel(tab1);
        textLabel8_2->setObjectName("textLabel8_2");
        QSizePolicy sizePolicy(QSizePolicy::Policy::Preferred, QSizePolicy::Policy::Preferred);
        sizePolicy.setHorizontalStretch(0);
        sizePolicy.setVerticalStretch(0);
        sizePolicy.setHeightForWidth(textLabel8_2->sizePolicy().hasHeightForWidth());
        textLabel8_2->setSizePolicy(sizePolicy);

        formLayout_3->setWidget(2, QFormLayout::ItemRole::LabelRole, textLabel8_2);

        horizontalLayout_11 = new QHBoxLayout();
        horizontalLayout_11->setObjectName("horizontalLayout_11");
        EyepieceAFOV = new QComboBox(tab1);
        EyepieceAFOV->setObjectName("EyepieceAFOV");
        QSizePolicy sizePolicy1(QSizePolicy::Policy::Minimum, QSizePolicy::Policy::Fixed);
        sizePolicy1.setHorizontalStretch(0);
        sizePolicy1.setVerticalStretch(0);
        sizePolicy1.setHeightForWidth(EyepieceAFOV->sizePolicy().hasHeightForWidth());
        EyepieceAFOV->setSizePolicy(sizePolicy1);
        EyepieceAFOV->setMinimumSize(QSize(250, 0));

        horizontalLayout_11->addWidget(EyepieceAFOV);

        hboxLayout1 = new QHBoxLayout();
        hboxLayout1->setSpacing(6);
        hboxLayout1->setObjectName("hboxLayout1");
        hboxLayout1->setContentsMargins(0, 0, 0, 0);
        EyeFOV = new QDoubleSpinBox(tab1);
        EyeFOV->setObjectName("EyeFOV");
        EyeFOV->setFocusPolicy(Qt::StrongFocus);
        EyeFOV->setMaximum(180.000000000000000);

        hboxLayout1->addWidget(EyeFOV);

        textLabel6_2_2_2 = new QLabel(tab1);
        textLabel6_2_2_2->setObjectName("textLabel6_2_2_2");
        textLabel6_2_2_2->setFont(font);

        hboxLayout1->addWidget(textLabel6_2_2_2);


        horizontalLayout_11->addLayout(hboxLayout1);


        formLayout_3->setLayout(2, QFormLayout::ItemRole::FieldRole, horizontalLayout_11);


        horizontalLayout_12->addLayout(formLayout_3);

        horizontalSpacer = new QSpacerItem(20, 20, QSizePolicy::Policy::Minimum, QSizePolicy::Policy::Minimum);

        horizontalLayout_12->addItem(horizontalSpacer);

        verticalLayout = new QVBoxLayout();
        verticalLayout->setObjectName("verticalLayout");
        ComputeTLengthFromFNum1 = new QPushButton(tab1);
        ComputeTLengthFromFNum1->setObjectName("ComputeTLengthFromFNum1");

        verticalLayout->addWidget(ComputeTLengthFromFNum1);

        verticalSpacer_3 = new QSpacerItem(20, 40, QSizePolicy::Policy::Minimum, QSizePolicy::Policy::Expanding);

        verticalLayout->addItem(verticalSpacer_3);


        horizontalLayout_12->addLayout(verticalLayout);


        verticalLayout_7->addLayout(horizontalLayout_12);

        label_4 = new QLabel(tab1);
        label_4->setObjectName("label_4");
        QFont font1;
        font1.setPointSize(7);
        font1.setBold(true);
        label_4->setFont(font1);

        verticalLayout_7->addWidget(label_4);

        spacerItem = new QSpacerItem(20, 21, QSizePolicy::Policy::Minimum, QSizePolicy::Policy::Expanding);

        verticalLayout_7->addItem(spacerItem);

        hboxLayout2 = new QHBoxLayout();
        hboxLayout2->setSpacing(6);
        hboxLayout2->setObjectName("hboxLayout2");
        hboxLayout2->setContentsMargins(0, 0, 0, 0);
        spacerItem1 = new QSpacerItem(152, 20, QSizePolicy::Policy::Expanding, QSizePolicy::Policy::Minimum);

        hboxLayout2->addItem(spacerItem1);

        ComputeEyeFOV = new QPushButton(tab1);
        ComputeEyeFOV->setObjectName("ComputeEyeFOV");

        hboxLayout2->addWidget(ComputeEyeFOV);


        verticalLayout_7->addLayout(hboxLayout2);

        tabWidget2->addTab(tab1, QString());
        tab2 = new QWidget();
        tab2->setObjectName("tab2");
        verticalLayout_3 = new QVBoxLayout(tab2);
        verticalLayout_3->setObjectName("verticalLayout_3");
        horizontalLayout_2 = new QHBoxLayout();
        horizontalLayout_2->setObjectName("horizontalLayout_2");
        gridLayout_2 = new QGridLayout();
        gridLayout_2->setObjectName("gridLayout_2");
        textLabel5_2 = new QLabel(tab2);
        textLabel5_2->setObjectName("textLabel5_2");

        gridLayout_2->addWidget(textLabel5_2, 0, 0, 1, 2);

        TLength2 = new QDoubleSpinBox(tab2);
        TLength2->setObjectName("TLength2");
        TLength2->setFocusPolicy(Qt::StrongFocus);
        TLength2->setMaximum(100000.000000000000000);
        TLength2->setSingleStep(100.000000000000000);

        gridLayout_2->addWidget(TLength2, 0, 3, 1, 1);

        textLabel6_2_3 = new QLabel(tab2);
        textLabel6_2_3->setObjectName("textLabel6_2_3");
        textLabel6_2_3->setMinimumSize(QSize(60, 0));

        gridLayout_2->addWidget(textLabel6_2_3, 0, 4, 1, 1);

        label_8 = new QLabel(tab2);
        label_8->setObjectName("label_8");

        gridLayout_2->addWidget(label_8, 1, 0, 1, 1);

        cameraWidth = new QSpinBox(tab2);
        cameraWidth->setObjectName("cameraWidth");
        cameraWidth->setMinimum(10);
        cameraWidth->setMaximum(20000);
        cameraWidth->setValue(10);

        gridLayout_2->addWidget(cameraWidth, 1, 1, 1, 1);

        label_10 = new QLabel(tab2);
        label_10->setObjectName("label_10");

        gridLayout_2->addWidget(label_10, 1, 2, 1, 1);

        cameraHeight = new QSpinBox(tab2);
        cameraHeight->setObjectName("cameraHeight");
        cameraHeight->setMinimum(10);
        cameraHeight->setMaximum(20000);

        gridLayout_2->addWidget(cameraHeight, 1, 3, 1, 1);

        label_9 = new QLabel(tab2);
        label_9->setObjectName("label_9");

        gridLayout_2->addWidget(label_9, 1, 4, 1, 1);

        textLabel9 = new QLabel(tab2);
        textLabel9->setObjectName("textLabel9");

        gridLayout_2->addWidget(textLabel9, 2, 0, 1, 1);

        cameraPixelSizeW = new QDoubleSpinBox(tab2);
        cameraPixelSizeW->setObjectName("cameraPixelSizeW");
        cameraPixelSizeW->setFocusPolicy(Qt::StrongFocus);
        cameraPixelSizeW->setMinimum(1.000000000000000);
        cameraPixelSizeW->setMaximum(30.000000000000000);
        cameraPixelSizeW->setValue(1.000000000000000);

        gridLayout_2->addWidget(cameraPixelSizeW, 2, 1, 1, 1);

        label_11 = new QLabel(tab2);
        label_11->setObjectName("label_11");

        gridLayout_2->addWidget(label_11, 2, 2, 1, 1);

        cameraPixelSizeH = new QDoubleSpinBox(tab2);
        cameraPixelSizeH->setObjectName("cameraPixelSizeH");
        cameraPixelSizeH->setFocusPolicy(Qt::StrongFocus);
        cameraPixelSizeH->setMinimum(1.000000000000000);
        cameraPixelSizeH->setMaximum(30.000000000000000);
        cameraPixelSizeH->setValue(1.000000000000000);

        gridLayout_2->addWidget(cameraPixelSizeH, 2, 3, 1, 1);

        textLabel6_2_3_2 = new QLabel(tab2);
        textLabel6_2_3_2->setObjectName("textLabel6_2_3_2");

        gridLayout_2->addWidget(textLabel6_2_3_2, 2, 4, 1, 1);


        horizontalLayout_2->addLayout(gridLayout_2);

        horizontalSpacer_2 = new QSpacerItem(40, 20, QSizePolicy::Policy::Expanding, QSizePolicy::Policy::Minimum);

        horizontalLayout_2->addItem(horizontalSpacer_2);


        verticalLayout_3->addLayout(horizontalLayout_2);

        verticalSpacer = new QSpacerItem(20, 51, QSizePolicy::Policy::Minimum, QSizePolicy::Policy::Expanding);

        verticalLayout_3->addItem(verticalSpacer);

        horizontalLayout_3 = new QHBoxLayout();
        horizontalLayout_3->setObjectName("horizontalLayout_3");
        ComputeCameraFOV = new QPushButton(tab2);
        ComputeCameraFOV->setObjectName("ComputeCameraFOV");

        horizontalLayout_3->addWidget(ComputeCameraFOV);

        DetectFromINDI = new QPushButton(tab2);
        DetectFromINDI->setObjectName("DetectFromINDI");
        sizePolicy1.setHeightForWidth(DetectFromINDI->sizePolicy().hasHeightForWidth());
        DetectFromINDI->setSizePolicy(sizePolicy1);

        horizontalLayout_3->addWidget(DetectFromINDI);

        spacerItem2 = new QSpacerItem(180, 20, QSizePolicy::Policy::Expanding, QSizePolicy::Policy::Minimum);

        horizontalLayout_3->addItem(spacerItem2);


        verticalLayout_3->addLayout(horizontalLayout_3);

        tabWidget2->addTab(tab2, QString());
        tab3 = new QWidget();
        tab3->setObjectName("tab3");
        verticalLayout_5 = new QVBoxLayout(tab3);
        verticalLayout_5->setObjectName("verticalLayout_5");
        horizontalLayout_6 = new QHBoxLayout();
        horizontalLayout_6->setObjectName("horizontalLayout_6");
        formLayout = new QFormLayout();
        formLayout->setObjectName("formLayout");
        textLabel15_3 = new QLabel(tab3);
        textLabel15_3->setObjectName("textLabel15_3");

        formLayout->setWidget(0, QFormLayout::ItemRole::LabelRole, textLabel15_3);

        horizontalLayout_4 = new QHBoxLayout();
        horizontalLayout_4->setObjectName("horizontalLayout_4");
        LinearFOV = new QDoubleSpinBox(tab3);
        LinearFOV->setObjectName("LinearFOV");
        LinearFOV->setFocusPolicy(Qt::StrongFocus);
        LinearFOV->setMaximum(10000.000000000000000);
        LinearFOV->setSingleStep(100.000000000000000);

        horizontalLayout_4->addWidget(LinearFOV);

        LabelUnits = new QLabel(tab3);
        LabelUnits->setObjectName("LabelUnits");
        LabelUnits->setMinimumSize(QSize(60, 0));
        LabelUnits->setFont(font);

        horizontalLayout_4->addWidget(LabelUnits);


        formLayout->setLayout(0, QFormLayout::ItemRole::FieldRole, horizontalLayout_4);

        textLabel9_31 = new QLabel(tab3);
        textLabel9_31->setObjectName("textLabel9_31");

        formLayout->setWidget(1, QFormLayout::ItemRole::LabelRole, textLabel9_31);

        LinearFOVDistance = new QComboBox(tab3);
        LinearFOVDistance->setObjectName("LinearFOVDistance");

        formLayout->setWidget(1, QFormLayout::ItemRole::FieldRole, LinearFOVDistance);


        horizontalLayout_6->addLayout(formLayout);

        horizontalSpacer_4 = new QSpacerItem(40, 20, QSizePolicy::Policy::Expanding, QSizePolicy::Policy::Minimum);

        horizontalLayout_6->addItem(horizontalSpacer_4);


        verticalLayout_5->addLayout(horizontalLayout_6);

        verticalSpacer_2 = new QSpacerItem(20, 78, QSizePolicy::Policy::Minimum, QSizePolicy::Policy::Expanding);

        verticalLayout_5->addItem(verticalSpacer_2);

        horizontalLayout_5 = new QHBoxLayout();
        horizontalLayout_5->setObjectName("horizontalLayout_5");
        spacerItem3 = new QSpacerItem(180, 20, QSizePolicy::Policy::Expanding, QSizePolicy::Policy::Minimum);

        horizontalLayout_5->addItem(spacerItem3);

        ComputeBinocularFOV = new QPushButton(tab3);
        ComputeBinocularFOV->setObjectName("ComputeBinocularFOV");

        horizontalLayout_5->addWidget(ComputeBinocularFOV);


        verticalLayout_5->addLayout(horizontalLayout_5);

        tabWidget2->addTab(tab3, QString());
        tab4 = new QWidget();
        tab4->setObjectName("tab4");
        verticalLayout_6 = new QVBoxLayout(tab4);
        verticalLayout_6->setObjectName("verticalLayout_6");
        horizontalLayout_9 = new QHBoxLayout();
        horizontalLayout_9->setObjectName("horizontalLayout_9");
        formLayout_2 = new QFormLayout();
        formLayout_2->setObjectName("formLayout_2");
        textLabel5_2_3 = new QLabel(tab4);
        textLabel5_2_3->setObjectName("textLabel5_2_3");

        formLayout_2->setWidget(0, QFormLayout::ItemRole::LabelRole, textLabel5_2_3);

        horizontalLayout_7 = new QHBoxLayout();
        horizontalLayout_7->setObjectName("horizontalLayout_7");
        RTDiameter = new QDoubleSpinBox(tab4);
        RTDiameter->setObjectName("RTDiameter");
        RTDiameter->setFocusPolicy(Qt::StrongFocus);
        RTDiameter->setMaximum(500.000000000000000);
        RTDiameter->setSingleStep(10.000000000000000);

        horizontalLayout_7->addWidget(RTDiameter);

        textLabel6_2_3_4 = new QLabel(tab4);
        textLabel6_2_3_4->setObjectName("textLabel6_2_3_4");
        textLabel6_2_3_4->setMinimumSize(QSize(0, 0));
        textLabel6_2_3_4->setFont(font);

        horizontalLayout_7->addWidget(textLabel6_2_3_4);


        formLayout_2->setLayout(0, QFormLayout::ItemRole::FieldRole, horizontalLayout_7);

        textLabel9_3 = new QLabel(tab4);
        textLabel9_3->setObjectName("textLabel9_3");

        formLayout_2->setWidget(1, QFormLayout::ItemRole::LabelRole, textLabel9_3);

        horizontalLayout_8 = new QHBoxLayout();
        horizontalLayout_8->setObjectName("horizontalLayout_8");
        WaveLength = new QDoubleSpinBox(tab4);
        WaveLength->setObjectName("WaveLength");
        WaveLength->setFocusPolicy(Qt::StrongFocus);

        horizontalLayout_8->addWidget(WaveLength);

        textLabel6_2_3_2_3 = new QLabel(tab4);
        textLabel6_2_3_2_3->setObjectName("textLabel6_2_3_2_3");
        textLabel6_2_3_2_3->setFont(font);

        horizontalLayout_8->addWidget(textLabel6_2_3_2_3);


        formLayout_2->setLayout(1, QFormLayout::ItemRole::FieldRole, horizontalLayout_8);


        horizontalLayout_9->addLayout(formLayout_2);

        horizontalSpacer_5 = new QSpacerItem(40, 20, QSizePolicy::Policy::Expanding, QSizePolicy::Policy::Minimum);

        horizontalLayout_9->addItem(horizontalSpacer_5);


        verticalLayout_6->addLayout(horizontalLayout_9);

        spacerItem4 = new QSpacerItem(21, 51, QSizePolicy::Policy::Minimum, QSizePolicy::Policy::Expanding);

        verticalLayout_6->addItem(spacerItem4);

        hboxLayout3 = new QHBoxLayout();
        hboxLayout3->setSpacing(6);
        hboxLayout3->setObjectName("hboxLayout3");
        hboxLayout3->setContentsMargins(0, 0, 0, 0);
        spacerItem5 = new QSpacerItem(281, 21, QSizePolicy::Policy::Expanding, QSizePolicy::Policy::Minimum);

        hboxLayout3->addItem(spacerItem5);

        ComputeHPBW = new QPushButton(tab4);
        ComputeHPBW->setObjectName("ComputeHPBW");
        ComputeHPBW->setFlat(false);

        hboxLayout3->addWidget(ComputeHPBW);


        verticalLayout_6->addLayout(hboxLayout3);

        tabWidget2->addTab(tab4, QString());

        verticalLayout_2->addWidget(tabWidget2);

        gridLayout = new QGridLayout();
        gridLayout->setObjectName("gridLayout");
        label_3 = new QLabel(NewFOV);
        label_3->setObjectName("label_3");

        gridLayout->addWidget(label_3, 0, 5, 1, 1);

        FOVEditY = new QLineEdit(NewFOV);
        FOVEditY->setObjectName("FOVEditY");

        gridLayout->addWidget(FOVEditY, 0, 4, 1, 1);

        label_6 = new QLabel(NewFOV);
        label_6->setObjectName("label_6");

        gridLayout->addWidget(label_6, 1, 5, 1, 1);

        label_5 = new QLabel(NewFOV);
        label_5->setObjectName("label_5");

        gridLayout->addWidget(label_5, 1, 2, 1, 1);

        fieldoFviewLabel = new QLabel(NewFOV);
        fieldoFviewLabel->setObjectName("fieldoFviewLabel");

        gridLayout->addWidget(fieldoFviewLabel, 0, 0, 1, 1);

        FOVEditRotation = new QLineEdit(NewFOV);
        FOVEditRotation->setObjectName("FOVEditRotation");

        gridLayout->addWidget(FOVEditRotation, 2, 1, 1, 1);

        label_2 = new QLabel(NewFOV);
        label_2->setObjectName("label_2");

        gridLayout->addWidget(label_2, 0, 2, 1, 1);

        FOVEditOffsetY = new QLineEdit(NewFOV);
        FOVEditOffsetY->setObjectName("FOVEditOffsetY");

        gridLayout->addWidget(FOVEditOffsetY, 1, 4, 1, 1);

        fieldoFviewLabel_3 = new QLabel(NewFOV);
        fieldoFviewLabel_3->setObjectName("fieldoFviewLabel_3");

        gridLayout->addWidget(fieldoFviewLabel_3, 1, 3, 1, 1);

        label_7 = new QLabel(NewFOV);
        label_7->setObjectName("label_7");

        gridLayout->addWidget(label_7, 2, 2, 1, 1);

        fieldoFviewLabel_4 = new QLabel(NewFOV);
        fieldoFviewLabel_4->setObjectName("fieldoFviewLabel_4");

        gridLayout->addWidget(fieldoFviewLabel_4, 2, 0, 1, 1);

        FOVEditX = new QLineEdit(NewFOV);
        FOVEditX->setObjectName("FOVEditX");

        gridLayout->addWidget(FOVEditX, 0, 1, 1, 1);

        fieldoFviewLabel_2 = new QLabel(NewFOV);
        fieldoFviewLabel_2->setObjectName("fieldoFviewLabel_2");

        gridLayout->addWidget(fieldoFviewLabel_2, 1, 0, 1, 1);

        label = new QLabel(NewFOV);
        label->setObjectName("label");
        label->setAlignment(Qt::AlignCenter);

        gridLayout->addWidget(label, 0, 3, 1, 1);

        FOVEditOffsetX = new QLineEdit(NewFOV);
        FOVEditOffsetX->setObjectName("FOVEditOffsetX");

        gridLayout->addWidget(FOVEditOffsetX, 1, 1, 1, 1);

        FOVLockCP = new QCheckBox(NewFOV);
        FOVLockCP->setObjectName("FOVLockCP");

        gridLayout->addWidget(FOVLockCP, 2, 4, 1, 2);


        verticalLayout_2->addLayout(gridLayout);

        spacerItem6 = new QSpacerItem(298, 20, QSizePolicy::Policy::Expanding, QSizePolicy::Policy::Minimum);

        verticalLayout_2->addItem(spacerItem6);

        hboxLayout4 = new QHBoxLayout();
        hboxLayout4->setSpacing(6);
        hboxLayout4->setObjectName("hboxLayout4");
        hboxLayout4->setContentsMargins(0, 0, 0, 0);
        vboxLayout = new QVBoxLayout();
        vboxLayout->setSpacing(6);
        vboxLayout->setObjectName("vboxLayout");
        vboxLayout->setContentsMargins(0, 0, 0, 0);
        gridLayout1 = new QGridLayout();
        gridLayout1->setSpacing(6);
        gridLayout1->setObjectName("gridLayout1");
        gridLayout1->setContentsMargins(0, 0, 0, 0);
        ColorButton = new KColorButton(NewFOV);
        ColorButton->setObjectName("ColorButton");
        ColorButton->setProperty("color", QVariant(QColor(255, 255, 255)));

        gridLayout1->addWidget(ColorButton, 1, 1, 1, 1);

        textLabel8 = new QLabel(NewFOV);
        textLabel8->setObjectName("textLabel8");

        gridLayout1->addWidget(textLabel8, 1, 0, 1, 1);

        ShapeBox = new QComboBox(NewFOV);
        ShapeBox->addItem(QString());
        ShapeBox->addItem(QString());
        ShapeBox->addItem(QString());
        ShapeBox->addItem(QString());
        ShapeBox->addItem(QString());
        ShapeBox->setObjectName("ShapeBox");

        gridLayout1->addWidget(ShapeBox, 0, 1, 1, 1);

        textLabel7 = new QLabel(NewFOV);
        textLabel7->setObjectName("textLabel7");

        gridLayout1->addWidget(textLabel7, 0, 0, 1, 1);


        vboxLayout->addLayout(gridLayout1);


        hboxLayout4->addLayout(vboxLayout);

        vboxLayout1 = new QVBoxLayout();
        vboxLayout1->setSpacing(6);
        vboxLayout1->setObjectName("vboxLayout1");
        vboxLayout1->setContentsMargins(0, 0, 0, 0);
        ViewBox = new FOVWidget(NewFOV);
        ViewBox->setObjectName("ViewBox");
        QSizePolicy sizePolicy2(QSizePolicy::Policy::Fixed, QSizePolicy::Policy::Fixed);
        sizePolicy2.setHorizontalStretch(0);
        sizePolicy2.setVerticalStretch(0);
        sizePolicy2.setHeightForWidth(ViewBox->sizePolicy().hasHeightForWidth());
        ViewBox->setSizePolicy(sizePolicy2);
        ViewBox->setMinimumSize(QSize(80, 80));
        ViewBox->setFrameShape(QFrame::StyledPanel);
        ViewBox->setFrameShadow(QFrame::Raised);

        vboxLayout1->addWidget(ViewBox);


        hboxLayout4->addLayout(vboxLayout1);


        verticalLayout_2->addLayout(hboxLayout4);

        QWidget::setTabOrder(FOVName, tabWidget2);
        QWidget::setTabOrder(tabWidget2, TLength1);
        QWidget::setTabOrder(TLength1, EyeLength);
        QWidget::setTabOrder(EyeLength, EyepieceAFOV);
        QWidget::setTabOrder(EyepieceAFOV, EyeFOV);
        QWidget::setTabOrder(EyeFOV, ComputeTLengthFromFNum1);
        QWidget::setTabOrder(ComputeTLengthFromFNum1, ComputeEyeFOV);
        QWidget::setTabOrder(ComputeEyeFOV, TLength2);
        QWidget::setTabOrder(TLength2, cameraWidth);
        QWidget::setTabOrder(cameraWidth, cameraHeight);
        QWidget::setTabOrder(cameraHeight, cameraPixelSizeW);
        QWidget::setTabOrder(cameraPixelSizeW, cameraPixelSizeH);
        QWidget::setTabOrder(cameraPixelSizeH, ComputeCameraFOV);
        QWidget::setTabOrder(ComputeCameraFOV, DetectFromINDI);
        QWidget::setTabOrder(DetectFromINDI, LinearFOV);
        QWidget::setTabOrder(LinearFOV, LinearFOVDistance);
        QWidget::setTabOrder(LinearFOVDistance, ComputeBinocularFOV);
        QWidget::setTabOrder(ComputeBinocularFOV, RTDiameter);
        QWidget::setTabOrder(RTDiameter, WaveLength);
        QWidget::setTabOrder(WaveLength, ComputeHPBW);
        QWidget::setTabOrder(ComputeHPBW, FOVEditX);
        QWidget::setTabOrder(FOVEditX, FOVEditY);
        QWidget::setTabOrder(FOVEditY, FOVEditOffsetX);
        QWidget::setTabOrder(FOVEditOffsetX, FOVEditOffsetY);
        QWidget::setTabOrder(FOVEditOffsetY, FOVEditRotation);
        QWidget::setTabOrder(FOVEditRotation, ShapeBox);
        QWidget::setTabOrder(ShapeBox, ColorButton);

        retranslateUi(NewFOV);

        tabWidget2->setCurrentIndex(0);


        QMetaObject::connectSlotsByName(NewFOV);
    } // setupUi

    void retranslateUi(QWidget *NewFOV)
    {
        NewFOV->setWindowTitle(tr2i18n("New FOV Indicator", nullptr));
        textLabel1->setText(tr2i18n("<html><head/><body><p><span style=\" font-weight:600;\">Name </span><span style=\" font-weight:600; color:#ff0000;\">*</span><span style=\" font-weight:600;\">:</span></p></body></html>", nullptr));
#if QT_CONFIG(tooltip)
        FOVName->setToolTip(tr2i18n("Name for FOV symbol", nullptr));
#endif // QT_CONFIG(tooltip)
#if QT_CONFIG(whatsthis)
        FOVName->setWhatsThis(tr2i18n("The name of the field-of-view (FOV) symbol.  This name appears in the FOV menu and in the \"Edit FOV Symbols\" tool.", nullptr));
#endif // QT_CONFIG(whatsthis)
        textLabel5->setText(tr2i18n("Telescope focal length:", nullptr));
#if QT_CONFIG(tooltip)
        TLength1->setToolTip(tr2i18n("Telescope focal length, in millimeters", nullptr));
#endif // QT_CONFIG(tooltip)
#if QT_CONFIG(whatsthis)
        TLength1->setWhatsThis(tr2i18n("Enter the telescope focal length, in millimeters.\n"
"\n"
"This is one of the data fields required for defining a field-of-view (FOV) symbol which matches the field-of-view of a telescope eyepiece.", nullptr));
#endif // QT_CONFIG(whatsthis)
        textLabel6_2->setText(tr2i18n("mm", nullptr));
        textLabel7_2->setText(tr2i18n("Eyepiece focal length:", nullptr));
#if QT_CONFIG(tooltip)
        EyeLength->setToolTip(tr2i18n("Eyepiece focal length, in millimeters", nullptr));
#endif // QT_CONFIG(tooltip)
#if QT_CONFIG(whatsthis)
        EyeLength->setWhatsThis(tr2i18n("Enter the eyepiece focal length, in millimeters.\n"
"\n"
"This is one of the data fields required for defining a field-of-view (FOV) symbol which matches the field-of-view of a telescope eyepiece.", nullptr));
#endif // QT_CONFIG(whatsthis)
        textLabel6_2_2->setText(tr2i18n("mm", nullptr));
#if QT_CONFIG(tooltip)
        textLabel8_2->setToolTip(tr2i18n("Enter the eyepiece's Apparent field-of-view", nullptr));
#endif // QT_CONFIG(tooltip)
        textLabel8_2->setText(tr2i18n("Eyepiece AFOV:", nullptr));
#if QT_CONFIG(tooltip)
        EyeFOV->setToolTip(tr2i18n("field-of-view of the eyepiece, in arcminutes", nullptr));
#endif // QT_CONFIG(tooltip)
#if QT_CONFIG(whatsthis)
        EyeFOV->setWhatsThis(tr2i18n("Enter the eyepiece field-of-view angle, in arcminutes.\n"
"\n"
"This is one of the data fields required for defining a field-of-view (FOV) symbol which matches the field-of-view of a telescope eyepiece.", nullptr));
#endif // QT_CONFIG(whatsthis)
        textLabel6_2_2_2->setText(tr2i18n("degrees", nullptr));
        ComputeTLengthFromFNum1->setText(tr2i18n("or compute from F-Number", nullptr));
        label_4->setText(tr2i18n("Note: Panoptic, Nagler, Radian, Delos and Ethos are trademarks of Tele Vue Optics, Inc.", nullptr));
#if QT_CONFIG(tooltip)
        ComputeEyeFOV->setToolTip(tr2i18n("Compute field-of-view from above data fields", nullptr));
#endif // QT_CONFIG(tooltip)
#if QT_CONFIG(whatsthis)
        ComputeEyeFOV->setWhatsThis(tr2i18n("This button will compute the field-of-view (FOV) angle for a specific eyepiece/telescope combination.  You must first specify the focal lengths of the telescope and eyepiece, and the FOV angle of the eyepiece in the above entry fields.\n"
"\n"
"The computed FOV angle (in arcminutes) will be displayed in the \"Field of view\" edit box.", nullptr));
#endif // QT_CONFIG(whatsthis)
        ComputeEyeFOV->setText(tr2i18n("Compute FOV", nullptr));
        tabWidget2->setTabText(tabWidget2->indexOf(tab1), tr2i18n("Eyepiece", nullptr));
        textLabel5_2->setText(tr2i18n("Telescope Focal length:", nullptr));
#if QT_CONFIG(tooltip)
        TLength2->setToolTip(tr2i18n("Telescope focal length, in millimeters", nullptr));
#endif // QT_CONFIG(tooltip)
#if QT_CONFIG(whatsthis)
        TLength2->setWhatsThis(tr2i18n("Enter the telescope focal length, in millimeters.\n"
"\n"
"This is one of the data fields required for defining a field-of-view (FOV) symbol which matches the field-of-view of a camera mounted on a telescope.", nullptr));
#endif // QT_CONFIG(whatsthis)
        textLabel6_2_3->setText(tr2i18n("mm", nullptr));
        label_8->setText(tr2i18n("Camera W:", nullptr));
        label_10->setText(tr2i18n("H:", nullptr));
        label_9->setText(tr2i18n("pixels", nullptr));
        textLabel9->setText(tr2i18n("Pixel W:", nullptr));
#if QT_CONFIG(tooltip)
        cameraPixelSizeW->setToolTip(tr2i18n("Size of chip or film, in millimeters", nullptr));
#endif // QT_CONFIG(tooltip)
#if QT_CONFIG(whatsthis)
        cameraPixelSizeW->setWhatsThis(tr2i18n("Enter the physical size of the CCD chip or film negative.\n"
"\n"
"This is one of the data fields required for defining a field-of-view (FOV) symbol which matches the field-of-view of a camera mounted on a telescope.", nullptr));
#endif // QT_CONFIG(whatsthis)
        label_11->setText(tr2i18n("H:", nullptr));
#if QT_CONFIG(tooltip)
        cameraPixelSizeH->setToolTip(tr2i18n("Size of chip or film, in millimeters", nullptr));
#endif // QT_CONFIG(tooltip)
#if QT_CONFIG(whatsthis)
        cameraPixelSizeH->setWhatsThis(tr2i18n("Enter the physical size of the CCD chip or film negative.\n"
"\n"
"This is one of the data fields required for defining a field-of-view (FOV) symbol which matches the field-of-view of a camera mounted on a telescope.", nullptr));
#endif // QT_CONFIG(whatsthis)
        textLabel6_2_3_2->setText(tr2i18n("\302\265m", nullptr));
#if QT_CONFIG(tooltip)
        ComputeCameraFOV->setToolTip(tr2i18n("Compute field-of-view from above data fields", nullptr));
#endif // QT_CONFIG(tooltip)
#if QT_CONFIG(whatsthis)
        ComputeCameraFOV->setWhatsThis(tr2i18n("This button will compute the field-of-view (FOV) angle for a specific camera/telescope combination.  You must first specify the focal length of the telescope and the size of the CCD chip or film negative.\n"
"\n"
"The computed FOV angle (in arcminutes) will be displayed in the \"Field of view\" edit box.", nullptr));
#endif // QT_CONFIG(whatsthis)
        ComputeCameraFOV->setText(tr2i18n("Compute FOV", nullptr));
        DetectFromINDI->setText(tr2i18n("Detect from Ekos", nullptr));
        tabWidget2->setTabText(tabWidget2->indexOf(tab2), tr2i18n("Camera", nullptr));
        textLabel15_3->setText(tr2i18n("Field of View:", nullptr));
#if QT_CONFIG(tooltip)
        LinearFOV->setToolTip(tr2i18n("Telescope focal length, in millimeters", nullptr));
#endif // QT_CONFIG(tooltip)
#if QT_CONFIG(whatsthis)
        LinearFOV->setWhatsThis(tr2i18n("Enter the telescope focal length, in millimeters.\n"
"\n"
"This is one of the data fields required for defining a field-of-view (FOV) symbol which matches the field-of-view of a camera mounted on a telescope.", nullptr));
#endif // QT_CONFIG(whatsthis)
        LabelUnits->setText(tr2i18n("feet", nullptr));
        textLabel9_31->setText(tr2i18n("At a distance of:", nullptr));
#if QT_CONFIG(tooltip)
        ComputeBinocularFOV->setToolTip(tr2i18n("Compute field-of-view from above data fields", nullptr));
#endif // QT_CONFIG(tooltip)
#if QT_CONFIG(whatsthis)
        ComputeBinocularFOV->setWhatsThis(tr2i18n("This button will compute the field-of-view (FOV) angle for a binocular.  You must specify the linear FOV as mentioned on the binocular.\n"
"\n"
"The computed FOV angle (in arcminutes) will be displayed in the \"Field of view\" edit box.", nullptr));
#endif // QT_CONFIG(whatsthis)
        ComputeBinocularFOV->setText(tr2i18n("Compute FOV", nullptr));
        tabWidget2->setTabText(tabWidget2->indexOf(tab3), tr2i18n("Binocular", nullptr));
        textLabel5_2_3->setText(tr2i18n("Radio Telescope diameter:", nullptr));
#if QT_CONFIG(tooltip)
        RTDiameter->setToolTip(tr2i18n("Telescope focal length, in millimeters", nullptr));
#endif // QT_CONFIG(tooltip)
#if QT_CONFIG(whatsthis)
        RTDiameter->setWhatsThis(tr2i18n("Enter the telescope focal length, in millimeters.\n"
"\n"
"This is one of the data fields required for defining a field-of-view (FOV) symbol which matches the field-of-view of a camera mounted on a telescope.", nullptr));
#endif // QT_CONFIG(whatsthis)
        textLabel6_2_3_4->setText(tr2i18n("m", nullptr));
        textLabel9_3->setText(tr2i18n("Wavelength:", nullptr));
#if QT_CONFIG(tooltip)
        WaveLength->setToolTip(tr2i18n("Size of chip or film, in millimeters", nullptr));
#endif // QT_CONFIG(tooltip)
#if QT_CONFIG(whatsthis)
        WaveLength->setWhatsThis(tr2i18n("Enter the physical size of the CCD chip or film negative.\n"
"\n"
"This is one of the data fields required for defining a field-of-view (FOV) symbol which matches the field-of-view of a camera mounted on a telescope.", nullptr));
#endif // QT_CONFIG(whatsthis)
        textLabel6_2_3_2_3->setText(tr2i18n("cm", nullptr));
#if QT_CONFIG(tooltip)
        ComputeHPBW->setToolTip(tr2i18n("Compute radiotelescope HPBW from above data fields", nullptr));
#endif // QT_CONFIG(tooltip)
#if QT_CONFIG(whatsthis)
        ComputeHPBW->setWhatsThis(tr2i18n("This button will compute the Half Power Beam Width (HPBW) angle for a specific radiotelescope and observing wavelength combination, assuming no multibeam receiver is available at the telescope.  You must first specify the diameter of the radiotelescope and the observing wavelength.\n"
"\n"
"The computed HPBW angle (in arcminutes) will be displayed in the \"Field of view\" edit box.", nullptr));
#endif // QT_CONFIG(whatsthis)
        ComputeHPBW->setText(tr2i18n("Compute HPBW", nullptr));
        tabWidget2->setTabText(tabWidget2->indexOf(tab4), tr2i18n("Radio Telescope", nullptr));
        label_3->setText(tr2i18n("arcmin", nullptr));
        label_6->setText(tr2i18n("arcmin", nullptr));
        label_5->setText(tr2i18n("arcmin", nullptr));
        fieldoFviewLabel->setText(tr2i18n("Field of view:", nullptr));
#if QT_CONFIG(tooltip)
        FOVEditRotation->setToolTip(tr2i18n("<p>Frame rotation with respect to Celestial Pole. Zero degrees indicates that <b>UP</b> is pointing directly at the pole. 90 degrees indicates that <b>UP</b> is rotated 90 degrees clockwise with respect to the pole.</p>", nullptr));
#endif // QT_CONFIG(tooltip)
#if QT_CONFIG(whatsthis)
        FOVEditRotation->setWhatsThis(QString());
#endif // QT_CONFIG(whatsthis)
        FOVEditRotation->setText(tr2i18n("0", nullptr));
        label_2->setText(tr2i18n("arcmin", nullptr));
#if QT_CONFIG(tooltip)
        FOVEditOffsetY->setToolTip(tr2i18n("Desired vertical offset in arcminutes", nullptr));
#endif // QT_CONFIG(tooltip)
#if QT_CONFIG(whatsthis)
        FOVEditOffsetY->setWhatsThis(QString());
#endif // QT_CONFIG(whatsthis)
        FOVEditOffsetY->setText(tr2i18n("0", nullptr));
        fieldoFviewLabel_3->setText(tr2i18n("Offset Y:", nullptr));
        label_7->setText(tr2i18n("Degrees E of N", nullptr));
        fieldoFviewLabel_4->setText(tr2i18n("Rotation:", nullptr));
#if QT_CONFIG(tooltip)
        FOVEditX->setToolTip(tr2i18n("Desired field-of-view size, in arcminutes", nullptr));
#endif // QT_CONFIG(tooltip)
#if QT_CONFIG(whatsthis)
        FOVEditX->setWhatsThis(tr2i18n("Enter the desired angular size for the field-of-view (FOV) symbol.\n"
"\n"
"You can either enter a value directly, or use the \"Eyepiece\" or \"Camera\" Tabs to compute an angular size for specific eyepieces or cameras.", nullptr));
#endif // QT_CONFIG(whatsthis)
        fieldoFviewLabel_2->setText(tr2i18n("Offset X:", nullptr));
        label->setText(tr2i18n(" x ", nullptr));
#if QT_CONFIG(tooltip)
        FOVEditOffsetX->setToolTip(tr2i18n("Desired horizontal offset in arcminutes", nullptr));
#endif // QT_CONFIG(tooltip)
#if QT_CONFIG(whatsthis)
        FOVEditOffsetX->setWhatsThis(QString());
#endif // QT_CONFIG(whatsthis)
        FOVEditOffsetX->setText(tr2i18n("0", nullptr));
#if QT_CONFIG(tooltip)
        FOVLockCP->setToolTip(tr2i18n("Rotation is performed with respect to the celestial pole.", nullptr));
#endif // QT_CONFIG(tooltip)
#if QT_CONFIG(statustip)
        FOVLockCP->setStatusTip(QString());
#endif // QT_CONFIG(statustip)
        FOVLockCP->setText(tr2i18n("Lock to Celestial Pole", nullptr));
#if QT_CONFIG(tooltip)
        ColorButton->setToolTip(tr2i18n("Select color for the field-of-view symbol", nullptr));
#endif // QT_CONFIG(tooltip)
#if QT_CONFIG(whatsthis)
        ColorButton->setWhatsThis(tr2i18n("Select a color for the field-of-view (FOV) symbol.", nullptr));
#endif // QT_CONFIG(whatsthis)
        ColorButton->setText(QString());
        textLabel8->setText(tr2i18n("Color:", nullptr));
        ShapeBox->setItemText(0, tr2i18n("Rectangle", nullptr));
        ShapeBox->setItemText(1, tr2i18n("Circle", nullptr));
        ShapeBox->setItemText(2, tr2i18n("Crosshairs", nullptr));
        ShapeBox->setItemText(3, tr2i18n("Bullseye", nullptr));
        ShapeBox->setItemText(4, tr2i18n("Semitransparent circle", nullptr));

#if QT_CONFIG(tooltip)
        ShapeBox->setToolTip(tr2i18n("Select a shape for the field-of-view symbol", nullptr));
#endif // QT_CONFIG(tooltip)
#if QT_CONFIG(whatsthis)
        ShapeBox->setWhatsThis(tr2i18n("Select a shape for the field-of-view (FOV) symbol.  The possible shapes are:\n"
"\n"
"Circle, Square, Crosshairs, Bullseye.", nullptr));
#endif // QT_CONFIG(whatsthis)
        textLabel7->setText(tr2i18n("Shape:", nullptr));
    } // retranslateUi

};

namespace Ui {
    class NewFOV: public Ui_NewFOV {};
} // namespace Ui

QT_END_NAMESPACE

#endif // NEWFOV_H

