/********************************************************************************
** Form generated from reading UI file 'indihostconf.ui'
**
** Created by: Qt User Interface Compiler version 6.11.1
**
** WARNING! All changes made in this file will be lost when recompiling UI file!
********************************************************************************/

#ifndef UI_INDIHOSTCONF_H
#define UI_INDIHOSTCONF_H

#include <QtCore/QVariant>
#include <QtWidgets/QAbstractButton>
#include <QtWidgets/QApplication>
#include <QtWidgets/QDialog>
#include <QtWidgets/QDialogButtonBox>
#include <QtWidgets/QGridLayout>
#include <QtWidgets/QLabel>
#include <QtWidgets/QLineEdit>
#include <QtWidgets/QSpacerItem>
#include <klocalizedstring.h>

QT_BEGIN_NAMESPACE

class Ui_INDIHostConf
{
public:
    QGridLayout *gridLayout;
    QLabel *textLabel1_3;
    QLineEdit *nameIN;
    QLabel *textLabel1;
    QLineEdit *hostname;
    QLabel *textLabel1_2;
    QLineEdit *portnumber;
    QSpacerItem *spacerItem;
    QDialogButtonBox *buttonBox;

    void setupUi(QDialog *INDIHostConf)
    {
        if (INDIHostConf->objectName().isEmpty())
            INDIHostConf->setObjectName("INDIHostConf");
        INDIHostConf->resize(437, 178);
        INDIHostConf->setSizeGripEnabled(true);
        gridLayout = new QGridLayout(INDIHostConf);
        gridLayout->setObjectName("gridLayout");
        textLabel1_3 = new QLabel(INDIHostConf);
        textLabel1_3->setObjectName("textLabel1_3");

        gridLayout->addWidget(textLabel1_3, 0, 0, 1, 1);

        nameIN = new QLineEdit(INDIHostConf);
        nameIN->setObjectName("nameIN");

        gridLayout->addWidget(nameIN, 0, 1, 1, 1);

        textLabel1 = new QLabel(INDIHostConf);
        textLabel1->setObjectName("textLabel1");

        gridLayout->addWidget(textLabel1, 1, 0, 1, 1);

        hostname = new QLineEdit(INDIHostConf);
        hostname->setObjectName("hostname");

        gridLayout->addWidget(hostname, 1, 1, 1, 1);

        textLabel1_2 = new QLabel(INDIHostConf);
        textLabel1_2->setObjectName("textLabel1_2");

        gridLayout->addWidget(textLabel1_2, 2, 0, 1, 1);

        portnumber = new QLineEdit(INDIHostConf);
        portnumber->setObjectName("portnumber");

        gridLayout->addWidget(portnumber, 2, 1, 1, 1);

        spacerItem = new QSpacerItem(10, 10, QSizePolicy::Policy::Minimum, QSizePolicy::Policy::Expanding);

        gridLayout->addItem(spacerItem, 3, 1, 1, 1);

        buttonBox = new QDialogButtonBox(INDIHostConf);
        buttonBox->setObjectName("buttonBox");
        buttonBox->setStandardButtons(QDialogButtonBox::Cancel|QDialogButtonBox::Ok);

        gridLayout->addWidget(buttonBox, 4, 0, 1, 2);

        QWidget::setTabOrder(nameIN, hostname);
        QWidget::setTabOrder(hostname, portnumber);

        retranslateUi(INDIHostConf);
        QObject::connect(buttonBox, &QDialogButtonBox::accepted, INDIHostConf, qOverload<>(&QDialog::accept));
        QObject::connect(buttonBox, &QDialogButtonBox::rejected, INDIHostConf, qOverload<>(&QDialog::reject));

        QMetaObject::connectSlotsByName(INDIHostConf);
    } // setupUi

    void retranslateUi(QDialog *INDIHostConf)
    {
        textLabel1_3->setText(tr2i18n("Name:", nullptr));
        textLabel1->setText(tr2i18n("Host:", nullptr));
        textLabel1_2->setText(tr2i18n("Port:", nullptr));
        (void)INDIHostConf;
    } // retranslateUi

};

namespace Ui {
    class INDIHostConf: public Ui_INDIHostConf {};
} // namespace Ui

QT_END_NAMESPACE

#endif // INDIHOSTCONF_H

