/********************************************************************************
** Form generated from reading UI file 'catalogdetails.ui'
**
** Created by: Qt User Interface Compiler version 6.11.1
**
** WARNING! All changes made in this file will be lost when recompiling UI file!
********************************************************************************/

#ifndef UI_CATALOGDETAILS_H
#define UI_CATALOGDETAILS_H

#include <QtCore/QVariant>
#include <QtWidgets/QAbstractButton>
#include <QtWidgets/QApplication>
#include <QtWidgets/QDialog>
#include <QtWidgets/QDialogButtonBox>
#include <QtWidgets/QFormLayout>
#include <QtWidgets/QGroupBox>
#include <QtWidgets/QHBoxLayout>
#include <QtWidgets/QHeaderView>
#include <QtWidgets/QLabel>
#include <QtWidgets/QLineEdit>
#include <QtWidgets/QPushButton>
#include <QtWidgets/QSpacerItem>
#include <QtWidgets/QTableView>
#include <QtWidgets/QVBoxLayout>
#include <klocalizedstring.h>

QT_BEGIN_NAMESPACE

class Ui_CatalogDetails
{
public:
    QVBoxLayout *verticalLayout;
    QHBoxLayout *horizontalLayout;
    QVBoxLayout *verticalLayout_4;
    QGroupBox *catalogInfo;
    QFormLayout *formLayout_2;
    QLabel *label;
    QLabel *id;
    QLabel *label_3;
    QLabel *precedence;
    QLabel *label_5;
    QLabel *author;
    QLabel *label_7;
    QLabel *source;
    QLabel *label_9;
    QLabel *description;
    QLabel *label_11;
    QLabel *version;
    QLabel *label_4;
    QLabel *maintainer;
    QLabel *label_6;
    QLabel *license;
    QGroupBox *object_group;
    QVBoxLayout *verticalLayout_3;
    QPushButton *edit_object;
    QPushButton *remove_object;
    QSpacerItem *verticalSpacer;
    QPushButton *edit;
    QPushButton *add_object;
    QPushButton *import_csv;
    QVBoxLayout *verticalLayout_2;
    QLineEdit *name_filter;
    QTableView *object_table;
    QDialogButtonBox *buttonBox;

    void setupUi(QDialog *CatalogDetails)
    {
        if (CatalogDetails->objectName().isEmpty())
            CatalogDetails->setObjectName("CatalogDetails");
        CatalogDetails->resize(987, 583);
        verticalLayout = new QVBoxLayout(CatalogDetails);
        verticalLayout->setObjectName("verticalLayout");
        horizontalLayout = new QHBoxLayout();
        horizontalLayout->setObjectName("horizontalLayout");
        verticalLayout_4 = new QVBoxLayout();
        verticalLayout_4->setObjectName("verticalLayout_4");
        verticalLayout_4->setContentsMargins(0, -1, -1, -1);
        catalogInfo = new QGroupBox(CatalogDetails);
        catalogInfo->setObjectName("catalogInfo");
        catalogInfo->setMinimumSize(QSize(0, 192));
        formLayout_2 = new QFormLayout(catalogInfo);
        formLayout_2->setObjectName("formLayout_2");
        label = new QLabel(catalogInfo);
        label->setObjectName("label");

        formLayout_2->setWidget(0, QFormLayout::ItemRole::LabelRole, label);

        id = new QLabel(catalogInfo);
        id->setObjectName("id");

        formLayout_2->setWidget(0, QFormLayout::ItemRole::FieldRole, id);

        label_3 = new QLabel(catalogInfo);
        label_3->setObjectName("label_3");

        formLayout_2->setWidget(1, QFormLayout::ItemRole::LabelRole, label_3);

        precedence = new QLabel(catalogInfo);
        precedence->setObjectName("precedence");

        formLayout_2->setWidget(1, QFormLayout::ItemRole::FieldRole, precedence);

        label_5 = new QLabel(catalogInfo);
        label_5->setObjectName("label_5");

        formLayout_2->setWidget(2, QFormLayout::ItemRole::LabelRole, label_5);

        author = new QLabel(catalogInfo);
        author->setObjectName("author");

        formLayout_2->setWidget(2, QFormLayout::ItemRole::FieldRole, author);

        label_7 = new QLabel(catalogInfo);
        label_7->setObjectName("label_7");

        formLayout_2->setWidget(4, QFormLayout::ItemRole::LabelRole, label_7);

        source = new QLabel(catalogInfo);
        source->setObjectName("source");

        formLayout_2->setWidget(4, QFormLayout::ItemRole::FieldRole, source);

        label_9 = new QLabel(catalogInfo);
        label_9->setObjectName("label_9");

        formLayout_2->setWidget(5, QFormLayout::ItemRole::LabelRole, label_9);

        description = new QLabel(catalogInfo);
        description->setObjectName("description");
        description->setMaximumSize(QSize(500, 1000));
        description->setTextFormat(Qt::RichText);
        description->setWordWrap(true);

        formLayout_2->setWidget(5, QFormLayout::ItemRole::FieldRole, description);

        label_11 = new QLabel(catalogInfo);
        label_11->setObjectName("label_11");

        formLayout_2->setWidget(6, QFormLayout::ItemRole::LabelRole, label_11);

        version = new QLabel(catalogInfo);
        version->setObjectName("version");

        formLayout_2->setWidget(6, QFormLayout::ItemRole::FieldRole, version);

        label_4 = new QLabel(catalogInfo);
        label_4->setObjectName("label_4");

        formLayout_2->setWidget(3, QFormLayout::ItemRole::LabelRole, label_4);

        maintainer = new QLabel(catalogInfo);
        maintainer->setObjectName("maintainer");

        formLayout_2->setWidget(3, QFormLayout::ItemRole::FieldRole, maintainer);

        label_6 = new QLabel(catalogInfo);
        label_6->setObjectName("label_6");

        formLayout_2->setWidget(8, QFormLayout::ItemRole::LabelRole, label_6);

        license = new QLabel(catalogInfo);
        license->setObjectName("license");

        formLayout_2->setWidget(8, QFormLayout::ItemRole::FieldRole, license);


        verticalLayout_4->addWidget(catalogInfo);

        object_group = new QGroupBox(CatalogDetails);
        object_group->setObjectName("object_group");
        object_group->setEnabled(false);
        verticalLayout_3 = new QVBoxLayout(object_group);
        verticalLayout_3->setObjectName("verticalLayout_3");
        edit_object = new QPushButton(object_group);
        edit_object->setObjectName("edit_object");
        edit_object->setEnabled(false);

        verticalLayout_3->addWidget(edit_object);

        remove_object = new QPushButton(object_group);
        remove_object->setObjectName("remove_object");
        remove_object->setEnabled(false);

        verticalLayout_3->addWidget(remove_object);


        verticalLayout_4->addWidget(object_group);

        verticalSpacer = new QSpacerItem(20, 40, QSizePolicy::Policy::Minimum, QSizePolicy::Policy::Expanding);

        verticalLayout_4->addItem(verticalSpacer);

        edit = new QPushButton(CatalogDetails);
        edit->setObjectName("edit");
        edit->setEnabled(false);

        verticalLayout_4->addWidget(edit);

        add_object = new QPushButton(CatalogDetails);
        add_object->setObjectName("add_object");
        add_object->setEnabled(false);

        verticalLayout_4->addWidget(add_object);

        import_csv = new QPushButton(CatalogDetails);
        import_csv->setObjectName("import_csv");
        import_csv->setEnabled(false);

        verticalLayout_4->addWidget(import_csv);


        horizontalLayout->addLayout(verticalLayout_4);

        verticalLayout_2 = new QVBoxLayout();
        verticalLayout_2->setObjectName("verticalLayout_2");
        verticalLayout_2->setContentsMargins(0, -1, -1, -1);
        name_filter = new QLineEdit(CatalogDetails);
        name_filter->setObjectName("name_filter");

        verticalLayout_2->addWidget(name_filter);

        object_table = new QTableView(CatalogDetails);
        object_table->setObjectName("object_table");

        verticalLayout_2->addWidget(object_table);


        horizontalLayout->addLayout(verticalLayout_2);


        verticalLayout->addLayout(horizontalLayout);

        buttonBox = new QDialogButtonBox(CatalogDetails);
        buttonBox->setObjectName("buttonBox");
        buttonBox->setOrientation(Qt::Horizontal);
        buttonBox->setStandardButtons(QDialogButtonBox::Cancel|QDialogButtonBox::Ok);

        verticalLayout->addWidget(buttonBox);


        retranslateUi(CatalogDetails);
        QObject::connect(buttonBox, &QDialogButtonBox::accepted, CatalogDetails, qOverload<>(&QDialog::accept));
        QObject::connect(buttonBox, &QDialogButtonBox::rejected, CatalogDetails, qOverload<>(&QDialog::reject));

        QMetaObject::connectSlotsByName(CatalogDetails);
    } // setupUi

    void retranslateUi(QDialog *CatalogDetails)
    {
        CatalogDetails->setWindowTitle(tr2i18n("Catalog Details", nullptr));
        catalogInfo->setTitle(tr2i18n("Info", nullptr));
        label->setText(tr2i18n("ID:", nullptr));
        id->setText(tr2i18n("_id", nullptr));
        label_3->setText(tr2i18n("Prec:", nullptr));
        precedence->setText(tr2i18n("_prec", nullptr));
        label_5->setText(tr2i18n("Author:", nullptr));
        author->setText(tr2i18n("_auth", nullptr));
        label_7->setText(tr2i18n("Source:", nullptr));
        source->setText(tr2i18n("_src", nullptr));
        label_9->setText(tr2i18n("Desc:", nullptr));
        description->setText(tr2i18n("_desc", nullptr));
        label_11->setText(tr2i18n("Version:", nullptr));
        version->setText(tr2i18n("_vers", nullptr));
        label_4->setText(tr2i18n("Maintainer:", nullptr));
        maintainer->setText(tr2i18n("_maint", nullptr));
        label_6->setText(tr2i18n("License:", nullptr));
        license->setText(tr2i18n("_lic", nullptr));
        object_group->setTitle(tr2i18n("Object", nullptr));
        edit_object->setText(tr2i18n("Edit...", nullptr));
        remove_object->setText(tr2i18n("Remove", nullptr));
        edit->setText(tr2i18n("Edit Catalog Meta...", nullptr));
        add_object->setText(tr2i18n("Add Object...", nullptr));
        import_csv->setText(tr2i18n("Import CSV...", nullptr));
#if QT_CONFIG(tooltip)
        name_filter->setToolTip(tr2i18n("Filter by Name", nullptr));
#endif // QT_CONFIG(tooltip)
    } // retranslateUi

};

namespace Ui {
    class CatalogDetails: public Ui_CatalogDetails {};
} // namespace Ui

QT_END_NAMESPACE

#endif // CATALOGDETAILS_H

