/********************************************************************************
** Form generated from reading UI file 'opssatellites.ui'
**
** Created by: Qt User Interface Compiler version 6.11.1
**
** WARNING! All changes made in this file will be lost when recompiling UI file!
********************************************************************************/

#ifndef UI_OPSSATELLITES_H
#define UI_OPSSATELLITES_H

#include <QtCore/QVariant>
#include <QtWidgets/QApplication>
#include <QtWidgets/QButtonGroup>
#include <QtWidgets/QCheckBox>
#include <QtWidgets/QGridLayout>
#include <QtWidgets/QGroupBox>
#include <QtWidgets/QHBoxLayout>
#include <QtWidgets/QHeaderView>
#include <QtWidgets/QLineEdit>
#include <QtWidgets/QPushButton>
#include <QtWidgets/QTreeView>
#include <QtWidgets/QVBoxLayout>
#include <QtWidgets/QWidget>
#include <klocalizedstring.h>

QT_BEGIN_NAMESPACE

class Ui_OpsSatellites
{
public:
    QGridLayout *gridLayout;
    QVBoxLayout *verticalLayout;
    QGroupBox *groupBox_2;
    QVBoxLayout *verticalLayout_3;
    QHBoxLayout *horizontalLayout;
    QCheckBox *kcfg_ShowSatellites;
    QCheckBox *kcfg_ShowVisibleSatellites;
    QHBoxLayout *horizontalLayout_2;
    QCheckBox *kcfg_ShowSatellitesLabels;
    QCheckBox *kcfg_DrawSatellitesLikeStars;
    QGroupBox *groupBox;
    QVBoxLayout *verticalLayout_2;
    QHBoxLayout *horizontalLayout_3;
    QLineEdit *FilterEdit;
    QPushButton *UpdateTLEButton;
    QTreeView *SatListTreeView;
    QButtonGroup *satelliteButtonGroup;

    void setupUi(QWidget *OpsSatellites)
    {
        if (OpsSatellites->objectName().isEmpty())
            OpsSatellites->setObjectName("OpsSatellites");
        OpsSatellites->resize(533, 575);
        gridLayout = new QGridLayout(OpsSatellites);
        gridLayout->setObjectName("gridLayout");
        verticalLayout = new QVBoxLayout();
        verticalLayout->setObjectName("verticalLayout");
        groupBox_2 = new QGroupBox(OpsSatellites);
        groupBox_2->setObjectName("groupBox_2");
        verticalLayout_3 = new QVBoxLayout(groupBox_2);
        verticalLayout_3->setObjectName("verticalLayout_3");
        horizontalLayout = new QHBoxLayout();
        horizontalLayout->setObjectName("horizontalLayout");
        horizontalLayout->setSizeConstraint(QLayout::SetDefaultConstraint);
        kcfg_ShowSatellites = new QCheckBox(groupBox_2);
        satelliteButtonGroup = new QButtonGroup(OpsSatellites);
        satelliteButtonGroup->setObjectName("satelliteButtonGroup");
        satelliteButtonGroup->setExclusive(false);
        satelliteButtonGroup->addButton(kcfg_ShowSatellites);
        kcfg_ShowSatellites->setObjectName("kcfg_ShowSatellites");

        horizontalLayout->addWidget(kcfg_ShowSatellites);

        kcfg_ShowVisibleSatellites = new QCheckBox(groupBox_2);
        satelliteButtonGroup->addButton(kcfg_ShowVisibleSatellites);
        kcfg_ShowVisibleSatellites->setObjectName("kcfg_ShowVisibleSatellites");

        horizontalLayout->addWidget(kcfg_ShowVisibleSatellites);


        verticalLayout_3->addLayout(horizontalLayout);

        horizontalLayout_2 = new QHBoxLayout();
        horizontalLayout_2->setObjectName("horizontalLayout_2");
        kcfg_ShowSatellitesLabels = new QCheckBox(groupBox_2);
        satelliteButtonGroup->addButton(kcfg_ShowSatellitesLabels);
        kcfg_ShowSatellitesLabels->setObjectName("kcfg_ShowSatellitesLabels");

        horizontalLayout_2->addWidget(kcfg_ShowSatellitesLabels);

        kcfg_DrawSatellitesLikeStars = new QCheckBox(groupBox_2);
        satelliteButtonGroup->addButton(kcfg_DrawSatellitesLikeStars);
        kcfg_DrawSatellitesLikeStars->setObjectName("kcfg_DrawSatellitesLikeStars");

        horizontalLayout_2->addWidget(kcfg_DrawSatellitesLikeStars);


        verticalLayout_3->addLayout(horizontalLayout_2);


        verticalLayout->addWidget(groupBox_2);

        groupBox = new QGroupBox(OpsSatellites);
        groupBox->setObjectName("groupBox");
        verticalLayout_2 = new QVBoxLayout(groupBox);
        verticalLayout_2->setObjectName("verticalLayout_2");
        horizontalLayout_3 = new QHBoxLayout();
        horizontalLayout_3->setObjectName("horizontalLayout_3");
        FilterEdit = new QLineEdit(groupBox);
        FilterEdit->setObjectName("FilterEdit");
        FilterEdit->setProperty("showClearButton", QVariant(true));

        horizontalLayout_3->addWidget(FilterEdit);

        UpdateTLEButton = new QPushButton(groupBox);
        UpdateTLEButton->setObjectName("UpdateTLEButton");
        QSizePolicy sizePolicy(QSizePolicy::Policy::Fixed, QSizePolicy::Policy::Fixed);
        sizePolicy.setHorizontalStretch(0);
        sizePolicy.setVerticalStretch(0);
        sizePolicy.setHeightForWidth(UpdateTLEButton->sizePolicy().hasHeightForWidth());
        UpdateTLEButton->setSizePolicy(sizePolicy);

        horizontalLayout_3->addWidget(UpdateTLEButton);


        verticalLayout_2->addLayout(horizontalLayout_3);

        SatListTreeView = new QTreeView(groupBox);
        SatListTreeView->setObjectName("SatListTreeView");

        verticalLayout_2->addWidget(SatListTreeView);


        verticalLayout->addWidget(groupBox);


        gridLayout->addLayout(verticalLayout, 1, 0, 1, 1);


        retranslateUi(OpsSatellites);

        QMetaObject::connectSlotsByName(OpsSatellites);
    } // setupUi

    void retranslateUi(QWidget *OpsSatellites)
    {
        groupBox_2->setTitle(tr2i18n("View Options", nullptr));
        kcfg_ShowSatellites->setText(tr2i18n("Show satellites", nullptr));
        kcfg_ShowVisibleSatellites->setText(tr2i18n("Show only visible satellites", nullptr));
        kcfg_ShowSatellitesLabels->setText(tr2i18n("Show labels", nullptr));
        kcfg_DrawSatellitesLikeStars->setText(tr2i18n("Draw satellites like stars", nullptr));
        groupBox->setTitle(tr2i18n("List of Satellites", nullptr));
        FilterEdit->setPlaceholderText(tr2i18n("Search satellites", nullptr));
        UpdateTLEButton->setText(tr2i18n("Update TLEs", nullptr));
        (void)OpsSatellites;
    } // retranslateUi

};

namespace Ui {
    class OpsSatellites: public Ui_OpsSatellites {};
} // namespace Ui

QT_END_NAMESPACE

#endif // OPSSATELLITES_H

