/********************************************************************************
** Form generated from reading UI file 'modcalcsimple.ui'
**
** Created by: Qt User Interface Compiler version 6.11.1
**
** WARNING! All changes made in this file will be lost when recompiling UI file!
********************************************************************************/

#ifndef UI_MODCALCSIMPLE_H
#define UI_MODCALCSIMPLE_H

#include <QtCore/QVariant>
#include <QtWidgets/QApplication>
#include <QtWidgets/QGridLayout>
#include <QtWidgets/QGroupBox>
#include <QtWidgets/QHBoxLayout>
#include <QtWidgets/QLabel>
#include <QtWidgets/QLineEdit>
#include <QtWidgets/QSpacerItem>
#include <QtWidgets/QTabWidget>
#include <QtWidgets/QVBoxLayout>
#include <QtWidgets/QWidget>
#include <klocalizedstring.h>
#include "widgets/dmsbox.h"

QT_BEGIN_NAMESPACE

class Ui_modCalcSimple
{
public:
    QVBoxLayout *vboxLayout;
    QTabWidget *tabWidget3;
    QWidget *interact;
    QVBoxLayout *vboxLayout1;
    QSpacerItem *spacerItem;
    QHBoxLayout *boxLayout1;
    QGroupBox *groupBox1a;
    QGridLayout *gridLayout;
    dmsBox *angle1Input;
    QLabel *angle1aLabel;
    QGroupBox *groupBox1b;
    QHBoxLayout *horizontalLayout_2;
    QLabel *angle1bLabel;
    QLineEdit *angle1Result;
    QSpacerItem *spacer;
    QHBoxLayout *boxlLayout2;
    QGroupBox *groupBox2a;
    QHBoxLayout *horizontalLayout_3;
    QLabel *angle2aLabel;
    dmsBox *angle2Input;
    QGroupBox *groupBox2b;
    QHBoxLayout *horizontalLayout;
    QLabel *angle2Label;
    QLineEdit *angle2Result;
    QSpacerItem *spacerItem1;

    void setupUi(QWidget *modCalcSimple)
    {
        if (modCalcSimple->objectName().isEmpty())
            modCalcSimple->setObjectName("modCalcSimple");
        modCalcSimple->setEnabled(true);
        modCalcSimple->resize(528, 544);
        vboxLayout = new QVBoxLayout(modCalcSimple);
        vboxLayout->setSpacing(6);
        vboxLayout->setObjectName("vboxLayout");
        vboxLayout->setContentsMargins(9, 9, 9, 9);
        tabWidget3 = new QTabWidget(modCalcSimple);
        tabWidget3->setObjectName("tabWidget3");
        interact = new QWidget();
        interact->setObjectName("interact");
        vboxLayout1 = new QVBoxLayout(interact);
        vboxLayout1->setSpacing(6);
        vboxLayout1->setObjectName("vboxLayout1");
        vboxLayout1->setContentsMargins(9, 9, 9, 9);
        spacerItem = new QSpacerItem(411, 20, QSizePolicy::Policy::Expanding, QSizePolicy::Policy::Minimum);

        vboxLayout1->addItem(spacerItem);

        boxLayout1 = new QHBoxLayout();
        boxLayout1->setSpacing(6);
        boxLayout1->setObjectName("boxLayout1");
        boxLayout1->setContentsMargins(0, 0, 0, 0);
        groupBox1a = new QGroupBox(interact);
        groupBox1a->setObjectName("groupBox1a");
        gridLayout = new QGridLayout(groupBox1a);
        gridLayout->setSpacing(6);
        gridLayout->setObjectName("gridLayout");
        gridLayout->setContentsMargins(9, 9, 9, 9);
        angle1Input = new dmsBox(groupBox1a);
        angle1Input->setObjectName("angle1Input");
        angle1Input->setEnabled(true);
        angle1Input->setMinimumSize(QSize(100, 0));
        angle1Input->setFocusPolicy(Qt::StrongFocus);

        gridLayout->addWidget(angle1Input, 0, 1, 1, 1);

        angle1aLabel = new QLabel(groupBox1a);
        angle1aLabel->setObjectName("angle1aLabel");

        gridLayout->addWidget(angle1aLabel, 0, 0, 1, 1);


        boxLayout1->addWidget(groupBox1a);

        groupBox1b = new QGroupBox(interact);
        groupBox1b->setObjectName("groupBox1b");
        horizontalLayout_2 = new QHBoxLayout(groupBox1b);
        horizontalLayout_2->setObjectName("horizontalLayout_2");
        angle1bLabel = new QLabel(groupBox1b);
        angle1bLabel->setObjectName("angle1bLabel");

        horizontalLayout_2->addWidget(angle1bLabel);

        angle1Result = new QLineEdit(groupBox1b);
        angle1Result->setObjectName("angle1Result");
        angle1Result->setReadOnly(true);

        horizontalLayout_2->addWidget(angle1Result);


        boxLayout1->addWidget(groupBox1b);

        boxLayout1->setStretch(0, 1);
        boxLayout1->setStretch(1, 1);

        vboxLayout1->addLayout(boxLayout1);

        spacer = new QSpacerItem(40, 20, QSizePolicy::Policy::Expanding, QSizePolicy::Policy::Minimum);

        vboxLayout1->addItem(spacer);

        boxlLayout2 = new QHBoxLayout();
        boxlLayout2->setSpacing(6);
        boxlLayout2->setObjectName("boxlLayout2");
        groupBox2a = new QGroupBox(interact);
        groupBox2a->setObjectName("groupBox2a");
        horizontalLayout_3 = new QHBoxLayout(groupBox2a);
        horizontalLayout_3->setObjectName("horizontalLayout_3");
        angle2aLabel = new QLabel(groupBox2a);
        angle2aLabel->setObjectName("angle2aLabel");

        horizontalLayout_3->addWidget(angle2aLabel);

        angle2Input = new dmsBox(groupBox2a);
        angle2Input->setObjectName("angle2Input");
        angle2Input->setEnabled(true);
        angle2Input->setMinimumSize(QSize(100, 0));
        angle2Input->setFocusPolicy(Qt::StrongFocus);

        horizontalLayout_3->addWidget(angle2Input);


        boxlLayout2->addWidget(groupBox2a);

        groupBox2b = new QGroupBox(interact);
        groupBox2b->setObjectName("groupBox2b");
        horizontalLayout = new QHBoxLayout(groupBox2b);
        horizontalLayout->setObjectName("horizontalLayout");
        angle2Label = new QLabel(groupBox2b);
        angle2Label->setObjectName("angle2Label");
        angle2Label->setTextInteractionFlags(Qt::LinksAccessibleByMouse|Qt::TextSelectableByKeyboard|Qt::TextSelectableByMouse);

        horizontalLayout->addWidget(angle2Label);

        angle2Result = new QLineEdit(groupBox2b);
        angle2Result->setObjectName("angle2Result");
        angle2Result->setReadOnly(true);

        horizontalLayout->addWidget(angle2Result);


        boxlLayout2->addWidget(groupBox2b);

        boxlLayout2->setStretch(0, 1);
        boxlLayout2->setStretch(1, 1);

        vboxLayout1->addLayout(boxlLayout2);

        spacerItem1 = new QSpacerItem(20, 37, QSizePolicy::Policy::Minimum, QSizePolicy::Policy::Expanding);

        vboxLayout1->addItem(spacerItem1);

        tabWidget3->addTab(interact, QString());

        vboxLayout->addWidget(tabWidget3);


        retranslateUi(modCalcSimple);

        tabWidget3->setCurrentIndex(0);


        QMetaObject::connectSlotsByName(modCalcSimple);
    } // setupUi

    void retranslateUi(QWidget *modCalcSimple)
    {
        modCalcSimple->setWindowTitle(tr2i18n("Horizontal Coordinates", nullptr));
        groupBox1a->setTitle(tr2i18n("Angle", nullptr));
        angle1aLabel->setText(tr2i18n("Angle (hh mm ss.s) ", nullptr));
        groupBox1b->setTitle(tr2i18n("Angle Result", nullptr));
        angle1bLabel->setText(tr2i18n("Angle (dd.d)", nullptr));
        groupBox2a->setTitle(tr2i18n("Angle", nullptr));
        angle2aLabel->setText(tr2i18n("Angle (dd mm ss.s)", nullptr));
        groupBox2b->setTitle(tr2i18n("Angle Result", nullptr));
        angle2Label->setText(tr2i18n("Angle (dd.d)", nullptr));
        tabWidget3->setTabText(tabWidget3->indexOf(interact), tr2i18n("Interactive Mode", nullptr));
    } // retranslateUi

};

namespace Ui {
    class modCalcSimple: public Ui_modCalcSimple {};
} // namespace Ui

QT_END_NAMESPACE

#endif // MODCALCSIMPLE_H

