/********************************************************************************
** Form generated from reading UI file 'wizdownload.ui'
**
** Created by: Qt User Interface Compiler version 6.11.1
**
** WARNING! All changes made in this file will be lost when recompiling UI file!
********************************************************************************/

#ifndef UI_WIZDOWNLOAD_H
#define UI_WIZDOWNLOAD_H

#include <QtCore/QVariant>
#include <QtWidgets/QApplication>
#include <QtWidgets/QHBoxLayout>
#include <QtWidgets/QLabel>
#include <QtWidgets/QPushButton>
#include <QtWidgets/QSpacerItem>
#include <QtWidgets/QVBoxLayout>
#include <QtWidgets/QWidget>
#include <klocalizedstring.h>

QT_BEGIN_NAMESPACE

class Ui_WizDownload
{
public:
    QHBoxLayout *hboxLayout;
    QLabel *Banner;
    QVBoxLayout *vboxLayout;
    QLabel *DownloadTitle;
    QSpacerItem *spacerItem;
    QLabel *DownloadText;
    QSpacerItem *spacerItem1;
    QHBoxLayout *hboxLayout1;
    QSpacerItem *spacerItem2;
    QPushButton *DownloadButton;
    QSpacerItem *spacerItem3;
    QSpacerItem *spacerItem4;

    void setupUi(QWidget *WizDownload)
    {
        if (WizDownload->objectName().isEmpty())
            WizDownload->setObjectName("WizDownload");
        WizDownload->resize(586, 395);
        hboxLayout = new QHBoxLayout(WizDownload);
#ifndef UI_Q_OS_MAC
        hboxLayout->setSpacing(6);
#endif
        hboxLayout->setContentsMargins(8, 8, 8, 8);
        hboxLayout->setObjectName("hboxLayout");
        Banner = new QLabel(WizDownload);
        Banner->setObjectName("Banner");
        QSizePolicy sizePolicy(QSizePolicy::Policy::Fixed, QSizePolicy::Policy::Fixed);
        sizePolicy.setHorizontalStretch(0);
        sizePolicy.setVerticalStretch(0);
        sizePolicy.setHeightForWidth(Banner->sizePolicy().hasHeightForWidth());
        Banner->setSizePolicy(sizePolicy);
        Banner->setMinimumSize(QSize(120, 360));

        hboxLayout->addWidget(Banner);

        vboxLayout = new QVBoxLayout();
#ifndef UI_Q_OS_MAC
        vboxLayout->setSpacing(6);
#endif
        vboxLayout->setContentsMargins(0, 0, 0, 0);
        vboxLayout->setObjectName("vboxLayout");
        DownloadTitle = new QLabel(WizDownload);
        DownloadTitle->setObjectName("DownloadTitle");
        QFont font;
        font.setFamilies({QString::fromUtf8("Sans Serif")});
        font.setPointSize(11);
        font.setBold(true);
        font.setItalic(false);
        font.setUnderline(false);
        font.setStrikeOut(false);
        DownloadTitle->setFont(font);

        vboxLayout->addWidget(DownloadTitle);

        spacerItem = new QSpacerItem(440, 16, QSizePolicy::Policy::Minimum, QSizePolicy::Policy::Fixed);

        vboxLayout->addItem(spacerItem);

        DownloadText = new QLabel(WizDownload);
        DownloadText->setObjectName("DownloadText");
        DownloadText->setWordWrap(true);

        vboxLayout->addWidget(DownloadText);

        spacerItem1 = new QSpacerItem(440, 41, QSizePolicy::Policy::Minimum, QSizePolicy::Policy::Expanding);

        vboxLayout->addItem(spacerItem1);

        hboxLayout1 = new QHBoxLayout();
#ifndef UI_Q_OS_MAC
        hboxLayout1->setSpacing(6);
#endif
        hboxLayout1->setContentsMargins(0, 0, 0, 0);
        hboxLayout1->setObjectName("hboxLayout1");
        spacerItem2 = new QSpacerItem(40, 20, QSizePolicy::Policy::Expanding, QSizePolicy::Policy::Minimum);

        hboxLayout1->addItem(spacerItem2);

        DownloadButton = new QPushButton(WizDownload);
        DownloadButton->setObjectName("DownloadButton");

        hboxLayout1->addWidget(DownloadButton);

        spacerItem3 = new QSpacerItem(40, 20, QSizePolicy::Policy::Expanding, QSizePolicy::Policy::Minimum);

        hboxLayout1->addItem(spacerItem3);


        vboxLayout->addLayout(hboxLayout1);

        spacerItem4 = new QSpacerItem(440, 41, QSizePolicy::Policy::Minimum, QSizePolicy::Policy::Expanding);

        vboxLayout->addItem(spacerItem4);


        hboxLayout->addLayout(vboxLayout);


        retranslateUi(WizDownload);

        QMetaObject::connectSlotsByName(WizDownload);
    } // setupUi

    void retranslateUi(QWidget *WizDownload)
    {
        Banner->setText(QString());
        DownloadTitle->setText(tr2i18n("Download Extra Data Files", nullptr));
        DownloadText->setText(tr2i18n("<p>You may now download optional data files to enhance KStars, such as Messier object images, or a more complete NGC/IC catalog. Press the <b>Download Extra Data</b> button to proceed. </p><p>You can also use this tool later, by selecting <b>Download New Data</b> from the <b>File</b> menu.</p>", nullptr));
        DownloadButton->setText(tr2i18n("Download Extra Data...", nullptr));
        (void)WizDownload;
    } // retranslateUi

};

namespace Ui {
    class WizDownload: public Ui_WizDownload {};
} // namespace Ui

QT_END_NAMESPACE

#endif // WIZDOWNLOAD_H

