/****************************************************************************
** Meta object code from reading C++ file 'indicamera.h'
**
** Created by: The Qt Meta Object Compiler version 69 (Qt 6.11.1)
**
** WARNING! All changes made in this file will be lost!
*****************************************************************************/

#include "../../../../kstars-3.8.4.1/kstars/indi/indicamera.h"
#include <QtNetwork/QSslError>
#include <QtDataVisualization/qbar3dseries.h>
#include <QtDataVisualization/q3dscene.h>
#include <QtGui/qtextcursor.h>
#include <QtCore/qmetatype.h>
#include <QtCore/QSharedPointer>

#include <QtCore/qtmochelpers.h>

#include <memory>


#include <QtCore/qxptype_traits.h>
#if !defined(Q_MOC_OUTPUT_REVISION)
#error "The header file 'indicamera.h' doesn't include <QObject>."
#elif Q_MOC_OUTPUT_REVISION != 69
#error "This file was generated using the moc from 6.11.1. It"
#error "cannot be used with the include files from this version of Qt."
#error "(The moc has changed too much.)"
#endif

#ifndef Q_CONSTINIT
#define Q_CONSTINIT
#endif

QT_WARNING_PUSH
QT_WARNING_DISABLE_DEPRECATED
QT_WARNING_DISABLE_GCC("-Wuseless-cast")
namespace {
struct qt_meta_tag_ZN3ISD6CameraE_t {};
} // unnamed namespace

template <> constexpr inline auto ISD::Camera::qt_create_metaobjectdata<qt_meta_tag_ZN3ISD6CameraE_t>()
{
    namespace QMC = QtMocConstants;
    QtMocHelpers::StringRefStorage qt_stringData {
        "ISD::Camera",
        "newTemperatureValue",
        "",
        "value",
        "newExposureValue",
        "ISD::CameraChip*",
        "chip",
        "IPState",
        "state",
        "newGuideStarData",
        "dx",
        "dy",
        "fit",
        "newBLOBManager",
        "INDI::Property",
        "prop",
        "newRemoteFile",
        "coolerToggled",
        "enabled",
        "error",
        "ErrorType",
        "type",
        "updateVideoWindow",
        "width",
        "height",
        "streamEnabled",
        "closeVideoWindow",
        "videoStreamToggled",
        "showVideoFrame",
        "videoRecordToggled",
        "newFPS",
        "instantFPS",
        "averageFPS",
        "newVideoFrame",
        "QSharedPointer<QImage>",
        "frame",
        "newImage",
        "QSharedPointer<FITSData>",
        "data",
        "extension",
        "newView",
        "QSharedPointer<FITSView>",
        "view",
        "StreamWindowHidden",
        "setBLOBManager",
        "const char*",
        "device",
        "setWSBLOB",
        "message",
        "StreamingEnabled"
    };

    QtMocHelpers::UintData qt_methods {
        // Signal 'newTemperatureValue'
        QtMocHelpers::SignalData<void(double)>(1, 2, QMC::AccessPublic, QMetaType::Void, {{
            { QMetaType::Double, 3 },
        }}),
        // Signal 'newExposureValue'
        QtMocHelpers::SignalData<void(ISD::CameraChip *, double, IPState)>(4, 2, QMC::AccessPublic, QMetaType::Void, {{
            { 0x80000000 | 5, 6 }, { QMetaType::Double, 3 }, { 0x80000000 | 7, 8 },
        }}),
        // Signal 'newGuideStarData'
        QtMocHelpers::SignalData<void(ISD::CameraChip *, double, double, double)>(9, 2, QMC::AccessPublic, QMetaType::Void, {{
            { 0x80000000 | 5, 6 }, { QMetaType::Double, 10 }, { QMetaType::Double, 11 }, { QMetaType::Double, 12 },
        }}),
        // Signal 'newBLOBManager'
        QtMocHelpers::SignalData<void(INDI::Property)>(13, 2, QMC::AccessPublic, QMetaType::Void, {{
            { 0x80000000 | 14, 15 },
        }}),
        // Signal 'newRemoteFile'
        QtMocHelpers::SignalData<void(QString)>(16, 2, QMC::AccessPublic, QMetaType::Void, {{
            { QMetaType::QString, 2 },
        }}),
        // Signal 'coolerToggled'
        QtMocHelpers::SignalData<void(bool)>(17, 2, QMC::AccessPublic, QMetaType::Void, {{
            { QMetaType::Bool, 18 },
        }}),
        // Signal 'error'
        QtMocHelpers::SignalData<void(ErrorType)>(19, 2, QMC::AccessPublic, QMetaType::Void, {{
            { 0x80000000 | 20, 21 },
        }}),
        // Signal 'updateVideoWindow'
        QtMocHelpers::SignalData<void(int, int, bool)>(22, 2, QMC::AccessPublic, QMetaType::Void, {{
            { QMetaType::Int, 23 }, { QMetaType::Int, 24 }, { QMetaType::Bool, 25 },
        }}),
        // Signal 'closeVideoWindow'
        QtMocHelpers::SignalData<void()>(26, 2, QMC::AccessPublic, QMetaType::Void),
        // Signal 'videoStreamToggled'
        QtMocHelpers::SignalData<void(bool)>(27, 2, QMC::AccessPublic, QMetaType::Void, {{
            { QMetaType::Bool, 18 },
        }}),
        // Signal 'showVideoFrame'
        QtMocHelpers::SignalData<void(INDI::Property, int, int)>(28, 2, QMC::AccessPublic, QMetaType::Void, {{
            { 0x80000000 | 14, 15 }, { QMetaType::Int, 23 }, { QMetaType::Int, 24 },
        }}),
        // Signal 'videoRecordToggled'
        QtMocHelpers::SignalData<void(bool)>(29, 2, QMC::AccessPublic, QMetaType::Void, {{
            { QMetaType::Bool, 18 },
        }}),
        // Signal 'newFPS'
        QtMocHelpers::SignalData<void(double, double)>(30, 2, QMC::AccessPublic, QMetaType::Void, {{
            { QMetaType::Double, 31 }, { QMetaType::Double, 32 },
        }}),
        // Signal 'newVideoFrame'
        QtMocHelpers::SignalData<void(const QSharedPointer<QImage> &)>(33, 2, QMC::AccessPublic, QMetaType::Void, {{
            { 0x80000000 | 34, 35 },
        }}),
        // Signal 'newImage'
        QtMocHelpers::SignalData<void(const QSharedPointer<FITSData> &, const QString &)>(36, 2, QMC::AccessPublic, QMetaType::Void, {{
            { 0x80000000 | 37, 38 }, { QMetaType::QString, 39 },
        }}),
        // Signal 'newImage'
        QtMocHelpers::SignalData<void(const QSharedPointer<FITSData> &)>(36, 2, QMC::AccessPublic | QMC::MethodCloned, QMetaType::Void, {{
            { 0x80000000 | 37, 38 },
        }}),
        // Signal 'newView'
        QtMocHelpers::SignalData<void(const QSharedPointer<FITSView> &)>(40, 2, QMC::AccessPublic, QMetaType::Void, {{
            { 0x80000000 | 41, 42 },
        }}),
        // Slot 'StreamWindowHidden'
        QtMocHelpers::SlotData<void()>(43, 2, QMC::AccessPublic, QMetaType::Void),
        // Slot 'setBLOBManager'
        QtMocHelpers::SlotData<void(const char *, INDI::Property)>(44, 2, QMC::AccessPublic, QMetaType::Void, {{
            { 0x80000000 | 45, 46 }, { 0x80000000 | 14, 15 },
        }}),
        // Slot 'setWSBLOB'
        QtMocHelpers::SlotData<void(const QByteArray &, const QString &)>(47, 2, QMC::AccessProtected, QMetaType::Void, {{
            { QMetaType::QByteArray, 48 }, { QMetaType::QString, 39 },
        }}),
    };
    QtMocHelpers::UintData qt_properties {
        // property 'StreamingEnabled'
        QtMocHelpers::PropertyData<bool>(49, QMetaType::Bool, QMC::DefaultPropertyFlags | QMC::Writable),
    };
    QtMocHelpers::UintData qt_enums {
    };
    return QtMocHelpers::metaObjectData<Camera, qt_meta_tag_ZN3ISD6CameraE_t>(QMC::MetaObjectFlag{}, qt_stringData,
            qt_methods, qt_properties, qt_enums);
}
Q_CONSTINIT const QMetaObject ISD::Camera::staticMetaObject = { {
    QMetaObject::SuperData::link<ConcreteDevice::staticMetaObject>(),
    qt_staticMetaObjectStaticContent<qt_meta_tag_ZN3ISD6CameraE_t>.stringdata,
    qt_staticMetaObjectStaticContent<qt_meta_tag_ZN3ISD6CameraE_t>.data,
    qt_static_metacall,
    nullptr,
    qt_staticMetaObjectRelocatingContent<qt_meta_tag_ZN3ISD6CameraE_t>.metaTypes,
    nullptr
} };

void ISD::Camera::qt_static_metacall(QObject *_o, QMetaObject::Call _c, int _id, void **_a)
{
    auto *_t = static_cast<Camera *>(_o);
    if (_c == QMetaObject::InvokeMetaMethod) {
        switch (_id) {
        case 0: _t->newTemperatureValue((*reinterpret_cast<std::add_pointer_t<double>>(_a[1]))); break;
        case 1: _t->newExposureValue((*reinterpret_cast<std::add_pointer_t<ISD::CameraChip*>>(_a[1])),(*reinterpret_cast<std::add_pointer_t<double>>(_a[2])),(*reinterpret_cast<std::add_pointer_t<IPState>>(_a[3]))); break;
        case 2: _t->newGuideStarData((*reinterpret_cast<std::add_pointer_t<ISD::CameraChip*>>(_a[1])),(*reinterpret_cast<std::add_pointer_t<double>>(_a[2])),(*reinterpret_cast<std::add_pointer_t<double>>(_a[3])),(*reinterpret_cast<std::add_pointer_t<double>>(_a[4]))); break;
        case 3: _t->newBLOBManager((*reinterpret_cast<std::add_pointer_t<INDI::Property>>(_a[1]))); break;
        case 4: _t->newRemoteFile((*reinterpret_cast<std::add_pointer_t<QString>>(_a[1]))); break;
        case 5: _t->coolerToggled((*reinterpret_cast<std::add_pointer_t<bool>>(_a[1]))); break;
        case 6: _t->error((*reinterpret_cast<std::add_pointer_t<ErrorType>>(_a[1]))); break;
        case 7: _t->updateVideoWindow((*reinterpret_cast<std::add_pointer_t<int>>(_a[1])),(*reinterpret_cast<std::add_pointer_t<int>>(_a[2])),(*reinterpret_cast<std::add_pointer_t<bool>>(_a[3]))); break;
        case 8: _t->closeVideoWindow(); break;
        case 9: _t->videoStreamToggled((*reinterpret_cast<std::add_pointer_t<bool>>(_a[1]))); break;
        case 10: _t->showVideoFrame((*reinterpret_cast<std::add_pointer_t<INDI::Property>>(_a[1])),(*reinterpret_cast<std::add_pointer_t<int>>(_a[2])),(*reinterpret_cast<std::add_pointer_t<int>>(_a[3]))); break;
        case 11: _t->videoRecordToggled((*reinterpret_cast<std::add_pointer_t<bool>>(_a[1]))); break;
        case 12: _t->newFPS((*reinterpret_cast<std::add_pointer_t<double>>(_a[1])),(*reinterpret_cast<std::add_pointer_t<double>>(_a[2]))); break;
        case 13: _t->newVideoFrame((*reinterpret_cast<std::add_pointer_t<QSharedPointer<QImage>>>(_a[1]))); break;
        case 14: _t->newImage((*reinterpret_cast<std::add_pointer_t<QSharedPointer<FITSData>>>(_a[1])),(*reinterpret_cast<std::add_pointer_t<QString>>(_a[2]))); break;
        case 15: _t->newImage((*reinterpret_cast<std::add_pointer_t<QSharedPointer<FITSData>>>(_a[1]))); break;
        case 16: _t->newView((*reinterpret_cast<std::add_pointer_t<QSharedPointer<FITSView>>>(_a[1]))); break;
        case 17: _t->StreamWindowHidden(); break;
        case 18: _t->setBLOBManager((*reinterpret_cast<std::add_pointer_t<const char*>>(_a[1])),(*reinterpret_cast<std::add_pointer_t<INDI::Property>>(_a[2]))); break;
        case 19: _t->setWSBLOB((*reinterpret_cast<std::add_pointer_t<QByteArray>>(_a[1])),(*reinterpret_cast<std::add_pointer_t<QString>>(_a[2]))); break;
        default: ;
        }
    }
    if (_c == QMetaObject::RegisterMethodArgumentMetaType) {
        switch (_id) {
        default: *reinterpret_cast<QMetaType *>(_a[0]) = QMetaType(); break;
        case 3:
            switch (*reinterpret_cast<int*>(_a[1])) {
            default: *reinterpret_cast<QMetaType *>(_a[0]) = QMetaType(); break;
            case 0:
                *reinterpret_cast<QMetaType *>(_a[0]) = QMetaType::fromType< INDI::Property >(); break;
            }
            break;
        case 10:
            switch (*reinterpret_cast<int*>(_a[1])) {
            default: *reinterpret_cast<QMetaType *>(_a[0]) = QMetaType(); break;
            case 0:
                *reinterpret_cast<QMetaType *>(_a[0]) = QMetaType::fromType< INDI::Property >(); break;
            }
            break;
        case 14:
            switch (*reinterpret_cast<int*>(_a[1])) {
            default: *reinterpret_cast<QMetaType *>(_a[0]) = QMetaType(); break;
            case 0:
                *reinterpret_cast<QMetaType *>(_a[0]) = QMetaType::fromType< QSharedPointer<FITSData> >(); break;
            }
            break;
        case 15:
            switch (*reinterpret_cast<int*>(_a[1])) {
            default: *reinterpret_cast<QMetaType *>(_a[0]) = QMetaType(); break;
            case 0:
                *reinterpret_cast<QMetaType *>(_a[0]) = QMetaType::fromType< QSharedPointer<FITSData> >(); break;
            }
            break;
        case 16:
            switch (*reinterpret_cast<int*>(_a[1])) {
            default: *reinterpret_cast<QMetaType *>(_a[0]) = QMetaType(); break;
            case 0:
                *reinterpret_cast<QMetaType *>(_a[0]) = QMetaType::fromType< QSharedPointer<FITSView> >(); break;
            }
            break;
        case 18:
            switch (*reinterpret_cast<int*>(_a[1])) {
            default: *reinterpret_cast<QMetaType *>(_a[0]) = QMetaType(); break;
            case 1:
                *reinterpret_cast<QMetaType *>(_a[0]) = QMetaType::fromType< INDI::Property >(); break;
            }
            break;
        }
    }
    if (_c == QMetaObject::IndexOfMethod) {
        if (QtMocHelpers::indexOfMethod<void (Camera::*)(double )>(_a, &Camera::newTemperatureValue, 0))
            return;
        if (QtMocHelpers::indexOfMethod<void (Camera::*)(ISD::CameraChip * , double , IPState )>(_a, &Camera::newExposureValue, 1))
            return;
        if (QtMocHelpers::indexOfMethod<void (Camera::*)(ISD::CameraChip * , double , double , double )>(_a, &Camera::newGuideStarData, 2))
            return;
        if (QtMocHelpers::indexOfMethod<void (Camera::*)(INDI::Property )>(_a, &Camera::newBLOBManager, 3))
            return;
        if (QtMocHelpers::indexOfMethod<void (Camera::*)(QString )>(_a, &Camera::newRemoteFile, 4))
            return;
        if (QtMocHelpers::indexOfMethod<void (Camera::*)(bool )>(_a, &Camera::coolerToggled, 5))
            return;
        if (QtMocHelpers::indexOfMethod<void (Camera::*)(ErrorType )>(_a, &Camera::error, 6))
            return;
        if (QtMocHelpers::indexOfMethod<void (Camera::*)(int , int , bool )>(_a, &Camera::updateVideoWindow, 7))
            return;
        if (QtMocHelpers::indexOfMethod<void (Camera::*)()>(_a, &Camera::closeVideoWindow, 8))
            return;
        if (QtMocHelpers::indexOfMethod<void (Camera::*)(bool )>(_a, &Camera::videoStreamToggled, 9))
            return;
        if (QtMocHelpers::indexOfMethod<void (Camera::*)(INDI::Property , int , int )>(_a, &Camera::showVideoFrame, 10))
            return;
        if (QtMocHelpers::indexOfMethod<void (Camera::*)(bool )>(_a, &Camera::videoRecordToggled, 11))
            return;
        if (QtMocHelpers::indexOfMethod<void (Camera::*)(double , double )>(_a, &Camera::newFPS, 12))
            return;
        if (QtMocHelpers::indexOfMethod<void (Camera::*)(const QSharedPointer<QImage> & )>(_a, &Camera::newVideoFrame, 13))
            return;
        if (QtMocHelpers::indexOfMethod<void (Camera::*)(const QSharedPointer<FITSData> & , const QString & )>(_a, &Camera::newImage, 14))
            return;
        if (QtMocHelpers::indexOfMethod<void (Camera::*)(const QSharedPointer<FITSView> & )>(_a, &Camera::newView, 16))
            return;
    }
    if (_c == QMetaObject::ReadProperty) {
        void *_v = _a[0];
        switch (_id) {
        case 0: *reinterpret_cast<bool*>(_v) = _t->m_StreamingEnabled; break;
        default: break;
        }
    }
    if (_c == QMetaObject::WriteProperty) {
        void *_v = _a[0];
        switch (_id) {
        case 0: QtMocHelpers::setProperty(_t->m_StreamingEnabled, *reinterpret_cast<bool*>(_v)); break;
        default: break;
        }
    }
}

const QMetaObject *ISD::Camera::metaObject() const
{
    return QObject::d_ptr->metaObject ? QObject::d_ptr->dynamicMetaObject() : &staticMetaObject;
}

void *ISD::Camera::qt_metacast(const char *_clname)
{
    if (!_clname) return nullptr;
    if (!strcmp(_clname, qt_staticMetaObjectStaticContent<qt_meta_tag_ZN3ISD6CameraE_t>.strings))
        return static_cast<void*>(this);
    return ConcreteDevice::qt_metacast(_clname);
}

int ISD::Camera::qt_metacall(QMetaObject::Call _c, int _id, void **_a)
{
    _id = ConcreteDevice::qt_metacall(_c, _id, _a);
    if (_id < 0)
        return _id;
    if (_c == QMetaObject::InvokeMetaMethod) {
        if (_id < 20)
            qt_static_metacall(this, _c, _id, _a);
        _id -= 20;
    }
    if (_c == QMetaObject::RegisterMethodArgumentMetaType) {
        if (_id < 20)
            qt_static_metacall(this, _c, _id, _a);
        _id -= 20;
    }
    if (_c == QMetaObject::ReadProperty || _c == QMetaObject::WriteProperty
            || _c == QMetaObject::ResetProperty || _c == QMetaObject::BindableProperty
            || _c == QMetaObject::RegisterPropertyMetaType) {
        qt_static_metacall(this, _c, _id, _a);
        _id -= 1;
    }
    return _id;
}

// SIGNAL 0
void ISD::Camera::newTemperatureValue(double _t1)
{
    QMetaObject::activate<void>(this, &staticMetaObject, 0, nullptr, _t1);
}

// SIGNAL 1
void ISD::Camera::newExposureValue(ISD::CameraChip * _t1, double _t2, IPState _t3)
{
    QMetaObject::activate<void>(this, &staticMetaObject, 1, nullptr, _t1, _t2, _t3);
}

// SIGNAL 2
void ISD::Camera::newGuideStarData(ISD::CameraChip * _t1, double _t2, double _t3, double _t4)
{
    QMetaObject::activate<void>(this, &staticMetaObject, 2, nullptr, _t1, _t2, _t3, _t4);
}

// SIGNAL 3
void ISD::Camera::newBLOBManager(INDI::Property _t1)
{
    QMetaObject::activate<void>(this, &staticMetaObject, 3, nullptr, _t1);
}

// SIGNAL 4
void ISD::Camera::newRemoteFile(QString _t1)
{
    QMetaObject::activate<void>(this, &staticMetaObject, 4, nullptr, _t1);
}

// SIGNAL 5
void ISD::Camera::coolerToggled(bool _t1)
{
    QMetaObject::activate<void>(this, &staticMetaObject, 5, nullptr, _t1);
}

// SIGNAL 6
void ISD::Camera::error(ErrorType _t1)
{
    QMetaObject::activate<void>(this, &staticMetaObject, 6, nullptr, _t1);
}

// SIGNAL 7
void ISD::Camera::updateVideoWindow(int _t1, int _t2, bool _t3)
{
    QMetaObject::activate<void>(this, &staticMetaObject, 7, nullptr, _t1, _t2, _t3);
}

// SIGNAL 8
void ISD::Camera::closeVideoWindow()
{
    QMetaObject::activate(this, &staticMetaObject, 8, nullptr);
}

// SIGNAL 9
void ISD::Camera::videoStreamToggled(bool _t1)
{
    QMetaObject::activate<void>(this, &staticMetaObject, 9, nullptr, _t1);
}

// SIGNAL 10
void ISD::Camera::showVideoFrame(INDI::Property _t1, int _t2, int _t3)
{
    QMetaObject::activate<void>(this, &staticMetaObject, 10, nullptr, _t1, _t2, _t3);
}

// SIGNAL 11
void ISD::Camera::videoRecordToggled(bool _t1)
{
    QMetaObject::activate<void>(this, &staticMetaObject, 11, nullptr, _t1);
}

// SIGNAL 12
void ISD::Camera::newFPS(double _t1, double _t2)
{
    QMetaObject::activate<void>(this, &staticMetaObject, 12, nullptr, _t1, _t2);
}

// SIGNAL 13
void ISD::Camera::newVideoFrame(const QSharedPointer<QImage> & _t1)
{
    QMetaObject::activate<void>(this, &staticMetaObject, 13, nullptr, _t1);
}

// SIGNAL 14
void ISD::Camera::newImage(const QSharedPointer<FITSData> & _t1, const QString & _t2)
{
    QMetaObject::activate<void>(this, &staticMetaObject, 14, nullptr, _t1, _t2);
}

// SIGNAL 16
void ISD::Camera::newView(const QSharedPointer<FITSView> & _t1)
{
    QMetaObject::activate<void>(this, &staticMetaObject, 16, nullptr, _t1);
}
QT_WARNING_POP
