/********************************************************************************
** Form generated from reading UI file 'pushtoassistant.ui'
**
** Created by: Qt User Interface Compiler version 6.11.1
**
** WARNING! All changes made in this file will be lost when recompiling UI file!
********************************************************************************/

#ifndef UI_PUSHTOASSISTANT_H
#define UI_PUSHTOASSISTANT_H

#include <QtCore/QVariant>
#include <QtGui/QIcon>
#include <QtWidgets/QApplication>
#include <QtWidgets/QButtonGroup>
#include <QtWidgets/QDialog>
#include <QtWidgets/QDoubleSpinBox>
#include <QtWidgets/QFrame>
#include <QtWidgets/QGridLayout>
#include <QtWidgets/QHBoxLayout>
#include <QtWidgets/QLabel>
#include <QtWidgets/QPushButton>
#include <QtWidgets/QRadioButton>
#include <QtWidgets/QSpacerItem>
#include <klocalizedstring.h>
#include "ekos/align/alignmentplot.h"
#include "ekos/auxiliary/ledstatuswidget.h"
#include "ekos/mount/mounttargetwidget.h"

QT_BEGIN_NAMESPACE

class Ui_PushToAssistant
{
public:
    QGridLayout *gridLayout;
    AlignmentPlot *targetPlot;
    QGridLayout *gridLayout_2;
    QPushButton *toggleSolvingB;
    QHBoxLayout *horizontalLayout;
    QPushButton *loopSolvingB;
    QDoubleSpinBox *refreshIntervalSB;
    QSpacerItem *verticalSpacer_2;
    QHBoxLayout *statusLayout;
    QPushButton *processEkosB;
    QLabel *processEkosLabel;
    QSpacerItem *horizontalSpacer;
    QLabel *alignStatusLabel;
    QLabel *mountStatusLabel;
    QFrame *separator;
    Ekos::MountTargetWidget *mountTarget;
    QSpacerItem *verticalSpacer;
    QLabel *targetLabel;
    Ekos::LedStatusWidget *statusLED;
    QHBoxLayout *horizontalLayout_2;
    QSpacerItem *horizontalSpacer_2;
    QRadioButton *jNowCheck;
    QRadioButton *j2000Check;
    QButtonGroup *epochGroup;

    void setupUi(QDialog *PushToAssistant)
    {
        if (PushToAssistant->objectName().isEmpty())
            PushToAssistant->setObjectName("PushToAssistant");
        PushToAssistant->resize(394, 568);
        gridLayout = new QGridLayout(PushToAssistant);
        gridLayout->setObjectName("gridLayout");
        gridLayout->setVerticalSpacing(3);
        gridLayout->setContentsMargins(6, 6, 6, 6);
        targetPlot = new AlignmentPlot(PushToAssistant);
        targetPlot->setObjectName("targetPlot");
        QSizePolicy sizePolicy(QSizePolicy::Policy::Preferred, QSizePolicy::Policy::Preferred);
        sizePolicy.setHorizontalStretch(1);
        sizePolicy.setVerticalStretch(1);
        sizePolicy.setHeightForWidth(targetPlot->sizePolicy().hasHeightForWidth());
        targetPlot->setSizePolicy(sizePolicy);
        targetPlot->setMinimumSize(QSize(180, 180));

        gridLayout->addWidget(targetPlot, 0, 0, 1, 6);

        gridLayout_2 = new QGridLayout();
        gridLayout_2->setObjectName("gridLayout_2");
        gridLayout_2->setContentsMargins(10, -1, -1, 6);
        toggleSolvingB = new QPushButton(PushToAssistant);
        toggleSolvingB->setObjectName("toggleSolvingB");
        toggleSolvingB->setEnabled(false);
        toggleSolvingB->setMinimumSize(QSize(80, 60));

        gridLayout_2->addWidget(toggleSolvingB, 1, 0, 1, 1);

        horizontalLayout = new QHBoxLayout();
        horizontalLayout->setObjectName("horizontalLayout");
        horizontalLayout->setContentsMargins(-1, -1, -1, 0);
        loopSolvingB = new QPushButton(PushToAssistant);
        loopSolvingB->setObjectName("loopSolvingB");
        QSizePolicy sizePolicy1(QSizePolicy::Policy::Fixed, QSizePolicy::Policy::Fixed);
        sizePolicy1.setHorizontalStretch(0);
        sizePolicy1.setVerticalStretch(0);
        sizePolicy1.setHeightForWidth(loopSolvingB->sizePolicy().hasHeightForWidth());
        loopSolvingB->setSizePolicy(sizePolicy1);
        loopSolvingB->setMinimumSize(QSize(0, 24));
        QIcon icon;
        QString iconThemeName = QString::fromUtf8("media-playlist-repeat");
        if (QIcon::hasThemeIcon(iconThemeName)) {
            icon = QIcon::fromTheme(iconThemeName);
        } else {
            icon.addFile(QString::fromUtf8("."), QSize(), QIcon::Mode::Normal, QIcon::State::Off);
        }
        loopSolvingB->setIcon(icon);
        loopSolvingB->setIconSize(QSize(24, 24));
        loopSolvingB->setCheckable(true);

        horizontalLayout->addWidget(loopSolvingB);

        refreshIntervalSB = new QDoubleSpinBox(PushToAssistant);
        refreshIntervalSB->setObjectName("refreshIntervalSB");
        refreshIntervalSB->setMinimum(0.100000000000000);
        refreshIntervalSB->setValue(5.000000000000000);

        horizontalLayout->addWidget(refreshIntervalSB);


        gridLayout_2->addLayout(horizontalLayout, 3, 0, 1, 1);

        verticalSpacer_2 = new QSpacerItem(20, 40, QSizePolicy::Policy::Minimum, QSizePolicy::Policy::Expanding);

        gridLayout_2->addItem(verticalSpacer_2, 0, 0, 1, 1);


        gridLayout->addLayout(gridLayout_2, 3, 5, 1, 1);

        statusLayout = new QHBoxLayout();
        statusLayout->setObjectName("statusLayout");
        processEkosB = new QPushButton(PushToAssistant);
        processEkosB->setObjectName("processEkosB");
        sizePolicy1.setHeightForWidth(processEkosB->sizePolicy().hasHeightForWidth());
        processEkosB->setSizePolicy(sizePolicy1);
        QIcon icon1;
        iconThemeName = QString::fromUtf8("media-playback-start");
        if (QIcon::hasThemeIcon(iconThemeName)) {
            icon1 = QIcon::fromTheme(iconThemeName);
        } else {
            icon1.addFile(QString::fromUtf8("."), QSize(), QIcon::Mode::Normal, QIcon::State::Off);
        }
        processEkosB->setIcon(icon1);
        processEkosB->setIconSize(QSize(12, 12));

        statusLayout->addWidget(processEkosB);

        processEkosLabel = new QLabel(PushToAssistant);
        processEkosLabel->setObjectName("processEkosLabel");

        statusLayout->addWidget(processEkosLabel);

        horizontalSpacer = new QSpacerItem(40, 20, QSizePolicy::Policy::Expanding, QSizePolicy::Policy::Minimum);

        statusLayout->addItem(horizontalSpacer);

        alignStatusLabel = new QLabel(PushToAssistant);
        alignStatusLabel->setObjectName("alignStatusLabel");

        statusLayout->addWidget(alignStatusLabel);

        mountStatusLabel = new QLabel(PushToAssistant);
        mountStatusLabel->setObjectName("mountStatusLabel");

        statusLayout->addWidget(mountStatusLabel);


        gridLayout->addLayout(statusLayout, 5, 0, 1, 6);

        separator = new QFrame(PushToAssistant);
        separator->setObjectName("separator");
        separator->setFrameShape(QFrame::Shape::HLine);
        separator->setFrameShadow(QFrame::Shadow::Sunken);

        gridLayout->addWidget(separator, 4, 0, 1, 6);

        mountTarget = new Ekos::MountTargetWidget(PushToAssistant);
        mountTarget->setObjectName("mountTarget");
        mountTarget->setMinimumSize(QSize(0, 140));

        gridLayout->addWidget(mountTarget, 3, 0, 1, 5);

        verticalSpacer = new QSpacerItem(20, 40, QSizePolicy::Policy::Minimum, QSizePolicy::Policy::Expanding);

        gridLayout->addItem(verticalSpacer, 1, 0, 1, 1);

        targetLabel = new QLabel(PushToAssistant);
        targetLabel->setObjectName("targetLabel");
        QFont font;
        font.setBold(true);
        targetLabel->setFont(font);

        gridLayout->addWidget(targetLabel, 2, 0, 1, 1);

        statusLED = new Ekos::LedStatusWidget(PushToAssistant);
        statusLED->setObjectName("statusLED");
        statusLED->setMinimumSize(QSize(0, 24));

        gridLayout->addWidget(statusLED, 2, 5, 1, 1);

        horizontalLayout_2 = new QHBoxLayout();
        horizontalLayout_2->setObjectName("horizontalLayout_2");
        horizontalSpacer_2 = new QSpacerItem(40, 20, QSizePolicy::Policy::Expanding, QSizePolicy::Policy::Minimum);

        horizontalLayout_2->addItem(horizontalSpacer_2);

        jNowCheck = new QRadioButton(PushToAssistant);
        epochGroup = new QButtonGroup(PushToAssistant);
        epochGroup->setObjectName("epochGroup");
        epochGroup->addButton(jNowCheck);
        jNowCheck->setObjectName("jNowCheck");
        jNowCheck->setChecked(true);

        horizontalLayout_2->addWidget(jNowCheck);

        j2000Check = new QRadioButton(PushToAssistant);
        epochGroup->addButton(j2000Check);
        j2000Check->setObjectName("j2000Check");

        horizontalLayout_2->addWidget(j2000Check);


        gridLayout->addLayout(horizontalLayout_2, 2, 1, 1, 4);

        gridLayout->setRowStretch(0, 1);
        gridLayout->setColumnStretch(0, 1);
        gridLayout->setColumnStretch(2, 1);

        retranslateUi(PushToAssistant);

        QMetaObject::connectSlotsByName(PushToAssistant);
    } // setupUi

    void retranslateUi(QDialog *PushToAssistant)
    {
        PushToAssistant->setWindowTitle(tr2i18n("Push-To Assistant", nullptr));
#if QT_CONFIG(tooltip)
        targetPlot->setToolTip(tr2i18n("<html><head/><body><p><span style=\" font-weight:600;\">Description</span></p><p>This assistant gives users of manual mounts (dobsons etc.) support finding their targets using a finder scope equipped with a camera.</p><p><span style=\" font-weight:600;\">Preparation</span></p><p>Open EKOS, create a profile with the camera of your choice, the Telescope Simulator as mount and add your finder scope as new telescope.</p><p><span style=\" font-weight:600;\">Usage</span></p><ul style=\"margin-top: 0px; margin-bottom: 0px; margin-left: 0px; margin-right: 0px; -qt-list-indent: 1;\"><li style=\" margin-top:0px; margin-bottom:0px; margin-left:0px; margin-right:0px; -qt-block-indent:0; text-indent:0px;\">Start EKOS</li><li style=\" margin-top:0px; margin-bottom:0px; margin-left:0px; margin-right:0px; -qt-block-indent:0; text-indent:0px;\">Position your mount as close as possible to your target</li><li style=\" margin-top:0px; margin-bottom:0px; margin-left:0px; margin-right:0px; -qt-block-indent:0; text-indent:0px;\">Sel"
                        "ect your target in the target finder and press the &quot;Select target&quot; button</li><li style=\" margin-top:0px; margin-bottom:0px; margin-left:0px; margin-right:0px; -qt-block-indent:0; text-indent:0px;\">Press the &quot;Solve position&quot; button. This captures a frame through your finder scope and solves the image against the star catalogs of KStars.</li><li style=\" margin-top:0px; margin-bottom:0px; margin-left:0px; margin-right:0px; -qt-block-indent:0; text-indent:0px;\">As soon as plate solving succeeds, the distance to the target is displayed. Arrows show the directions how to correct your mount position.</li><li style=\" margin-top:0px; margin-bottom:0px; margin-left:0px; margin-right:0px; -qt-block-indent:0; text-indent:0px;\">Move your mount in the indicated position and repeat solving.</li></ul><p><span style=\" font-weight:600;\">Hints</span></p><ul style=\"margin-top: 0px; margin-bottom: 0px; margin-left: 0px; margin-right: 0px; -qt-list-indent: 1;\"><li style=\" margin-top:12px; margin-bott"
                        "om:0px; margin-left:0px; margin-right:0px; -qt-block-indent:0; text-indent:0px;\">If you press the &quot;Repeat&quot; button, capturing and plate solving will be repeated after the configured delay.</li><li style=\" margin-top:0px; margin-bottom:12px; margin-left:0px; margin-right:0px; -qt-block-indent:0; text-indent:0px;\">If plate solving fails, check if the focal length of your finder scope is correctly configured and your telescope is roughly pointing to the target that you have selected.</li></ul></body></html>", nullptr));
#endif // QT_CONFIG(tooltip)
        toggleSolvingB->setText(tr2i18n("Abort Solving", nullptr));
#if QT_CONFIG(tooltip)
        loopSolvingB->setToolTip(tr2i18n("Repeat solving", nullptr));
#endif // QT_CONFIG(tooltip)
        loopSolvingB->setText(QString());
#if QT_CONFIG(tooltip)
        refreshIntervalSB->setToolTip(tr2i18n("Interval after which solving is repeated", nullptr));
#endif // QT_CONFIG(tooltip)
        refreshIntervalSB->setSpecialValueText(QString());
        refreshIntervalSB->setSuffix(tr2i18n(" s", nullptr));
        processEkosB->setText(QString());
        processEkosLabel->setText(tr2i18n("start Ekos", nullptr));
        alignStatusLabel->setText(tr2i18n("Align", nullptr));
        mountStatusLabel->setText(tr2i18n("Mount", nullptr));
        targetLabel->setText(tr2i18n("Target", nullptr));
        jNowCheck->setText(tr2i18n("JNow", nullptr));
        j2000Check->setText(tr2i18n("J2000", nullptr));
    } // retranslateUi

};

namespace Ui {
    class PushToAssistant: public Ui_PushToAssistant {};
} // namespace Ui

QT_END_NAMESPACE

#endif // PUSHTOASSISTANT_H

