/********************************************************************************
** Form generated from reading UI file 'scriptnamedialog.ui'
**
** Created by: Qt User Interface Compiler version 6.11.1
**
** WARNING! All changes made in this file will be lost when recompiling UI file!
********************************************************************************/

#ifndef UI_SCRIPTNAMEDIALOG_H
#define UI_SCRIPTNAMEDIALOG_H

#include <QtCore/QVariant>
#include <QtWidgets/QApplication>
#include <QtWidgets/QGridLayout>
#include <QtWidgets/QLabel>
#include <QtWidgets/QLineEdit>
#include <QtWidgets/QWidget>
#include <klocalizedstring.h>

QT_BEGIN_NAMESPACE

class Ui_ScriptNameDialog
{
public:
    QGridLayout *gridLayout;
    QLabel *textLabel2;
    QLineEdit *ScriptName;
    QLineEdit *AuthorName;
    QLabel *textLabel1;

    void setupUi(QWidget *ScriptNameDialog)
    {
        if (ScriptNameDialog->objectName().isEmpty())
            ScriptNameDialog->setObjectName("ScriptNameDialog");
        ScriptNameDialog->resize(400, 82);
        gridLayout = new QGridLayout(ScriptNameDialog);
#ifndef UI_Q_OS_MAC
        gridLayout->setSpacing(6);
#endif
#ifndef UI_Q_OS_MAC
        gridLayout->setContentsMargins(9, 9, 9, 9);
#endif
        gridLayout->setObjectName("gridLayout");
        textLabel2 = new QLabel(ScriptNameDialog);
        textLabel2->setObjectName("textLabel2");

        gridLayout->addWidget(textLabel2, 1, 0, 1, 1);

        ScriptName = new QLineEdit(ScriptNameDialog);
        ScriptName->setObjectName("ScriptName");

        gridLayout->addWidget(ScriptName, 0, 1, 1, 1);

        AuthorName = new QLineEdit(ScriptNameDialog);
        AuthorName->setObjectName("AuthorName");

        gridLayout->addWidget(AuthorName, 1, 1, 1, 1);

        textLabel1 = new QLabel(ScriptNameDialog);
        textLabel1->setObjectName("textLabel1");
        textLabel1->setFrameShape(QFrame::NoFrame);
        textLabel1->setFrameShadow(QFrame::Plain);

        gridLayout->addWidget(textLabel1, 0, 0, 1, 1);


        retranslateUi(ScriptNameDialog);

        QMetaObject::connectSlotsByName(ScriptNameDialog);
    } // setupUi

    void retranslateUi(QWidget *ScriptNameDialog)
    {
        textLabel2->setText(tr2i18n("Author:", nullptr));
#if QT_CONFIG(tooltip)
        ScriptName->setToolTip(tr2i18n("Enter name for the script", nullptr));
#endif // QT_CONFIG(tooltip)
#if QT_CONFIG(whatsthis)
        ScriptName->setWhatsThis(tr2i18n("Enter a name for the script.  This is not the file name, just a short descriptive line of text.", nullptr));
#endif // QT_CONFIG(whatsthis)
#if QT_CONFIG(tooltip)
        AuthorName->setToolTip(tr2i18n("Enter author's name", nullptr));
#endif // QT_CONFIG(tooltip)
        textLabel1->setText(tr2i18n("Script name:", nullptr));
        (void)ScriptNameDialog;
    } // retranslateUi

};

namespace Ui {
    class ScriptNameDialog: public Ui_ScriptNameDialog {};
} // namespace Ui

QT_END_NAMESPACE

#endif // SCRIPTNAMEDIALOG_H

