/*
 * This file was generated by qdbusxml2cpp version 0.8
 * Source file was org.kde.kstars.Ekos.Capture.xml
 *
 * qdbusxml2cpp is Copyright (C) The Qt Company Ltd. and other contributors.
 *
 * This is an auto-generated file.
 * Do not edit! All changes made to it will be lost.
 */

#include "captureadaptor.h"
#include <QtCore/QMetaObject>
#include <QtCore/QByteArray>
#include <QtCore/QList>
#include <QtCore/QMap>
#include <QtCore/QString>
#include <QtCore/QStringList>
#include <QtCore/QVariant>

/*
 * Implementation of adaptor class CaptureAdaptor
 */

CaptureAdaptor::CaptureAdaptor(Ekos::Capture *parent)
    : QDBusAbstractAdaptor(parent)
{
    // constructor
    setAutoRelaySignals(true);
}

CaptureAdaptor::~CaptureAdaptor()
{
    // destructor
}

QString CaptureAdaptor::camera() const
{
    // get the value of property camera
    return qvariant_cast< QString >(parent()->property("camera"));
}

bool CaptureAdaptor::coolerControl() const
{
    // get the value of property coolerControl
    return qvariant_cast< bool >(parent()->property("coolerControl"));
}

void CaptureAdaptor::setCoolerControl(bool value)
{
    // set the value of property coolerControl
    parent()->setProperty("coolerControl", QVariant::fromValue(value));
}

QString CaptureAdaptor::filter() const
{
    // get the value of property filter
    return qvariant_cast< QString >(parent()->property("filter"));
}

void CaptureAdaptor::setFilter(const QString &value)
{
    // set the value of property filter
    parent()->setProperty("filter", QVariant::fromValue(value));
}

QString CaptureAdaptor::filterWheel() const
{
    // get the value of property filterWheel
    return qvariant_cast< QString >(parent()->property("filterWheel"));
}

QStringList CaptureAdaptor::logText() const
{
    // get the value of property logText
    return qvariant_cast< QStringList >(parent()->property("logText"));
}

QString CaptureAdaptor::observerName() const
{
    // get the value of property observerName
    return qvariant_cast< QString >(parent()->property("observerName"));
}

void CaptureAdaptor::setObserverName(const QString &value)
{
    // set the value of property observerName
    parent()->setProperty("observerName", QVariant::fromValue(value));
}

QString CaptureAdaptor::opticalTrain() const
{
    // get the value of property opticalTrain
    return qvariant_cast< QString >(parent()->property("opticalTrain"));
}

void CaptureAdaptor::setOpticalTrain(const QString &value)
{
    // set the value of property opticalTrain
    parent()->setProperty("opticalTrain", QVariant::fromValue(value));
}

int CaptureAdaptor::status() const
{
    // get the value of property status
    return qvariant_cast< int >(parent()->property("status"));
}

QString CaptureAdaptor::targetName() const
{
    // get the value of property targetName
    return qvariant_cast< QString >(parent()->property("targetName"));
}

void CaptureAdaptor::setTargetName(const QString &value)
{
    // set the value of property targetName
    parent()->setProperty("targetName", QVariant::fromValue(value));
}

void CaptureAdaptor::abort(const QString &train)
{
    // handle method call org.kde.kstars.Ekos.Capture.abort
    parent()->abort(train);
}

void CaptureAdaptor::clearAutoFocusHFR(const QString &trainname)
{
    // handle method call org.kde.kstars.Ekos.Capture.clearAutoFocusHFR
    parent()->clearAutoFocusHFR(trainname);
}

void CaptureAdaptor::clearSequenceQueue()
{
    // handle method call org.kde.kstars.Ekos.Capture.clearSequenceQueue
    parent()->clearSequenceQueue();
}

int CaptureAdaptor::findCameraPosition(const QString &train, bool addIfNecessary)
{
    // handle method call org.kde.kstars.Ekos.Capture.findCameraPosition
    return parent()->findCameraPosition(train, addIfNecessary);
}

int CaptureAdaptor::getActiveJobID()
{
    // handle method call org.kde.kstars.Ekos.Capture.getActiveJobID
    return parent()->getActiveJobID();
}

int CaptureAdaptor::getActiveJobRemainingTime()
{
    // handle method call org.kde.kstars.Ekos.Capture.getActiveJobRemainingTime
    return parent()->getActiveJobRemainingTime();
}

int CaptureAdaptor::getJobCount()
{
    // handle method call org.kde.kstars.Ekos.Capture.getJobCount
    return parent()->getJobCount();
}

double CaptureAdaptor::getJobExposureDuration(int id)
{
    // handle method call org.kde.kstars.Ekos.Capture.getJobExposureDuration
    return parent()->getJobExposureDuration(id);
}

double CaptureAdaptor::getJobExposureProgress(int id)
{
    // handle method call org.kde.kstars.Ekos.Capture.getJobExposureProgress
    return parent()->getJobExposureProgress(id);
}

QString CaptureAdaptor::getJobFilterName(int id)
{
    // handle method call org.kde.kstars.Ekos.Capture.getJobFilterName
    return parent()->getJobFilterName(id);
}

int CaptureAdaptor::getJobFrameType(int id)
{
    // handle method call org.kde.kstars.Ekos.Capture.getJobFrameType
    return parent()->getJobFrameType(id);
}

int CaptureAdaptor::getJobImageCount(int id)
{
    // handle method call org.kde.kstars.Ekos.Capture.getJobImageCount
    return parent()->getJobImageCount(id);
}

int CaptureAdaptor::getJobImageProgress(int id)
{
    // handle method call org.kde.kstars.Ekos.Capture.getJobImageProgress
    return parent()->getJobImageProgress(id);
}

QString CaptureAdaptor::getJobPlaceholderFormat()
{
    // handle method call org.kde.kstars.Ekos.Capture.getJobPlaceholderFormat
    return parent()->getJobPlaceholderFormat();
}

QString CaptureAdaptor::getJobPreviewFileName()
{
    // handle method call org.kde.kstars.Ekos.Capture.getJobPreviewFileName
    return parent()->getJobPreviewFileName();
}

QString CaptureAdaptor::getJobState(int id)
{
    // handle method call org.kde.kstars.Ekos.Capture.getJobState
    return parent()->getJobState(id);
}

int CaptureAdaptor::getOverallRemainingTime()
{
    // handle method call org.kde.kstars.Ekos.Capture.getOverallRemainingTime
    return parent()->getOverallRemainingTime();
}

int CaptureAdaptor::getPendingJobCount()
{
    // handle method call org.kde.kstars.Ekos.Capture.getPendingJobCount
    return parent()->getPendingJobCount();
}

QString CaptureAdaptor::getPicturesDirectory()
{
    // handle method call org.kde.kstars.Ekos.Capture.getPicturesDirectory
    return parent()->getPicturesDirectory();
}

double CaptureAdaptor::getProgressPercentage()
{
    // handle method call org.kde.kstars.Ekos.Capture.getProgressPercentage
    return parent()->getProgressPercentage();
}

QString CaptureAdaptor::getSequenceQueueStatus()
{
    // handle method call org.kde.kstars.Ekos.Capture.getSequenceQueueStatus
    return parent()->getSequenceQueueStatus();
}

void CaptureAdaptor::ignoreSequenceHistory()
{
    // handle method call org.kde.kstars.Ekos.Capture.ignoreSequenceHistory
    parent()->ignoreSequenceHistory();
}

bool CaptureAdaptor::loadSequenceQueue(const QString &fileURL, const QString &train, bool isMaster, const QString &targetName)
{
    // handle method call org.kde.kstars.Ekos.Capture.loadSequenceQueue
    return parent()->loadSequenceQueue(fileURL, train, isMaster, targetName);
}

QString CaptureAdaptor::mainCameraDeviceName()
{
    // handle method call org.kde.kstars.Ekos.Capture.mainCameraDeviceName
    return parent()->mainCameraDeviceName();
}

void CaptureAdaptor::pause()
{
    // handle method call org.kde.kstars.Ekos.Capture.pause
    parent()->pause();
}

void CaptureAdaptor::restartCamera(const QString &name)
{
    // handle method call org.kde.kstars.Ekos.Capture.restartCamera
    parent()->restartCamera(name);
}

bool CaptureAdaptor::saveSequenceQueue(const QString &path)
{
    // handle method call org.kde.kstars.Ekos.Capture.saveSequenceQueue
    return parent()->saveSequenceQueue(path);
}

void CaptureAdaptor::setCapturedFramesMap(const QString &signature, int count, const QString &train)
{
    // handle method call org.kde.kstars.Ekos.Capture.setCapturedFramesMap
    parent()->setCapturedFramesMap(signature, count, train);
}

void CaptureAdaptor::setInSequenceFocus(bool enable, double HFR)
{
    // handle method call org.kde.kstars.Ekos.Capture.setInSequenceFocus
    parent()->setInSequenceFocus(enable, HFR);
}

void CaptureAdaptor::setMaximumGuidingDeviation(bool enable, double value)
{
    // handle method call org.kde.kstars.Ekos.Capture.setMaximumGuidingDeviation
    parent()->setMaximumGuidingDeviation(enable, value);
}

bool CaptureAdaptor::setPicturesDirectory(const QString &path)
{
    // handle method call org.kde.kstars.Ekos.Capture.setPicturesDirectory
    return parent()->setPicturesDirectory(path);
}

QString CaptureAdaptor::start(const QString &train)
{
    // handle method call org.kde.kstars.Ekos.Capture.start
    return parent()->start(train);
}

void CaptureAdaptor::stop()
{
    // handle method call org.kde.kstars.Ekos.Capture.stop
    parent()->stop();
}

void CaptureAdaptor::suspend()
{
    // handle method call org.kde.kstars.Ekos.Capture.suspend
    parent()->suspend();
}

void CaptureAdaptor::toggleSequence()
{
    // handle method call org.kde.kstars.Ekos.Capture.toggleSequence
    parent()->toggleSequence();
}

void CaptureAdaptor::toggleVideo(bool enabled)
{
    // handle method call org.kde.kstars.Ekos.Capture.toggleVideo
    parent()->toggleVideo(enabled);
}


#include "moc_captureadaptor.cpp"
