/****************************************************************************
** Meta object code from reading C++ file 'framingassistantui.h'
**
** Created by: The Qt Meta Object Compiler version 69 (Qt 6.11.1)
**
** WARNING! All changes made in this file will be lost!
*****************************************************************************/

#include "../../../../kstars-3.8.4.1/kstars/ekos/scheduler/framingassistantui.h"
#include <QtCore/qmetatype.h>

#include <QtCore/qtmochelpers.h>

#include <memory>


#include <QtCore/qxptype_traits.h>
#if !defined(Q_MOC_OUTPUT_REVISION)
#error "The header file 'framingassistantui.h' doesn't include <QObject>."
#elif Q_MOC_OUTPUT_REVISION != 69
#error "This file was generated using the moc from 6.11.1. It"
#error "cannot be used with the include files from this version of Qt."
#error "(The moc has changed too much.)"
#endif

#ifndef Q_CONSTINIT
#define Q_CONSTINIT
#endif

QT_WARNING_PUSH
QT_WARNING_DISABLE_DEPRECATED
QT_WARNING_DISABLE_GCC("-Wuseless-cast")
namespace {
struct qt_meta_tag_ZN4Ekos18FramingAssistantUIE_t {};
} // unnamed namespace

template <> constexpr inline auto Ekos::FramingAssistantUI::qt_create_metaobjectdata<qt_meta_tag_ZN4Ekos18FramingAssistantUIE_t>()
{
    namespace QMC = QtMocConstants;
    QtMocHelpers::StringRefStorage qt_stringData {
        "Ekos::FramingAssistantUI",
        "gridSizeChanged",
        "",
        "QSize",
        "value",
        "overlapChanged",
        "positionAngleChanged",
        "sequenceFileChanged",
        "outputDirectoryChanged",
        "targetNameChanged",
        "focusEveryNChanged",
        "alignEveryNChanged",
        "isTrackCheckedChanged",
        "isFocusCheckedChanged",
        "isAlignCheckedChanged",
        "isGuideCheckedChanged",
        "completionConditionChanged",
        "completionConditionArgChanged",
        "updateTargetFOVFromGrid",
        "updateGridFromTargetFOV",
        "constructMosaic",
        "calculateFOV",
        "resetFOV",
        "fetchINDIInformation",
        "rewordStepEvery",
        "v",
        "setMountState",
        "ISD::Mount::Status",
        "setAlignState",
        "AlignState",
        "setGridSize",
        "setOverlap",
        "setPositionAngle",
        "setSequenceFile",
        "setOutputDirectory",
        "setTargetName",
        "setFocusEveryN",
        "setAlignEveryN",
        "setIsTrackChecked",
        "setIsFocusChecked",
        "setIsAlignChecked",
        "setIsGuideChecked",
        "setCompletionCondition",
        "setCompletionConditionArg",
        "createJobs",
        "setCenter",
        "ra0",
        "dec0",
        "gridSize",
        "overlap",
        "positionAngle",
        "sequenceFile",
        "outputDirectory",
        "targetName",
        "focusEveryN",
        "alignEveryN",
        "isTrackChecked",
        "isFocusChecked",
        "isAlignChecked",
        "isGuideChecked",
        "completionCondition",
        "completionConditionArg"
    };

    QtMocHelpers::UintData qt_methods {
        // Signal 'gridSizeChanged'
        QtMocHelpers::SignalData<void(const QSize &)>(1, 2, QMC::AccessPublic, QMetaType::Void, {{
            { 0x80000000 | 3, 4 },
        }}),
        // Signal 'overlapChanged'
        QtMocHelpers::SignalData<void(double)>(5, 2, QMC::AccessPublic, QMetaType::Void, {{
            { QMetaType::Double, 4 },
        }}),
        // Signal 'positionAngleChanged'
        QtMocHelpers::SignalData<void(double)>(6, 2, QMC::AccessPublic, QMetaType::Void, {{
            { QMetaType::Double, 4 },
        }}),
        // Signal 'sequenceFileChanged'
        QtMocHelpers::SignalData<void(const QString &)>(7, 2, QMC::AccessPublic, QMetaType::Void, {{
            { QMetaType::QString, 4 },
        }}),
        // Signal 'outputDirectoryChanged'
        QtMocHelpers::SignalData<void(const QString &)>(8, 2, QMC::AccessPublic, QMetaType::Void, {{
            { QMetaType::QString, 4 },
        }}),
        // Signal 'targetNameChanged'
        QtMocHelpers::SignalData<void(const QString &)>(9, 2, QMC::AccessPublic, QMetaType::Void, {{
            { QMetaType::QString, 4 },
        }}),
        // Signal 'focusEveryNChanged'
        QtMocHelpers::SignalData<void(int)>(10, 2, QMC::AccessPublic, QMetaType::Void, {{
            { QMetaType::Int, 4 },
        }}),
        // Signal 'alignEveryNChanged'
        QtMocHelpers::SignalData<void(int)>(11, 2, QMC::AccessPublic, QMetaType::Void, {{
            { QMetaType::Int, 4 },
        }}),
        // Signal 'isTrackCheckedChanged'
        QtMocHelpers::SignalData<void(bool)>(12, 2, QMC::AccessPublic, QMetaType::Void, {{
            { QMetaType::Bool, 4 },
        }}),
        // Signal 'isFocusCheckedChanged'
        QtMocHelpers::SignalData<void(bool)>(13, 2, QMC::AccessPublic, QMetaType::Void, {{
            { QMetaType::Bool, 4 },
        }}),
        // Signal 'isAlignCheckedChanged'
        QtMocHelpers::SignalData<void(bool)>(14, 2, QMC::AccessPublic, QMetaType::Void, {{
            { QMetaType::Bool, 4 },
        }}),
        // Signal 'isGuideCheckedChanged'
        QtMocHelpers::SignalData<void(bool)>(15, 2, QMC::AccessPublic, QMetaType::Void, {{
            { QMetaType::Bool, 4 },
        }}),
        // Signal 'completionConditionChanged'
        QtMocHelpers::SignalData<void(const QString &)>(16, 2, QMC::AccessPublic, QMetaType::Void, {{
            { QMetaType::QString, 4 },
        }}),
        // Signal 'completionConditionArgChanged'
        QtMocHelpers::SignalData<void(const QString &)>(17, 2, QMC::AccessPublic, QMetaType::Void, {{
            { QMetaType::QString, 4 },
        }}),
        // Slot 'updateTargetFOVFromGrid'
        QtMocHelpers::SlotData<void()>(18, 2, QMC::AccessPublic, QMetaType::Void),
        // Slot 'updateGridFromTargetFOV'
        QtMocHelpers::SlotData<void()>(19, 2, QMC::AccessPublic, QMetaType::Void),
        // Slot 'constructMosaic'
        QtMocHelpers::SlotData<void()>(20, 2, QMC::AccessPublic, QMetaType::Void),
        // Slot 'calculateFOV'
        QtMocHelpers::SlotData<void()>(21, 2, QMC::AccessPublic, QMetaType::Void),
        // Slot 'resetFOV'
        QtMocHelpers::SlotData<void()>(22, 2, QMC::AccessPublic, QMetaType::Void),
        // Slot 'fetchINDIInformation'
        QtMocHelpers::SlotData<void()>(23, 2, QMC::AccessPublic, QMetaType::Void),
        // Slot 'rewordStepEvery'
        QtMocHelpers::SlotData<void(int)>(24, 2, QMC::AccessPublic, QMetaType::Void, {{
            { QMetaType::Int, 25 },
        }}),
        // Slot 'setMountState'
        QtMocHelpers::SlotData<void(ISD::Mount::Status)>(26, 2, QMC::AccessPublic, QMetaType::Void, {{
            { 0x80000000 | 27, 4 },
        }}),
        // Slot 'setAlignState'
        QtMocHelpers::SlotData<void(AlignState)>(28, 2, QMC::AccessPublic, QMetaType::Void, {{
            { 0x80000000 | 29, 4 },
        }}),
        // Method 'setGridSize'
        QtMocHelpers::MethodData<void(const QSize &)>(30, 2, QMC::AccessPublic, QMetaType::Void, {{
            { 0x80000000 | 3, 4 },
        }}),
        // Method 'setOverlap'
        QtMocHelpers::MethodData<void(double)>(31, 2, QMC::AccessPublic, QMetaType::Void, {{
            { QMetaType::Double, 4 },
        }}),
        // Method 'setPositionAngle'
        QtMocHelpers::MethodData<void(double)>(32, 2, QMC::AccessPublic, QMetaType::Void, {{
            { QMetaType::Double, 2 },
        }}),
        // Method 'setSequenceFile'
        QtMocHelpers::MethodData<void(const QString &)>(33, 2, QMC::AccessPublic, QMetaType::Void, {{
            { QMetaType::QString, 4 },
        }}),
        // Method 'setOutputDirectory'
        QtMocHelpers::MethodData<void(const QString &)>(34, 2, QMC::AccessPublic, QMetaType::Void, {{
            { QMetaType::QString, 4 },
        }}),
        // Method 'setTargetName'
        QtMocHelpers::MethodData<void(const QString &)>(35, 2, QMC::AccessPublic, QMetaType::Void, {{
            { QMetaType::QString, 4 },
        }}),
        // Method 'setFocusEveryN'
        QtMocHelpers::MethodData<void(int)>(36, 2, QMC::AccessPublic, QMetaType::Void, {{
            { QMetaType::Int, 4 },
        }}),
        // Method 'setAlignEveryN'
        QtMocHelpers::MethodData<void(int)>(37, 2, QMC::AccessPublic, QMetaType::Void, {{
            { QMetaType::Int, 4 },
        }}),
        // Method 'setIsTrackChecked'
        QtMocHelpers::MethodData<void(bool)>(38, 2, QMC::AccessPublic, QMetaType::Void, {{
            { QMetaType::Bool, 4 },
        }}),
        // Method 'setIsFocusChecked'
        QtMocHelpers::MethodData<void(bool)>(39, 2, QMC::AccessPublic, QMetaType::Void, {{
            { QMetaType::Bool, 4 },
        }}),
        // Method 'setIsAlignChecked'
        QtMocHelpers::MethodData<void(bool)>(40, 2, QMC::AccessPublic, QMetaType::Void, {{
            { QMetaType::Bool, 4 },
        }}),
        // Method 'setIsGuideChecked'
        QtMocHelpers::MethodData<void(bool)>(41, 2, QMC::AccessPublic, QMetaType::Void, {{
            { QMetaType::Bool, 4 },
        }}),
        // Method 'setCompletionCondition'
        QtMocHelpers::MethodData<void(const QString &)>(42, 2, QMC::AccessPublic, QMetaType::Void, {{
            { QMetaType::QString, 4 },
        }}),
        // Method 'setCompletionConditionArg'
        QtMocHelpers::MethodData<void(const QString &)>(43, 2, QMC::AccessPublic, QMetaType::Void, {{
            { QMetaType::QString, 4 },
        }}),
        // Method 'createJobs'
        QtMocHelpers::MethodData<void()>(44, 2, QMC::AccessPublic, QMetaType::Void),
        // Method 'setCenter'
        QtMocHelpers::MethodData<void(double, double)>(45, 2, QMC::AccessPublic, QMetaType::Void, {{
            { QMetaType::Double, 46 }, { QMetaType::Double, 47 },
        }}),
    };
    QtMocHelpers::UintData qt_properties {
        // property 'gridSize'
        QtMocHelpers::PropertyData<QSize>(48, 0x80000000 | 3, QMC::DefaultPropertyFlags | QMC::Writable | QMC::EnumOrFlag | QMC::StdCppSet, 0),
        // property 'overlap'
        QtMocHelpers::PropertyData<double>(49, QMetaType::Double, QMC::DefaultPropertyFlags | QMC::Writable | QMC::StdCppSet, 1),
        // property 'positionAngle'
        QtMocHelpers::PropertyData<double>(50, QMetaType::Double, QMC::DefaultPropertyFlags | QMC::Writable | QMC::StdCppSet, 2),
        // property 'sequenceFile'
        QtMocHelpers::PropertyData<QString>(51, QMetaType::QString, QMC::DefaultPropertyFlags | QMC::Writable | QMC::StdCppSet, 3),
        // property 'outputDirectory'
        QtMocHelpers::PropertyData<QString>(52, QMetaType::QString, QMC::DefaultPropertyFlags | QMC::Writable | QMC::StdCppSet, 4),
        // property 'targetName'
        QtMocHelpers::PropertyData<QString>(53, QMetaType::QString, QMC::DefaultPropertyFlags | QMC::Writable | QMC::StdCppSet, 5),
        // property 'focusEveryN'
        QtMocHelpers::PropertyData<int>(54, QMetaType::Int, QMC::DefaultPropertyFlags | QMC::Writable | QMC::StdCppSet, 6),
        // property 'alignEveryN'
        QtMocHelpers::PropertyData<int>(55, QMetaType::Int, QMC::DefaultPropertyFlags | QMC::Writable | QMC::StdCppSet, 7),
        // property 'isTrackChecked'
        QtMocHelpers::PropertyData<bool>(56, QMetaType::Bool, QMC::DefaultPropertyFlags | QMC::Writable | QMC::StdCppSet, 8),
        // property 'isFocusChecked'
        QtMocHelpers::PropertyData<bool>(57, QMetaType::Bool, QMC::DefaultPropertyFlags | QMC::Writable | QMC::StdCppSet, 9),
        // property 'isAlignChecked'
        QtMocHelpers::PropertyData<bool>(58, QMetaType::Bool, QMC::DefaultPropertyFlags | QMC::Writable | QMC::StdCppSet, 10),
        // property 'isGuideChecked'
        QtMocHelpers::PropertyData<bool>(59, QMetaType::Bool, QMC::DefaultPropertyFlags | QMC::Writable | QMC::StdCppSet, 11),
        // property 'completionCondition'
        QtMocHelpers::PropertyData<QString>(60, QMetaType::QString, QMC::DefaultPropertyFlags | QMC::Writable | QMC::StdCppSet, 12),
        // property 'completionConditionArg'
        QtMocHelpers::PropertyData<QString>(61, QMetaType::QString, QMC::DefaultPropertyFlags | QMC::Writable | QMC::StdCppSet, 13),
    };
    QtMocHelpers::UintData qt_enums {
    };
    return QtMocHelpers::metaObjectData<FramingAssistantUI, qt_meta_tag_ZN4Ekos18FramingAssistantUIE_t>(QMC::MetaObjectFlag{}, qt_stringData,
            qt_methods, qt_properties, qt_enums);
}
Q_CONSTINIT const QMetaObject Ekos::FramingAssistantUI::staticMetaObject = { {
    QMetaObject::SuperData::link<QDialog::staticMetaObject>(),
    qt_staticMetaObjectStaticContent<qt_meta_tag_ZN4Ekos18FramingAssistantUIE_t>.stringdata,
    qt_staticMetaObjectStaticContent<qt_meta_tag_ZN4Ekos18FramingAssistantUIE_t>.data,
    qt_static_metacall,
    nullptr,
    qt_staticMetaObjectRelocatingContent<qt_meta_tag_ZN4Ekos18FramingAssistantUIE_t>.metaTypes,
    nullptr
} };

void Ekos::FramingAssistantUI::qt_static_metacall(QObject *_o, QMetaObject::Call _c, int _id, void **_a)
{
    auto *_t = static_cast<FramingAssistantUI *>(_o);
    if (_c == QMetaObject::InvokeMetaMethod) {
        switch (_id) {
        case 0: _t->gridSizeChanged((*reinterpret_cast<std::add_pointer_t<QSize>>(_a[1]))); break;
        case 1: _t->overlapChanged((*reinterpret_cast<std::add_pointer_t<double>>(_a[1]))); break;
        case 2: _t->positionAngleChanged((*reinterpret_cast<std::add_pointer_t<double>>(_a[1]))); break;
        case 3: _t->sequenceFileChanged((*reinterpret_cast<std::add_pointer_t<QString>>(_a[1]))); break;
        case 4: _t->outputDirectoryChanged((*reinterpret_cast<std::add_pointer_t<QString>>(_a[1]))); break;
        case 5: _t->targetNameChanged((*reinterpret_cast<std::add_pointer_t<QString>>(_a[1]))); break;
        case 6: _t->focusEveryNChanged((*reinterpret_cast<std::add_pointer_t<int>>(_a[1]))); break;
        case 7: _t->alignEveryNChanged((*reinterpret_cast<std::add_pointer_t<int>>(_a[1]))); break;
        case 8: _t->isTrackCheckedChanged((*reinterpret_cast<std::add_pointer_t<bool>>(_a[1]))); break;
        case 9: _t->isFocusCheckedChanged((*reinterpret_cast<std::add_pointer_t<bool>>(_a[1]))); break;
        case 10: _t->isAlignCheckedChanged((*reinterpret_cast<std::add_pointer_t<bool>>(_a[1]))); break;
        case 11: _t->isGuideCheckedChanged((*reinterpret_cast<std::add_pointer_t<bool>>(_a[1]))); break;
        case 12: _t->completionConditionChanged((*reinterpret_cast<std::add_pointer_t<QString>>(_a[1]))); break;
        case 13: _t->completionConditionArgChanged((*reinterpret_cast<std::add_pointer_t<QString>>(_a[1]))); break;
        case 14: _t->updateTargetFOVFromGrid(); break;
        case 15: _t->updateGridFromTargetFOV(); break;
        case 16: _t->constructMosaic(); break;
        case 17: _t->calculateFOV(); break;
        case 18: _t->resetFOV(); break;
        case 19: _t->fetchINDIInformation(); break;
        case 20: _t->rewordStepEvery((*reinterpret_cast<std::add_pointer_t<int>>(_a[1]))); break;
        case 21: _t->setMountState((*reinterpret_cast<std::add_pointer_t<ISD::Mount::Status>>(_a[1]))); break;
        case 22: _t->setAlignState((*reinterpret_cast<std::add_pointer_t<AlignState>>(_a[1]))); break;
        case 23: _t->setGridSize((*reinterpret_cast<std::add_pointer_t<QSize>>(_a[1]))); break;
        case 24: _t->setOverlap((*reinterpret_cast<std::add_pointer_t<double>>(_a[1]))); break;
        case 25: _t->setPositionAngle((*reinterpret_cast<std::add_pointer_t<double>>(_a[1]))); break;
        case 26: _t->setSequenceFile((*reinterpret_cast<std::add_pointer_t<QString>>(_a[1]))); break;
        case 27: _t->setOutputDirectory((*reinterpret_cast<std::add_pointer_t<QString>>(_a[1]))); break;
        case 28: _t->setTargetName((*reinterpret_cast<std::add_pointer_t<QString>>(_a[1]))); break;
        case 29: _t->setFocusEveryN((*reinterpret_cast<std::add_pointer_t<int>>(_a[1]))); break;
        case 30: _t->setAlignEveryN((*reinterpret_cast<std::add_pointer_t<int>>(_a[1]))); break;
        case 31: _t->setIsTrackChecked((*reinterpret_cast<std::add_pointer_t<bool>>(_a[1]))); break;
        case 32: _t->setIsFocusChecked((*reinterpret_cast<std::add_pointer_t<bool>>(_a[1]))); break;
        case 33: _t->setIsAlignChecked((*reinterpret_cast<std::add_pointer_t<bool>>(_a[1]))); break;
        case 34: _t->setIsGuideChecked((*reinterpret_cast<std::add_pointer_t<bool>>(_a[1]))); break;
        case 35: _t->setCompletionCondition((*reinterpret_cast<std::add_pointer_t<QString>>(_a[1]))); break;
        case 36: _t->setCompletionConditionArg((*reinterpret_cast<std::add_pointer_t<QString>>(_a[1]))); break;
        case 37: _t->createJobs(); break;
        case 38: _t->setCenter((*reinterpret_cast<std::add_pointer_t<double>>(_a[1])),(*reinterpret_cast<std::add_pointer_t<double>>(_a[2]))); break;
        default: ;
        }
    }
    if (_c == QMetaObject::RegisterMethodArgumentMetaType) {
        switch (_id) {
        default: *reinterpret_cast<QMetaType *>(_a[0]) = QMetaType(); break;
        case 21:
            switch (*reinterpret_cast<int*>(_a[1])) {
            default: *reinterpret_cast<QMetaType *>(_a[0]) = QMetaType(); break;
            case 0:
                *reinterpret_cast<QMetaType *>(_a[0]) = QMetaType::fromType< ISD::Mount::Status >(); break;
            }
            break;
        }
    }
    if (_c == QMetaObject::IndexOfMethod) {
        if (QtMocHelpers::indexOfMethod<void (FramingAssistantUI::*)(const QSize & )>(_a, &FramingAssistantUI::gridSizeChanged, 0))
            return;
        if (QtMocHelpers::indexOfMethod<void (FramingAssistantUI::*)(double )>(_a, &FramingAssistantUI::overlapChanged, 1))
            return;
        if (QtMocHelpers::indexOfMethod<void (FramingAssistantUI::*)(double )>(_a, &FramingAssistantUI::positionAngleChanged, 2))
            return;
        if (QtMocHelpers::indexOfMethod<void (FramingAssistantUI::*)(const QString & )>(_a, &FramingAssistantUI::sequenceFileChanged, 3))
            return;
        if (QtMocHelpers::indexOfMethod<void (FramingAssistantUI::*)(const QString & )>(_a, &FramingAssistantUI::outputDirectoryChanged, 4))
            return;
        if (QtMocHelpers::indexOfMethod<void (FramingAssistantUI::*)(const QString & )>(_a, &FramingAssistantUI::targetNameChanged, 5))
            return;
        if (QtMocHelpers::indexOfMethod<void (FramingAssistantUI::*)(int )>(_a, &FramingAssistantUI::focusEveryNChanged, 6))
            return;
        if (QtMocHelpers::indexOfMethod<void (FramingAssistantUI::*)(int )>(_a, &FramingAssistantUI::alignEveryNChanged, 7))
            return;
        if (QtMocHelpers::indexOfMethod<void (FramingAssistantUI::*)(bool )>(_a, &FramingAssistantUI::isTrackCheckedChanged, 8))
            return;
        if (QtMocHelpers::indexOfMethod<void (FramingAssistantUI::*)(bool )>(_a, &FramingAssistantUI::isFocusCheckedChanged, 9))
            return;
        if (QtMocHelpers::indexOfMethod<void (FramingAssistantUI::*)(bool )>(_a, &FramingAssistantUI::isAlignCheckedChanged, 10))
            return;
        if (QtMocHelpers::indexOfMethod<void (FramingAssistantUI::*)(bool )>(_a, &FramingAssistantUI::isGuideCheckedChanged, 11))
            return;
        if (QtMocHelpers::indexOfMethod<void (FramingAssistantUI::*)(const QString & )>(_a, &FramingAssistantUI::completionConditionChanged, 12))
            return;
        if (QtMocHelpers::indexOfMethod<void (FramingAssistantUI::*)(const QString & )>(_a, &FramingAssistantUI::completionConditionArgChanged, 13))
            return;
    }
    if (_c == QMetaObject::ReadProperty) {
        void *_v = _a[0];
        switch (_id) {
        case 0: *reinterpret_cast<QSize*>(_v) = _t->gridSize(); break;
        case 1: *reinterpret_cast<double*>(_v) = _t->overlap(); break;
        case 2: *reinterpret_cast<double*>(_v) = _t->positionAngle(); break;
        case 3: *reinterpret_cast<QString*>(_v) = _t->sequenceFile(); break;
        case 4: *reinterpret_cast<QString*>(_v) = _t->outputDirectory(); break;
        case 5: *reinterpret_cast<QString*>(_v) = _t->targetName(); break;
        case 6: *reinterpret_cast<int*>(_v) = _t->focusEveryN(); break;
        case 7: *reinterpret_cast<int*>(_v) = _t->alignEveryN(); break;
        case 8: *reinterpret_cast<bool*>(_v) = _t->isTrackChecked(); break;
        case 9: *reinterpret_cast<bool*>(_v) = _t->isFocusChecked(); break;
        case 10: *reinterpret_cast<bool*>(_v) = _t->isAlignChecked(); break;
        case 11: *reinterpret_cast<bool*>(_v) = _t->isGuideChecked(); break;
        case 12: *reinterpret_cast<QString*>(_v) = _t->completionCondition(); break;
        case 13: *reinterpret_cast<QString*>(_v) = _t->completionConditionArg(); break;
        default: break;
        }
    }
    if (_c == QMetaObject::WriteProperty) {
        void *_v = _a[0];
        switch (_id) {
        case 0: _t->setGridSize(*reinterpret_cast<QSize*>(_v)); break;
        case 1: _t->setOverlap(*reinterpret_cast<double*>(_v)); break;
        case 2: _t->setPositionAngle(*reinterpret_cast<double*>(_v)); break;
        case 3: _t->setSequenceFile(*reinterpret_cast<QString*>(_v)); break;
        case 4: _t->setOutputDirectory(*reinterpret_cast<QString*>(_v)); break;
        case 5: _t->setTargetName(*reinterpret_cast<QString*>(_v)); break;
        case 6: _t->setFocusEveryN(*reinterpret_cast<int*>(_v)); break;
        case 7: _t->setAlignEveryN(*reinterpret_cast<int*>(_v)); break;
        case 8: _t->setIsTrackChecked(*reinterpret_cast<bool*>(_v)); break;
        case 9: _t->setIsFocusChecked(*reinterpret_cast<bool*>(_v)); break;
        case 10: _t->setIsAlignChecked(*reinterpret_cast<bool*>(_v)); break;
        case 11: _t->setIsGuideChecked(*reinterpret_cast<bool*>(_v)); break;
        case 12: _t->setCompletionCondition(*reinterpret_cast<QString*>(_v)); break;
        case 13: _t->setCompletionConditionArg(*reinterpret_cast<QString*>(_v)); break;
        default: break;
        }
    }
}

const QMetaObject *Ekos::FramingAssistantUI::metaObject() const
{
    return QObject::d_ptr->metaObject ? QObject::d_ptr->dynamicMetaObject() : &staticMetaObject;
}

void *Ekos::FramingAssistantUI::qt_metacast(const char *_clname)
{
    if (!_clname) return nullptr;
    if (!strcmp(_clname, qt_staticMetaObjectStaticContent<qt_meta_tag_ZN4Ekos18FramingAssistantUIE_t>.strings))
        return static_cast<void*>(this);
    return QDialog::qt_metacast(_clname);
}

int Ekos::FramingAssistantUI::qt_metacall(QMetaObject::Call _c, int _id, void **_a)
{
    _id = QDialog::qt_metacall(_c, _id, _a);
    if (_id < 0)
        return _id;
    if (_c == QMetaObject::InvokeMetaMethod) {
        if (_id < 39)
            qt_static_metacall(this, _c, _id, _a);
        _id -= 39;
    }
    if (_c == QMetaObject::RegisterMethodArgumentMetaType) {
        if (_id < 39)
            qt_static_metacall(this, _c, _id, _a);
        _id -= 39;
    }
    if (_c == QMetaObject::ReadProperty || _c == QMetaObject::WriteProperty
            || _c == QMetaObject::ResetProperty || _c == QMetaObject::BindableProperty
            || _c == QMetaObject::RegisterPropertyMetaType) {
        qt_static_metacall(this, _c, _id, _a);
        _id -= 14;
    }
    return _id;
}

// SIGNAL 0
void Ekos::FramingAssistantUI::gridSizeChanged(const QSize & _t1)
{
    QMetaObject::activate<void>(this, &staticMetaObject, 0, nullptr, _t1);
}

// SIGNAL 1
void Ekos::FramingAssistantUI::overlapChanged(double _t1)
{
    QMetaObject::activate<void>(this, &staticMetaObject, 1, nullptr, _t1);
}

// SIGNAL 2
void Ekos::FramingAssistantUI::positionAngleChanged(double _t1)
{
    QMetaObject::activate<void>(this, &staticMetaObject, 2, nullptr, _t1);
}

// SIGNAL 3
void Ekos::FramingAssistantUI::sequenceFileChanged(const QString & _t1)
{
    QMetaObject::activate<void>(this, &staticMetaObject, 3, nullptr, _t1);
}

// SIGNAL 4
void Ekos::FramingAssistantUI::outputDirectoryChanged(const QString & _t1)
{
    QMetaObject::activate<void>(this, &staticMetaObject, 4, nullptr, _t1);
}

// SIGNAL 5
void Ekos::FramingAssistantUI::targetNameChanged(const QString & _t1)
{
    QMetaObject::activate<void>(this, &staticMetaObject, 5, nullptr, _t1);
}

// SIGNAL 6
void Ekos::FramingAssistantUI::focusEveryNChanged(int _t1)
{
    QMetaObject::activate<void>(this, &staticMetaObject, 6, nullptr, _t1);
}

// SIGNAL 7
void Ekos::FramingAssistantUI::alignEveryNChanged(int _t1)
{
    QMetaObject::activate<void>(this, &staticMetaObject, 7, nullptr, _t1);
}

// SIGNAL 8
void Ekos::FramingAssistantUI::isTrackCheckedChanged(bool _t1)
{
    QMetaObject::activate<void>(this, &staticMetaObject, 8, nullptr, _t1);
}

// SIGNAL 9
void Ekos::FramingAssistantUI::isFocusCheckedChanged(bool _t1)
{
    QMetaObject::activate<void>(this, &staticMetaObject, 9, nullptr, _t1);
}

// SIGNAL 10
void Ekos::FramingAssistantUI::isAlignCheckedChanged(bool _t1)
{
    QMetaObject::activate<void>(this, &staticMetaObject, 10, nullptr, _t1);
}

// SIGNAL 11
void Ekos::FramingAssistantUI::isGuideCheckedChanged(bool _t1)
{
    QMetaObject::activate<void>(this, &staticMetaObject, 11, nullptr, _t1);
}

// SIGNAL 12
void Ekos::FramingAssistantUI::completionConditionChanged(const QString & _t1)
{
    QMetaObject::activate<void>(this, &staticMetaObject, 12, nullptr, _t1);
}

// SIGNAL 13
void Ekos::FramingAssistantUI::completionConditionArgChanged(const QString & _t1)
{
    QMetaObject::activate<void>(this, &staticMetaObject, 13, nullptr, _t1);
}
QT_WARNING_POP
