/********************************************************************************
** Form generated from reading UI file 'profilewizard.ui'
**
** Created by: Qt User Interface Compiler version 6.11.1
**
** WARNING! All changes made in this file will be lost when recompiling UI file!
********************************************************************************/

#ifndef UI_PROFILEWIZARD_H
#define UI_PROFILEWIZARD_H

#include <QtCore/QVariant>
#include <QtGui/QIcon>
#include <QtSvgWidgets/QSvgWidget>
#include <QtWidgets/QAbstractButton>
#include <QtWidgets/QApplication>
#include <QtWidgets/QCheckBox>
#include <QtWidgets/QDialog>
#include <QtWidgets/QDialogButtonBox>
#include <QtWidgets/QGridLayout>
#include <QtWidgets/QHBoxLayout>
#include <QtWidgets/QLabel>
#include <QtWidgets/QLineEdit>
#include <QtWidgets/QPushButton>
#include <QtWidgets/QRadioButton>
#include <QtWidgets/QSpacerItem>
#include <QtWidgets/QStackedWidget>
#include <QtWidgets/QToolButton>
#include <QtWidgets/QVBoxLayout>
#include <QtWidgets/QWidget>
#include <klocalizedstring.h>

QT_BEGIN_NAMESPACE

class Ui_ProfileWizard
{
public:
    QHBoxLayout *horizontalLayout_2;
    QLabel *wizardPix;
    QVBoxLayout *verticalLayout_9;
    QStackedWidget *wizardContainer;
    QWidget *introPage;
    QVBoxLayout *verticalLayout_8;
    QLabel *intoPageLabel;
    QSpacerItem *verticalSpacer;
    QVBoxLayout *verticalLayout;
    QLabel *label_14;
    QHBoxLayout *horizontalLayout;
    QPushButton *INDIInfoB;
    QPushButton *discoverEkosB;
    QPushButton *videoTutorialsB;
    QSpacerItem *horizontalSpacer_2;
    QPushButton *introNextB;
    QWidget *equipmentLocationPage;
    QVBoxLayout *verticalLayout_2;
    QLabel *label;
    QPushButton *localEquipmentB;
    QHBoxLayout *horizontalLayout_11;
    QPushButton *remoteEquipmentB;
    QWidget *remoteEquipmentSelectionPage;
    QVBoxLayout *verticalLayout_11;
    QLabel *label_22;
    QHBoxLayout *horizontalLayout_4;
    QGridLayout *gridLayout_3;
    QToolButton *equipmentAtikbaseB;
    QPushButton *equipmentOtherB;
    QToolButton *equipmentStellarmateB;
    QSvgWidget *remoteEquipmentSVG;
    QWidget *genericEquipmentPage;
    QVBoxLayout *verticalLayout_3;
    QLabel *label_2;
    QGridLayout *gridLayout_2;
    QLabel *label_3;
    QLineEdit *remoteHostEdit;
    QLabel *label_4;
    QLineEdit *remotePortEdit;
    QLabel *label_5;
    QHBoxLayout *horizontalLayout_3;
    QRadioButton *webManagerYesR;
    QRadioButton *webManagerNoR;
    QRadioButton *webManagerNotSureB;
    QSpacerItem *horizontalSpacer_3;
    QLabel *label_18;
    QHBoxLayout *horizontalLayout_7;
    QSpacerItem *horizontalSpacer_11;
    QPushButton *remoteEquipmentNextB;
    QSpacerItem *horizontalSpacer_12;
    QWidget *piPage;
    QVBoxLayout *verticalLayout_10;
    QLabel *label_8;
    QGridLayout *gridLayout;
    QLabel *label_20;
    QLineEdit *PiHost;
    QPushButton *PiAutoDetectB;
    QLabel *label_21;
    QLineEdit *PiPort;
    QHBoxLayout *horizontalLayout_12;
    QSpacerItem *horizontalSpacer_16;
    QPushButton *stellarMateEquipmentNextB;
    QSpacerItem *horizontalSpacer_17;
    QWidget *windowsLocalPage;
    QVBoxLayout *verticalLayout_4;
    QLabel *label_7;
    QWidget *macLocalPage;
    QVBoxLayout *verticalLayout_5;
    QLabel *label_6;
    QPushButton *useInternalINDIB;
    QPushButton *useExternalINDIB;
    QLabel *label_10;
    QWidget *createProfilePage;
    QVBoxLayout *verticalLayout_7;
    QLabel *label_11;
    QLabel *label_17;
    QHBoxLayout *horizontalLayout_8;
    QLabel *label_12;
    QLineEdit *profileNameEdit;
    QLabel *label_15;
    QHBoxLayout *horizontalLayout_6;
    QRadioButton *useInternalGuiderR;
    QRadioButton *usePHD2R;
    QRadioButton *useLinGuiderR;
    QSpacerItem *horizontalSpacer_4;
    QLabel *label_16;
    QLabel *label_13;
    QHBoxLayout *horizontalLayout_9;
    QVBoxLayout *verticalLayout_6;
    QCheckBox *useJoystickCheck;
    QCheckBox *useRemoteAstrometryCheck;
    QCheckBox *useWatchDogCheck;
    QCheckBox *useSkySafariCheck;
    QSpacerItem *horizontalSpacer_13;
    QPushButton *createProfileB;
    QDialogButtonBox *buttonBox;

    void setupUi(QDialog *ProfileWizard)
    {
        if (ProfileWizard->objectName().isEmpty())
            ProfileWizard->setObjectName("ProfileWizard");
        ProfileWizard->resize(651, 366);
        QSizePolicy sizePolicy(QSizePolicy::Policy::Preferred, QSizePolicy::Policy::Preferred);
        sizePolicy.setHorizontalStretch(0);
        sizePolicy.setVerticalStretch(0);
        sizePolicy.setHeightForWidth(ProfileWizard->sizePolicy().hasHeightForWidth());
        ProfileWizard->setSizePolicy(sizePolicy);
        ProfileWizard->setMaximumSize(QSize(16777215, 366));
        ProfileWizard->setSizeGripEnabled(true);
        horizontalLayout_2 = new QHBoxLayout(ProfileWizard);
        horizontalLayout_2->setSpacing(3);
        horizontalLayout_2->setObjectName("horizontalLayout_2");
        horizontalLayout_2->setContentsMargins(3, 3, 3, 3);
        wizardPix = new QLabel(ProfileWizard);
        wizardPix->setObjectName("wizardPix");
        sizePolicy.setHeightForWidth(wizardPix->sizePolicy().hasHeightForWidth());
        wizardPix->setSizePolicy(sizePolicy);
        wizardPix->setMinimumSize(QSize(120, 360));
        wizardPix->setMaximumSize(QSize(120, 360));
        wizardPix->setFrameShape(QFrame::Box);
        wizardPix->setScaledContents(true);

        horizontalLayout_2->addWidget(wizardPix);

        verticalLayout_9 = new QVBoxLayout();
        verticalLayout_9->setSpacing(3);
        verticalLayout_9->setObjectName("verticalLayout_9");
        wizardContainer = new QStackedWidget(ProfileWizard);
        wizardContainer->setObjectName("wizardContainer");
        sizePolicy.setHeightForWidth(wizardContainer->sizePolicy().hasHeightForWidth());
        wizardContainer->setSizePolicy(sizePolicy);
        wizardContainer->setMinimumSize(QSize(16, 16));
        wizardContainer->setMaximumSize(QSize(16777215, 16777215));
        introPage = new QWidget();
        introPage->setObjectName("introPage");
        verticalLayout_8 = new QVBoxLayout(introPage);
        verticalLayout_8->setObjectName("verticalLayout_8");
        intoPageLabel = new QLabel(introPage);
        intoPageLabel->setObjectName("intoPageLabel");
        sizePolicy.setHeightForWidth(intoPageLabel->sizePolicy().hasHeightForWidth());
        intoPageLabel->setSizePolicy(sizePolicy);
        QFont font;
        font.setPointSize(12);
        intoPageLabel->setFont(font);
        intoPageLabel->setScaledContents(true);
        intoPageLabel->setAlignment(Qt::AlignJustify|Qt::AlignVCenter);
        intoPageLabel->setWordWrap(true);

        verticalLayout_8->addWidget(intoPageLabel);

        verticalSpacer = new QSpacerItem(20, 72, QSizePolicy::Policy::Minimum, QSizePolicy::Policy::Expanding);

        verticalLayout_8->addItem(verticalSpacer);

        verticalLayout = new QVBoxLayout();
        verticalLayout->setObjectName("verticalLayout");
        label_14 = new QLabel(introPage);
        label_14->setObjectName("label_14");
        QFont font1;
        font1.setPointSize(10);
        label_14->setFont(font1);

        verticalLayout->addWidget(label_14);

        horizontalLayout = new QHBoxLayout();
        horizontalLayout->setObjectName("horizontalLayout");
        INDIInfoB = new QPushButton(introPage);
        INDIInfoB->setObjectName("INDIInfoB");
        INDIInfoB->setMinimumSize(QSize(0, 64));
        INDIInfoB->setAutoDefault(false);
        INDIInfoB->setFlat(false);

        horizontalLayout->addWidget(INDIInfoB);

        discoverEkosB = new QPushButton(introPage);
        discoverEkosB->setObjectName("discoverEkosB");
        discoverEkosB->setMinimumSize(QSize(0, 64));
        discoverEkosB->setAutoDefault(false);
        discoverEkosB->setFlat(false);

        horizontalLayout->addWidget(discoverEkosB);

        videoTutorialsB = new QPushButton(introPage);
        videoTutorialsB->setObjectName("videoTutorialsB");
        videoTutorialsB->setMinimumSize(QSize(0, 64));
        videoTutorialsB->setAutoDefault(false);
        videoTutorialsB->setFlat(false);

        horizontalLayout->addWidget(videoTutorialsB);

        horizontalSpacer_2 = new QSpacerItem(40, 20, QSizePolicy::Policy::Expanding, QSizePolicy::Policy::Minimum);

        horizontalLayout->addItem(horizontalSpacer_2);

        introNextB = new QPushButton(introPage);
        introNextB->setObjectName("introNextB");
        introNextB->setMinimumSize(QSize(0, 64));
        introNextB->setAutoDefault(false);

        horizontalLayout->addWidget(introNextB);


        verticalLayout->addLayout(horizontalLayout);


        verticalLayout_8->addLayout(verticalLayout);

        wizardContainer->addWidget(introPage);
        equipmentLocationPage = new QWidget();
        equipmentLocationPage->setObjectName("equipmentLocationPage");
        verticalLayout_2 = new QVBoxLayout(equipmentLocationPage);
        verticalLayout_2->setObjectName("verticalLayout_2");
        label = new QLabel(equipmentLocationPage);
        label->setObjectName("label");
        QFont font2;
        font2.setFamilies({QString::fromUtf8("Arial Black")});
        font2.setPointSize(12);
        label->setFont(font2);

        verticalLayout_2->addWidget(label);

        localEquipmentB = new QPushButton(equipmentLocationPage);
        localEquipmentB->setObjectName("localEquipmentB");
        QSizePolicy sizePolicy1(QSizePolicy::Policy::MinimumExpanding, QSizePolicy::Policy::MinimumExpanding);
        sizePolicy1.setHorizontalStretch(0);
        sizePolicy1.setVerticalStretch(0);
        sizePolicy1.setHeightForWidth(localEquipmentB->sizePolicy().hasHeightForWidth());
        localEquipmentB->setSizePolicy(sizePolicy1);
        localEquipmentB->setFont(font2);
        localEquipmentB->setFocusPolicy(Qt::ClickFocus);
        QIcon icon;
        QString iconThemeName = QString::fromUtf8("computer");
        if (QIcon::hasThemeIcon(iconThemeName)) {
            icon = QIcon::fromTheme(iconThemeName);
        } else {
            icon.addFile(QString::fromUtf8("."), QSize(), QIcon::Mode::Normal, QIcon::State::Off);
        }
        localEquipmentB->setIcon(icon);
        localEquipmentB->setIconSize(QSize(64, 64));
        localEquipmentB->setAutoDefault(false);
        localEquipmentB->setFlat(false);

        verticalLayout_2->addWidget(localEquipmentB);

        horizontalLayout_11 = new QHBoxLayout();
        horizontalLayout_11->setObjectName("horizontalLayout_11");
        remoteEquipmentB = new QPushButton(equipmentLocationPage);
        remoteEquipmentB->setObjectName("remoteEquipmentB");
        sizePolicy1.setHeightForWidth(remoteEquipmentB->sizePolicy().hasHeightForWidth());
        remoteEquipmentB->setSizePolicy(sizePolicy1);
        remoteEquipmentB->setFont(font2);
        remoteEquipmentB->setFocusPolicy(Qt::ClickFocus);
        QIcon icon1;
        iconThemeName = QString::fromUtf8("applications-internet");
        if (QIcon::hasThemeIcon(iconThemeName)) {
            icon1 = QIcon::fromTheme(iconThemeName);
        } else {
            icon1.addFile(QString::fromUtf8("."), QSize(), QIcon::Mode::Normal, QIcon::State::Off);
        }
        remoteEquipmentB->setIcon(icon1);
        remoteEquipmentB->setIconSize(QSize(64, 64));
        remoteEquipmentB->setAutoDefault(false);

        horizontalLayout_11->addWidget(remoteEquipmentB);


        verticalLayout_2->addLayout(horizontalLayout_11);

        wizardContainer->addWidget(equipmentLocationPage);
        remoteEquipmentSelectionPage = new QWidget();
        remoteEquipmentSelectionPage->setObjectName("remoteEquipmentSelectionPage");
        verticalLayout_11 = new QVBoxLayout(remoteEquipmentSelectionPage);
        verticalLayout_11->setObjectName("verticalLayout_11");
        label_22 = new QLabel(remoteEquipmentSelectionPage);
        label_22->setObjectName("label_22");
        QSizePolicy sizePolicy2(QSizePolicy::Policy::Preferred, QSizePolicy::Policy::Minimum);
        sizePolicy2.setHorizontalStretch(0);
        sizePolicy2.setVerticalStretch(0);
        sizePolicy2.setHeightForWidth(label_22->sizePolicy().hasHeightForWidth());
        label_22->setSizePolicy(sizePolicy2);
        label_22->setFont(font2);

        verticalLayout_11->addWidget(label_22);

        horizontalLayout_4 = new QHBoxLayout();
        horizontalLayout_4->setObjectName("horizontalLayout_4");
        gridLayout_3 = new QGridLayout();
        gridLayout_3->setObjectName("gridLayout_3");
        equipmentAtikbaseB = new QToolButton(remoteEquipmentSelectionPage);
        equipmentAtikbaseB->setObjectName("equipmentAtikbaseB");
        equipmentAtikbaseB->setMinimumSize(QSize(64, 64));
        equipmentAtikbaseB->setMaximumSize(QSize(128, 128));
        equipmentAtikbaseB->setIconSize(QSize(48, 48));
        equipmentAtikbaseB->setToolButtonStyle(Qt::ToolButtonTextUnderIcon);

        gridLayout_3->addWidget(equipmentAtikbaseB, 0, 1, 1, 1);

        equipmentOtherB = new QPushButton(remoteEquipmentSelectionPage);
        equipmentOtherB->setObjectName("equipmentOtherB");
        equipmentOtherB->setMinimumSize(QSize(64, 64));
        equipmentOtherB->setMaximumSize(QSize(128, 128));

        gridLayout_3->addWidget(equipmentOtherB, 1, 0, 1, 1);

        equipmentStellarmateB = new QToolButton(remoteEquipmentSelectionPage);
        equipmentStellarmateB->setObjectName("equipmentStellarmateB");
        equipmentStellarmateB->setMinimumSize(QSize(64, 64));
        equipmentStellarmateB->setMaximumSize(QSize(128, 128));
        equipmentStellarmateB->setIconSize(QSize(48, 48));
        equipmentStellarmateB->setToolButtonStyle(Qt::ToolButtonTextUnderIcon);

        gridLayout_3->addWidget(equipmentStellarmateB, 0, 0, 1, 1);


        horizontalLayout_4->addLayout(gridLayout_3);

        remoteEquipmentSVG = new QSvgWidget(remoteEquipmentSelectionPage);
        remoteEquipmentSVG->setObjectName("remoteEquipmentSVG");
        remoteEquipmentSVG->setMinimumSize(QSize(99, 250));
        remoteEquipmentSVG->setMaximumSize(QSize(99, 250));

        horizontalLayout_4->addWidget(remoteEquipmentSVG);


        verticalLayout_11->addLayout(horizontalLayout_4);

        wizardContainer->addWidget(remoteEquipmentSelectionPage);
        genericEquipmentPage = new QWidget();
        genericEquipmentPage->setObjectName("genericEquipmentPage");
        verticalLayout_3 = new QVBoxLayout(genericEquipmentPage);
        verticalLayout_3->setObjectName("verticalLayout_3");
        label_2 = new QLabel(genericEquipmentPage);
        label_2->setObjectName("label_2");
        sizePolicy2.setHeightForWidth(label_2->sizePolicy().hasHeightForWidth());
        label_2->setSizePolicy(sizePolicy2);
        label_2->setFont(font2);

        verticalLayout_3->addWidget(label_2);

        gridLayout_2 = new QGridLayout();
        gridLayout_2->setObjectName("gridLayout_2");
        label_3 = new QLabel(genericEquipmentPage);
        label_3->setObjectName("label_3");

        gridLayout_2->addWidget(label_3, 0, 0, 1, 1);

        remoteHostEdit = new QLineEdit(genericEquipmentPage);
        remoteHostEdit->setObjectName("remoteHostEdit");

        gridLayout_2->addWidget(remoteHostEdit, 0, 1, 1, 1);

        label_4 = new QLabel(genericEquipmentPage);
        label_4->setObjectName("label_4");

        gridLayout_2->addWidget(label_4, 1, 0, 1, 1);

        remotePortEdit = new QLineEdit(genericEquipmentPage);
        remotePortEdit->setObjectName("remotePortEdit");

        gridLayout_2->addWidget(remotePortEdit, 1, 1, 1, 1);


        verticalLayout_3->addLayout(gridLayout_2);

        label_5 = new QLabel(genericEquipmentPage);
        label_5->setObjectName("label_5");
        label_5->setFont(font2);
        label_5->setWordWrap(true);

        verticalLayout_3->addWidget(label_5);

        horizontalLayout_3 = new QHBoxLayout();
        horizontalLayout_3->setObjectName("horizontalLayout_3");
        webManagerYesR = new QRadioButton(genericEquipmentPage);
        webManagerYesR->setObjectName("webManagerYesR");

        horizontalLayout_3->addWidget(webManagerYesR);

        webManagerNoR = new QRadioButton(genericEquipmentPage);
        webManagerNoR->setObjectName("webManagerNoR");

        horizontalLayout_3->addWidget(webManagerNoR);

        webManagerNotSureB = new QRadioButton(genericEquipmentPage);
        webManagerNotSureB->setObjectName("webManagerNotSureB");
        webManagerNotSureB->setChecked(true);

        horizontalLayout_3->addWidget(webManagerNotSureB);

        horizontalSpacer_3 = new QSpacerItem(40, 20, QSizePolicy::Policy::Expanding, QSizePolicy::Policy::Minimum);

        horizontalLayout_3->addItem(horizontalSpacer_3);


        verticalLayout_3->addLayout(horizontalLayout_3);

        label_18 = new QLabel(genericEquipmentPage);
        label_18->setObjectName("label_18");
        label_18->setFont(font1);
        label_18->setAlignment(Qt::AlignJustify|Qt::AlignVCenter);
        label_18->setWordWrap(true);

        verticalLayout_3->addWidget(label_18);

        horizontalLayout_7 = new QHBoxLayout();
        horizontalLayout_7->setObjectName("horizontalLayout_7");
        horizontalSpacer_11 = new QSpacerItem(40, 20, QSizePolicy::Policy::Expanding, QSizePolicy::Policy::Minimum);

        horizontalLayout_7->addItem(horizontalSpacer_11);

        remoteEquipmentNextB = new QPushButton(genericEquipmentPage);
        remoteEquipmentNextB->setObjectName("remoteEquipmentNextB");
        remoteEquipmentNextB->setMinimumSize(QSize(0, 64));
        remoteEquipmentNextB->setAutoDefault(false);

        horizontalLayout_7->addWidget(remoteEquipmentNextB);

        horizontalSpacer_12 = new QSpacerItem(40, 20, QSizePolicy::Policy::Expanding, QSizePolicy::Policy::Minimum);

        horizontalLayout_7->addItem(horizontalSpacer_12);


        verticalLayout_3->addLayout(horizontalLayout_7);

        wizardContainer->addWidget(genericEquipmentPage);
        piPage = new QWidget();
        piPage->setObjectName("piPage");
        verticalLayout_10 = new QVBoxLayout(piPage);
        verticalLayout_10->setObjectName("verticalLayout_10");
        label_8 = new QLabel(piPage);
        label_8->setObjectName("label_8");
        sizePolicy2.setHeightForWidth(label_8->sizePolicy().hasHeightForWidth());
        label_8->setSizePolicy(sizePolicy2);
        label_8->setFont(font2);
        label_8->setWordWrap(true);

        verticalLayout_10->addWidget(label_8);

        gridLayout = new QGridLayout();
        gridLayout->setObjectName("gridLayout");
        label_20 = new QLabel(piPage);
        label_20->setObjectName("label_20");

        gridLayout->addWidget(label_20, 0, 0, 1, 1);

        PiHost = new QLineEdit(piPage);
        PiHost->setObjectName("PiHost");

        gridLayout->addWidget(PiHost, 0, 1, 1, 1);

        PiAutoDetectB = new QPushButton(piPage);
        PiAutoDetectB->setObjectName("PiAutoDetectB");
        PiAutoDetectB->setEnabled(false);

        gridLayout->addWidget(PiAutoDetectB, 0, 2, 1, 1);

        label_21 = new QLabel(piPage);
        label_21->setObjectName("label_21");

        gridLayout->addWidget(label_21, 1, 0, 1, 1);

        PiPort = new QLineEdit(piPage);
        PiPort->setObjectName("PiPort");

        gridLayout->addWidget(PiPort, 1, 1, 1, 1);


        verticalLayout_10->addLayout(gridLayout);

        horizontalLayout_12 = new QHBoxLayout();
        horizontalLayout_12->setObjectName("horizontalLayout_12");
        horizontalSpacer_16 = new QSpacerItem(40, 20, QSizePolicy::Policy::Expanding, QSizePolicy::Policy::Minimum);

        horizontalLayout_12->addItem(horizontalSpacer_16);

        stellarMateEquipmentNextB = new QPushButton(piPage);
        stellarMateEquipmentNextB->setObjectName("stellarMateEquipmentNextB");
        stellarMateEquipmentNextB->setMinimumSize(QSize(0, 64));
        stellarMateEquipmentNextB->setAutoDefault(false);

        horizontalLayout_12->addWidget(stellarMateEquipmentNextB);

        horizontalSpacer_17 = new QSpacerItem(40, 20, QSizePolicy::Policy::Expanding, QSizePolicy::Policy::Minimum);

        horizontalLayout_12->addItem(horizontalSpacer_17);


        verticalLayout_10->addLayout(horizontalLayout_12);

        wizardContainer->addWidget(piPage);
        windowsLocalPage = new QWidget();
        windowsLocalPage->setObjectName("windowsLocalPage");
        verticalLayout_4 = new QVBoxLayout(windowsLocalPage);
        verticalLayout_4->setObjectName("verticalLayout_4");
        label_7 = new QLabel(windowsLocalPage);
        label_7->setObjectName("label_7");
        label_7->setFont(font1);
        label_7->setWordWrap(true);

        verticalLayout_4->addWidget(label_7);

        wizardContainer->addWidget(windowsLocalPage);
        macLocalPage = new QWidget();
        macLocalPage->setObjectName("macLocalPage");
        verticalLayout_5 = new QVBoxLayout(macLocalPage);
        verticalLayout_5->setObjectName("verticalLayout_5");
        label_6 = new QLabel(macLocalPage);
        label_6->setObjectName("label_6");
        QFont font3;
        font3.setFamilies({QString::fromUtf8("Arial Black")});
        font3.setPointSize(14);
        label_6->setFont(font3);

        verticalLayout_5->addWidget(label_6);

        useInternalINDIB = new QPushButton(macLocalPage);
        useInternalINDIB->setObjectName("useInternalINDIB");
        QSizePolicy sizePolicy3(QSizePolicy::Policy::MinimumExpanding, QSizePolicy::Policy::Preferred);
        sizePolicy3.setHorizontalStretch(0);
        sizePolicy3.setVerticalStretch(0);
        sizePolicy3.setHeightForWidth(useInternalINDIB->sizePolicy().hasHeightForWidth());
        useInternalINDIB->setSizePolicy(sizePolicy3);
        useInternalINDIB->setFont(font2);
        useInternalINDIB->setFocusPolicy(Qt::ClickFocus);
        QIcon icon2;
        iconThemeName = QString::fromUtf8("kstars_indi");
        if (QIcon::hasThemeIcon(iconThemeName)) {
            icon2 = QIcon::fromTheme(iconThemeName);
        } else {
            icon2.addFile(QString::fromUtf8("."), QSize(), QIcon::Mode::Normal, QIcon::State::Off);
        }
        useInternalINDIB->setIcon(icon2);
        useInternalINDIB->setIconSize(QSize(64, 64));
        useInternalINDIB->setAutoDefault(false);

        verticalLayout_5->addWidget(useInternalINDIB);

        useExternalINDIB = new QPushButton(macLocalPage);
        useExternalINDIB->setObjectName("useExternalINDIB");
        sizePolicy3.setHeightForWidth(useExternalINDIB->sizePolicy().hasHeightForWidth());
        useExternalINDIB->setSizePolicy(sizePolicy3);
        useExternalINDIB->setFont(font2);
        useExternalINDIB->setFocusPolicy(Qt::ClickFocus);
        QIcon icon3;
        iconThemeName = QString::fromUtf8("draw-cuboid");
        if (QIcon::hasThemeIcon(iconThemeName)) {
            icon3 = QIcon::fromTheme(iconThemeName);
        } else {
            icon3.addFile(QString::fromUtf8("."), QSize(), QIcon::Mode::Normal, QIcon::State::Off);
        }
        useExternalINDIB->setIcon(icon3);
        useExternalINDIB->setIconSize(QSize(64, 64));
        useExternalINDIB->setAutoDefault(false);

        verticalLayout_5->addWidget(useExternalINDIB);

        label_10 = new QLabel(macLocalPage);
        label_10->setObjectName("label_10");
        label_10->setFont(font1);
        label_10->setAlignment(Qt::AlignJustify|Qt::AlignVCenter);
        label_10->setWordWrap(true);

        verticalLayout_5->addWidget(label_10);

        wizardContainer->addWidget(macLocalPage);
        createProfilePage = new QWidget();
        createProfilePage->setObjectName("createProfilePage");
        verticalLayout_7 = new QVBoxLayout(createProfilePage);
        verticalLayout_7->setObjectName("verticalLayout_7");
        label_11 = new QLabel(createProfilePage);
        label_11->setObjectName("label_11");
        QFont font4;
        font4.setPointSize(14);
        label_11->setFont(font4);

        verticalLayout_7->addWidget(label_11);

        label_17 = new QLabel(createProfilePage);
        label_17->setObjectName("label_17");
        label_17->setFont(font2);

        verticalLayout_7->addWidget(label_17);

        horizontalLayout_8 = new QHBoxLayout();
        horizontalLayout_8->setObjectName("horizontalLayout_8");
        label_12 = new QLabel(createProfilePage);
        label_12->setObjectName("label_12");

        horizontalLayout_8->addWidget(label_12);

        profileNameEdit = new QLineEdit(createProfilePage);
        profileNameEdit->setObjectName("profileNameEdit");

        horizontalLayout_8->addWidget(profileNameEdit);


        verticalLayout_7->addLayout(horizontalLayout_8);

        label_15 = new QLabel(createProfilePage);
        label_15->setObjectName("label_15");
        label_15->setFont(font2);

        verticalLayout_7->addWidget(label_15);

        horizontalLayout_6 = new QHBoxLayout();
        horizontalLayout_6->setObjectName("horizontalLayout_6");
        useInternalGuiderR = new QRadioButton(createProfilePage);
        useInternalGuiderR->setObjectName("useInternalGuiderR");
        useInternalGuiderR->setChecked(true);

        horizontalLayout_6->addWidget(useInternalGuiderR);

        usePHD2R = new QRadioButton(createProfilePage);
        usePHD2R->setObjectName("usePHD2R");

        horizontalLayout_6->addWidget(usePHD2R);

        useLinGuiderR = new QRadioButton(createProfilePage);
        useLinGuiderR->setObjectName("useLinGuiderR");

        horizontalLayout_6->addWidget(useLinGuiderR);

        horizontalSpacer_4 = new QSpacerItem(40, 20, QSizePolicy::Policy::Expanding, QSizePolicy::Policy::Minimum);

        horizontalLayout_6->addItem(horizontalSpacer_4);


        verticalLayout_7->addLayout(horizontalLayout_6);

        label_16 = new QLabel(createProfilePage);
        label_16->setObjectName("label_16");
        label_16->setFont(font1);
        label_16->setAlignment(Qt::AlignJustify|Qt::AlignVCenter);
        label_16->setWordWrap(true);

        verticalLayout_7->addWidget(label_16);

        label_13 = new QLabel(createProfilePage);
        label_13->setObjectName("label_13");
        label_13->setFont(font2);

        verticalLayout_7->addWidget(label_13);

        horizontalLayout_9 = new QHBoxLayout();
        horizontalLayout_9->setObjectName("horizontalLayout_9");
        verticalLayout_6 = new QVBoxLayout();
        verticalLayout_6->setObjectName("verticalLayout_6");
        useJoystickCheck = new QCheckBox(createProfilePage);
        useJoystickCheck->setObjectName("useJoystickCheck");
        useJoystickCheck->setEnabled(false);

        verticalLayout_6->addWidget(useJoystickCheck);

        useRemoteAstrometryCheck = new QCheckBox(createProfilePage);
        useRemoteAstrometryCheck->setObjectName("useRemoteAstrometryCheck");
        useRemoteAstrometryCheck->setEnabled(false);

        verticalLayout_6->addWidget(useRemoteAstrometryCheck);

        useWatchDogCheck = new QCheckBox(createProfilePage);
        useWatchDogCheck->setObjectName("useWatchDogCheck");
        useWatchDogCheck->setEnabled(false);

        verticalLayout_6->addWidget(useWatchDogCheck);

        useSkySafariCheck = new QCheckBox(createProfilePage);
        useSkySafariCheck->setObjectName("useSkySafariCheck");

        verticalLayout_6->addWidget(useSkySafariCheck);


        horizontalLayout_9->addLayout(verticalLayout_6);

        horizontalSpacer_13 = new QSpacerItem(40, 20, QSizePolicy::Policy::Expanding, QSizePolicy::Policy::Minimum);

        horizontalLayout_9->addItem(horizontalSpacer_13);

        createProfileB = new QPushButton(createProfilePage);
        createProfileB->setObjectName("createProfileB");
        createProfileB->setMinimumSize(QSize(0, 64));
        createProfileB->setFont(font4);
        QIcon icon4;
        icon4.addFile(QString::fromUtf8(":/icons/AlignSuccess.svg"), QSize(), QIcon::Mode::Normal, QIcon::State::Off);
        createProfileB->setIcon(icon4);
        createProfileB->setIconSize(QSize(64, 64));
        createProfileB->setAutoDefault(false);

        horizontalLayout_9->addWidget(createProfileB);


        verticalLayout_7->addLayout(horizontalLayout_9);

        wizardContainer->addWidget(createProfilePage);

        verticalLayout_9->addWidget(wizardContainer);

        buttonBox = new QDialogButtonBox(ProfileWizard);
        buttonBox->setObjectName("buttonBox");
        buttonBox->setStandardButtons(QDialogButtonBox::Close|QDialogButtonBox::Help|QDialogButtonBox::Reset);

        verticalLayout_9->addWidget(buttonBox);


        horizontalLayout_2->addLayout(verticalLayout_9);


        retranslateUi(ProfileWizard);

        wizardContainer->setCurrentIndex(0);
        INDIInfoB->setDefault(false);
        discoverEkosB->setDefault(false);
        videoTutorialsB->setDefault(false);
        localEquipmentB->setDefault(false);


        QMetaObject::connectSlotsByName(ProfileWizard);
    } // setupUi

    void retranslateUi(QDialog *ProfileWizard)
    {
        ProfileWizard->setWindowTitle(tr2i18n("Ekos Profile Wizard", nullptr));
        intoPageLabel->setText(tr2i18n("<html><head/><body><p>Welcome to the <span style=\" font-weight:600;\">Ekos Profile Wizard</span></p><p>Ekos is the premier observatory control and automation platform. With Ekos, you can capture images and gather scientific data with ease. This Wizard will help you create your equipment profile. You will be asked to verify some basic information. </p><p>Please click <span style=\" font-weight:600;\">next</span> to continue. </p></body></html>", nullptr));
        label_14->setText(tr2i18n("<html><head/><body><p><span style=\" font-weight:600;\">Online Resources:</span></p></body></html>", nullptr));
        INDIInfoB->setText(tr2i18n("What is\n"
"INDI?", nullptr));
        discoverEkosB->setText(tr2i18n("Discover\n"
"Ekos", nullptr));
        videoTutorialsB->setText(tr2i18n("Video\n"
"Tutorials", nullptr));
        introNextB->setText(tr2i18n("Next", nullptr));
        label->setText(tr2i18n("Where is your equipment connected?", nullptr));
        localEquipmentB->setText(tr2i18n("Equipment is attached\n"
"to this device", nullptr));
        remoteEquipmentB->setText(tr2i18n("Equipment is attached to\n"
"a remote device", nullptr));
        label_22->setText(tr2i18n("<html><head/><body><p>Which <span style=\" color:#ff5500;\">remote</span> device is the equipment connected to?</p></body></html>", nullptr));
        equipmentAtikbaseB->setText(tr2i18n("AtikBase", nullptr));
        equipmentOtherB->setText(tr2i18n("Other", nullptr));
        equipmentStellarmateB->setText(tr2i18n("StellarMate", nullptr));
        label_2->setText(tr2i18n("Enter the remote computer information:", nullptr));
        label_3->setText(tr2i18n("Host:", nullptr));
        remoteHostEdit->setPlaceholderText(tr2i18n("Enter IP address or host name", nullptr));
        label_4->setText(tr2i18n("Port:", nullptr));
        remotePortEdit->setText(tr2i18n("7624", nullptr));
        label_5->setText(tr2i18n("<html><head/><body><p><a href=\"https://github.com/knro/indiwebmanager\"><span style=\" text-decoration: underline; color:#007af4;\">INDI Web Manager</span></a> running on the Remote Computer?</p></body></html>", nullptr));
        webManagerYesR->setText(tr2i18n("Yes", nullptr));
        webManagerNoR->setText(tr2i18n("No", nullptr));
        webManagerNotSureB->setText(tr2i18n("Not Sure", nullptr));
        label_18->setText(tr2i18n("<html><head/><body><p><span style=\" font-weight:600;\">Tip</span>: <span style=\" font-style:italic;\">INDI Web Manager</span> is a service that runs on remote devices to help you start and stop INDI services remotely.</p></body></html>", nullptr));
        remoteEquipmentNextB->setText(tr2i18n("Next", nullptr));
        label_8->setText(tr2i18n("Enter host name and port. If you do not know, leave as is.", nullptr));
        label_20->setText(tr2i18n("Host:", nullptr));
        PiHost->setText(tr2i18n("stellarmate.local", nullptr));
        PiHost->setPlaceholderText(tr2i18n("Enter IP address or host name", nullptr));
        PiAutoDetectB->setText(tr2i18n("Auto Detect", nullptr));
        label_21->setText(tr2i18n("Port:", nullptr));
        PiPort->setText(tr2i18n("7624", nullptr));
        stellarMateEquipmentNextB->setText(tr2i18n("Next", nullptr));
        label_7->setText(tr2i18n("<html><head/><body><p>Using Ekos locally on Windows is not supported. You must connect to a remote gadget to control devices.</p></body></html>", nullptr));
        label_6->setText(tr2i18n("Which INDI Server do you want to use?", nullptr));
        useInternalINDIB->setText(tr2i18n("Internal INDI\n"
"Server", nullptr));
        useExternalINDIB->setText(tr2i18n("External INDI\n"
"Server", nullptr));
        label_10->setText(tr2i18n("<html><head/><body><p><span style=\" font-weight:600;\">Tip</span>: External INDI Server can be <a href=\"http://www.cloudmakers.eu/indigoserver/\"><span style=\" text-decoration: underline; color:#007af4;\">INDI Server for OSX</span></a> or an INDI Server launched manually locally. If unsure, select Internal INDI Server.</p></body></html>", nullptr));
        label_11->setText(tr2i18n("<html><head/><body><p>You're almost done...</p></body></html>", nullptr));
        label_17->setText(tr2i18n("<html><head/><body><p>What do you want to name your profile?</p></body></html>", nullptr));
        label_12->setText(tr2i18n("Profile:", nullptr));
        profileNameEdit->setText(tr2i18n("My Astro Gear", nullptr));
        label_15->setText(tr2i18n("<html><head/><body><p>Which guider application do you want to use?</p></body></html>", nullptr));
        useInternalGuiderR->setText(tr2i18n("Internal Guider", nullptr));
        usePHD2R->setText(tr2i18n("PHD2", nullptr));
        useLinGuiderR->setText(tr2i18n("Lin Guider", nullptr));
        label_16->setText(tr2i18n("<html><head/><body><p><span style=\" font-weight:600;\">Tip</span>: Internal Guider is recommended. Using external guider applications requires additional setup instructions outside the scope of Ekos.</p></body></html>", nullptr));
        label_13->setText(tr2i18n("<html><head/><body><p>Do you want to select additional services?</p></body></html>", nullptr));
#if QT_CONFIG(tooltip)
        useJoystickCheck->setToolTip(tr2i18n("<html><head/><body><p>Use INDI Joystick driver to enable control of mounts, domes, and focusers with any compatible game pad.</p></body></html>", nullptr));
#endif // QT_CONFIG(tooltip)
        useJoystickCheck->setText(tr2i18n("Joystick", nullptr));
#if QT_CONFIG(tooltip)
        useRemoteAstrometryCheck->setToolTip(tr2i18n("<html><head/><body><p>If the remote computer has astrometry.net installed, you can run the remote astrometry driver and use it to solve images in Ekos Align module.</p></body></html>", nullptr));
#endif // QT_CONFIG(tooltip)
        useRemoteAstrometryCheck->setText(tr2i18n("Remote Astrometry", nullptr));
#if QT_CONFIG(tooltip)
        useWatchDogCheck->setToolTip(tr2i18n("<html><head/><body><p>Use the INDI WatchDog driver. It monitors connection between your remote equipment and Ekos. If the communication is lost between the two, the WatchDog driver goes into safe mode and executes a shutdown procedure to protect your equipment.</p></body></html>", nullptr));
#endif // QT_CONFIG(tooltip)
        useWatchDogCheck->setText(tr2i18n("Watch Dog", nullptr));
#if QT_CONFIG(tooltip)
        useSkySafariCheck->setToolTip(tr2i18n("<html><head/><body><p>If you plan to use SkySafari to monitor and/or control your mount, check this box to start INDI SkySafari Server. You can connect SkySafari to this server and it shall enable you to connect and control your mount. For more details, please check the <a href=\"https://indilib.org/devices/telescopes/skysafari.html\"><span style=\" text-decoration: underline; color:#007af4;\">INDI SkySafari Documentation.</span></a></p></body></html>", nullptr));
#endif // QT_CONFIG(tooltip)
        useSkySafariCheck->setText(tr2i18n("SkySafari", nullptr));
        createProfileB->setText(tr2i18n("Create Profile &&\n"
"Select Devices", nullptr));
    } // retranslateUi

};

namespace Ui {
    class ProfileWizard: public Ui_ProfileWizard {};
} // namespace Ui

QT_END_NAMESPACE

#endif // PROFILEWIZARD_H

