/********************************************************************************
** Form generated from reading UI file 'details_position.ui'
**
** Created by: Qt User Interface Compiler version 6.11.1
**
** WARNING! All changes made in this file will be lost when recompiling UI file!
********************************************************************************/

#ifndef UI_DETAILS_POSITION_H
#define UI_DETAILS_POSITION_H

#include <QtCore/QVariant>
#include <QtWidgets/QApplication>
#include <QtWidgets/QFrame>
#include <QtWidgets/QGridLayout>
#include <QtWidgets/QHBoxLayout>
#include <QtWidgets/QLabel>
#include <QtWidgets/QSpacerItem>
#include <QtWidgets/QVBoxLayout>
#include <QtWidgets/QWidget>
#include <klocalizedstring.h>

QT_BEGIN_NAMESPACE

class Ui_DetailsPosition
{
public:
    QVBoxLayout *vboxLayout;
    QVBoxLayout *vboxLayout1;
    QLabel *CoordTitle;
    QFrame *CoordFrame;
    QVBoxLayout *vboxLayout2;
    QGridLayout *gridLayout;
    QLabel *DecLabel;
    QSpacerItem *spacerItem;
    QLabel *RA0Label;
    QLabel *Dec0;
    QLabel *Airmass;
    QLabel *RALabel;
    QLabel *RA0;
    QSpacerItem *spacerItem1;
    QLabel *HA;
    QLabel *Dec0Label;
    QLabel *Dec;
    QLabel *Alt;
    QLabel *AzLabel;
    QSpacerItem *spacerItem2;
    QLabel *AirmassLabel;
    QLabel *AltLabel;
    QLabel *Az;
    QLabel *HALabel;
    QSpacerItem *spacer;
    QLabel *RA;
    QFrame *line;
    QSpacerItem *spacerItem3;
    QSpacerItem *spacerItem4;
    QVBoxLayout *vboxLayout3;
    QLabel *RSTTitle;
    QFrame *RSTFrame;
    QVBoxLayout *vboxLayout4;
    QHBoxLayout *hboxLayout;
    QGridLayout *gridLayout1;
    QLabel *TimeSetLabel;
    QLabel *TimeTransitLabel;
    QLabel *TimeRiseLabel;
    QLabel *TimeRise;
    QLabel *TimeTransit;
    QLabel *TimeSet;
    QSpacerItem *spacerItem5;
    QGridLayout *gridLayout2;
    QLabel *AzSetLabel;
    QLabel *AltTransitLabel;
    QLabel *AzRiseLabel;
    QLabel *AzRise;
    QLabel *AltTransit;
    QLabel *AzSet;
    QSpacerItem *spacerItem6;

    void setupUi(QWidget *DetailsPosition)
    {
        if (DetailsPosition->objectName().isEmpty())
            DetailsPosition->setObjectName("DetailsPosition");
        DetailsPosition->resize(325, 314);
        vboxLayout = new QVBoxLayout(DetailsPosition);
        vboxLayout->setSpacing(6);
        vboxLayout->setObjectName("vboxLayout");
        vboxLayout->setContentsMargins(9, 9, 9, 9);
        vboxLayout1 = new QVBoxLayout();
        vboxLayout1->setSpacing(0);
        vboxLayout1->setObjectName("vboxLayout1");
        vboxLayout1->setContentsMargins(0, 0, 0, 0);
        CoordTitle = new QLabel(DetailsPosition);
        CoordTitle->setObjectName("CoordTitle");
        QFont font;
        font.setFamilies({QString::fromUtf8("Sans Serif")});
        font.setPointSize(10);
        font.setBold(true);
        font.setItalic(false);
        font.setUnderline(false);
        font.setStrikeOut(false);
        CoordTitle->setFont(font);
        CoordTitle->setAutoFillBackground(true);
        CoordTitle->setAlignment(Qt::AlignCenter);

        vboxLayout1->addWidget(CoordTitle);

        CoordFrame = new QFrame(DetailsPosition);
        CoordFrame->setObjectName("CoordFrame");
        QSizePolicy sizePolicy(QSizePolicy::Policy::Preferred, QSizePolicy::Policy::Expanding);
        sizePolicy.setHorizontalStretch(0);
        sizePolicy.setVerticalStretch(0);
        sizePolicy.setHeightForWidth(CoordFrame->sizePolicy().hasHeightForWidth());
        CoordFrame->setSizePolicy(sizePolicy);
        CoordFrame->setAutoFillBackground(true);
        CoordFrame->setFrameShape(QFrame::Box);
        CoordFrame->setFrameShadow(QFrame::Plain);
        CoordFrame->setLineWidth(4);
        vboxLayout2 = new QVBoxLayout(CoordFrame);
        vboxLayout2->setSpacing(6);
        vboxLayout2->setObjectName("vboxLayout2");
        vboxLayout2->setContentsMargins(9, 9, 9, 9);
        gridLayout = new QGridLayout();
        gridLayout->setSpacing(6);
        gridLayout->setObjectName("gridLayout");
        gridLayout->setContentsMargins(0, 0, 0, 0);
        DecLabel = new QLabel(CoordFrame);
        DecLabel->setObjectName("DecLabel");
        DecLabel->setLineWidth(2);
        DecLabel->setAlignment(Qt::AlignLeading|Qt::AlignLeft|Qt::AlignVCenter);
        DecLabel->setMargin(1);
        DecLabel->setOpenExternalLinks(false);

        gridLayout->addWidget(DecLabel, 1, 0, 1, 1);

        spacerItem = new QSpacerItem(81, 24, QSizePolicy::Policy::Expanding, QSizePolicy::Policy::Minimum);

        gridLayout->addItem(spacerItem, 3, 2, 1, 1);

        RA0Label = new QLabel(CoordFrame);
        RA0Label->setObjectName("RA0Label");

        gridLayout->addWidget(RA0Label, 3, 0, 1, 1);

        Dec0 = new QLabel(CoordFrame);
        Dec0->setObjectName("Dec0");
        QFont font1;
        font1.setFamilies({QString::fromUtf8("Monospace")});
        font1.setPointSize(10);
        font1.setBold(true);
        Dec0->setFont(font1);
        Dec0->setTextInteractionFlags(Qt::TextSelectableByMouse);

        gridLayout->addWidget(Dec0, 4, 1, 1, 1);

        Airmass = new QLabel(CoordFrame);
        Airmass->setObjectName("Airmass");
        Airmass->setFont(font1);
        Airmass->setTextInteractionFlags(Qt::TextSelectableByMouse);

        gridLayout->addWidget(Airmass, 4, 4, 1, 1);

        RALabel = new QLabel(CoordFrame);
        RALabel->setObjectName("RALabel");
        RALabel->setLineWidth(2);
        RALabel->setAlignment(Qt::AlignLeading|Qt::AlignLeft|Qt::AlignVCenter);
        RALabel->setMargin(1);
        RALabel->setOpenExternalLinks(false);

        gridLayout->addWidget(RALabel, 0, 0, 1, 1);

        RA0 = new QLabel(CoordFrame);
        RA0->setObjectName("RA0");
        RA0->setFont(font1);
        RA0->setTextInteractionFlags(Qt::TextSelectableByMouse);

        gridLayout->addWidget(RA0, 3, 1, 1, 1);

        spacerItem1 = new QSpacerItem(97, 20, QSizePolicy::Policy::Expanding, QSizePolicy::Policy::Minimum);

        gridLayout->addItem(spacerItem1, 0, 2, 1, 1);

        HA = new QLabel(CoordFrame);
        HA->setObjectName("HA");
        HA->setFont(font1);
        HA->setTextInteractionFlags(Qt::TextSelectableByMouse);

        gridLayout->addWidget(HA, 3, 4, 1, 1);

        Dec0Label = new QLabel(CoordFrame);
        Dec0Label->setObjectName("Dec0Label");

        gridLayout->addWidget(Dec0Label, 4, 0, 1, 1);

        Dec = new QLabel(CoordFrame);
        Dec->setObjectName("Dec");
        Dec->setFont(font1);
        Dec->setTextInteractionFlags(Qt::TextSelectableByMouse);

        gridLayout->addWidget(Dec, 1, 1, 1, 1);

        Alt = new QLabel(CoordFrame);
        Alt->setObjectName("Alt");
        Alt->setFont(font1);
        Alt->setTextInteractionFlags(Qt::TextSelectableByMouse);

        gridLayout->addWidget(Alt, 1, 4, 1, 1);

        AzLabel = new QLabel(CoordFrame);
        AzLabel->setObjectName("AzLabel");
        AzLabel->setLineWidth(2);
        AzLabel->setAlignment(Qt::AlignLeading|Qt::AlignLeft|Qt::AlignVCenter);
        AzLabel->setMargin(1);
        AzLabel->setOpenExternalLinks(false);

        gridLayout->addWidget(AzLabel, 0, 3, 1, 1);

        spacerItem2 = new QSpacerItem(101, 20, QSizePolicy::Policy::Expanding, QSizePolicy::Policy::Minimum);

        gridLayout->addItem(spacerItem2, 1, 2, 1, 1);

        AirmassLabel = new QLabel(CoordFrame);
        AirmassLabel->setObjectName("AirmassLabel");
        AirmassLabel->setLineWidth(2);
        AirmassLabel->setAlignment(Qt::AlignLeading|Qt::AlignLeft|Qt::AlignVCenter);
        AirmassLabel->setMargin(1);

        gridLayout->addWidget(AirmassLabel, 4, 3, 1, 1);

        AltLabel = new QLabel(CoordFrame);
        AltLabel->setObjectName("AltLabel");
        AltLabel->setLineWidth(2);
        AltLabel->setAlignment(Qt::AlignLeading|Qt::AlignLeft|Qt::AlignVCenter);
        AltLabel->setMargin(1);
        AltLabel->setOpenExternalLinks(false);

        gridLayout->addWidget(AltLabel, 1, 3, 1, 1);

        Az = new QLabel(CoordFrame);
        Az->setObjectName("Az");
        Az->setFont(font1);
        Az->setTextInteractionFlags(Qt::TextSelectableByMouse);

        gridLayout->addWidget(Az, 0, 4, 1, 1);

        HALabel = new QLabel(CoordFrame);
        HALabel->setObjectName("HALabel");
        HALabel->setLineWidth(2);
        HALabel->setAlignment(Qt::AlignLeading|Qt::AlignLeft|Qt::AlignVCenter);
        HALabel->setMargin(1);
        HALabel->setOpenExternalLinks(false);

        gridLayout->addWidget(HALabel, 3, 3, 1, 1);

        spacer = new QSpacerItem(81, 24, QSizePolicy::Policy::Expanding, QSizePolicy::Policy::Minimum);

        gridLayout->addItem(spacer, 4, 2, 1, 1);

        RA = new QLabel(CoordFrame);
        RA->setObjectName("RA");
        RA->setFont(font1);
        RA->setTextInteractionFlags(Qt::TextSelectableByMouse);

        gridLayout->addWidget(RA, 0, 1, 1, 1);

        line = new QFrame(CoordFrame);
        line->setObjectName("line");
        line->setFrameShape(QFrame::Shape::HLine);
        line->setFrameShadow(QFrame::Shadow::Sunken);

        gridLayout->addWidget(line, 2, 0, 1, 5);


        vboxLayout2->addLayout(gridLayout);

        spacerItem3 = new QSpacerItem(20, 20, QSizePolicy::Policy::Minimum, QSizePolicy::Policy::Expanding);

        vboxLayout2->addItem(spacerItem3);


        vboxLayout1->addWidget(CoordFrame);


        vboxLayout->addLayout(vboxLayout1);

        spacerItem4 = new QSpacerItem(20, 16, QSizePolicy::Policy::Minimum, QSizePolicy::Policy::Fixed);

        vboxLayout->addItem(spacerItem4);

        vboxLayout3 = new QVBoxLayout();
        vboxLayout3->setSpacing(0);
        vboxLayout3->setObjectName("vboxLayout3");
        vboxLayout3->setContentsMargins(0, 0, 0, 0);
        RSTTitle = new QLabel(DetailsPosition);
        RSTTitle->setObjectName("RSTTitle");
        RSTTitle->setFont(font);
        RSTTitle->setAutoFillBackground(true);
        RSTTitle->setAlignment(Qt::AlignHCenter);

        vboxLayout3->addWidget(RSTTitle);

        RSTFrame = new QFrame(DetailsPosition);
        RSTFrame->setObjectName("RSTFrame");
        sizePolicy.setHeightForWidth(RSTFrame->sizePolicy().hasHeightForWidth());
        RSTFrame->setSizePolicy(sizePolicy);
        RSTFrame->setAutoFillBackground(true);
        RSTFrame->setFrameShape(QFrame::Box);
        RSTFrame->setFrameShadow(QFrame::Plain);
        RSTFrame->setLineWidth(4);
        vboxLayout4 = new QVBoxLayout(RSTFrame);
        vboxLayout4->setSpacing(6);
        vboxLayout4->setObjectName("vboxLayout4");
        vboxLayout4->setContentsMargins(10, 10, 10, 10);
        hboxLayout = new QHBoxLayout();
        hboxLayout->setSpacing(6);
        hboxLayout->setObjectName("hboxLayout");
        hboxLayout->setContentsMargins(0, 0, 0, 0);
        gridLayout1 = new QGridLayout();
        gridLayout1->setSpacing(6);
        gridLayout1->setObjectName("gridLayout1");
        gridLayout1->setContentsMargins(0, 0, 0, 0);
        TimeSetLabel = new QLabel(RSTFrame);
        TimeSetLabel->setObjectName("TimeSetLabel");
        TimeSetLabel->setLineWidth(2);
        TimeSetLabel->setAlignment(Qt::AlignTop);
        TimeSetLabel->setMargin(1);

        gridLayout1->addWidget(TimeSetLabel, 2, 0, 1, 1);

        TimeTransitLabel = new QLabel(RSTFrame);
        TimeTransitLabel->setObjectName("TimeTransitLabel");
        TimeTransitLabel->setLineWidth(2);
        TimeTransitLabel->setAlignment(Qt::AlignTop);
        TimeTransitLabel->setMargin(1);

        gridLayout1->addWidget(TimeTransitLabel, 1, 0, 1, 1);

        TimeRiseLabel = new QLabel(RSTFrame);
        TimeRiseLabel->setObjectName("TimeRiseLabel");
        TimeRiseLabel->setLineWidth(2);
        TimeRiseLabel->setAlignment(Qt::AlignTop);
        TimeRiseLabel->setMargin(1);

        gridLayout1->addWidget(TimeRiseLabel, 0, 0, 1, 1);

        TimeRise = new QLabel(RSTFrame);
        TimeRise->setObjectName("TimeRise");
        TimeRise->setFont(font1);
        TimeRise->setTextInteractionFlags(Qt::TextSelectableByMouse);

        gridLayout1->addWidget(TimeRise, 0, 1, 1, 1);

        TimeTransit = new QLabel(RSTFrame);
        TimeTransit->setObjectName("TimeTransit");
        TimeTransit->setFont(font1);
        TimeTransit->setTextInteractionFlags(Qt::TextSelectableByMouse);

        gridLayout1->addWidget(TimeTransit, 1, 1, 1, 1);

        TimeSet = new QLabel(RSTFrame);
        TimeSet->setObjectName("TimeSet");
        TimeSet->setFont(font1);
        TimeSet->setTextInteractionFlags(Qt::TextSelectableByMouse);

        gridLayout1->addWidget(TimeSet, 2, 1, 1, 1);


        hboxLayout->addLayout(gridLayout1);

        spacerItem5 = new QSpacerItem(83, 20, QSizePolicy::Policy::Expanding, QSizePolicy::Policy::Minimum);

        hboxLayout->addItem(spacerItem5);

        gridLayout2 = new QGridLayout();
        gridLayout2->setSpacing(6);
        gridLayout2->setObjectName("gridLayout2");
        gridLayout2->setContentsMargins(0, 0, 0, 0);
        AzSetLabel = new QLabel(RSTFrame);
        AzSetLabel->setObjectName("AzSetLabel");
        AzSetLabel->setLineWidth(2);
        AzSetLabel->setAlignment(Qt::AlignTop);
        AzSetLabel->setMargin(1);

        gridLayout2->addWidget(AzSetLabel, 2, 0, 1, 1);

        AltTransitLabel = new QLabel(RSTFrame);
        AltTransitLabel->setObjectName("AltTransitLabel");
        AltTransitLabel->setLineWidth(2);
        AltTransitLabel->setAlignment(Qt::AlignTop);
        AltTransitLabel->setMargin(1);

        gridLayout2->addWidget(AltTransitLabel, 1, 0, 1, 1);

        AzRiseLabel = new QLabel(RSTFrame);
        AzRiseLabel->setObjectName("AzRiseLabel");
        AzRiseLabel->setLineWidth(2);
        AzRiseLabel->setAlignment(Qt::AlignTop);
        AzRiseLabel->setMargin(1);

        gridLayout2->addWidget(AzRiseLabel, 0, 0, 1, 1);

        AzRise = new QLabel(RSTFrame);
        AzRise->setObjectName("AzRise");
        AzRise->setFont(font1);
        AzRise->setTextInteractionFlags(Qt::TextSelectableByKeyboard|Qt::TextSelectableByMouse);

        gridLayout2->addWidget(AzRise, 0, 1, 1, 1);

        AltTransit = new QLabel(RSTFrame);
        AltTransit->setObjectName("AltTransit");
        AltTransit->setFont(font1);
        AltTransit->setTextInteractionFlags(Qt::TextSelectableByMouse);

        gridLayout2->addWidget(AltTransit, 1, 1, 1, 1);

        AzSet = new QLabel(RSTFrame);
        AzSet->setObjectName("AzSet");
        AzSet->setFont(font1);
        AzSet->setTextInteractionFlags(Qt::TextSelectableByMouse);

        gridLayout2->addWidget(AzSet, 2, 1, 1, 1);


        hboxLayout->addLayout(gridLayout2);


        vboxLayout4->addLayout(hboxLayout);

        spacerItem6 = new QSpacerItem(20, 0, QSizePolicy::Policy::Minimum, QSizePolicy::Policy::Expanding);

        vboxLayout4->addItem(spacerItem6);


        vboxLayout3->addWidget(RSTFrame);


        vboxLayout->addLayout(vboxLayout3);


        retranslateUi(DetailsPosition);

        QMetaObject::connectSlotsByName(DetailsPosition);
    } // setupUi

    void retranslateUi(QWidget *DetailsPosition)
    {
        DetailsPosition->setWindowTitle(tr2i18n("Details - Position Data", nullptr));
        CoordTitle->setText(tr2i18n("Coordinates", nullptr));
        DecLabel->setText(tr2i18n("DE (2000.0):", nullptr));
        DecLabel->setProperty("anchor", QVariant(tr2i18n("skycoords", "KDE::DoNotExtract")));
        RA0Label->setText(tr2i18n("RA (J2000.0):", nullptr));
        RA0Label->setProperty("anchor", QVariant(tr2i18n("ai-epoch", "KDE::DoNotExtract")));
        Dec0->setText(tr2i18n("00:00:00", nullptr));
        Airmass->setText(tr2i18n("0.00", nullptr));
        RALabel->setText(tr2i18n("RA (2000.0):", nullptr));
        RALabel->setProperty("anchor", QVariant(tr2i18n("skycoords", "KDE::DoNotExtract")));
        RA0->setText(tr2i18n("00:00:00", nullptr));
        HA->setText(tr2i18n("00:00:00", nullptr));
        Dec0Label->setText(tr2i18n("DE (J2000.0):", nullptr));
        Dec0Label->setProperty("anchor", QVariant(tr2i18n("ai-epoch", "KDE::DoNotExtract")));
        Dec->setText(tr2i18n("00:00:00", nullptr));
        Alt->setText(tr2i18n("00:00:00", nullptr));
        AzLabel->setText(tr2i18n("Azimuth:", nullptr));
        AzLabel->setProperty("anchor", QVariant(tr2i18n("skycoords", "KDE::DoNotExtract")));
        AirmassLabel->setText(tr2i18n("Airmass:", nullptr));
        AltLabel->setText(tr2i18n("Altitude:", nullptr));
        AltLabel->setProperty("anchor", QVariant(tr2i18n("skycoords", "KDE::DoNotExtract")));
        Az->setText(tr2i18n("00:00:00", nullptr));
        HALabel->setText(tr2i18n("Hour angle:", nullptr));
        HALabel->setProperty("anchor", QVariant(tr2i18n("hourangle", "KDE::DoNotExtract")));
        RA->setText(tr2i18n("00:00:00", nullptr));
        RSTTitle->setText(tr2i18n("Rise/Set/Transit", nullptr));
        TimeSetLabel->setText(tr2i18n("Set time:", nullptr));
        TimeTransitLabel->setText(tr2i18n("Transit time:", nullptr));
        TimeRiseLabel->setText(tr2i18n("Rise time:", nullptr));
        TimeRise->setText(tr2i18n("00:00", nullptr));
        TimeTransit->setText(tr2i18n("00:00", nullptr));
        TimeSet->setText(tr2i18n("00:00", nullptr));
        AzSetLabel->setText(tr2i18n("Azimuth at set:", nullptr));
        AltTransitLabel->setText(tr2i18n("Altitude at transit:", nullptr));
        AzRiseLabel->setText(tr2i18n("Azimuth at rise:", nullptr));
        AzRise->setText(tr2i18n("00:00:00", nullptr));
        AltTransit->setText(tr2i18n("00:00:00", nullptr));
        AzSet->setText(tr2i18n("00:00:00", nullptr));
    } // retranslateUi

};

namespace Ui {
    class DetailsPosition: public Ui_DetailsPosition {};
} // namespace Ui

QT_END_NAMESPACE

#endif // DETAILS_POSITION_H

