/********************************************************************************
** Form generated from reading UI file 'pwizprint.ui'
**
** Created by: Qt User Interface Compiler version 6.11.1
**
** WARNING! All changes made in this file will be lost when recompiling UI file!
********************************************************************************/

#ifndef UI_PWIZPRINT_H
#define UI_PWIZPRINT_H

#include <QtCore/QVariant>
#include <QtWidgets/QApplication>
#include <QtWidgets/QHBoxLayout>
#include <QtWidgets/QLabel>
#include <QtWidgets/QPushButton>
#include <QtWidgets/QSpacerItem>
#include <QtWidgets/QVBoxLayout>
#include <QtWidgets/QWidget>
#include <klocalizedstring.h>

QT_BEGIN_NAMESPACE

class Ui_PWizPrint
{
public:
    QHBoxLayout *horizontalLayout_2;
    QLabel *banner;
    QSpacerItem *horSpacer7;
    QVBoxLayout *printLayout;
    QLabel *stepTitle;
    QSpacerItem *vertSpacer1;
    QLabel *stepText;
    QSpacerItem *vertSpacer2;
    QHBoxLayout *horLayout1;
    QSpacerItem *horSpacer1;
    QPushButton *previewButton;
    QSpacerItem *horSpacer2;
    QHBoxLayout *horLayout2;
    QSpacerItem *horSpacer3;
    QPushButton *printButton;
    QSpacerItem *horSpacer4;
    QHBoxLayout *horizontalLayout;
    QSpacerItem *horSpacer5;
    QPushButton *exportButton;
    QSpacerItem *horSpacer6;
    QSpacerItem *vertSpacer3;

    void setupUi(QWidget *PWizPrint)
    {
        if (PWizPrint->objectName().isEmpty())
            PWizPrint->setObjectName("PWizPrint");
        PWizPrint->resize(586, 395);
        PWizPrint->setMinimumSize(QSize(586, 395));
        horizontalLayout_2 = new QHBoxLayout(PWizPrint);
        horizontalLayout_2->setObjectName("horizontalLayout_2");
        banner = new QLabel(PWizPrint);
        banner->setObjectName("banner");
        QSizePolicy sizePolicy(QSizePolicy::Policy::Fixed, QSizePolicy::Policy::Fixed);
        sizePolicy.setHorizontalStretch(0);
        sizePolicy.setVerticalStretch(0);
        sizePolicy.setHeightForWidth(banner->sizePolicy().hasHeightForWidth());
        banner->setSizePolicy(sizePolicy);
        banner->setMinimumSize(QSize(120, 360));

        horizontalLayout_2->addWidget(banner);

        horSpacer7 = new QSpacerItem(5, 20, QSizePolicy::Policy::Fixed, QSizePolicy::Policy::Minimum);

        horizontalLayout_2->addItem(horSpacer7);

        printLayout = new QVBoxLayout();
#ifndef UI_Q_OS_MAC
        printLayout->setSpacing(6);
#endif
        printLayout->setContentsMargins(0, 0, 0, 0);
        printLayout->setObjectName("printLayout");
        stepTitle = new QLabel(PWizPrint);
        stepTitle->setObjectName("stepTitle");
        QFont font;
        font.setFamilies({QString::fromUtf8("Sans Serif")});
        font.setPointSize(11);
        font.setBold(true);
        font.setItalic(false);
        font.setUnderline(false);
        font.setStrikeOut(false);
        stepTitle->setFont(font);

        printLayout->addWidget(stepTitle);

        vertSpacer1 = new QSpacerItem(20, 12, QSizePolicy::Policy::Minimum, QSizePolicy::Policy::Fixed);

        printLayout->addItem(vertSpacer1);

        stepText = new QLabel(PWizPrint);
        stepText->setObjectName("stepText");
        stepText->setWordWrap(true);

        printLayout->addWidget(stepText);

        vertSpacer2 = new QSpacerItem(20, 12, QSizePolicy::Policy::Minimum, QSizePolicy::Policy::Fixed);

        printLayout->addItem(vertSpacer2);

        horLayout1 = new QHBoxLayout();
        horLayout1->setObjectName("horLayout1");
        horSpacer1 = new QSpacerItem(40, 20, QSizePolicy::Policy::Expanding, QSizePolicy::Policy::Minimum);

        horLayout1->addItem(horSpacer1);

        previewButton = new QPushButton(PWizPrint);
        previewButton->setObjectName("previewButton");

        horLayout1->addWidget(previewButton);

        horSpacer2 = new QSpacerItem(40, 20, QSizePolicy::Policy::Expanding, QSizePolicy::Policy::Minimum);

        horLayout1->addItem(horSpacer2);


        printLayout->addLayout(horLayout1);

        horLayout2 = new QHBoxLayout();
        horLayout2->setObjectName("horLayout2");
        horSpacer3 = new QSpacerItem(40, 20, QSizePolicy::Policy::Expanding, QSizePolicy::Policy::Minimum);

        horLayout2->addItem(horSpacer3);

        printButton = new QPushButton(PWizPrint);
        printButton->setObjectName("printButton");

        horLayout2->addWidget(printButton);

        horSpacer4 = new QSpacerItem(40, 20, QSizePolicy::Policy::Expanding, QSizePolicy::Policy::Minimum);

        horLayout2->addItem(horSpacer4);


        printLayout->addLayout(horLayout2);

        horizontalLayout = new QHBoxLayout();
        horizontalLayout->setObjectName("horizontalLayout");
        horSpacer5 = new QSpacerItem(40, 20, QSizePolicy::Policy::Expanding, QSizePolicy::Policy::Minimum);

        horizontalLayout->addItem(horSpacer5);

        exportButton = new QPushButton(PWizPrint);
        exportButton->setObjectName("exportButton");

        horizontalLayout->addWidget(exportButton);

        horSpacer6 = new QSpacerItem(40, 20, QSizePolicy::Policy::Expanding, QSizePolicy::Policy::Minimum);

        horizontalLayout->addItem(horSpacer6);


        printLayout->addLayout(horizontalLayout);

        vertSpacer3 = new QSpacerItem(20, 40, QSizePolicy::Policy::Minimum, QSizePolicy::Policy::Expanding);

        printLayout->addItem(vertSpacer3);


        horizontalLayout_2->addLayout(printLayout);


        retranslateUi(PWizPrint);

        QMetaObject::connectSlotsByName(PWizPrint);
    } // setupUi

    void retranslateUi(QWidget *PWizPrint)
    {
        banner->setText(QString());
        stepTitle->setText(tr2i18n("Preview, Print and Export", nullptr));
        stepText->setText(tr2i18n("<p>Your document is ready to be printed. Click <b>Print preview</b> button to preview it and <b>Print</b> button to begin printing. You can also export it to file.</p>\n"
"<p>If you wish to change contents of printed document, click <b>Previous</b> button to get back to previous steps.</p>", nullptr));
        previewButton->setText(tr2i18n("Print preview", nullptr));
        printButton->setText(tr2i18n("Print", nullptr));
        exportButton->setText(tr2i18n("Export to File...", nullptr));
        (void)PWizPrint;
    } // retranslateUi

};

namespace Ui {
    class PWizPrint: public Ui_PWizPrint {};
} // namespace Ui

QT_END_NAMESPACE

#endif // PWIZPRINT_H

