/****************************************************************************
** Meta object code from reading C++ file 'observinglist.h'
**
** Created by: The Qt Meta Object Compiler version 69 (Qt 6.11.1)
**
** WARNING! All changes made in this file will be lost!
*****************************************************************************/

#include "../../../../kstars-3.8.4.1/kstars/tools/observinglist.h"
#include <QtCore/qmetatype.h>

#include <QtCore/qtmochelpers.h>

#include <memory>


#include <QtCore/qxptype_traits.h>
#if !defined(Q_MOC_OUTPUT_REVISION)
#error "The header file 'observinglist.h' doesn't include <QObject>."
#elif Q_MOC_OUTPUT_REVISION != 69
#error "This file was generated using the moc from 6.11.1. It"
#error "cannot be used with the include files from this version of Qt."
#error "(The moc has changed too much.)"
#endif

#ifndef Q_CONSTINIT
#define Q_CONSTINIT
#endif

QT_WARNING_PUSH
QT_WARNING_DISABLE_DEPRECATED
QT_WARNING_DISABLE_GCC("-Wuseless-cast")
namespace {
struct qt_meta_tag_ZN15ObservingListUIE_t {};
} // unnamed namespace

template <> constexpr inline auto ObservingListUI::qt_create_metaobjectdata<qt_meta_tag_ZN15ObservingListUIE_t>()
{
    namespace QMC = QtMocConstants;
    QtMocHelpers::StringRefStorage qt_stringData {
        "ObservingListUI"
    };

    QtMocHelpers::UintData qt_methods {
    };
    QtMocHelpers::UintData qt_properties {
    };
    QtMocHelpers::UintData qt_enums {
    };
    return QtMocHelpers::metaObjectData<ObservingListUI, qt_meta_tag_ZN15ObservingListUIE_t>(QMC::MetaObjectFlag{}, qt_stringData,
            qt_methods, qt_properties, qt_enums);
}
Q_CONSTINIT const QMetaObject ObservingListUI::staticMetaObject = { {
    QMetaObject::SuperData::link<QFrame::staticMetaObject>(),
    qt_staticMetaObjectStaticContent<qt_meta_tag_ZN15ObservingListUIE_t>.stringdata,
    qt_staticMetaObjectStaticContent<qt_meta_tag_ZN15ObservingListUIE_t>.data,
    qt_static_metacall,
    nullptr,
    qt_staticMetaObjectRelocatingContent<qt_meta_tag_ZN15ObservingListUIE_t>.metaTypes,
    nullptr
} };

void ObservingListUI::qt_static_metacall(QObject *_o, QMetaObject::Call _c, int _id, void **_a)
{
    auto *_t = static_cast<ObservingListUI *>(_o);
    (void)_t;
    (void)_c;
    (void)_id;
    (void)_a;
}

const QMetaObject *ObservingListUI::metaObject() const
{
    return QObject::d_ptr->metaObject ? QObject::d_ptr->dynamicMetaObject() : &staticMetaObject;
}

void *ObservingListUI::qt_metacast(const char *_clname)
{
    if (!_clname) return nullptr;
    if (!strcmp(_clname, qt_staticMetaObjectStaticContent<qt_meta_tag_ZN15ObservingListUIE_t>.strings))
        return static_cast<void*>(this);
    if (!strcmp(_clname, "Ui::ObservingList"))
        return static_cast< Ui::ObservingList*>(this);
    return QFrame::qt_metacast(_clname);
}

int ObservingListUI::qt_metacall(QMetaObject::Call _c, int _id, void **_a)
{
    _id = QFrame::qt_metacall(_c, _id, _a);
    return _id;
}
namespace {
struct qt_meta_tag_ZN13ObservingListE_t {};
} // unnamed namespace

template <> constexpr inline auto ObservingList::qt_create_metaobjectdata<qt_meta_tag_ZN13ObservingListE_t>()
{
    namespace QMC = QtMocConstants;
    QtMocHelpers::StringRefStorage qt_stringData {
        "ObservingList",
        "slotAddObject",
        "",
        "const SkyObject*",
        "o",
        "session",
        "update",
        "slotRemoveSelectedObjects",
        "slotRemoveObject",
        "slotCenterObject",
        "slotSlewToObject",
        "slotAddToEkosScheduler",
        "slotDetails",
        "slotAVT",
        "slotWUT",
        "slotAddToSession",
        "slotFind",
        "slotBatchAdd",
        "slotNewSelection",
        "slotOpenList",
        "slotSaveList",
        "slotLoadWishList",
        "slotSaveSessionAs",
        "nativeSave",
        "slotSaveSession",
        "slotWizard",
        "slotChangeTab",
        "index",
        "slotLocation",
        "slotUpdate",
        "slotSetTime",
        "slotGetImage",
        "_dss",
        "slotSearchImage",
        "slotSaveAllImages",
        "saveImage",
        "QUrl",
        "url",
        "filename",
        "slotImageViewer",
        "slotDeleteCurrentImage",
        "slotDeleteAllImages",
        "slotDSS",
        "slotCustomDSS",
        "slotOALExport",
        "slotAddVisibleObj",
        "slotUpdateAltitudes",
        "slotClearList",
        "slotClose",
        "downloadReady",
        "success"
    };

    QtMocHelpers::UintData qt_methods {
        // Slot 'slotAddObject'
        QtMocHelpers::SlotData<void(const SkyObject *, bool, bool)>(1, 2, QMC::AccessPublic, QMetaType::Void, {{
            { 0x80000000 | 3, 4 }, { QMetaType::Bool, 5 }, { QMetaType::Bool, 6 },
        }}),
        // Slot 'slotAddObject'
        QtMocHelpers::SlotData<void(const SkyObject *, bool)>(1, 2, QMC::AccessPublic | QMC::MethodCloned, QMetaType::Void, {{
            { 0x80000000 | 3, 4 }, { QMetaType::Bool, 5 },
        }}),
        // Slot 'slotAddObject'
        QtMocHelpers::SlotData<void(const SkyObject *)>(1, 2, QMC::AccessPublic | QMC::MethodCloned, QMetaType::Void, {{
            { 0x80000000 | 3, 4 },
        }}),
        // Slot 'slotAddObject'
        QtMocHelpers::SlotData<void()>(1, 2, QMC::AccessPublic | QMC::MethodCloned, QMetaType::Void),
        // Slot 'slotRemoveSelectedObjects'
        QtMocHelpers::SlotData<void()>(7, 2, QMC::AccessPublic, QMetaType::Void),
        // Slot 'slotRemoveObject'
        QtMocHelpers::SlotData<void(const SkyObject *, bool, bool)>(8, 2, QMC::AccessPublic, QMetaType::Void, {{
            { 0x80000000 | 3, 4 }, { QMetaType::Bool, 5 }, { QMetaType::Bool, 6 },
        }}),
        // Slot 'slotRemoveObject'
        QtMocHelpers::SlotData<void(const SkyObject *, bool)>(8, 2, QMC::AccessPublic | QMC::MethodCloned, QMetaType::Void, {{
            { 0x80000000 | 3, 4 }, { QMetaType::Bool, 5 },
        }}),
        // Slot 'slotRemoveObject'
        QtMocHelpers::SlotData<void(const SkyObject *)>(8, 2, QMC::AccessPublic | QMC::MethodCloned, QMetaType::Void, {{
            { 0x80000000 | 3, 4 },
        }}),
        // Slot 'slotRemoveObject'
        QtMocHelpers::SlotData<void()>(8, 2, QMC::AccessPublic | QMC::MethodCloned, QMetaType::Void),
        // Slot 'slotCenterObject'
        QtMocHelpers::SlotData<void()>(9, 2, QMC::AccessPublic, QMetaType::Void),
        // Slot 'slotSlewToObject'
        QtMocHelpers::SlotData<void()>(10, 2, QMC::AccessPublic, QMetaType::Void),
        // Slot 'slotAddToEkosScheduler'
        QtMocHelpers::SlotData<void()>(11, 2, QMC::AccessPublic, QMetaType::Void),
        // Slot 'slotDetails'
        QtMocHelpers::SlotData<void()>(12, 2, QMC::AccessPublic, QMetaType::Void),
        // Slot 'slotAVT'
        QtMocHelpers::SlotData<void()>(13, 2, QMC::AccessPublic, QMetaType::Void),
        // Slot 'slotWUT'
        QtMocHelpers::SlotData<void()>(14, 2, QMC::AccessPublic, QMetaType::Void),
        // Slot 'slotAddToSession'
        QtMocHelpers::SlotData<void()>(15, 2, QMC::AccessPublic, QMetaType::Void),
        // Slot 'slotFind'
        QtMocHelpers::SlotData<void()>(16, 2, QMC::AccessPublic, QMetaType::Void),
        // Slot 'slotBatchAdd'
        QtMocHelpers::SlotData<void()>(17, 2, QMC::AccessPublic, QMetaType::Void),
        // Slot 'slotNewSelection'
        QtMocHelpers::SlotData<void()>(18, 2, QMC::AccessPublic, QMetaType::Void),
        // Slot 'slotOpenList'
        QtMocHelpers::SlotData<void()>(19, 2, QMC::AccessPublic, QMetaType::Void),
        // Slot 'slotSaveList'
        QtMocHelpers::SlotData<void()>(20, 2, QMC::AccessPublic, QMetaType::Void),
        // Slot 'slotLoadWishList'
        QtMocHelpers::SlotData<void()>(21, 2, QMC::AccessPublic, QMetaType::Void),
        // Slot 'slotSaveSessionAs'
        QtMocHelpers::SlotData<void(bool)>(22, 2, QMC::AccessPublic, QMetaType::Void, {{
            { QMetaType::Bool, 23 },
        }}),
        // Slot 'slotSaveSessionAs'
        QtMocHelpers::SlotData<void()>(22, 2, QMC::AccessPublic | QMC::MethodCloned, QMetaType::Void),
        // Slot 'slotSaveSession'
        QtMocHelpers::SlotData<void(bool)>(24, 2, QMC::AccessPublic, QMetaType::Void, {{
            { QMetaType::Bool, 23 },
        }}),
        // Slot 'slotSaveSession'
        QtMocHelpers::SlotData<void()>(24, 2, QMC::AccessPublic | QMC::MethodCloned, QMetaType::Void),
        // Slot 'slotWizard'
        QtMocHelpers::SlotData<void()>(25, 2, QMC::AccessPublic, QMetaType::Void),
        // Slot 'slotChangeTab'
        QtMocHelpers::SlotData<void(int)>(26, 2, QMC::AccessPublic, QMetaType::Void, {{
            { QMetaType::Int, 27 },
        }}),
        // Slot 'slotLocation'
        QtMocHelpers::SlotData<void()>(28, 2, QMC::AccessPublic, QMetaType::Void),
        // Slot 'slotUpdate'
        QtMocHelpers::SlotData<void()>(29, 2, QMC::AccessPublic, QMetaType::Void),
        // Slot 'slotSetTime'
        QtMocHelpers::SlotData<void()>(30, 2, QMC::AccessPublic, QMetaType::Void),
        // Slot 'slotGetImage'
        QtMocHelpers::SlotData<void(bool, const SkyObject *)>(31, 2, QMC::AccessPublic, QMetaType::Void, {{
            { QMetaType::Bool, 32 }, { 0x80000000 | 3, 4 },
        }}),
        // Slot 'slotGetImage'
        QtMocHelpers::SlotData<void(bool)>(31, 2, QMC::AccessPublic | QMC::MethodCloned, QMetaType::Void, {{
            { QMetaType::Bool, 32 },
        }}),
        // Slot 'slotGetImage'
        QtMocHelpers::SlotData<void()>(31, 2, QMC::AccessPublic | QMC::MethodCloned, QMetaType::Void),
        // Slot 'slotSearchImage'
        QtMocHelpers::SlotData<void()>(33, 2, QMC::AccessPublic, QMetaType::Void),
        // Slot 'slotSaveAllImages'
        QtMocHelpers::SlotData<void()>(34, 2, QMC::AccessPublic, QMetaType::Void),
        // Slot 'saveImage'
        QtMocHelpers::SlotData<void(QUrl, QString, const SkyObject *)>(35, 2, QMC::AccessPublic, QMetaType::Void, {{
            { 0x80000000 | 36, 37 }, { QMetaType::QString, 38 }, { 0x80000000 | 3, 4 },
        }}),
        // Slot 'saveImage'
        QtMocHelpers::SlotData<void(QUrl, QString)>(35, 2, QMC::AccessPublic | QMC::MethodCloned, QMetaType::Void, {{
            { 0x80000000 | 36, 37 }, { QMetaType::QString, 38 },
        }}),
        // Slot 'slotImageViewer'
        QtMocHelpers::SlotData<void()>(39, 2, QMC::AccessPublic, QMetaType::Void),
        // Slot 'slotDeleteCurrentImage'
        QtMocHelpers::SlotData<void()>(40, 2, QMC::AccessPublic, QMetaType::Void),
        // Slot 'slotDeleteAllImages'
        QtMocHelpers::SlotData<void()>(41, 2, QMC::AccessPublic, QMetaType::Void),
        // Slot 'slotDSS'
        QtMocHelpers::SlotData<void()>(42, 2, QMC::AccessPublic, QMetaType::Void),
        // Slot 'slotCustomDSS'
        QtMocHelpers::SlotData<void()>(43, 2, QMC::AccessPublic, QMetaType::Void),
        // Slot 'slotOALExport'
        QtMocHelpers::SlotData<void()>(44, 2, QMC::AccessPublic, QMetaType::Void),
        // Slot 'slotAddVisibleObj'
        QtMocHelpers::SlotData<void()>(45, 2, QMC::AccessPublic, QMetaType::Void),
        // Slot 'slotUpdateAltitudes'
        QtMocHelpers::SlotData<void()>(46, 2, QMC::AccessPublic, QMetaType::Void),
        // Slot 'slotClearList'
        QtMocHelpers::SlotData<void()>(47, 2, QMC::AccessPublic, QMetaType::Void),
        // Slot 'slotClose'
        QtMocHelpers::SlotData<void()>(48, 2, QMC::AccessProtected, QMetaType::Void),
        // Slot 'downloadReady'
        QtMocHelpers::SlotData<void(bool)>(49, 2, QMC::AccessProtected, QMetaType::Void, {{
            { QMetaType::Bool, 50 },
        }}),
    };
    QtMocHelpers::UintData qt_properties {
    };
    QtMocHelpers::UintData qt_enums {
    };
    return QtMocHelpers::metaObjectData<ObservingList, qt_meta_tag_ZN13ObservingListE_t>(QMC::MetaObjectFlag{}, qt_stringData,
            qt_methods, qt_properties, qt_enums);
}
Q_CONSTINIT const QMetaObject ObservingList::staticMetaObject = { {
    QMetaObject::SuperData::link<QDialog::staticMetaObject>(),
    qt_staticMetaObjectStaticContent<qt_meta_tag_ZN13ObservingListE_t>.stringdata,
    qt_staticMetaObjectStaticContent<qt_meta_tag_ZN13ObservingListE_t>.data,
    qt_static_metacall,
    nullptr,
    qt_staticMetaObjectRelocatingContent<qt_meta_tag_ZN13ObservingListE_t>.metaTypes,
    nullptr
} };

void ObservingList::qt_static_metacall(QObject *_o, QMetaObject::Call _c, int _id, void **_a)
{
    auto *_t = static_cast<ObservingList *>(_o);
    if (_c == QMetaObject::InvokeMetaMethod) {
        switch (_id) {
        case 0: _t->slotAddObject((*reinterpret_cast<std::add_pointer_t<const SkyObject*>>(_a[1])),(*reinterpret_cast<std::add_pointer_t<bool>>(_a[2])),(*reinterpret_cast<std::add_pointer_t<bool>>(_a[3]))); break;
        case 1: _t->slotAddObject((*reinterpret_cast<std::add_pointer_t<const SkyObject*>>(_a[1])),(*reinterpret_cast<std::add_pointer_t<bool>>(_a[2]))); break;
        case 2: _t->slotAddObject((*reinterpret_cast<std::add_pointer_t<const SkyObject*>>(_a[1]))); break;
        case 3: _t->slotAddObject(); break;
        case 4: _t->slotRemoveSelectedObjects(); break;
        case 5: _t->slotRemoveObject((*reinterpret_cast<std::add_pointer_t<const SkyObject*>>(_a[1])),(*reinterpret_cast<std::add_pointer_t<bool>>(_a[2])),(*reinterpret_cast<std::add_pointer_t<bool>>(_a[3]))); break;
        case 6: _t->slotRemoveObject((*reinterpret_cast<std::add_pointer_t<const SkyObject*>>(_a[1])),(*reinterpret_cast<std::add_pointer_t<bool>>(_a[2]))); break;
        case 7: _t->slotRemoveObject((*reinterpret_cast<std::add_pointer_t<const SkyObject*>>(_a[1]))); break;
        case 8: _t->slotRemoveObject(); break;
        case 9: _t->slotCenterObject(); break;
        case 10: _t->slotSlewToObject(); break;
        case 11: _t->slotAddToEkosScheduler(); break;
        case 12: _t->slotDetails(); break;
        case 13: _t->slotAVT(); break;
        case 14: _t->slotWUT(); break;
        case 15: _t->slotAddToSession(); break;
        case 16: _t->slotFind(); break;
        case 17: _t->slotBatchAdd(); break;
        case 18: _t->slotNewSelection(); break;
        case 19: _t->slotOpenList(); break;
        case 20: _t->slotSaveList(); break;
        case 21: _t->slotLoadWishList(); break;
        case 22: _t->slotSaveSessionAs((*reinterpret_cast<std::add_pointer_t<bool>>(_a[1]))); break;
        case 23: _t->slotSaveSessionAs(); break;
        case 24: _t->slotSaveSession((*reinterpret_cast<std::add_pointer_t<bool>>(_a[1]))); break;
        case 25: _t->slotSaveSession(); break;
        case 26: _t->slotWizard(); break;
        case 27: _t->slotChangeTab((*reinterpret_cast<std::add_pointer_t<int>>(_a[1]))); break;
        case 28: _t->slotLocation(); break;
        case 29: _t->slotUpdate(); break;
        case 30: _t->slotSetTime(); break;
        case 31: _t->slotGetImage((*reinterpret_cast<std::add_pointer_t<bool>>(_a[1])),(*reinterpret_cast<std::add_pointer_t<const SkyObject*>>(_a[2]))); break;
        case 32: _t->slotGetImage((*reinterpret_cast<std::add_pointer_t<bool>>(_a[1]))); break;
        case 33: _t->slotGetImage(); break;
        case 34: _t->slotSearchImage(); break;
        case 35: _t->slotSaveAllImages(); break;
        case 36: _t->saveImage((*reinterpret_cast<std::add_pointer_t<QUrl>>(_a[1])),(*reinterpret_cast<std::add_pointer_t<QString>>(_a[2])),(*reinterpret_cast<std::add_pointer_t<const SkyObject*>>(_a[3]))); break;
        case 37: _t->saveImage((*reinterpret_cast<std::add_pointer_t<QUrl>>(_a[1])),(*reinterpret_cast<std::add_pointer_t<QString>>(_a[2]))); break;
        case 38: _t->slotImageViewer(); break;
        case 39: _t->slotDeleteCurrentImage(); break;
        case 40: _t->slotDeleteAllImages(); break;
        case 41: _t->slotDSS(); break;
        case 42: _t->slotCustomDSS(); break;
        case 43: _t->slotOALExport(); break;
        case 44: _t->slotAddVisibleObj(); break;
        case 45: _t->slotUpdateAltitudes(); break;
        case 46: _t->slotClearList(); break;
        case 47: _t->slotClose(); break;
        case 48: _t->downloadReady((*reinterpret_cast<std::add_pointer_t<bool>>(_a[1]))); break;
        default: ;
        }
    }
}

const QMetaObject *ObservingList::metaObject() const
{
    return QObject::d_ptr->metaObject ? QObject::d_ptr->dynamicMetaObject() : &staticMetaObject;
}

void *ObservingList::qt_metacast(const char *_clname)
{
    if (!_clname) return nullptr;
    if (!strcmp(_clname, qt_staticMetaObjectStaticContent<qt_meta_tag_ZN13ObservingListE_t>.strings))
        return static_cast<void*>(this);
    return QDialog::qt_metacast(_clname);
}

int ObservingList::qt_metacall(QMetaObject::Call _c, int _id, void **_a)
{
    _id = QDialog::qt_metacall(_c, _id, _a);
    if (_id < 0)
        return _id;
    if (_c == QMetaObject::InvokeMetaMethod) {
        if (_id < 49)
            qt_static_metacall(this, _c, _id, _a);
        _id -= 49;
    }
    if (_c == QMetaObject::RegisterMethodArgumentMetaType) {
        if (_id < 49)
            *reinterpret_cast<QMetaType *>(_a[0]) = QMetaType();
        _id -= 49;
    }
    return _id;
}
QT_WARNING_POP
