/********************************************************************************
** Form generated from reading UI file 'starhopperdialog.ui'
**
** Created by: Qt User Interface Compiler version 6.11.1
**
** WARNING! All changes made in this file will be lost when recompiling UI file!
********************************************************************************/

#ifndef UI_STARHOPPERDIALOG_H
#define UI_STARHOPPERDIALOG_H

#include <QtCore/QVariant>
#include <QtWidgets/QApplication>
#include <QtWidgets/QDialog>
#include <QtWidgets/QHBoxLayout>
#include <QtWidgets/QLabel>
#include <QtWidgets/QListWidget>
#include <QtWidgets/QPushButton>
#include <QtWidgets/QWidget>
#include <klocalizedstring.h>

QT_BEGIN_NAMESPACE

class Ui_StarHopperDialog
{
public:
    QListWidget *listWidget;
    QWidget *horizontalWidget;
    QHBoxLayout *horizontalLayout;
    QPushButton *DetailsButton;
    QPushButton *GotoButton;
    QPushButton *NextButton;
    QLabel *directionsLabel;

    void setupUi(QDialog *StarHopperDialog)
    {
        if (StarHopperDialog->objectName().isEmpty())
            StarHopperDialog->setObjectName("StarHopperDialog");
        StarHopperDialog->resize(400, 348);
        listWidget = new QListWidget(StarHopperDialog);
        listWidget->setObjectName("listWidget");
        listWidget->setGeometry(QRect(20, 20, 361, 211));
        horizontalWidget = new QWidget(StarHopperDialog);
        horizontalWidget->setObjectName("horizontalWidget");
        horizontalWidget->setGeometry(QRect(40, 290, 321, 61));
        horizontalLayout = new QHBoxLayout(horizontalWidget);
        horizontalLayout->setSpacing(6);
        horizontalLayout->setContentsMargins(11, 11, 11, 11);
        horizontalLayout->setObjectName("horizontalLayout");
        DetailsButton = new QPushButton(horizontalWidget);
        DetailsButton->setObjectName("DetailsButton");

        horizontalLayout->addWidget(DetailsButton);

        GotoButton = new QPushButton(horizontalWidget);
        GotoButton->setObjectName("GotoButton");

        horizontalLayout->addWidget(GotoButton);

        NextButton = new QPushButton(horizontalWidget);
        NextButton->setObjectName("NextButton");

        horizontalLayout->addWidget(NextButton);

        directionsLabel = new QLabel(StarHopperDialog);
        directionsLabel->setObjectName("directionsLabel");
        directionsLabel->setGeometry(QRect(20, 240, 361, 51));
        directionsLabel->raise();
        horizontalWidget->raise();
        listWidget->raise();

        retranslateUi(StarHopperDialog);

        QMetaObject::connectSlotsByName(StarHopperDialog);
    } // setupUi

    void retranslateUi(QDialog *StarHopperDialog)
    {
        StarHopperDialog->setWindowTitle(tr2i18n("Star-Hopper Results", nullptr));
        DetailsButton->setText(tr2i18n("Details", nullptr));
        GotoButton->setText(tr2i18n("Center", nullptr));
        NextButton->setText(tr2i18n("Next", nullptr));
        directionsLabel->setText(QString());
    } // retranslateUi

};

namespace Ui {
    class StarHopperDialog: public Ui_StarHopperDialog {};
} // namespace Ui

QT_END_NAMESPACE

#endif // STARHOPPERDIALOG_H

