/********************************************************************************
** Form generated from reading UI file 'opsfits.ui'
**
** Created by: Qt User Interface Compiler version 6.11.1
**
** WARNING! All changes made in this file will be lost when recompiling UI file!
********************************************************************************/

#ifndef UI_OPSFITS_H
#define UI_OPSFITS_H

#include <QtCore/QVariant>
#include <QtWidgets/QApplication>
#include <QtWidgets/QCheckBox>
#include <QtWidgets/QComboBox>
#include <QtWidgets/QGridLayout>
#include <QtWidgets/QGroupBox>
#include <QtWidgets/QHBoxLayout>
#include <QtWidgets/QLabel>
#include <QtWidgets/QPushButton>
#include <QtWidgets/QSlider>
#include <QtWidgets/QSpacerItem>
#include <QtWidgets/QSpinBox>
#include <QtWidgets/QVBoxLayout>
#include <QtWidgets/QWidget>
#include <klocalizedstring.h>

QT_BEGIN_NAMESPACE

class Ui_OpsFITS
{
public:
    QVBoxLayout *verticalLayout_4;
    QHBoxLayout *horizontalLayout_3;
    QVBoxLayout *verticalLayout_3;
    QGroupBox *FITSViewerGroup;
    QVBoxLayout *verticalLayout_2;
    QCheckBox *kcfg_useFITSViewer;
    QCheckBox *kcfg_singlePreviewFITS;
    QCheckBox *kcfg_singleWindowCapturedFITS;
    QCheckBox *kcfg_singleWindowOpenedFITS;
    QCheckBox *kcfg_focusFITSOnNewImage;
    QCheckBox *kcfg_independentWindowFITS;
    QCheckBox *kcfg_liveStackerOwnProcess;
    QGridLayout *gridLayout_2;
    QLabel *label;
    QLabel *label_2;
    QSpinBox *hipsOffsetY;
    QSpinBox *hipsOffsetX;
    QSlider *hipsOpacity;
    QGroupBox *groupBox_2;
    QGridLayout *gridLayout;
    QCheckBox *kcfg_AdaptiveSampling;
    QLabel *stretchPreviewSamplingLabel;
    QSpinBox *kcfg_StretchPreviewSampling;
    QGroupBox *clippingBox;
    QGridLayout *clippingLayout;
    QLabel *clipping64KLabel;
    QSpinBox *kcfg_Clipping64KValue;
    QLabel *clipping256Label;
    QSpinBox *kcfg_Clipping256Value;
    QGroupBox *groupBox;
    QVBoxLayout *verticalLayout;
    QCheckBox *kcfg_AutoStretch;
    QCheckBox *kcfg_LimitedResourcesMode;
    QCheckBox *kcfg_AutoDebayer;
    QCheckBox *kcfg_AutoWCS;
    QCheckBox *kcfg_Auto3DCube;
    QCheckBox *kcfg_NonLinearHistogram;
    QHBoxLayout *horizontalLayout_4;
    QLabel *label_3;
    QComboBox *kcfg_FitsCatalog;
    QCheckBox *kcfg_AutoHFR;
    QCheckBox *kcfg_QuickHFR;
    QHBoxLayout *horizontalLayout_2;
    QLabel *hfrSepLabel;
    QComboBox *HfrOptionsProfiles;
    QPushButton *editHfrProfile;
    QCheckBox *kcfg_StellarSolverPartition;
    QSpacerItem *verticalSpacer;
    QSpacerItem *verticalSpacer_2;

    void setupUi(QWidget *OpsFITS)
    {
        if (OpsFITS->objectName().isEmpty())
            OpsFITS->setObjectName("OpsFITS");
        OpsFITS->resize(575, 557);
        verticalLayout_4 = new QVBoxLayout(OpsFITS);
        verticalLayout_4->setSpacing(3);
        verticalLayout_4->setObjectName("verticalLayout_4");
        verticalLayout_4->setContentsMargins(3, 3, 3, 3);
        horizontalLayout_3 = new QHBoxLayout();
        horizontalLayout_3->setSpacing(3);
        horizontalLayout_3->setObjectName("horizontalLayout_3");
        verticalLayout_3 = new QVBoxLayout();
        verticalLayout_3->setSpacing(3);
        verticalLayout_3->setObjectName("verticalLayout_3");
        FITSViewerGroup = new QGroupBox(OpsFITS);
        FITSViewerGroup->setObjectName("FITSViewerGroup");
        FITSViewerGroup->setEnabled(true);
        verticalLayout_2 = new QVBoxLayout(FITSViewerGroup);
        verticalLayout_2->setObjectName("verticalLayout_2");
        kcfg_useFITSViewer = new QCheckBox(FITSViewerGroup);
        kcfg_useFITSViewer->setObjectName("kcfg_useFITSViewer");

        verticalLayout_2->addWidget(kcfg_useFITSViewer);

        kcfg_singlePreviewFITS = new QCheckBox(FITSViewerGroup);
        kcfg_singlePreviewFITS->setObjectName("kcfg_singlePreviewFITS");
        kcfg_singlePreviewFITS->setChecked(true);

        verticalLayout_2->addWidget(kcfg_singlePreviewFITS);

        kcfg_singleWindowCapturedFITS = new QCheckBox(FITSViewerGroup);
        kcfg_singleWindowCapturedFITS->setObjectName("kcfg_singleWindowCapturedFITS");
        kcfg_singleWindowCapturedFITS->setChecked(false);

        verticalLayout_2->addWidget(kcfg_singleWindowCapturedFITS);

        kcfg_singleWindowOpenedFITS = new QCheckBox(FITSViewerGroup);
        kcfg_singleWindowOpenedFITS->setObjectName("kcfg_singleWindowOpenedFITS");
        kcfg_singleWindowOpenedFITS->setChecked(true);

        verticalLayout_2->addWidget(kcfg_singleWindowOpenedFITS);

        kcfg_focusFITSOnNewImage = new QCheckBox(FITSViewerGroup);
        kcfg_focusFITSOnNewImage->setObjectName("kcfg_focusFITSOnNewImage");

        verticalLayout_2->addWidget(kcfg_focusFITSOnNewImage);

        kcfg_independentWindowFITS = new QCheckBox(FITSViewerGroup);
        kcfg_independentWindowFITS->setObjectName("kcfg_independentWindowFITS");

        verticalLayout_2->addWidget(kcfg_independentWindowFITS);

        kcfg_liveStackerOwnProcess = new QCheckBox(FITSViewerGroup);
        kcfg_liveStackerOwnProcess->setObjectName("kcfg_liveStackerOwnProcess");

        verticalLayout_2->addWidget(kcfg_liveStackerOwnProcess);

        gridLayout_2 = new QGridLayout();
        gridLayout_2->setObjectName("gridLayout_2");
        label = new QLabel(FITSViewerGroup);
        label->setObjectName("label");

        gridLayout_2->addWidget(label, 0, 0, 1, 1);

        label_2 = new QLabel(FITSViewerGroup);
        label_2->setObjectName("label_2");

        gridLayout_2->addWidget(label_2, 1, 0, 1, 1);

        hipsOffsetY = new QSpinBox(FITSViewerGroup);
        hipsOffsetY->setObjectName("hipsOffsetY");
        hipsOffsetY->setMinimum(-500);
        hipsOffsetY->setMaximum(500);
        hipsOffsetY->setSingleStep(10);

        gridLayout_2->addWidget(hipsOffsetY, 1, 1, 1, 1);

        hipsOffsetX = new QSpinBox(FITSViewerGroup);
        hipsOffsetX->setObjectName("hipsOffsetX");
        hipsOffsetX->setMinimum(-500);
        hipsOffsetX->setMaximum(500);
        hipsOffsetX->setSingleStep(10);

        gridLayout_2->addWidget(hipsOffsetX, 1, 2, 1, 1);

        hipsOpacity = new QSlider(FITSViewerGroup);
        hipsOpacity->setObjectName("hipsOpacity");
        hipsOpacity->setMinimum(1);
        hipsOpacity->setMaximum(100);
        hipsOpacity->setSingleStep(10);
        hipsOpacity->setOrientation(Qt::Horizontal);

        gridLayout_2->addWidget(hipsOpacity, 0, 1, 1, 2);


        verticalLayout_2->addLayout(gridLayout_2);


        verticalLayout_3->addWidget(FITSViewerGroup);

        groupBox_2 = new QGroupBox(OpsFITS);
        groupBox_2->setObjectName("groupBox_2");
        gridLayout = new QGridLayout(groupBox_2);
        gridLayout->setSpacing(3);
        gridLayout->setObjectName("gridLayout");
        gridLayout->setContentsMargins(3, 3, 3, 3);
        kcfg_AdaptiveSampling = new QCheckBox(groupBox_2);
        kcfg_AdaptiveSampling->setObjectName("kcfg_AdaptiveSampling");

        gridLayout->addWidget(kcfg_AdaptiveSampling, 0, 0, 1, 2);

        stretchPreviewSamplingLabel = new QLabel(groupBox_2);
        stretchPreviewSamplingLabel->setObjectName("stretchPreviewSamplingLabel");

        gridLayout->addWidget(stretchPreviewSamplingLabel, 1, 0, 1, 1);

        kcfg_StretchPreviewSampling = new QSpinBox(groupBox_2);
        kcfg_StretchPreviewSampling->setObjectName("kcfg_StretchPreviewSampling");
        kcfg_StretchPreviewSampling->setMinimum(1);
        kcfg_StretchPreviewSampling->setMaximum(5);
        kcfg_StretchPreviewSampling->setValue(4);

        gridLayout->addWidget(kcfg_StretchPreviewSampling, 1, 1, 1, 1);


        verticalLayout_3->addWidget(groupBox_2);

        clippingBox = new QGroupBox(OpsFITS);
        clippingBox->setObjectName("clippingBox");
        clippingLayout = new QGridLayout(clippingBox);
        clippingLayout->setSpacing(3);
        clippingLayout->setObjectName("clippingLayout");
        clippingLayout->setContentsMargins(3, 3, 3, 3);
        clipping64KLabel = new QLabel(clippingBox);
        clipping64KLabel->setObjectName("clipping64KLabel");

        clippingLayout->addWidget(clipping64KLabel, 0, 0, 1, 1);

        kcfg_Clipping64KValue = new QSpinBox(clippingBox);
        kcfg_Clipping64KValue->setObjectName("kcfg_Clipping64KValue");
        kcfg_Clipping64KValue->setMinimum(1);
        kcfg_Clipping64KValue->setMaximum(65536);
        kcfg_Clipping64KValue->setValue(60000);

        clippingLayout->addWidget(kcfg_Clipping64KValue, 0, 1, 1, 1);

        clipping256Label = new QLabel(clippingBox);
        clipping256Label->setObjectName("clipping256Label");

        clippingLayout->addWidget(clipping256Label, 1, 0, 1, 1);

        kcfg_Clipping256Value = new QSpinBox(clippingBox);
        kcfg_Clipping256Value->setObjectName("kcfg_Clipping256Value");
        kcfg_Clipping256Value->setMinimum(1);
        kcfg_Clipping256Value->setMaximum(255);
        kcfg_Clipping256Value->setValue(250);

        clippingLayout->addWidget(kcfg_Clipping256Value, 1, 1, 1, 1);


        verticalLayout_3->addWidget(clippingBox);


        horizontalLayout_3->addLayout(verticalLayout_3);

        groupBox = new QGroupBox(OpsFITS);
        groupBox->setObjectName("groupBox");
        verticalLayout = new QVBoxLayout(groupBox);
        verticalLayout->setObjectName("verticalLayout");
        verticalLayout->setContentsMargins(3, 3, 3, 3);
        kcfg_AutoStretch = new QCheckBox(groupBox);
        kcfg_AutoStretch->setObjectName("kcfg_AutoStretch");

        verticalLayout->addWidget(kcfg_AutoStretch);

        kcfg_LimitedResourcesMode = new QCheckBox(groupBox);
        kcfg_LimitedResourcesMode->setObjectName("kcfg_LimitedResourcesMode");

        verticalLayout->addWidget(kcfg_LimitedResourcesMode);

        kcfg_AutoDebayer = new QCheckBox(groupBox);
        kcfg_AutoDebayer->setObjectName("kcfg_AutoDebayer");
        kcfg_AutoDebayer->setChecked(true);

        verticalLayout->addWidget(kcfg_AutoDebayer);

        kcfg_AutoWCS = new QCheckBox(groupBox);
        kcfg_AutoWCS->setObjectName("kcfg_AutoWCS");

        verticalLayout->addWidget(kcfg_AutoWCS);

        kcfg_Auto3DCube = new QCheckBox(groupBox);
        kcfg_Auto3DCube->setObjectName("kcfg_Auto3DCube");
        kcfg_Auto3DCube->setChecked(true);

        verticalLayout->addWidget(kcfg_Auto3DCube);

        kcfg_NonLinearHistogram = new QCheckBox(groupBox);
        kcfg_NonLinearHistogram->setObjectName("kcfg_NonLinearHistogram");

        verticalLayout->addWidget(kcfg_NonLinearHistogram);

        horizontalLayout_4 = new QHBoxLayout();
        horizontalLayout_4->setObjectName("horizontalLayout_4");
        label_3 = new QLabel(groupBox);
        label_3->setObjectName("label_3");

        horizontalLayout_4->addWidget(label_3);

        kcfg_FitsCatalog = new QComboBox(groupBox);
        kcfg_FitsCatalog->addItem(QString());
        kcfg_FitsCatalog->addItem(QString());
        kcfg_FitsCatalog->setObjectName("kcfg_FitsCatalog");

        horizontalLayout_4->addWidget(kcfg_FitsCatalog);


        verticalLayout->addLayout(horizontalLayout_4);

        kcfg_AutoHFR = new QCheckBox(groupBox);
        kcfg_AutoHFR->setObjectName("kcfg_AutoHFR");
        kcfg_AutoHFR->setChecked(false);

        verticalLayout->addWidget(kcfg_AutoHFR);

        kcfg_QuickHFR = new QCheckBox(groupBox);
        kcfg_QuickHFR->setObjectName("kcfg_QuickHFR");
        kcfg_QuickHFR->setChecked(true);

        verticalLayout->addWidget(kcfg_QuickHFR);

        horizontalLayout_2 = new QHBoxLayout();
        horizontalLayout_2->setSpacing(2);
        horizontalLayout_2->setObjectName("horizontalLayout_2");
        hfrSepLabel = new QLabel(groupBox);
        hfrSepLabel->setObjectName("hfrSepLabel");

        horizontalLayout_2->addWidget(hfrSepLabel);

        HfrOptionsProfiles = new QComboBox(groupBox);
        HfrOptionsProfiles->setObjectName("HfrOptionsProfiles");

        horizontalLayout_2->addWidget(HfrOptionsProfiles);

        editHfrProfile = new QPushButton(groupBox);
        editHfrProfile->setObjectName("editHfrProfile");
        editHfrProfile->setMaximumSize(QSize(30, 16777215));

        horizontalLayout_2->addWidget(editHfrProfile);


        verticalLayout->addLayout(horizontalLayout_2);

        kcfg_StellarSolverPartition = new QCheckBox(groupBox);
        kcfg_StellarSolverPartition->setObjectName("kcfg_StellarSolverPartition");
        kcfg_StellarSolverPartition->setChecked(false);

        verticalLayout->addWidget(kcfg_StellarSolverPartition);

        verticalSpacer = new QSpacerItem(0, 0, QSizePolicy::Policy::Minimum, QSizePolicy::Policy::Expanding);

        verticalLayout->addItem(verticalSpacer);


        horizontalLayout_3->addWidget(groupBox);


        verticalLayout_4->addLayout(horizontalLayout_3);

        verticalSpacer_2 = new QSpacerItem(20, 3, QSizePolicy::Policy::Minimum, QSizePolicy::Policy::Expanding);

        verticalLayout_4->addItem(verticalSpacer_2);


        retranslateUi(OpsFITS);

        QMetaObject::connectSlotsByName(OpsFITS);
    } // setupUi

    void retranslateUi(QWidget *OpsFITS)
    {
        FITSViewerGroup->setTitle(tr2i18n("Look && Feel", nullptr));
#if QT_CONFIG(tooltip)
        kcfg_useFITSViewer->setToolTip(tr2i18n("Automatically display received images in the FITS Viewer", nullptr));
#endif // QT_CONFIG(tooltip)
        kcfg_useFITSViewer->setText(tr2i18n("Use FITS viewer", nullptr));
#if QT_CONFIG(tooltip)
        kcfg_singlePreviewFITS->setToolTip(tr2i18n("Display all captured FITS images in a single tab instead of multiple tabs per image.", nullptr));
#endif // QT_CONFIG(tooltip)
#if QT_CONFIG(statustip)
        kcfg_singlePreviewFITS->setStatusTip(QString());
#endif // QT_CONFIG(statustip)
#if QT_CONFIG(whatsthis)
        kcfg_singlePreviewFITS->setWhatsThis(QString());
#endif // QT_CONFIG(whatsthis)
        kcfg_singlePreviewFITS->setText(tr2i18n("Single preview tab", nullptr));
#if QT_CONFIG(tooltip)
        kcfg_singleWindowCapturedFITS->setToolTip(tr2i18n("Display captured FITS images from all cameras in a single FITS Viewer window instead of a dedicated window to each camera.", nullptr));
#endif // QT_CONFIG(tooltip)
#if QT_CONFIG(whatsthis)
        kcfg_singleWindowCapturedFITS->setWhatsThis(QString());
#endif // QT_CONFIG(whatsthis)
        kcfg_singleWindowCapturedFITS->setText(tr2i18n("Single window capture", nullptr));
#if QT_CONFIG(tooltip)
        kcfg_singleWindowOpenedFITS->setToolTip(tr2i18n("Display opened FITS images in a single FITS Viewer window instead of a dedicated window to each file.", nullptr));
#endif // QT_CONFIG(tooltip)
#if QT_CONFIG(whatsthis)
        kcfg_singleWindowOpenedFITS->setWhatsThis(QString());
#endif // QT_CONFIG(whatsthis)
        kcfg_singleWindowOpenedFITS->setText(tr2i18n("Single window open", nullptr));
#if QT_CONFIG(tooltip)
        kcfg_focusFITSOnNewImage->setToolTip(tr2i18n("Bring the FITSViewer window to the foreground when receiving a new image", nullptr));
#endif // QT_CONFIG(tooltip)
        kcfg_focusFITSOnNewImage->setText(tr2i18n("Focus on receiving an image", nullptr));
#if QT_CONFIG(tooltip)
        kcfg_independentWindowFITS->setToolTip(tr2i18n("Make FITS Viewer window independent from KStars", nullptr));
#endif // QT_CONFIG(tooltip)
        kcfg_independentWindowFITS->setText(tr2i18n("Independent window", nullptr));
#if QT_CONFIG(tooltip)
        kcfg_liveStackerOwnProcess->setToolTip(tr2i18n("<html><head/><body><p>Run Live Stacker as a separate process.</p></body></html>", nullptr));
#endif // QT_CONFIG(tooltip)
        kcfg_liveStackerOwnProcess->setText(tr2i18n("Live Stacker own process", nullptr));
        label->setText(tr2i18n("HiPS opacity:", nullptr));
        label_2->setText(tr2i18n("HiPS offset:", nullptr));
        groupBox_2->setTitle(tr2i18n("Down Sampling", nullptr));
#if QT_CONFIG(tooltip)
        kcfg_AdaptiveSampling->setToolTip(tr2i18n("<html><head/><body><p>Automatically down sample images based on available resources.</p></body></html>", nullptr));
#endif // QT_CONFIG(tooltip)
        kcfg_AdaptiveSampling->setText(tr2i18n("Adaptive sampling", nullptr));
#if QT_CONFIG(tooltip)
        stretchPreviewSamplingLabel->setToolTip(tr2i18n("Set the coarseness of the preview shown when sliding the fitsviewer's stretch parameter sliders. 1 is full resolution, but can be slow, 4 would be coarse resolution and fast.", nullptr));
#endif // QT_CONFIG(tooltip)
        stretchPreviewSamplingLabel->setText(tr2i18n("Stretch preview:", nullptr));
#if QT_CONFIG(tooltip)
        kcfg_StretchPreviewSampling->setToolTip(tr2i18n("Set the coarseness of the preview shown when sliding the fitsviewer's stretch parameter sliders. 1 is full resolution, but can be slow, 4 would be coarse resolution and fast.", nullptr));
#endif // QT_CONFIG(tooltip)
        clippingBox->setTitle(tr2i18n("Clipping Limits", nullptr));
#if QT_CONFIG(tooltip)
        clipping64KLabel->setToolTip(tr2i18n("Clipping value for 16-bit values.", nullptr));
#endif // QT_CONFIG(tooltip)
        clipping64KLabel->setText(tr2i18n("16bit threshold:", nullptr));
#if QT_CONFIG(tooltip)
        kcfg_Clipping64KValue->setToolTip(tr2i18n("64K Clipping value.", nullptr));
#endif // QT_CONFIG(tooltip)
#if QT_CONFIG(tooltip)
        clipping256Label->setToolTip(tr2i18n("Clipping value for 8-bit values.", nullptr));
#endif // QT_CONFIG(tooltip)
        clipping256Label->setText(tr2i18n("8Bit threshold:", nullptr));
#if QT_CONFIG(tooltip)
        kcfg_Clipping256Value->setToolTip(tr2i18n("Byte Clipping value.", nullptr));
#endif // QT_CONFIG(tooltip)
        groupBox->setTitle(tr2i18n("Processing", nullptr));
#if QT_CONFIG(tooltip)
        kcfg_AutoStretch->setToolTip(tr2i18n("Always apply auto stretch to images in FITS Viewer", nullptr));
#endif // QT_CONFIG(tooltip)
        kcfg_AutoStretch->setText(tr2i18n("Auto stretch", nullptr));
#if QT_CONFIG(tooltip)
        kcfg_LimitedResourcesMode->setToolTip(tr2i18n("<html><head/><body><p>Enable limited resource mode to turn off any resource-intensive operations:</p><ul style=\"margin-top: 0px; margin-bottom: 0px; margin-left: 0px; margin-right: 0px; -qt-list-indent: 1;\"><li style=\" margin-top:12px; margin-bottom:0px; margin-left:0px; margin-right:0px; -qt-block-indent:0; text-indent:0px;\"><span style=\" font-weight:600;\">Auto debayer</span>: Bayered images will not be debayered. Only grayscale images are shown.</li><li style=\" margin-top:0px; margin-bottom:0px; margin-left:0px; margin-right:0px; -qt-block-indent:0; text-indent:0px;\"><span style=\" font-weight:600;\">Auto WCS</span>: World Coordinate System data will not be processed. WCS maps sky coordinates to image coordinates. Equatorial grid lines, object identification, and telescope slew within an image are disabled.</li><li style=\" margin-top:0px; margin-bottom:12px; margin-left:0px; margin-right:0px; -qt-block-indent:0; text-indent:0px;\"><span style=\" font-weight:600;\">3D Cube</span>: RGB images will not"
                        " be processed. Only grayscale images are shown.</li></ul></body></html>", nullptr));
#endif // QT_CONFIG(tooltip)
        kcfg_LimitedResourcesMode->setText(tr2i18n("Limited resources mode", nullptr));
#if QT_CONFIG(tooltip)
        kcfg_AutoDebayer->setToolTip(tr2i18n("Automatically debayer captured image if it contains a bayer pattern", nullptr));
#endif // QT_CONFIG(tooltip)
        kcfg_AutoDebayer->setText(tr2i18n("Auto debayer", nullptr));
#if QT_CONFIG(tooltip)
        kcfg_AutoWCS->setToolTip(tr2i18n("<html><head/><body><p>Automatically load World-Coordinate-System (WCS) data when opening a FITS file.</p><p><span style=\" font-weight:600;\">Warning: Only enable this option on very fast machines as it can lead to unpredictable behavior resulting in crashes on slower machines.</span></p></body></html>", nullptr));
#endif // QT_CONFIG(tooltip)
        kcfg_AutoWCS->setText(tr2i18n("Auto WCS", nullptr));
#if QT_CONFIG(tooltip)
        kcfg_Auto3DCube->setToolTip(tr2i18n("<html><head/><body><p>Process 3D (RGB) FITS images. If unchecked, only first channel is processed.</p><p>NOTE: Live Stacker will always display a color image if requested to do so.</p></body></html>", nullptr));
#endif // QT_CONFIG(tooltip)
        kcfg_Auto3DCube->setText(tr2i18n("3D cube", nullptr));
#if QT_CONFIG(tooltip)
        kcfg_NonLinearHistogram->setToolTip(tr2i18n("<html><head/><body><p>Display histogram for the stretched non-linear image.</p></body></html>", nullptr));
#endif // QT_CONFIG(tooltip)
        kcfg_NonLinearHistogram->setText(tr2i18n("Non linear histogram", nullptr));
#if QT_CONFIG(tooltip)
        label_3->setToolTip(tr2i18n("<html><head/><body><p>Select a catalog to use to identify objects in the image. The default is the internal Sky Map. External catalogs require WCS and internet access.</p><p><span style=\" font-weight:600;\">Warning: Querying external catalogs can be slow on slow machines.</span></p></body></html>", nullptr));
#endif // QT_CONFIG(tooltip)
        label_3->setText(tr2i18n("Object Catalog:", nullptr));
        kcfg_FitsCatalog->setItemText(0, tr2i18n("Sky Map", nullptr));
        kcfg_FitsCatalog->setItemText(1, tr2i18n("Simbad", nullptr));

#if QT_CONFIG(tooltip)
        kcfg_AutoHFR->setToolTip(tr2i18n("Compute the HFR of images loaded into fitsviewer.", nullptr));
#endif // QT_CONFIG(tooltip)
        kcfg_AutoHFR->setText(tr2i18n("Auto compute HFR", nullptr));
#if QT_CONFIG(tooltip)
        kcfg_QuickHFR->setToolTip(tr2i18n("When computing the HFR, run it quickly by only looking at 25% of the image.", nullptr));
#endif // QT_CONFIG(tooltip)
        kcfg_QuickHFR->setText(tr2i18n("Quick HFR", nullptr));
#if QT_CONFIG(tooltip)
        hfrSepLabel->setToolTip(tr2i18n("Set the StellarSolver SEP profile for Capture-image HFR calculations.", nullptr));
#endif // QT_CONFIG(tooltip)
        hfrSepLabel->setText(tr2i18n("HFR SEP profile:", nullptr));
        editHfrProfile->setText(QString());
#if QT_CONFIG(tooltip)
        kcfg_StellarSolverPartition->setToolTip(tr2i18n("Enable StellarSolver partition. Partitions the image in multiple threads to speed up detecting stars. This may significantly speed up source extraction but may result in unstable operation.", nullptr));
#endif // QT_CONFIG(tooltip)
        kcfg_StellarSolverPartition->setText(tr2i18n("StellarSolver partitioning", nullptr));
        (void)OpsFITS;
    } // retranslateUi

};

namespace Ui {
    class OpsFITS: public Ui_OpsFITS {};
} // namespace Ui

QT_END_NAMESPACE

#endif // OPSFITS_H

