/*
 * This file was generated by qdbusxml2cpp version 0.8
 * Source file was org.kde.kstars.Ekos.Focus.xml
 *
 * qdbusxml2cpp is Copyright (C) The Qt Company Ltd. and other contributors.
 *
 * This is an auto-generated file.
 * Do not edit! All changes made to it will be lost.
 */

#include "focusadaptor.h"
#include <QtCore/QMetaObject>
#include <QtCore/QByteArray>
#include <QtCore/QList>
#include <QtCore/QMap>
#include <QtCore/QString>
#include <QtCore/QStringList>
#include <QtCore/QVariant>

/*
 * Implementation of adaptor class FocusAdaptor
 */

FocusAdaptor::FocusAdaptor(Ekos::FocusModule *parent)
    : QDBusAbstractAdaptor(parent)
{
    // constructor
    setAutoRelaySignals(true);
}

FocusAdaptor::~FocusAdaptor()
{
    // destructor
}

void FocusAdaptor::abort(const QString &trainname)
{
    // handle method call org.kde.kstars.Ekos.Focus.abort
    parent()->abort(trainname);
}

QString FocusAdaptor::camera(const QString &trainname)
{
    // handle method call org.kde.kstars.Ekos.Focus.camera
    return parent()->camera(trainname);
}

bool FocusAdaptor::canAutoFocus(const QString &trainname)
{
    // handle method call org.kde.kstars.Ekos.Focus.canAutoFocus
    return parent()->canAutoFocus(trainname);
}

bool FocusAdaptor::capture(const QString &trainname, double settleTime)
{
    // handle method call org.kde.kstars.Ekos.Focus.capture
    return parent()->capture(trainname, settleTime);
}

void FocusAdaptor::checkFocus(double requiredHFR, const QString &trainname)
{
    // handle method call org.kde.kstars.Ekos.Focus.checkFocus
    parent()->checkFocus(requiredHFR, trainname);
}

QString FocusAdaptor::filter(const QString &trainname)
{
    // handle method call org.kde.kstars.Ekos.Focus.filter
    return parent()->filter(trainname);
}

QString FocusAdaptor::filterWheel(const QString &trainname)
{
    // handle method call org.kde.kstars.Ekos.Focus.filterWheel
    return parent()->filterWheel(trainname);
}

bool FocusAdaptor::focusIn(const QString &trainname, int ms)
{
    // handle method call org.kde.kstars.Ekos.Focus.focusIn
    return parent()->focusIn(trainname, ms);
}

bool FocusAdaptor::focusOut(const QString &trainname, int ms)
{
    // handle method call org.kde.kstars.Ekos.Focus.focusOut
    return parent()->focusOut(trainname, ms);
}

QString FocusAdaptor::focuser(const QString &trainname)
{
    // handle method call org.kde.kstars.Ekos.Focus.focuser
    return parent()->focuser(trainname);
}

void FocusAdaptor::resetFrame(const QString &trainname)
{
    // handle method call org.kde.kstars.Ekos.Focus.resetFrame
    parent()->resetFrame(trainname);
}

bool FocusAdaptor::setAutoFocusParameters(const QString &trainname, int boxSize, int stepSize, int maxTravel, double tolerance)
{
    // handle method call org.kde.kstars.Ekos.Focus.setAutoFocusParameters
    return parent()->setAutoFocusParameters(trainname, boxSize, stepSize, maxTravel, tolerance);
}

bool FocusAdaptor::setAutoStarEnabled(bool enable, const QString &trainname)
{
    // handle method call org.kde.kstars.Ekos.Focus.setAutoStarEnabled
    return parent()->setAutoStarEnabled(enable, trainname);
}

bool FocusAdaptor::setAutoSubFrameEnabled(bool enable, const QString &trainname)
{
    // handle method call org.kde.kstars.Ekos.Focus.setAutoSubFrameEnabled
    return parent()->setAutoSubFrameEnabled(enable, trainname);
}

bool FocusAdaptor::setBinning(int binX, int binY, const QString &trainname)
{
    // handle method call org.kde.kstars.Ekos.Focus.setBinning
    return parent()->setBinning(binX, binY, trainname);
}

bool FocusAdaptor::setFilter(const QString &filter, const QString &trainname)
{
    // handle method call org.kde.kstars.Ekos.Focus.setFilter
    return parent()->setFilter(filter, trainname);
}

bool FocusAdaptor::start(const QString &trainname)
{
    // handle method call org.kde.kstars.Ekos.Focus.start
    return parent()->start(trainname);
}

Ekos::FocusState FocusAdaptor::status(const QString &trainname)
{
    // handle method call org.kde.kstars.Ekos.Focus.status
    return parent()->status(trainname);
}

bool FocusAdaptor::useFullField(const QString &trainname)
{
    // handle method call org.kde.kstars.Ekos.Focus.useFullField
    return parent()->useFullField(trainname);
}


#include "moc_focusadaptor.cpp"
