/****************************************************************************
** Meta object code from reading C++ file 'focusadaptor.h'
**
** Created by: The Qt Meta Object Compiler version 69 (Qt 6.11.1)
**
** WARNING! All changes made in this file will be lost!
*****************************************************************************/

#include "focusadaptor.h"
#include <QtCore/qmetatype.h>

#include <QtCore/qtmochelpers.h>

#include <memory>


#include <QtCore/qxptype_traits.h>
#if !defined(Q_MOC_OUTPUT_REVISION)
#error "The header file 'focusadaptor.h' doesn't include <QObject>."
#elif Q_MOC_OUTPUT_REVISION != 69
#error "This file was generated using the moc from 6.11.1. It"
#error "cannot be used with the include files from this version of Qt."
#error "(The moc has changed too much.)"
#endif

#ifndef Q_CONSTINIT
#define Q_CONSTINIT
#endif

QT_WARNING_PUSH
QT_WARNING_DISABLE_DEPRECATED
QT_WARNING_DISABLE_GCC("-Wuseless-cast")
namespace {
struct qt_meta_tag_ZN12FocusAdaptorE_t {};
} // unnamed namespace

template <> constexpr inline auto FocusAdaptor::qt_create_metaobjectdata<qt_meta_tag_ZN12FocusAdaptorE_t>()
{
    namespace QMC = QtMocConstants;
    QtMocHelpers::StringRefStorage qt_stringData {
        "FocusAdaptor",
        "D-Bus Interface",
        "org.kde.kstars.Ekos.Focus",
        "D-Bus Introspection",
        "  <interface name=\"org.kde.kstars.Ekos.Focus\">\n    <method name"
        "=\"camera\">\n      <arg direction=\"in\" type=\"s\" name=\"trainn"
        "ame\"/>\n      <arg direction=\"out\" type=\"s\"/>\n    </method>\n"
        "    <method name=\"filterWheel\">\n      <arg direction=\"in\" typ"
        "e=\"s\" name=\"trainname\"/>\n      <arg direction=\"out\" type=\""
        "s\"/>\n    </method>\n    <method name=\"filter\">\n      <arg dir"
        "ection=\"in\" type=\"s\" name=\"trainname\"/>\n      <arg directio"
        "n=\"out\" type=\"s\"/>\n    </method>\n    <method name=\"setFilte"
        "r\">\n      <arg direction=\"in\" type=\"s\" name=\"filter\"/>\n  "
        "    <arg direction=\"in\" type=\"s\" name=\"trainname\"/>\n      <"
        "arg direction=\"out\" type=\"b\"/>\n    </method>\n    <method nam"
        "e=\"focuser\">\n      <arg direction=\"in\" type=\"s\" name=\"trai"
        "nname\"/>\n      <arg direction=\"out\" type=\"s\"/>\n    </method"
        ">\n    <method name=\"status\">\n      <arg direction=\"in\" type="
        "\"s\" name=\"trainname\"/>\n      <arg direction=\"out\" type=\"(i"
        ")\"/>\n      <annotation value=\"Ekos::FocusState\" name=\"org.qtp"
        "roject.QtDBus.QtTypeName.Out0\"/>\n    </method>\n    <method name"
        "=\"start\">\n      <arg direction=\"in\" type=\"s\" name=\"trainna"
        "me\"/>\n      <arg direction=\"out\" type=\"b\"/>\n    </method>\n"
        "    <method name=\"abort\">\n      <arg direction=\"in\" type=\"s\""
        " name=\"trainname\"/>\n      <annotation value=\"true\" name=\"org"
        ".freedesktop.DBus.Method.NoReply\"/>\n    </method>\n    <method n"
        "ame=\"capture\">\n      <arg direction=\"in\" type=\"s\" name=\"tr"
        "ainname\"/>\n      <arg direction=\"in\" type=\"d\" name=\"settleT"
        "ime\"/>\n      <arg direction=\"out\" type=\"b\"/>\n    </method>\n"
        "    <method name=\"focusIn\">\n      <arg direction=\"in\" type=\""
        "s\" name=\"trainname\"/>\n      <arg direction=\"out\" type=\"b\"/"
        ">\n      <arg direction=\"in\" type=\"i\" name=\"ms\"/>\n    </met"
        "hod>\n    <method name=\"focusOut\">\n      <arg direction=\"in\" "
        "type=\"s\" name=\"trainname\"/>\n      <arg direction=\"out\" type"
        "=\"b\"/>\n      <arg direction=\"in\" type=\"i\" name=\"ms\"/>\n  "
        "  </method>\n    <method name=\"checkFocus\">\n      <arg directio"
        "n=\"in\" type=\"d\" name=\"requiredHFR\"/>\n      <arg direction=\""
        "in\" type=\"s\" name=\"trainname\"/>\n      <annotation value=\"tr"
        "ue\" name=\"org.freedesktop.DBus.Method.NoReply\"/>\n    </method>"
        "\n    <method name=\"canAutoFocus\">\n      <arg direction=\"in\" "
        "type=\"s\" name=\"trainname\"/>\n      <arg direction=\"out\" type"
        "=\"b\"/>\n    </method>\n    <method name=\"useFullField\">\n     "
        " <arg direction=\"in\" type=\"s\" name=\"trainname\"/>\n      <arg"
        " direction=\"out\" type=\"b\"/>\n    </method>\n    <method name=\""
        "setBinning\">\n      <arg direction=\"in\" type=\"i\" name=\"binX\""
        "/>\n      <arg direction=\"in\" type=\"i\" name=\"binY\"/>\n      "
        "<arg direction=\"in\" type=\"s\" name=\"trainname\"/>\n      <arg "
        "direction=\"out\" type=\"b\"/>\n    </method>\n    <method name=\""
        "setAutoStarEnabled\">\n      <arg direction=\"in\" type=\"b\" name"
        "=\"enable\"/>\n      <arg direction=\"in\" type=\"s\" name=\"train"
        "name\"/>\n      <arg direction=\"out\" type=\"b\"/>\n    </method>"
        "\n    <method name=\"setAutoSubFrameEnabled\">\n      <arg directi"
        "on=\"in\" type=\"b\" name=\"enable\"/>\n      <arg direction=\"in\""
        " type=\"s\" name=\"trainname\"/>\n      <arg direction=\"out\" typ"
        "e=\"b\"/>\n    </method>\n    <method name=\"setAutoFocusParameter"
        "s\">\n      <arg direction=\"in\" type=\"s\" name=\"trainname\"/>\n"
        "      <arg direction=\"in\" type=\"i\" name=\"boxSize\"/>\n      <"
        "arg direction=\"in\" type=\"i\" name=\"stepSize\"/>\n      <arg di"
        "rection=\"in\" type=\"i\" name=\"maxTravel\"/>\n      <arg directi"
        "on=\"in\" type=\"d\" name=\"tolerance\"/>\n      <arg direction=\""
        "out\" type=\"b\"/>\n    </method>\n    <method name=\"resetFrame\""
        ">\n      <arg direction=\"in\" type=\"s\" name=\"trainname\"/>\n  "
        "    <annotation value=\"true\" name=\"org.freedesktop.DBus.Method."
        "NoReply\"/>\n    </method>\n    <signal name=\"newStatus\">\n     "
        " <arg direction=\"out\" type=\"(i)\" name=\"status\"/>\n      <arg"
        " direction=\"out\" type=\"s\" name=\"trainname\"/>\n      <annotat"
        "ion value=\"Ekos::FocusState\" name=\"org.qtproject.QtDBus.QtTypeN"
        "ame.Out0\"/>\n    </signal>\n    <signal name=\"newLog\">\n      <"
        "arg direction=\"out\" type=\"s\" name=\"text\"/>\n    </signal>\n "
        "   <signal name=\"newHFR\">\n      <arg direction=\"out\" type=\"d"
        "\" name=\"HFR\"/>\n      <arg direction=\"out\" type=\"i\" name=\""
        "position\"/>\n      <arg direction=\"out\" type=\"b\" name=\"inAut"
        "ofocus\"/>\n      <arg direction=\"out\" type=\"s\" name=\"trainna"
        "me\"/>\n    </signal>\n  </interface>\n",
        "newHFR",
        "",
        "HFR",
        "position",
        "inAutofocus",
        "trainname",
        "newLog",
        "text",
        "newStatus",
        "Ekos::FocusState",
        "status",
        "abort",
        "Q_NOREPLY",
        "camera",
        "canAutoFocus",
        "capture",
        "settleTime",
        "checkFocus",
        "requiredHFR",
        "filter",
        "filterWheel",
        "focusIn",
        "ms",
        "focusOut",
        "focuser",
        "resetFrame",
        "setAutoFocusParameters",
        "boxSize",
        "stepSize",
        "maxTravel",
        "tolerance",
        "setAutoStarEnabled",
        "enable",
        "setAutoSubFrameEnabled",
        "setBinning",
        "binX",
        "binY",
        "setFilter",
        "start",
        "useFullField"
    };

    QtMocHelpers::UintData qt_methods {
        // Signal 'newHFR'
        QtMocHelpers::SignalData<void(double, int, bool, const QString &)>(5, 6, QMC::AccessPublic, QMetaType::Void, {{
            { QMetaType::Double, 7 }, { QMetaType::Int, 8 }, { QMetaType::Bool, 9 }, { QMetaType::QString, 10 },
        }}),
        // Signal 'newLog'
        QtMocHelpers::SignalData<void(const QString &)>(11, 6, QMC::AccessPublic, QMetaType::Void, {{
            { QMetaType::QString, 12 },
        }}),
        // Signal 'newStatus'
        QtMocHelpers::SignalData<void(Ekos::FocusState, const QString &)>(13, 6, QMC::AccessPublic, QMetaType::Void, {{
            { 0x80000000 | 14, 15 }, { QMetaType::QString, 10 },
        }}),
        // Slot 'abort'
        QtMocHelpers::SlotData<void(const QString &)>(16, 17, QMC::AccessPublic, QMetaType::Void, {{
            { QMetaType::QString, 10 },
        }}),
        // Slot 'camera'
        QtMocHelpers::SlotData<QString(const QString &)>(18, 6, QMC::AccessPublic, QMetaType::QString, {{
            { QMetaType::QString, 10 },
        }}),
        // Slot 'canAutoFocus'
        QtMocHelpers::SlotData<bool(const QString &)>(19, 6, QMC::AccessPublic, QMetaType::Bool, {{
            { QMetaType::QString, 10 },
        }}),
        // Slot 'capture'
        QtMocHelpers::SlotData<bool(const QString &, double)>(20, 6, QMC::AccessPublic, QMetaType::Bool, {{
            { QMetaType::QString, 10 }, { QMetaType::Double, 21 },
        }}),
        // Slot 'checkFocus'
        QtMocHelpers::SlotData<void(double, const QString &)>(22, 17, QMC::AccessPublic, QMetaType::Void, {{
            { QMetaType::Double, 23 }, { QMetaType::QString, 10 },
        }}),
        // Slot 'filter'
        QtMocHelpers::SlotData<QString(const QString &)>(24, 6, QMC::AccessPublic, QMetaType::QString, {{
            { QMetaType::QString, 10 },
        }}),
        // Slot 'filterWheel'
        QtMocHelpers::SlotData<QString(const QString &)>(25, 6, QMC::AccessPublic, QMetaType::QString, {{
            { QMetaType::QString, 10 },
        }}),
        // Slot 'focusIn'
        QtMocHelpers::SlotData<bool(const QString &, int)>(26, 6, QMC::AccessPublic, QMetaType::Bool, {{
            { QMetaType::QString, 10 }, { QMetaType::Int, 27 },
        }}),
        // Slot 'focusOut'
        QtMocHelpers::SlotData<bool(const QString &, int)>(28, 6, QMC::AccessPublic, QMetaType::Bool, {{
            { QMetaType::QString, 10 }, { QMetaType::Int, 27 },
        }}),
        // Slot 'focuser'
        QtMocHelpers::SlotData<QString(const QString &)>(29, 6, QMC::AccessPublic, QMetaType::QString, {{
            { QMetaType::QString, 10 },
        }}),
        // Slot 'resetFrame'
        QtMocHelpers::SlotData<void(const QString &)>(30, 17, QMC::AccessPublic, QMetaType::Void, {{
            { QMetaType::QString, 10 },
        }}),
        // Slot 'setAutoFocusParameters'
        QtMocHelpers::SlotData<bool(const QString &, int, int, int, double)>(31, 6, QMC::AccessPublic, QMetaType::Bool, {{
            { QMetaType::QString, 10 }, { QMetaType::Int, 32 }, { QMetaType::Int, 33 }, { QMetaType::Int, 34 },
            { QMetaType::Double, 35 },
        }}),
        // Slot 'setAutoStarEnabled'
        QtMocHelpers::SlotData<bool(bool, const QString &)>(36, 6, QMC::AccessPublic, QMetaType::Bool, {{
            { QMetaType::Bool, 37 }, { QMetaType::QString, 10 },
        }}),
        // Slot 'setAutoSubFrameEnabled'
        QtMocHelpers::SlotData<bool(bool, const QString &)>(38, 6, QMC::AccessPublic, QMetaType::Bool, {{
            { QMetaType::Bool, 37 }, { QMetaType::QString, 10 },
        }}),
        // Slot 'setBinning'
        QtMocHelpers::SlotData<bool(int, int, const QString &)>(39, 6, QMC::AccessPublic, QMetaType::Bool, {{
            { QMetaType::Int, 40 }, { QMetaType::Int, 41 }, { QMetaType::QString, 10 },
        }}),
        // Slot 'setFilter'
        QtMocHelpers::SlotData<bool(const QString &, const QString &)>(42, 6, QMC::AccessPublic, QMetaType::Bool, {{
            { QMetaType::QString, 24 }, { QMetaType::QString, 10 },
        }}),
        // Slot 'start'
        QtMocHelpers::SlotData<bool(const QString &)>(43, 6, QMC::AccessPublic, QMetaType::Bool, {{
            { QMetaType::QString, 10 },
        }}),
        // Slot 'status'
        QtMocHelpers::SlotData<Ekos::FocusState(const QString &)>(15, 6, QMC::AccessPublic, 0x80000000 | 14, {{
            { QMetaType::QString, 10 },
        }}),
        // Slot 'useFullField'
        QtMocHelpers::SlotData<bool(const QString &)>(44, 6, QMC::AccessPublic, QMetaType::Bool, {{
            { QMetaType::QString, 10 },
        }}),
    };
    QtMocHelpers::UintData qt_properties {
    };
    QtMocHelpers::UintData qt_enums {
    };
    QtMocHelpers::UintData qt_constructors {};
    QtMocHelpers::ClassInfos qt_classinfo({
            {    1,    2 },
            {    3,    4 },
    });
    return QtMocHelpers::metaObjectData<FocusAdaptor, qt_meta_tag_ZN12FocusAdaptorE_t>(QMC::MetaObjectFlag{}, qt_stringData,
            qt_methods, qt_properties, qt_enums, qt_constructors, qt_classinfo);
}
Q_CONSTINIT const QMetaObject FocusAdaptor::staticMetaObject = { {
    QMetaObject::SuperData::link<QDBusAbstractAdaptor::staticMetaObject>(),
    qt_staticMetaObjectStaticContent<qt_meta_tag_ZN12FocusAdaptorE_t>.stringdata,
    qt_staticMetaObjectStaticContent<qt_meta_tag_ZN12FocusAdaptorE_t>.data,
    qt_static_metacall,
    nullptr,
    qt_staticMetaObjectRelocatingContent<qt_meta_tag_ZN12FocusAdaptorE_t>.metaTypes,
    nullptr
} };

void FocusAdaptor::qt_static_metacall(QObject *_o, QMetaObject::Call _c, int _id, void **_a)
{
    auto *_t = static_cast<FocusAdaptor *>(_o);
    if (_c == QMetaObject::InvokeMetaMethod) {
        switch (_id) {
        case 0: _t->newHFR((*reinterpret_cast<std::add_pointer_t<double>>(_a[1])),(*reinterpret_cast<std::add_pointer_t<int>>(_a[2])),(*reinterpret_cast<std::add_pointer_t<bool>>(_a[3])),(*reinterpret_cast<std::add_pointer_t<QString>>(_a[4]))); break;
        case 1: _t->newLog((*reinterpret_cast<std::add_pointer_t<QString>>(_a[1]))); break;
        case 2: _t->newStatus((*reinterpret_cast<std::add_pointer_t<Ekos::FocusState>>(_a[1])),(*reinterpret_cast<std::add_pointer_t<QString>>(_a[2]))); break;
        case 3: _t->abort((*reinterpret_cast<std::add_pointer_t<QString>>(_a[1]))); break;
        case 4: { QString _r = _t->camera((*reinterpret_cast<std::add_pointer_t<QString>>(_a[1])));
            if (_a[0]) *reinterpret_cast<QString*>(_a[0]) = std::move(_r); }  break;
        case 5: { bool _r = _t->canAutoFocus((*reinterpret_cast<std::add_pointer_t<QString>>(_a[1])));
            if (_a[0]) *reinterpret_cast<bool*>(_a[0]) = std::move(_r); }  break;
        case 6: { bool _r = _t->capture((*reinterpret_cast<std::add_pointer_t<QString>>(_a[1])),(*reinterpret_cast<std::add_pointer_t<double>>(_a[2])));
            if (_a[0]) *reinterpret_cast<bool*>(_a[0]) = std::move(_r); }  break;
        case 7: _t->checkFocus((*reinterpret_cast<std::add_pointer_t<double>>(_a[1])),(*reinterpret_cast<std::add_pointer_t<QString>>(_a[2]))); break;
        case 8: { QString _r = _t->filter((*reinterpret_cast<std::add_pointer_t<QString>>(_a[1])));
            if (_a[0]) *reinterpret_cast<QString*>(_a[0]) = std::move(_r); }  break;
        case 9: { QString _r = _t->filterWheel((*reinterpret_cast<std::add_pointer_t<QString>>(_a[1])));
            if (_a[0]) *reinterpret_cast<QString*>(_a[0]) = std::move(_r); }  break;
        case 10: { bool _r = _t->focusIn((*reinterpret_cast<std::add_pointer_t<QString>>(_a[1])),(*reinterpret_cast<std::add_pointer_t<int>>(_a[2])));
            if (_a[0]) *reinterpret_cast<bool*>(_a[0]) = std::move(_r); }  break;
        case 11: { bool _r = _t->focusOut((*reinterpret_cast<std::add_pointer_t<QString>>(_a[1])),(*reinterpret_cast<std::add_pointer_t<int>>(_a[2])));
            if (_a[0]) *reinterpret_cast<bool*>(_a[0]) = std::move(_r); }  break;
        case 12: { QString _r = _t->focuser((*reinterpret_cast<std::add_pointer_t<QString>>(_a[1])));
            if (_a[0]) *reinterpret_cast<QString*>(_a[0]) = std::move(_r); }  break;
        case 13: _t->resetFrame((*reinterpret_cast<std::add_pointer_t<QString>>(_a[1]))); break;
        case 14: { bool _r = _t->setAutoFocusParameters((*reinterpret_cast<std::add_pointer_t<QString>>(_a[1])),(*reinterpret_cast<std::add_pointer_t<int>>(_a[2])),(*reinterpret_cast<std::add_pointer_t<int>>(_a[3])),(*reinterpret_cast<std::add_pointer_t<int>>(_a[4])),(*reinterpret_cast<std::add_pointer_t<double>>(_a[5])));
            if (_a[0]) *reinterpret_cast<bool*>(_a[0]) = std::move(_r); }  break;
        case 15: { bool _r = _t->setAutoStarEnabled((*reinterpret_cast<std::add_pointer_t<bool>>(_a[1])),(*reinterpret_cast<std::add_pointer_t<QString>>(_a[2])));
            if (_a[0]) *reinterpret_cast<bool*>(_a[0]) = std::move(_r); }  break;
        case 16: { bool _r = _t->setAutoSubFrameEnabled((*reinterpret_cast<std::add_pointer_t<bool>>(_a[1])),(*reinterpret_cast<std::add_pointer_t<QString>>(_a[2])));
            if (_a[0]) *reinterpret_cast<bool*>(_a[0]) = std::move(_r); }  break;
        case 17: { bool _r = _t->setBinning((*reinterpret_cast<std::add_pointer_t<int>>(_a[1])),(*reinterpret_cast<std::add_pointer_t<int>>(_a[2])),(*reinterpret_cast<std::add_pointer_t<QString>>(_a[3])));
            if (_a[0]) *reinterpret_cast<bool*>(_a[0]) = std::move(_r); }  break;
        case 18: { bool _r = _t->setFilter((*reinterpret_cast<std::add_pointer_t<QString>>(_a[1])),(*reinterpret_cast<std::add_pointer_t<QString>>(_a[2])));
            if (_a[0]) *reinterpret_cast<bool*>(_a[0]) = std::move(_r); }  break;
        case 19: { bool _r = _t->start((*reinterpret_cast<std::add_pointer_t<QString>>(_a[1])));
            if (_a[0]) *reinterpret_cast<bool*>(_a[0]) = std::move(_r); }  break;
        case 20: { Ekos::FocusState _r = _t->status((*reinterpret_cast<std::add_pointer_t<QString>>(_a[1])));
            if (_a[0]) *reinterpret_cast<Ekos::FocusState*>(_a[0]) = std::move(_r); }  break;
        case 21: { bool _r = _t->useFullField((*reinterpret_cast<std::add_pointer_t<QString>>(_a[1])));
            if (_a[0]) *reinterpret_cast<bool*>(_a[0]) = std::move(_r); }  break;
        default: ;
        }
    }
    if (_c == QMetaObject::RegisterMethodArgumentMetaType) {
        switch (_id) {
        default: *reinterpret_cast<QMetaType *>(_a[0]) = QMetaType(); break;
        case 2:
            switch (*reinterpret_cast<int*>(_a[1])) {
            default: *reinterpret_cast<QMetaType *>(_a[0]) = QMetaType(); break;
            case 0:
                *reinterpret_cast<QMetaType *>(_a[0]) = QMetaType::fromType< Ekos::FocusState >(); break;
            }
            break;
        }
    }
    if (_c == QMetaObject::IndexOfMethod) {
        if (QtMocHelpers::indexOfMethod<void (FocusAdaptor::*)(double , int , bool , const QString & )>(_a, &FocusAdaptor::newHFR, 0))
            return;
        if (QtMocHelpers::indexOfMethod<void (FocusAdaptor::*)(const QString & )>(_a, &FocusAdaptor::newLog, 1))
            return;
        if (QtMocHelpers::indexOfMethod<void (FocusAdaptor::*)(Ekos::FocusState , const QString & )>(_a, &FocusAdaptor::newStatus, 2))
            return;
    }
}

const QMetaObject *FocusAdaptor::metaObject() const
{
    return QObject::d_ptr->metaObject ? QObject::d_ptr->dynamicMetaObject() : &staticMetaObject;
}

void *FocusAdaptor::qt_metacast(const char *_clname)
{
    if (!_clname) return nullptr;
    if (!strcmp(_clname, qt_staticMetaObjectStaticContent<qt_meta_tag_ZN12FocusAdaptorE_t>.strings))
        return static_cast<void*>(this);
    return QDBusAbstractAdaptor::qt_metacast(_clname);
}

int FocusAdaptor::qt_metacall(QMetaObject::Call _c, int _id, void **_a)
{
    _id = QDBusAbstractAdaptor::qt_metacall(_c, _id, _a);
    if (_id < 0)
        return _id;
    if (_c == QMetaObject::InvokeMetaMethod) {
        if (_id < 22)
            qt_static_metacall(this, _c, _id, _a);
        _id -= 22;
    }
    if (_c == QMetaObject::RegisterMethodArgumentMetaType) {
        if (_id < 22)
            qt_static_metacall(this, _c, _id, _a);
        _id -= 22;
    }
    return _id;
}

// SIGNAL 0
void FocusAdaptor::newHFR(double _t1, int _t2, bool _t3, const QString & _t4)
{
    QMetaObject::activate<void>(this, &staticMetaObject, 0, nullptr, _t1, _t2, _t3, _t4);
}

// SIGNAL 1
void FocusAdaptor::newLog(const QString & _t1)
{
    QMetaObject::activate<void>(this, &staticMetaObject, 1, nullptr, _t1);
}

// SIGNAL 2
void FocusAdaptor::newStatus(Ekos::FocusState _t1, const QString & _t2)
{
    QMetaObject::activate<void>(this, &staticMetaObject, 2, nullptr, _t1, _t2);
}
QT_WARNING_POP
