/****************************************************************************
** Meta object code from reading C++ file 'fitsviewer.h'
**
** Created by: The Qt Meta Object Compiler version 69 (Qt 6.11.1)
**
** WARNING! All changes made in this file will be lost!
*****************************************************************************/

#include "../../../../kstars-3.8.4.1/kstars/fitsviewer/fitsviewer.h"
#include <QtGui/qtextcursor.h>
#include <QtNetwork/QSslError>
#include <QtGui/qscreen.h>
#include <QtCore/qmetatype.h>

#include <QtCore/qtmochelpers.h>

#include <memory>


#include <QtCore/qxptype_traits.h>
#if !defined(Q_MOC_OUTPUT_REVISION)
#error "The header file 'fitsviewer.h' doesn't include <QObject>."
#elif Q_MOC_OUTPUT_REVISION != 69
#error "This file was generated using the moc from 6.11.1. It"
#error "cannot be used with the include files from this version of Qt."
#error "(The moc has changed too much.)"
#endif

#ifndef Q_CONSTINIT
#define Q_CONSTINIT
#endif

QT_WARNING_PUSH
QT_WARNING_DISABLE_DEPRECATED
QT_WARNING_DISABLE_GCC("-Wuseless-cast")
namespace {
struct qt_meta_tag_ZN10FITSViewerE_t {};
} // unnamed namespace

template <> constexpr inline auto FITSViewer::qt_create_metaobjectdata<qt_meta_tag_ZN10FITSViewerE_t>()
{
    namespace QMC = QtMocConstants;
    QtMocHelpers::StringRefStorage qt_stringData {
        "FITSViewer",
        "trackingStarSelected",
        "",
        "x",
        "y",
        "loaded",
        "tabUID",
        "closed",
        "failed",
        "errorMessage",
        "terminated",
        "changeAlwaysOnTop",
        "Qt::ApplicationState",
        "state",
        "openFile",
        "blink",
        "nextBlink",
        "previousBlink",
        "stack",
        "restack",
        "stackCancelled",
        "saveFile",
        "saveFileAs",
        "copyFITS",
        "statFITS",
        "toggleSelectionMode",
        "headerFITS",
        "debayerFITS",
        "histoFITS",
        "tabFocusUpdated",
        "currentIndex",
        "updateStatusBar",
        "msg",
        "FITSBar",
        "id",
        "ZoomIn",
        "ZoomOut",
        "ZoomAllIn",
        "ZoomAllOut",
        "ZoomDefault",
        "ZoomToFit",
        "FitToZoom",
        "updateAction",
        "name",
        "enable",
        "updateTabStatus",
        "clean",
        "QUrl",
        "imageURL",
        "closeTab",
        "index",
        "toggleStars",
        "nextTab",
        "previousTab",
        "toggleCrossHair",
        "toggleClipping",
        "toggleEQGrid",
        "toggleObjects",
        "togglePixelGrid",
        "toggle3DGraph",
        "toggleHiPSOverlay",
        "starProfileButtonOff",
        "centerTelescope",
        "updateWCSFunctions",
        "applyFilter",
        "ftype",
        "rotateCW",
        "rotateCCW",
        "flipHorizontal",
        "flipVertical",
        "setDebayerAction",
        "updateScopeButton",
        "ROIFixedSize",
        "s",
        "customROIInputWindow"
    };

    QtMocHelpers::UintData qt_methods {
        // Signal 'trackingStarSelected'
        QtMocHelpers::SignalData<void(int, int)>(1, 2, QMC::AccessPublic, QMetaType::Void, {{
            { QMetaType::Int, 3 }, { QMetaType::Int, 4 },
        }}),
        // Signal 'loaded'
        QtMocHelpers::SignalData<void(int)>(5, 2, QMC::AccessPublic, QMetaType::Void, {{
            { QMetaType::Int, 6 },
        }}),
        // Signal 'closed'
        QtMocHelpers::SignalData<void(int)>(7, 2, QMC::AccessPublic, QMetaType::Void, {{
            { QMetaType::Int, 6 },
        }}),
        // Signal 'failed'
        QtMocHelpers::SignalData<void(const QString &)>(8, 2, QMC::AccessPublic, QMetaType::Void, {{
            { QMetaType::QString, 9 },
        }}),
        // Signal 'terminated'
        QtMocHelpers::SignalData<void()>(10, 2, QMC::AccessPublic, QMetaType::Void),
        // Slot 'changeAlwaysOnTop'
        QtMocHelpers::SlotData<void(Qt::ApplicationState)>(11, 2, QMC::AccessPublic, QMetaType::Void, {{
            { 0x80000000 | 12, 13 },
        }}),
        // Slot 'openFile'
        QtMocHelpers::SlotData<void()>(14, 2, QMC::AccessPublic, QMetaType::Void),
        // Slot 'blink'
        QtMocHelpers::SlotData<void()>(15, 2, QMC::AccessPublic, QMetaType::Void),
        // Slot 'nextBlink'
        QtMocHelpers::SlotData<void()>(16, 2, QMC::AccessPublic, QMetaType::Void),
        // Slot 'previousBlink'
        QtMocHelpers::SlotData<void()>(17, 2, QMC::AccessPublic, QMetaType::Void),
        // Slot 'stack'
        QtMocHelpers::SlotData<void()>(18, 2, QMC::AccessPublic, QMetaType::Void),
        // Slot 'restack'
        QtMocHelpers::SlotData<void(const int)>(19, 2, QMC::AccessPublic, QMetaType::Void, {{
            { QMetaType::Int, 6 },
        }}),
        // Slot 'stackCancelled'
        QtMocHelpers::SlotData<void(const int)>(20, 2, QMC::AccessPublic, QMetaType::Void, {{
            { QMetaType::Int, 6 },
        }}),
        // Slot 'saveFile'
        QtMocHelpers::SlotData<void()>(21, 2, QMC::AccessPublic, QMetaType::Void),
        // Slot 'saveFileAs'
        QtMocHelpers::SlotData<void()>(22, 2, QMC::AccessPublic, QMetaType::Void),
        // Slot 'copyFITS'
        QtMocHelpers::SlotData<void()>(23, 2, QMC::AccessPublic, QMetaType::Void),
        // Slot 'statFITS'
        QtMocHelpers::SlotData<void()>(24, 2, QMC::AccessPublic, QMetaType::Void),
        // Slot 'toggleSelectionMode'
        QtMocHelpers::SlotData<void()>(25, 2, QMC::AccessPublic, QMetaType::Void),
        // Slot 'headerFITS'
        QtMocHelpers::SlotData<void()>(26, 2, QMC::AccessPublic, QMetaType::Void),
        // Slot 'debayerFITS'
        QtMocHelpers::SlotData<void()>(27, 2, QMC::AccessPublic, QMetaType::Void),
        // Slot 'histoFITS'
        QtMocHelpers::SlotData<void()>(28, 2, QMC::AccessPublic, QMetaType::Void),
        // Slot 'tabFocusUpdated'
        QtMocHelpers::SlotData<void(int)>(29, 2, QMC::AccessPublic, QMetaType::Void, {{
            { QMetaType::Int, 30 },
        }}),
        // Slot 'updateStatusBar'
        QtMocHelpers::SlotData<void(const QString &, FITSBar)>(31, 2, QMC::AccessPublic, QMetaType::Void, {{
            { QMetaType::QString, 32 }, { 0x80000000 | 33, 34 },
        }}),
        // Slot 'ZoomIn'
        QtMocHelpers::SlotData<void()>(35, 2, QMC::AccessPublic, QMetaType::Void),
        // Slot 'ZoomOut'
        QtMocHelpers::SlotData<void()>(36, 2, QMC::AccessPublic, QMetaType::Void),
        // Slot 'ZoomAllIn'
        QtMocHelpers::SlotData<void()>(37, 2, QMC::AccessPublic, QMetaType::Void),
        // Slot 'ZoomAllOut'
        QtMocHelpers::SlotData<void()>(38, 2, QMC::AccessPublic, QMetaType::Void),
        // Slot 'ZoomDefault'
        QtMocHelpers::SlotData<void()>(39, 2, QMC::AccessPublic, QMetaType::Void),
        // Slot 'ZoomToFit'
        QtMocHelpers::SlotData<void()>(40, 2, QMC::AccessPublic, QMetaType::Void),
        // Slot 'FitToZoom'
        QtMocHelpers::SlotData<void()>(41, 2, QMC::AccessPublic, QMetaType::Void),
        // Slot 'updateAction'
        QtMocHelpers::SlotData<void(const QString &, bool)>(42, 2, QMC::AccessPublic, QMetaType::Void, {{
            { QMetaType::QString, 43 }, { QMetaType::Bool, 44 },
        }}),
        // Slot 'updateTabStatus'
        QtMocHelpers::SlotData<void(bool, const QUrl &)>(45, 2, QMC::AccessPublic, QMetaType::Void, {{
            { QMetaType::Bool, 46 }, { 0x80000000 | 47, 48 },
        }}),
        // Slot 'closeTab'
        QtMocHelpers::SlotData<void(int)>(49, 2, QMC::AccessPublic, QMetaType::Void, {{
            { QMetaType::Int, 50 },
        }}),
        // Slot 'toggleStars'
        QtMocHelpers::SlotData<void()>(51, 2, QMC::AccessPublic, QMetaType::Void),
        // Slot 'nextTab'
        QtMocHelpers::SlotData<void()>(52, 2, QMC::AccessPublic, QMetaType::Void),
        // Slot 'previousTab'
        QtMocHelpers::SlotData<void()>(53, 2, QMC::AccessPublic, QMetaType::Void),
        // Slot 'toggleCrossHair'
        QtMocHelpers::SlotData<void()>(54, 2, QMC::AccessPublic, QMetaType::Void),
        // Slot 'toggleClipping'
        QtMocHelpers::SlotData<void()>(55, 2, QMC::AccessPublic, QMetaType::Void),
        // Slot 'toggleEQGrid'
        QtMocHelpers::SlotData<void()>(56, 2, QMC::AccessPublic, QMetaType::Void),
        // Slot 'toggleObjects'
        QtMocHelpers::SlotData<void()>(57, 2, QMC::AccessPublic, QMetaType::Void),
        // Slot 'togglePixelGrid'
        QtMocHelpers::SlotData<void()>(58, 2, QMC::AccessPublic, QMetaType::Void),
        // Slot 'toggle3DGraph'
        QtMocHelpers::SlotData<void()>(59, 2, QMC::AccessPublic, QMetaType::Void),
        // Slot 'toggleHiPSOverlay'
        QtMocHelpers::SlotData<void()>(60, 2, QMC::AccessPublic, QMetaType::Void),
        // Slot 'starProfileButtonOff'
        QtMocHelpers::SlotData<void()>(61, 2, QMC::AccessPublic, QMetaType::Void),
        // Slot 'centerTelescope'
        QtMocHelpers::SlotData<void()>(62, 2, QMC::AccessPublic, QMetaType::Void),
        // Slot 'updateWCSFunctions'
        QtMocHelpers::SlotData<void()>(63, 2, QMC::AccessPublic, QMetaType::Void),
        // Slot 'applyFilter'
        QtMocHelpers::SlotData<void(int)>(64, 2, QMC::AccessPublic, QMetaType::Void, {{
            { QMetaType::Int, 65 },
        }}),
        // Slot 'rotateCW'
        QtMocHelpers::SlotData<void()>(66, 2, QMC::AccessPublic, QMetaType::Void),
        // Slot 'rotateCCW'
        QtMocHelpers::SlotData<void()>(67, 2, QMC::AccessPublic, QMetaType::Void),
        // Slot 'flipHorizontal'
        QtMocHelpers::SlotData<void()>(68, 2, QMC::AccessPublic, QMetaType::Void),
        // Slot 'flipVertical'
        QtMocHelpers::SlotData<void()>(69, 2, QMC::AccessPublic, QMetaType::Void),
        // Slot 'setDebayerAction'
        QtMocHelpers::SlotData<void(bool)>(70, 2, QMC::AccessPublic, QMetaType::Void, {{
            { QMetaType::Bool, 2 },
        }}),
        // Slot 'updateScopeButton'
        QtMocHelpers::SlotData<void()>(71, 2, QMC::AccessPublic, QMetaType::Void),
        // Slot 'ROIFixedSize'
        QtMocHelpers::SlotData<void(int)>(72, 2, QMC::AccessPublic, QMetaType::Void, {{
            { QMetaType::Int, 73 },
        }}),
        // Slot 'customROIInputWindow'
        QtMocHelpers::SlotData<void()>(74, 2, QMC::AccessPublic, QMetaType::Void),
    };
    QtMocHelpers::UintData qt_properties {
    };
    QtMocHelpers::UintData qt_enums {
    };
    return QtMocHelpers::metaObjectData<FITSViewer, qt_meta_tag_ZN10FITSViewerE_t>(QMC::MetaObjectFlag{}, qt_stringData,
            qt_methods, qt_properties, qt_enums);
}
Q_CONSTINIT const QMetaObject FITSViewer::staticMetaObject = { {
    QMetaObject::SuperData::link<KXmlGuiWindow::staticMetaObject>(),
    qt_staticMetaObjectStaticContent<qt_meta_tag_ZN10FITSViewerE_t>.stringdata,
    qt_staticMetaObjectStaticContent<qt_meta_tag_ZN10FITSViewerE_t>.data,
    qt_static_metacall,
    nullptr,
    qt_staticMetaObjectRelocatingContent<qt_meta_tag_ZN10FITSViewerE_t>.metaTypes,
    nullptr
} };

void FITSViewer::qt_static_metacall(QObject *_o, QMetaObject::Call _c, int _id, void **_a)
{
    auto *_t = static_cast<FITSViewer *>(_o);
    if (_c == QMetaObject::InvokeMetaMethod) {
        switch (_id) {
        case 0: _t->trackingStarSelected((*reinterpret_cast<std::add_pointer_t<int>>(_a[1])),(*reinterpret_cast<std::add_pointer_t<int>>(_a[2]))); break;
        case 1: _t->loaded((*reinterpret_cast<std::add_pointer_t<int>>(_a[1]))); break;
        case 2: _t->closed((*reinterpret_cast<std::add_pointer_t<int>>(_a[1]))); break;
        case 3: _t->failed((*reinterpret_cast<std::add_pointer_t<QString>>(_a[1]))); break;
        case 4: _t->terminated(); break;
        case 5: _t->changeAlwaysOnTop((*reinterpret_cast<std::add_pointer_t<Qt::ApplicationState>>(_a[1]))); break;
        case 6: _t->openFile(); break;
        case 7: _t->blink(); break;
        case 8: _t->nextBlink(); break;
        case 9: _t->previousBlink(); break;
        case 10: _t->stack(); break;
        case 11: _t->restack((*reinterpret_cast<std::add_pointer_t<int>>(_a[1]))); break;
        case 12: _t->stackCancelled((*reinterpret_cast<std::add_pointer_t<int>>(_a[1]))); break;
        case 13: _t->saveFile(); break;
        case 14: _t->saveFileAs(); break;
        case 15: _t->copyFITS(); break;
        case 16: _t->statFITS(); break;
        case 17: _t->toggleSelectionMode(); break;
        case 18: _t->headerFITS(); break;
        case 19: _t->debayerFITS(); break;
        case 20: _t->histoFITS(); break;
        case 21: _t->tabFocusUpdated((*reinterpret_cast<std::add_pointer_t<int>>(_a[1]))); break;
        case 22: _t->updateStatusBar((*reinterpret_cast<std::add_pointer_t<QString>>(_a[1])),(*reinterpret_cast<std::add_pointer_t<FITSBar>>(_a[2]))); break;
        case 23: _t->ZoomIn(); break;
        case 24: _t->ZoomOut(); break;
        case 25: _t->ZoomAllIn(); break;
        case 26: _t->ZoomAllOut(); break;
        case 27: _t->ZoomDefault(); break;
        case 28: _t->ZoomToFit(); break;
        case 29: _t->FitToZoom(); break;
        case 30: _t->updateAction((*reinterpret_cast<std::add_pointer_t<QString>>(_a[1])),(*reinterpret_cast<std::add_pointer_t<bool>>(_a[2]))); break;
        case 31: _t->updateTabStatus((*reinterpret_cast<std::add_pointer_t<bool>>(_a[1])),(*reinterpret_cast<std::add_pointer_t<QUrl>>(_a[2]))); break;
        case 32: _t->closeTab((*reinterpret_cast<std::add_pointer_t<int>>(_a[1]))); break;
        case 33: _t->toggleStars(); break;
        case 34: _t->nextTab(); break;
        case 35: _t->previousTab(); break;
        case 36: _t->toggleCrossHair(); break;
        case 37: _t->toggleClipping(); break;
        case 38: _t->toggleEQGrid(); break;
        case 39: _t->toggleObjects(); break;
        case 40: _t->togglePixelGrid(); break;
        case 41: _t->toggle3DGraph(); break;
        case 42: _t->toggleHiPSOverlay(); break;
        case 43: _t->starProfileButtonOff(); break;
        case 44: _t->centerTelescope(); break;
        case 45: _t->updateWCSFunctions(); break;
        case 46: _t->applyFilter((*reinterpret_cast<std::add_pointer_t<int>>(_a[1]))); break;
        case 47: _t->rotateCW(); break;
        case 48: _t->rotateCCW(); break;
        case 49: _t->flipHorizontal(); break;
        case 50: _t->flipVertical(); break;
        case 51: _t->setDebayerAction((*reinterpret_cast<std::add_pointer_t<bool>>(_a[1]))); break;
        case 52: _t->updateScopeButton(); break;
        case 53: _t->ROIFixedSize((*reinterpret_cast<std::add_pointer_t<int>>(_a[1]))); break;
        case 54: _t->customROIInputWindow(); break;
        default: ;
        }
    }
    if (_c == QMetaObject::IndexOfMethod) {
        if (QtMocHelpers::indexOfMethod<void (FITSViewer::*)(int , int )>(_a, &FITSViewer::trackingStarSelected, 0))
            return;
        if (QtMocHelpers::indexOfMethod<void (FITSViewer::*)(int )>(_a, &FITSViewer::loaded, 1))
            return;
        if (QtMocHelpers::indexOfMethod<void (FITSViewer::*)(int )>(_a, &FITSViewer::closed, 2))
            return;
        if (QtMocHelpers::indexOfMethod<void (FITSViewer::*)(const QString & )>(_a, &FITSViewer::failed, 3))
            return;
        if (QtMocHelpers::indexOfMethod<void (FITSViewer::*)()>(_a, &FITSViewer::terminated, 4))
            return;
    }
}

const QMetaObject *FITSViewer::metaObject() const
{
    return QObject::d_ptr->metaObject ? QObject::d_ptr->dynamicMetaObject() : &staticMetaObject;
}

void *FITSViewer::qt_metacast(const char *_clname)
{
    if (!_clname) return nullptr;
    if (!strcmp(_clname, qt_staticMetaObjectStaticContent<qt_meta_tag_ZN10FITSViewerE_t>.strings))
        return static_cast<void*>(this);
    return KXmlGuiWindow::qt_metacast(_clname);
}

int FITSViewer::qt_metacall(QMetaObject::Call _c, int _id, void **_a)
{
    _id = KXmlGuiWindow::qt_metacall(_c, _id, _a);
    if (_id < 0)
        return _id;
    if (_c == QMetaObject::InvokeMetaMethod) {
        if (_id < 55)
            qt_static_metacall(this, _c, _id, _a);
        _id -= 55;
    }
    if (_c == QMetaObject::RegisterMethodArgumentMetaType) {
        if (_id < 55)
            *reinterpret_cast<QMetaType *>(_a[0]) = QMetaType();
        _id -= 55;
    }
    return _id;
}

// SIGNAL 0
void FITSViewer::trackingStarSelected(int _t1, int _t2)
{
    QMetaObject::activate<void>(this, &staticMetaObject, 0, nullptr, _t1, _t2);
}

// SIGNAL 1
void FITSViewer::loaded(int _t1)
{
    QMetaObject::activate<void>(this, &staticMetaObject, 1, nullptr, _t1);
}

// SIGNAL 2
void FITSViewer::closed(int _t1)
{
    QMetaObject::activate<void>(this, &staticMetaObject, 2, nullptr, _t1);
}

// SIGNAL 3
void FITSViewer::failed(const QString & _t1)
{
    QMetaObject::activate<void>(this, &staticMetaObject, 3, nullptr, _t1);
}

// SIGNAL 4
void FITSViewer::terminated()
{
    QMetaObject::activate(this, &staticMetaObject, 4, nullptr);
}
QT_WARNING_POP
