/********************************************************************************
** Form generated from reading UI file 'altvstime.ui'
**
** Created by: Qt User Interface Compiler version 6.11.1
**
** WARNING! All changes made in this file will be lost when recompiling UI file!
********************************************************************************/

#ifndef UI_ALTVSTIME_H
#define UI_ALTVSTIME_H

#include <QtCore/QDate>
#include <QtCore/QVariant>
#include <QtWidgets/QApplication>
#include <QtWidgets/QDateTimeEdit>
#include <QtWidgets/QGridLayout>
#include <QtWidgets/QHBoxLayout>
#include <QtWidgets/QLabel>
#include <QtWidgets/QLineEdit>
#include <QtWidgets/QListWidget>
#include <QtWidgets/QPushButton>
#include <QtWidgets/QSpacerItem>
#include <QtWidgets/QTabWidget>
#include <QtWidgets/QVBoxLayout>
#include <QtWidgets/QWidget>
#include <klocalizedstring.h>
#include "kdatepicker.h"
#include "qcustomplot.h"
#include "widgets/dmsbox.h"

QT_BEGIN_NAMESPACE

class Ui_AltVsTime
{
public:
    QVBoxLayout *vboxLayout;
    QCustomPlot *View;
    QTabWidget *tabWidget2;
    QWidget *tab1;
    QVBoxLayout *vboxLayout1;
    QGridLayout *gridLayout;
    QLabel *textLabel1;
    QLineEdit *nameBox;
    QPushButton *browseButton;
    QLabel *textLabel2;
    dmsBox *raBox;
    dmsBox *decBox;
    QPushButton *addButton;
    QPushButton *clearFieldsButton;
    QLabel *textLabel4;
    QLineEdit *epochName;
    QPushButton *clearButton;
    QLabel *textLabel3;
    QSpacerItem *spacerItem;
    QListWidget *PlotList;
    QHBoxLayout *horizontalLayout;
    QLabel *timeLabel;
    QDateTimeEdit *timeSpin;
    QPushButton *computeButton;
    QSpacerItem *horizontalSpacer_2;
    QLabel *altitudeLabel;
    QLineEdit *altitudeBox;
    QSpacerItem *horizontalSpacer_3;
    QPushButton *riseButton;
    QPushButton *setButton;
    QPushButton *transitButton;
    QWidget *tab2;
    QVBoxLayout *vboxLayout2;
    QHBoxLayout *hboxLayout;
    QLabel *textLabel5;
    KDatePicker *DateWidget;
    QSpacerItem *spacerItem1;
    QHBoxLayout *hboxLayout1;
    QPushButton *cityButton;
    QLabel *textLabel7;
    dmsBox *longBox;
    QLabel *textLabel6;
    dmsBox *latBox;
    QSpacerItem *spacerItem2;
    QHBoxLayout *hboxLayout2;
    QSpacerItem *spacerItem3;
    QPushButton *updateButton;

    void setupUi(QWidget *AltVsTime)
    {
        if (AltVsTime->objectName().isEmpty())
            AltVsTime->setObjectName("AltVsTime");
        AltVsTime->resize(678, 599);
        vboxLayout = new QVBoxLayout(AltVsTime);
        vboxLayout->setObjectName("vboxLayout");
        View = new QCustomPlot(AltVsTime);
        View->setObjectName("View");
        QSizePolicy sizePolicy(QSizePolicy::Policy::Preferred, QSizePolicy::Policy::Expanding);
        sizePolicy.setHorizontalStretch(0);
        sizePolicy.setVerticalStretch(0);
        sizePolicy.setHeightForWidth(View->sizePolicy().hasHeightForWidth());
        View->setSizePolicy(sizePolicy);
        View->setMinimumSize(QSize(400, 325));

        vboxLayout->addWidget(View);

        tabWidget2 = new QTabWidget(AltVsTime);
        tabWidget2->setObjectName("tabWidget2");
        QSizePolicy sizePolicy1(QSizePolicy::Policy::Expanding, QSizePolicy::Policy::Minimum);
        sizePolicy1.setHorizontalStretch(0);
        sizePolicy1.setVerticalStretch(0);
        sizePolicy1.setHeightForWidth(tabWidget2->sizePolicy().hasHeightForWidth());
        tabWidget2->setSizePolicy(sizePolicy1);
        tab1 = new QWidget();
        tab1->setObjectName("tab1");
        vboxLayout1 = new QVBoxLayout(tab1);
        vboxLayout1->setObjectName("vboxLayout1");
        gridLayout = new QGridLayout();
        gridLayout->setObjectName("gridLayout");
        textLabel1 = new QLabel(tab1);
        textLabel1->setObjectName("textLabel1");

        gridLayout->addWidget(textLabel1, 0, 0, 1, 1);

        nameBox = new QLineEdit(tab1);
        nameBox->setObjectName("nameBox");
        nameBox->setProperty("trapEnterKeyEvent", QVariant(true));

        gridLayout->addWidget(nameBox, 0, 1, 1, 2);

        browseButton = new QPushButton(tab1);
        browseButton->setObjectName("browseButton");
        QSizePolicy sizePolicy2(QSizePolicy::Policy::Preferred, QSizePolicy::Policy::Minimum);
        sizePolicy2.setHorizontalStretch(0);
        sizePolicy2.setVerticalStretch(0);
        sizePolicy2.setHeightForWidth(browseButton->sizePolicy().hasHeightForWidth());
        browseButton->setSizePolicy(sizePolicy2);

        gridLayout->addWidget(browseButton, 0, 3, 1, 1);

        textLabel2 = new QLabel(tab1);
        textLabel2->setObjectName("textLabel2");
        QSizePolicy sizePolicy3(QSizePolicy::Policy::Preferred, QSizePolicy::Policy::Preferred);
        sizePolicy3.setHorizontalStretch(0);
        sizePolicy3.setVerticalStretch(0);
        sizePolicy3.setHeightForWidth(textLabel2->sizePolicy().hasHeightForWidth());
        textLabel2->setSizePolicy(sizePolicy3);
        textLabel2->setAlignment(Qt::AlignVCenter);

        gridLayout->addWidget(textLabel2, 1, 0, 1, 1);

        raBox = new dmsBox(tab1);
        raBox->setObjectName("raBox");
        raBox->setEnabled(true);
        QSizePolicy sizePolicy4(QSizePolicy::Policy::Expanding, QSizePolicy::Policy::Fixed);
        sizePolicy4.setHorizontalStretch(0);
        sizePolicy4.setVerticalStretch(0);
        sizePolicy4.setHeightForWidth(raBox->sizePolicy().hasHeightForWidth());
        raBox->setSizePolicy(sizePolicy4);

        gridLayout->addWidget(raBox, 1, 1, 1, 2);

        decBox = new dmsBox(tab1);
        decBox->setObjectName("decBox");

        gridLayout->addWidget(decBox, 2, 1, 1, 2);

        addButton = new QPushButton(tab1);
        addButton->setObjectName("addButton");
        sizePolicy2.setHeightForWidth(addButton->sizePolicy().hasHeightForWidth());
        addButton->setSizePolicy(sizePolicy2);

        gridLayout->addWidget(addButton, 1, 3, 1, 1);

        clearFieldsButton = new QPushButton(tab1);
        clearFieldsButton->setObjectName("clearFieldsButton");
        sizePolicy2.setHeightForWidth(clearFieldsButton->sizePolicy().hasHeightForWidth());
        clearFieldsButton->setSizePolicy(sizePolicy2);
        clearFieldsButton->setMinimumSize(QSize(100, 0));

        gridLayout->addWidget(clearFieldsButton, 2, 3, 1, 1);

        textLabel4 = new QLabel(tab1);
        textLabel4->setObjectName("textLabel4");
        QSizePolicy sizePolicy5(QSizePolicy::Policy::Fixed, QSizePolicy::Policy::Preferred);
        sizePolicy5.setHorizontalStretch(0);
        sizePolicy5.setVerticalStretch(0);
        sizePolicy5.setHeightForWidth(textLabel4->sizePolicy().hasHeightForWidth());
        textLabel4->setSizePolicy(sizePolicy5);

        gridLayout->addWidget(textLabel4, 2, 0, 1, 1);

        epochName = new QLineEdit(tab1);
        epochName->setObjectName("epochName");
        epochName->setMinimumSize(QSize(80, 0));
        epochName->setMaximumSize(QSize(80, 26));

        gridLayout->addWidget(epochName, 3, 1, 1, 1);

        clearButton = new QPushButton(tab1);
        clearButton->setObjectName("clearButton");
        sizePolicy2.setHeightForWidth(clearButton->sizePolicy().hasHeightForWidth());
        clearButton->setSizePolicy(sizePolicy2);

        gridLayout->addWidget(clearButton, 3, 3, 1, 1);

        textLabel3 = new QLabel(tab1);
        textLabel3->setObjectName("textLabel3");

        gridLayout->addWidget(textLabel3, 3, 0, 1, 1);

        spacerItem = new QSpacerItem(40, 20, QSizePolicy::Policy::Expanding, QSizePolicy::Policy::Minimum);

        gridLayout->addItem(spacerItem, 3, 2, 1, 1);

        PlotList = new QListWidget(tab1);
        PlotList->setObjectName("PlotList");
        QSizePolicy sizePolicy6(QSizePolicy::Policy::Expanding, QSizePolicy::Policy::Preferred);
        sizePolicy6.setHorizontalStretch(0);
        sizePolicy6.setVerticalStretch(0);
        sizePolicy6.setHeightForWidth(PlotList->sizePolicy().hasHeightForWidth());
        PlotList->setSizePolicy(sizePolicy6);

        gridLayout->addWidget(PlotList, 0, 4, 4, 1);


        vboxLayout1->addLayout(gridLayout);

        horizontalLayout = new QHBoxLayout();
        horizontalLayout->setSpacing(6);
        horizontalLayout->setObjectName("horizontalLayout");
        horizontalLayout->setSizeConstraint(QLayout::SetNoConstraint);
        timeLabel = new QLabel(tab1);
        timeLabel->setObjectName("timeLabel");

        horizontalLayout->addWidget(timeLabel);

        timeSpin = new QDateTimeEdit(tab1);
        timeSpin->setObjectName("timeSpin");
        timeSpin->setMinimumDate(QDate(2000, 1, 1));
        timeSpin->setCurrentSection(QDateTimeEdit::HourSection);

        horizontalLayout->addWidget(timeSpin);

        computeButton = new QPushButton(tab1);
        computeButton->setObjectName("computeButton");
        QSizePolicy sizePolicy7(QSizePolicy::Policy::Fixed, QSizePolicy::Policy::Fixed);
        sizePolicy7.setHorizontalStretch(108);
        sizePolicy7.setVerticalStretch(0);
        sizePolicy7.setHeightForWidth(computeButton->sizePolicy().hasHeightForWidth());
        computeButton->setSizePolicy(sizePolicy7);

        horizontalLayout->addWidget(computeButton);

        horizontalSpacer_2 = new QSpacerItem(20, 20, QSizePolicy::Policy::Expanding, QSizePolicy::Policy::Minimum);

        horizontalLayout->addItem(horizontalSpacer_2);

        altitudeLabel = new QLabel(tab1);
        altitudeLabel->setObjectName("altitudeLabel");
        QSizePolicy sizePolicy8(QSizePolicy::Policy::Fixed, QSizePolicy::Policy::Fixed);
        sizePolicy8.setHorizontalStretch(0);
        sizePolicy8.setVerticalStretch(0);
        sizePolicy8.setHeightForWidth(altitudeLabel->sizePolicy().hasHeightForWidth());
        altitudeLabel->setSizePolicy(sizePolicy8);

        horizontalLayout->addWidget(altitudeLabel);

        altitudeBox = new QLineEdit(tab1);
        altitudeBox->setObjectName("altitudeBox");
        QSizePolicy sizePolicy9(QSizePolicy::Policy::MinimumExpanding, QSizePolicy::Policy::Fixed);
        sizePolicy9.setHorizontalStretch(150);
        sizePolicy9.setVerticalStretch(0);
        sizePolicy9.setHeightForWidth(altitudeBox->sizePolicy().hasHeightForWidth());
        altitudeBox->setSizePolicy(sizePolicy9);
        altitudeBox->setMinimumSize(QSize(0, 0));

        horizontalLayout->addWidget(altitudeBox);

        horizontalSpacer_3 = new QSpacerItem(40, 20, QSizePolicy::Policy::Expanding, QSizePolicy::Policy::Minimum);

        horizontalLayout->addItem(horizontalSpacer_3);

        riseButton = new QPushButton(tab1);
        riseButton->setObjectName("riseButton");
        riseButton->setAutoFillBackground(false);

        horizontalLayout->addWidget(riseButton);

        setButton = new QPushButton(tab1);
        setButton->setObjectName("setButton");

        horizontalLayout->addWidget(setButton);

        transitButton = new QPushButton(tab1);
        transitButton->setObjectName("transitButton");

        horizontalLayout->addWidget(transitButton);


        vboxLayout1->addLayout(horizontalLayout);

        tabWidget2->addTab(tab1, QString());
        tab2 = new QWidget();
        tab2->setObjectName("tab2");
        vboxLayout2 = new QVBoxLayout(tab2);
        vboxLayout2->setSpacing(6);
        vboxLayout2->setObjectName("vboxLayout2");
        vboxLayout2->setContentsMargins(8, 8, 8, 8);
        hboxLayout = new QHBoxLayout();
        hboxLayout->setSpacing(6);
        hboxLayout->setObjectName("hboxLayout");
        hboxLayout->setContentsMargins(0, 0, 0, 0);
        textLabel5 = new QLabel(tab2);
        textLabel5->setObjectName("textLabel5");

        hboxLayout->addWidget(textLabel5);

        DateWidget = new KDatePicker(tab2);
        DateWidget->setObjectName("DateWidget");

        hboxLayout->addWidget(DateWidget);

        spacerItem1 = new QSpacerItem(257, 20, QSizePolicy::Policy::Expanding, QSizePolicy::Policy::Minimum);

        hboxLayout->addItem(spacerItem1);


        vboxLayout2->addLayout(hboxLayout);

        hboxLayout1 = new QHBoxLayout();
        hboxLayout1->setSpacing(6);
        hboxLayout1->setObjectName("hboxLayout1");
        hboxLayout1->setContentsMargins(0, 0, 0, 0);
        cityButton = new QPushButton(tab2);
        cityButton->setObjectName("cityButton");

        hboxLayout1->addWidget(cityButton);

        textLabel7 = new QLabel(tab2);
        textLabel7->setObjectName("textLabel7");
        sizePolicy5.setHeightForWidth(textLabel7->sizePolicy().hasHeightForWidth());
        textLabel7->setSizePolicy(sizePolicy5);

        hboxLayout1->addWidget(textLabel7);

        longBox = new dmsBox(tab2);
        longBox->setObjectName("longBox");

        hboxLayout1->addWidget(longBox);

        textLabel6 = new QLabel(tab2);
        textLabel6->setObjectName("textLabel6");
        sizePolicy5.setHeightForWidth(textLabel6->sizePolicy().hasHeightForWidth());
        textLabel6->setSizePolicy(sizePolicy5);

        hboxLayout1->addWidget(textLabel6);

        latBox = new dmsBox(tab2);
        latBox->setObjectName("latBox");

        hboxLayout1->addWidget(latBox);


        vboxLayout2->addLayout(hboxLayout1);

        spacerItem2 = new QSpacerItem(20, 16, QSizePolicy::Policy::Minimum, QSizePolicy::Policy::Expanding);

        vboxLayout2->addItem(spacerItem2);

        hboxLayout2 = new QHBoxLayout();
        hboxLayout2->setSpacing(6);
        hboxLayout2->setObjectName("hboxLayout2");
        hboxLayout2->setContentsMargins(0, 0, 0, 0);
        spacerItem3 = new QSpacerItem(40, 20, QSizePolicy::Policy::Expanding, QSizePolicy::Policy::Minimum);

        hboxLayout2->addItem(spacerItem3);

        updateButton = new QPushButton(tab2);
        updateButton->setObjectName("updateButton");

        hboxLayout2->addWidget(updateButton);


        vboxLayout2->addLayout(hboxLayout2);

        tabWidget2->addTab(tab2, QString());

        vboxLayout->addWidget(tabWidget2, 0, Qt::AlignTop);

        QWidget::setTabOrder(tabWidget2, nameBox);
        QWidget::setTabOrder(nameBox, epochName);
        QWidget::setTabOrder(epochName, addButton);
        QWidget::setTabOrder(addButton, browseButton);
        QWidget::setTabOrder(browseButton, clearFieldsButton);
        QWidget::setTabOrder(clearFieldsButton, clearButton);
        QWidget::setTabOrder(clearButton, cityButton);
        QWidget::setTabOrder(cityButton, updateButton);

        retranslateUi(AltVsTime);

        tabWidget2->setCurrentIndex(0);


        QMetaObject::connectSlotsByName(AltVsTime);
    } // setupUi

    void retranslateUi(QWidget *AltVsTime)
    {
        AltVsTime->setWindowTitle(tr2i18n("Altitude vs. Time", nullptr));
        textLabel1->setText(tr2i18n("Name:", nullptr));
#if QT_CONFIG(tooltip)
        nameBox->setToolTip(tr2i18n("Name of plotted object", nullptr));
#endif // QT_CONFIG(tooltip)
#if QT_CONFIG(whatsthis)
        nameBox->setWhatsThis(tr2i18n("There are two ways to use this field:  \n"
"\n"
"1. Simply type the name of a known object and press the \"Plot\" button (or press Enter).  The object's Altitude vs. Time curve will be added to the plot, and its coordinates will be displayed below.\n"
"\n"
"2. Type a name label for a custom object.  You will also need to specify the RA and Dec coordinates of the object, and then press the \"Plot\" button to add its curve to the plot.", nullptr));
#endif // QT_CONFIG(whatsthis)
        browseButton->setText(tr2i18n("Find Object...", nullptr));
        textLabel2->setText(tr2i18n("RA:", nullptr));
        addButton->setText(tr2i18n("Plot", nullptr));
        clearFieldsButton->setText(tr2i18n("Clear Fields", nullptr));
        textLabel4->setText(tr2i18n("Dec:", nullptr));
        clearButton->setText(tr2i18n("Clear List", nullptr));
        textLabel3->setText(tr2i18n("Equinox:     ", nullptr));
        timeLabel->setText(tr2i18n("Local time:", nullptr));
        timeSpin->setDisplayFormat(tr2i18n("HH:mm", nullptr));
        computeButton->setText(tr2i18n("    Compute    ", nullptr));
        altitudeLabel->setText(tr2i18n("Altitude: ", nullptr));
        altitudeBox->setText(QString());
        riseButton->setText(tr2i18n("Object Rise", nullptr));
        setButton->setText(tr2i18n("Object Set", nullptr));
        transitButton->setText(tr2i18n("Transit", nullptr));
        tabWidget2->setTabText(tabWidget2->indexOf(tab1), tr2i18n("Sources", nullptr));
        textLabel5->setText(tr2i18n("Date:", nullptr));
        cityButton->setText(tr2i18n("Choose City...", nullptr));
        textLabel7->setText(tr2i18n("Long.:", nullptr));
        textLabel6->setText(tr2i18n("Lat.:", nullptr));
        updateButton->setText(tr2i18n("Update", nullptr));
        tabWidget2->setTabText(tabWidget2->indexOf(tab2), tr2i18n("Date && Location", nullptr));
    } // retranslateUi

};

namespace Ui {
    class AltVsTime: public Ui_AltVsTime {};
} // namespace Ui

QT_END_NAMESPACE

#endif // ALTVSTIME_H

