/********************************************************************************
** Form generated from reading UI file 'mounttargetwidget.ui'
**
** Created by: Qt User Interface Compiler version 6.11.1
**
** WARNING! All changes made in this file will be lost when recompiling UI file!
********************************************************************************/

#ifndef UI_MOUNTTARGETWIDGET_H
#define UI_MOUNTTARGETWIDGET_H

#include <QtCore/QVariant>
#include <QtGui/QIcon>
#include <QtWidgets/QApplication>
#include <QtWidgets/QButtonGroup>
#include <QtWidgets/QGridLayout>
#include <QtWidgets/QHBoxLayout>
#include <QtWidgets/QLabel>
#include <QtWidgets/QLineEdit>
#include <QtWidgets/QPushButton>
#include <QtWidgets/QRadioButton>
#include <QtWidgets/QSpacerItem>
#include <QtWidgets/QWidget>
#include <klocalizedstring.h>
#include "widgets/dmsbox.h"

QT_BEGIN_NAMESPACE

class Ui_MountTargetWidget
{
public:
    QGridLayout *gridLayout;
    QLabel *targetRALabel;
    dmsBox *targetRATextObject;
    QPushButton *findButtonObject;
    dmsBox *targetDETextObject;
    QLabel *targetDECLabel;
    QLineEdit *targetTextObject;
    QHBoxLayout *horizontalLayout_7;
    QLabel *label_18;
    QRadioButton *equatorialCheckObject;
    QRadioButton *horizontalCheckObject;
    QRadioButton *haEquatorialCheckObject;
    QSpacerItem *horizontalSpacer_2;
    QGridLayout *gridLayout_2;
    QPushButton *gotoButtonObject;
    QPushButton *syncButtonObject;
    QButtonGroup *coordinateButtonGroup;

    void setupUi(QWidget *MountTargetWidget)
    {
        if (MountTargetWidget->objectName().isEmpty())
            MountTargetWidget->setObjectName("MountTargetWidget");
        MountTargetWidget->resize(304, 140);
        MountTargetWidget->setFocusPolicy(Qt::ClickFocus);
        gridLayout = new QGridLayout(MountTargetWidget);
        gridLayout->setObjectName("gridLayout");
        gridLayout->setContentsMargins(3, 3, 3, 3);
        targetRALabel = new QLabel(MountTargetWidget);
        targetRALabel->setObjectName("targetRALabel");
        QFont font;
        font.setPointSize(12);
        font.setBold(true);
        targetRALabel->setFont(font);

        gridLayout->addWidget(targetRALabel, 3, 0, 1, 1);

        targetRATextObject = new dmsBox(MountTargetWidget);
        targetRATextObject->setObjectName("targetRATextObject");
        targetRATextObject->setMinimumSize(QSize(0, 32));
        targetRATextObject->setMaximumSize(QSize(16777215, 32));

        gridLayout->addWidget(targetRATextObject, 3, 1, 1, 1);

        findButtonObject = new QPushButton(MountTargetWidget);
        findButtonObject->setObjectName("findButtonObject");
        findButtonObject->setMinimumSize(QSize(32, 32));
        findButtonObject->setMaximumSize(QSize(32, 32));
        QIcon icon;
        QString iconThemeName = QString::fromUtf8("search");
        if (QIcon::hasThemeIcon(iconThemeName)) {
            icon = QIcon::fromTheme(iconThemeName);
        } else {
            icon.addFile(QString::fromUtf8("."), QSize(), QIcon::Mode::Normal, QIcon::State::Off);
        }
        findButtonObject->setIcon(icon);
        findButtonObject->setIconSize(QSize(28, 28));

        gridLayout->addWidget(findButtonObject, 2, 4, 1, 1);

        targetDETextObject = new dmsBox(MountTargetWidget);
        targetDETextObject->setObjectName("targetDETextObject");
        targetDETextObject->setMinimumSize(QSize(0, 32));
        targetDETextObject->setMaximumSize(QSize(16777215, 32));

        gridLayout->addWidget(targetDETextObject, 3, 3, 1, 1);

        targetDECLabel = new QLabel(MountTargetWidget);
        targetDECLabel->setObjectName("targetDECLabel");
        targetDECLabel->setFont(font);

        gridLayout->addWidget(targetDECLabel, 3, 2, 1, 1);

        targetTextObject = new QLineEdit(MountTargetWidget);
        targetTextObject->setObjectName("targetTextObject");
        targetTextObject->setMinimumSize(QSize(0, 32));
        targetTextObject->setMaximumSize(QSize(16777215, 32));
        targetTextObject->setReadOnly(true);

        gridLayout->addWidget(targetTextObject, 2, 0, 1, 4);

        horizontalLayout_7 = new QHBoxLayout();
        horizontalLayout_7->setSpacing(3);
        horizontalLayout_7->setObjectName("horizontalLayout_7");
        label_18 = new QLabel(MountTargetWidget);
        label_18->setObjectName("label_18");

        horizontalLayout_7->addWidget(label_18);

        equatorialCheckObject = new QRadioButton(MountTargetWidget);
        coordinateButtonGroup = new QButtonGroup(MountTargetWidget);
        coordinateButtonGroup->setObjectName("coordinateButtonGroup");
        coordinateButtonGroup->addButton(equatorialCheckObject);
        equatorialCheckObject->setObjectName("equatorialCheckObject");
        equatorialCheckObject->setChecked(true);

        horizontalLayout_7->addWidget(equatorialCheckObject);

        horizontalCheckObject = new QRadioButton(MountTargetWidget);
        coordinateButtonGroup->addButton(horizontalCheckObject);
        horizontalCheckObject->setObjectName("horizontalCheckObject");

        horizontalLayout_7->addWidget(horizontalCheckObject);

        haEquatorialCheckObject = new QRadioButton(MountTargetWidget);
        coordinateButtonGroup->addButton(haEquatorialCheckObject);
        haEquatorialCheckObject->setObjectName("haEquatorialCheckObject");

        horizontalLayout_7->addWidget(haEquatorialCheckObject);

        horizontalSpacer_2 = new QSpacerItem(40, 20, QSizePolicy::Policy::Expanding, QSizePolicy::Policy::Minimum);

        horizontalLayout_7->addItem(horizontalSpacer_2);


        gridLayout->addLayout(horizontalLayout_7, 4, 0, 1, 4);

        gridLayout_2 = new QGridLayout();
        gridLayout_2->setSpacing(3);
        gridLayout_2->setObjectName("gridLayout_2");
        gotoButtonObject = new QPushButton(MountTargetWidget);
        gotoButtonObject->setObjectName("gotoButtonObject");

        gridLayout_2->addWidget(gotoButtonObject, 0, 0, 1, 1);

        syncButtonObject = new QPushButton(MountTargetWidget);
        syncButtonObject->setObjectName("syncButtonObject");

        gridLayout_2->addWidget(syncButtonObject, 0, 1, 1, 1);


        gridLayout->addLayout(gridLayout_2, 5, 0, 1, 5);


        retranslateUi(MountTargetWidget);

        QMetaObject::connectSlotsByName(MountTargetWidget);
    } // setupUi

    void retranslateUi(QWidget *MountTargetWidget)
    {
        MountTargetWidget->setWindowTitle(tr2i18n("Mount Control Panel", nullptr));
        targetRALabel->setText(tr2i18n("RA:", nullptr));
        findButtonObject->setText(QString());
        targetDECLabel->setText(tr2i18n("DE:", nullptr));
        label_18->setText(tr2i18n("Type:", nullptr));
        equatorialCheckObject->setText(tr2i18n("RA/DE", nullptr));
        horizontalCheckObject->setText(tr2i18n("Alt/AZ", nullptr));
        haEquatorialCheckObject->setText(tr2i18n("HA/DE", nullptr));
        gotoButtonObject->setText(tr2i18n("GOTO", nullptr));
        syncButtonObject->setText(tr2i18n("SYNC", nullptr));
    } // retranslateUi

};

namespace Ui {
    class MountTargetWidget: public Ui_MountTargetWidget {};
} // namespace Ui

QT_END_NAMESPACE

#endif // MOUNTTARGETWIDGET_H

