/********************************************************************************
** Form generated from reading UI file 'pwizfovconfig.ui'
**
** Created by: Qt User Interface Compiler version 6.11.1
**
** WARNING! All changes made in this file will be lost when recompiling UI file!
********************************************************************************/

#ifndef UI_PWIZFOVCONFIG_H
#define UI_PWIZFOVCONFIG_H

#include <QtCore/QVariant>
#include <QtWidgets/QApplication>
#include <QtWidgets/QCheckBox>
#include <QtWidgets/QComboBox>
#include <QtWidgets/QGridLayout>
#include <QtWidgets/QHBoxLayout>
#include <QtWidgets/QLabel>
#include <QtWidgets/QSpacerItem>
#include <QtWidgets/QVBoxLayout>
#include <QtWidgets/QWidget>
#include <klocalizedstring.h>

QT_BEGIN_NAMESPACE

class Ui_PWizFovConfig
{
public:
    QHBoxLayout *horizontalLayout;
    QLabel *banner;
    QSpacerItem *horSpacer1;
    QVBoxLayout *fovConfigLayout;
    QLabel *stepTitle;
    QSpacerItem *vertSpacer1;
    QLabel *stepText;
    QSpacerItem *vertSpacer4;
    QCheckBox *switchColorsBox;
    QCheckBox *overrideShapeBox;
    QSpacerItem *vertSpacer3;
    QLabel *label1;
    QCheckBox *addLegendBox;
    QCheckBox *useAlphaBlendBox;
    QGridLayout *gridLayout;
    QLabel *label3;
    QComboBox *orientationCombo;
    QLabel *label4;
    QComboBox *positionCombo;
    QLabel *label2;
    QComboBox *typeCombo;
    QSpacerItem *vertSpacer2;

    void setupUi(QWidget *PWizFovConfig)
    {
        if (PWizFovConfig->objectName().isEmpty())
            PWizFovConfig->setObjectName("PWizFovConfig");
        PWizFovConfig->resize(586, 395);
        PWizFovConfig->setMinimumSize(QSize(586, 395));
        horizontalLayout = new QHBoxLayout(PWizFovConfig);
        horizontalLayout->setObjectName("horizontalLayout");
        banner = new QLabel(PWizFovConfig);
        banner->setObjectName("banner");
        QSizePolicy sizePolicy(QSizePolicy::Policy::Fixed, QSizePolicy::Policy::Fixed);
        sizePolicy.setHorizontalStretch(0);
        sizePolicy.setVerticalStretch(0);
        sizePolicy.setHeightForWidth(banner->sizePolicy().hasHeightForWidth());
        banner->setSizePolicy(sizePolicy);
        banner->setMinimumSize(QSize(120, 360));

        horizontalLayout->addWidget(banner);

        horSpacer1 = new QSpacerItem(5, 20, QSizePolicy::Policy::Fixed, QSizePolicy::Policy::Minimum);

        horizontalLayout->addItem(horSpacer1);

        fovConfigLayout = new QVBoxLayout();
#ifndef UI_Q_OS_MAC
        fovConfigLayout->setSpacing(6);
#endif
        fovConfigLayout->setContentsMargins(0, 0, 0, 0);
        fovConfigLayout->setObjectName("fovConfigLayout");
        stepTitle = new QLabel(PWizFovConfig);
        stepTitle->setObjectName("stepTitle");
        QFont font;
        font.setFamilies({QString::fromUtf8("Sans Serif")});
        font.setPointSize(11);
        font.setBold(true);
        font.setItalic(false);
        font.setUnderline(false);
        font.setStrikeOut(false);
        stepTitle->setFont(font);

        fovConfigLayout->addWidget(stepTitle);

        vertSpacer1 = new QSpacerItem(20, 12, QSizePolicy::Policy::Minimum, QSizePolicy::Policy::Fixed);

        fovConfigLayout->addItem(vertSpacer1);

        stepText = new QLabel(PWizFovConfig);
        stepText->setObjectName("stepText");
        stepText->setWordWrap(true);

        fovConfigLayout->addWidget(stepText);

        vertSpacer4 = new QSpacerItem(20, 12, QSizePolicy::Policy::Minimum, QSizePolicy::Policy::Fixed);

        fovConfigLayout->addItem(vertSpacer4);

        switchColorsBox = new QCheckBox(PWizFovConfig);
        switchColorsBox->setObjectName("switchColorsBox");
        switchColorsBox->setChecked(true);

        fovConfigLayout->addWidget(switchColorsBox);

        overrideShapeBox = new QCheckBox(PWizFovConfig);
        overrideShapeBox->setObjectName("overrideShapeBox");

        fovConfigLayout->addWidget(overrideShapeBox);

        vertSpacer3 = new QSpacerItem(20, 12, QSizePolicy::Policy::Minimum, QSizePolicy::Policy::Fixed);

        fovConfigLayout->addItem(vertSpacer3);

        label1 = new QLabel(PWizFovConfig);
        label1->setObjectName("label1");
        QFont font1;
        font1.setBold(true);
        label1->setFont(font1);

        fovConfigLayout->addWidget(label1);

        addLegendBox = new QCheckBox(PWizFovConfig);
        addLegendBox->setObjectName("addLegendBox");

        fovConfigLayout->addWidget(addLegendBox);

        useAlphaBlendBox = new QCheckBox(PWizFovConfig);
        useAlphaBlendBox->setObjectName("useAlphaBlendBox");

        fovConfigLayout->addWidget(useAlphaBlendBox);

        gridLayout = new QGridLayout();
        gridLayout->setObjectName("gridLayout");
        label3 = new QLabel(PWizFovConfig);
        label3->setObjectName("label3");

        gridLayout->addWidget(label3, 1, 0, 1, 1);

        orientationCombo = new QComboBox(PWizFovConfig);
        orientationCombo->setObjectName("orientationCombo");

        gridLayout->addWidget(orientationCombo, 1, 1, 1, 1);

        label4 = new QLabel(PWizFovConfig);
        label4->setObjectName("label4");

        gridLayout->addWidget(label4, 2, 0, 1, 1);

        positionCombo = new QComboBox(PWizFovConfig);
        positionCombo->setObjectName("positionCombo");

        gridLayout->addWidget(positionCombo, 2, 1, 1, 1);

        label2 = new QLabel(PWizFovConfig);
        label2->setObjectName("label2");

        gridLayout->addWidget(label2, 0, 0, 1, 1);

        typeCombo = new QComboBox(PWizFovConfig);
        typeCombo->setObjectName("typeCombo");

        gridLayout->addWidget(typeCombo, 0, 1, 1, 1);


        fovConfigLayout->addLayout(gridLayout);

        vertSpacer2 = new QSpacerItem(20, 40, QSizePolicy::Policy::Minimum, QSizePolicy::Policy::Expanding);

        fovConfigLayout->addItem(vertSpacer2);


        horizontalLayout->addLayout(fovConfigLayout);

        QWidget::setTabOrder(switchColorsBox, overrideShapeBox);
        QWidget::setTabOrder(overrideShapeBox, addLegendBox);
        QWidget::setTabOrder(addLegendBox, useAlphaBlendBox);
        QWidget::setTabOrder(useAlphaBlendBox, typeCombo);
        QWidget::setTabOrder(typeCombo, orientationCombo);
        QWidget::setTabOrder(orientationCombo, positionCombo);

        retranslateUi(PWizFovConfig);

        QMetaObject::connectSlotsByName(PWizFovConfig);
    } // setupUi

    void retranslateUi(QWidget *PWizFovConfig)
    {
        banner->setText(QString());
        stepTitle->setText(tr2i18n("Set Basic Field of View Capture Settings", nullptr));
        stepText->setText(tr2i18n("<p>Set basic field of view capture settings: color scheme, legend and FOV image shape, then click <b>Next</b> to proceed.</p>", nullptr));
        switchColorsBox->setText(tr2i18n("Use \"Sky Chart\" color scheme", nullptr));
        overrideShapeBox->setText(tr2i18n("Override FOV shape to rectangular", nullptr));
        label1->setText(tr2i18n("Scale and magnitudes chart", nullptr));
        addLegendBox->setText(tr2i18n("Add scale and magnitudes chart to exported FOV images", nullptr));
        useAlphaBlendBox->setText(tr2i18n("Use alpha-blended background", nullptr));
        label3->setText(tr2i18n("Chart orientation:", nullptr));
        label4->setText(tr2i18n("Chart position:", nullptr));
        label2->setText(tr2i18n("Chart type:", nullptr));
        (void)PWizFovConfig;
    } // retranslateUi

};

namespace Ui {
    class PWizFovConfig: public Ui_PWizFovConfig {};
} // namespace Ui

QT_END_NAMESPACE

#endif // PWIZFOVCONFIG_H

