/********************************************************************************
** Form generated from reading UI file 'thumbnaileditor.ui'
**
** Created by: Qt User Interface Compiler version 6.11.1
**
** WARNING! All changes made in this file will be lost when recompiling UI file!
********************************************************************************/

#ifndef UI_THUMBNAILEDITOR_H
#define UI_THUMBNAILEDITOR_H

#include <QtCore/QVariant>
#include <QtWidgets/QApplication>
#include <QtWidgets/QLabel>
#include <QtWidgets/QVBoxLayout>
#include <QtWidgets/QWidget>
#include <klocalizedstring.h>
#include "widgets/thumbimage.h"

QT_BEGIN_NAMESPACE

class Ui_ThumbnailEditor
{
public:
    QVBoxLayout *vboxLayout;
    ThumbImage *ImageCanvas;
    QLabel *CropLabel;
    QLabel *MessageLabel;

    void setupUi(QWidget *ThumbnailEditor)
    {
        if (ThumbnailEditor->objectName().isEmpty())
            ThumbnailEditor->setObjectName("ThumbnailEditor");
        ThumbnailEditor->resize(383, 396);
        vboxLayout = new QVBoxLayout(ThumbnailEditor);
#ifndef UI_Q_OS_MAC
        vboxLayout->setSpacing(6);
#endif
        vboxLayout->setContentsMargins(4, 4, 4, 4);
        vboxLayout->setObjectName("vboxLayout");
        ImageCanvas = new ThumbImage(ThumbnailEditor);
        ImageCanvas->setObjectName("ImageCanvas");
        QSizePolicy sizePolicy(QSizePolicy::Policy::Preferred, QSizePolicy::Policy::Expanding);
        sizePolicy.setHorizontalStretch(0);
        sizePolicy.setVerticalStretch(0);
        sizePolicy.setHeightForWidth(ImageCanvas->sizePolicy().hasHeightForWidth());
        ImageCanvas->setSizePolicy(sizePolicy);

        vboxLayout->addWidget(ImageCanvas);

        CropLabel = new QLabel(ThumbnailEditor);
        CropLabel->setObjectName("CropLabel");
        CropLabel->setFrameShape(QFrame::StyledPanel);
        CropLabel->setFrameShadow(QFrame::Sunken);
        CropLabel->setAlignment(Qt::AlignCenter);

        vboxLayout->addWidget(CropLabel);

        MessageLabel = new QLabel(ThumbnailEditor);
        MessageLabel->setObjectName("MessageLabel");
        MessageLabel->setFrameShape(QFrame::StyledPanel);
        MessageLabel->setFrameShadow(QFrame::Sunken);
        MessageLabel->setAlignment(Qt::AlignCenter);

        vboxLayout->addWidget(MessageLabel);


        retranslateUi(ThumbnailEditor);

        QMetaObject::connectSlotsByName(ThumbnailEditor);
    } // setupUi

    void retranslateUi(QWidget *ThumbnailEditor)
    {
        ThumbnailEditor->setWindowTitle(tr2i18n("Thumbnail Editor", nullptr));
        CropLabel->setText(tr2i18n("Crop region: [0,0  200 x 200]", nullptr));
        MessageLabel->setText(tr2i18n("(crop region will be scaled to 200x200)", nullptr));
    } // retranslateUi

};

namespace Ui {
    class ThumbnailEditor: public Ui_ThumbnailEditor {};
} // namespace Ui

QT_END_NAMESPACE

#endif // THUMBNAILEDITOR_H

