/********************************************************************************
** Form generated from reading UI file 'opticaltrains.ui'
**
** Created by: Qt User Interface Compiler version 6.11.1
**
** WARNING! All changes made in this file will be lost when recompiling UI file!
********************************************************************************/

#ifndef UI_OPTICALTRAINS_H
#define UI_OPTICALTRAINS_H

#include <QtCore/QVariant>
#include <QtGui/QIcon>
#include <QtWidgets/QAbstractButton>
#include <QtWidgets/QApplication>
#include <QtWidgets/QComboBox>
#include <QtWidgets/QDialog>
#include <QtWidgets/QDialogButtonBox>
#include <QtWidgets/QDoubleSpinBox>
#include <QtWidgets/QFrame>
#include <QtWidgets/QGridLayout>
#include <QtWidgets/QGroupBox>
#include <QtWidgets/QHBoxLayout>
#include <QtWidgets/QLabel>
#include <QtWidgets/QListWidget>
#include <QtWidgets/QPushButton>
#include <QtWidgets/QSpacerItem>
#include <QtWidgets/QSplitter>
#include <QtWidgets/QVBoxLayout>
#include <klocalizedstring.h>

QT_BEGIN_NAMESPACE

class Ui_OpticalTrain
{
public:
    QVBoxLayout *verticalLayout;
    QHBoxLayout *horizontalLayout;
    QPushButton *addB;
    QPushButton *removeB;
    QSpacerItem *horizontalSpacer;
    QSplitter *splitter;
    QListWidget *trainNamesList;
    QGroupBox *trainConfigBox;
    QGridLayout *gridLayout;
    QLabel *scopeLabel;
    QLabel *mountLabel;
    QComboBox *filterComboBox;
    QLabel *cameraLabel;
    QComboBox *guiderComboBox;
    QLabel *dustCapLlabel;
    QComboBox *dustCapComboBox;
    QLabel *reducerLabel;
    QComboBox *focusComboBox;
    QComboBox *scopeComboBox;
    QLabel *lightBoxLabel;
    QLabel *filterLabel;
    QComboBox *rotatorComboBox;
    QLabel *guiderLabel;
    QComboBox *mountComboBox;
    QLabel *focusLabel;
    QDoubleSpinBox *reducerSpinBox;
    QLabel *rotatorLabel;
    QComboBox *lightBoxComboBox;
    QComboBox *cameraComboBox;
    QFrame *line;
    QHBoxLayout *horizontalLayout_3;
    QPushButton *opticalElementsB;
    QPushButton *resetB;
    QSpacerItem *horizontalSpacer_2;
    QDialogButtonBox *buttonBox;

    void setupUi(QDialog *OpticalTrain)
    {
        if (OpticalTrain->objectName().isEmpty())
            OpticalTrain->setObjectName("OpticalTrain");
        OpticalTrain->resize(677, 259);
        verticalLayout = new QVBoxLayout(OpticalTrain);
        verticalLayout->setSpacing(3);
        verticalLayout->setObjectName("verticalLayout");
        verticalLayout->setContentsMargins(3, 3, 3, 3);
        horizontalLayout = new QHBoxLayout();
        horizontalLayout->setSpacing(3);
        horizontalLayout->setObjectName("horizontalLayout");
        addB = new QPushButton(OpticalTrain);
        addB->setObjectName("addB");
        addB->setMaximumSize(QSize(32, 32));
        QIcon icon(QIcon::fromTheme(QString::fromUtf8("list-add")));
        addB->setIcon(icon);

        horizontalLayout->addWidget(addB);

        removeB = new QPushButton(OpticalTrain);
        removeB->setObjectName("removeB");
        removeB->setEnabled(false);
        removeB->setMaximumSize(QSize(32, 32));
        QIcon icon1(QIcon::fromTheme(QString::fromUtf8("list-remove")));
        removeB->setIcon(icon1);

        horizontalLayout->addWidget(removeB);

        horizontalSpacer = new QSpacerItem(40, 20, QSizePolicy::Policy::Expanding, QSizePolicy::Policy::Minimum);

        horizontalLayout->addItem(horizontalSpacer);


        verticalLayout->addLayout(horizontalLayout);

        splitter = new QSplitter(OpticalTrain);
        splitter->setObjectName("splitter");
        QSizePolicy sizePolicy(QSizePolicy::Policy::Expanding, QSizePolicy::Policy::Preferred);
        sizePolicy.setHorizontalStretch(0);
        sizePolicy.setVerticalStretch(0);
        sizePolicy.setHeightForWidth(splitter->sizePolicy().hasHeightForWidth());
        splitter->setSizePolicy(sizePolicy);
        splitter->setOrientation(Qt::Horizontal);
        trainNamesList = new QListWidget(splitter);
        trainNamesList->setObjectName("trainNamesList");
        trainNamesList->setMinimumSize(QSize(120, 0));
        trainNamesList->setSizeAdjustPolicy(QAbstractScrollArea::AdjustToContentsOnFirstShow);
        splitter->addWidget(trainNamesList);
        trainConfigBox = new QGroupBox(splitter);
        trainConfigBox->setObjectName("trainConfigBox");
        QSizePolicy sizePolicy1(QSizePolicy::Policy::Preferred, QSizePolicy::Policy::Preferred);
        sizePolicy1.setHorizontalStretch(0);
        sizePolicy1.setVerticalStretch(0);
        sizePolicy1.setHeightForWidth(trainConfigBox->sizePolicy().hasHeightForWidth());
        trainConfigBox->setSizePolicy(sizePolicy1);
        gridLayout = new QGridLayout(trainConfigBox);
        gridLayout->setSpacing(3);
        gridLayout->setObjectName("gridLayout");
        gridLayout->setContentsMargins(3, 3, 3, 3);
        scopeLabel = new QLabel(trainConfigBox);
        scopeLabel->setObjectName("scopeLabel");
        scopeLabel->setAlignment(Qt::AlignLeading|Qt::AlignLeft|Qt::AlignVCenter);

        gridLayout->addWidget(scopeLabel, 0, 3, 1, 1);

        mountLabel = new QLabel(trainConfigBox);
        mountLabel->setObjectName("mountLabel");
        mountLabel->setAlignment(Qt::AlignLeading|Qt::AlignLeft|Qt::AlignVCenter);

        gridLayout->addWidget(mountLabel, 0, 0, 1, 1);

        filterComboBox = new QComboBox(trainConfigBox);
        filterComboBox->setObjectName("filterComboBox");
        QSizePolicy sizePolicy2(QSizePolicy::Policy::MinimumExpanding, QSizePolicy::Policy::Fixed);
        sizePolicy2.setHorizontalStretch(0);
        sizePolicy2.setVerticalStretch(0);
        sizePolicy2.setHeightForWidth(filterComboBox->sizePolicy().hasHeightForWidth());
        filterComboBox->setSizePolicy(sizePolicy2);

        gridLayout->addWidget(filterComboBox, 1, 4, 1, 1);

        cameraLabel = new QLabel(trainConfigBox);
        cameraLabel->setObjectName("cameraLabel");
        cameraLabel->setAlignment(Qt::AlignLeading|Qt::AlignLeft|Qt::AlignVCenter);

        gridLayout->addWidget(cameraLabel, 1, 0, 1, 1);

        guiderComboBox = new QComboBox(trainConfigBox);
        guiderComboBox->setObjectName("guiderComboBox");
        sizePolicy2.setHeightForWidth(guiderComboBox->sizePolicy().hasHeightForWidth());
        guiderComboBox->setSizePolicy(sizePolicy2);

        gridLayout->addWidget(guiderComboBox, 3, 1, 1, 1);

        dustCapLlabel = new QLabel(trainConfigBox);
        dustCapLlabel->setObjectName("dustCapLlabel");
        dustCapLlabel->setAlignment(Qt::AlignLeading|Qt::AlignLeft|Qt::AlignVCenter);

        gridLayout->addWidget(dustCapLlabel, 4, 0, 1, 1);

        dustCapComboBox = new QComboBox(trainConfigBox);
        dustCapComboBox->setObjectName("dustCapComboBox");
        sizePolicy2.setHeightForWidth(dustCapComboBox->sizePolicy().hasHeightForWidth());
        dustCapComboBox->setSizePolicy(sizePolicy2);

        gridLayout->addWidget(dustCapComboBox, 4, 1, 1, 1);

        reducerLabel = new QLabel(trainConfigBox);
        reducerLabel->setObjectName("reducerLabel");
        reducerLabel->setAlignment(Qt::AlignLeading|Qt::AlignLeft|Qt::AlignVCenter);

        gridLayout->addWidget(reducerLabel, 3, 3, 1, 1);

        focusComboBox = new QComboBox(trainConfigBox);
        focusComboBox->setObjectName("focusComboBox");
        sizePolicy2.setHeightForWidth(focusComboBox->sizePolicy().hasHeightForWidth());
        focusComboBox->setSizePolicy(sizePolicy2);

        gridLayout->addWidget(focusComboBox, 2, 4, 1, 1);

        scopeComboBox = new QComboBox(trainConfigBox);
        scopeComboBox->setObjectName("scopeComboBox");
        sizePolicy2.setHeightForWidth(scopeComboBox->sizePolicy().hasHeightForWidth());
        scopeComboBox->setSizePolicy(sizePolicy2);

        gridLayout->addWidget(scopeComboBox, 0, 4, 1, 1);

        lightBoxLabel = new QLabel(trainConfigBox);
        lightBoxLabel->setObjectName("lightBoxLabel");
        lightBoxLabel->setAlignment(Qt::AlignLeading|Qt::AlignLeft|Qt::AlignVCenter);

        gridLayout->addWidget(lightBoxLabel, 4, 3, 1, 1);

        filterLabel = new QLabel(trainConfigBox);
        filterLabel->setObjectName("filterLabel");
        filterLabel->setAlignment(Qt::AlignLeading|Qt::AlignLeft|Qt::AlignVCenter);

        gridLayout->addWidget(filterLabel, 1, 3, 1, 1);

        rotatorComboBox = new QComboBox(trainConfigBox);
        rotatorComboBox->setObjectName("rotatorComboBox");
        sizePolicy2.setHeightForWidth(rotatorComboBox->sizePolicy().hasHeightForWidth());
        rotatorComboBox->setSizePolicy(sizePolicy2);

        gridLayout->addWidget(rotatorComboBox, 2, 1, 1, 1);

        guiderLabel = new QLabel(trainConfigBox);
        guiderLabel->setObjectName("guiderLabel");
        guiderLabel->setAlignment(Qt::AlignLeading|Qt::AlignLeft|Qt::AlignVCenter);

        gridLayout->addWidget(guiderLabel, 3, 0, 1, 1);

        mountComboBox = new QComboBox(trainConfigBox);
        mountComboBox->setObjectName("mountComboBox");
        sizePolicy2.setHeightForWidth(mountComboBox->sizePolicy().hasHeightForWidth());
        mountComboBox->setSizePolicy(sizePolicy2);

        gridLayout->addWidget(mountComboBox, 0, 1, 1, 1);

        focusLabel = new QLabel(trainConfigBox);
        focusLabel->setObjectName("focusLabel");
        focusLabel->setAlignment(Qt::AlignLeading|Qt::AlignLeft|Qt::AlignVCenter);

        gridLayout->addWidget(focusLabel, 2, 3, 1, 1);

        reducerSpinBox = new QDoubleSpinBox(trainConfigBox);
        reducerSpinBox->setObjectName("reducerSpinBox");
        reducerSpinBox->setAlignment(Qt::AlignRight|Qt::AlignTrailing|Qt::AlignVCenter);
        reducerSpinBox->setMinimum(0.100000000000000);
        reducerSpinBox->setMaximum(5.000000000000000);
        reducerSpinBox->setSingleStep(0.100000000000000);
        reducerSpinBox->setValue(1.000000000000000);

        gridLayout->addWidget(reducerSpinBox, 3, 4, 1, 1);

        rotatorLabel = new QLabel(trainConfigBox);
        rotatorLabel->setObjectName("rotatorLabel");
        rotatorLabel->setAlignment(Qt::AlignLeading|Qt::AlignLeft|Qt::AlignVCenter);

        gridLayout->addWidget(rotatorLabel, 2, 0, 1, 1);

        lightBoxComboBox = new QComboBox(trainConfigBox);
        lightBoxComboBox->setObjectName("lightBoxComboBox");
        sizePolicy2.setHeightForWidth(lightBoxComboBox->sizePolicy().hasHeightForWidth());
        lightBoxComboBox->setSizePolicy(sizePolicy2);

        gridLayout->addWidget(lightBoxComboBox, 4, 4, 1, 1);

        cameraComboBox = new QComboBox(trainConfigBox);
        cameraComboBox->setObjectName("cameraComboBox");
        sizePolicy2.setHeightForWidth(cameraComboBox->sizePolicy().hasHeightForWidth());
        cameraComboBox->setSizePolicy(sizePolicy2);

        gridLayout->addWidget(cameraComboBox, 1, 1, 1, 1);

        line = new QFrame(trainConfigBox);
        line->setObjectName("line");
        line->setMinimumSize(QSize(20, 0));
        line->setFrameShape(QFrame::Shape::VLine);
        line->setFrameShadow(QFrame::Shadow::Sunken);

        gridLayout->addWidget(line, 0, 2, 5, 1);

        gridLayout->setColumnStretch(1, 3);
        gridLayout->setColumnStretch(4, 3);
        splitter->addWidget(trainConfigBox);

        verticalLayout->addWidget(splitter);

        horizontalLayout_3 = new QHBoxLayout();
        horizontalLayout_3->setSpacing(3);
        horizontalLayout_3->setObjectName("horizontalLayout_3");
        opticalElementsB = new QPushButton(OpticalTrain);
        opticalElementsB->setObjectName("opticalElementsB");

        horizontalLayout_3->addWidget(opticalElementsB);

        resetB = new QPushButton(OpticalTrain);
        resetB->setObjectName("resetB");
        resetB->setMinimumSize(QSize(28, 28));
        resetB->setMaximumSize(QSize(28, 28));
        QIcon icon2(QIcon::fromTheme(QString::fromUtf8("system-reboot")));
        resetB->setIcon(icon2);
        resetB->setIconSize(QSize(24, 24));

        horizontalLayout_3->addWidget(resetB);

        horizontalSpacer_2 = new QSpacerItem(40, 20, QSizePolicy::Policy::Expanding, QSizePolicy::Policy::Minimum);

        horizontalLayout_3->addItem(horizontalSpacer_2);

        buttonBox = new QDialogButtonBox(OpticalTrain);
        buttonBox->setObjectName("buttonBox");
        buttonBox->setOrientation(Qt::Horizontal);
        buttonBox->setStandardButtons(QDialogButtonBox::Close);

        horizontalLayout_3->addWidget(buttonBox);


        verticalLayout->addLayout(horizontalLayout_3);


        retranslateUi(OpticalTrain);
        QObject::connect(buttonBox, &QDialogButtonBox::accepted, OpticalTrain, qOverload<>(&QDialog::accept));
        QObject::connect(buttonBox, &QDialogButtonBox::rejected, OpticalTrain, qOverload<>(&QDialog::reject));

        QMetaObject::connectSlotsByName(OpticalTrain);
    } // setupUi

    void retranslateUi(QDialog *OpticalTrain)
    {
        OpticalTrain->setWindowTitle(tr2i18n("Optical Trains", nullptr));
#if QT_CONFIG(tooltip)
        addB->setToolTip(tr2i18n("<html><head/><body><p>Create a new optical train.</p></body></html>", nullptr));
#endif // QT_CONFIG(tooltip)
        addB->setText(QString());
#if QT_CONFIG(tooltip)
        removeB->setToolTip(tr2i18n("<html><head/><body><p>Delete selected optical train.</p></body></html>", nullptr));
#endif // QT_CONFIG(tooltip)
        removeB->setText(QString());
#if QT_CONFIG(tooltip)
        trainNamesList->setToolTip(tr2i18n("Optical train name (double click to change the name)", nullptr));
#endif // QT_CONFIG(tooltip)
        trainConfigBox->setTitle(tr2i18n("Optical Train", nullptr));
#if QT_CONFIG(tooltip)
        scopeLabel->setToolTip(tr2i18n("<html><head/><body><p>Select the scope or lens used in the optical train. This is a required selection in all trains.</p><p>To add, edit, or delete optical elements, tap the <span style=\" font-weight:600;\">Telescope &amp; Lens</span> button.</p></body></html>", nullptr));
#endif // QT_CONFIG(tooltip)
        scopeLabel->setText(tr2i18n("<html><head/><body><p>Scope/Lens: <span style=\" color:#ff0000;\">*</span></p></body></html>", nullptr));
#if QT_CONFIG(tooltip)
        mountLabel->setToolTip(tr2i18n("Select which mount to use. Typically, all optical trains in the same profile use the same mount.", nullptr));
#endif // QT_CONFIG(tooltip)
        mountLabel->setText(tr2i18n("Mount:", nullptr));
#if QT_CONFIG(tooltip)
        cameraLabel->setToolTip(tr2i18n("<html><head/><body><p>Select the imaging camera for this optical train.  This is a required selection in all trains.</p></body></html>", nullptr));
#endif // QT_CONFIG(tooltip)
        cameraLabel->setText(tr2i18n("<html><head/><body><p>Camera: <span style=\" color:#ff0000;\">*</span></p></body></html>", nullptr));
#if QT_CONFIG(tooltip)
        dustCapLlabel->setToolTip(tr2i18n("Select a mechanized dust cap if any (e.g. FlipFlat).", nullptr));
#endif // QT_CONFIG(tooltip)
        dustCapLlabel->setText(tr2i18n("Dust cap:", nullptr));
#if QT_CONFIG(tooltip)
        reducerLabel->setToolTip(tr2i18n("<html><head/><body><p>Select if any reducer or barlow is used in the train.</p><p><span style=\" font-weight:600;\">Reducer:</span> If the value is less than 1.0x, this element is considered as a reducer (focal length is decreased by this factor).</p><p><span style=\" font-weight:600;\">Barlow</span>: If the value is over 1.0x, then it is considered a barlow element (focal length is increased by this factor).</p></body></html>", nullptr));
#endif // QT_CONFIG(tooltip)
        reducerLabel->setText(tr2i18n("Reducer/Barlow:", nullptr));
#if QT_CONFIG(tooltip)
        lightBoxLabel->setToolTip(tr2i18n("Select a flat field lightbox if any (e.g. FlipFlat).", nullptr));
#endif // QT_CONFIG(tooltip)
        lightBoxLabel->setText(tr2i18n("Light box:", nullptr));
#if QT_CONFIG(tooltip)
        filterLabel->setToolTip(tr2i18n("<html><head/><body><p>Select a filter wheel.</p><p>This could be a dedicated filter wheel or part of a camera driver.</p></body></html>", nullptr));
#endif // QT_CONFIG(tooltip)
        filterLabel->setText(tr2i18n("Filter wheel:", nullptr));
#if QT_CONFIG(tooltip)
        guiderLabel->setToolTip(tr2i18n("<html><head/><body><p>Select the device that receives the guiding correction pulses. This can be one of the following devices:</p><p><span style=\" font-weight:600;\">Mount</span>: If the Mount can receive guiding correction pulses, then it is best to select it so that the pulses are directly sent to the mount. This is the recommended option.</p><p><span style=\" font-weight:600;\">ST4</span>: If using an ST4 cable between the guide camera and mount, then you should select the Guide Camera as the Guider.</p><p><span style=\" font-weight:600;\">Dedicated Guider</span>: If using a dedicated guider interface device (like Shoestring GPUSB) then select it as the Guider.</p></body></html>", nullptr));
#endif // QT_CONFIG(tooltip)
        guiderLabel->setText(tr2i18n("Guide via:", nullptr));
#if QT_CONFIG(tooltip)
        focusLabel->setToolTip(tr2i18n("Select a mechanized focuser if any.", nullptr));
#endif // QT_CONFIG(tooltip)
        focusLabel->setText(tr2i18n("Focuser:", nullptr));
        reducerSpinBox->setSuffix(tr2i18n("x", nullptr));
#if QT_CONFIG(tooltip)
        rotatorLabel->setToolTip(tr2i18n("Select a mechanized rotator if any.", nullptr));
#endif // QT_CONFIG(tooltip)
        rotatorLabel->setText(tr2i18n("Rotator:", nullptr));
        opticalElementsB->setText(tr2i18n("Telescopes && Lenses", nullptr));
#if QT_CONFIG(tooltip)
        resetB->setToolTip(tr2i18n("Reset train", nullptr));
#endif // QT_CONFIG(tooltip)
        resetB->setText(QString());
    } // retranslateUi

};

namespace Ui {
    class OpticalTrain: public Ui_OpticalTrain {};
} // namespace Ui

QT_END_NAMESPACE

#endif // OPTICALTRAINS_H

