/********************************************************************************
** Form generated from reading UI file 'fovdialog.ui'
**
** Created by: Qt User Interface Compiler version 6.11.1
**
** WARNING! All changes made in this file will be lost when recompiling UI file!
********************************************************************************/

#ifndef UI_FOVDIALOG_H
#define UI_FOVDIALOG_H

#include <QtCore/QVariant>
#include <QtWidgets/QApplication>
#include <QtWidgets/QHBoxLayout>
#include <QtWidgets/QListWidget>
#include <QtWidgets/QPushButton>
#include <QtWidgets/QSpacerItem>
#include <QtWidgets/QVBoxLayout>
#include <QtWidgets/QWidget>
#include <klocalizedstring.h>
#include "widgets/fovwidget.h"

QT_BEGIN_NAMESPACE

class Ui_FOVDialog
{
public:
    QHBoxLayout *hboxLayout;
    QListWidget *FOVListBox;
    QVBoxLayout *vboxLayout;
    QPushButton *NewButton;
    QSpacerItem *spacerItem;
    QPushButton *EditButton;
    QPushButton *RemoveButton;
    QSpacerItem *spacerItem1;
    FOVWidget *ViewBox;
    QSpacerItem *spacerItem2;

    void setupUi(QWidget *FOVDialog)
    {
        if (FOVDialog->objectName().isEmpty())
            FOVDialog->setObjectName("FOVDialog");
        FOVDialog->resize(275, 325);
        hboxLayout = new QHBoxLayout(FOVDialog);
        hboxLayout->setSpacing(6);
        hboxLayout->setObjectName("hboxLayout");
        hboxLayout->setContentsMargins(10, 10, 10, 10);
        FOVListBox = new QListWidget(FOVDialog);
        FOVListBox->setObjectName("FOVListBox");

        hboxLayout->addWidget(FOVListBox);

        vboxLayout = new QVBoxLayout();
        vboxLayout->setSpacing(6);
        vboxLayout->setObjectName("vboxLayout");
        vboxLayout->setContentsMargins(0, 0, 0, 0);
        NewButton = new QPushButton(FOVDialog);
        NewButton->setObjectName("NewButton");

        vboxLayout->addWidget(NewButton);

        spacerItem = new QSpacerItem(85, 16, QSizePolicy::Policy::Minimum, QSizePolicy::Policy::Fixed);

        vboxLayout->addItem(spacerItem);

        EditButton = new QPushButton(FOVDialog);
        EditButton->setObjectName("EditButton");

        vboxLayout->addWidget(EditButton);

        RemoveButton = new QPushButton(FOVDialog);
        RemoveButton->setObjectName("RemoveButton");

        vboxLayout->addWidget(RemoveButton);

        spacerItem1 = new QSpacerItem(85, 20, QSizePolicy::Policy::Minimum, QSizePolicy::Policy::Fixed);

        vboxLayout->addItem(spacerItem1);

        ViewBox = new FOVWidget(FOVDialog);
        ViewBox->setObjectName("ViewBox");
        ViewBox->setMinimumSize(QSize(80, 80));
        ViewBox->setFrameShape(QFrame::StyledPanel);
        ViewBox->setFrameShadow(QFrame::Raised);

        vboxLayout->addWidget(ViewBox);

        spacerItem2 = new QSpacerItem(85, 126, QSizePolicy::Policy::Minimum, QSizePolicy::Policy::Expanding);

        vboxLayout->addItem(spacerItem2);


        hboxLayout->addLayout(vboxLayout);


        retranslateUi(FOVDialog);

        QMetaObject::connectSlotsByName(FOVDialog);
    } // setupUi

    void retranslateUi(QWidget *FOVDialog)
    {
        FOVDialog->setWindowTitle(tr2i18n("Edit FOV Symbols", nullptr));
#if QT_CONFIG(tooltip)
        NewButton->setToolTip(tr2i18n("Add a new FOV symbol", nullptr));
#endif // QT_CONFIG(tooltip)
#if QT_CONFIG(whatsthis)
        NewButton->setWhatsThis(tr2i18n("Add a new field-of-view (FOV) symbol to the list.  You can define the size, shape, and color of the new symbol.", nullptr));
#endif // QT_CONFIG(whatsthis)
        NewButton->setText(tr2i18n("New...", nullptr));
#if QT_CONFIG(tooltip)
        EditButton->setToolTip(tr2i18n("Modify the highlighted FOV symbol", nullptr));
#endif // QT_CONFIG(tooltip)
#if QT_CONFIG(whatsthis)
        EditButton->setWhatsThis(tr2i18n("Press this button to modify the highlighted FOV symbol.  You can change its size, shape and color.", nullptr));
#endif // QT_CONFIG(whatsthis)
        EditButton->setText(tr2i18n("Edit...", nullptr));
#if QT_CONFIG(tooltip)
        RemoveButton->setToolTip(tr2i18n("Remove highlighted FOV symbol", nullptr));
#endif // QT_CONFIG(tooltip)
#if QT_CONFIG(whatsthis)
        RemoveButton->setWhatsThis(tr2i18n("Press this button to remove the highlighted FOV symbol from the list.", nullptr));
#endif // QT_CONFIG(whatsthis)
        RemoveButton->setText(tr2i18n("Remove", nullptr));
    } // retranslateUi

};

namespace Ui {
    class FOVDialog: public Ui_FOVDialog {};
} // namespace Ui

QT_END_NAMESPACE

#endif // FOVDIALOG_H

