/********************************************************************************
** Form generated from reading UI file 'mount.ui'
**
** Created by: Qt User Interface Compiler version 6.11.1
**
** WARNING! All changes made in this file will be lost when recompiling UI file!
********************************************************************************/

#ifndef UI_MOUNT_H
#define UI_MOUNT_H

#include <QtCore/QVariant>
#include <QtGui/QIcon>
#include <QtWidgets/QApplication>
#include <QtWidgets/QCheckBox>
#include <QtWidgets/QComboBox>
#include <QtWidgets/QDoubleSpinBox>
#include <QtWidgets/QFrame>
#include <QtWidgets/QGridLayout>
#include <QtWidgets/QGroupBox>
#include <QtWidgets/QHBoxLayout>
#include <QtWidgets/QLabel>
#include <QtWidgets/QPushButton>
#include <QtWidgets/QSpacerItem>
#include <QtWidgets/QTimeEdit>
#include <QtWidgets/QVBoxLayout>
#include <QtWidgets/QWidget>
#include <klocalizedstring.h>
#include "ekos/mount/meridianflipstatuswidget.h"
#include "ekos/mount/mountmotionwidget.h"
#include "ekos/mount/mountpositionwidget.h"
#include "ekos/mount/mounttargetwidget.h"

QT_BEGIN_NAMESPACE

class Ui_Mount
{
public:
    QVBoxLayout *verticalLayout;
    QGridLayout *mainLayout;
    QVBoxLayout *LeftLayout;
    QGroupBox *groupBox;
    QHBoxLayout *horizontalLayout;
    Ekos::MountPositionWidget *mountPosition;
    QGroupBox *MeridianFlipGroup;
    QGridLayout *gridLayout;
    QLabel *pierSideLabel;
    QCheckBox *executeMeridianFlip;
    QDoubleSpinBox *meridianFlipOffsetDegrees;
    Ekos::MeridianFlipStatusWidget *meridianFlipStatusWidget;
    QLabel *degLabel;
    QGroupBox *LimitGroup;
    QGridLayout *gridLayout_3;
    QDoubleSpinBox *minimumAltLimit;
    QLabel *minAltLabel;
    QDoubleSpinBox *maximumAltLimit;
    QDoubleSpinBox *maximumHaLimit;
    QLabel *maxAltLabel;
    QCheckBox *enableHaLimit;
    QLabel *maxHaLabel;
    QFrame *line_2;
    QCheckBox *enableAltitudeLimits;
    QCheckBox *enableAltitudeLimitsTrackingOnly;
    QVBoxLayout *MiddleLayout;
    QGroupBox *targetGroup;
    QVBoxLayout *verticalLayout_2;
    Ekos::MountTargetWidget *mountTarget;
    Ekos::MountMotionWidget *mountMotion;
    QSpacerItem *verticalSpacer_3;
    QHBoxLayout *opticalTrainLayout;
    QLabel *trainLabel;
    QComboBox *opticalTrainCombo;
    QPushButton *trainB;
    QSpacerItem *horizontalSpacer;
    QGroupBox *AutoPark;
    QHBoxLayout *horizontalLayout_5;
    QLabel *label_12;
    QTimeEdit *autoParkTime;
    QCheckBox *parkEveryDay;
    QSpacerItem *horizontalSpacer_4;
    QLabel *countdownLabel;
    QPushButton *startTimerB;
    QPushButton *stopTimerB;
    QVBoxLayout *RightLayout;
    QGroupBox *mountStatusGroup;
    QGridLayout *gridLayout_7;
    QPushButton *trackOffB;
    QPushButton *trackOnB;
    QPushButton *parkB;
    QPushButton *unparkB;
    QLabel *trackingLabel;
    QLabel *parkingLabel;
    QGroupBox *groupBox_4;
    QGridLayout *gridLayout_8;
    QCheckBox *useTimeUpdate;
    QComboBox *locationSource;
    QComboBox *timeSource;
    QCheckBox *useGeographicUpdate;
    QGroupBox *groupBox_2;
    QGridLayout *gridLayout_6;
    QPushButton *clearAlignmentModelB;
    QPushButton *clearParkingB;
    QPushButton *purgeConfigB;
    QSpacerItem *verticalSpacer_2;
    QPushButton *mountToolBoxB;
    QFrame *line;
    QSpacerItem *verticalSpacer;

    void setupUi(QWidget *Mount)
    {
        if (Mount->objectName().isEmpty())
            Mount->setObjectName("Mount");
        Mount->resize(822, 578);
        QSizePolicy sizePolicy(QSizePolicy::Policy::Preferred, QSizePolicy::Policy::Preferred);
        sizePolicy.setHorizontalStretch(0);
        sizePolicy.setVerticalStretch(0);
        sizePolicy.setHeightForWidth(Mount->sizePolicy().hasHeightForWidth());
        Mount->setSizePolicy(sizePolicy);
        verticalLayout = new QVBoxLayout(Mount);
        verticalLayout->setSpacing(3);
        verticalLayout->setObjectName("verticalLayout");
        verticalLayout->setContentsMargins(3, 3, 3, 3);
        mainLayout = new QGridLayout();
        mainLayout->setObjectName("mainLayout");
        LeftLayout = new QVBoxLayout();
        LeftLayout->setSpacing(12);
        LeftLayout->setObjectName("LeftLayout");
        groupBox = new QGroupBox(Mount);
        groupBox->setObjectName("groupBox");
        groupBox->setMinimumSize(QSize(270, 100));
        groupBox->setAlignment(Qt::AlignmentFlag::AlignCenter);
        horizontalLayout = new QHBoxLayout(groupBox);
        horizontalLayout->setObjectName("horizontalLayout");
        horizontalLayout->setContentsMargins(0, 0, 0, 0);
        mountPosition = new Ekos::MountPositionWidget(groupBox);
        mountPosition->setObjectName("mountPosition");
        mountPosition->setMinimumSize(QSize(270, 100));

        horizontalLayout->addWidget(mountPosition);


        LeftLayout->addWidget(groupBox);

        MeridianFlipGroup = new QGroupBox(Mount);
        MeridianFlipGroup->setObjectName("MeridianFlipGroup");
        gridLayout = new QGridLayout(MeridianFlipGroup);
        gridLayout->setSpacing(3);
        gridLayout->setObjectName("gridLayout");
        gridLayout->setContentsMargins(3, 3, 3, 3);
        pierSideLabel = new QLabel(MeridianFlipGroup);
        pierSideLabel->setObjectName("pierSideLabel");

        gridLayout->addWidget(pierSideLabel, 2, 0, 1, 3);

        executeMeridianFlip = new QCheckBox(MeridianFlipGroup);
        executeMeridianFlip->setObjectName("executeMeridianFlip");
        executeMeridianFlip->setChecked(true);

        gridLayout->addWidget(executeMeridianFlip, 0, 0, 1, 1);

        meridianFlipOffsetDegrees = new QDoubleSpinBox(MeridianFlipGroup);
        meridianFlipOffsetDegrees->setObjectName("meridianFlipOffsetDegrees");
        QSizePolicy sizePolicy1(QSizePolicy::Policy::Minimum, QSizePolicy::Policy::Preferred);
        sizePolicy1.setHorizontalStretch(0);
        sizePolicy1.setVerticalStretch(0);
        sizePolicy1.setHeightForWidth(meridianFlipOffsetDegrees->sizePolicy().hasHeightForWidth());
        meridianFlipOffsetDegrees->setSizePolicy(sizePolicy1);
        meridianFlipOffsetDegrees->setToolTipDuration(-1);
        meridianFlipOffsetDegrees->setMaximum(120.000000000000000);
        meridianFlipOffsetDegrees->setSingleStep(5.000000000000000);
        meridianFlipOffsetDegrees->setValue(5.000000000000000);

        gridLayout->addWidget(meridianFlipOffsetDegrees, 0, 1, 1, 1);

        meridianFlipStatusWidget = new Ekos::MeridianFlipStatusWidget(MeridianFlipGroup);
        meridianFlipStatusWidget->setObjectName("meridianFlipStatusWidget");
        meridianFlipStatusWidget->setMinimumSize(QSize(16, 16));

        gridLayout->addWidget(meridianFlipStatusWidget, 1, 0, 1, 3);

        degLabel = new QLabel(MeridianFlipGroup);
        degLabel->setObjectName("degLabel");
        QSizePolicy sizePolicy2(QSizePolicy::Policy::MinimumExpanding, QSizePolicy::Policy::Preferred);
        sizePolicy2.setHorizontalStretch(0);
        sizePolicy2.setVerticalStretch(0);
        sizePolicy2.setHeightForWidth(degLabel->sizePolicy().hasHeightForWidth());
        degLabel->setSizePolicy(sizePolicy2);

        gridLayout->addWidget(degLabel, 0, 2, 1, 1);


        LeftLayout->addWidget(MeridianFlipGroup);

        LimitGroup = new QGroupBox(Mount);
        LimitGroup->setObjectName("LimitGroup");
        QSizePolicy sizePolicy3(QSizePolicy::Policy::Minimum, QSizePolicy::Policy::Minimum);
        sizePolicy3.setHorizontalStretch(0);
        sizePolicy3.setVerticalStretch(0);
        sizePolicy3.setHeightForWidth(LimitGroup->sizePolicy().hasHeightForWidth());
        LimitGroup->setSizePolicy(sizePolicy3);
        gridLayout_3 = new QGridLayout(LimitGroup);
        gridLayout_3->setSpacing(6);
        gridLayout_3->setObjectName("gridLayout_3");
        gridLayout_3->setContentsMargins(9, 9, 9, 9);
        minimumAltLimit = new QDoubleSpinBox(LimitGroup);
        minimumAltLimit->setObjectName("minimumAltLimit");
        minimumAltLimit->setEnabled(false);
        QSizePolicy sizePolicy4(QSizePolicy::Policy::Preferred, QSizePolicy::Policy::Fixed);
        sizePolicy4.setHorizontalStretch(0);
        sizePolicy4.setVerticalStretch(0);
        sizePolicy4.setHeightForWidth(minimumAltLimit->sizePolicy().hasHeightForWidth());
        minimumAltLimit->setSizePolicy(sizePolicy4);
        minimumAltLimit->setMinimum(-90.000000000000000);
        minimumAltLimit->setMaximum(90.000000000000000);
        minimumAltLimit->setValue(90.000000000000000);

        gridLayout_3->addWidget(minimumAltLimit, 1, 1, 1, 1);

        minAltLabel = new QLabel(LimitGroup);
        minAltLabel->setObjectName("minAltLabel");
        minAltLabel->setEnabled(false);

        gridLayout_3->addWidget(minAltLabel, 1, 0, 1, 1);

        maximumAltLimit = new QDoubleSpinBox(LimitGroup);
        maximumAltLimit->setObjectName("maximumAltLimit");
        maximumAltLimit->setEnabled(false);
        sizePolicy4.setHeightForWidth(maximumAltLimit->sizePolicy().hasHeightForWidth());
        maximumAltLimit->setSizePolicy(sizePolicy4);
        maximumAltLimit->setMinimum(-90.000000000000000);
        maximumAltLimit->setMaximum(90.000000000000000);
        maximumAltLimit->setValue(90.000000000000000);

        gridLayout_3->addWidget(maximumAltLimit, 2, 1, 1, 1);

        maximumHaLimit = new QDoubleSpinBox(LimitGroup);
        maximumHaLimit->setObjectName("maximumHaLimit");
        maximumHaLimit->setEnabled(false);
        sizePolicy4.setHeightForWidth(maximumHaLimit->sizePolicy().hasHeightForWidth());
        maximumHaLimit->setSizePolicy(sizePolicy4);
        maximumHaLimit->setMinimum(-2.000000000000000);
        maximumHaLimit->setMaximum(2.000000000000000);
        maximumHaLimit->setSingleStep(0.100000000000000);
        maximumHaLimit->setValue(0.000000000000000);

        gridLayout_3->addWidget(maximumHaLimit, 5, 1, 1, 1);

        maxAltLabel = new QLabel(LimitGroup);
        maxAltLabel->setObjectName("maxAltLabel");
        maxAltLabel->setEnabled(false);

        gridLayout_3->addWidget(maxAltLabel, 2, 0, 1, 1);

        enableHaLimit = new QCheckBox(LimitGroup);
        enableHaLimit->setObjectName("enableHaLimit");

        gridLayout_3->addWidget(enableHaLimit, 3, 0, 1, 1);

        maxHaLabel = new QLabel(LimitGroup);
        maxHaLabel->setObjectName("maxHaLabel");
        maxHaLabel->setEnabled(false);

        gridLayout_3->addWidget(maxHaLabel, 5, 0, 1, 1);

        line_2 = new QFrame(LimitGroup);
        line_2->setObjectName("line_2");
        line_2->setFrameShape(QFrame::Shape::HLine);
        line_2->setFrameShadow(QFrame::Shadow::Sunken);

        gridLayout_3->addWidget(line_2, 4, 0, 1, 2);

        enableAltitudeLimits = new QCheckBox(LimitGroup);
        enableAltitudeLimits->setObjectName("enableAltitudeLimits");

        gridLayout_3->addWidget(enableAltitudeLimits, 0, 0, 1, 1);

        enableAltitudeLimitsTrackingOnly = new QCheckBox(LimitGroup);
        enableAltitudeLimitsTrackingOnly->setObjectName("enableAltitudeLimitsTrackingOnly");
        enableAltitudeLimitsTrackingOnly->setEnabled(false);

        gridLayout_3->addWidget(enableAltitudeLimitsTrackingOnly, 0, 1, 1, 1);


        LeftLayout->addWidget(LimitGroup);


        mainLayout->addLayout(LeftLayout, 1, 0, 1, 1);

        MiddleLayout = new QVBoxLayout();
        MiddleLayout->setSpacing(12);
        MiddleLayout->setObjectName("MiddleLayout");
        targetGroup = new QGroupBox(Mount);
        targetGroup->setObjectName("targetGroup");
        verticalLayout_2 = new QVBoxLayout(targetGroup);
        verticalLayout_2->setSpacing(0);
        verticalLayout_2->setObjectName("verticalLayout_2");
        verticalLayout_2->setContentsMargins(0, 0, 0, 0);
        mountTarget = new Ekos::MountTargetWidget(targetGroup);
        mountTarget->setObjectName("mountTarget");
        mountTarget->setMinimumSize(QSize(200, 140));

        verticalLayout_2->addWidget(mountTarget);


        MiddleLayout->addWidget(targetGroup);

        mountMotion = new Ekos::MountMotionWidget(Mount);
        mountMotion->setObjectName("mountMotion");
        mountMotion->setMinimumSize(QSize(235, 230));

        MiddleLayout->addWidget(mountMotion);

        verticalSpacer_3 = new QSpacerItem(20, 40, QSizePolicy::Policy::Minimum, QSizePolicy::Policy::Expanding);

        MiddleLayout->addItem(verticalSpacer_3);


        mainLayout->addLayout(MiddleLayout, 1, 1, 1, 1);

        opticalTrainLayout = new QHBoxLayout();
        opticalTrainLayout->setObjectName("opticalTrainLayout");
        trainLabel = new QLabel(Mount);
        trainLabel->setObjectName("trainLabel");

        opticalTrainLayout->addWidget(trainLabel);

        opticalTrainCombo = new QComboBox(Mount);
        opticalTrainCombo->setObjectName("opticalTrainCombo");
        QSizePolicy sizePolicy5(QSizePolicy::Policy::MinimumExpanding, QSizePolicy::Policy::Fixed);
        sizePolicy5.setHorizontalStretch(0);
        sizePolicy5.setVerticalStretch(0);
        sizePolicy5.setHeightForWidth(opticalTrainCombo->sizePolicy().hasHeightForWidth());
        opticalTrainCombo->setSizePolicy(sizePolicy5);
        opticalTrainCombo->setMinimumSize(QSize(0, 32));

        opticalTrainLayout->addWidget(opticalTrainCombo);

        trainB = new QPushButton(Mount);
        trainB->setObjectName("trainB");
        trainB->setEnabled(false);
        trainB->setMinimumSize(QSize(24, 24));
        trainB->setMaximumSize(QSize(16777215, 32));
        QIcon icon(QIcon::fromTheme(QString::fromUtf8("document-edit")));
        trainB->setIcon(icon);
        trainB->setIconSize(QSize(24, 24));

        opticalTrainLayout->addWidget(trainB);

        horizontalSpacer = new QSpacerItem(40, 20, QSizePolicy::Policy::Expanding, QSizePolicy::Policy::Minimum);

        opticalTrainLayout->addItem(horizontalSpacer);


        mainLayout->addLayout(opticalTrainLayout, 0, 0, 1, 2);

        AutoPark = new QGroupBox(Mount);
        AutoPark->setObjectName("AutoPark");
        horizontalLayout_5 = new QHBoxLayout(AutoPark);
        horizontalLayout_5->setSpacing(3);
        horizontalLayout_5->setObjectName("horizontalLayout_5");
        horizontalLayout_5->setContentsMargins(3, 3, 3, 3);
        label_12 = new QLabel(AutoPark);
        label_12->setObjectName("label_12");

        horizontalLayout_5->addWidget(label_12);

        autoParkTime = new QTimeEdit(AutoPark);
        autoParkTime->setObjectName("autoParkTime");
        autoParkTime->setTime(QTime(3, 0, 0));

        horizontalLayout_5->addWidget(autoParkTime);

        parkEveryDay = new QCheckBox(AutoPark);
        parkEveryDay->setObjectName("parkEveryDay");

        horizontalLayout_5->addWidget(parkEveryDay);

        horizontalSpacer_4 = new QSpacerItem(40, 20, QSizePolicy::Policy::Expanding, QSizePolicy::Policy::Minimum);

        horizontalLayout_5->addItem(horizontalSpacer_4);

        countdownLabel = new QLabel(AutoPark);
        countdownLabel->setObjectName("countdownLabel");
        QFont font;
        font.setFamilies({QString::fromUtf8("Arial")});
        font.setPointSize(26);
        font.setBold(true);
        font.setItalic(false);
        countdownLabel->setFont(font);
        countdownLabel->setFrameShape(QFrame::Shape::Box);
        countdownLabel->setLineWidth(2);

        horizontalLayout_5->addWidget(countdownLabel);

        startTimerB = new QPushButton(AutoPark);
        startTimerB->setObjectName("startTimerB");
        startTimerB->setMinimumSize(QSize(32, 32));
        startTimerB->setMaximumSize(QSize(32, 32));
        QIcon icon1(QIcon::fromTheme(QString::fromUtf8("media-playback-start")));
        startTimerB->setIcon(icon1);
        startTimerB->setIconSize(QSize(32, 32));

        horizontalLayout_5->addWidget(startTimerB);

        stopTimerB = new QPushButton(AutoPark);
        stopTimerB->setObjectName("stopTimerB");
        stopTimerB->setMinimumSize(QSize(32, 32));
        stopTimerB->setMaximumSize(QSize(32, 32));
        QIcon icon2(QIcon::fromTheme(QString::fromUtf8("media-playback-stop")));
        stopTimerB->setIcon(icon2);
        stopTimerB->setIconSize(QSize(32, 32));

        horizontalLayout_5->addWidget(stopTimerB);


        mainLayout->addWidget(AutoPark, 2, 0, 1, 2);

        RightLayout = new QVBoxLayout();
        RightLayout->setSpacing(12);
        RightLayout->setObjectName("RightLayout");
        mountStatusGroup = new QGroupBox(Mount);
        mountStatusGroup->setObjectName("mountStatusGroup");
        gridLayout_7 = new QGridLayout(mountStatusGroup);
        gridLayout_7->setObjectName("gridLayout_7");
        trackOffB = new QPushButton(mountStatusGroup);
        trackOffB->setObjectName("trackOffB");
        trackOffB->setMinimumSize(QSize(64, 32));
        trackOffB->setMaximumSize(QSize(48, 48));
        trackOffB->setStyleSheet(QString::fromUtf8("QPushButton:checked\n"
"{\n"
"background-color: maroon;\n"
"border: 1px outset;\n"
"font-weight:bold;\n"
"}"));
        trackOffB->setCheckable(true);

        gridLayout_7->addWidget(trackOffB, 0, 2, 1, 1);

        trackOnB = new QPushButton(mountStatusGroup);
        trackOnB->setObjectName("trackOnB");
        trackOnB->setMinimumSize(QSize(64, 32));
        trackOnB->setMaximumSize(QSize(48, 48));
        trackOnB->setStyleSheet(QString::fromUtf8("QPushButton:checked\n"
"{\n"
"background-color: maroon;\n"
"border: 1px outset;\n"
"font-weight:bold;\n"
"}"));
        trackOnB->setCheckable(true);
        trackOnB->setChecked(false);

        gridLayout_7->addWidget(trackOnB, 0, 1, 1, 1);

        parkB = new QPushButton(mountStatusGroup);
        parkB->setObjectName("parkB");
        parkB->setEnabled(false);
        parkB->setMinimumSize(QSize(64, 32));
        parkB->setMaximumSize(QSize(64, 48));
        parkB->setStyleSheet(QString::fromUtf8("QPushButton:checked\n"
"{\n"
"background-color: maroon;\n"
"border: 1px outset;\n"
"font-weight:bold;\n"
"}"));

        gridLayout_7->addWidget(parkB, 2, 1, 1, 1);

        unparkB = new QPushButton(mountStatusGroup);
        unparkB->setObjectName("unparkB");
        unparkB->setEnabled(false);
        unparkB->setMinimumSize(QSize(64, 32));
        unparkB->setMaximumSize(QSize(64, 48));
        unparkB->setStyleSheet(QString::fromUtf8("QPushButton:checked\n"
"{\n"
"background-color: maroon;\n"
"border: 1px outset;\n"
"font-weight:bold;\n"
"}"));

        gridLayout_7->addWidget(unparkB, 2, 2, 1, 1);

        trackingLabel = new QLabel(mountStatusGroup);
        trackingLabel->setObjectName("trackingLabel");

        gridLayout_7->addWidget(trackingLabel, 0, 0, 1, 1);

        parkingLabel = new QLabel(mountStatusGroup);
        parkingLabel->setObjectName("parkingLabel");

        gridLayout_7->addWidget(parkingLabel, 2, 0, 1, 1);


        RightLayout->addWidget(mountStatusGroup);

        groupBox_4 = new QGroupBox(Mount);
        groupBox_4->setObjectName("groupBox_4");
        gridLayout_8 = new QGridLayout(groupBox_4);
        gridLayout_8->setObjectName("gridLayout_8");
        useTimeUpdate = new QCheckBox(groupBox_4);
        useTimeUpdate->setObjectName("useTimeUpdate");

        gridLayout_8->addWidget(useTimeUpdate, 0, 0, 1, 1);

        locationSource = new QComboBox(groupBox_4);
        locationSource->setObjectName("locationSource");

        gridLayout_8->addWidget(locationSource, 1, 1, 1, 1);

        timeSource = new QComboBox(groupBox_4);
        timeSource->setObjectName("timeSource");

        gridLayout_8->addWidget(timeSource, 0, 1, 1, 1);

        useGeographicUpdate = new QCheckBox(groupBox_4);
        useGeographicUpdate->setObjectName("useGeographicUpdate");

        gridLayout_8->addWidget(useGeographicUpdate, 1, 0, 1, 1);


        RightLayout->addWidget(groupBox_4);

        groupBox_2 = new QGroupBox(Mount);
        groupBox_2->setObjectName("groupBox_2");
        gridLayout_6 = new QGridLayout(groupBox_2);
        gridLayout_6->setSpacing(3);
        gridLayout_6->setObjectName("gridLayout_6");
        gridLayout_6->setContentsMargins(3, 3, 3, 3);
        clearAlignmentModelB = new QPushButton(groupBox_2);
        clearAlignmentModelB->setObjectName("clearAlignmentModelB");
        QIcon icon3(QIcon::fromTheme(QString::fromUtf8("edit-clear-all")));
        clearAlignmentModelB->setIcon(icon3);
        clearAlignmentModelB->setIconSize(QSize(24, 24));

        gridLayout_6->addWidget(clearAlignmentModelB, 0, 0, 1, 1);

        clearParkingB = new QPushButton(groupBox_2);
        clearParkingB->setObjectName("clearParkingB");
        QIcon icon4(QIcon::fromTheme(QString::fromUtf8("xml-attribute-delete")));
        clearParkingB->setIcon(icon4);
        clearParkingB->setIconSize(QSize(24, 24));

        gridLayout_6->addWidget(clearParkingB, 0, 1, 1, 1);

        purgeConfigB = new QPushButton(groupBox_2);
        purgeConfigB->setObjectName("purgeConfigB");
        QIcon icon5(QIcon::fromTheme(QString::fromUtf8("delete")));
        purgeConfigB->setIcon(icon5);
        purgeConfigB->setIconSize(QSize(24, 24));

        gridLayout_6->addWidget(purgeConfigB, 1, 0, 1, 2);


        RightLayout->addWidget(groupBox_2);

        verticalSpacer_2 = new QSpacerItem(20, 40, QSizePolicy::Policy::Minimum, QSizePolicy::Policy::Expanding);

        RightLayout->addItem(verticalSpacer_2);


        mainLayout->addLayout(RightLayout, 1, 2, 2, 1);

        mountToolBoxB = new QPushButton(Mount);
        mountToolBoxB->setObjectName("mountToolBoxB");
        QFont font1;
        font1.setBold(true);
        mountToolBoxB->setFont(font1);
        QIcon icon6(QIcon::fromTheme(QString::fromUtf8("draw-text")));
        mountToolBoxB->setIcon(icon6);
        mountToolBoxB->setIconSize(QSize(32, 32));
        mountToolBoxB->setAutoDefault(true);

        mainLayout->addWidget(mountToolBoxB, 0, 2, 1, 1);

        mainLayout->setRowStretch(2, 1);
        mainLayout->setColumnStretch(0, 1);
        mainLayout->setColumnStretch(1, 1);

        verticalLayout->addLayout(mainLayout);

        line = new QFrame(Mount);
        line->setObjectName("line");
        line->setFrameShape(QFrame::Shape::VLine);
        line->setFrameShadow(QFrame::Shadow::Sunken);

        verticalLayout->addWidget(line);

        verticalSpacer = new QSpacerItem(20, 20, QSizePolicy::Policy::Minimum, QSizePolicy::Policy::Expanding);

        verticalLayout->addItem(verticalSpacer);

        verticalLayout->setStretch(2, 10);

        retranslateUi(Mount);

        mountToolBoxB->setDefault(true);


        QMetaObject::connectSlotsByName(Mount);
    } // setupUi

    void retranslateUi(QWidget *Mount)
    {
        groupBox->setTitle(tr2i18n("Position", nullptr));
        MeridianFlipGroup->setTitle(tr2i18n("Meridian Flip", nullptr));
        pierSideLabel->setText(QString());
#if QT_CONFIG(tooltip)
        executeMeridianFlip->setToolTip(tr2i18n("<html><head/><body><p>Request a meridian flip if the hour angle exceeds the specified value. Capture and Guiding will be suspended and resumed after the flip is complete.</p></body></html>", nullptr));
#endif // QT_CONFIG(tooltip)
        executeMeridianFlip->setText(tr2i18n("Flip if HA >:", nullptr));
#if QT_CONFIG(tooltip)
        meridianFlipOffsetDegrees->setToolTip(tr2i18n("RA position in degrees behind the meridian where the meridian flip should be activated.", nullptr));
#endif // QT_CONFIG(tooltip)
        degLabel->setText(tr2i18n("deg", nullptr));
#if QT_CONFIG(tooltip)
        LimitGroup->setToolTip(tr2i18n("<html><head/><body><p><br/></p></body></html>", nullptr));
#endif // QT_CONFIG(tooltip)
        LimitGroup->setTitle(tr2i18n("Limits", nullptr));
#if QT_CONFIG(tooltip)
        minimumAltLimit->setToolTip(tr2i18n("<html><head/><body><p>Minimum telescope altitude limit. If the telescope is below this limit, it will be commanded to stop.</p></body></html>", nullptr));
#endif // QT_CONFIG(tooltip)
#if QT_CONFIG(tooltip)
        minAltLabel->setToolTip(tr2i18n("Minimum telescope altitude limit. If the telescope is below this limit, it will be commanded to stop.", nullptr));
#endif // QT_CONFIG(tooltip)
        minAltLabel->setText(tr2i18n("Min. Alt:", nullptr));
#if QT_CONFIG(tooltip)
        maximumAltLimit->setToolTip(tr2i18n("<html><head/><body><p>Maximum telescope altitude limit. If the telescope is above this limit, it will be commanded to stop.</p></body></html>", nullptr));
#endif // QT_CONFIG(tooltip)
#if QT_CONFIG(tooltip)
        maximumHaLimit->setToolTip(tr2i18n("<html><head/><body><p>Maximum Hour Angle limit if the mount has not flipped. If the telescope is above this limit, it will be commanded to stop.</p></body></html>", nullptr));
#endif // QT_CONFIG(tooltip)
#if QT_CONFIG(tooltip)
        maxAltLabel->setToolTip(tr2i18n("<html><head/><body><p>Maximum telescope altitude limit. If the telescope is above this limit, it will be commanded to stop.</p></body></html>", nullptr));
#endif // QT_CONFIG(tooltip)
        maxAltLabel->setText(tr2i18n("Max. Alt:", nullptr));
#if QT_CONFIG(tooltip)
        enableHaLimit->setToolTip(tr2i18n("<html><head/><body><p>Enable or Disable the mount Hour Angle limit. Once enabled, Ekos monitors the mount's hour angle while slewing or tracking. If the mount slews/tracks past the limit while the Pier Side is in the state that does not allow that, it shall be commanded to stop and tracking will be turned off. Requires a mount that reports the pier side correctly.</p></body></html>", nullptr));
#endif // QT_CONFIG(tooltip)
        enableHaLimit->setText(tr2i18n("Enable HA limits", nullptr));
#if QT_CONFIG(tooltip)
        maxHaLabel->setToolTip(tr2i18n("<html><head/><body><p>Maximum Hour Angle limit if the mount has not flipped. If the telescope is above this limit, it will be commanded to stop.</p></body></html>", nullptr));
#endif // QT_CONFIG(tooltip)
        maxHaLabel->setText(tr2i18n("Max. HA (hours):", nullptr));
#if QT_CONFIG(tooltip)
        enableAltitudeLimits->setToolTip(tr2i18n("<html><head/><body><p>Enable or Disable the mount travel range limits. Once enabled, Ekos monitors the mount's altitude while slewing or tracking. If the mount slews/tracks below or above the limits, it shall be commanded to stop and tracking will be turned off.</p></body></html>", nullptr));
#endif // QT_CONFIG(tooltip)
        enableAltitudeLimits->setText(tr2i18n("Enable Alt limits", nullptr));
#if QT_CONFIG(tooltip)
        enableAltitudeLimitsTrackingOnly->setToolTip(tr2i18n("<html><head/><body><p>Use altitude limits only while the mount tracking. This is necessary for some mounts that intentionally pass this limit, e.g. for parking.</p><p><span style=\" font-weight:600;\">WARNING</span>: leave unchecked if unsure, use only if you know what you are doing.</p></body></html>", nullptr));
#endif // QT_CONFIG(tooltip)
        enableAltitudeLimitsTrackingOnly->setText(tr2i18n("Tracking only", nullptr));
        targetGroup->setTitle(tr2i18n("Target", nullptr));
        trainLabel->setText(tr2i18n("Train:", nullptr));
#if QT_CONFIG(tooltip)
        opticalTrainCombo->setToolTip(tr2i18n("Optical Train", nullptr));
#endif // QT_CONFIG(tooltip)
        trainB->setText(QString());
        AutoPark->setTitle(tr2i18n("Auto Park", nullptr));
        label_12->setText(tr2i18n("Park at:", nullptr));
#if QT_CONFIG(tooltip)
        parkEveryDay->setToolTip(tr2i18n("Automatically start the park timer on startup", nullptr));
#endif // QT_CONFIG(tooltip)
        parkEveryDay->setText(tr2i18n("Every day", nullptr));
        countdownLabel->setText(tr2i18n("00:00:00", nullptr));
        startTimerB->setText(QString());
        stopTimerB->setText(QString());
        mountStatusGroup->setTitle(tr2i18n("Status", nullptr));
        trackOffB->setText(tr2i18n("OFF", nullptr));
        trackOnB->setText(tr2i18n("ON", nullptr));
        parkB->setText(tr2i18n("Park", nullptr));
        unparkB->setText(tr2i18n("UnPark", nullptr));
        trackingLabel->setText(tr2i18n("Tracking", nullptr));
        parkingLabel->setText(tr2i18n("Parking Status", nullptr));
        groupBox_4->setTitle(tr2i18n("Sources", nullptr));
#if QT_CONFIG(tooltip)
        useTimeUpdate->setToolTip(tr2i18n("Enable time synchronization upon connection between KStars and INDI", nullptr));
#endif // QT_CONFIG(tooltip)
        useTimeUpdate->setText(tr2i18n("Time:", nullptr));
#if QT_CONFIG(tooltip)
        useGeographicUpdate->setToolTip(tr2i18n("Enable geographic location synchronization upon connection between KStars and INDI", nullptr));
#endif // QT_CONFIG(tooltip)
        useGeographicUpdate->setText(tr2i18n("Location:", nullptr));
        groupBox_2->setTitle(tr2i18n("Reset", nullptr));
#if QT_CONFIG(tooltip)
        clearAlignmentModelB->setToolTip(tr2i18n("Deletes all mount alignment points", nullptr));
#endif // QT_CONFIG(tooltip)
        clearAlignmentModelB->setText(tr2i18n("Clear  Model", nullptr));
        clearParkingB->setText(tr2i18n("Clear Parking", nullptr));
        purgeConfigB->setText(tr2i18n("Purge All Configuration", nullptr));
        mountToolBoxB->setText(tr2i18n("Mount Control", nullptr));
#if QT_CONFIG(shortcut)
        mountToolBoxB->setShortcut(tr2i18n("Ctrl+S", nullptr));
#endif // QT_CONFIG(shortcut)
        (void)Mount;
    } // retranslateUi

};

namespace Ui {
    class Mount: public Ui_Mount {};
} // namespace Ui

QT_END_NAMESPACE

#endif // MOUNT_H

