/****************************************************************************
** Meta object code from reading C++ file 'aiguidewizard.h'
**
** Created by: The Qt Meta Object Compiler version 69 (Qt 6.11.1)
**
** WARNING! All changes made in this file will be lost!
*****************************************************************************/

#include "../../../../kstars-3.8.4.1/kstars/ekos/guide/aiguidewizard.h"
#include <QtCore/qmetatype.h>

#include <QtCore/qtmochelpers.h>

#include <memory>


#include <QtCore/qxptype_traits.h>
#if !defined(Q_MOC_OUTPUT_REVISION)
#error "The header file 'aiguidewizard.h' doesn't include <QObject>."
#elif Q_MOC_OUTPUT_REVISION != 69
#error "This file was generated using the moc from 6.11.1. It"
#error "cannot be used with the include files from this version of Qt."
#error "(The moc has changed too much.)"
#endif

#ifndef Q_CONSTINIT
#define Q_CONSTINIT
#endif

QT_WARNING_PUSH
QT_WARNING_DISABLE_DEPRECATED
QT_WARNING_DISABLE_GCC("-Wuseless-cast")
namespace {
struct qt_meta_tag_ZN4Ekos13AIGuideWizardE_t {};
} // unnamed namespace

template <> constexpr inline auto Ekos::AIGuideWizard::qt_create_metaobjectdata<qt_meta_tag_ZN4Ekos13AIGuideWizardE_t>()
{
    namespace QMC = QtMocConstants;
    QtMocHelpers::StringRefStorage qt_stringData {
        "Ekos::AIGuideWizard",
        "aiGuideProgress",
        "",
        "current",
        "total",
        "status",
        "aiGuideLog",
        "message",
        "aiGuideComplete",
        "trainInEkosLiveRequested",
        "QJsonObject",
        "sysidData",
        "slotStartProtocol",
        "slotStopProtocol",
        "onTrainingResult",
        "success",
        "result",
        "slotExportOffline",
        "slotExportLogs",
        "mountType",
        "state",
        "totalPhases",
        "phasesRemaining"
    };

    QtMocHelpers::UintData qt_methods {
        // Signal 'aiGuideProgress'
        QtMocHelpers::SignalData<void(int, int, const QString &)>(1, 2, QMC::AccessPublic, QMetaType::Void, {{
            { QMetaType::Int, 3 }, { QMetaType::Int, 4 }, { QMetaType::QString, 5 },
        }}),
        // Signal 'aiGuideLog'
        QtMocHelpers::SignalData<void(const QString &)>(6, 2, QMC::AccessPublic, QMetaType::Void, {{
            { QMetaType::QString, 7 },
        }}),
        // Signal 'aiGuideComplete'
        QtMocHelpers::SignalData<void()>(8, 2, QMC::AccessPublic, QMetaType::Void),
        // Signal 'trainInEkosLiveRequested'
        QtMocHelpers::SignalData<void(const QJsonObject &)>(9, 2, QMC::AccessPublic, QMetaType::Void, {{
            { 0x80000000 | 10, 11 },
        }}),
        // Slot 'slotStartProtocol'
        QtMocHelpers::SlotData<void()>(12, 2, QMC::AccessPublic, QMetaType::Void),
        // Slot 'slotStopProtocol'
        QtMocHelpers::SlotData<void()>(13, 2, QMC::AccessPublic, QMetaType::Void),
        // Slot 'onTrainingResult'
        QtMocHelpers::SlotData<void(bool, const QJsonObject &)>(14, 2, QMC::AccessPublic, QMetaType::Void, {{
            { QMetaType::Bool, 15 }, { 0x80000000 | 10, 16 },
        }}),
        // Slot 'slotExportOffline'
        QtMocHelpers::SlotData<void()>(17, 2, QMC::AccessPrivate, QMetaType::Void),
        // Slot 'slotExportLogs'
        QtMocHelpers::SlotData<void()>(18, 2, QMC::AccessPrivate, QMetaType::Void),
    };
    QtMocHelpers::UintData qt_properties {
        // property 'mountType'
        QtMocHelpers::PropertyData<QString>(19, QMetaType::QString, QMC::DefaultPropertyFlags),
        // property 'state'
        QtMocHelpers::PropertyData<int>(20, QMetaType::Int, QMC::DefaultPropertyFlags),
        // property 'totalPhases'
        QtMocHelpers::PropertyData<int>(21, QMetaType::Int, QMC::DefaultPropertyFlags),
        // property 'phasesRemaining'
        QtMocHelpers::PropertyData<int>(22, QMetaType::Int, QMC::DefaultPropertyFlags),
    };
    QtMocHelpers::UintData qt_enums {
    };
    return QtMocHelpers::metaObjectData<AIGuideWizard, qt_meta_tag_ZN4Ekos13AIGuideWizardE_t>(QMC::MetaObjectFlag{}, qt_stringData,
            qt_methods, qt_properties, qt_enums);
}
Q_CONSTINIT const QMetaObject Ekos::AIGuideWizard::staticMetaObject = { {
    QMetaObject::SuperData::link<QWizard::staticMetaObject>(),
    qt_staticMetaObjectStaticContent<qt_meta_tag_ZN4Ekos13AIGuideWizardE_t>.stringdata,
    qt_staticMetaObjectStaticContent<qt_meta_tag_ZN4Ekos13AIGuideWizardE_t>.data,
    qt_static_metacall,
    nullptr,
    qt_staticMetaObjectRelocatingContent<qt_meta_tag_ZN4Ekos13AIGuideWizardE_t>.metaTypes,
    nullptr
} };

void Ekos::AIGuideWizard::qt_static_metacall(QObject *_o, QMetaObject::Call _c, int _id, void **_a)
{
    auto *_t = static_cast<AIGuideWizard *>(_o);
    if (_c == QMetaObject::InvokeMetaMethod) {
        switch (_id) {
        case 0: _t->aiGuideProgress((*reinterpret_cast<std::add_pointer_t<int>>(_a[1])),(*reinterpret_cast<std::add_pointer_t<int>>(_a[2])),(*reinterpret_cast<std::add_pointer_t<QString>>(_a[3]))); break;
        case 1: _t->aiGuideLog((*reinterpret_cast<std::add_pointer_t<QString>>(_a[1]))); break;
        case 2: _t->aiGuideComplete(); break;
        case 3: _t->trainInEkosLiveRequested((*reinterpret_cast<std::add_pointer_t<QJsonObject>>(_a[1]))); break;
        case 4: _t->slotStartProtocol(); break;
        case 5: _t->slotStopProtocol(); break;
        case 6: _t->onTrainingResult((*reinterpret_cast<std::add_pointer_t<bool>>(_a[1])),(*reinterpret_cast<std::add_pointer_t<QJsonObject>>(_a[2]))); break;
        case 7: _t->slotExportOffline(); break;
        case 8: _t->slotExportLogs(); break;
        default: ;
        }
    }
    if (_c == QMetaObject::IndexOfMethod) {
        if (QtMocHelpers::indexOfMethod<void (AIGuideWizard::*)(int , int , const QString & )>(_a, &AIGuideWizard::aiGuideProgress, 0))
            return;
        if (QtMocHelpers::indexOfMethod<void (AIGuideWizard::*)(const QString & )>(_a, &AIGuideWizard::aiGuideLog, 1))
            return;
        if (QtMocHelpers::indexOfMethod<void (AIGuideWizard::*)()>(_a, &AIGuideWizard::aiGuideComplete, 2))
            return;
        if (QtMocHelpers::indexOfMethod<void (AIGuideWizard::*)(const QJsonObject & )>(_a, &AIGuideWizard::trainInEkosLiveRequested, 3))
            return;
    }
    if (_c == QMetaObject::ReadProperty) {
        void *_v = _a[0];
        switch (_id) {
        case 0: *reinterpret_cast<QString*>(_v) = _t->mountType(); break;
        case 1: *reinterpret_cast<int*>(_v) = _t->state(); break;
        case 2: *reinterpret_cast<int*>(_v) = _t->totalPhases(); break;
        case 3: *reinterpret_cast<int*>(_v) = _t->phasesRemaining(); break;
        default: break;
        }
    }
}

const QMetaObject *Ekos::AIGuideWizard::metaObject() const
{
    return QObject::d_ptr->metaObject ? QObject::d_ptr->dynamicMetaObject() : &staticMetaObject;
}

void *Ekos::AIGuideWizard::qt_metacast(const char *_clname)
{
    if (!_clname) return nullptr;
    if (!strcmp(_clname, qt_staticMetaObjectStaticContent<qt_meta_tag_ZN4Ekos13AIGuideWizardE_t>.strings))
        return static_cast<void*>(this);
    if (!strcmp(_clname, "Ui::AIGuideWizard"))
        return static_cast< Ui::AIGuideWizard*>(this);
    return QWizard::qt_metacast(_clname);
}

int Ekos::AIGuideWizard::qt_metacall(QMetaObject::Call _c, int _id, void **_a)
{
    _id = QWizard::qt_metacall(_c, _id, _a);
    if (_id < 0)
        return _id;
    if (_c == QMetaObject::InvokeMetaMethod) {
        if (_id < 9)
            qt_static_metacall(this, _c, _id, _a);
        _id -= 9;
    }
    if (_c == QMetaObject::RegisterMethodArgumentMetaType) {
        if (_id < 9)
            *reinterpret_cast<QMetaType *>(_a[0]) = QMetaType();
        _id -= 9;
    }
    if (_c == QMetaObject::ReadProperty || _c == QMetaObject::WriteProperty
            || _c == QMetaObject::ResetProperty || _c == QMetaObject::BindableProperty
            || _c == QMetaObject::RegisterPropertyMetaType) {
        qt_static_metacall(this, _c, _id, _a);
        _id -= 4;
    }
    return _id;
}

// SIGNAL 0
void Ekos::AIGuideWizard::aiGuideProgress(int _t1, int _t2, const QString & _t3)
{
    QMetaObject::activate<void>(this, &staticMetaObject, 0, nullptr, _t1, _t2, _t3);
}

// SIGNAL 1
void Ekos::AIGuideWizard::aiGuideLog(const QString & _t1)
{
    QMetaObject::activate<void>(this, &staticMetaObject, 1, nullptr, _t1);
}

// SIGNAL 2
void Ekos::AIGuideWizard::aiGuideComplete()
{
    QMetaObject::activate(this, &staticMetaObject, 2, nullptr);
}

// SIGNAL 3
void Ekos::AIGuideWizard::trainInEkosLiveRequested(const QJsonObject & _t1)
{
    QMetaObject::activate<void>(this, &staticMetaObject, 3, nullptr, _t1);
}
QT_WARNING_POP
