/*
 * This file was generated by qdbusxml2cpp version 0.8
 * Source file was org.kde.kstars.Ekos.Mount.xml
 *
 * qdbusxml2cpp is Copyright (C) The Qt Company Ltd. and other contributors.
 *
 * This is an auto-generated file.
 * Do not edit! All changes made to it will be lost.
 */

#include "mountadaptor.h"
#include <QtCore/QMetaObject>
#include <QtCore/QByteArray>
#include <QtCore/QList>
#include <QtCore/QMap>
#include <QtCore/QString>
#include <QtCore/QStringList>
#include <QtCore/QVariant>

/*
 * Implementation of adaptor class MountAdaptor
 */

MountAdaptor::MountAdaptor(Ekos::Mount *parent)
    : QDBusAbstractAdaptor(parent)
{
    // constructor
    setAutoRelaySignals(true);
}

MountAdaptor::~MountAdaptor()
{
    // destructor
}

QList<double> MountAdaptor::altitudeLimits() const
{
    // get the value of property altitudeLimits
    return qvariant_cast< QList<double> >(parent()->property("altitudeLimits"));
}

void MountAdaptor::setAltitudeLimits(const QList<double> &value)
{
    // set the value of property altitudeLimits
    parent()->setProperty("altitudeLimits", QVariant::fromValue(value));
}

bool MountAdaptor::altitudeLimitsEnabled() const
{
    // get the value of property altitudeLimitsEnabled
    return qvariant_cast< bool >(parent()->property("altitudeLimitsEnabled"));
}

void MountAdaptor::setAltitudeLimitsEnabled(bool value)
{
    // set the value of property altitudeLimitsEnabled
    parent()->setProperty("altitudeLimitsEnabled", QVariant::fromValue(value));
}

bool MountAdaptor::canPark() const
{
    // get the value of property canPark
    return qvariant_cast< bool >(parent()->property("canPark"));
}

QList<double> MountAdaptor::equatorialCoords() const
{
    // get the value of property equatorialCoords
    return qvariant_cast< QList<double> >(parent()->property("equatorialCoords"));
}

QList<double> MountAdaptor::horizontalCoords() const
{
    // get the value of property horizontalCoords
    return qvariant_cast< QList<double> >(parent()->property("horizontalCoords"));
}

double MountAdaptor::hourAngle() const
{
    // get the value of property hourAngle
    return qvariant_cast< double >(parent()->property("hourAngle"));
}

double MountAdaptor::hourAngleLimit() const
{
    // get the value of property hourAngleLimit
    return qvariant_cast< double >(parent()->property("hourAngleLimit"));
}

void MountAdaptor::setHourAngleLimit(double value)
{
    // set the value of property hourAngleLimit
    parent()->setProperty("hourAngleLimit", QVariant::fromValue(value));
}

bool MountAdaptor::hourAngleLimitEnabled() const
{
    // get the value of property hourAngleLimitEnabled
    return qvariant_cast< bool >(parent()->property("hourAngleLimitEnabled"));
}

void MountAdaptor::setHourAngleLimitEnabled(bool value)
{
    // set the value of property hourAngleLimitEnabled
    parent()->setProperty("hourAngleLimitEnabled", QVariant::fromValue(value));
}

QStringList MountAdaptor::logText() const
{
    // get the value of property logText
    return qvariant_cast< QStringList >(parent()->property("logText"));
}

QString MountAdaptor::opticalTrain() const
{
    // get the value of property opticalTrain
    return qvariant_cast< QString >(parent()->property("opticalTrain"));
}

void MountAdaptor::setOpticalTrain(const QString &value)
{
    // set the value of property opticalTrain
    parent()->setProperty("opticalTrain", QVariant::fromValue(value));
}

int MountAdaptor::parkStatus() const
{
    // get the value of property parkStatus
    return qvariant_cast< int >(parent()->property("parkStatus"));
}

int MountAdaptor::pierSide() const
{
    // get the value of property pierSide
    return qvariant_cast< int >(parent()->property("pierSide"));
}

int MountAdaptor::slewRate() const
{
    // get the value of property slewRate
    return qvariant_cast< int >(parent()->property("slewRate"));
}

void MountAdaptor::setSlewRate(int value)
{
    // set the value of property slewRate
    parent()->setProperty("slewRate", QVariant::fromValue(value));
}

int MountAdaptor::slewStatus() const
{
    // get the value of property slewStatus
    return qvariant_cast< int >(parent()->property("slewStatus"));
}

int MountAdaptor::status() const
{
    // get the value of property status
    return qvariant_cast< int >(parent()->property("status"));
}

bool MountAdaptor::abort()
{
    // handle method call org.kde.kstars.Ekos.Mount.abort
    return parent()->abort();
}

bool MountAdaptor::gotoTarget(const QString &target)
{
    // handle method call org.kde.kstars.Ekos.Mount.gotoTarget
    return parent()->gotoTarget(target);
}

bool MountAdaptor::park()
{
    // handle method call org.kde.kstars.Ekos.Mount.park
    return parent()->park();
}

bool MountAdaptor::resetModel()
{
    // handle method call org.kde.kstars.Ekos.Mount.resetModel
    return parent()->resetModel();
}

void MountAdaptor::setMeridianFlipValues(bool activate, double hours)
{
    // handle method call org.kde.kstars.Ekos.Mount.setMeridianFlipValues
    parent()->setMeridianFlipValues(activate, hours);
}

bool MountAdaptor::slew(double RA, double DEC)
{
    // handle method call org.kde.kstars.Ekos.Mount.slew
    return parent()->slew(RA, DEC);
}

bool MountAdaptor::sync(double RA, double DEC)
{
    // handle method call org.kde.kstars.Ekos.Mount.sync
    return parent()->sync(RA, DEC);
}

bool MountAdaptor::syncTarget(const QString &target)
{
    // handle method call org.kde.kstars.Ekos.Mount.syncTarget
    return parent()->syncTarget(target);
}

bool MountAdaptor::unpark()
{
    // handle method call org.kde.kstars.Ekos.Mount.unpark
    return parent()->unpark();
}


#include "moc_mountadaptor.cpp"
