/****************************************************************************
** Meta object code from reading C++ file 'indidustcap.h'
**
** Created by: The Qt Meta Object Compiler version 69 (Qt 6.11.1)
**
** WARNING! All changes made in this file will be lost!
*****************************************************************************/

#include "../../../../kstars-3.8.4.1/kstars/indi/indidustcap.h"
#include <QtCore/qmetatype.h>

#include <QtCore/qtmochelpers.h>

#include <memory>


#include <QtCore/qxptype_traits.h>
#if !defined(Q_MOC_OUTPUT_REVISION)
#error "The header file 'indidustcap.h' doesn't include <QObject>."
#elif Q_MOC_OUTPUT_REVISION != 69
#error "This file was generated using the moc from 6.11.1. It"
#error "cannot be used with the include files from this version of Qt."
#error "(The moc has changed too much.)"
#endif

#ifndef Q_CONSTINIT
#define Q_CONSTINIT
#endif

QT_WARNING_PUSH
QT_WARNING_DISABLE_DEPRECATED
QT_WARNING_DISABLE_GCC("-Wuseless-cast")
namespace {
struct qt_meta_tag_ZN3ISD7DustCapE_t {};
} // unnamed namespace

template <> constexpr inline auto ISD::DustCap::qt_create_metaobjectdata<qt_meta_tag_ZN3ISD7DustCapE_t>()
{
    namespace QMC = QtMocConstants;
    QtMocHelpers::StringRefStorage qt_stringData {
        "ISD::DustCap",
        "D-Bus Interface",
        "org.kde.kstars.INDI.DustCap",
        "newStatus",
        "",
        "ISD::DustCap::Status",
        "status",
        "newParkStatus",
        "ISD::ParkStatus",
        "park",
        "unpark",
        "Status",
        "parkStatus",
        "canPark",
        "isParked",
        "isUnParked"
    };

    QtMocHelpers::UintData qt_methods {
        // Signal 'newStatus'
        QtMocHelpers::SignalData<void(ISD::DustCap::Status)>(3, 4, QMC::AccessPublic, QMetaType::Void, {{
            { 0x80000000 | 5, 6 },
        }}),
        // Signal 'newParkStatus'
        QtMocHelpers::SignalData<void(ISD::ParkStatus)>(7, 4, QMC::AccessPublic, QMetaType::Void, {{
            { 0x80000000 | 8, 6 },
        }}),
        // Slot 'park'
        QtMocHelpers::SlotData<bool()>(9, 4, QMC::AccessPublic | QMC::MethodScriptable, QMetaType::Bool),
        // Slot 'unpark'
        QtMocHelpers::SlotData<bool()>(10, 4, QMC::AccessPublic | QMC::MethodScriptable, QMetaType::Bool),
        // Slot 'status'
        QtMocHelpers::SlotData<Status()>(6, 4, QMC::AccessPublic | QMC::MethodScriptable, 0x80000000 | 11),
        // Slot 'parkStatus'
        QtMocHelpers::SlotData<ISD::ParkStatus() const>(12, 4, QMC::AccessPublic, 0x80000000 | 8),
        // Method 'canPark'
        QtMocHelpers::MethodData<bool()>(13, 4, QMC::AccessPublic | QMC::MethodScriptable, QMetaType::Bool),
        // Method 'isParked'
        QtMocHelpers::MethodData<bool()>(14, 4, QMC::AccessPublic | QMC::MethodScriptable, QMetaType::Bool),
        // Method 'isUnParked'
        QtMocHelpers::MethodData<bool()>(15, 4, QMC::AccessPublic | QMC::MethodScriptable, QMetaType::Bool),
    };
    QtMocHelpers::UintData qt_properties {
        // property 'status'
        QtMocHelpers::PropertyData<ISD::DustCap::Status>(6, 0x80000000 | 5, QMC::DefaultPropertyFlags | QMC::EnumOrFlag, 0),
        // property 'parkStatus'
        QtMocHelpers::PropertyData<ISD::ParkStatus>(12, 0x80000000 | 8, QMC::DefaultPropertyFlags | QMC::EnumOrFlag, 1),
        // property 'canPark'
        QtMocHelpers::PropertyData<bool>(13, QMetaType::Bool, QMC::DefaultPropertyFlags),
    };
    QtMocHelpers::UintData qt_enums {
    };
    QtMocHelpers::UintData qt_constructors {};
    QtMocHelpers::ClassInfos qt_classinfo({
            {    1,    2 },
    });
    return QtMocHelpers::metaObjectData<DustCap, qt_meta_tag_ZN3ISD7DustCapE_t>(QMC::MetaObjectFlag{}, qt_stringData,
            qt_methods, qt_properties, qt_enums, qt_constructors, qt_classinfo);
}
Q_CONSTINIT const QMetaObject ISD::DustCap::staticMetaObject = { {
    QMetaObject::SuperData::link<ConcreteDevice::staticMetaObject>(),
    qt_staticMetaObjectStaticContent<qt_meta_tag_ZN3ISD7DustCapE_t>.stringdata,
    qt_staticMetaObjectStaticContent<qt_meta_tag_ZN3ISD7DustCapE_t>.data,
    qt_static_metacall,
    nullptr,
    qt_staticMetaObjectRelocatingContent<qt_meta_tag_ZN3ISD7DustCapE_t>.metaTypes,
    nullptr
} };

void ISD::DustCap::qt_static_metacall(QObject *_o, QMetaObject::Call _c, int _id, void **_a)
{
    auto *_t = static_cast<DustCap *>(_o);
    if (_c == QMetaObject::InvokeMetaMethod) {
        switch (_id) {
        case 0: _t->newStatus((*reinterpret_cast<std::add_pointer_t<ISD::DustCap::Status>>(_a[1]))); break;
        case 1: _t->newParkStatus((*reinterpret_cast<std::add_pointer_t<ISD::ParkStatus>>(_a[1]))); break;
        case 2: { bool _r = _t->park();
            if (_a[0]) *reinterpret_cast<bool*>(_a[0]) = std::move(_r); }  break;
        case 3: { bool _r = _t->unpark();
            if (_a[0]) *reinterpret_cast<bool*>(_a[0]) = std::move(_r); }  break;
        case 4: { Status _r = _t->status();
            if (_a[0]) *reinterpret_cast<Status*>(_a[0]) = std::move(_r); }  break;
        case 5: { ISD::ParkStatus _r = _t->parkStatus();
            if (_a[0]) *reinterpret_cast<ISD::ParkStatus*>(_a[0]) = std::move(_r); }  break;
        case 6: { bool _r = _t->canPark();
            if (_a[0]) *reinterpret_cast<bool*>(_a[0]) = std::move(_r); }  break;
        case 7: { bool _r = _t->isParked();
            if (_a[0]) *reinterpret_cast<bool*>(_a[0]) = std::move(_r); }  break;
        case 8: { bool _r = _t->isUnParked();
            if (_a[0]) *reinterpret_cast<bool*>(_a[0]) = std::move(_r); }  break;
        default: ;
        }
    }
    if (_c == QMetaObject::RegisterMethodArgumentMetaType) {
        switch (_id) {
        default: *reinterpret_cast<QMetaType *>(_a[0]) = QMetaType(); break;
        case 0:
            switch (*reinterpret_cast<int*>(_a[1])) {
            default: *reinterpret_cast<QMetaType *>(_a[0]) = QMetaType(); break;
            case 0:
                *reinterpret_cast<QMetaType *>(_a[0]) = QMetaType::fromType< ISD::DustCap::Status >(); break;
            }
            break;
        case 1:
            switch (*reinterpret_cast<int*>(_a[1])) {
            default: *reinterpret_cast<QMetaType *>(_a[0]) = QMetaType(); break;
            case 0:
                *reinterpret_cast<QMetaType *>(_a[0]) = QMetaType::fromType< ISD::ParkStatus >(); break;
            }
            break;
        }
    }
    if (_c == QMetaObject::IndexOfMethod) {
        if (QtMocHelpers::indexOfMethod<void (DustCap::*)(ISD::DustCap::Status )>(_a, &DustCap::newStatus, 0))
            return;
        if (QtMocHelpers::indexOfMethod<void (DustCap::*)(ISD::ParkStatus )>(_a, &DustCap::newParkStatus, 1))
            return;
    }
    if (_c == QMetaObject::RegisterPropertyMetaType) {
        switch (_id) {
        default: *reinterpret_cast<int*>(_a[0]) = -1; break;
        case 0:
            *reinterpret_cast<int*>(_a[0]) = qRegisterMetaType< ISD::DustCap::Status >(); break;
        case 1:
            *reinterpret_cast<int*>(_a[0]) = qRegisterMetaType< ISD::ParkStatus >(); break;
        }
    }
    if (_c == QMetaObject::ReadProperty) {
        void *_v = _a[0];
        switch (_id) {
        case 0: *reinterpret_cast<ISD::DustCap::Status*>(_v) = _t->status(); break;
        case 1: *reinterpret_cast<ISD::ParkStatus*>(_v) = _t->parkStatus(); break;
        case 2: *reinterpret_cast<bool*>(_v) = _t->canPark(); break;
        default: break;
        }
    }
}

const QMetaObject *ISD::DustCap::metaObject() const
{
    return QObject::d_ptr->metaObject ? QObject::d_ptr->dynamicMetaObject() : &staticMetaObject;
}

void *ISD::DustCap::qt_metacast(const char *_clname)
{
    if (!_clname) return nullptr;
    if (!strcmp(_clname, qt_staticMetaObjectStaticContent<qt_meta_tag_ZN3ISD7DustCapE_t>.strings))
        return static_cast<void*>(this);
    return ConcreteDevice::qt_metacast(_clname);
}

int ISD::DustCap::qt_metacall(QMetaObject::Call _c, int _id, void **_a)
{
    _id = ConcreteDevice::qt_metacall(_c, _id, _a);
    if (_id < 0)
        return _id;
    if (_c == QMetaObject::InvokeMetaMethod) {
        if (_id < 9)
            qt_static_metacall(this, _c, _id, _a);
        _id -= 9;
    }
    if (_c == QMetaObject::RegisterMethodArgumentMetaType) {
        if (_id < 9)
            qt_static_metacall(this, _c, _id, _a);
        _id -= 9;
    }
    if (_c == QMetaObject::ReadProperty || _c == QMetaObject::WriteProperty
            || _c == QMetaObject::ResetProperty || _c == QMetaObject::BindableProperty
            || _c == QMetaObject::RegisterPropertyMetaType) {
        qt_static_metacall(this, _c, _id, _a);
        _id -= 3;
    }
    return _id;
}

// SIGNAL 0
void ISD::DustCap::newStatus(ISD::DustCap::Status _t1)
{
    QMetaObject::activate<void>(this, &staticMetaObject, 0, nullptr, _t1);
}

// SIGNAL 1
void ISD::DustCap::newParkStatus(ISD::ParkStatus _t1)
{
    QMetaObject::activate<void>(this, &staticMetaObject, 1, nullptr, _t1);
}
QT_WARNING_POP
