/********************************************************************************
** Form generated from reading UI file 'guidemanager.ui'
**
** Created by: Qt User Interface Compiler version 6.11.1
**
** WARNING! All changes made in this file will be lost when recompiling UI file!
********************************************************************************/

#ifndef UI_GUIDEMANAGER_H
#define UI_GUIDEMANAGER_H

#include <QtCore/QVariant>
#include <QtWidgets/QApplication>
#include <QtWidgets/QHBoxLayout>
#include <QtWidgets/QLabel>
#include <QtWidgets/QPushButton>
#include <QtWidgets/QSpacerItem>
#include <QtWidgets/QStackedWidget>
#include <QtWidgets/QVBoxLayout>
#include <QtWidgets/QWidget>
#include <klocalizedstring.h>
#include "ekos/guide/guidedriftgraph.h"
#include "ekos/guide/guidetargetplot.h"

QT_BEGIN_NAMESPACE

class Ui_GuideManager
{
public:
    QVBoxLayout *guideManagerLayout;
    QHBoxLayout *guideStatusLayout;
    QVBoxLayout *guideHeaderLayout;
    QHBoxLayout *guideTitleLayout;
    QLabel *label_12;
    QLabel *guideStatus;
    QSpacerItem *horizontalSpacer_6;
    QHBoxLayout *guideDataLayout;
    QLabel *label_15;
    QLabel *errRMS;
    QLabel *label_11;
    QLabel *errRA;
    QLabel *label_14;
    QLabel *errDEC;
    QSpacerItem *horizontalSpacer;
    QHBoxLayout *guideGraphsLayout;
    QPushButton *guideDetailPrevButton;
    QStackedWidget *guideDetailWidget;
    GuideDriftGraph *driftGraph;
    GuideTargetPlot *targetPlot;
    QWidget *guideStarPage;
    QHBoxLayout *horizontalLayout;
    QLabel *guideStarView;
    QPushButton *guideDetailNextButton;

    void setupUi(QWidget *GuideManager)
    {
        if (GuideManager->objectName().isEmpty())
            GuideManager->setObjectName("GuideManager");
        GuideManager->setEnabled(false);
        GuideManager->resize(284, 200);
        QSizePolicy sizePolicy(QSizePolicy::Policy::MinimumExpanding, QSizePolicy::Policy::MinimumExpanding);
        sizePolicy.setHorizontalStretch(0);
        sizePolicy.setVerticalStretch(0);
        sizePolicy.setHeightForWidth(GuideManager->sizePolicy().hasHeightForWidth());
        GuideManager->setSizePolicy(sizePolicy);
        GuideManager->setMinimumSize(QSize(200, 200));
        GuideManager->setMaximumSize(QSize(16777215, 16777215));
        GuideManager->setBaseSize(QSize(0, 0));
        guideManagerLayout = new QVBoxLayout(GuideManager);
        guideManagerLayout->setSpacing(0);
        guideManagerLayout->setObjectName("guideManagerLayout");
        guideManagerLayout->setContentsMargins(0, 4, 0, 4);
        guideStatusLayout = new QHBoxLayout();
        guideStatusLayout->setSpacing(1);
        guideStatusLayout->setObjectName("guideStatusLayout");
        guideHeaderLayout = new QVBoxLayout();
        guideHeaderLayout->setSpacing(0);
        guideHeaderLayout->setObjectName("guideHeaderLayout");
        guideHeaderLayout->setContentsMargins(-1, -1, -1, 4);
        guideTitleLayout = new QHBoxLayout();
        guideTitleLayout->setObjectName("guideTitleLayout");
        label_12 = new QLabel(GuideManager);
        label_12->setObjectName("label_12");
        label_12->setMinimumSize(QSize(0, 20));
        label_12->setMaximumSize(QSize(16777215, 20));
        label_12->setStyleSheet(QString::fromUtf8("font-weight:bold;"));
        label_12->setMargin(1);

        guideTitleLayout->addWidget(label_12);

        guideStatus = new QLabel(GuideManager);
        guideStatus->setObjectName("guideStatus");
        guideStatus->setMinimumSize(QSize(0, 20));
        guideStatus->setMaximumSize(QSize(16777215, 20));
        guideStatus->setStyleSheet(QString::fromUtf8(""));
        guideStatus->setTextFormat(Qt::AutoText);
        guideStatus->setMargin(1);

        guideTitleLayout->addWidget(guideStatus);

        horizontalSpacer_6 = new QSpacerItem(1, 20, QSizePolicy::Policy::Minimum, QSizePolicy::Policy::Minimum);

        guideTitleLayout->addItem(horizontalSpacer_6);

        guideTitleLayout->setStretch(2, 1);

        guideHeaderLayout->addLayout(guideTitleLayout);

        guideDataLayout = new QHBoxLayout();
        guideDataLayout->setSpacing(0);
        guideDataLayout->setObjectName("guideDataLayout");
        label_15 = new QLabel(GuideManager);
        label_15->setObjectName("label_15");
        label_15->setMinimumSize(QSize(30, 24));
        label_15->setMaximumSize(QSize(250, 24));
        label_15->setMouseTracking(true);
        label_15->setLayoutDirection(Qt::RightToLeft);
        label_15->setAutoFillBackground(false);
        label_15->setTextFormat(Qt::RichText);
        label_15->setMargin(1);

        guideDataLayout->addWidget(label_15);

        errRMS = new QLabel(GuideManager);
        errRMS->setObjectName("errRMS");
        errRMS->setMinimumSize(QSize(30, 24));
        errRMS->setMaximumSize(QSize(250, 24));
        errRMS->setLayoutDirection(Qt::LeftToRight);
        errRMS->setAutoFillBackground(false);
        errRMS->setTextFormat(Qt::RichText);
        errRMS->setMargin(1);

        guideDataLayout->addWidget(errRMS);

        label_11 = new QLabel(GuideManager);
        label_11->setObjectName("label_11");
        label_11->setMinimumSize(QSize(0, 24));
        label_11->setMaximumSize(QSize(250, 24));
        label_11->setLayoutDirection(Qt::RightToLeft);
        label_11->setTextFormat(Qt::RichText);
        label_11->setAlignment(Qt::AlignLeading|Qt::AlignLeft|Qt::AlignVCenter);
        label_11->setMargin(1);

        guideDataLayout->addWidget(label_11);

        errRA = new QLabel(GuideManager);
        errRA->setObjectName("errRA");
        QSizePolicy sizePolicy1(QSizePolicy::Policy::Preferred, QSizePolicy::Policy::Preferred);
        sizePolicy1.setHorizontalStretch(0);
        sizePolicy1.setVerticalStretch(0);
        sizePolicy1.setHeightForWidth(errRA->sizePolicy().hasHeightForWidth());
        errRA->setSizePolicy(sizePolicy1);
        errRA->setMinimumSize(QSize(30, 24));
        errRA->setMaximumSize(QSize(250, 24));
        errRA->setLayoutDirection(Qt::LeftToRight);
        errRA->setAutoFillBackground(false);
        errRA->setTextFormat(Qt::RichText);
        errRA->setAlignment(Qt::AlignLeading|Qt::AlignLeft|Qt::AlignVCenter);
        errRA->setMargin(1);

        guideDataLayout->addWidget(errRA);

        label_14 = new QLabel(GuideManager);
        label_14->setObjectName("label_14");
        label_14->setMinimumSize(QSize(30, 24));
        label_14->setMaximumSize(QSize(250, 24));
        label_14->setLayoutDirection(Qt::RightToLeft);
        label_14->setTextFormat(Qt::RichText);
        label_14->setAlignment(Qt::AlignLeading|Qt::AlignLeft|Qt::AlignVCenter);
        label_14->setMargin(1);

        guideDataLayout->addWidget(label_14);

        errDEC = new QLabel(GuideManager);
        errDEC->setObjectName("errDEC");
        sizePolicy1.setHeightForWidth(errDEC->sizePolicy().hasHeightForWidth());
        errDEC->setSizePolicy(sizePolicy1);
        errDEC->setMinimumSize(QSize(30, 24));
        errDEC->setMaximumSize(QSize(250, 24));
        errDEC->setLayoutDirection(Qt::LeftToRight);
        errDEC->setAutoFillBackground(false);
        errDEC->setTextFormat(Qt::RichText);
        errDEC->setAlignment(Qt::AlignLeading|Qt::AlignLeft|Qt::AlignVCenter);
        errDEC->setMargin(1);

        guideDataLayout->addWidget(errDEC);

        horizontalSpacer = new QSpacerItem(40, 24, QSizePolicy::Policy::Expanding, QSizePolicy::Policy::Minimum);

        guideDataLayout->addItem(horizontalSpacer);


        guideHeaderLayout->addLayout(guideDataLayout);


        guideStatusLayout->addLayout(guideHeaderLayout);


        guideManagerLayout->addLayout(guideStatusLayout);

        guideGraphsLayout = new QHBoxLayout();
        guideGraphsLayout->setSpacing(0);
        guideGraphsLayout->setObjectName("guideGraphsLayout");
        guideDetailPrevButton = new QPushButton(GuideManager);
        guideDetailPrevButton->setObjectName("guideDetailPrevButton");
        sizePolicy1.setHeightForWidth(guideDetailPrevButton->sizePolicy().hasHeightForWidth());
        guideDetailPrevButton->setSizePolicy(sizePolicy1);
        guideDetailPrevButton->setMinimumSize(QSize(20, 0));
        guideDetailPrevButton->setMaximumSize(QSize(20, 16777215));
        QFont font;
        font.setPointSize(16);
        font.setBold(true);
        guideDetailPrevButton->setFont(font);

        guideGraphsLayout->addWidget(guideDetailPrevButton);

        guideDetailWidget = new QStackedWidget(GuideManager);
        guideDetailWidget->setObjectName("guideDetailWidget");
        driftGraph = new GuideDriftGraph();
        driftGraph->setObjectName("driftGraph");
        driftGraph->setStyleSheet(QString::fromUtf8("background-color: qlineargradient(x1:0, y1:0, x2:0, y2:0.5,\n"
"                                      stop:0 darkgray, stop:1 black);"));
        guideDetailWidget->addWidget(driftGraph);
        targetPlot = new GuideTargetPlot();
        targetPlot->setObjectName("targetPlot");
        guideDetailWidget->addWidget(targetPlot);
        guideStarPage = new QWidget();
        guideStarPage->setObjectName("guideStarPage");
        sizePolicy1.setHeightForWidth(guideStarPage->sizePolicy().hasHeightForWidth());
        guideStarPage->setSizePolicy(sizePolicy1);
        horizontalLayout = new QHBoxLayout(guideStarPage);
        horizontalLayout->setSpacing(0);
        horizontalLayout->setObjectName("horizontalLayout");
        horizontalLayout->setContentsMargins(0, 0, 0, 0);
        guideStarView = new QLabel(guideStarPage);
        guideStarView->setObjectName("guideStarView");
        guideStarView->setStyleSheet(QString::fromUtf8("background-color: qlineargradient(x1:0, y1:0, x2:0, y2:0.5,\n"
"                                      stop:0 darkgray, stop:1 black);"));
        guideStarView->setAlignment(Qt::AlignCenter);

        horizontalLayout->addWidget(guideStarView);

        guideDetailWidget->addWidget(guideStarPage);

        guideGraphsLayout->addWidget(guideDetailWidget);

        guideDetailNextButton = new QPushButton(GuideManager);
        guideDetailNextButton->setObjectName("guideDetailNextButton");
        sizePolicy1.setHeightForWidth(guideDetailNextButton->sizePolicy().hasHeightForWidth());
        guideDetailNextButton->setSizePolicy(sizePolicy1);
        guideDetailNextButton->setMinimumSize(QSize(20, 0));
        guideDetailNextButton->setMaximumSize(QSize(20, 16777215));
        guideDetailNextButton->setFont(font);

        guideGraphsLayout->addWidget(guideDetailNextButton);

        guideGraphsLayout->setStretch(1, 1);

        guideManagerLayout->addLayout(guideGraphsLayout);

        guideManagerLayout->setStretch(1, 1);

        retranslateUi(GuideManager);

        guideDetailWidget->setCurrentIndex(0);


        QMetaObject::connectSlotsByName(GuideManager);
    } // setupUi

    void retranslateUi(QWidget *GuideManager)
    {
        GuideManager->setWindowTitle(tr2i18n("Ekos", nullptr));
        label_12->setText(tr2i18n("Guide: ", nullptr));
        guideStatus->setText(tr2i18n("Idle", nullptr));
        label_15->setText(tr2i18n("Total RMS: ", nullptr));
        errRMS->setText(QString());
        label_11->setText(tr2i18n(" \317\203RA: ", nullptr));
        errRA->setText(QString());
        label_14->setText(tr2i18n("\317\203DEC: ", nullptr));
        errDEC->setText(QString());
        guideDetailPrevButton->setText(tr2i18n("<", nullptr));
#if QT_CONFIG(tooltip)
        guideStarView->setToolTip(tr2i18n("Guide star", nullptr));
#endif // QT_CONFIG(tooltip)
        guideStarView->setText(tr2i18n("guide star", nullptr));
        guideDetailNextButton->setText(tr2i18n(">", nullptr));
    } // retranslateUi

};

namespace Ui {
    class GuideManager: public Ui_GuideManager {};
} // namespace Ui

QT_END_NAMESPACE

#endif // GUIDEMANAGER_H

