/********************************************************************************
** Form generated from reading UI file 'mountcontrolpanel.ui'
**
** Created by: Qt User Interface Compiler version 6.11.1
**
** WARNING! All changes made in this file will be lost when recompiling UI file!
********************************************************************************/

#ifndef UI_MOUNTCONTROLPANEL_H
#define UI_MOUNTCONTROLPANEL_H

#include <QtCore/QVariant>
#include <QtGui/QIcon>
#include <QtWidgets/QApplication>
#include <QtWidgets/QDialog>
#include <QtWidgets/QGridLayout>
#include <QtWidgets/QHBoxLayout>
#include <QtWidgets/QLabel>
#include <QtWidgets/QPushButton>
#include <QtWidgets/QSpacerItem>
#include <QtWidgets/QVBoxLayout>
#include <klocalizedstring.h>
#include "ekos/mount/mountmotionwidget.h"
#include "ekos/mount/mountpositionwidget.h"
#include "ekos/mount/mounttargetwidget.h"

QT_BEGIN_NAMESPACE

class Ui_MountControlPanel
{
public:
    QVBoxLayout *verticalLayout_2;
    Ekos::MountMotionWidget *mountMotion;
    Ekos::MountPositionWidget *mountPosition;
    QVBoxLayout *targetLayout;
    QLabel *label;
    Ekos::MountTargetWidget *mountTarget;
    QGridLayout *gridLayout_2;
    QPushButton *unparkButtonObject;
    QPushButton *parkButtonObject;
    QHBoxLayout *horizontalLayout_11;
    QLabel *statusTextObject;
    QSpacerItem *horizontalSpacer_4;
    QPushButton *centerButtonObject;

    void setupUi(QDialog *MountControlPanel)
    {
        if (MountControlPanel->objectName().isEmpty())
            MountControlPanel->setObjectName("MountControlPanel");
        MountControlPanel->resize(340, 326);
        MountControlPanel->setFocusPolicy(Qt::ClickFocus);
        verticalLayout_2 = new QVBoxLayout(MountControlPanel);
        verticalLayout_2->setSpacing(3);
        verticalLayout_2->setObjectName("verticalLayout_2");
        verticalLayout_2->setContentsMargins(3, 3, 3, 3);
        mountMotion = new Ekos::MountMotionWidget(MountControlPanel);
        mountMotion->setObjectName("mountMotion");

        verticalLayout_2->addWidget(mountMotion);

        mountPosition = new Ekos::MountPositionWidget(MountControlPanel);
        mountPosition->setObjectName("mountPosition");

        verticalLayout_2->addWidget(mountPosition);

        targetLayout = new QVBoxLayout();
        targetLayout->setSpacing(3);
        targetLayout->setObjectName("targetLayout");
        targetLayout->setContentsMargins(-1, 6, -1, -1);
        label = new QLabel(MountControlPanel);
        label->setObjectName("label");
        QFont font;
        font.setBold(true);
        label->setFont(font);

        targetLayout->addWidget(label);

        mountTarget = new Ekos::MountTargetWidget(MountControlPanel);
        mountTarget->setObjectName("mountTarget");

        targetLayout->addWidget(mountTarget);


        verticalLayout_2->addLayout(targetLayout);

        gridLayout_2 = new QGridLayout();
        gridLayout_2->setSpacing(3);
        gridLayout_2->setObjectName("gridLayout_2");
        unparkButtonObject = new QPushButton(MountControlPanel);
        unparkButtonObject->setObjectName("unparkButtonObject");

        gridLayout_2->addWidget(unparkButtonObject, 0, 1, 1, 1);

        parkButtonObject = new QPushButton(MountControlPanel);
        parkButtonObject->setObjectName("parkButtonObject");

        gridLayout_2->addWidget(parkButtonObject, 0, 0, 1, 1);


        verticalLayout_2->addLayout(gridLayout_2);

        horizontalLayout_11 = new QHBoxLayout();
        horizontalLayout_11->setSpacing(3);
        horizontalLayout_11->setObjectName("horizontalLayout_11");
        statusTextObject = new QLabel(MountControlPanel);
        statusTextObject->setObjectName("statusTextObject");
        QFont font1;
        font1.setPointSize(12);
        font1.setBold(true);
        statusTextObject->setFont(font1);

        horizontalLayout_11->addWidget(statusTextObject);

        horizontalSpacer_4 = new QSpacerItem(40, 20, QSizePolicy::Policy::Expanding, QSizePolicy::Policy::Minimum);

        horizontalLayout_11->addItem(horizontalSpacer_4);

        centerButtonObject = new QPushButton(MountControlPanel);
        centerButtonObject->setObjectName("centerButtonObject");
        centerButtonObject->setMinimumSize(QSize(32, 32));
        centerButtonObject->setMaximumSize(QSize(32, 32));
        QIcon icon;
        QString iconThemeName = QString::fromUtf8("zoom-fit-best");
        if (QIcon::hasThemeIcon(iconThemeName)) {
            icon = QIcon::fromTheme(iconThemeName);
        } else {
            icon.addFile(QString::fromUtf8("."), QSize(), QIcon::Mode::Normal, QIcon::State::Off);
        }
        centerButtonObject->setIcon(icon);
        centerButtonObject->setIconSize(QSize(28, 28));

        horizontalLayout_11->addWidget(centerButtonObject);


        verticalLayout_2->addLayout(horizontalLayout_11);


        retranslateUi(MountControlPanel);

        QMetaObject::connectSlotsByName(MountControlPanel);
    } // setupUi

    void retranslateUi(QDialog *MountControlPanel)
    {
        MountControlPanel->setWindowTitle(tr2i18n("Mount Control Panel", nullptr));
        label->setText(tr2i18n("Target", nullptr));
        unparkButtonObject->setText(tr2i18n("UNPARK", nullptr));
        parkButtonObject->setText(tr2i18n("PARK", nullptr));
        statusTextObject->setText(tr2i18n("Status: Idle", nullptr));
        centerButtonObject->setText(QString());
    } // retranslateUi

};

namespace Ui {
    class MountControlPanel: public Ui_MountControlPanel {};
} // namespace Ui

QT_END_NAMESPACE

#endif // MOUNTCONTROLPANEL_H

