/********************************************************************************
** Form generated from reading UI file 'pwizchartconfig.ui'
**
** Created by: Qt User Interface Compiler version 6.11.1
**
** WARNING! All changes made in this file will be lost when recompiling UI file!
********************************************************************************/

#ifndef UI_PWIZCHARTCONFIG_H
#define UI_PWIZCHARTCONFIG_H

#include <QtCore/QVariant>
#include <QtWidgets/QApplication>
#include <QtWidgets/QGridLayout>
#include <QtWidgets/QHBoxLayout>
#include <QtWidgets/QLabel>
#include <QtWidgets/QLineEdit>
#include <QtWidgets/QPlainTextEdit>
#include <QtWidgets/QSpacerItem>
#include <QtWidgets/QVBoxLayout>
#include <QtWidgets/QWidget>
#include <klocalizedstring.h>

QT_BEGIN_NAMESPACE

class Ui_PWizChartConfig
{
public:
    QHBoxLayout *horizontalLayout;
    QLabel *banner;
    QSpacerItem *horizontalSpacer;
    QVBoxLayout *contentsLayout;
    QLabel *stepTitle;
    QSpacerItem *vertSpacer1;
    QLabel *stepText;
    QSpacerItem *verticalSpacer;
    QGridLayout *gridLayout;
    QLabel *titleLabel;
    QLineEdit *titleEdit;
    QLineEdit *subtitleEdit;
    QLabel *subtitleLabel;
    QLabel *descriptionLabel;
    QPlainTextEdit *descriptionTextEdit;
    QSpacerItem *verticalSpacer_2;

    void setupUi(QWidget *PWizChartConfig)
    {
        if (PWizChartConfig->objectName().isEmpty())
            PWizChartConfig->setObjectName("PWizChartConfig");
        PWizChartConfig->resize(586, 395);
        QSizePolicy sizePolicy(QSizePolicy::Policy::Minimum, QSizePolicy::Policy::Minimum);
        sizePolicy.setHorizontalStretch(0);
        sizePolicy.setVerticalStretch(0);
        sizePolicy.setHeightForWidth(PWizChartConfig->sizePolicy().hasHeightForWidth());
        PWizChartConfig->setSizePolicy(sizePolicy);
        PWizChartConfig->setMinimumSize(QSize(586, 395));
        horizontalLayout = new QHBoxLayout(PWizChartConfig);
        horizontalLayout->setObjectName("horizontalLayout");
        banner = new QLabel(PWizChartConfig);
        banner->setObjectName("banner");
        QSizePolicy sizePolicy1(QSizePolicy::Policy::Fixed, QSizePolicy::Policy::Fixed);
        sizePolicy1.setHorizontalStretch(0);
        sizePolicy1.setVerticalStretch(0);
        sizePolicy1.setHeightForWidth(banner->sizePolicy().hasHeightForWidth());
        banner->setSizePolicy(sizePolicy1);
        banner->setMinimumSize(QSize(120, 360));

        horizontalLayout->addWidget(banner);

        horizontalSpacer = new QSpacerItem(5, 20, QSizePolicy::Policy::Fixed, QSizePolicy::Policy::Minimum);

        horizontalLayout->addItem(horizontalSpacer);

        contentsLayout = new QVBoxLayout();
#ifndef UI_Q_OS_MAC
        contentsLayout->setSpacing(6);
#endif
        contentsLayout->setContentsMargins(0, 0, 0, 0);
        contentsLayout->setObjectName("contentsLayout");
        contentsLayout->setSizeConstraint(QLayout::SetMinimumSize);
        stepTitle = new QLabel(PWizChartConfig);
        stepTitle->setObjectName("stepTitle");
        QFont font;
        font.setFamilies({QString::fromUtf8("Sans Serif")});
        font.setPointSize(11);
        font.setBold(true);
        font.setItalic(false);
        font.setUnderline(false);
        font.setStrikeOut(false);
        stepTitle->setFont(font);

        contentsLayout->addWidget(stepTitle);

        vertSpacer1 = new QSpacerItem(20, 12, QSizePolicy::Policy::Minimum, QSizePolicy::Policy::Fixed);

        contentsLayout->addItem(vertSpacer1);

        stepText = new QLabel(PWizChartConfig);
        stepText->setObjectName("stepText");
        stepText->setWordWrap(true);

        contentsLayout->addWidget(stepText);

        verticalSpacer = new QSpacerItem(20, 12, QSizePolicy::Policy::Minimum, QSizePolicy::Policy::Fixed);

        contentsLayout->addItem(verticalSpacer);

        gridLayout = new QGridLayout();
        gridLayout->setObjectName("gridLayout");
        gridLayout->setSizeConstraint(QLayout::SetMinimumSize);
        titleLabel = new QLabel(PWizChartConfig);
        titleLabel->setObjectName("titleLabel");

        gridLayout->addWidget(titleLabel, 0, 0, 1, 1);

        titleEdit = new QLineEdit(PWizChartConfig);
        titleEdit->setObjectName("titleEdit");

        gridLayout->addWidget(titleEdit, 0, 1, 1, 1);

        subtitleEdit = new QLineEdit(PWizChartConfig);
        subtitleEdit->setObjectName("subtitleEdit");

        gridLayout->addWidget(subtitleEdit, 1, 1, 1, 1);

        subtitleLabel = new QLabel(PWizChartConfig);
        subtitleLabel->setObjectName("subtitleLabel");

        gridLayout->addWidget(subtitleLabel, 1, 0, 1, 1);

        descriptionLabel = new QLabel(PWizChartConfig);
        descriptionLabel->setObjectName("descriptionLabel");

        gridLayout->addWidget(descriptionLabel, 2, 0, 1, 1);

        descriptionTextEdit = new QPlainTextEdit(PWizChartConfig);
        descriptionTextEdit->setObjectName("descriptionTextEdit");

        gridLayout->addWidget(descriptionTextEdit, 2, 1, 1, 1);

        verticalSpacer_2 = new QSpacerItem(20, 12, QSizePolicy::Policy::Minimum, QSizePolicy::Policy::Fixed);

        gridLayout->addItem(verticalSpacer_2, 3, 1, 1, 1);


        contentsLayout->addLayout(gridLayout);


        horizontalLayout->addLayout(contentsLayout);


        retranslateUi(PWizChartConfig);

        QMetaObject::connectSlotsByName(PWizChartConfig);
    } // setupUi

    void retranslateUi(QWidget *PWizChartConfig)
    {
        banner->setText(QString());
        stepTitle->setText(tr2i18n("Basic Finder Chart Settings", nullptr));
        stepText->setText(tr2i18n("<p>Set basic document details: title, subtitle and description.</p>\n"
"<p>When done, press <b>Next</b> button.</p>", nullptr));
        titleLabel->setText(tr2i18n("Title:", nullptr));
        subtitleLabel->setText(tr2i18n("Subtitle:", nullptr));
        descriptionLabel->setText(tr2i18n("Description:", nullptr));
        (void)PWizChartConfig;
    } // retranslateUi

};

namespace Ui {
    class PWizChartConfig: public Ui_PWizChartConfig {};
} // namespace Ui

QT_END_NAMESPACE

#endif // PWIZCHARTCONFIG_H

