/********************************************************************************
** Form generated from reading UI file 'catalogeditform.ui'
**
** Created by: Qt User Interface Compiler version 6.11.1
**
** WARNING! All changes made in this file will be lost when recompiling UI file!
********************************************************************************/

#ifndef UI_CATALOGEDITFORM_H
#define UI_CATALOGEDITFORM_H

#include <QtCore/QVariant>
#include <QtWidgets/QAbstractButton>
#include <QtWidgets/QApplication>
#include <QtWidgets/QDialog>
#include <QtWidgets/QDialogButtonBox>
#include <QtWidgets/QFormLayout>
#include <QtWidgets/QLabel>
#include <QtWidgets/QLineEdit>
#include <QtWidgets/QPushButton>
#include <QtWidgets/QSpinBox>
#include <QtWidgets/QTextEdit>
#include <QtWidgets/QVBoxLayout>
#include <klocalizedstring.h>

QT_BEGIN_NAMESPACE

class Ui_CatalogEditForm
{
public:
    QVBoxLayout *verticalLayout;
    QFormLayout *formLayout;
    QLabel *label;
    QSpinBox *id;
    QLabel *label_2;
    QLabel *label_4;
    QLabel *label_5;
    QLabel *label_6;
    QLineEdit *name;
    QLineEdit *author;
    QLineEdit *source;
    QTextEdit *description;
    QLabel *label_3;
    QPushButton *color;
    QLabel *label_7;
    QLineEdit *maintainer;
    QLabel *label_8;
    QLineEdit *license;
    QDialogButtonBox *buttonBox;

    void setupUi(QDialog *CatalogsUInewCatalog)
    {
        if (CatalogsUInewCatalog->objectName().isEmpty())
            CatalogsUInewCatalog->setObjectName("CatalogsUInewCatalog");
        CatalogsUInewCatalog->resize(400, 300);
        verticalLayout = new QVBoxLayout(CatalogsUInewCatalog);
        verticalLayout->setObjectName("verticalLayout");
        formLayout = new QFormLayout();
        formLayout->setObjectName("formLayout");
        label = new QLabel(CatalogsUInewCatalog);
        label->setObjectName("label");

        formLayout->setWidget(0, QFormLayout::ItemRole::LabelRole, label);

        id = new QSpinBox(CatalogsUInewCatalog);
        id->setObjectName("id");
        id->setMinimum(1000);
        id->setMaximum(2000);

        formLayout->setWidget(0, QFormLayout::ItemRole::FieldRole, id);

        label_2 = new QLabel(CatalogsUInewCatalog);
        label_2->setObjectName("label_2");

        formLayout->setWidget(1, QFormLayout::ItemRole::LabelRole, label_2);

        label_4 = new QLabel(CatalogsUInewCatalog);
        label_4->setObjectName("label_4");

        formLayout->setWidget(2, QFormLayout::ItemRole::LabelRole, label_4);

        label_5 = new QLabel(CatalogsUInewCatalog);
        label_5->setObjectName("label_5");

        formLayout->setWidget(4, QFormLayout::ItemRole::LabelRole, label_5);

        label_6 = new QLabel(CatalogsUInewCatalog);
        label_6->setObjectName("label_6");

        formLayout->setWidget(7, QFormLayout::ItemRole::LabelRole, label_6);

        name = new QLineEdit(CatalogsUInewCatalog);
        name->setObjectName("name");

        formLayout->setWidget(1, QFormLayout::ItemRole::FieldRole, name);

        author = new QLineEdit(CatalogsUInewCatalog);
        author->setObjectName("author");

        formLayout->setWidget(2, QFormLayout::ItemRole::FieldRole, author);

        source = new QLineEdit(CatalogsUInewCatalog);
        source->setObjectName("source");

        formLayout->setWidget(4, QFormLayout::ItemRole::FieldRole, source);

        description = new QTextEdit(CatalogsUInewCatalog);
        description->setObjectName("description");

        formLayout->setWidget(7, QFormLayout::ItemRole::FieldRole, description);

        label_3 = new QLabel(CatalogsUInewCatalog);
        label_3->setObjectName("label_3");

        formLayout->setWidget(5, QFormLayout::ItemRole::LabelRole, label_3);

        color = new QPushButton(CatalogsUInewCatalog);
        color->setObjectName("color");

        formLayout->setWidget(5, QFormLayout::ItemRole::FieldRole, color);

        label_7 = new QLabel(CatalogsUInewCatalog);
        label_7->setObjectName("label_7");

        formLayout->setWidget(3, QFormLayout::ItemRole::LabelRole, label_7);

        maintainer = new QLineEdit(CatalogsUInewCatalog);
        maintainer->setObjectName("maintainer");

        formLayout->setWidget(3, QFormLayout::ItemRole::FieldRole, maintainer);

        label_8 = new QLabel(CatalogsUInewCatalog);
        label_8->setObjectName("label_8");

        formLayout->setWidget(6, QFormLayout::ItemRole::LabelRole, label_8);

        license = new QLineEdit(CatalogsUInewCatalog);
        license->setObjectName("license");

        formLayout->setWidget(6, QFormLayout::ItemRole::FieldRole, license);


        verticalLayout->addLayout(formLayout);

        buttonBox = new QDialogButtonBox(CatalogsUInewCatalog);
        buttonBox->setObjectName("buttonBox");
        buttonBox->setOrientation(Qt::Horizontal);
        buttonBox->setStandardButtons(QDialogButtonBox::Cancel|QDialogButtonBox::Ok);

        verticalLayout->addWidget(buttonBox);


        retranslateUi(CatalogsUInewCatalog);
        QObject::connect(buttonBox, &QDialogButtonBox::accepted, CatalogsUInewCatalog, qOverload<>(&QDialog::accept));
        QObject::connect(buttonBox, &QDialogButtonBox::rejected, CatalogsUInewCatalog, qOverload<>(&QDialog::reject));

        QMetaObject::connectSlotsByName(CatalogsUInewCatalog);
    } // setupUi

    void retranslateUi(QDialog *CatalogsUInewCatalog)
    {
        CatalogsUInewCatalog->setWindowTitle(tr2i18n("Create/Edit Catalog", nullptr));
        label->setText(tr2i18n("ID:", nullptr));
        label_2->setText(tr2i18n("Name:", nullptr));
        label_4->setText(tr2i18n("Author:", nullptr));
        label_5->setText(tr2i18n("Source:", nullptr));
        label_6->setText(tr2i18n("Description:", nullptr));
        label_3->setText(tr2i18n("Color:", nullptr));
        color->setText(tr2i18n("Edit", nullptr));
        label_7->setText(tr2i18n("Maintainer:", nullptr));
        label_8->setText(tr2i18n("License:", nullptr));
    } // retranslateUi

};

namespace Ui {
    class CatalogEditForm: public Ui_CatalogEditForm {};
} // namespace Ui

QT_END_NAMESPACE

#endif // CATALOGEDITFORM_H

