/****************************************************************************
** Meta object code from reading C++ file 'platesolve.h'
**
** Created by: The Qt Meta Object Compiler version 69 (Qt 6.11.1)
**
** WARNING! All changes made in this file will be lost!
*****************************************************************************/

#include "../../../../kstars-3.8.4.1/kstars/fitsviewer/platesolve.h"
#include <QtCore/qmetatype.h>
#include <QtCore/QSharedPointer>

#include <QtCore/qtmochelpers.h>

#include <memory>


#include <QtCore/qxptype_traits.h>
#if !defined(Q_MOC_OUTPUT_REVISION)
#error "The header file 'platesolve.h' doesn't include <QObject>."
#elif Q_MOC_OUTPUT_REVISION != 69
#error "This file was generated using the moc from 6.11.1. It"
#error "cannot be used with the include files from this version of Qt."
#error "(The moc has changed too much.)"
#endif

#ifndef Q_CONSTINIT
#define Q_CONSTINIT
#endif

QT_WARNING_PUSH
QT_WARNING_DISABLE_DEPRECATED
QT_WARNING_DISABLE_GCC("-Wuseless-cast")
namespace {
struct qt_meta_tag_ZN10PlateSolveE_t {};
} // unnamed namespace

template <> constexpr inline auto PlateSolve::qt_create_metaobjectdata<qt_meta_tag_ZN10PlateSolveE_t>()
{
    namespace QMC = QtMocConstants;
    QtMocHelpers::StringRefStorage qt_stringData {
        "PlateSolve",
        "clicked",
        "",
        "extractorSuccess",
        "subExtractorSuccess",
        "medianHFR",
        "numStars",
        "solverSuccess",
        "subSolverSuccess",
        "extractorFailed",
        "subExtractorFailed",
        "solverFailed",
        "subSolverFailed",
        "auxClicked",
        "extractImage",
        "QSharedPointer<FITSData>",
        "imageData",
        "solveImage",
        "filename",
        "plateSolveSub",
        "ra",
        "dec",
        "pixScale",
        "index",
        "healpix",
        "SSolver::ProcessType",
        "solveType"
    };

    QtMocHelpers::UintData qt_methods {
        // Signal 'clicked'
        QtMocHelpers::SignalData<void()>(1, 2, QMC::AccessPublic, QMetaType::Void),
        // Signal 'extractorSuccess'
        QtMocHelpers::SignalData<void()>(3, 2, QMC::AccessPublic, QMetaType::Void),
        // Signal 'subExtractorSuccess'
        QtMocHelpers::SignalData<void(const double, const int)>(4, 2, QMC::AccessPublic, QMetaType::Void, {{
            { QMetaType::Double, 5 }, { QMetaType::Int, 6 },
        }}),
        // Signal 'solverSuccess'
        QtMocHelpers::SignalData<void()>(7, 2, QMC::AccessPublic, QMetaType::Void),
        // Signal 'subSolverSuccess'
        QtMocHelpers::SignalData<void()>(8, 2, QMC::AccessPublic, QMetaType::Void),
        // Signal 'extractorFailed'
        QtMocHelpers::SignalData<void()>(9, 2, QMC::AccessPublic, QMetaType::Void),
        // Signal 'subExtractorFailed'
        QtMocHelpers::SignalData<void()>(10, 2, QMC::AccessPublic, QMetaType::Void),
        // Signal 'solverFailed'
        QtMocHelpers::SignalData<void()>(11, 2, QMC::AccessPublic, QMetaType::Void),
        // Signal 'subSolverFailed'
        QtMocHelpers::SignalData<void()>(12, 2, QMC::AccessPublic, QMetaType::Void),
        // Signal 'auxClicked'
        QtMocHelpers::SignalData<void()>(13, 2, QMC::AccessPublic, QMetaType::Void),
        // Slot 'extractImage'
        QtMocHelpers::SlotData<void(const QSharedPointer<FITSData> &)>(14, 2, QMC::AccessPublic, QMetaType::Void, {{
            { 0x80000000 | 15, 16 },
        }}),
        // Slot 'solveImage'
        QtMocHelpers::SlotData<void(const QSharedPointer<FITSData> &)>(17, 2, QMC::AccessPublic, QMetaType::Void, {{
            { 0x80000000 | 15, 16 },
        }}),
        // Slot 'solveImage'
        QtMocHelpers::SlotData<void(const QString &)>(17, 2, QMC::AccessPublic, QMetaType::Void, {{
            { QMetaType::QString, 18 },
        }}),
        // Slot 'plateSolveSub'
        QtMocHelpers::SlotData<void(const QSharedPointer<FITSData> &, const double, const double, const double, const int, const int, const SSolver::ProcessType)>(19, 2, QMC::AccessPublic, QMetaType::Void, {{
            { 0x80000000 | 15, 16 }, { QMetaType::Double, 20 }, { QMetaType::Double, 21 }, { QMetaType::Double, 22 },
            { QMetaType::Int, 23 }, { QMetaType::Int, 24 }, { 0x80000000 | 25, 26 },
        }}),
    };
    QtMocHelpers::UintData qt_properties {
    };
    QtMocHelpers::UintData qt_enums {
    };
    return QtMocHelpers::metaObjectData<PlateSolve, qt_meta_tag_ZN10PlateSolveE_t>(QMC::MetaObjectFlag{}, qt_stringData,
            qt_methods, qt_properties, qt_enums);
}
Q_CONSTINIT const QMetaObject PlateSolve::staticMetaObject = { {
    QMetaObject::SuperData::link<QDialog::staticMetaObject>(),
    qt_staticMetaObjectStaticContent<qt_meta_tag_ZN10PlateSolveE_t>.stringdata,
    qt_staticMetaObjectStaticContent<qt_meta_tag_ZN10PlateSolveE_t>.data,
    qt_static_metacall,
    nullptr,
    qt_staticMetaObjectRelocatingContent<qt_meta_tag_ZN10PlateSolveE_t>.metaTypes,
    nullptr
} };

void PlateSolve::qt_static_metacall(QObject *_o, QMetaObject::Call _c, int _id, void **_a)
{
    auto *_t = static_cast<PlateSolve *>(_o);
    if (_c == QMetaObject::InvokeMetaMethod) {
        switch (_id) {
        case 0: _t->clicked(); break;
        case 1: _t->extractorSuccess(); break;
        case 2: _t->subExtractorSuccess((*reinterpret_cast<std::add_pointer_t<double>>(_a[1])),(*reinterpret_cast<std::add_pointer_t<int>>(_a[2]))); break;
        case 3: _t->solverSuccess(); break;
        case 4: _t->subSolverSuccess(); break;
        case 5: _t->extractorFailed(); break;
        case 6: _t->subExtractorFailed(); break;
        case 7: _t->solverFailed(); break;
        case 8: _t->subSolverFailed(); break;
        case 9: _t->auxClicked(); break;
        case 10: _t->extractImage((*reinterpret_cast<std::add_pointer_t<QSharedPointer<FITSData>>>(_a[1]))); break;
        case 11: _t->solveImage((*reinterpret_cast<std::add_pointer_t<QSharedPointer<FITSData>>>(_a[1]))); break;
        case 12: _t->solveImage((*reinterpret_cast<std::add_pointer_t<QString>>(_a[1]))); break;
        case 13: _t->plateSolveSub((*reinterpret_cast<std::add_pointer_t<QSharedPointer<FITSData>>>(_a[1])),(*reinterpret_cast<std::add_pointer_t<double>>(_a[2])),(*reinterpret_cast<std::add_pointer_t<double>>(_a[3])),(*reinterpret_cast<std::add_pointer_t<double>>(_a[4])),(*reinterpret_cast<std::add_pointer_t<int>>(_a[5])),(*reinterpret_cast<std::add_pointer_t<int>>(_a[6])),(*reinterpret_cast<std::add_pointer_t<SSolver::ProcessType>>(_a[7]))); break;
        default: ;
        }
    }
    if (_c == QMetaObject::IndexOfMethod) {
        if (QtMocHelpers::indexOfMethod<void (PlateSolve::*)()>(_a, &PlateSolve::clicked, 0))
            return;
        if (QtMocHelpers::indexOfMethod<void (PlateSolve::*)()>(_a, &PlateSolve::extractorSuccess, 1))
            return;
        if (QtMocHelpers::indexOfMethod<void (PlateSolve::*)(const double , const int )>(_a, &PlateSolve::subExtractorSuccess, 2))
            return;
        if (QtMocHelpers::indexOfMethod<void (PlateSolve::*)()>(_a, &PlateSolve::solverSuccess, 3))
            return;
        if (QtMocHelpers::indexOfMethod<void (PlateSolve::*)()>(_a, &PlateSolve::subSolverSuccess, 4))
            return;
        if (QtMocHelpers::indexOfMethod<void (PlateSolve::*)()>(_a, &PlateSolve::extractorFailed, 5))
            return;
        if (QtMocHelpers::indexOfMethod<void (PlateSolve::*)()>(_a, &PlateSolve::subExtractorFailed, 6))
            return;
        if (QtMocHelpers::indexOfMethod<void (PlateSolve::*)()>(_a, &PlateSolve::solverFailed, 7))
            return;
        if (QtMocHelpers::indexOfMethod<void (PlateSolve::*)()>(_a, &PlateSolve::subSolverFailed, 8))
            return;
        if (QtMocHelpers::indexOfMethod<void (PlateSolve::*)()>(_a, &PlateSolve::auxClicked, 9))
            return;
    }
}

const QMetaObject *PlateSolve::metaObject() const
{
    return QObject::d_ptr->metaObject ? QObject::d_ptr->dynamicMetaObject() : &staticMetaObject;
}

void *PlateSolve::qt_metacast(const char *_clname)
{
    if (!_clname) return nullptr;
    if (!strcmp(_clname, qt_staticMetaObjectStaticContent<qt_meta_tag_ZN10PlateSolveE_t>.strings))
        return static_cast<void*>(this);
    if (!strcmp(_clname, "Ui::PlateSolveUI"))
        return static_cast< Ui::PlateSolveUI*>(this);
    return QDialog::qt_metacast(_clname);
}

int PlateSolve::qt_metacall(QMetaObject::Call _c, int _id, void **_a)
{
    _id = QDialog::qt_metacall(_c, _id, _a);
    if (_id < 0)
        return _id;
    if (_c == QMetaObject::InvokeMetaMethod) {
        if (_id < 14)
            qt_static_metacall(this, _c, _id, _a);
        _id -= 14;
    }
    if (_c == QMetaObject::RegisterMethodArgumentMetaType) {
        if (_id < 14)
            *reinterpret_cast<QMetaType *>(_a[0]) = QMetaType();
        _id -= 14;
    }
    return _id;
}

// SIGNAL 0
void PlateSolve::clicked()
{
    QMetaObject::activate(this, &staticMetaObject, 0, nullptr);
}

// SIGNAL 1
void PlateSolve::extractorSuccess()
{
    QMetaObject::activate(this, &staticMetaObject, 1, nullptr);
}

// SIGNAL 2
void PlateSolve::subExtractorSuccess(const double _t1, const int _t2)
{
    QMetaObject::activate<void>(this, &staticMetaObject, 2, nullptr, _t1, _t2);
}

// SIGNAL 3
void PlateSolve::solverSuccess()
{
    QMetaObject::activate(this, &staticMetaObject, 3, nullptr);
}

// SIGNAL 4
void PlateSolve::subSolverSuccess()
{
    QMetaObject::activate(this, &staticMetaObject, 4, nullptr);
}

// SIGNAL 5
void PlateSolve::extractorFailed()
{
    QMetaObject::activate(this, &staticMetaObject, 5, nullptr);
}

// SIGNAL 6
void PlateSolve::subExtractorFailed()
{
    QMetaObject::activate(this, &staticMetaObject, 6, nullptr);
}

// SIGNAL 7
void PlateSolve::solverFailed()
{
    QMetaObject::activate(this, &staticMetaObject, 7, nullptr);
}

// SIGNAL 8
void PlateSolve::subSolverFailed()
{
    QMetaObject::activate(this, &staticMetaObject, 8, nullptr);
}

// SIGNAL 9
void PlateSolve::auxClicked()
{
    QMetaObject::activate(this, &staticMetaObject, 9, nullptr);
}
QT_WARNING_POP
