/********************************************************************************
** Form generated from reading UI file 'opscolors.ui'
**
** Created by: Qt User Interface Compiler version 6.11.1
**
** WARNING! All changes made in this file will be lost when recompiling UI file!
********************************************************************************/

#ifndef UI_OPSCOLORS_H
#define UI_OPSCOLORS_H

#include <QtCore/QVariant>
#include <QtWidgets/QApplication>
#include <QtWidgets/QCheckBox>
#include <QtWidgets/QComboBox>
#include <QtWidgets/QGroupBox>
#include <QtWidgets/QHBoxLayout>
#include <QtWidgets/QLabel>
#include <QtWidgets/QListWidget>
#include <QtWidgets/QPushButton>
#include <QtWidgets/QSpinBox>
#include <QtWidgets/QVBoxLayout>
#include <QtWidgets/QWidget>
#include <klocalizedstring.h>

QT_BEGIN_NAMESPACE

class Ui_OpsColors
{
public:
    QHBoxLayout *hboxLayout;
    QGroupBox *groupBox;
    QVBoxLayout *vboxLayout;
    QListWidget *ColorPalette;
    QHBoxLayout *hboxLayout1;
    QLabel *textLabel1_2;
    QComboBox *kcfg_BoxBGMode;
    QHBoxLayout *hboxLayout2;
    QLabel *textLabel1;
    QComboBox *kcfg_StarColorMode;
    QHBoxLayout *hboxLayout3;
    QLabel *textLabel2;
    QSpinBox *kcfg_StarColorIntensity;
    QHBoxLayout *horizontalLayout_2;
    QCheckBox *kcfg_DomeSlitInverted;
    QGroupBox *groupBox_2;
    QVBoxLayout *verticalLayout;
    QListWidget *PresetBox;
    QHBoxLayout *horizontalLayout;
    QPushButton *SavePreset;
    QPushButton *AddPreset;
    QPushButton *RemovePreset;
    QLabel *label;
    QListWidget *themesWidget;

    void setupUi(QWidget *OpsColors)
    {
        if (OpsColors->objectName().isEmpty())
            OpsColors->setObjectName("OpsColors");
        OpsColors->resize(568, 377);
        hboxLayout = new QHBoxLayout(OpsColors);
        hboxLayout->setSpacing(5);
        hboxLayout->setObjectName("hboxLayout");
        hboxLayout->setContentsMargins(5, 5, 5, 5);
        groupBox = new QGroupBox(OpsColors);
        groupBox->setObjectName("groupBox");
        vboxLayout = new QVBoxLayout(groupBox);
        vboxLayout->setSpacing(5);
        vboxLayout->setObjectName("vboxLayout");
        vboxLayout->setContentsMargins(5, 5, 5, 5);
        ColorPalette = new QListWidget(groupBox);
        ColorPalette->setObjectName("ColorPalette");

        vboxLayout->addWidget(ColorPalette);

        hboxLayout1 = new QHBoxLayout();
        hboxLayout1->setSpacing(3);
        hboxLayout1->setObjectName("hboxLayout1");
        hboxLayout1->setContentsMargins(0, 0, 0, 0);
        textLabel1_2 = new QLabel(groupBox);
        textLabel1_2->setObjectName("textLabel1_2");

        hboxLayout1->addWidget(textLabel1_2);

        kcfg_BoxBGMode = new QComboBox(groupBox);
        kcfg_BoxBGMode->addItem(QString());
        kcfg_BoxBGMode->addItem(QString());
        kcfg_BoxBGMode->addItem(QString());
        kcfg_BoxBGMode->setObjectName("kcfg_BoxBGMode");

        hboxLayout1->addWidget(kcfg_BoxBGMode);


        vboxLayout->addLayout(hboxLayout1);

        hboxLayout2 = new QHBoxLayout();
        hboxLayout2->setSpacing(6);
        hboxLayout2->setObjectName("hboxLayout2");
        hboxLayout2->setContentsMargins(0, 0, 0, 0);
        textLabel1 = new QLabel(groupBox);
        textLabel1->setObjectName("textLabel1");

        hboxLayout2->addWidget(textLabel1);

        kcfg_StarColorMode = new QComboBox(groupBox);
        kcfg_StarColorMode->setObjectName("kcfg_StarColorMode");

        hboxLayout2->addWidget(kcfg_StarColorMode);


        vboxLayout->addLayout(hboxLayout2);

        hboxLayout3 = new QHBoxLayout();
        hboxLayout3->setSpacing(3);
        hboxLayout3->setObjectName("hboxLayout3");
        hboxLayout3->setContentsMargins(0, 0, 0, 0);
        textLabel2 = new QLabel(groupBox);
        textLabel2->setObjectName("textLabel2");

        hboxLayout3->addWidget(textLabel2);

        kcfg_StarColorIntensity = new QSpinBox(groupBox);
        kcfg_StarColorIntensity->setObjectName("kcfg_StarColorIntensity");

        hboxLayout3->addWidget(kcfg_StarColorIntensity);


        vboxLayout->addLayout(hboxLayout3);

        horizontalLayout_2 = new QHBoxLayout();
        horizontalLayout_2->setObjectName("horizontalLayout_2");
        kcfg_DomeSlitInverted = new QCheckBox(groupBox);
        kcfg_DomeSlitInverted->setObjectName("kcfg_DomeSlitInverted");
        kcfg_DomeSlitInverted->setEnabled(true);
        kcfg_DomeSlitInverted->setTristate(false);

        horizontalLayout_2->addWidget(kcfg_DomeSlitInverted);


        vboxLayout->addLayout(horizontalLayout_2);


        hboxLayout->addWidget(groupBox);

        groupBox_2 = new QGroupBox(OpsColors);
        groupBox_2->setObjectName("groupBox_2");
        verticalLayout = new QVBoxLayout(groupBox_2);
        verticalLayout->setObjectName("verticalLayout");
        PresetBox = new QListWidget(groupBox_2);
        PresetBox->setObjectName("PresetBox");

        verticalLayout->addWidget(PresetBox);

        horizontalLayout = new QHBoxLayout();
        horizontalLayout->setObjectName("horizontalLayout");
        SavePreset = new QPushButton(groupBox_2);
        SavePreset->setObjectName("SavePreset");

        horizontalLayout->addWidget(SavePreset);

        AddPreset = new QPushButton(groupBox_2);
        AddPreset->setObjectName("AddPreset");

        horizontalLayout->addWidget(AddPreset);

        RemovePreset = new QPushButton(groupBox_2);
        RemovePreset->setObjectName("RemovePreset");

        horizontalLayout->addWidget(RemovePreset);


        verticalLayout->addLayout(horizontalLayout);

        label = new QLabel(groupBox_2);
        label->setObjectName("label");

        verticalLayout->addWidget(label);

        themesWidget = new QListWidget(groupBox_2);
        themesWidget->setObjectName("themesWidget");

        verticalLayout->addWidget(themesWidget);


        hboxLayout->addWidget(groupBox_2);

#if QT_CONFIG(shortcut)
        textLabel1->setBuddy(kcfg_StarColorMode);
#endif // QT_CONFIG(shortcut)
        QWidget::setTabOrder(ColorPalette, kcfg_BoxBGMode);
        QWidget::setTabOrder(kcfg_BoxBGMode, kcfg_StarColorMode);
        QWidget::setTabOrder(kcfg_StarColorMode, kcfg_StarColorIntensity);
        QWidget::setTabOrder(kcfg_StarColorIntensity, PresetBox);
        QWidget::setTabOrder(PresetBox, AddPreset);

        retranslateUi(OpsColors);

        QMetaObject::connectSlotsByName(OpsColors);
    } // setupUi

    void retranslateUi(QWidget *OpsColors)
    {
        groupBox->setTitle(tr2i18n("Current Scheme Colors", nullptr));
#if QT_CONFIG(tooltip)
        ColorPalette->setToolTip(tr2i18n("Current color settings", nullptr));
#endif // QT_CONFIG(tooltip)
#if QT_CONFIG(whatsthis)
        ColorPalette->setWhatsThis(tr2i18n("The list of all customizable colors in the program.  Next to each item is a square showing the color it is currently set to.  Click on any item to change its color.", nullptr));
#endif // QT_CONFIG(whatsthis)
        textLabel1_2->setText(tr2i18n("InfoBox BG mode:", nullptr));
        kcfg_BoxBGMode->setItemText(0, tr2i18n("No Fill", nullptr));
        kcfg_BoxBGMode->setItemText(1, tr2i18n("Transparent", nullptr));
        kcfg_BoxBGMode->setItemText(2, tr2i18n("Opaque", nullptr));

        textLabel1->setText(tr2i18n("Star color mode:", nullptr));
#if QT_CONFIG(tooltip)
        kcfg_StarColorMode->setToolTip(tr2i18n("Set the star color mode", nullptr));
#endif // QT_CONFIG(tooltip)
#if QT_CONFIG(whatsthis)
        kcfg_StarColorMode->setWhatsThis(tr2i18n("There are four ways to draw stars on the map.  By default, stars are circles with a white core and a rim which is tinted to reflect the star's actual color.  You may also choose to draw the stars as solid white, red, or black circles, to match the needs of your overall color scheme.", nullptr));
#endif // QT_CONFIG(whatsthis)
        textLabel2->setText(tr2i18n("Star color intensity:", nullptr));
#if QT_CONFIG(tooltip)
        kcfg_StarColorIntensity->setToolTip(tr2i18n("Set the intensity of star colors", nullptr));
#endif // QT_CONFIG(tooltip)
#if QT_CONFIG(whatsthis)
        kcfg_StarColorIntensity->setWhatsThis(tr2i18n("When using the realistic-color star mode, this option will set the saturation level of the star's colors.  A higher value means more intense colors.", nullptr));
#endif // QT_CONFIG(whatsthis)
        kcfg_DomeSlitInverted->setText(tr2i18n("Dome Slit Inverted", nullptr));
        groupBox_2->setTitle(tr2i18n("Preset Color Schemes", nullptr));
#if QT_CONFIG(tooltip)
        PresetBox->setToolTip(tr2i18n("List of preset color schemes", nullptr));
#endif // QT_CONFIG(tooltip)
#if QT_CONFIG(whatsthis)
        PresetBox->setWhatsThis(tr2i18n("List of all known color schemes.  Several are provided by default, and you may also define your own.", nullptr));
#endif // QT_CONFIG(whatsthis)
        SavePreset->setText(tr2i18n("Save", nullptr));
#if QT_CONFIG(tooltip)
        AddPreset->setToolTip(tr2i18n("Create a new preset color scheme using current settings", nullptr));
#endif // QT_CONFIG(tooltip)
#if QT_CONFIG(whatsthis)
        AddPreset->setWhatsThis(tr2i18n("After changing the colors to a scheme that you like, press this button to create a new scheme using those colors.  Your scheme will appear here in the list of presets, and will also be available in the \"Settings\" menu of the main window.", nullptr));
#endif // QT_CONFIG(whatsthis)
        AddPreset->setText(tr2i18n("Save As...", nullptr));
#if QT_CONFIG(tooltip)
        RemovePreset->setToolTip(tr2i18n("Remove a preset color scheme", nullptr));
#endif // QT_CONFIG(tooltip)
#if QT_CONFIG(whatsthis)
        RemovePreset->setWhatsThis(tr2i18n("Press this button to remove the highlighted color scheme.  This will only work on your custom color schemes.", nullptr));
#endif // QT_CONFIG(whatsthis)
        RemovePreset->setText(tr2i18n("Remove", nullptr));
        label->setText(tr2i18n("Application Themes", nullptr));
        (void)OpsColors;
    } // retranslateUi

};

namespace Ui {
    class OpsColors: public Ui_OpsColors {};
} // namespace Ui

QT_END_NAMESPACE

#endif // OPSCOLORS_H

