/********************************************************************************
** Form generated from reading UI file 'argsetlocaltime.ui'
**
** Created by: Qt User Interface Compiler version 6.11.1
**
** WARNING! All changes made in this file will be lost when recompiling UI file!
********************************************************************************/

#ifndef UI_ARGSETLOCALTIME_H
#define UI_ARGSETLOCALTIME_H

#include <QtCore/QVariant>
#include <QtWidgets/QApplication>
#include <QtWidgets/QDateEdit>
#include <QtWidgets/QHBoxLayout>
#include <QtWidgets/QSpacerItem>
#include <QtWidgets/QTimeEdit>
#include <QtWidgets/QVBoxLayout>
#include <QtWidgets/QWidget>
#include <klocalizedstring.h>

QT_BEGIN_NAMESPACE

class Ui_ArgSetLocalTime
{
public:
    QVBoxLayout *vboxLayout;
    QDateEdit *DateWidget;
    QHBoxLayout *hboxLayout;
    QSpacerItem *spacerItem;
    QTimeEdit *TimeBox;
    QSpacerItem *spacerItem1;

    void setupUi(QWidget *ArgSetLocalTime)
    {
        if (ArgSetLocalTime->objectName().isEmpty())
            ArgSetLocalTime->setObjectName("ArgSetLocalTime");
        ArgSetLocalTime->resize(293, 107);
        vboxLayout = new QVBoxLayout(ArgSetLocalTime);
        vboxLayout->setSpacing(6);
        vboxLayout->setObjectName("vboxLayout");
        vboxLayout->setContentsMargins(8, 8, 8, 8);
        DateWidget = new QDateEdit(ArgSetLocalTime);
        DateWidget->setObjectName("DateWidget");

        vboxLayout->addWidget(DateWidget);

        hboxLayout = new QHBoxLayout();
        hboxLayout->setSpacing(6);
        hboxLayout->setObjectName("hboxLayout");
        hboxLayout->setContentsMargins(0, 0, 0, 0);
        spacerItem = new QSpacerItem(111, 27, QSizePolicy::Policy::Expanding, QSizePolicy::Policy::Minimum);

        hboxLayout->addItem(spacerItem);

        TimeBox = new QTimeEdit(ArgSetLocalTime);
        TimeBox->setObjectName("TimeBox");

        hboxLayout->addWidget(TimeBox);


        vboxLayout->addLayout(hboxLayout);

        spacerItem1 = new QSpacerItem(271, 20, QSizePolicy::Policy::Minimum, QSizePolicy::Policy::Expanding);

        vboxLayout->addItem(spacerItem1);


        retranslateUi(ArgSetLocalTime);

        QMetaObject::connectSlotsByName(ArgSetLocalTime);
    } // setupUi

    void retranslateUi(QWidget *ArgSetLocalTime)
    {
        (void)ArgSetLocalTime;
    } // retranslateUi

};

namespace Ui {
    class ArgSetLocalTime: public Ui_ArgSetLocalTime {};
} // namespace Ui

QT_END_NAMESPACE

#endif // ARGSETLOCALTIME_H

