/****************************************************************************
** Meta object code from reading C++ file 'capturedeviceadaptor.h'
**
** Created by: The Qt Meta Object Compiler version 69 (Qt 6.11.1)
**
** WARNING! All changes made in this file will be lost!
*****************************************************************************/

#include "../../../../kstars-3.8.4.1/kstars/ekos/capture/capturedeviceadaptor.h"
#include <QtNetwork/QSslError>
#include <QtDataVisualization/qbar3dseries.h>
#include <QtDataVisualization/q3dscene.h>
#include <QtGui/qtextcursor.h>
#include <QtCore/qmetatype.h>

#include <QtCore/qtmochelpers.h>

#include <memory>


#include <QtCore/qxptype_traits.h>
#if !defined(Q_MOC_OUTPUT_REVISION)
#error "The header file 'capturedeviceadaptor.h' doesn't include <QObject>."
#elif Q_MOC_OUTPUT_REVISION != 69
#error "This file was generated using the moc from 6.11.1. It"
#error "cannot be used with the include files from this version of Qt."
#error "(The moc has changed too much.)"
#endif

#ifndef Q_CONSTINIT
#define Q_CONSTINIT
#endif

QT_WARNING_PUSH
QT_WARNING_DISABLE_DEPRECATED
QT_WARNING_DISABLE_GCC("-Wuseless-cast")
namespace {
struct qt_meta_tag_ZN4Ekos20CaptureDeviceAdaptorE_t {};
} // unnamed namespace

template <> constexpr inline auto Ekos::CaptureDeviceAdaptor::qt_create_metaobjectdata<qt_meta_tag_ZN4Ekos20CaptureDeviceAdaptorE_t>()
{
    namespace QMC = QtMocConstants;
    QtMocHelpers::StringRefStorage qt_stringData {
        "Ekos::CaptureDeviceAdaptor",
        "filterIdChanged",
        "",
        "id",
        "newCamera",
        "name",
        "CameraConnected",
        "connected",
        "newCCDTemperatureValue",
        "value",
        "newRotator",
        "newRotatorAngle",
        "IPState",
        "state",
        "rotatorReverseToggled",
        "enabled",
        "newFilterWheel",
        "FilterWheelConnected",
        "manualScopeCoverUpdated",
        "closed",
        "success",
        "light",
        "lightBoxLight",
        "on",
        "dustCapStatusChanged",
        "ISD::DustCap::Status",
        "status",
        "lightBoxStatusChanged",
        "ISD::LightBox::LightStatus",
        "scopeStatusChanged",
        "ISD::Mount::Status",
        "pierSideChanged",
        "ISD::Mount::PierSide",
        "pierside",
        "scopeParkStatusChanged",
        "ISD::ParkStatus",
        "domeStatusChanged",
        "ISD::Dome::Status",
        "flatSyncFocusChanged",
        "completed",
        "hasShutter",
        "present",
        "readCurrentState",
        "CaptureState",
        "readCurrentMountParkState"
    };

    QtMocHelpers::UintData qt_methods {
        // Signal 'filterIdChanged'
        QtMocHelpers::SignalData<void(int)>(1, 2, QMC::AccessPublic, QMetaType::Void, {{
            { QMetaType::Int, 3 },
        }}),
        // Signal 'newCamera'
        QtMocHelpers::SignalData<void(QString)>(4, 2, QMC::AccessPublic, QMetaType::Void, {{
            { QMetaType::QString, 5 },
        }}),
        // Signal 'CameraConnected'
        QtMocHelpers::SignalData<void(bool)>(6, 2, QMC::AccessPublic, QMetaType::Void, {{
            { QMetaType::Bool, 7 },
        }}),
        // Signal 'newCCDTemperatureValue'
        QtMocHelpers::SignalData<void(double)>(8, 2, QMC::AccessPublic, QMetaType::Void, {{
            { QMetaType::Double, 9 },
        }}),
        // Signal 'newRotator'
        QtMocHelpers::SignalData<void(QString)>(10, 2, QMC::AccessPublic, QMetaType::Void, {{
            { QMetaType::QString, 5 },
        }}),
        // Signal 'newRotatorAngle'
        QtMocHelpers::SignalData<void(double, IPState)>(11, 2, QMC::AccessPublic, QMetaType::Void, {{
            { QMetaType::Double, 9 }, { 0x80000000 | 12, 13 },
        }}),
        // Signal 'rotatorReverseToggled'
        QtMocHelpers::SignalData<void(bool)>(14, 2, QMC::AccessPublic, QMetaType::Void, {{
            { QMetaType::Bool, 15 },
        }}),
        // Signal 'newFilterWheel'
        QtMocHelpers::SignalData<void(QString)>(16, 2, QMC::AccessPublic, QMetaType::Void, {{
            { QMetaType::QString, 5 },
        }}),
        // Signal 'FilterWheelConnected'
        QtMocHelpers::SignalData<void(bool)>(17, 2, QMC::AccessPublic, QMetaType::Void, {{
            { QMetaType::Bool, 7 },
        }}),
        // Signal 'manualScopeCoverUpdated'
        QtMocHelpers::SignalData<void(bool, bool, bool)>(18, 2, QMC::AccessPublic, QMetaType::Void, {{
            { QMetaType::Bool, 19 }, { QMetaType::Bool, 20 }, { QMetaType::Bool, 21 },
        }}),
        // Signal 'lightBoxLight'
        QtMocHelpers::SignalData<void(bool)>(22, 2, QMC::AccessPublic, QMetaType::Void, {{
            { QMetaType::Bool, 23 },
        }}),
        // Signal 'dustCapStatusChanged'
        QtMocHelpers::SignalData<void(ISD::DustCap::Status)>(24, 2, QMC::AccessPublic, QMetaType::Void, {{
            { 0x80000000 | 25, 26 },
        }}),
        // Signal 'lightBoxStatusChanged'
        QtMocHelpers::SignalData<void(ISD::LightBox::LightStatus)>(27, 2, QMC::AccessPublic, QMetaType::Void, {{
            { 0x80000000 | 28, 26 },
        }}),
        // Signal 'scopeStatusChanged'
        QtMocHelpers::SignalData<void(ISD::Mount::Status)>(29, 2, QMC::AccessPublic, QMetaType::Void, {{
            { 0x80000000 | 30, 26 },
        }}),
        // Signal 'pierSideChanged'
        QtMocHelpers::SignalData<void(ISD::Mount::PierSide)>(31, 2, QMC::AccessPublic, QMetaType::Void, {{
            { 0x80000000 | 32, 33 },
        }}),
        // Signal 'scopeParkStatusChanged'
        QtMocHelpers::SignalData<void(ISD::ParkStatus)>(34, 2, QMC::AccessPublic, QMetaType::Void, {{
            { 0x80000000 | 35, 26 },
        }}),
        // Signal 'domeStatusChanged'
        QtMocHelpers::SignalData<void(ISD::Dome::Status)>(36, 2, QMC::AccessPublic, QMetaType::Void, {{
            { 0x80000000 | 37, 26 },
        }}),
        // Signal 'flatSyncFocusChanged'
        QtMocHelpers::SignalData<void(bool)>(38, 2, QMC::AccessPublic, QMetaType::Void, {{
            { QMetaType::Bool, 39 },
        }}),
        // Signal 'hasShutter'
        QtMocHelpers::SignalData<void(bool)>(40, 2, QMC::AccessPublic, QMetaType::Void, {{
            { QMetaType::Bool, 41 },
        }}),
        // Slot 'readCurrentState'
        QtMocHelpers::SlotData<void(CaptureState)>(42, 2, QMC::AccessPublic, QMetaType::Void, {{
            { 0x80000000 | 43, 13 },
        }}),
        // Slot 'readCurrentMountParkState'
        QtMocHelpers::SlotData<void()>(44, 2, QMC::AccessPublic, QMetaType::Void),
    };
    QtMocHelpers::UintData qt_properties {
    };
    QtMocHelpers::UintData qt_enums {
    };
    return QtMocHelpers::metaObjectData<CaptureDeviceAdaptor, qt_meta_tag_ZN4Ekos20CaptureDeviceAdaptorE_t>(QMC::MetaObjectFlag{}, qt_stringData,
            qt_methods, qt_properties, qt_enums);
}
Q_CONSTINIT const QMetaObject Ekos::CaptureDeviceAdaptor::staticMetaObject = { {
    QMetaObject::SuperData::link<QObject::staticMetaObject>(),
    qt_staticMetaObjectStaticContent<qt_meta_tag_ZN4Ekos20CaptureDeviceAdaptorE_t>.stringdata,
    qt_staticMetaObjectStaticContent<qt_meta_tag_ZN4Ekos20CaptureDeviceAdaptorE_t>.data,
    qt_static_metacall,
    nullptr,
    qt_staticMetaObjectRelocatingContent<qt_meta_tag_ZN4Ekos20CaptureDeviceAdaptorE_t>.metaTypes,
    nullptr
} };

void Ekos::CaptureDeviceAdaptor::qt_static_metacall(QObject *_o, QMetaObject::Call _c, int _id, void **_a)
{
    auto *_t = static_cast<CaptureDeviceAdaptor *>(_o);
    if (_c == QMetaObject::InvokeMetaMethod) {
        switch (_id) {
        case 0: _t->filterIdChanged((*reinterpret_cast<std::add_pointer_t<int>>(_a[1]))); break;
        case 1: _t->newCamera((*reinterpret_cast<std::add_pointer_t<QString>>(_a[1]))); break;
        case 2: _t->CameraConnected((*reinterpret_cast<std::add_pointer_t<bool>>(_a[1]))); break;
        case 3: _t->newCCDTemperatureValue((*reinterpret_cast<std::add_pointer_t<double>>(_a[1]))); break;
        case 4: _t->newRotator((*reinterpret_cast<std::add_pointer_t<QString>>(_a[1]))); break;
        case 5: _t->newRotatorAngle((*reinterpret_cast<std::add_pointer_t<double>>(_a[1])),(*reinterpret_cast<std::add_pointer_t<IPState>>(_a[2]))); break;
        case 6: _t->rotatorReverseToggled((*reinterpret_cast<std::add_pointer_t<bool>>(_a[1]))); break;
        case 7: _t->newFilterWheel((*reinterpret_cast<std::add_pointer_t<QString>>(_a[1]))); break;
        case 8: _t->FilterWheelConnected((*reinterpret_cast<std::add_pointer_t<bool>>(_a[1]))); break;
        case 9: _t->manualScopeCoverUpdated((*reinterpret_cast<std::add_pointer_t<bool>>(_a[1])),(*reinterpret_cast<std::add_pointer_t<bool>>(_a[2])),(*reinterpret_cast<std::add_pointer_t<bool>>(_a[3]))); break;
        case 10: _t->lightBoxLight((*reinterpret_cast<std::add_pointer_t<bool>>(_a[1]))); break;
        case 11: _t->dustCapStatusChanged((*reinterpret_cast<std::add_pointer_t<ISD::DustCap::Status>>(_a[1]))); break;
        case 12: _t->lightBoxStatusChanged((*reinterpret_cast<std::add_pointer_t<ISD::LightBox::LightStatus>>(_a[1]))); break;
        case 13: _t->scopeStatusChanged((*reinterpret_cast<std::add_pointer_t<ISD::Mount::Status>>(_a[1]))); break;
        case 14: _t->pierSideChanged((*reinterpret_cast<std::add_pointer_t<ISD::Mount::PierSide>>(_a[1]))); break;
        case 15: _t->scopeParkStatusChanged((*reinterpret_cast<std::add_pointer_t<ISD::ParkStatus>>(_a[1]))); break;
        case 16: _t->domeStatusChanged((*reinterpret_cast<std::add_pointer_t<ISD::Dome::Status>>(_a[1]))); break;
        case 17: _t->flatSyncFocusChanged((*reinterpret_cast<std::add_pointer_t<bool>>(_a[1]))); break;
        case 18: _t->hasShutter((*reinterpret_cast<std::add_pointer_t<bool>>(_a[1]))); break;
        case 19: _t->readCurrentState((*reinterpret_cast<std::add_pointer_t<CaptureState>>(_a[1]))); break;
        case 20: _t->readCurrentMountParkState(); break;
        default: ;
        }
    }
    if (_c == QMetaObject::RegisterMethodArgumentMetaType) {
        switch (_id) {
        default: *reinterpret_cast<QMetaType *>(_a[0]) = QMetaType(); break;
        case 11:
            switch (*reinterpret_cast<int*>(_a[1])) {
            default: *reinterpret_cast<QMetaType *>(_a[0]) = QMetaType(); break;
            case 0:
                *reinterpret_cast<QMetaType *>(_a[0]) = QMetaType::fromType< ISD::DustCap::Status >(); break;
            }
            break;
        case 13:
            switch (*reinterpret_cast<int*>(_a[1])) {
            default: *reinterpret_cast<QMetaType *>(_a[0]) = QMetaType(); break;
            case 0:
                *reinterpret_cast<QMetaType *>(_a[0]) = QMetaType::fromType< ISD::Mount::Status >(); break;
            }
            break;
        case 14:
            switch (*reinterpret_cast<int*>(_a[1])) {
            default: *reinterpret_cast<QMetaType *>(_a[0]) = QMetaType(); break;
            case 0:
                *reinterpret_cast<QMetaType *>(_a[0]) = QMetaType::fromType< ISD::Mount::PierSide >(); break;
            }
            break;
        case 15:
            switch (*reinterpret_cast<int*>(_a[1])) {
            default: *reinterpret_cast<QMetaType *>(_a[0]) = QMetaType(); break;
            case 0:
                *reinterpret_cast<QMetaType *>(_a[0]) = QMetaType::fromType< ISD::ParkStatus >(); break;
            }
            break;
        case 16:
            switch (*reinterpret_cast<int*>(_a[1])) {
            default: *reinterpret_cast<QMetaType *>(_a[0]) = QMetaType(); break;
            case 0:
                *reinterpret_cast<QMetaType *>(_a[0]) = QMetaType::fromType< ISD::Dome::Status >(); break;
            }
            break;
        }
    }
    if (_c == QMetaObject::IndexOfMethod) {
        if (QtMocHelpers::indexOfMethod<void (CaptureDeviceAdaptor::*)(int )>(_a, &CaptureDeviceAdaptor::filterIdChanged, 0))
            return;
        if (QtMocHelpers::indexOfMethod<void (CaptureDeviceAdaptor::*)(QString )>(_a, &CaptureDeviceAdaptor::newCamera, 1))
            return;
        if (QtMocHelpers::indexOfMethod<void (CaptureDeviceAdaptor::*)(bool )>(_a, &CaptureDeviceAdaptor::CameraConnected, 2))
            return;
        if (QtMocHelpers::indexOfMethod<void (CaptureDeviceAdaptor::*)(double )>(_a, &CaptureDeviceAdaptor::newCCDTemperatureValue, 3))
            return;
        if (QtMocHelpers::indexOfMethod<void (CaptureDeviceAdaptor::*)(QString )>(_a, &CaptureDeviceAdaptor::newRotator, 4))
            return;
        if (QtMocHelpers::indexOfMethod<void (CaptureDeviceAdaptor::*)(double , IPState )>(_a, &CaptureDeviceAdaptor::newRotatorAngle, 5))
            return;
        if (QtMocHelpers::indexOfMethod<void (CaptureDeviceAdaptor::*)(bool )>(_a, &CaptureDeviceAdaptor::rotatorReverseToggled, 6))
            return;
        if (QtMocHelpers::indexOfMethod<void (CaptureDeviceAdaptor::*)(QString )>(_a, &CaptureDeviceAdaptor::newFilterWheel, 7))
            return;
        if (QtMocHelpers::indexOfMethod<void (CaptureDeviceAdaptor::*)(bool )>(_a, &CaptureDeviceAdaptor::FilterWheelConnected, 8))
            return;
        if (QtMocHelpers::indexOfMethod<void (CaptureDeviceAdaptor::*)(bool , bool , bool )>(_a, &CaptureDeviceAdaptor::manualScopeCoverUpdated, 9))
            return;
        if (QtMocHelpers::indexOfMethod<void (CaptureDeviceAdaptor::*)(bool )>(_a, &CaptureDeviceAdaptor::lightBoxLight, 10))
            return;
        if (QtMocHelpers::indexOfMethod<void (CaptureDeviceAdaptor::*)(ISD::DustCap::Status )>(_a, &CaptureDeviceAdaptor::dustCapStatusChanged, 11))
            return;
        if (QtMocHelpers::indexOfMethod<void (CaptureDeviceAdaptor::*)(ISD::LightBox::LightStatus )>(_a, &CaptureDeviceAdaptor::lightBoxStatusChanged, 12))
            return;
        if (QtMocHelpers::indexOfMethod<void (CaptureDeviceAdaptor::*)(ISD::Mount::Status )>(_a, &CaptureDeviceAdaptor::scopeStatusChanged, 13))
            return;
        if (QtMocHelpers::indexOfMethod<void (CaptureDeviceAdaptor::*)(ISD::Mount::PierSide )>(_a, &CaptureDeviceAdaptor::pierSideChanged, 14))
            return;
        if (QtMocHelpers::indexOfMethod<void (CaptureDeviceAdaptor::*)(ISD::ParkStatus )>(_a, &CaptureDeviceAdaptor::scopeParkStatusChanged, 15))
            return;
        if (QtMocHelpers::indexOfMethod<void (CaptureDeviceAdaptor::*)(ISD::Dome::Status )>(_a, &CaptureDeviceAdaptor::domeStatusChanged, 16))
            return;
        if (QtMocHelpers::indexOfMethod<void (CaptureDeviceAdaptor::*)(bool )>(_a, &CaptureDeviceAdaptor::flatSyncFocusChanged, 17))
            return;
        if (QtMocHelpers::indexOfMethod<void (CaptureDeviceAdaptor::*)(bool )>(_a, &CaptureDeviceAdaptor::hasShutter, 18))
            return;
    }
}

const QMetaObject *Ekos::CaptureDeviceAdaptor::metaObject() const
{
    return QObject::d_ptr->metaObject ? QObject::d_ptr->dynamicMetaObject() : &staticMetaObject;
}

void *Ekos::CaptureDeviceAdaptor::qt_metacast(const char *_clname)
{
    if (!_clname) return nullptr;
    if (!strcmp(_clname, qt_staticMetaObjectStaticContent<qt_meta_tag_ZN4Ekos20CaptureDeviceAdaptorE_t>.strings))
        return static_cast<void*>(this);
    return QObject::qt_metacast(_clname);
}

int Ekos::CaptureDeviceAdaptor::qt_metacall(QMetaObject::Call _c, int _id, void **_a)
{
    _id = QObject::qt_metacall(_c, _id, _a);
    if (_id < 0)
        return _id;
    if (_c == QMetaObject::InvokeMetaMethod) {
        if (_id < 21)
            qt_static_metacall(this, _c, _id, _a);
        _id -= 21;
    }
    if (_c == QMetaObject::RegisterMethodArgumentMetaType) {
        if (_id < 21)
            qt_static_metacall(this, _c, _id, _a);
        _id -= 21;
    }
    return _id;
}

// SIGNAL 0
void Ekos::CaptureDeviceAdaptor::filterIdChanged(int _t1)
{
    QMetaObject::activate<void>(this, &staticMetaObject, 0, nullptr, _t1);
}

// SIGNAL 1
void Ekos::CaptureDeviceAdaptor::newCamera(QString _t1)
{
    QMetaObject::activate<void>(this, &staticMetaObject, 1, nullptr, _t1);
}

// SIGNAL 2
void Ekos::CaptureDeviceAdaptor::CameraConnected(bool _t1)
{
    QMetaObject::activate<void>(this, &staticMetaObject, 2, nullptr, _t1);
}

// SIGNAL 3
void Ekos::CaptureDeviceAdaptor::newCCDTemperatureValue(double _t1)
{
    QMetaObject::activate<void>(this, &staticMetaObject, 3, nullptr, _t1);
}

// SIGNAL 4
void Ekos::CaptureDeviceAdaptor::newRotator(QString _t1)
{
    QMetaObject::activate<void>(this, &staticMetaObject, 4, nullptr, _t1);
}

// SIGNAL 5
void Ekos::CaptureDeviceAdaptor::newRotatorAngle(double _t1, IPState _t2)
{
    QMetaObject::activate<void>(this, &staticMetaObject, 5, nullptr, _t1, _t2);
}

// SIGNAL 6
void Ekos::CaptureDeviceAdaptor::rotatorReverseToggled(bool _t1)
{
    QMetaObject::activate<void>(this, &staticMetaObject, 6, nullptr, _t1);
}

// SIGNAL 7
void Ekos::CaptureDeviceAdaptor::newFilterWheel(QString _t1)
{
    QMetaObject::activate<void>(this, &staticMetaObject, 7, nullptr, _t1);
}

// SIGNAL 8
void Ekos::CaptureDeviceAdaptor::FilterWheelConnected(bool _t1)
{
    QMetaObject::activate<void>(this, &staticMetaObject, 8, nullptr, _t1);
}

// SIGNAL 9
void Ekos::CaptureDeviceAdaptor::manualScopeCoverUpdated(bool _t1, bool _t2, bool _t3)
{
    QMetaObject::activate<void>(this, &staticMetaObject, 9, nullptr, _t1, _t2, _t3);
}

// SIGNAL 10
void Ekos::CaptureDeviceAdaptor::lightBoxLight(bool _t1)
{
    QMetaObject::activate<void>(this, &staticMetaObject, 10, nullptr, _t1);
}

// SIGNAL 11
void Ekos::CaptureDeviceAdaptor::dustCapStatusChanged(ISD::DustCap::Status _t1)
{
    QMetaObject::activate<void>(this, &staticMetaObject, 11, nullptr, _t1);
}

// SIGNAL 12
void Ekos::CaptureDeviceAdaptor::lightBoxStatusChanged(ISD::LightBox::LightStatus _t1)
{
    QMetaObject::activate<void>(this, &staticMetaObject, 12, nullptr, _t1);
}

// SIGNAL 13
void Ekos::CaptureDeviceAdaptor::scopeStatusChanged(ISD::Mount::Status _t1)
{
    QMetaObject::activate<void>(this, &staticMetaObject, 13, nullptr, _t1);
}

// SIGNAL 14
void Ekos::CaptureDeviceAdaptor::pierSideChanged(ISD::Mount::PierSide _t1)
{
    QMetaObject::activate<void>(this, &staticMetaObject, 14, nullptr, _t1);
}

// SIGNAL 15
void Ekos::CaptureDeviceAdaptor::scopeParkStatusChanged(ISD::ParkStatus _t1)
{
    QMetaObject::activate<void>(this, &staticMetaObject, 15, nullptr, _t1);
}

// SIGNAL 16
void Ekos::CaptureDeviceAdaptor::domeStatusChanged(ISD::Dome::Status _t1)
{
    QMetaObject::activate<void>(this, &staticMetaObject, 16, nullptr, _t1);
}

// SIGNAL 17
void Ekos::CaptureDeviceAdaptor::flatSyncFocusChanged(bool _t1)
{
    QMetaObject::activate<void>(this, &staticMetaObject, 17, nullptr, _t1);
}

// SIGNAL 18
void Ekos::CaptureDeviceAdaptor::hasShutter(bool _t1)
{
    QMetaObject::activate<void>(this, &staticMetaObject, 18, nullptr, _t1);
}
QT_WARNING_POP
