/********************************************************************************
** Form generated from reading UI file 'details_links.ui'
**
** Created by: Qt User Interface Compiler version 6.11.1
**
** WARNING! All changes made in this file will be lost when recompiling UI file!
********************************************************************************/

#ifndef UI_DETAILS_LINKS_H
#define UI_DETAILS_LINKS_H

#include <QtCore/QVariant>
#include <QtWidgets/QApplication>
#include <QtWidgets/QHBoxLayout>
#include <QtWidgets/QLabel>
#include <QtWidgets/QListWidget>
#include <QtWidgets/QPushButton>
#include <QtWidgets/QSpacerItem>
#include <QtWidgets/QVBoxLayout>
#include <QtWidgets/QWidget>
#include <klocalizedstring.h>

QT_BEGIN_NAMESPACE

class Ui_DetailsLinks
{
public:
    QVBoxLayout *vboxLayout;
    QVBoxLayout *vboxLayout1;
    QLabel *InfoTitle;
    QListWidget *InfoTitleList;
    QSpacerItem *spacerItem;
    QVBoxLayout *vboxLayout2;
    QLabel *ImagesTitle;
    QListWidget *ImageTitleList;
    QHBoxLayout *hboxLayout;
    QPushButton *ViewButton;
    QPushButton *AddLinkButton;
    QPushButton *EditLinkButton;
    QPushButton *RemoveLinkButton;
    QSpacerItem *spacerItem1;

    void setupUi(QWidget *DetailsLinks)
    {
        if (DetailsLinks->objectName().isEmpty())
            DetailsLinks->setObjectName("DetailsLinks");
        DetailsLinks->resize(512, 236);
        vboxLayout = new QVBoxLayout(DetailsLinks);
#ifndef UI_Q_OS_MAC
        vboxLayout->setSpacing(6);
#endif
        vboxLayout->setContentsMargins(10, 10, 10, 10);
        vboxLayout->setObjectName("vboxLayout");
        vboxLayout1 = new QVBoxLayout();
        vboxLayout1->setSpacing(0);
#ifndef UI_Q_OS_MAC
        vboxLayout1->setContentsMargins(0, 0, 0, 0);
#endif
        vboxLayout1->setObjectName("vboxLayout1");
        InfoTitle = new QLabel(DetailsLinks);
        InfoTitle->setObjectName("InfoTitle");
        QFont font;
        font.setFamilies({QString::fromUtf8("Sans Serif")});
        font.setPointSize(10);
        font.setBold(true);
        font.setItalic(false);
        font.setUnderline(false);
        font.setStrikeOut(false);
        InfoTitle->setFont(font);
        InfoTitle->setAutoFillBackground(true);
        InfoTitle->setAlignment(Qt::AlignCenter);

        vboxLayout1->addWidget(InfoTitle);

        InfoTitleList = new QListWidget(DetailsLinks);
        InfoTitleList->setObjectName("InfoTitleList");
        InfoTitleList->setFrameShape(QFrame::Box);
        InfoTitleList->setFrameShadow(QFrame::Plain);
        InfoTitleList->setLineWidth(4);

        vboxLayout1->addWidget(InfoTitleList);


        vboxLayout->addLayout(vboxLayout1);

        spacerItem = new QSpacerItem(20, 16, QSizePolicy::Policy::Minimum, QSizePolicy::Policy::Fixed);

        vboxLayout->addItem(spacerItem);

        vboxLayout2 = new QVBoxLayout();
        vboxLayout2->setSpacing(0);
        vboxLayout2->setContentsMargins(0, 0, 0, 0);
        vboxLayout2->setObjectName("vboxLayout2");
        ImagesTitle = new QLabel(DetailsLinks);
        ImagesTitle->setObjectName("ImagesTitle");
        ImagesTitle->setFont(font);
        ImagesTitle->setAutoFillBackground(true);
        ImagesTitle->setAlignment(Qt::AlignHCenter);

        vboxLayout2->addWidget(ImagesTitle);

        ImageTitleList = new QListWidget(DetailsLinks);
        ImageTitleList->setObjectName("ImageTitleList");
        ImageTitleList->setFrameShape(QFrame::Box);
        ImageTitleList->setFrameShadow(QFrame::Plain);
        ImageTitleList->setLineWidth(4);

        vboxLayout2->addWidget(ImageTitleList);


        vboxLayout->addLayout(vboxLayout2);

        hboxLayout = new QHBoxLayout();
#ifndef UI_Q_OS_MAC
        hboxLayout->setSpacing(6);
#endif
        hboxLayout->setContentsMargins(0, 0, 0, 0);
        hboxLayout->setObjectName("hboxLayout");
        ViewButton = new QPushButton(DetailsLinks);
        ViewButton->setObjectName("ViewButton");

        hboxLayout->addWidget(ViewButton);

        AddLinkButton = new QPushButton(DetailsLinks);
        AddLinkButton->setObjectName("AddLinkButton");

        hboxLayout->addWidget(AddLinkButton);

        EditLinkButton = new QPushButton(DetailsLinks);
        EditLinkButton->setObjectName("EditLinkButton");

        hboxLayout->addWidget(EditLinkButton);

        RemoveLinkButton = new QPushButton(DetailsLinks);
        RemoveLinkButton->setObjectName("RemoveLinkButton");

        hboxLayout->addWidget(RemoveLinkButton);

        spacerItem1 = new QSpacerItem(40, 20, QSizePolicy::Policy::Expanding, QSizePolicy::Policy::Minimum);

        hboxLayout->addItem(spacerItem1);


        vboxLayout->addLayout(hboxLayout);


        retranslateUi(DetailsLinks);

        QMetaObject::connectSlotsByName(DetailsLinks);
    } // setupUi

    void retranslateUi(QWidget *DetailsLinks)
    {
        DetailsLinks->setWindowTitle(tr2i18n("Details - Resource Links", nullptr));
        InfoTitle->setText(tr2i18n("Information Links", nullptr));
        ImagesTitle->setText(tr2i18n("Image Links", nullptr));
        ViewButton->setText(tr2i18n("View Resource", nullptr));
        AddLinkButton->setText(tr2i18n("Add Link...", nullptr));
        EditLinkButton->setText(tr2i18n("Edit Link...", nullptr));
        RemoveLinkButton->setText(tr2i18n("Remove Link", nullptr));
    } // retranslateUi

};

namespace Ui {
    class DetailsLinks: public Ui_DetailsLinks {};
} // namespace Ui

QT_END_NAMESPACE

#endif // DETAILS_LINKS_H

