/********************************************************************************
** Form generated from reading UI file 'polarishourangle.ui'
**
** Created by: Qt User Interface Compiler version 6.11.1
**
** WARNING! All changes made in this file will be lost when recompiling UI file!
********************************************************************************/

#ifndef UI_POLARISHOURANGLE_H
#define UI_POLARISHOURANGLE_H

#include <QtCore/QVariant>
#include <QtWidgets/QApplication>
#include <QtWidgets/QDateTimeEdit>
#include <QtWidgets/QDialog>
#include <QtWidgets/QFrame>
#include <QtWidgets/QGroupBox>
#include <QtWidgets/QHBoxLayout>
#include <QtWidgets/QLabel>
#include <QtWidgets/QPushButton>
#include <QtWidgets/QRadioButton>
#include <QtWidgets/QSpacerItem>
#include <QtWidgets/QVBoxLayout>
#include <klocalizedstring.h>

QT_BEGIN_NAMESPACE

class Ui_PolarisHourAngle
{
public:
    QHBoxLayout *horizontalLayout_2;
    QFrame *frame;
    QVBoxLayout *verticalLayout;
    QGroupBox *groupBox;
    QVBoxLayout *verticalLayout_4;
    QVBoxLayout *verticalLayout_3;
    QLabel *labelDate;
    QLabel *labelTime;
    QGroupBox *groupBox_2;
    QVBoxLayout *verticalLayout_6;
    QVBoxLayout *verticalLayout_5;
    QLabel *labelPolarisHA;
    QPushButton *currentTimeB;
    QLabel *label;
    QDateTimeEdit *dateTimeEdit;
    QHBoxLayout *horizontalLayout;
    QRadioButton *twelveHourR;
    QRadioButton *twentyFourHourR;
    QSpacerItem *verticalSpacer;

    void setupUi(QDialog *PolarisHourAngle)
    {
        if (PolarisHourAngle->objectName().isEmpty())
            PolarisHourAngle->setObjectName("PolarisHourAngle");
        PolarisHourAngle->resize(667, 526);
        horizontalLayout_2 = new QHBoxLayout(PolarisHourAngle);
        horizontalLayout_2->setObjectName("horizontalLayout_2");
        frame = new QFrame(PolarisHourAngle);
        frame->setObjectName("frame");
        QSizePolicy sizePolicy(QSizePolicy::Policy::Fixed, QSizePolicy::Policy::Fixed);
        sizePolicy.setHorizontalStretch(0);
        sizePolicy.setVerticalStretch(0);
        sizePolicy.setHeightForWidth(frame->sizePolicy().hasHeightForWidth());
        frame->setSizePolicy(sizePolicy);
        frame->setMinimumSize(QSize(512, 512));
        frame->setFrameShape(QFrame::Panel);
        frame->setFrameShadow(QFrame::Raised);

        horizontalLayout_2->addWidget(frame);

        verticalLayout = new QVBoxLayout();
        verticalLayout->setObjectName("verticalLayout");
        groupBox = new QGroupBox(PolarisHourAngle);
        groupBox->setObjectName("groupBox");
        verticalLayout_4 = new QVBoxLayout(groupBox);
        verticalLayout_4->setObjectName("verticalLayout_4");
        verticalLayout_3 = new QVBoxLayout();
        verticalLayout_3->setObjectName("verticalLayout_3");
        labelDate = new QLabel(groupBox);
        labelDate->setObjectName("labelDate");
        QFont font;
        font.setPointSize(10);
        font.setBold(true);
        labelDate->setFont(font);
        labelDate->setAlignment(Qt::AlignCenter);

        verticalLayout_3->addWidget(labelDate);

        labelTime = new QLabel(groupBox);
        labelTime->setObjectName("labelTime");
        labelTime->setFont(font);
        labelTime->setAlignment(Qt::AlignCenter);

        verticalLayout_3->addWidget(labelTime);


        verticalLayout_4->addLayout(verticalLayout_3);


        verticalLayout->addWidget(groupBox);

        groupBox_2 = new QGroupBox(PolarisHourAngle);
        groupBox_2->setObjectName("groupBox_2");
        verticalLayout_6 = new QVBoxLayout(groupBox_2);
        verticalLayout_6->setObjectName("verticalLayout_6");
        verticalLayout_5 = new QVBoxLayout();
        verticalLayout_5->setObjectName("verticalLayout_5");
        labelPolarisHA = new QLabel(groupBox_2);
        labelPolarisHA->setObjectName("labelPolarisHA");
        labelPolarisHA->setFont(font);
        labelPolarisHA->setAlignment(Qt::AlignCenter);

        verticalLayout_5->addWidget(labelPolarisHA);


        verticalLayout_6->addLayout(verticalLayout_5);


        verticalLayout->addWidget(groupBox_2);

        currentTimeB = new QPushButton(PolarisHourAngle);
        currentTimeB->setObjectName("currentTimeB");

        verticalLayout->addWidget(currentTimeB);

        label = new QLabel(PolarisHourAngle);
        label->setObjectName("label");

        verticalLayout->addWidget(label);

        dateTimeEdit = new QDateTimeEdit(PolarisHourAngle);
        dateTimeEdit->setObjectName("dateTimeEdit");
        dateTimeEdit->setCurrentSection(QDateTimeEdit::DaySection);
        dateTimeEdit->setCalendarPopup(false);

        verticalLayout->addWidget(dateTimeEdit);

        horizontalLayout = new QHBoxLayout();
        horizontalLayout->setSpacing(3);
        horizontalLayout->setObjectName("horizontalLayout");
        twelveHourR = new QRadioButton(PolarisHourAngle);
        twelveHourR->setObjectName("twelveHourR");
        twelveHourR->setChecked(false);

        horizontalLayout->addWidget(twelveHourR);

        twentyFourHourR = new QRadioButton(PolarisHourAngle);
        twentyFourHourR->setObjectName("twentyFourHourR");
        twentyFourHourR->setChecked(true);

        horizontalLayout->addWidget(twentyFourHourR);


        verticalLayout->addLayout(horizontalLayout);

        verticalSpacer = new QSpacerItem(20, 40, QSizePolicy::Policy::Minimum, QSizePolicy::Policy::Expanding);

        verticalLayout->addItem(verticalSpacer);


        horizontalLayout_2->addLayout(verticalLayout);


        retranslateUi(PolarisHourAngle);

        QMetaObject::connectSlotsByName(PolarisHourAngle);
    } // setupUi

    void retranslateUi(QDialog *PolarisHourAngle)
    {
        PolarisHourAngle->setWindowTitle(tr2i18n("Polaris Hour Angle", nullptr));
        groupBox->setTitle(tr2i18n("Date / Time", nullptr));
        labelDate->setText(tr2i18n("TextLabel", nullptr));
        labelTime->setText(tr2i18n("TextLabel", nullptr));
        groupBox_2->setTitle(tr2i18n("Polaris HourAngle", nullptr));
        labelPolarisHA->setText(tr2i18n("TextLabel", nullptr));
        currentTimeB->setText(tr2i18n("Current time", nullptr));
        label->setText(tr2i18n("Set Local Time", nullptr));
        twelveHourR->setText(tr2i18n("12 Hour", nullptr));
        twentyFourHourR->setText(tr2i18n("24 Hours", nullptr));
    } // retranslateUi

};

namespace Ui {
    class PolarisHourAngle: public Ui_PolarisHourAngle {};
} // namespace Ui

QT_END_NAMESPACE

#endif // POLARISHOURANGLE_H

