/********************************************************************************
** Form generated from reading UI file 'argfindobject.ui'
**
** Created by: Qt User Interface Compiler version 6.11.1
**
** WARNING! All changes made in this file will be lost when recompiling UI file!
********************************************************************************/

#ifndef UI_ARGFINDOBJECT_H
#define UI_ARGFINDOBJECT_H

#include <QtCore/QVariant>
#include <QtWidgets/QApplication>
#include <QtWidgets/QHBoxLayout>
#include <QtWidgets/QLabel>
#include <QtWidgets/QLineEdit>
#include <QtWidgets/QPushButton>
#include <QtWidgets/QSpacerItem>
#include <QtWidgets/QVBoxLayout>
#include <QtWidgets/QWidget>
#include <klocalizedstring.h>

QT_BEGIN_NAMESPACE

class Ui_ArgFindObject
{
public:
    QVBoxLayout *vboxLayout;
    QHBoxLayout *hboxLayout;
    QLabel *textLabel1;
    QLineEdit *NameEdit;
    QPushButton *FindButton;
    QSpacerItem *spacerItem;
    QSpacerItem *spacerItem1;

    void setupUi(QWidget *ArgFindObject)
    {
        if (ArgFindObject->objectName().isEmpty())
            ArgFindObject->setObjectName("ArgFindObject");
        ArgFindObject->resize(311, 69);
        vboxLayout = new QVBoxLayout(ArgFindObject);
        vboxLayout->setContentsMargins(10, 10, 10, 10);
        vboxLayout->setObjectName("vboxLayout");
        hboxLayout = new QHBoxLayout();
        hboxLayout->setObjectName("hboxLayout");
        textLabel1 = new QLabel(ArgFindObject);
        textLabel1->setObjectName("textLabel1");

        hboxLayout->addWidget(textLabel1);

        NameEdit = new QLineEdit(ArgFindObject);
        NameEdit->setObjectName("NameEdit");

        hboxLayout->addWidget(NameEdit);

        FindButton = new QPushButton(ArgFindObject);
        FindButton->setObjectName("FindButton");
        QFont font;
        font.setPointSize(9);
        font.setBold(false);
        font.setItalic(false);
        font.setUnderline(false);
        font.setStrikeOut(false);
        FindButton->setFont(font);

        hboxLayout->addWidget(FindButton);

        spacerItem = new QSpacerItem(40, 20, QSizePolicy::Policy::Expanding, QSizePolicy::Policy::Minimum);

        hboxLayout->addItem(spacerItem);


        vboxLayout->addLayout(hboxLayout);

        spacerItem1 = new QSpacerItem(20, 40, QSizePolicy::Policy::Minimum, QSizePolicy::Policy::Expanding);

        vboxLayout->addItem(spacerItem1);


        retranslateUi(ArgFindObject);

        QMetaObject::connectSlotsByName(ArgFindObject);
    } // setupUi

    void retranslateUi(QWidget *ArgFindObject)
    {
        textLabel1->setText(tr2i18n("Name:", nullptr));
#if QT_CONFIG(tooltip)
        FindButton->setToolTip(tr2i18n("Select object from a list", nullptr));
#endif // QT_CONFIG(tooltip)
#if QT_CONFIG(whatsthis)
        FindButton->setWhatsThis(tr2i18n("Opens the Find Object dialog, which allows you to select an object from the list of known objects.  When an object has been selected, its name will appear in the \"dir\" box at left.", nullptr));
#endif // QT_CONFIG(whatsthis)
        FindButton->setText(tr2i18n("Object...", nullptr));
        (void)ArgFindObject;
    } // retranslateUi

};

namespace Ui {
    class ArgFindObject: public Ui_ArgFindObject {};
} // namespace Ui

QT_END_NAMESPACE

#endif // ARGFINDOBJECT_H

