/****************************************************************************
** Meta object code from reading C++ file 'mountcontrolpanel.h'
**
** Created by: The Qt Meta Object Compiler version 69 (Qt 6.11.1)
**
** WARNING! All changes made in this file will be lost!
*****************************************************************************/

#include "../../../../kstars-3.8.4.1/kstars/ekos/mount/mountcontrolpanel.h"
#include <QtCore/qmetatype.h>

#include <QtCore/qtmochelpers.h>

#include <memory>


#include <QtCore/qxptype_traits.h>
#if !defined(Q_MOC_OUTPUT_REVISION)
#error "The header file 'mountcontrolpanel.h' doesn't include <QObject>."
#elif Q_MOC_OUTPUT_REVISION != 69
#error "This file was generated using the moc from 6.11.1. It"
#error "cannot be used with the include files from this version of Qt."
#error "(The moc has changed too much.)"
#endif

#ifndef Q_CONSTINIT
#define Q_CONSTINIT
#endif

QT_WARNING_PUSH
QT_WARNING_DISABLE_DEPRECATED
QT_WARNING_DISABLE_GCC("-Wuseless-cast")
namespace {
struct qt_meta_tag_ZN4Ekos17MountControlPanelE_t {};
} // unnamed namespace

template <> constexpr inline auto Ekos::MountControlPanel::qt_create_metaobjectdata<qt_meta_tag_ZN4Ekos17MountControlPanelE_t>()
{
    namespace QMC = QtMocConstants;
    QtMocHelpers::StringRefStorage qt_stringData {
        "Ekos::MountControlPanel",
        "newMotionCommand",
        "",
        "command",
        "NS",
        "WE",
        "newSlewRate",
        "rate",
        "aborted",
        "park",
        "unpark",
        "center",
        "sync",
        "RA",
        "DE",
        "slew",
        "updownReversed",
        "enable",
        "leftrightReversed",
        "isJ2000"
    };

    QtMocHelpers::UintData qt_methods {
        // Signal 'newMotionCommand'
        QtMocHelpers::SignalData<void(int, int, int)>(1, 2, QMC::AccessPublic, QMetaType::Void, {{
            { QMetaType::Int, 3 }, { QMetaType::Int, 4 }, { QMetaType::Int, 5 },
        }}),
        // Signal 'newSlewRate'
        QtMocHelpers::SignalData<void(int)>(6, 2, QMC::AccessPublic, QMetaType::Void, {{
            { QMetaType::Int, 7 },
        }}),
        // Signal 'aborted'
        QtMocHelpers::SignalData<void()>(8, 2, QMC::AccessPublic, QMetaType::Void),
        // Signal 'park'
        QtMocHelpers::SignalData<void()>(9, 2, QMC::AccessPublic, QMetaType::Void),
        // Signal 'unpark'
        QtMocHelpers::SignalData<void()>(10, 2, QMC::AccessPublic, QMetaType::Void),
        // Signal 'center'
        QtMocHelpers::SignalData<void()>(11, 2, QMC::AccessPublic, QMetaType::Void),
        // Signal 'sync'
        QtMocHelpers::SignalData<void(double, double)>(12, 2, QMC::AccessPublic, QMetaType::Void, {{
            { QMetaType::Double, 13 }, { QMetaType::Double, 14 },
        }}),
        // Signal 'slew'
        QtMocHelpers::SignalData<void(double, double)>(15, 2, QMC::AccessPublic, QMetaType::Void, {{
            { QMetaType::Double, 13 }, { QMetaType::Double, 14 },
        }}),
        // Signal 'updownReversed'
        QtMocHelpers::SignalData<void(bool)>(16, 2, QMC::AccessPublic, QMetaType::Void, {{
            { QMetaType::Bool, 17 },
        }}),
        // Signal 'leftrightReversed'
        QtMocHelpers::SignalData<void(bool)>(18, 2, QMC::AccessPublic, QMetaType::Void, {{
            { QMetaType::Bool, 17 },
        }}),
    };
    QtMocHelpers::UintData qt_properties {
        // property 'isJ2000'
        QtMocHelpers::PropertyData<bool>(19, QMetaType::Bool, QMC::DefaultPropertyFlags | QMC::Writable),
    };
    QtMocHelpers::UintData qt_enums {
    };
    return QtMocHelpers::metaObjectData<MountControlPanel, qt_meta_tag_ZN4Ekos17MountControlPanelE_t>(QMC::MetaObjectFlag{}, qt_stringData,
            qt_methods, qt_properties, qt_enums);
}
Q_CONSTINIT const QMetaObject Ekos::MountControlPanel::staticMetaObject = { {
    QMetaObject::SuperData::link<QDialog::staticMetaObject>(),
    qt_staticMetaObjectStaticContent<qt_meta_tag_ZN4Ekos17MountControlPanelE_t>.stringdata,
    qt_staticMetaObjectStaticContent<qt_meta_tag_ZN4Ekos17MountControlPanelE_t>.data,
    qt_static_metacall,
    nullptr,
    qt_staticMetaObjectRelocatingContent<qt_meta_tag_ZN4Ekos17MountControlPanelE_t>.metaTypes,
    nullptr
} };

void Ekos::MountControlPanel::qt_static_metacall(QObject *_o, QMetaObject::Call _c, int _id, void **_a)
{
    auto *_t = static_cast<MountControlPanel *>(_o);
    if (_c == QMetaObject::InvokeMetaMethod) {
        switch (_id) {
        case 0: _t->newMotionCommand((*reinterpret_cast<std::add_pointer_t<int>>(_a[1])),(*reinterpret_cast<std::add_pointer_t<int>>(_a[2])),(*reinterpret_cast<std::add_pointer_t<int>>(_a[3]))); break;
        case 1: _t->newSlewRate((*reinterpret_cast<std::add_pointer_t<int>>(_a[1]))); break;
        case 2: _t->aborted(); break;
        case 3: _t->park(); break;
        case 4: _t->unpark(); break;
        case 5: _t->center(); break;
        case 6: _t->sync((*reinterpret_cast<std::add_pointer_t<double>>(_a[1])),(*reinterpret_cast<std::add_pointer_t<double>>(_a[2]))); break;
        case 7: _t->slew((*reinterpret_cast<std::add_pointer_t<double>>(_a[1])),(*reinterpret_cast<std::add_pointer_t<double>>(_a[2]))); break;
        case 8: _t->updownReversed((*reinterpret_cast<std::add_pointer_t<bool>>(_a[1]))); break;
        case 9: _t->leftrightReversed((*reinterpret_cast<std::add_pointer_t<bool>>(_a[1]))); break;
        default: ;
        }
    }
    if (_c == QMetaObject::IndexOfMethod) {
        if (QtMocHelpers::indexOfMethod<void (MountControlPanel::*)(int , int , int )>(_a, &MountControlPanel::newMotionCommand, 0))
            return;
        if (QtMocHelpers::indexOfMethod<void (MountControlPanel::*)(int )>(_a, &MountControlPanel::newSlewRate, 1))
            return;
        if (QtMocHelpers::indexOfMethod<void (MountControlPanel::*)()>(_a, &MountControlPanel::aborted, 2))
            return;
        if (QtMocHelpers::indexOfMethod<void (MountControlPanel::*)()>(_a, &MountControlPanel::park, 3))
            return;
        if (QtMocHelpers::indexOfMethod<void (MountControlPanel::*)()>(_a, &MountControlPanel::unpark, 4))
            return;
        if (QtMocHelpers::indexOfMethod<void (MountControlPanel::*)()>(_a, &MountControlPanel::center, 5))
            return;
        if (QtMocHelpers::indexOfMethod<void (MountControlPanel::*)(double , double )>(_a, &MountControlPanel::sync, 6))
            return;
        if (QtMocHelpers::indexOfMethod<void (MountControlPanel::*)(double , double )>(_a, &MountControlPanel::slew, 7))
            return;
        if (QtMocHelpers::indexOfMethod<void (MountControlPanel::*)(bool )>(_a, &MountControlPanel::updownReversed, 8))
            return;
        if (QtMocHelpers::indexOfMethod<void (MountControlPanel::*)(bool )>(_a, &MountControlPanel::leftrightReversed, 9))
            return;
    }
    if (_c == QMetaObject::ReadProperty) {
        void *_v = _a[0];
        switch (_id) {
        case 0: *reinterpret_cast<bool*>(_v) = _t->m_isJ2000; break;
        default: break;
        }
    }
    if (_c == QMetaObject::WriteProperty) {
        void *_v = _a[0];
        switch (_id) {
        case 0: QtMocHelpers::setProperty(_t->m_isJ2000, *reinterpret_cast<bool*>(_v)); break;
        default: break;
        }
    }
}

const QMetaObject *Ekos::MountControlPanel::metaObject() const
{
    return QObject::d_ptr->metaObject ? QObject::d_ptr->dynamicMetaObject() : &staticMetaObject;
}

void *Ekos::MountControlPanel::qt_metacast(const char *_clname)
{
    if (!_clname) return nullptr;
    if (!strcmp(_clname, qt_staticMetaObjectStaticContent<qt_meta_tag_ZN4Ekos17MountControlPanelE_t>.strings))
        return static_cast<void*>(this);
    if (!strcmp(_clname, "Ui::MountControlPanel"))
        return static_cast< Ui::MountControlPanel*>(this);
    return QDialog::qt_metacast(_clname);
}

int Ekos::MountControlPanel::qt_metacall(QMetaObject::Call _c, int _id, void **_a)
{
    _id = QDialog::qt_metacall(_c, _id, _a);
    if (_id < 0)
        return _id;
    if (_c == QMetaObject::InvokeMetaMethod) {
        if (_id < 10)
            qt_static_metacall(this, _c, _id, _a);
        _id -= 10;
    }
    if (_c == QMetaObject::RegisterMethodArgumentMetaType) {
        if (_id < 10)
            *reinterpret_cast<QMetaType *>(_a[0]) = QMetaType();
        _id -= 10;
    }
    if (_c == QMetaObject::ReadProperty || _c == QMetaObject::WriteProperty
            || _c == QMetaObject::ResetProperty || _c == QMetaObject::BindableProperty
            || _c == QMetaObject::RegisterPropertyMetaType) {
        qt_static_metacall(this, _c, _id, _a);
        _id -= 1;
    }
    return _id;
}

// SIGNAL 0
void Ekos::MountControlPanel::newMotionCommand(int _t1, int _t2, int _t3)
{
    QMetaObject::activate<void>(this, &staticMetaObject, 0, nullptr, _t1, _t2, _t3);
}

// SIGNAL 1
void Ekos::MountControlPanel::newSlewRate(int _t1)
{
    QMetaObject::activate<void>(this, &staticMetaObject, 1, nullptr, _t1);
}

// SIGNAL 2
void Ekos::MountControlPanel::aborted()
{
    QMetaObject::activate(this, &staticMetaObject, 2, nullptr);
}

// SIGNAL 3
void Ekos::MountControlPanel::park()
{
    QMetaObject::activate(this, &staticMetaObject, 3, nullptr);
}

// SIGNAL 4
void Ekos::MountControlPanel::unpark()
{
    QMetaObject::activate(this, &staticMetaObject, 4, nullptr);
}

// SIGNAL 5
void Ekos::MountControlPanel::center()
{
    QMetaObject::activate(this, &staticMetaObject, 5, nullptr);
}

// SIGNAL 6
void Ekos::MountControlPanel::sync(double _t1, double _t2)
{
    QMetaObject::activate<void>(this, &staticMetaObject, 6, nullptr, _t1, _t2);
}

// SIGNAL 7
void Ekos::MountControlPanel::slew(double _t1, double _t2)
{
    QMetaObject::activate<void>(this, &staticMetaObject, 7, nullptr, _t1, _t2);
}

// SIGNAL 8
void Ekos::MountControlPanel::updownReversed(bool _t1)
{
    QMetaObject::activate<void>(this, &staticMetaObject, 8, nullptr, _t1);
}

// SIGNAL 9
void Ekos::MountControlPanel::leftrightReversed(bool _t1)
{
    QMetaObject::activate<void>(this, &staticMetaObject, 9, nullptr, _t1);
}
QT_WARNING_POP
