/****************************************************************************
** Meta object code from reading C++ file 'fitsdata.h'
**
** Created by: The Qt Meta Object Compiler version 69 (Qt 6.11.1)
**
** WARNING! All changes made in this file will be lost!
*****************************************************************************/

#include "../../../../kstars-3.8.4.1/kstars/fitsviewer/fitsdata.h"
#include <QtNetwork/QSslError>
#include <QtCore/qmetatype.h>
#include <QtCore/QList>

#include <QtCore/qtmochelpers.h>

#include <memory>


#include <QtCore/qxptype_traits.h>
#if !defined(Q_MOC_OUTPUT_REVISION)
#error "The header file 'fitsdata.h' doesn't include <QObject>."
#elif Q_MOC_OUTPUT_REVISION != 69
#error "This file was generated using the moc from 6.11.1. It"
#error "cannot be used with the include files from this version of Qt."
#error "(The moc has changed too much.)"
#endif

#ifndef Q_CONSTINIT
#define Q_CONSTINIT
#endif

QT_WARNING_PUSH
QT_WARNING_DISABLE_DEPRECATED
QT_WARNING_DISABLE_GCC("-Wuseless-cast")
namespace {
struct qt_meta_tag_ZN8FITSDataE_t {};
} // unnamed namespace

template <> constexpr inline auto FITSData::qt_create_metaobjectdata<qt_meta_tag_ZN8FITSDataE_t>()
{
    namespace QMC = QtMocConstants;
    QtMocHelpers::StringRefStorage qt_stringData {
        "FITSData",
        "converted",
        "",
        "QImage",
        "histogramReady",
        "dataChanged",
        "headerChanged",
        "loadingCatalogData",
        "loadedCatalogData",
        "catalogQueryFailed",
        "text",
        "plateSolveSub",
        "ra",
        "dec",
        "pixScale",
        "index",
        "healpix",
        "LiveStackFrameWeighting",
        "weighting",
        "stackInProgress",
        "alignMasterChosen",
        "alignMaster",
        "stackReady",
        "cancelled",
        "stackUpdateStats",
        "ok",
        "sub",
        "total",
        "meanSNR",
        "minSNR",
        "maxSNR",
        "initStackMon",
        "timestamp",
        "QList<LiveStackFile>",
        "subs",
        "addStackMon",
        "updateStackMon",
        "QList<LiveStackStageInfo>",
        "infos",
        "makeRoiBuffer",
        "QRect",
        "roi",
        "newStackSubs",
        "newFile",
        "filename",
        "extension",
        "size",
        "width",
        "height",
        "mode",
        "FITSMode",
        "channels",
        "bpp",
        "hasWCS",
        "hasDebayer"
    };

    QtMocHelpers::UintData qt_methods {
        // Signal 'converted'
        QtMocHelpers::SignalData<void(QImage)>(1, 2, QMC::AccessPublic, QMetaType::Void, {{
            { 0x80000000 | 3, 2 },
        }}),
        // Signal 'histogramReady'
        QtMocHelpers::SignalData<void()>(4, 2, QMC::AccessPublic, QMetaType::Void),
        // Signal 'dataChanged'
        QtMocHelpers::SignalData<void()>(5, 2, QMC::AccessPublic, QMetaType::Void),
        // Signal 'headerChanged'
        QtMocHelpers::SignalData<void()>(6, 2, QMC::AccessPublic, QMetaType::Void),
        // Signal 'loadingCatalogData'
        QtMocHelpers::SignalData<void()>(7, 2, QMC::AccessPublic, QMetaType::Void),
        // Signal 'loadedCatalogData'
        QtMocHelpers::SignalData<void()>(8, 2, QMC::AccessPublic, QMetaType::Void),
        // Signal 'catalogQueryFailed'
        QtMocHelpers::SignalData<void(const QString)>(9, 2, QMC::AccessPublic, QMetaType::Void, {{
            { QMetaType::QString, 10 },
        }}),
        // Signal 'plateSolveSub'
        QtMocHelpers::SignalData<void(const double, const double, const double, const int, const int, const LiveStackFrameWeighting &)>(11, 2, QMC::AccessPublic, QMetaType::Void, {{
            { QMetaType::Double, 12 }, { QMetaType::Double, 13 }, { QMetaType::Double, 14 }, { QMetaType::Int, 15 },
            { QMetaType::Int, 16 }, { 0x80000000 | 17, 18 },
        }}),
        // Signal 'stackInProgress'
        QtMocHelpers::SignalData<void()>(19, 2, QMC::AccessPublic, QMetaType::Void),
        // Signal 'alignMasterChosen'
        QtMocHelpers::SignalData<void(const QString &)>(20, 2, QMC::AccessPublic, QMetaType::Void, {{
            { QMetaType::QString, 21 },
        }}),
        // Signal 'stackReady'
        QtMocHelpers::SignalData<void(const bool)>(22, 2, QMC::AccessPublic, QMetaType::Void, {{
            { QMetaType::Bool, 23 },
        }}),
        // Signal 'stackReady'
        QtMocHelpers::SignalData<void()>(22, 2, QMC::AccessPublic | QMC::MethodCloned, QMetaType::Void),
        // Signal 'stackUpdateStats'
        QtMocHelpers::SignalData<void(const bool, const int, const int, const double, const double, const double)>(24, 2, QMC::AccessPublic, QMetaType::Void, {{
            { QMetaType::Bool, 25 }, { QMetaType::Int, 26 }, { QMetaType::Int, 27 }, { QMetaType::Double, 28 },
            { QMetaType::Double, 29 }, { QMetaType::Double, 30 },
        }}),
        // Signal 'initStackMon'
        QtMocHelpers::SignalData<void(QDateTime, const QVector<LiveStackFile> &)>(31, 2, QMC::AccessPublic, QMetaType::Void, {{
            { QMetaType::QDateTime, 32 }, { 0x80000000 | 33, 34 },
        }}),
        // Signal 'addStackMon'
        QtMocHelpers::SignalData<void(QDateTime, const QVector<LiveStackFile> &)>(35, 2, QMC::AccessPublic, QMetaType::Void, {{
            { QMetaType::QDateTime, 32 }, { 0x80000000 | 33, 34 },
        }}),
        // Signal 'updateStackMon'
        QtMocHelpers::SignalData<void(const QVector<LiveStackFile> &, const QVector<LiveStackStageInfo> &)>(36, 2, QMC::AccessPublic, QMetaType::Void, {{
            { 0x80000000 | 33, 34 }, { 0x80000000 | 37, 38 },
        }}),
        // Slot 'makeRoiBuffer'
        QtMocHelpers::SlotData<void(QRect)>(39, 2, QMC::AccessPublic, QMetaType::Void, {{
            { 0x80000000 | 40, 41 },
        }}),
        // Slot 'newStackSubs'
        QtMocHelpers::SlotData<void(QDateTime, const QVector<LiveStackFile> &)>(42, 2, QMC::AccessPublic, QMetaType::Void, {{
            { QMetaType::QDateTime, 32 }, { 0x80000000 | 33, 43 },
        }}),
    };
    QtMocHelpers::UintData qt_properties {
        // property 'filename'
        QtMocHelpers::PropertyData<QString>(44, QMetaType::QString, QMC::DefaultPropertyFlags),
        // property 'extension'
        QtMocHelpers::PropertyData<QString>(45, QMetaType::QString, QMC::DefaultPropertyFlags),
        // property 'size'
        QtMocHelpers::PropertyData<qint64>(46, QMetaType::LongLong, QMC::DefaultPropertyFlags),
        // property 'width'
        QtMocHelpers::PropertyData<quint16>(47, QMetaType::UShort, QMC::DefaultPropertyFlags),
        // property 'height'
        QtMocHelpers::PropertyData<quint16>(48, QMetaType::UShort, QMC::DefaultPropertyFlags),
        // property 'mode'
        QtMocHelpers::PropertyData<FITSMode>(49, 0x80000000 | 50, QMC::DefaultPropertyFlags | QMC::Writable | QMC::EnumOrFlag),
        // property 'channels'
        QtMocHelpers::PropertyData<quint8>(51, QMetaType::UChar, QMC::DefaultPropertyFlags),
        // property 'bpp'
        QtMocHelpers::PropertyData<quint8>(52, QMetaType::UChar, QMC::DefaultPropertyFlags),
        // property 'hasWCS'
        QtMocHelpers::PropertyData<bool>(53, QMetaType::Bool, QMC::DefaultPropertyFlags),
        // property 'hasDebayer'
        QtMocHelpers::PropertyData<bool>(54, QMetaType::Bool, QMC::DefaultPropertyFlags),
    };
    QtMocHelpers::UintData qt_enums {
    };
    return QtMocHelpers::metaObjectData<FITSData, qt_meta_tag_ZN8FITSDataE_t>(QMC::MetaObjectFlag{}, qt_stringData,
            qt_methods, qt_properties, qt_enums);
}
Q_CONSTINIT const QMetaObject FITSData::staticMetaObject = { {
    QMetaObject::SuperData::link<QObject::staticMetaObject>(),
    qt_staticMetaObjectStaticContent<qt_meta_tag_ZN8FITSDataE_t>.stringdata,
    qt_staticMetaObjectStaticContent<qt_meta_tag_ZN8FITSDataE_t>.data,
    qt_static_metacall,
    nullptr,
    qt_staticMetaObjectRelocatingContent<qt_meta_tag_ZN8FITSDataE_t>.metaTypes,
    nullptr
} };

void FITSData::qt_static_metacall(QObject *_o, QMetaObject::Call _c, int _id, void **_a)
{
    auto *_t = static_cast<FITSData *>(_o);
    if (_c == QMetaObject::InvokeMetaMethod) {
        switch (_id) {
        case 0: _t->converted((*reinterpret_cast<std::add_pointer_t<QImage>>(_a[1]))); break;
        case 1: _t->histogramReady(); break;
        case 2: _t->dataChanged(); break;
        case 3: _t->headerChanged(); break;
        case 4: _t->loadingCatalogData(); break;
        case 5: _t->loadedCatalogData(); break;
        case 6: _t->catalogQueryFailed((*reinterpret_cast<std::add_pointer_t<QString>>(_a[1]))); break;
        case 7: _t->plateSolveSub((*reinterpret_cast<std::add_pointer_t<double>>(_a[1])),(*reinterpret_cast<std::add_pointer_t<double>>(_a[2])),(*reinterpret_cast<std::add_pointer_t<double>>(_a[3])),(*reinterpret_cast<std::add_pointer_t<int>>(_a[4])),(*reinterpret_cast<std::add_pointer_t<int>>(_a[5])),(*reinterpret_cast<std::add_pointer_t<LiveStackFrameWeighting>>(_a[6]))); break;
        case 8: _t->stackInProgress(); break;
        case 9: _t->alignMasterChosen((*reinterpret_cast<std::add_pointer_t<QString>>(_a[1]))); break;
        case 10: _t->stackReady((*reinterpret_cast<std::add_pointer_t<bool>>(_a[1]))); break;
        case 11: _t->stackReady(); break;
        case 12: _t->stackUpdateStats((*reinterpret_cast<std::add_pointer_t<bool>>(_a[1])),(*reinterpret_cast<std::add_pointer_t<int>>(_a[2])),(*reinterpret_cast<std::add_pointer_t<int>>(_a[3])),(*reinterpret_cast<std::add_pointer_t<double>>(_a[4])),(*reinterpret_cast<std::add_pointer_t<double>>(_a[5])),(*reinterpret_cast<std::add_pointer_t<double>>(_a[6]))); break;
        case 13: _t->initStackMon((*reinterpret_cast<std::add_pointer_t<QDateTime>>(_a[1])),(*reinterpret_cast<std::add_pointer_t<QList<LiveStackFile>>>(_a[2]))); break;
        case 14: _t->addStackMon((*reinterpret_cast<std::add_pointer_t<QDateTime>>(_a[1])),(*reinterpret_cast<std::add_pointer_t<QList<LiveStackFile>>>(_a[2]))); break;
        case 15: _t->updateStackMon((*reinterpret_cast<std::add_pointer_t<QList<LiveStackFile>>>(_a[1])),(*reinterpret_cast<std::add_pointer_t<QList<LiveStackStageInfo>>>(_a[2]))); break;
        case 16: _t->makeRoiBuffer((*reinterpret_cast<std::add_pointer_t<QRect>>(_a[1]))); break;
        case 17: _t->newStackSubs((*reinterpret_cast<std::add_pointer_t<QDateTime>>(_a[1])),(*reinterpret_cast<std::add_pointer_t<QList<LiveStackFile>>>(_a[2]))); break;
        default: ;
        }
    }
    if (_c == QMetaObject::RegisterMethodArgumentMetaType) {
        switch (_id) {
        default: *reinterpret_cast<QMetaType *>(_a[0]) = QMetaType(); break;
        case 15:
            switch (*reinterpret_cast<int*>(_a[1])) {
            default: *reinterpret_cast<QMetaType *>(_a[0]) = QMetaType(); break;
            case 1:
                *reinterpret_cast<QMetaType *>(_a[0]) = QMetaType::fromType< QList<LiveStackStageInfo> >(); break;
            }
            break;
        }
    }
    if (_c == QMetaObject::IndexOfMethod) {
        if (QtMocHelpers::indexOfMethod<void (FITSData::*)(QImage )>(_a, &FITSData::converted, 0))
            return;
        if (QtMocHelpers::indexOfMethod<void (FITSData::*)()>(_a, &FITSData::histogramReady, 1))
            return;
        if (QtMocHelpers::indexOfMethod<void (FITSData::*)()>(_a, &FITSData::dataChanged, 2))
            return;
        if (QtMocHelpers::indexOfMethod<void (FITSData::*)()>(_a, &FITSData::headerChanged, 3))
            return;
        if (QtMocHelpers::indexOfMethod<void (FITSData::*)()>(_a, &FITSData::loadingCatalogData, 4))
            return;
        if (QtMocHelpers::indexOfMethod<void (FITSData::*)()>(_a, &FITSData::loadedCatalogData, 5))
            return;
        if (QtMocHelpers::indexOfMethod<void (FITSData::*)(const QString )>(_a, &FITSData::catalogQueryFailed, 6))
            return;
        if (QtMocHelpers::indexOfMethod<void (FITSData::*)(const double , const double , const double , const int , const int , const LiveStackFrameWeighting & )>(_a, &FITSData::plateSolveSub, 7))
            return;
        if (QtMocHelpers::indexOfMethod<void (FITSData::*)()>(_a, &FITSData::stackInProgress, 8))
            return;
        if (QtMocHelpers::indexOfMethod<void (FITSData::*)(const QString & )>(_a, &FITSData::alignMasterChosen, 9))
            return;
        if (QtMocHelpers::indexOfMethod<void (FITSData::*)(const bool )>(_a, &FITSData::stackReady, 10))
            return;
        if (QtMocHelpers::indexOfMethod<void (FITSData::*)(const bool , const int , const int , const double , const double , const double )>(_a, &FITSData::stackUpdateStats, 12))
            return;
        if (QtMocHelpers::indexOfMethod<void (FITSData::*)(QDateTime , const QVector<LiveStackFile> & )>(_a, &FITSData::initStackMon, 13))
            return;
        if (QtMocHelpers::indexOfMethod<void (FITSData::*)(QDateTime , const QVector<LiveStackFile> & )>(_a, &FITSData::addStackMon, 14))
            return;
        if (QtMocHelpers::indexOfMethod<void (FITSData::*)(const QVector<LiveStackFile> & , const QVector<LiveStackStageInfo> & )>(_a, &FITSData::updateStackMon, 15))
            return;
    }
    if (_c == QMetaObject::ReadProperty) {
        void *_v = _a[0];
        switch (_id) {
        case 0: *reinterpret_cast<QString*>(_v) = _t->filename(); break;
        case 1: *reinterpret_cast<QString*>(_v) = _t->extension(); break;
        case 2: *reinterpret_cast<qint64*>(_v) = _t->size(); break;
        case 3: *reinterpret_cast<quint16*>(_v) = _t->width(); break;
        case 4: *reinterpret_cast<quint16*>(_v) = _t->height(); break;
        case 5: *reinterpret_cast<FITSMode*>(_v) = _t->m_Mode; break;
        case 6: *reinterpret_cast<quint8*>(_v) = _t->channels(); break;
        case 7: *reinterpret_cast<quint8*>(_v) = _t->bpp(); break;
        case 8: *reinterpret_cast<bool*>(_v) = _t->hasWCS(); break;
        case 9: *reinterpret_cast<bool*>(_v) = _t->hasDebayer(); break;
        default: break;
        }
    }
    if (_c == QMetaObject::WriteProperty) {
        void *_v = _a[0];
        switch (_id) {
        case 5: QtMocHelpers::setProperty(_t->m_Mode, *reinterpret_cast<FITSMode*>(_v)); break;
        default: break;
        }
    }
}

const QMetaObject *FITSData::metaObject() const
{
    return QObject::d_ptr->metaObject ? QObject::d_ptr->dynamicMetaObject() : &staticMetaObject;
}

void *FITSData::qt_metacast(const char *_clname)
{
    if (!_clname) return nullptr;
    if (!strcmp(_clname, qt_staticMetaObjectStaticContent<qt_meta_tag_ZN8FITSDataE_t>.strings))
        return static_cast<void*>(this);
    return QObject::qt_metacast(_clname);
}

int FITSData::qt_metacall(QMetaObject::Call _c, int _id, void **_a)
{
    _id = QObject::qt_metacall(_c, _id, _a);
    if (_id < 0)
        return _id;
    if (_c == QMetaObject::InvokeMetaMethod) {
        if (_id < 18)
            qt_static_metacall(this, _c, _id, _a);
        _id -= 18;
    }
    if (_c == QMetaObject::RegisterMethodArgumentMetaType) {
        if (_id < 18)
            qt_static_metacall(this, _c, _id, _a);
        _id -= 18;
    }
    if (_c == QMetaObject::ReadProperty || _c == QMetaObject::WriteProperty
            || _c == QMetaObject::ResetProperty || _c == QMetaObject::BindableProperty
            || _c == QMetaObject::RegisterPropertyMetaType) {
        qt_static_metacall(this, _c, _id, _a);
        _id -= 10;
    }
    return _id;
}

// SIGNAL 0
void FITSData::converted(QImage _t1)
{
    QMetaObject::activate<void>(this, &staticMetaObject, 0, nullptr, _t1);
}

// SIGNAL 1
void FITSData::histogramReady()
{
    QMetaObject::activate(this, &staticMetaObject, 1, nullptr);
}

// SIGNAL 2
void FITSData::dataChanged()
{
    QMetaObject::activate(this, &staticMetaObject, 2, nullptr);
}

// SIGNAL 3
void FITSData::headerChanged()
{
    QMetaObject::activate(this, &staticMetaObject, 3, nullptr);
}

// SIGNAL 4
void FITSData::loadingCatalogData()
{
    QMetaObject::activate(this, &staticMetaObject, 4, nullptr);
}

// SIGNAL 5
void FITSData::loadedCatalogData()
{
    QMetaObject::activate(this, &staticMetaObject, 5, nullptr);
}

// SIGNAL 6
void FITSData::catalogQueryFailed(const QString _t1)
{
    QMetaObject::activate<void>(this, &staticMetaObject, 6, nullptr, _t1);
}

// SIGNAL 7
void FITSData::plateSolveSub(const double _t1, const double _t2, const double _t3, const int _t4, const int _t5, const LiveStackFrameWeighting & _t6)
{
    QMetaObject::activate<void>(this, &staticMetaObject, 7, nullptr, _t1, _t2, _t3, _t4, _t5, _t6);
}

// SIGNAL 8
void FITSData::stackInProgress()
{
    QMetaObject::activate(this, &staticMetaObject, 8, nullptr);
}

// SIGNAL 9
void FITSData::alignMasterChosen(const QString & _t1)
{
    QMetaObject::activate<void>(this, &staticMetaObject, 9, nullptr, _t1);
}

// SIGNAL 10
void FITSData::stackReady(const bool _t1)
{
    QMetaObject::activate<void>(this, &staticMetaObject, 10, nullptr, _t1);
}

// SIGNAL 12
void FITSData::stackUpdateStats(const bool _t1, const int _t2, const int _t3, const double _t4, const double _t5, const double _t6)
{
    QMetaObject::activate<void>(this, &staticMetaObject, 12, nullptr, _t1, _t2, _t3, _t4, _t5, _t6);
}

// SIGNAL 13
void FITSData::initStackMon(QDateTime _t1, const QVector<LiveStackFile> & _t2)
{
    QMetaObject::activate<void>(this, &staticMetaObject, 13, nullptr, _t1, _t2);
}

// SIGNAL 14
void FITSData::addStackMon(QDateTime _t1, const QVector<LiveStackFile> & _t2)
{
    QMetaObject::activate<void>(this, &staticMetaObject, 14, nullptr, _t1, _t2);
}

// SIGNAL 15
void FITSData::updateStackMon(const QVector<LiveStackFile> & _t1, const QVector<LiveStackStageInfo> & _t2)
{
    QMetaObject::activate<void>(this, &staticMetaObject, 15, nullptr, _t1, _t2);
}
QT_WARNING_POP
