/********************************************************************************
** Form generated from reading UI file 'modcalceclipticcoords.ui'
**
** Created by: Qt User Interface Compiler version 6.11.1
**
** WARNING! All changes made in this file will be lost when recompiling UI file!
********************************************************************************/

#ifndef UI_MODCALCECLIPTICCOORDS_H
#define UI_MODCALCECLIPTICCOORDS_H

#include <QtCore/QVariant>
#include <QtWidgets/QApplication>
#include <QtWidgets/QDateTimeEdit>
#include <QtWidgets/QGridLayout>
#include <QtWidgets/QGroupBox>
#include <QtWidgets/QHBoxLayout>
#include <QtWidgets/QLabel>
#include <QtWidgets/QLineEdit>
#include <QtWidgets/QPushButton>
#include <QtWidgets/QSpacerItem>
#include <QtWidgets/QTabWidget>
#include <QtWidgets/QVBoxLayout>
#include <QtWidgets/QWidget>
#include <klocalizedstring.h>
#include "widgets/dmsbox.h"

QT_BEGIN_NAMESPACE

class Ui_modCalcEclCoordsDlg
{
public:
    QVBoxLayout *vboxLayout;
    QTabWidget *tabWidget;
    QWidget *interact;
    QVBoxLayout *vboxLayout1;
    QHBoxLayout *hboxLayout;
    QLabel *label_5;
    QDateTimeEdit *DateTime;
    QPushButton *NowButton;
    QSpacerItem *spacerItem;
    QHBoxLayout *hboxLayout1;
    QGroupBox *groupBox_3;
    QGridLayout *gridLayout;
    QLabel *raLabel;
    QLabel *decLabel;
    dmsBox *RA;
    dmsBox *Dec;
    QPushButton *ObjectButton;
    QGroupBox *groupBox_2;
    QVBoxLayout *vboxLayout2;
    QGridLayout *gridLayout1;
    QLabel *label_2;
    QLabel *label;
    dmsBox *EcLong;
    dmsBox *EcLat;
    QSpacerItem *spacerItem1;
    QSpacerItem *spacerItem2;

    void setupUi(QWidget *modCalcEclCoordsDlg)
    {
        if (modCalcEclCoordsDlg->objectName().isEmpty())
            modCalcEclCoordsDlg->setObjectName("modCalcEclCoordsDlg");
        modCalcEclCoordsDlg->resize(639, 495);
        vboxLayout = new QVBoxLayout(modCalcEclCoordsDlg);
        vboxLayout->setSpacing(6);
        vboxLayout->setObjectName("vboxLayout");
        vboxLayout->setContentsMargins(9, 9, 9, 9);
        tabWidget = new QTabWidget(modCalcEclCoordsDlg);
        tabWidget->setObjectName("tabWidget");
        interact = new QWidget();
        interact->setObjectName("interact");
        vboxLayout1 = new QVBoxLayout(interact);
        vboxLayout1->setObjectName("vboxLayout1");
        hboxLayout = new QHBoxLayout();
        hboxLayout->setObjectName("hboxLayout");
        label_5 = new QLabel(interact);
        label_5->setObjectName("label_5");

        hboxLayout->addWidget(label_5);

        DateTime = new QDateTimeEdit(interact);
        DateTime->setObjectName("DateTime");

        hboxLayout->addWidget(DateTime);

        NowButton = new QPushButton(interact);
        NowButton->setObjectName("NowButton");

        hboxLayout->addWidget(NowButton);

        spacerItem = new QSpacerItem(40, 20, QSizePolicy::Policy::Expanding, QSizePolicy::Policy::Minimum);

        hboxLayout->addItem(spacerItem);


        vboxLayout1->addLayout(hboxLayout);

        hboxLayout1 = new QHBoxLayout();
        hboxLayout1->setSpacing(6);
        hboxLayout1->setObjectName("hboxLayout1");
        hboxLayout1->setContentsMargins(0, 0, 0, 0);
        groupBox_3 = new QGroupBox(interact);
        groupBox_3->setObjectName("groupBox_3");
        gridLayout = new QGridLayout(groupBox_3);
        gridLayout->setSpacing(6);
        gridLayout->setObjectName("gridLayout");
        gridLayout->setContentsMargins(8, 8, 8, 8);
        raLabel = new QLabel(groupBox_3);
        raLabel->setObjectName("raLabel");

        gridLayout->addWidget(raLabel, 0, 0, 1, 1);

        decLabel = new QLabel(groupBox_3);
        decLabel->setObjectName("decLabel");

        gridLayout->addWidget(decLabel, 1, 0, 1, 1);

        RA = new dmsBox(groupBox_3);
        RA->setObjectName("RA");

        gridLayout->addWidget(RA, 0, 1, 1, 1);

        Dec = new dmsBox(groupBox_3);
        Dec->setObjectName("Dec");

        gridLayout->addWidget(Dec, 1, 1, 1, 1);

        ObjectButton = new QPushButton(groupBox_3);
        ObjectButton->setObjectName("ObjectButton");

        gridLayout->addWidget(ObjectButton, 2, 1, 1, 1);


        hboxLayout1->addWidget(groupBox_3);

        groupBox_2 = new QGroupBox(interact);
        groupBox_2->setObjectName("groupBox_2");
        vboxLayout2 = new QVBoxLayout(groupBox_2);
        vboxLayout2->setSpacing(6);
        vboxLayout2->setObjectName("vboxLayout2");
        vboxLayout2->setContentsMargins(8, 8, 8, 8);
        gridLayout1 = new QGridLayout();
        gridLayout1->setSpacing(6);
        gridLayout1->setObjectName("gridLayout1");
        gridLayout1->setContentsMargins(0, 0, 0, 0);
        label_2 = new QLabel(groupBox_2);
        label_2->setObjectName("label_2");

        gridLayout1->addWidget(label_2, 1, 0, 1, 1);

        label = new QLabel(groupBox_2);
        label->setObjectName("label");

        gridLayout1->addWidget(label, 0, 0, 1, 1);

        EcLong = new dmsBox(groupBox_2);
        EcLong->setObjectName("EcLong");

        gridLayout1->addWidget(EcLong, 0, 1, 1, 1);

        EcLat = new dmsBox(groupBox_2);
        EcLat->setObjectName("EcLat");

        gridLayout1->addWidget(EcLat, 1, 1, 1, 1);


        vboxLayout2->addLayout(gridLayout1);

        spacerItem1 = new QSpacerItem(40, 20, QSizePolicy::Policy::Expanding, QSizePolicy::Policy::Minimum);

        vboxLayout2->addItem(spacerItem1);


        hboxLayout1->addWidget(groupBox_2);


        vboxLayout1->addLayout(hboxLayout1);

        spacerItem2 = new QSpacerItem(20, 40, QSizePolicy::Policy::Minimum, QSizePolicy::Policy::Expanding);

        vboxLayout1->addItem(spacerItem2);

        tabWidget->addTab(interact, QString());

        vboxLayout->addWidget(tabWidget);

        QWidget::setTabOrder(tabWidget, RA);
        QWidget::setTabOrder(RA, Dec);
        QWidget::setTabOrder(Dec, EcLong);
        QWidget::setTabOrder(EcLong, EcLat);

        retranslateUi(modCalcEclCoordsDlg);

        tabWidget->setCurrentIndex(0);


        QMetaObject::connectSlotsByName(modCalcEclCoordsDlg);
    } // setupUi

    void retranslateUi(QWidget *modCalcEclCoordsDlg)
    {
        label_5->setText(tr2i18n("Date and time:", nullptr));
        NowButton->setText(tr2i18n("Now", nullptr));
        groupBox_3->setTitle(tr2i18n("Equatorial Coordinates", nullptr));
        raLabel->setText(tr2i18n("Right ascension:", nullptr));
        decLabel->setText(tr2i18n("Declination:", nullptr));
        ObjectButton->setText(tr2i18n("Select Object...", nullptr));
        groupBox_2->setTitle(tr2i18n("Ecliptic Coordinates", nullptr));
        label_2->setText(tr2i18n("Latitude:", nullptr));
        label->setText(tr2i18n("Longitude:", nullptr));
        tabWidget->setTabText(tabWidget->indexOf(interact), tr2i18n("Interactive Mode", nullptr));
        (void)modCalcEclCoordsDlg;
    } // retranslateUi

};

namespace Ui {
    class modCalcEclCoordsDlg: public Ui_modCalcEclCoordsDlg {};
} // namespace Ui

QT_END_NAMESPACE

#endif // MODCALCECLIPTICCOORDS_H

