/********************************************************************************
** Form generated from reading UI file 'opsdither.ui'
**
** Created by: Qt User Interface Compiler version 6.11.1
**
** WARNING! All changes made in this file will be lost when recompiling UI file!
********************************************************************************/

#ifndef UI_OPSDITHER_H
#define UI_OPSDITHER_H

#include <QtCore/QVariant>
#include <QtWidgets/QApplication>
#include <QtWidgets/QCheckBox>
#include <QtWidgets/QDoubleSpinBox>
#include <QtWidgets/QGridLayout>
#include <QtWidgets/QGroupBox>
#include <QtWidgets/QHBoxLayout>
#include <QtWidgets/QLabel>
#include <QtWidgets/QSpacerItem>
#include <QtWidgets/QSpinBox>
#include <QtWidgets/QVBoxLayout>
#include <QtWidgets/QWidget>
#include <klocalizedstring.h>

QT_BEGIN_NAMESPACE

class Ui_OpsDither
{
public:
    QVBoxLayout *verticalLayout_2;
    QGroupBox *groupBox_3;
    QVBoxLayout *verticalLayout;
    QGridLayout *gridLayout;
    QDoubleSpinBox *kcfg_DitherPixels;
    QLabel *label_4;
    QLabel *label_5;
    QLabel *label_6;
    QSpinBox *kcfg_DitherTimeout;
    QCheckBox *kcfg_DitherEnabled;
    QLabel *l_22;
    QDoubleSpinBox *kcfg_DitherThreshold;
    QLabel *label_9;
    QLabel *label_7;
    QLabel *label_8;
    QSpinBox *kcfg_DitherSettle;
    QSpinBox *kcfg_DitherFrames;
    QLabel *label;
    QLabel *label_15;
    QLabel *label_3;
    QSpinBox *kcfg_DitherMaxIterations;
    QCheckBox *kcfg_DitherWithOnePulse;
    QCheckBox *kcfg_DitherFailAbortsAutoGuide;
    QHBoxLayout *horizontalLayout;
    QCheckBox *kcfg_DitherNoGuiding;
    QSpinBox *kcfg_DitherNoGuidingPulse;
    QLabel *label_10;
    QSpacerItem *verticalSpacer;

    void setupUi(QWidget *OpsDither)
    {
        if (OpsDither->objectName().isEmpty())
            OpsDither->setObjectName("OpsDither");
        OpsDither->resize(361, 604);
        verticalLayout_2 = new QVBoxLayout(OpsDither);
        verticalLayout_2->setSpacing(3);
        verticalLayout_2->setObjectName("verticalLayout_2");
        verticalLayout_2->setContentsMargins(3, 3, 3, 3);
        groupBox_3 = new QGroupBox(OpsDither);
        groupBox_3->setObjectName("groupBox_3");
        verticalLayout = new QVBoxLayout(groupBox_3);
        verticalLayout->setObjectName("verticalLayout");
        gridLayout = new QGridLayout();
        gridLayout->setSpacing(3);
        gridLayout->setObjectName("gridLayout");
        kcfg_DitherPixels = new QDoubleSpinBox(groupBox_3);
        kcfg_DitherPixels->setObjectName("kcfg_DitherPixels");
        kcfg_DitherPixels->setMinimum(0.100000000000000);
        kcfg_DitherPixels->setMaximum(30.000000000000000);
        kcfg_DitherPixels->setSingleStep(0.100000000000000);
        kcfg_DitherPixels->setValue(2.000000000000000);

        gridLayout->addWidget(kcfg_DitherPixels, 0, 1, 1, 1);

        label_4 = new QLabel(groupBox_3);
        label_4->setObjectName("label_4");

        gridLayout->addWidget(label_4, 3, 0, 1, 1);

        label_5 = new QLabel(groupBox_3);
        label_5->setObjectName("label_5");

        gridLayout->addWidget(label_5, 3, 2, 1, 1);

        label_6 = new QLabel(groupBox_3);
        label_6->setObjectName("label_6");

        gridLayout->addWidget(label_6, 2, 0, 1, 1);

        kcfg_DitherTimeout = new QSpinBox(groupBox_3);
        kcfg_DitherTimeout->setObjectName("kcfg_DitherTimeout");
        kcfg_DitherTimeout->setMaximum(360);

        gridLayout->addWidget(kcfg_DitherTimeout, 4, 1, 1, 1);

        kcfg_DitherEnabled = new QCheckBox(groupBox_3);
        kcfg_DitherEnabled->setObjectName("kcfg_DitherEnabled");

        gridLayout->addWidget(kcfg_DitherEnabled, 0, 0, 1, 1);

        l_22 = new QLabel(groupBox_3);
        l_22->setObjectName("l_22");

        gridLayout->addWidget(l_22, 0, 2, 1, 1);

        kcfg_DitherThreshold = new QDoubleSpinBox(groupBox_3);
        kcfg_DitherThreshold->setObjectName("kcfg_DitherThreshold");
        kcfg_DitherThreshold->setMaximum(50.000000000000000);

        gridLayout->addWidget(kcfg_DitherThreshold, 2, 1, 1, 1);

        label_9 = new QLabel(groupBox_3);
        label_9->setObjectName("label_9");

        gridLayout->addWidget(label_9, 4, 2, 1, 1);

        label_7 = new QLabel(groupBox_3);
        label_7->setObjectName("label_7");

        gridLayout->addWidget(label_7, 2, 2, 1, 1);

        label_8 = new QLabel(groupBox_3);
        label_8->setObjectName("label_8");

        gridLayout->addWidget(label_8, 4, 0, 1, 1);

        kcfg_DitherSettle = new QSpinBox(groupBox_3);
        kcfg_DitherSettle->setObjectName("kcfg_DitherSettle");
        kcfg_DitherSettle->setMaximum(360);

        gridLayout->addWidget(kcfg_DitherSettle, 3, 1, 1, 1);

        kcfg_DitherFrames = new QSpinBox(groupBox_3);
        kcfg_DitherFrames->setObjectName("kcfg_DitherFrames");
        kcfg_DitherFrames->setMinimum(1);
        kcfg_DitherFrames->setMaximum(60);

        gridLayout->addWidget(kcfg_DitherFrames, 1, 1, 1, 1);

        label = new QLabel(groupBox_3);
        label->setObjectName("label");

        gridLayout->addWidget(label, 1, 2, 1, 1);

        label_15 = new QLabel(groupBox_3);
        label_15->setObjectName("label_15");

        gridLayout->addWidget(label_15, 1, 0, 1, 1);

        label_3 = new QLabel(groupBox_3);
        label_3->setObjectName("label_3");

        gridLayout->addWidget(label_3, 5, 0, 1, 1);

        kcfg_DitherMaxIterations = new QSpinBox(groupBox_3);
        kcfg_DitherMaxIterations->setObjectName("kcfg_DitherMaxIterations");
        kcfg_DitherMaxIterations->setMinimum(1);
        kcfg_DitherMaxIterations->setMaximum(30);

        gridLayout->addWidget(kcfg_DitherMaxIterations, 5, 1, 1, 1);


        verticalLayout->addLayout(gridLayout);

        kcfg_DitherWithOnePulse = new QCheckBox(groupBox_3);
        kcfg_DitherWithOnePulse->setObjectName("kcfg_DitherWithOnePulse");

        verticalLayout->addWidget(kcfg_DitherWithOnePulse);

        kcfg_DitherFailAbortsAutoGuide = new QCheckBox(groupBox_3);
        kcfg_DitherFailAbortsAutoGuide->setObjectName("kcfg_DitherFailAbortsAutoGuide");

        verticalLayout->addWidget(kcfg_DitherFailAbortsAutoGuide);

        horizontalLayout = new QHBoxLayout();
        horizontalLayout->setObjectName("horizontalLayout");
        kcfg_DitherNoGuiding = new QCheckBox(groupBox_3);
        kcfg_DitherNoGuiding->setObjectName("kcfg_DitherNoGuiding");

        horizontalLayout->addWidget(kcfg_DitherNoGuiding);

        kcfg_DitherNoGuidingPulse = new QSpinBox(groupBox_3);
        kcfg_DitherNoGuidingPulse->setObjectName("kcfg_DitherNoGuidingPulse");
        kcfg_DitherNoGuidingPulse->setMinimum(10);
        kcfg_DitherNoGuidingPulse->setMaximum(10000);
        kcfg_DitherNoGuidingPulse->setSingleStep(100);

        horizontalLayout->addWidget(kcfg_DitherNoGuidingPulse);

        label_10 = new QLabel(groupBox_3);
        label_10->setObjectName("label_10");

        horizontalLayout->addWidget(label_10);


        verticalLayout->addLayout(horizontalLayout);


        verticalLayout_2->addWidget(groupBox_3);

        verticalSpacer = new QSpacerItem(20, 40, QSizePolicy::Policy::Minimum, QSizePolicy::Policy::Expanding);

        verticalLayout_2->addItem(verticalSpacer);

        QWidget::setTabOrder(kcfg_DitherEnabled, kcfg_DitherPixels);
        QWidget::setTabOrder(kcfg_DitherPixels, kcfg_DitherFrames);
        QWidget::setTabOrder(kcfg_DitherFrames, kcfg_DitherThreshold);
        QWidget::setTabOrder(kcfg_DitherThreshold, kcfg_DitherSettle);
        QWidget::setTabOrder(kcfg_DitherSettle, kcfg_DitherTimeout);
        QWidget::setTabOrder(kcfg_DitherTimeout, kcfg_DitherMaxIterations);
        QWidget::setTabOrder(kcfg_DitherMaxIterations, kcfg_DitherFailAbortsAutoGuide);
        QWidget::setTabOrder(kcfg_DitherFailAbortsAutoGuide, kcfg_DitherNoGuiding);
        QWidget::setTabOrder(kcfg_DitherNoGuiding, kcfg_DitherNoGuidingPulse);

        retranslateUi(OpsDither);

        QMetaObject::connectSlotsByName(OpsDither);
    } // setupUi

    void retranslateUi(QWidget *OpsDither)
    {
        groupBox_3->setTitle(QString());
#if QT_CONFIG(tooltip)
        kcfg_DitherPixels->setToolTip(tr2i18n("Number of pixels to move the guiding square in a random direction.", nullptr));
#endif // QT_CONFIG(tooltip)
#if QT_CONFIG(tooltip)
        label_4->setToolTip(tr2i18n("After dither is successful, wait for this many seconds before proceeding.", nullptr));
#endif // QT_CONFIG(tooltip)
        label_4->setText(tr2i18n("Settle", nullptr));
        label_5->setText(tr2i18n("seconds", nullptr));
#if QT_CONFIG(tooltip)
        label_6->setToolTip(QString());
#endif // QT_CONFIG(tooltip)
        label_6->setText(tr2i18n("PHD2 Dither Threshold", nullptr));
#if QT_CONFIG(tooltip)
        kcfg_DitherTimeout->setToolTip(tr2i18n("<html><head/><body><p>Maximum allowable distance for dithering to be considered settled (PHD2 only).</p></body></html>", nullptr));
#endif // QT_CONFIG(tooltip)
#if QT_CONFIG(tooltip)
        kcfg_DitherEnabled->setToolTip(tr2i18n("Move locked guiding square location after frame capture", nullptr));
#endif // QT_CONFIG(tooltip)
        kcfg_DitherEnabled->setText(tr2i18n("Dither", nullptr));
        l_22->setText(tr2i18n("pixels", nullptr));
#if QT_CONFIG(tooltip)
        kcfg_DitherThreshold->setToolTip(tr2i18n("Maximum allowable distance for guiding to be considered settled (PHD2 only).", nullptr));
#endif // QT_CONFIG(tooltip)
        label_9->setText(tr2i18n("seconds", nullptr));
        label_7->setText(tr2i18n("pixels", nullptr));
        label_8->setText(tr2i18n("PHD2 Dither Timeout", nullptr));
#if QT_CONFIG(tooltip)
        kcfg_DitherSettle->setToolTip(tr2i18n("After dither is successful, wait for this many seconds before proceeding.", nullptr));
#endif // QT_CONFIG(tooltip)
#if QT_CONFIG(tooltip)
        kcfg_DitherFrames->setToolTip(tr2i18n("Dither after this many captured frames in the CCD module", nullptr));
#endif // QT_CONFIG(tooltip)
        label->setText(tr2i18n("frames", nullptr));
#if QT_CONFIG(tooltip)
        label_15->setToolTip(tr2i18n("Dither after this many captured frames in the CCD module", nullptr));
#endif // QT_CONFIG(tooltip)
        label_15->setText(tr2i18n("Frequency", nullptr));
#if QT_CONFIG(tooltip)
        label_3->setToolTip(tr2i18n("<html><head/><body><p>Maximum dithering iteration attempts before giving up</p></body></html>", nullptr));
#endif // QT_CONFIG(tooltip)
        label_3->setText(tr2i18n("Max. Iterations", nullptr));
#if QT_CONFIG(tooltip)
        kcfg_DitherMaxIterations->setToolTip(tr2i18n("<html><head/><body><p>Maximum dithering iteration attempts before giving up</p></body></html>", nullptr));
#endif // QT_CONFIG(tooltip)
#if QT_CONFIG(tooltip)
        kcfg_DitherWithOnePulse->setToolTip(tr2i18n("<html><head/><body><p>If checked, dithering amount is randomly generated, pulses are sent, but the resultant pixel dithering amount is not enforced so only the one dither pulse is sent. This is quicker, and recommended as dither amount is random anyway. It is necessary when 2-D dither is required but guiding is only done in one axis.</p></body></html>", nullptr));
#endif // QT_CONFIG(tooltip)
        kcfg_DitherWithOnePulse->setText(tr2i18n("One Pulse Dither", nullptr));
#if QT_CONFIG(tooltip)
        kcfg_DitherFailAbortsAutoGuide->setToolTip(tr2i18n("<html><head/><body><p>If checked, autoguiding is aborted when dithering fails. Otherwise, guiding resumes normally.</p></body></html>", nullptr));
#endif // QT_CONFIG(tooltip)
        kcfg_DitherFailAbortsAutoGuide->setText(tr2i18n("Abort Autoguide on failure", nullptr));
#if QT_CONFIG(tooltip)
        kcfg_DitherNoGuiding->setToolTip(tr2i18n("<html><head/><body><p>Perform dithering when not guiding.</p></body></html>", nullptr));
#endif // QT_CONFIG(tooltip)
        kcfg_DitherNoGuiding->setText(tr2i18n("Non-Guide Dither Pulse", nullptr));
#if QT_CONFIG(tooltip)
        kcfg_DitherNoGuidingPulse->setToolTip(tr2i18n("Pulse length in milliseconds to command mount motion in a random direction", nullptr));
#endif // QT_CONFIG(tooltip)
        label_10->setText(tr2i18n("ms", nullptr));
        (void)OpsDither;
    } // retranslateUi

};

namespace Ui {
    class OpsDither: public Ui_OpsDither {};
} // namespace Ui

QT_END_NAMESPACE

#endif // OPSDITHER_H

