/****************************************************************************
** Meta object code from reading C++ file 'sequencejob.h'
**
** Created by: The Qt Meta Object Compiler version 69 (Qt 6.11.1)
**
** WARNING! All changes made in this file will be lost!
*****************************************************************************/

#include "../../../../kstars-3.8.4.1/kstars/ekos/capture/sequencejob.h"
#include <QtNetwork/QSslError>
#include <QtDataVisualization/qbar3dseries.h>
#include <QtDataVisualization/q3dscene.h>
#include <QtGui/qtextcursor.h>
#include <QtCore/qmetatype.h>

#include <QtCore/qtmochelpers.h>

#include <memory>


#include <QtCore/qxptype_traits.h>
#if !defined(Q_MOC_OUTPUT_REVISION)
#error "The header file 'sequencejob.h' doesn't include <QObject>."
#elif Q_MOC_OUTPUT_REVISION != 69
#error "This file was generated using the moc from 6.11.1. It"
#error "cannot be used with the include files from this version of Qt."
#error "(The moc has changed too much.)"
#endif

#ifndef Q_CONSTINIT
#define Q_CONSTINIT
#endif

QT_WARNING_PUSH
QT_WARNING_DISABLE_DEPRECATED
QT_WARNING_DISABLE_GCC("-Wuseless-cast")
namespace {
struct qt_meta_tag_ZN4Ekos11SequenceJobE_t {};
} // unnamed namespace

template <> constexpr inline auto Ekos::SequenceJob::qt_create_metaobjectdata<qt_meta_tag_ZN4Ekos11SequenceJobE_t>()
{
    namespace QMC = QtMocConstants;
    QtMocHelpers::StringRefStorage qt_stringData {
        "Ekos::SequenceJob",
        "prepareComplete",
        "",
        "success",
        "captureStarted",
        "CaptureResult",
        "rc",
        "abortCapture",
        "newLog",
        "prepareState",
        "CaptureState",
        "state",
        "prepareCapture",
        "CCDFrameType",
        "frameType",
        "enforceCCDTemp",
        "enforceStartGuiderDrift",
        "isPreview",
        "updateGuiderDrift",
        "deviation_rms"
    };

    QtMocHelpers::UintData qt_methods {
        // Signal 'prepareComplete'
        QtMocHelpers::SignalData<void(bool)>(1, 2, QMC::AccessPublic, QMetaType::Void, {{
            { QMetaType::Bool, 3 },
        }}),
        // Signal 'prepareComplete'
        QtMocHelpers::SignalData<void()>(1, 2, QMC::AccessPublic | QMC::MethodCloned, QMetaType::Void),
        // Signal 'captureStarted'
        QtMocHelpers::SignalData<void(CaptureResult)>(4, 2, QMC::AccessPublic, QMetaType::Void, {{
            { 0x80000000 | 5, 6 },
        }}),
        // Signal 'abortCapture'
        QtMocHelpers::SignalData<void()>(7, 2, QMC::AccessPublic, QMetaType::Void),
        // Signal 'newLog'
        QtMocHelpers::SignalData<void(QString)>(8, 2, QMC::AccessPublic, QMetaType::Void, {{
            { QMetaType::QString, 2 },
        }}),
        // Signal 'prepareState'
        QtMocHelpers::SignalData<void(CaptureState)>(9, 2, QMC::AccessPublic, QMetaType::Void, {{
            { 0x80000000 | 10, 11 },
        }}),
        // Signal 'prepareCapture'
        QtMocHelpers::SignalData<void(CCDFrameType, bool, bool, bool)>(12, 2, QMC::AccessPublic, QMetaType::Void, {{
            { 0x80000000 | 13, 14 }, { QMetaType::Bool, 15 }, { QMetaType::Bool, 16 }, { QMetaType::Bool, 17 },
        }}),
        // Signal 'updateGuiderDrift'
        QtMocHelpers::SignalData<void(double)>(18, 2, QMC::AccessPublic, QMetaType::Void, {{
            { QMetaType::Double, 19 },
        }}),
    };
    QtMocHelpers::UintData qt_properties {
    };
    QtMocHelpers::UintData qt_enums {
    };
    return QtMocHelpers::metaObjectData<SequenceJob, qt_meta_tag_ZN4Ekos11SequenceJobE_t>(QMC::MetaObjectFlag{}, qt_stringData,
            qt_methods, qt_properties, qt_enums);
}
Q_CONSTINIT const QMetaObject Ekos::SequenceJob::staticMetaObject = { {
    QMetaObject::SuperData::link<QObject::staticMetaObject>(),
    qt_staticMetaObjectStaticContent<qt_meta_tag_ZN4Ekos11SequenceJobE_t>.stringdata,
    qt_staticMetaObjectStaticContent<qt_meta_tag_ZN4Ekos11SequenceJobE_t>.data,
    qt_static_metacall,
    nullptr,
    qt_staticMetaObjectRelocatingContent<qt_meta_tag_ZN4Ekos11SequenceJobE_t>.metaTypes,
    nullptr
} };

void Ekos::SequenceJob::qt_static_metacall(QObject *_o, QMetaObject::Call _c, int _id, void **_a)
{
    auto *_t = static_cast<SequenceJob *>(_o);
    if (_c == QMetaObject::InvokeMetaMethod) {
        switch (_id) {
        case 0: _t->prepareComplete((*reinterpret_cast<std::add_pointer_t<bool>>(_a[1]))); break;
        case 1: _t->prepareComplete(); break;
        case 2: _t->captureStarted((*reinterpret_cast<std::add_pointer_t<CaptureResult>>(_a[1]))); break;
        case 3: _t->abortCapture(); break;
        case 4: _t->newLog((*reinterpret_cast<std::add_pointer_t<QString>>(_a[1]))); break;
        case 5: _t->prepareState((*reinterpret_cast<std::add_pointer_t<CaptureState>>(_a[1]))); break;
        case 6: _t->prepareCapture((*reinterpret_cast<std::add_pointer_t<CCDFrameType>>(_a[1])),(*reinterpret_cast<std::add_pointer_t<bool>>(_a[2])),(*reinterpret_cast<std::add_pointer_t<bool>>(_a[3])),(*reinterpret_cast<std::add_pointer_t<bool>>(_a[4]))); break;
        case 7: _t->updateGuiderDrift((*reinterpret_cast<std::add_pointer_t<double>>(_a[1]))); break;
        default: ;
        }
    }
    if (_c == QMetaObject::IndexOfMethod) {
        if (QtMocHelpers::indexOfMethod<void (SequenceJob::*)(bool )>(_a, &SequenceJob::prepareComplete, 0))
            return;
        if (QtMocHelpers::indexOfMethod<void (SequenceJob::*)(CaptureResult )>(_a, &SequenceJob::captureStarted, 2))
            return;
        if (QtMocHelpers::indexOfMethod<void (SequenceJob::*)()>(_a, &SequenceJob::abortCapture, 3))
            return;
        if (QtMocHelpers::indexOfMethod<void (SequenceJob::*)(QString )>(_a, &SequenceJob::newLog, 4))
            return;
        if (QtMocHelpers::indexOfMethod<void (SequenceJob::*)(CaptureState )>(_a, &SequenceJob::prepareState, 5))
            return;
        if (QtMocHelpers::indexOfMethod<void (SequenceJob::*)(CCDFrameType , bool , bool , bool )>(_a, &SequenceJob::prepareCapture, 6))
            return;
        if (QtMocHelpers::indexOfMethod<void (SequenceJob::*)(double )>(_a, &SequenceJob::updateGuiderDrift, 7))
            return;
    }
}

const QMetaObject *Ekos::SequenceJob::metaObject() const
{
    return QObject::d_ptr->metaObject ? QObject::d_ptr->dynamicMetaObject() : &staticMetaObject;
}

void *Ekos::SequenceJob::qt_metacast(const char *_clname)
{
    if (!_clname) return nullptr;
    if (!strcmp(_clname, qt_staticMetaObjectStaticContent<qt_meta_tag_ZN4Ekos11SequenceJobE_t>.strings))
        return static_cast<void*>(this);
    return QObject::qt_metacast(_clname);
}

int Ekos::SequenceJob::qt_metacall(QMetaObject::Call _c, int _id, void **_a)
{
    _id = QObject::qt_metacall(_c, _id, _a);
    if (_id < 0)
        return _id;
    if (_c == QMetaObject::InvokeMetaMethod) {
        if (_id < 8)
            qt_static_metacall(this, _c, _id, _a);
        _id -= 8;
    }
    if (_c == QMetaObject::RegisterMethodArgumentMetaType) {
        if (_id < 8)
            *reinterpret_cast<QMetaType *>(_a[0]) = QMetaType();
        _id -= 8;
    }
    return _id;
}

// SIGNAL 0
void Ekos::SequenceJob::prepareComplete(bool _t1)
{
    QMetaObject::activate<void>(this, &staticMetaObject, 0, nullptr, _t1);
}

// SIGNAL 2
void Ekos::SequenceJob::captureStarted(CaptureResult _t1)
{
    QMetaObject::activate<void>(this, &staticMetaObject, 2, nullptr, _t1);
}

// SIGNAL 3
void Ekos::SequenceJob::abortCapture()
{
    QMetaObject::activate(this, &staticMetaObject, 3, nullptr);
}

// SIGNAL 4
void Ekos::SequenceJob::newLog(QString _t1)
{
    QMetaObject::activate<void>(this, &staticMetaObject, 4, nullptr, _t1);
}

// SIGNAL 5
void Ekos::SequenceJob::prepareState(CaptureState _t1)
{
    QMetaObject::activate<void>(this, &staticMetaObject, 5, nullptr, _t1);
}

// SIGNAL 6
void Ekos::SequenceJob::prepareCapture(CCDFrameType _t1, bool _t2, bool _t3, bool _t4)
{
    QMetaObject::activate<void>(this, &staticMetaObject, 6, nullptr, _t1, _t2, _t3, _t4);
}

// SIGNAL 7
void Ekos::SequenceJob::updateGuiderDrift(double _t1)
{
    QMetaObject::activate<void>(this, &staticMetaObject, 7, nullptr, _t1);
}
QT_WARNING_POP
