/********************************************************************************
** Form generated from reading UI file 'opsadvanced.ui'
**
** Created by: Qt User Interface Compiler version 6.11.1
**
** WARNING! All changes made in this file will be lost when recompiling UI file!
********************************************************************************/

#ifndef UI_OPSADVANCED_H
#define UI_OPSADVANCED_H

#include <QtCore/QVariant>
#include <QtGui/QIcon>
#include <QtWidgets/QApplication>
#include <QtWidgets/QButtonGroup>
#include <QtWidgets/QCheckBox>
#include <QtWidgets/QComboBox>
#include <QtWidgets/QDoubleSpinBox>
#include <QtWidgets/QFrame>
#include <QtWidgets/QGridLayout>
#include <QtWidgets/QGroupBox>
#include <QtWidgets/QHBoxLayout>
#include <QtWidgets/QLabel>
#include <QtWidgets/QPushButton>
#include <QtWidgets/QRadioButton>
#include <QtWidgets/QSlider>
#include <QtWidgets/QSpacerItem>
#include <QtWidgets/QTabWidget>
#include <QtWidgets/QVBoxLayout>
#include <QtWidgets/QWidget>
#include <klocalizedstring.h>
#include "widgets/magnitudespinbox.h"
#include "widgets/timestepbox.h"

QT_BEGIN_NAMESPACE

class Ui_OpsAdvanced
{
public:
    QVBoxLayout *verticalLayout_5;
    QTabWidget *AdvancedOptionsTabWidget;
    QWidget *tab;
    QVBoxLayout *verticalLayout;
    QHBoxLayout *horizontalLayout_3;
    QGroupBox *BackendsGroupBox;
    QVBoxLayout *verticalLayout_4;
    QCheckBox *kcfg_UseRefraction;
    QCheckBox *kcfg_UseRelativistic;
    QCheckBox *kcfg_AlwaysRecomputeCoordinates;
    QGroupBox *ImageryGroupBox;
    QGridLayout *gridLayout;
    QLabel *label;
    QDoubleSpinBox *kcfg_DefaultDSSImageSize;
    QLabel *DefaultDSSImageSizeUnitLabel;
    QLabel *label_3;
    QDoubleSpinBox *kcfg_DSSPadding;
    QLabel *DSSPaddingUnitLabel;
    QGroupBox *groupBox;
    QGridLayout *gridLayout_4;
    QRadioButton *kcfg_RegularLogging;
    QSpacerItem *horizontalSpacer;
    QRadioButton *kcfg_DisableLogging;
    QPushButton *showLogsB;
    QLabel *label_5;
    QLabel *label_4;
    QRadioButton *kcfg_VerboseLogging;
    QRadioButton *kcfg_LogToDefault;
    QRadioButton *kcfg_LogToFile;
    QSpacerItem *horizontalSpacer_2;
    QFrame *line;
    QHBoxLayout *horizontalLayout_2;
    QSpacerItem *horizontalSpacer_3;
    QPushButton *purgeAllConfigB;
    QSpacerItem *GeneralTabSpacer;
    QWidget *tab_3;
    QVBoxLayout *verticalLayout_3;
    QGridLayout *gridLayout_2;
    QLabel *label_2;
    QSlider *zoomScrollSlider;
    QCheckBox *kcfg_UseAutoLabel;
    QSpacerItem *horizontalSpacer_5;
    QSpacerItem *horizontalSpacer_4;
    QDoubleSpinBox *kcfg_ZoomScrollFactor;
    QCheckBox *kcfg_UseHoverLabel;
    QCheckBox *kcfg_ShowInlineImages;
    QComboBox *kcfg_DefaultCursor;
    QCheckBox *kcfg_UseAntialias;
    QCheckBox *kcfg_LeftClickSelectsObject;
    QLabel *label_6;
    QCheckBox *kcfg_UseAnimatedSlewing;
    QLabel *label_7;
    QSlider *kcfg_LabelFontScaling;
    QGroupBox *hideObjectsWhileSlewing;
    QGridLayout *gridLayout_5;
    QCheckBox *kcfg_HideOnSlew;
    QGridLayout *gridLayout_3;
    QLabel *textLabelHideTimeStep;
    QCheckBox *kcfg_HideStars;
    TimeStepBox *SlewTimeScale;
    MagnitudeSpinBox *kcfg_MagLimitHideStar;
    QCheckBox *kcfg_HidePlanets;
    QCheckBox *kcfg_HideLabels;
    QCheckBox *kcfg_HideCLines;
    QCheckBox *kcfg_HideGrids;
    QCheckBox *kcfg_HideCBounds;
    QCheckBox *kcfg_HideCNames;
    QSpacerItem *verticalSpacer;
    QWidget *tab_2;
    QVBoxLayout *verticalLayout_2;
    QGroupBox *ObsListOptions;
    QHBoxLayout *hboxLayout;
    QRadioButton *kcfg_ObsListSymbol;
    QRadioButton *kcfg_ObsListText;
    QGroupBox *ObsListImageryOptions;
    QHBoxLayout *_3;
    QRadioButton *kcfg_ObsListPreferDSS;
    QRadioButton *kcfg_ObsListPreferSDSS;
    QGroupBox *ObsListMiscOptions;
    QVBoxLayout *verticalLayout_6;
    QCheckBox *kcfg_ObsListDemoteHole;
    QHBoxLayout *horizontalLayout;
    QSpacerItem *holeSizeSpacer;
    QLabel *holeSizeLabel;
    QDoubleSpinBox *kcfg_ObsListHoleSize;
    QSpacerItem *verticalSpacer_2;
    QButtonGroup *verbosityButtonGroup;
    QButtonGroup *logbuttonGroup;

    void setupUi(QWidget *OpsAdvanced)
    {
        if (OpsAdvanced->objectName().isEmpty())
            OpsAdvanced->setObjectName("OpsAdvanced");
        OpsAdvanced->resize(642, 395);
        verticalLayout_5 = new QVBoxLayout(OpsAdvanced);
        verticalLayout_5->setSpacing(3);
        verticalLayout_5->setObjectName("verticalLayout_5");
        verticalLayout_5->setContentsMargins(3, 3, 3, 3);
        AdvancedOptionsTabWidget = new QTabWidget(OpsAdvanced);
        AdvancedOptionsTabWidget->setObjectName("AdvancedOptionsTabWidget");
        tab = new QWidget();
        tab->setObjectName("tab");
        verticalLayout = new QVBoxLayout(tab);
        verticalLayout->setObjectName("verticalLayout");
        verticalLayout->setContentsMargins(3, 3, 3, 3);
        horizontalLayout_3 = new QHBoxLayout();
        horizontalLayout_3->setSpacing(3);
        horizontalLayout_3->setObjectName("horizontalLayout_3");
        BackendsGroupBox = new QGroupBox(tab);
        BackendsGroupBox->setObjectName("BackendsGroupBox");
        verticalLayout_4 = new QVBoxLayout(BackendsGroupBox);
        verticalLayout_4->setObjectName("verticalLayout_4");
        kcfg_UseRefraction = new QCheckBox(BackendsGroupBox);
        kcfg_UseRefraction->setObjectName("kcfg_UseRefraction");

        verticalLayout_4->addWidget(kcfg_UseRefraction);

        kcfg_UseRelativistic = new QCheckBox(BackendsGroupBox);
        kcfg_UseRelativistic->setObjectName("kcfg_UseRelativistic");

        verticalLayout_4->addWidget(kcfg_UseRelativistic);

        kcfg_AlwaysRecomputeCoordinates = new QCheckBox(BackendsGroupBox);
        kcfg_AlwaysRecomputeCoordinates->setObjectName("kcfg_AlwaysRecomputeCoordinates");

        verticalLayout_4->addWidget(kcfg_AlwaysRecomputeCoordinates);


        horizontalLayout_3->addWidget(BackendsGroupBox);

        ImageryGroupBox = new QGroupBox(tab);
        ImageryGroupBox->setObjectName("ImageryGroupBox");
        gridLayout = new QGridLayout(ImageryGroupBox);
        gridLayout->setSpacing(3);
        gridLayout->setObjectName("gridLayout");
        gridLayout->setContentsMargins(3, 3, 3, 3);
        label = new QLabel(ImageryGroupBox);
        label->setObjectName("label");

        gridLayout->addWidget(label, 0, 0, 1, 1);

        kcfg_DefaultDSSImageSize = new QDoubleSpinBox(ImageryGroupBox);
        kcfg_DefaultDSSImageSize->setObjectName("kcfg_DefaultDSSImageSize");
        QSizePolicy sizePolicy(QSizePolicy::Policy::Minimum, QSizePolicy::Policy::Fixed);
        sizePolicy.setHorizontalStretch(0);
        sizePolicy.setVerticalStretch(0);
        sizePolicy.setHeightForWidth(kcfg_DefaultDSSImageSize->sizePolicy().hasHeightForWidth());
        kcfg_DefaultDSSImageSize->setSizePolicy(sizePolicy);
        kcfg_DefaultDSSImageSize->setMinimumSize(QSize(75, 0));
        kcfg_DefaultDSSImageSize->setDecimals(1);
        kcfg_DefaultDSSImageSize->setMinimum(1.000000000000000);
        kcfg_DefaultDSSImageSize->setMaximum(75.000000000000000);
        kcfg_DefaultDSSImageSize->setValue(15.000000000000000);

        gridLayout->addWidget(kcfg_DefaultDSSImageSize, 0, 1, 1, 1);

        DefaultDSSImageSizeUnitLabel = new QLabel(ImageryGroupBox);
        DefaultDSSImageSizeUnitLabel->setObjectName("DefaultDSSImageSizeUnitLabel");
        QSizePolicy sizePolicy1(QSizePolicy::Policy::Expanding, QSizePolicy::Policy::Preferred);
        sizePolicy1.setHorizontalStretch(0);
        sizePolicy1.setVerticalStretch(0);
        sizePolicy1.setHeightForWidth(DefaultDSSImageSizeUnitLabel->sizePolicy().hasHeightForWidth());
        DefaultDSSImageSizeUnitLabel->setSizePolicy(sizePolicy1);

        gridLayout->addWidget(DefaultDSSImageSizeUnitLabel, 0, 3, 1, 1);

        label_3 = new QLabel(ImageryGroupBox);
        label_3->setObjectName("label_3");

        gridLayout->addWidget(label_3, 1, 0, 1, 1);

        kcfg_DSSPadding = new QDoubleSpinBox(ImageryGroupBox);
        kcfg_DSSPadding->setObjectName("kcfg_DSSPadding");
        kcfg_DSSPadding->setMinimumSize(QSize(75, 0));
        kcfg_DSSPadding->setDecimals(1);
        kcfg_DSSPadding->setMinimum(1.000000000000000);
        kcfg_DSSPadding->setMaximum(75.000000000000000);
        kcfg_DSSPadding->setValue(10.000000000000000);

        gridLayout->addWidget(kcfg_DSSPadding, 1, 1, 1, 1);

        DSSPaddingUnitLabel = new QLabel(ImageryGroupBox);
        DSSPaddingUnitLabel->setObjectName("DSSPaddingUnitLabel");
        sizePolicy1.setHeightForWidth(DSSPaddingUnitLabel->sizePolicy().hasHeightForWidth());
        DSSPaddingUnitLabel->setSizePolicy(sizePolicy1);

        gridLayout->addWidget(DSSPaddingUnitLabel, 1, 2, 1, 2);


        horizontalLayout_3->addWidget(ImageryGroupBox);


        verticalLayout->addLayout(horizontalLayout_3);

        groupBox = new QGroupBox(tab);
        groupBox->setObjectName("groupBox");
        gridLayout_4 = new QGridLayout(groupBox);
        gridLayout_4->setSpacing(3);
        gridLayout_4->setObjectName("gridLayout_4");
        gridLayout_4->setContentsMargins(3, 3, 3, 3);
        kcfg_RegularLogging = new QRadioButton(groupBox);
        verbosityButtonGroup = new QButtonGroup(OpsAdvanced);
        verbosityButtonGroup->setObjectName("verbosityButtonGroup");
        verbosityButtonGroup->addButton(kcfg_RegularLogging);
        kcfg_RegularLogging->setObjectName("kcfg_RegularLogging");
        kcfg_RegularLogging->setChecked(true);

        gridLayout_4->addWidget(kcfg_RegularLogging, 0, 2, 1, 2);

        horizontalSpacer = new QSpacerItem(216, 20, QSizePolicy::Policy::Expanding, QSizePolicy::Policy::Minimum);

        gridLayout_4->addItem(horizontalSpacer, 0, 5, 1, 1);

        kcfg_DisableLogging = new QRadioButton(groupBox);
        verbosityButtonGroup->addButton(kcfg_DisableLogging);
        kcfg_DisableLogging->setObjectName("kcfg_DisableLogging");
        kcfg_DisableLogging->setChecked(false);

        gridLayout_4->addWidget(kcfg_DisableLogging, 0, 4, 1, 1);

        showLogsB = new QPushButton(groupBox);
        showLogsB->setObjectName("showLogsB");

        gridLayout_4->addWidget(showLogsB, 0, 6, 1, 1);

        label_5 = new QLabel(groupBox);
        label_5->setObjectName("label_5");

        gridLayout_4->addWidget(label_5, 1, 0, 1, 1);

        label_4 = new QLabel(groupBox);
        label_4->setObjectName("label_4");

        gridLayout_4->addWidget(label_4, 0, 0, 1, 1);

        kcfg_VerboseLogging = new QRadioButton(groupBox);
        verbosityButtonGroup->addButton(kcfg_VerboseLogging);
        kcfg_VerboseLogging->setObjectName("kcfg_VerboseLogging");

        gridLayout_4->addWidget(kcfg_VerboseLogging, 0, 1, 1, 1);

        kcfg_LogToDefault = new QRadioButton(groupBox);
        logbuttonGroup = new QButtonGroup(OpsAdvanced);
        logbuttonGroup->setObjectName("logbuttonGroup");
        logbuttonGroup->addButton(kcfg_LogToDefault);
        kcfg_LogToDefault->setObjectName("kcfg_LogToDefault");
        kcfg_LogToDefault->setChecked(true);

        gridLayout_4->addWidget(kcfg_LogToDefault, 1, 1, 1, 2);

        kcfg_LogToFile = new QRadioButton(groupBox);
        logbuttonGroup->addButton(kcfg_LogToFile);
        kcfg_LogToFile->setObjectName("kcfg_LogToFile");

        gridLayout_4->addWidget(kcfg_LogToFile, 1, 3, 1, 1);

        horizontalSpacer_2 = new QSpacerItem(216, 20, QSizePolicy::Policy::Expanding, QSizePolicy::Policy::Minimum);

        gridLayout_4->addItem(horizontalSpacer_2, 1, 5, 1, 1);

        line = new QFrame(groupBox);
        line->setObjectName("line");
        line->setFrameShape(QFrame::Shape::HLine);
        line->setFrameShadow(QFrame::Shadow::Sunken);

        gridLayout_4->addWidget(line, 2, 0, 1, 7);


        verticalLayout->addWidget(groupBox);

        horizontalLayout_2 = new QHBoxLayout();
        horizontalLayout_2->setObjectName("horizontalLayout_2");
        horizontalSpacer_3 = new QSpacerItem(40, 20, QSizePolicy::Policy::Expanding, QSizePolicy::Policy::Minimum);

        horizontalLayout_2->addItem(horizontalSpacer_3);

        purgeAllConfigB = new QPushButton(tab);
        purgeAllConfigB->setObjectName("purgeAllConfigB");
        QIcon icon;
        QString iconThemeName = QString::fromUtf8("data-warning");
        if (QIcon::hasThemeIcon(iconThemeName)) {
            icon = QIcon::fromTheme(iconThemeName);
        } else {
            icon.addFile(QString::fromUtf8("."), QSize(), QIcon::Mode::Normal, QIcon::State::Off);
        }
        purgeAllConfigB->setIcon(icon);
        purgeAllConfigB->setIconSize(QSize(22, 22));

        horizontalLayout_2->addWidget(purgeAllConfigB);


        verticalLayout->addLayout(horizontalLayout_2);

        GeneralTabSpacer = new QSpacerItem(20, 40, QSizePolicy::Policy::Minimum, QSizePolicy::Policy::Expanding);

        verticalLayout->addItem(GeneralTabSpacer);

        AdvancedOptionsTabWidget->addTab(tab, QString());
        tab_3 = new QWidget();
        tab_3->setObjectName("tab_3");
        verticalLayout_3 = new QVBoxLayout(tab_3);
        verticalLayout_3->setObjectName("verticalLayout_3");
        gridLayout_2 = new QGridLayout();
        gridLayout_2->setSpacing(3);
        gridLayout_2->setObjectName("gridLayout_2");
        label_2 = new QLabel(tab_3);
        label_2->setObjectName("label_2");

        gridLayout_2->addWidget(label_2, 5, 0, 1, 1);

        zoomScrollSlider = new QSlider(tab_3);
        zoomScrollSlider->setObjectName("zoomScrollSlider");
        QSizePolicy sizePolicy2(QSizePolicy::Policy::Expanding, QSizePolicy::Policy::Fixed);
        sizePolicy2.setHorizontalStretch(0);
        sizePolicy2.setVerticalStretch(0);
        sizePolicy2.setHeightForWidth(zoomScrollSlider->sizePolicy().hasHeightForWidth());
        zoomScrollSlider->setSizePolicy(sizePolicy2);
        zoomScrollSlider->setMinimum(1);
        zoomScrollSlider->setMaximum(100);
        zoomScrollSlider->setSingleStep(10);
        zoomScrollSlider->setValue(20);
        zoomScrollSlider->setOrientation(Qt::Horizontal);

        gridLayout_2->addWidget(zoomScrollSlider, 5, 1, 1, 1);

        kcfg_UseAutoLabel = new QCheckBox(tab_3);
        kcfg_UseAutoLabel->setObjectName("kcfg_UseAutoLabel");

        gridLayout_2->addWidget(kcfg_UseAutoLabel, 0, 1, 1, 3);

        horizontalSpacer_5 = new QSpacerItem(40, 20, QSizePolicy::Policy::Expanding, QSizePolicy::Policy::Minimum);

        gridLayout_2->addItem(horizontalSpacer_5, 5, 3, 1, 1);

        horizontalSpacer_4 = new QSpacerItem(40, 20, QSizePolicy::Policy::Expanding, QSizePolicy::Policy::Minimum);

        gridLayout_2->addItem(horizontalSpacer_4, 3, 3, 1, 1);

        kcfg_ZoomScrollFactor = new QDoubleSpinBox(tab_3);
        kcfg_ZoomScrollFactor->setObjectName("kcfg_ZoomScrollFactor");
        kcfg_ZoomScrollFactor->setMinimum(0.010000000000000);
        kcfg_ZoomScrollFactor->setMaximum(1.000000000000000);
        kcfg_ZoomScrollFactor->setSingleStep(0.100000000000000);
        kcfg_ZoomScrollFactor->setValue(0.200000000000000);

        gridLayout_2->addWidget(kcfg_ZoomScrollFactor, 5, 2, 1, 1);

        kcfg_UseHoverLabel = new QCheckBox(tab_3);
        kcfg_UseHoverLabel->setObjectName("kcfg_UseHoverLabel");

        gridLayout_2->addWidget(kcfg_UseHoverLabel, 1, 1, 1, 3);

        kcfg_ShowInlineImages = new QCheckBox(tab_3);
        kcfg_ShowInlineImages->setObjectName("kcfg_ShowInlineImages");

        gridLayout_2->addWidget(kcfg_ShowInlineImages, 2, 0, 1, 1);

        kcfg_DefaultCursor = new QComboBox(tab_3);
        kcfg_DefaultCursor->addItem(QString());
        kcfg_DefaultCursor->addItem(QString());
        kcfg_DefaultCursor->addItem(QString());
        kcfg_DefaultCursor->setObjectName("kcfg_DefaultCursor");

        gridLayout_2->addWidget(kcfg_DefaultCursor, 3, 2, 1, 1);

        kcfg_UseAntialias = new QCheckBox(tab_3);
        kcfg_UseAntialias->setObjectName("kcfg_UseAntialias");

        gridLayout_2->addWidget(kcfg_UseAntialias, 1, 0, 1, 1);

        kcfg_LeftClickSelectsObject = new QCheckBox(tab_3);
        kcfg_LeftClickSelectsObject->setObjectName("kcfg_LeftClickSelectsObject");

        gridLayout_2->addWidget(kcfg_LeftClickSelectsObject, 3, 0, 1, 1);

        label_6 = new QLabel(tab_3);
        label_6->setObjectName("label_6");

        gridLayout_2->addWidget(label_6, 3, 1, 1, 1);

        kcfg_UseAnimatedSlewing = new QCheckBox(tab_3);
        kcfg_UseAnimatedSlewing->setObjectName("kcfg_UseAnimatedSlewing");

        gridLayout_2->addWidget(kcfg_UseAnimatedSlewing, 0, 0, 1, 1);

        label_7 = new QLabel(tab_3);
        label_7->setObjectName("label_7");

        gridLayout_2->addWidget(label_7, 6, 0, 1, 1);

        kcfg_LabelFontScaling = new QSlider(tab_3);
        kcfg_LabelFontScaling->setObjectName("kcfg_LabelFontScaling");
        kcfg_LabelFontScaling->setMinimum(-100);
        kcfg_LabelFontScaling->setMaximum(100);
        kcfg_LabelFontScaling->setValue(0);
        kcfg_LabelFontScaling->setOrientation(Qt::Horizontal);

        gridLayout_2->addWidget(kcfg_LabelFontScaling, 6, 1, 1, 1);


        verticalLayout_3->addLayout(gridLayout_2);

        hideObjectsWhileSlewing = new QGroupBox(tab_3);
        hideObjectsWhileSlewing->setObjectName("hideObjectsWhileSlewing");
        gridLayout_5 = new QGridLayout(hideObjectsWhileSlewing);
        gridLayout_5->setSpacing(3);
        gridLayout_5->setObjectName("gridLayout_5");
        gridLayout_5->setContentsMargins(3, 3, 3, 3);
        kcfg_HideOnSlew = new QCheckBox(hideObjectsWhileSlewing);
        kcfg_HideOnSlew->setObjectName("kcfg_HideOnSlew");

        gridLayout_5->addWidget(kcfg_HideOnSlew, 0, 0, 1, 1);

        gridLayout_3 = new QGridLayout();
        gridLayout_3->setSpacing(3);
        gridLayout_3->setObjectName("gridLayout_3");
        textLabelHideTimeStep = new QLabel(hideObjectsWhileSlewing);
        textLabelHideTimeStep->setObjectName("textLabelHideTimeStep");

        gridLayout_3->addWidget(textLabelHideTimeStep, 0, 0, 1, 1);

        kcfg_HideStars = new QCheckBox(hideObjectsWhileSlewing);
        kcfg_HideStars->setObjectName("kcfg_HideStars");

        gridLayout_3->addWidget(kcfg_HideStars, 1, 0, 1, 1);

        SlewTimeScale = new TimeStepBox(hideObjectsWhileSlewing);
        SlewTimeScale->setObjectName("SlewTimeScale");

        gridLayout_3->addWidget(SlewTimeScale, 0, 1, 1, 2);

        kcfg_MagLimitHideStar = new MagnitudeSpinBox(hideObjectsWhileSlewing);
        kcfg_MagLimitHideStar->setObjectName("kcfg_MagLimitHideStar");
        kcfg_MagLimitHideStar->setMinimumSize(QSize(40, 0));
        kcfg_MagLimitHideStar->setFocusPolicy(Qt::StrongFocus);

        gridLayout_3->addWidget(kcfg_MagLimitHideStar, 1, 1, 1, 2);


        gridLayout_5->addLayout(gridLayout_3, 0, 1, 2, 1);

        kcfg_HidePlanets = new QCheckBox(hideObjectsWhileSlewing);
        kcfg_HidePlanets->setObjectName("kcfg_HidePlanets");

        gridLayout_5->addWidget(kcfg_HidePlanets, 1, 0, 1, 1);

        kcfg_HideLabels = new QCheckBox(hideObjectsWhileSlewing);
        kcfg_HideLabels->setObjectName("kcfg_HideLabels");

        gridLayout_5->addWidget(kcfg_HideLabels, 2, 0, 1, 1);

        kcfg_HideCLines = new QCheckBox(hideObjectsWhileSlewing);
        kcfg_HideCLines->setObjectName("kcfg_HideCLines");

        gridLayout_5->addWidget(kcfg_HideCLines, 2, 1, 2, 1);

        kcfg_HideGrids = new QCheckBox(hideObjectsWhileSlewing);
        kcfg_HideGrids->setObjectName("kcfg_HideGrids");

        gridLayout_5->addWidget(kcfg_HideGrids, 3, 0, 2, 1);

        kcfg_HideCBounds = new QCheckBox(hideObjectsWhileSlewing);
        kcfg_HideCBounds->setObjectName("kcfg_HideCBounds");
        kcfg_HideCBounds->setAcceptDrops(false);

        gridLayout_5->addWidget(kcfg_HideCBounds, 4, 1, 1, 1);

        kcfg_HideCNames = new QCheckBox(hideObjectsWhileSlewing);
        kcfg_HideCNames->setObjectName("kcfg_HideCNames");

        gridLayout_5->addWidget(kcfg_HideCNames, 5, 0, 1, 1);


        verticalLayout_3->addWidget(hideObjectsWhileSlewing);

        verticalSpacer = new QSpacerItem(574, 13, QSizePolicy::Policy::Minimum, QSizePolicy::Policy::Expanding);

        verticalLayout_3->addItem(verticalSpacer);

        AdvancedOptionsTabWidget->addTab(tab_3, QString());
        tab_2 = new QWidget();
        tab_2->setObjectName("tab_2");
        verticalLayout_2 = new QVBoxLayout(tab_2);
        verticalLayout_2->setSpacing(3);
        verticalLayout_2->setObjectName("verticalLayout_2");
        verticalLayout_2->setContentsMargins(3, 3, 3, 3);
        ObsListOptions = new QGroupBox(tab_2);
        ObsListOptions->setObjectName("ObsListOptions");
        sizePolicy1.setHeightForWidth(ObsListOptions->sizePolicy().hasHeightForWidth());
        ObsListOptions->setSizePolicy(sizePolicy1);
        hboxLayout = new QHBoxLayout(ObsListOptions);
        hboxLayout->setSpacing(5);
        hboxLayout->setObjectName("hboxLayout");
        hboxLayout->setContentsMargins(5, 5, 5, 5);
        kcfg_ObsListSymbol = new QRadioButton(ObsListOptions);
        kcfg_ObsListSymbol->setObjectName("kcfg_ObsListSymbol");
        kcfg_ObsListSymbol->setChecked(true);

        hboxLayout->addWidget(kcfg_ObsListSymbol);

        kcfg_ObsListText = new QRadioButton(ObsListOptions);
        kcfg_ObsListText->setObjectName("kcfg_ObsListText");

        hboxLayout->addWidget(kcfg_ObsListText);


        verticalLayout_2->addWidget(ObsListOptions);

        ObsListImageryOptions = new QGroupBox(tab_2);
        ObsListImageryOptions->setObjectName("ObsListImageryOptions");
        sizePolicy1.setHeightForWidth(ObsListImageryOptions->sizePolicy().hasHeightForWidth());
        ObsListImageryOptions->setSizePolicy(sizePolicy1);
        _3 = new QHBoxLayout(ObsListImageryOptions);
        _3->setSpacing(5);
        _3->setObjectName("_3");
        _3->setContentsMargins(5, 5, 5, 5);
        kcfg_ObsListPreferDSS = new QRadioButton(ObsListImageryOptions);
        kcfg_ObsListPreferDSS->setObjectName("kcfg_ObsListPreferDSS");
        kcfg_ObsListPreferDSS->setEnabled(false);
        kcfg_ObsListPreferDSS->setChecked(true);

        _3->addWidget(kcfg_ObsListPreferDSS);

        kcfg_ObsListPreferSDSS = new QRadioButton(ObsListImageryOptions);
        kcfg_ObsListPreferSDSS->setObjectName("kcfg_ObsListPreferSDSS");
        kcfg_ObsListPreferSDSS->setEnabled(false);

        _3->addWidget(kcfg_ObsListPreferSDSS);


        verticalLayout_2->addWidget(ObsListImageryOptions);

        ObsListMiscOptions = new QGroupBox(tab_2);
        ObsListMiscOptions->setObjectName("ObsListMiscOptions");
        verticalLayout_6 = new QVBoxLayout(ObsListMiscOptions);
        verticalLayout_6->setSpacing(5);
        verticalLayout_6->setObjectName("verticalLayout_6");
        verticalLayout_6->setContentsMargins(5, 5, 5, 5);
        kcfg_ObsListDemoteHole = new QCheckBox(ObsListMiscOptions);
        kcfg_ObsListDemoteHole->setObjectName("kcfg_ObsListDemoteHole");

        verticalLayout_6->addWidget(kcfg_ObsListDemoteHole);

        horizontalLayout = new QHBoxLayout();
        horizontalLayout->setSpacing(5);
        horizontalLayout->setObjectName("horizontalLayout");
        holeSizeSpacer = new QSpacerItem(40, 20, QSizePolicy::Policy::Expanding, QSizePolicy::Policy::Minimum);

        horizontalLayout->addItem(holeSizeSpacer);

        holeSizeLabel = new QLabel(ObsListMiscOptions);
        holeSizeLabel->setObjectName("holeSizeLabel");
        QSizePolicy sizePolicy3(QSizePolicy::Policy::MinimumExpanding, QSizePolicy::Policy::Preferred);
        sizePolicy3.setHorizontalStretch(0);
        sizePolicy3.setVerticalStretch(0);
        sizePolicy3.setHeightForWidth(holeSizeLabel->sizePolicy().hasHeightForWidth());
        holeSizeLabel->setSizePolicy(sizePolicy3);
        holeSizeLabel->setAlignment(Qt::AlignRight|Qt::AlignTrailing|Qt::AlignVCenter);

        horizontalLayout->addWidget(holeSizeLabel);

        kcfg_ObsListHoleSize = new QDoubleSpinBox(ObsListMiscOptions);
        kcfg_ObsListHoleSize->setObjectName("kcfg_ObsListHoleSize");
        QSizePolicy sizePolicy4(QSizePolicy::Policy::Minimum, QSizePolicy::Policy::Minimum);
        sizePolicy4.setHorizontalStretch(0);
        sizePolicy4.setVerticalStretch(0);
        sizePolicy4.setHeightForWidth(kcfg_ObsListHoleSize->sizePolicy().hasHeightForWidth());
        kcfg_ObsListHoleSize->setSizePolicy(sizePolicy4);
        kcfg_ObsListHoleSize->setMaximum(89.989999999999995);
        kcfg_ObsListHoleSize->setValue(15.000000000000000);

        horizontalLayout->addWidget(kcfg_ObsListHoleSize);


        verticalLayout_6->addLayout(horizontalLayout);


        verticalLayout_2->addWidget(ObsListMiscOptions);

        verticalSpacer_2 = new QSpacerItem(20, 417, QSizePolicy::Policy::Minimum, QSizePolicy::Policy::Expanding);

        verticalLayout_2->addItem(verticalSpacer_2);

        AdvancedOptionsTabWidget->addTab(tab_2, QString());

        verticalLayout_5->addWidget(AdvancedOptionsTabWidget);

        QWidget::setTabOrder(AdvancedOptionsTabWidget, kcfg_UseRefraction);
        QWidget::setTabOrder(kcfg_UseRefraction, kcfg_UseRelativistic);
        QWidget::setTabOrder(kcfg_UseRelativistic, kcfg_AlwaysRecomputeCoordinates);
        QWidget::setTabOrder(kcfg_AlwaysRecomputeCoordinates, kcfg_DefaultDSSImageSize);
        QWidget::setTabOrder(kcfg_DefaultDSSImageSize, kcfg_DSSPadding);
        QWidget::setTabOrder(kcfg_DSSPadding, kcfg_UseAnimatedSlewing);
        QWidget::setTabOrder(kcfg_UseAnimatedSlewing, kcfg_UseAutoLabel);
        QWidget::setTabOrder(kcfg_UseAutoLabel, kcfg_UseHoverLabel);
        QWidget::setTabOrder(kcfg_UseHoverLabel, kcfg_UseAntialias);
        QWidget::setTabOrder(kcfg_UseAntialias, kcfg_ObsListSymbol);
        QWidget::setTabOrder(kcfg_ObsListSymbol, kcfg_ObsListText);
        QWidget::setTabOrder(kcfg_ObsListText, kcfg_ObsListPreferDSS);
        QWidget::setTabOrder(kcfg_ObsListPreferDSS, kcfg_ObsListPreferSDSS);

        retranslateUi(OpsAdvanced);

        AdvancedOptionsTabWidget->setCurrentIndex(0);


        QMetaObject::connectSlotsByName(OpsAdvanced);
    } // setupUi

    void retranslateUi(QWidget *OpsAdvanced)
    {
        BackendsGroupBox->setTitle(tr2i18n("Backends", nullptr));
#if QT_CONFIG(tooltip)
        kcfg_UseRefraction->setToolTip(tr2i18n("Correct coordinates of objects for the effects of the atmosphere", nullptr));
#endif // QT_CONFIG(tooltip)
#if QT_CONFIG(whatsthis)
        kcfg_UseRefraction->setWhatsThis(tr2i18n("The atmosphere bends light passing through it, like a lens.  If this item is checked, this \"atmospheric refraction\" will be simulated in the sky map.  Note that this correction is only applied when using the Horizontal coordinate system.", nullptr));
#endif // QT_CONFIG(whatsthis)
        kcfg_UseRefraction->setText(tr2i18n("Correct for atmospheric refraction", nullptr));
#if QT_CONFIG(tooltip)
        kcfg_UseRelativistic->setToolTip(tr2i18n("Correct for the effect of sun's gravity on star positions, as predicted by General Relativity, and verified by Eddington's experiment.", nullptr));
#endif // QT_CONFIG(tooltip)
        kcfg_UseRelativistic->setText(tr2i18n("General Relativity effects near the sun", nullptr));
#if QT_CONFIG(whatsthis)
        kcfg_AlwaysRecomputeCoordinates->setWhatsThis(tr2i18n("Checking this option causes recomputation of current equatorial coordinates from catalog coordinates (i.e. application of precession, nutation and aberration corrections) for every redraw of the map. This makes processing slower when there are many stars to handle, but is more likely to be bug-free. There are known bugs in the rendering of stars when this recomputation is avoided.", nullptr));
#endif // QT_CONFIG(whatsthis)
        kcfg_AlwaysRecomputeCoordinates->setText(tr2i18n("Always recompute coordinates", nullptr));
        ImageryGroupBox->setTitle(tr2i18n("DSS Imagery", nullptr));
        label->setText(tr2i18n("Default DSS image size:", nullptr));
        DefaultDSSImageSizeUnitLabel->setText(tr2i18n("arcminutes", nullptr));
        label_3->setText(tr2i18n("Padding around deep sky objects:", nullptr));
        DSSPaddingUnitLabel->setText(tr2i18n("arcminutes", nullptr));
        groupBox->setTitle(tr2i18n("Logging Output", nullptr));
#if QT_CONFIG(tooltip)
        kcfg_RegularLogging->setToolTip(tr2i18n("Enable regular debug output", nullptr));
#endif // QT_CONFIG(tooltip)
        kcfg_RegularLogging->setText(tr2i18n("Reg&ular", nullptr));
#if QT_CONFIG(tooltip)
        kcfg_DisableLogging->setToolTip(tr2i18n("Disable all logging output", nullptr));
#endif // QT_CONFIG(tooltip)
        kcfg_DisableLogging->setText(tr2i18n("&Disable", nullptr));
        showLogsB->setText(tr2i18n("Show Logs...", nullptr));
        label_5->setText(tr2i18n("Output:", nullptr));
        label_4->setText(tr2i18n("Verbosity:", nullptr));
#if QT_CONFIG(tooltip)
        kcfg_VerboseLogging->setToolTip(tr2i18n("Enable verbose debug output", nullptr));
#endif // QT_CONFIG(tooltip)
        kcfg_VerboseLogging->setText(tr2i18n("&Verbose", nullptr));
#if QT_CONFIG(tooltip)
        kcfg_LogToDefault->setToolTip(tr2i18n("Log debug messages to default output device used by the platform (e.g. Standard Error)", nullptr));
#endif // QT_CONFIG(tooltip)
        kcfg_LogToDefault->setText(tr2i18n("Defaul&t", nullptr));
#if QT_CONFIG(tooltip)
        kcfg_LogToFile->setToolTip(tr2i18n("Log output to log file", nullptr));
#endif // QT_CONFIG(tooltip)
        kcfg_LogToFile->setText(tr2i18n("File", nullptr));
#if QT_CONFIG(tooltip)
        purgeAllConfigB->setToolTip(tr2i18n("Clear all KStars configuration and user database.", nullptr));
#endif // QT_CONFIG(tooltip)
        purgeAllConfigB->setText(tr2i18n("Purge All Configuration", nullptr));
        AdvancedOptionsTabWidget->setTabText(AdvancedOptionsTabWidget->indexOf(tab), tr2i18n("&General", nullptr));
#if QT_CONFIG(tooltip)
        label_2->setToolTip(tr2i18n("Adjust speed of zooming when scrolling in and out with the mouse wheel", nullptr));
#endif // QT_CONFIG(tooltip)
        label_2->setText(tr2i18n("Zoom scroll speed:", nullptr));
#if QT_CONFIG(tooltip)
        kcfg_UseAutoLabel->setToolTip(tr2i18n("Show name label of centered object?", nullptr));
#endif // QT_CONFIG(tooltip)
#if QT_CONFIG(whatsthis)
        kcfg_UseAutoLabel->setWhatsThis(tr2i18n("If checked, a name label will be temporarily attached to an object while it is centered in the display.  You can attach a more persistent label to any object using the right-click popup menu.", nullptr));
#endif // QT_CONFIG(whatsthis)
        kcfg_UseAutoLabel->setText(tr2i18n("Attach label to centered object", nullptr));
#if QT_CONFIG(tooltip)
        kcfg_UseHoverLabel->setToolTip(tr2i18n("Show name label of centered object?", nullptr));
#endif // QT_CONFIG(tooltip)
#if QT_CONFIG(whatsthis)
        kcfg_UseHoverLabel->setWhatsThis(tr2i18n("If checked, a name label will be temporarily attached to an object while it is centered in the display.  You can attach a more persistent label to any object using the right-click popup menu.", nullptr));
#endif // QT_CONFIG(whatsthis)
        kcfg_UseHoverLabel->setText(tr2i18n("Attach temporary label when hovering mouse", nullptr));
#if QT_CONFIG(tooltip)
        kcfg_ShowInlineImages->setToolTip(tr2i18n("Show inline images on the sky?", nullptr));
#endif // QT_CONFIG(tooltip)
#if QT_CONFIG(whatsthis)
        kcfg_ShowInlineImages->setWhatsThis(tr2i18n("If checked, inline images will be shown on the skymap.", nullptr));
#endif // QT_CONFIG(whatsthis)
        kcfg_ShowInlineImages->setText(tr2i18n("Show inline images", nullptr));
        kcfg_DefaultCursor->setItemText(0, tr2i18n("Arrow", nullptr));
        kcfg_DefaultCursor->setItemText(1, tr2i18n("Cross", nullptr));
        kcfg_DefaultCursor->setItemText(2, tr2i18n("Circle", nullptr));

#if QT_CONFIG(tooltip)
        kcfg_UseAntialias->setToolTip(tr2i18n("Select this for smoother (but slower) graphics", nullptr));
#endif // QT_CONFIG(tooltip)
        kcfg_UseAntialias->setText(tr2i18n("Use antialiased drawing", nullptr));
        kcfg_LeftClickSelectsObject->setText(tr2i18n("Left click selects object", nullptr));
        label_6->setText(tr2i18n("Default cursor:", nullptr));
#if QT_CONFIG(tooltip)
        kcfg_UseAnimatedSlewing->setToolTip(tr2i18n("Show slewing motion when focus changes?", nullptr));
#endif // QT_CONFIG(tooltip)
#if QT_CONFIG(whatsthis)
        kcfg_UseAnimatedSlewing->setWhatsThis(tr2i18n("If checked, changing the focus position will result in a visible animated \"slew\" to the new position.  Otherwise, the display will center on the new position instantaneously.", nullptr));
#endif // QT_CONFIG(whatsthis)
        kcfg_UseAnimatedSlewing->setText(tr2i18n("Use animated slewing", nullptr));
        label_7->setText(tr2i18n("Font size of sky map labels:", nullptr));
        hideObjectsWhileSlewing->setTitle(tr2i18n("Configure hidden objects while moving", nullptr));
#if QT_CONFIG(tooltip)
        kcfg_HideOnSlew->setToolTip(tr2i18n("Do not draw all objects while the map is moving?", nullptr));
#endif // QT_CONFIG(tooltip)
#if QT_CONFIG(whatsthis)
        kcfg_HideOnSlew->setWhatsThis(tr2i18n("When the map is in motion, smooth animation is compromised if the program has too many objects to draw on the map; check this item to temporarily hide some of the objects while the display is in motion.", nullptr));
#endif // QT_CONFIG(whatsthis)
        kcfg_HideOnSlew->setText(tr2i18n("Hide objects while moving", nullptr));
#if QT_CONFIG(tooltip)
        textLabelHideTimeStep->setToolTip(tr2i18n("Hide objects only if time step is larger than threshold", nullptr));
#endif // QT_CONFIG(tooltip)
        textLabelHideTimeStep->setText(tr2i18n("Also hide if time step larger than:", nullptr));
#if QT_CONFIG(tooltip)
        kcfg_HideStars->setToolTip(tr2i18n("Hide faint stars while moving?", nullptr));
#endif // QT_CONFIG(tooltip)
#if QT_CONFIG(whatsthis)
        kcfg_HideStars->setWhatsThis(tr2i18n("If checked, then fainter stars will be hidden when the map is in motion.", nullptr));
#endif // QT_CONFIG(whatsthis)
        kcfg_HideStars->setText(tr2i18n("Stars fainter than magnitude:", nullptr));
#if QT_CONFIG(whatsthis)
        kcfg_MagLimitHideStar->setWhatsThis(tr2i18n("Stars fainter than this will not be drawn while the map is moving.", nullptr));
#endif // QT_CONFIG(whatsthis)
#if QT_CONFIG(tooltip)
        kcfg_HidePlanets->setToolTip(tr2i18n("Hide solar system bodies while moving?", nullptr));
#endif // QT_CONFIG(tooltip)
#if QT_CONFIG(whatsthis)
        kcfg_HidePlanets->setWhatsThis(tr2i18n("If checked, then all solar system bodies will be hidden when the map is in motion.", nullptr));
#endif // QT_CONFIG(whatsthis)
        kcfg_HidePlanets->setText(tr2i18n("Solar system", nullptr));
#if QT_CONFIG(tooltip)
        kcfg_HideLabels->setToolTip(tr2i18n("Hide object labels while moving?", nullptr));
#endif // QT_CONFIG(tooltip)
        kcfg_HideLabels->setText(tr2i18n("Object labels", nullptr));
#if QT_CONFIG(tooltip)
        kcfg_HideCLines->setToolTip(tr2i18n("Hide constellation lines while moving?", nullptr));
#endif // QT_CONFIG(tooltip)
#if QT_CONFIG(whatsthis)
        kcfg_HideCLines->setWhatsThis(tr2i18n("If checked, then constellation lines will be hidden when the map is in motion.", nullptr));
#endif // QT_CONFIG(whatsthis)
        kcfg_HideCLines->setText(tr2i18n("Constellation lines", nullptr));
#if QT_CONFIG(tooltip)
        kcfg_HideGrids->setToolTip(tr2i18n("Hide coordinate grids while moving?", nullptr));
#endif // QT_CONFIG(tooltip)
#if QT_CONFIG(whatsthis)
        kcfg_HideGrids->setWhatsThis(tr2i18n("If checked, then the coordinate grids will be hidden when the map is in motion.", nullptr));
#endif // QT_CONFIG(whatsthis)
        kcfg_HideGrids->setText(tr2i18n("Coordinate grids", nullptr));
#if QT_CONFIG(tooltip)
        kcfg_HideCBounds->setToolTip(tr2i18n("Hide constellation boundaries while moving?", nullptr));
#endif // QT_CONFIG(tooltip)
        kcfg_HideCBounds->setText(tr2i18n("Constellation boundaries", nullptr));
#if QT_CONFIG(tooltip)
        kcfg_HideCNames->setToolTip(tr2i18n("Hide constellation names while moving?", nullptr));
#endif // QT_CONFIG(tooltip)
#if QT_CONFIG(whatsthis)
        kcfg_HideCNames->setWhatsThis(tr2i18n("If checked, then constellation names will be hidden when the map is in motion.", nullptr));
#endif // QT_CONFIG(whatsthis)
        kcfg_HideCNames->setText(tr2i18n("Constellation names", nullptr));
        AdvancedOptionsTabWidget->setTabText(AdvancedOptionsTabWidget->indexOf(tab_3), tr2i18n("Look and &Feel", nullptr));
        ObsListOptions->setTitle(tr2i18n("Observing List Labels", nullptr));
        kcfg_ObsListSymbol->setText(tr2i18n("S&ymbol", nullptr));
        kcfg_ObsListText->setText(tr2i18n("Te&xt", nullptr));
        ObsListImageryOptions->setTitle(tr2i18n("Preferred Imagery", nullptr));
        kcfg_ObsListPreferDSS->setText(tr2i18n("Digiti&zed Sky Survey (DSS)", nullptr));
        kcfg_ObsListPreferSDSS->setText(tr2i18n("Sloan &Digital Sky Survey (SDSS)", nullptr));
        ObsListMiscOptions->setTitle(tr2i18n("Miscellaneous", nullptr));
        kcfg_ObsListDemoteHole->setText(tr2i18n("While sorting by percentage altitude, demote objects present in the Dobsonian hole", nullptr));
        holeSizeLabel->setText(tr2i18n("Hole size in degrees:", nullptr));
        AdvancedOptionsTabWidget->setTabText(AdvancedOptionsTabWidget->indexOf(tab_2), tr2i18n("Observing &List", nullptr));
        (void)OpsAdvanced;
    } // retranslateUi

};

namespace Ui {
    class OpsAdvanced: public Ui_OpsAdvanced {};
} // namespace Ui

QT_END_NAMESPACE

#endif // OPSADVANCED_H

