/****************************************************************************
** Meta object code from reading C++ file 'fitsview.h'
**
** Created by: The Qt Meta Object Compiler version 69 (Qt 6.11.1)
**
** WARNING! All changes made in this file will be lost!
*****************************************************************************/

#include "../../../../kstars-3.8.4.1/kstars/fitsviewer/fitsview.h"
#include <QtNetwork/QSslError>
#include <QtDataVisualization/qbar3dseries.h>
#include <QtDataVisualization/q3dscene.h>
#include <QtGui/qtextcursor.h>
#include <QtCore/qmetatype.h>

#include <QtCore/qtmochelpers.h>

#include <memory>


#include <QtCore/qxptype_traits.h>
#if !defined(Q_MOC_OUTPUT_REVISION)
#error "The header file 'fitsview.h' doesn't include <QObject>."
#elif Q_MOC_OUTPUT_REVISION != 69
#error "This file was generated using the moc from 6.11.1. It"
#error "cannot be used with the include files from this version of Qt."
#error "(The moc has changed too much.)"
#endif

#ifndef Q_CONSTINIT
#define Q_CONSTINIT
#endif

QT_WARNING_PUSH
QT_WARNING_DISABLE_DEPRECATED
QT_WARNING_DISABLE_GCC("-Wuseless-cast")
namespace {
struct qt_meta_tag_ZN8FITSViewE_t {};
} // unnamed namespace

template <> constexpr inline auto FITSView::qt_create_metaobjectdata<qt_meta_tag_ZN8FITSViewE_t>()
{
    namespace QMC = QtMocConstants;
    QtMocHelpers::StringRefStorage qt_stringData {
        "FITSView",
        "newStatus",
        "",
        "msg",
        "FITSBar",
        "id",
        "newStretch",
        "StretchParams",
        "params",
        "debayerToggled",
        "wcsToggled",
        "actionUpdated",
        "name",
        "enable",
        "trackingStarSelected",
        "x",
        "y",
        "loaded",
        "updated",
        "failed",
        "error",
        "starProfileWindowClosed",
        "rectangleUpdated",
        "QRect",
        "roi",
        "setRubberBand",
        "rect",
        "showRubberBand",
        "on",
        "zoomRubberBand",
        "scale",
        "mouseOverPixel",
        "catLoaded",
        "catQueried",
        "catQueryFailed",
        "text",
        "catReset",
        "catHighlightChanged",
        "highlight",
        "headerChanged",
        "plateSolveSub",
        "ra",
        "dec",
        "pixScale",
        "index",
        "healpix",
        "LiveStackFrameWeighting",
        "weighting",
        "stackInProgress",
        "alignMasterChosen",
        "alignMaster",
        "stackUpdateStats",
        "ok",
        "sub",
        "total",
        "meanSNR",
        "minSNR",
        "maxSNR",
        "updateStackSNR",
        "SNR",
        "resetStack",
        "cancelled",
        "stackFrameSaved",
        "frameNumber",
        "filePath",
        "wheelEvent",
        "QWheelEvent*",
        "event",
        "resizeEvent",
        "QResizeEvent*",
        "ZoomIn",
        "ZoomOut",
        "ZoomDefault",
        "ZoomToFit",
        "updateMagnifyingGlass",
        "toggleEQGrid",
        "toggleObjects",
        "togglePixelGrid",
        "toggleCrosshair",
        "toggleHiPSOverlay",
        "toggleSelectionMode",
        "toggleStars",
        "toggleStarProfile",
        "viewStarProfile",
        "centerTelescope",
        "toggleStretch",
        "toggleClipping",
        "processPointSelection",
        "processMarkerSelection",
        "processHighlight",
        "processCircle",
        "QPoint",
        "p1",
        "p2",
        "move3DTrackingBox",
        "resizeTrackingBox",
        "newSize",
        "processRectangle",
        "refreshCenter",
        "processRectangleFixed",
        "s",
        "syncWCSState",
        "QEvent*",
        "gestureEvent",
        "QGestureEvent*",
        "pinchTriggered",
        "QPinchGesture*",
        "gesture",
        "setStretchValues",
        "shadows",
        "midtones",
        "highlights",
        "setAutoStretch",
        "suspended"
    };

    QtMocHelpers::UintData qt_methods {
        // Signal 'newStatus'
        QtMocHelpers::SignalData<void(const QString &, FITSBar)>(1, 2, QMC::AccessPublic, QMetaType::Void, {{
            { QMetaType::QString, 3 }, { 0x80000000 | 4, 5 },
        }}),
        // Signal 'newStretch'
        QtMocHelpers::SignalData<void(const StretchParams &)>(6, 2, QMC::AccessPublic, QMetaType::Void, {{
            { 0x80000000 | 7, 8 },
        }}),
        // Signal 'debayerToggled'
        QtMocHelpers::SignalData<void(bool)>(9, 2, QMC::AccessPublic, QMetaType::Void, {{
            { QMetaType::Bool, 2 },
        }}),
        // Signal 'wcsToggled'
        QtMocHelpers::SignalData<void(bool)>(10, 2, QMC::AccessPublic, QMetaType::Void, {{
            { QMetaType::Bool, 2 },
        }}),
        // Signal 'actionUpdated'
        QtMocHelpers::SignalData<void(const QString &, bool)>(11, 2, QMC::AccessPublic, QMetaType::Void, {{
            { QMetaType::QString, 12 }, { QMetaType::Bool, 13 },
        }}),
        // Signal 'trackingStarSelected'
        QtMocHelpers::SignalData<void(int, int)>(14, 2, QMC::AccessPublic, QMetaType::Void, {{
            { QMetaType::Int, 15 }, { QMetaType::Int, 16 },
        }}),
        // Signal 'loaded'
        QtMocHelpers::SignalData<void()>(17, 2, QMC::AccessPublic, QMetaType::Void),
        // Signal 'updated'
        QtMocHelpers::SignalData<void()>(18, 2, QMC::AccessPublic, QMetaType::Void),
        // Signal 'failed'
        QtMocHelpers::SignalData<void(const QString &)>(19, 2, QMC::AccessPublic, QMetaType::Void, {{
            { QMetaType::QString, 20 },
        }}),
        // Signal 'starProfileWindowClosed'
        QtMocHelpers::SignalData<void()>(21, 2, QMC::AccessPublic, QMetaType::Void),
        // Signal 'rectangleUpdated'
        QtMocHelpers::SignalData<void(QRect)>(22, 2, QMC::AccessPublic, QMetaType::Void, {{
            { 0x80000000 | 23, 24 },
        }}),
        // Signal 'setRubberBand'
        QtMocHelpers::SignalData<void(QRect)>(25, 2, QMC::AccessPublic, QMetaType::Void, {{
            { 0x80000000 | 23, 26 },
        }}),
        // Signal 'showRubberBand'
        QtMocHelpers::SignalData<void(bool)>(27, 2, QMC::AccessPublic, QMetaType::Void, {{
            { QMetaType::Bool, 28 },
        }}),
        // Signal 'showRubberBand'
        QtMocHelpers::SignalData<void()>(27, 2, QMC::AccessPublic | QMC::MethodCloned, QMetaType::Void),
        // Signal 'zoomRubberBand'
        QtMocHelpers::SignalData<void(double)>(29, 2, QMC::AccessPublic, QMetaType::Void, {{
            { QMetaType::Double, 30 },
        }}),
        // Signal 'mouseOverPixel'
        QtMocHelpers::SignalData<void(int, int)>(31, 2, QMC::AccessPublic, QMetaType::Void, {{
            { QMetaType::Int, 15 }, { QMetaType::Int, 16 },
        }}),
        // Signal 'catLoaded'
        QtMocHelpers::SignalData<void()>(32, 2, QMC::AccessPublic, QMetaType::Void),
        // Signal 'catQueried'
        QtMocHelpers::SignalData<void()>(33, 2, QMC::AccessPublic, QMetaType::Void),
        // Signal 'catQueryFailed'
        QtMocHelpers::SignalData<void(const QString)>(34, 2, QMC::AccessPublic, QMetaType::Void, {{
            { QMetaType::QString, 35 },
        }}),
        // Signal 'catReset'
        QtMocHelpers::SignalData<void()>(36, 2, QMC::AccessPublic, QMetaType::Void),
        // Signal 'catHighlightChanged'
        QtMocHelpers::SignalData<void(const int)>(37, 2, QMC::AccessPublic, QMetaType::Void, {{
            { QMetaType::Int, 38 },
        }}),
        // Signal 'headerChanged'
        QtMocHelpers::SignalData<void()>(39, 2, QMC::AccessPublic, QMetaType::Void),
        // Signal 'plateSolveSub'
        QtMocHelpers::SignalData<void(const double, const double, const double, const int, const int, const LiveStackFrameWeighting &)>(40, 2, QMC::AccessPublic, QMetaType::Void, {{
            { QMetaType::Double, 41 }, { QMetaType::Double, 42 }, { QMetaType::Double, 43 }, { QMetaType::Int, 44 },
            { QMetaType::Int, 45 }, { 0x80000000 | 46, 47 },
        }}),
        // Signal 'stackInProgress'
        QtMocHelpers::SignalData<void()>(48, 2, QMC::AccessPublic, QMetaType::Void),
        // Signal 'alignMasterChosen'
        QtMocHelpers::SignalData<void(const QString &)>(49, 2, QMC::AccessPublic, QMetaType::Void, {{
            { QMetaType::QString, 50 },
        }}),
        // Signal 'stackUpdateStats'
        QtMocHelpers::SignalData<void(const bool, const int, const int, const double, const double, const double)>(51, 2, QMC::AccessPublic, QMetaType::Void, {{
            { QMetaType::Bool, 52 }, { QMetaType::Int, 53 }, { QMetaType::Int, 54 }, { QMetaType::Double, 55 },
            { QMetaType::Double, 56 }, { QMetaType::Double, 57 },
        }}),
        // Signal 'updateStackSNR'
        QtMocHelpers::SignalData<void(const double)>(58, 2, QMC::AccessPublic, QMetaType::Void, {{
            { QMetaType::Double, 59 },
        }}),
        // Signal 'resetStack'
        QtMocHelpers::SignalData<void(const bool)>(60, 2, QMC::AccessPublic, QMetaType::Void, {{
            { QMetaType::Bool, 61 },
        }}),
        // Signal 'stackFrameSaved'
        QtMocHelpers::SignalData<void(int, const QString &)>(62, 2, QMC::AccessPublic, QMetaType::Void, {{
            { QMetaType::Int, 63 }, { QMetaType::QString, 64 },
        }}),
        // Slot 'wheelEvent'
        QtMocHelpers::SlotData<void(QWheelEvent *)>(65, 2, QMC::AccessPublic, QMetaType::Void, {{
            { 0x80000000 | 66, 67 },
        }}),
        // Slot 'resizeEvent'
        QtMocHelpers::SlotData<void(QResizeEvent *)>(68, 2, QMC::AccessPublic, QMetaType::Void, {{
            { 0x80000000 | 69, 67 },
        }}),
        // Slot 'ZoomIn'
        QtMocHelpers::SlotData<void()>(70, 2, QMC::AccessPublic, QMetaType::Void),
        // Slot 'ZoomOut'
        QtMocHelpers::SlotData<void()>(71, 2, QMC::AccessPublic, QMetaType::Void),
        // Slot 'ZoomDefault'
        QtMocHelpers::SlotData<void()>(72, 2, QMC::AccessPublic, QMetaType::Void),
        // Slot 'ZoomToFit'
        QtMocHelpers::SlotData<void()>(73, 2, QMC::AccessPublic, QMetaType::Void),
        // Slot 'updateMagnifyingGlass'
        QtMocHelpers::SlotData<void(int, int)>(74, 2, QMC::AccessPublic, QMetaType::Void, {{
            { QMetaType::Int, 15 }, { QMetaType::Int, 16 },
        }}),
        // Slot 'toggleEQGrid'
        QtMocHelpers::SlotData<void()>(75, 2, QMC::AccessPublic, QMetaType::Void),
        // Slot 'toggleObjects'
        QtMocHelpers::SlotData<void()>(76, 2, QMC::AccessPublic, QMetaType::Void),
        // Slot 'togglePixelGrid'
        QtMocHelpers::SlotData<void()>(77, 2, QMC::AccessPublic, QMetaType::Void),
        // Slot 'toggleCrosshair'
        QtMocHelpers::SlotData<void()>(78, 2, QMC::AccessPublic, QMetaType::Void),
        // Slot 'toggleHiPSOverlay'
        QtMocHelpers::SlotData<void()>(79, 2, QMC::AccessPublic, QMetaType::Void),
        // Slot 'toggleSelectionMode'
        QtMocHelpers::SlotData<void()>(80, 2, QMC::AccessPublic, QMetaType::Void),
        // Slot 'toggleStars'
        QtMocHelpers::SlotData<void()>(81, 2, QMC::AccessPublic, QMetaType::Void),
        // Slot 'toggleStarProfile'
        QtMocHelpers::SlotData<void()>(82, 2, QMC::AccessPublic, QMetaType::Void),
        // Slot 'viewStarProfile'
        QtMocHelpers::SlotData<void()>(83, 2, QMC::AccessPublic, QMetaType::Void),
        // Slot 'centerTelescope'
        QtMocHelpers::SlotData<void()>(84, 2, QMC::AccessPublic, QMetaType::Void),
        // Slot 'toggleStretch'
        QtMocHelpers::SlotData<void()>(85, 2, QMC::AccessPublic, QMetaType::Void),
        // Slot 'toggleClipping'
        QtMocHelpers::SlotData<void()>(86, 2, QMC::AccessPublic, QMetaType::Void),
        // Slot 'processPointSelection'
        QtMocHelpers::SlotData<void(int, int)>(87, 2, QMC::AccessPublic, QMetaType::Void, {{
            { QMetaType::Int, 15 }, { QMetaType::Int, 16 },
        }}),
        // Slot 'processMarkerSelection'
        QtMocHelpers::SlotData<void(int, int)>(88, 2, QMC::AccessPublic, QMetaType::Void, {{
            { QMetaType::Int, 15 }, { QMetaType::Int, 16 },
        }}),
        // Slot 'processHighlight'
        QtMocHelpers::SlotData<void(int, int)>(89, 2, QMC::AccessPublic, QMetaType::Void, {{
            { QMetaType::Int, 15 }, { QMetaType::Int, 16 },
        }}),
        // Slot 'processCircle'
        QtMocHelpers::SlotData<void(QPoint, QPoint)>(90, 2, QMC::AccessPublic, QMetaType::Void, {{
            { 0x80000000 | 91, 92 }, { 0x80000000 | 91, 93 },
        }}),
        // Slot 'move3DTrackingBox'
        QtMocHelpers::SlotData<void(int, int)>(94, 2, QMC::AccessPublic, QMetaType::Void, {{
            { QMetaType::Int, 15 }, { QMetaType::Int, 16 },
        }}),
        // Slot 'resizeTrackingBox'
        QtMocHelpers::SlotData<void(int)>(95, 2, QMC::AccessPublic, QMetaType::Void, {{
            { QMetaType::Int, 96 },
        }}),
        // Slot 'processRectangle'
        QtMocHelpers::SlotData<void(QPoint, QPoint, bool)>(97, 2, QMC::AccessPublic, QMetaType::Void, {{
            { 0x80000000 | 91, 92 }, { 0x80000000 | 91, 93 }, { QMetaType::Bool, 98 },
        }}),
        // Slot 'processRectangle'
        QtMocHelpers::SlotData<void(QPoint, QPoint)>(97, 2, QMC::AccessPublic | QMC::MethodCloned, QMetaType::Void, {{
            { 0x80000000 | 91, 92 }, { 0x80000000 | 91, 93 },
        }}),
        // Slot 'processRectangleFixed'
        QtMocHelpers::SlotData<void(int)>(99, 2, QMC::AccessPublic, QMetaType::Void, {{
            { QMetaType::Int, 100 },
        }}),
        // Slot 'syncWCSState'
        QtMocHelpers::SlotData<void()>(101, 2, QMC::AccessPublic, QMetaType::Void),
        // Slot 'event'
        QtMocHelpers::SlotData<bool(QEvent *)>(67, 2, QMC::AccessProtected, QMetaType::Bool, {{
            { 0x80000000 | 102, 67 },
        }}),
        // Slot 'gestureEvent'
        QtMocHelpers::SlotData<bool(QGestureEvent *)>(103, 2, QMC::AccessProtected, QMetaType::Bool, {{
            { 0x80000000 | 104, 67 },
        }}),
        // Slot 'pinchTriggered'
        QtMocHelpers::SlotData<void(QPinchGesture *)>(105, 2, QMC::AccessProtected, QMetaType::Void, {{
            { 0x80000000 | 106, 107 },
        }}),
        // Method 'setStretchValues'
        QtMocHelpers::MethodData<void(double, double, double)>(108, 2, QMC::AccessPublic | QMC::MethodScriptable, QMetaType::Void, {{
            { QMetaType::Double, 109 }, { QMetaType::Double, 110 }, { QMetaType::Double, 111 },
        }}),
        // Method 'setAutoStretch'
        QtMocHelpers::MethodData<void()>(112, 2, QMC::AccessPublic | QMC::MethodScriptable, QMetaType::Void),
    };
    QtMocHelpers::UintData qt_properties {
        // property 'suspended'
        QtMocHelpers::PropertyData<bool>(113, QMetaType::Bool, QMC::DefaultPropertyFlags | QMC::Writable),
    };
    QtMocHelpers::UintData qt_enums {
    };
    return QtMocHelpers::metaObjectData<FITSView, qt_meta_tag_ZN8FITSViewE_t>(QMC::MetaObjectFlag{}, qt_stringData,
            qt_methods, qt_properties, qt_enums);
}
Q_CONSTINIT const QMetaObject FITSView::staticMetaObject = { {
    QMetaObject::SuperData::link<QScrollArea::staticMetaObject>(),
    qt_staticMetaObjectStaticContent<qt_meta_tag_ZN8FITSViewE_t>.stringdata,
    qt_staticMetaObjectStaticContent<qt_meta_tag_ZN8FITSViewE_t>.data,
    qt_static_metacall,
    nullptr,
    qt_staticMetaObjectRelocatingContent<qt_meta_tag_ZN8FITSViewE_t>.metaTypes,
    nullptr
} };

void FITSView::qt_static_metacall(QObject *_o, QMetaObject::Call _c, int _id, void **_a)
{
    auto *_t = static_cast<FITSView *>(_o);
    if (_c == QMetaObject::InvokeMetaMethod) {
        switch (_id) {
        case 0: _t->newStatus((*reinterpret_cast<std::add_pointer_t<QString>>(_a[1])),(*reinterpret_cast<std::add_pointer_t<FITSBar>>(_a[2]))); break;
        case 1: _t->newStretch((*reinterpret_cast<std::add_pointer_t<StretchParams>>(_a[1]))); break;
        case 2: _t->debayerToggled((*reinterpret_cast<std::add_pointer_t<bool>>(_a[1]))); break;
        case 3: _t->wcsToggled((*reinterpret_cast<std::add_pointer_t<bool>>(_a[1]))); break;
        case 4: _t->actionUpdated((*reinterpret_cast<std::add_pointer_t<QString>>(_a[1])),(*reinterpret_cast<std::add_pointer_t<bool>>(_a[2]))); break;
        case 5: _t->trackingStarSelected((*reinterpret_cast<std::add_pointer_t<int>>(_a[1])),(*reinterpret_cast<std::add_pointer_t<int>>(_a[2]))); break;
        case 6: _t->loaded(); break;
        case 7: _t->updated(); break;
        case 8: _t->failed((*reinterpret_cast<std::add_pointer_t<QString>>(_a[1]))); break;
        case 9: _t->starProfileWindowClosed(); break;
        case 10: _t->rectangleUpdated((*reinterpret_cast<std::add_pointer_t<QRect>>(_a[1]))); break;
        case 11: _t->setRubberBand((*reinterpret_cast<std::add_pointer_t<QRect>>(_a[1]))); break;
        case 12: _t->showRubberBand((*reinterpret_cast<std::add_pointer_t<bool>>(_a[1]))); break;
        case 13: _t->showRubberBand(); break;
        case 14: _t->zoomRubberBand((*reinterpret_cast<std::add_pointer_t<double>>(_a[1]))); break;
        case 15: _t->mouseOverPixel((*reinterpret_cast<std::add_pointer_t<int>>(_a[1])),(*reinterpret_cast<std::add_pointer_t<int>>(_a[2]))); break;
        case 16: _t->catLoaded(); break;
        case 17: _t->catQueried(); break;
        case 18: _t->catQueryFailed((*reinterpret_cast<std::add_pointer_t<QString>>(_a[1]))); break;
        case 19: _t->catReset(); break;
        case 20: _t->catHighlightChanged((*reinterpret_cast<std::add_pointer_t<int>>(_a[1]))); break;
        case 21: _t->headerChanged(); break;
        case 22: _t->plateSolveSub((*reinterpret_cast<std::add_pointer_t<double>>(_a[1])),(*reinterpret_cast<std::add_pointer_t<double>>(_a[2])),(*reinterpret_cast<std::add_pointer_t<double>>(_a[3])),(*reinterpret_cast<std::add_pointer_t<int>>(_a[4])),(*reinterpret_cast<std::add_pointer_t<int>>(_a[5])),(*reinterpret_cast<std::add_pointer_t<LiveStackFrameWeighting>>(_a[6]))); break;
        case 23: _t->stackInProgress(); break;
        case 24: _t->alignMasterChosen((*reinterpret_cast<std::add_pointer_t<QString>>(_a[1]))); break;
        case 25: _t->stackUpdateStats((*reinterpret_cast<std::add_pointer_t<bool>>(_a[1])),(*reinterpret_cast<std::add_pointer_t<int>>(_a[2])),(*reinterpret_cast<std::add_pointer_t<int>>(_a[3])),(*reinterpret_cast<std::add_pointer_t<double>>(_a[4])),(*reinterpret_cast<std::add_pointer_t<double>>(_a[5])),(*reinterpret_cast<std::add_pointer_t<double>>(_a[6]))); break;
        case 26: _t->updateStackSNR((*reinterpret_cast<std::add_pointer_t<double>>(_a[1]))); break;
        case 27: _t->resetStack((*reinterpret_cast<std::add_pointer_t<bool>>(_a[1]))); break;
        case 28: _t->stackFrameSaved((*reinterpret_cast<std::add_pointer_t<int>>(_a[1])),(*reinterpret_cast<std::add_pointer_t<QString>>(_a[2]))); break;
        case 29: _t->wheelEvent((*reinterpret_cast<std::add_pointer_t<QWheelEvent*>>(_a[1]))); break;
        case 30: _t->resizeEvent((*reinterpret_cast<std::add_pointer_t<QResizeEvent*>>(_a[1]))); break;
        case 31: _t->ZoomIn(); break;
        case 32: _t->ZoomOut(); break;
        case 33: _t->ZoomDefault(); break;
        case 34: _t->ZoomToFit(); break;
        case 35: _t->updateMagnifyingGlass((*reinterpret_cast<std::add_pointer_t<int>>(_a[1])),(*reinterpret_cast<std::add_pointer_t<int>>(_a[2]))); break;
        case 36: _t->toggleEQGrid(); break;
        case 37: _t->toggleObjects(); break;
        case 38: _t->togglePixelGrid(); break;
        case 39: _t->toggleCrosshair(); break;
        case 40: _t->toggleHiPSOverlay(); break;
        case 41: _t->toggleSelectionMode(); break;
        case 42: _t->toggleStars(); break;
        case 43: _t->toggleStarProfile(); break;
        case 44: _t->viewStarProfile(); break;
        case 45: _t->centerTelescope(); break;
        case 46: _t->toggleStretch(); break;
        case 47: _t->toggleClipping(); break;
        case 48: _t->processPointSelection((*reinterpret_cast<std::add_pointer_t<int>>(_a[1])),(*reinterpret_cast<std::add_pointer_t<int>>(_a[2]))); break;
        case 49: _t->processMarkerSelection((*reinterpret_cast<std::add_pointer_t<int>>(_a[1])),(*reinterpret_cast<std::add_pointer_t<int>>(_a[2]))); break;
        case 50: _t->processHighlight((*reinterpret_cast<std::add_pointer_t<int>>(_a[1])),(*reinterpret_cast<std::add_pointer_t<int>>(_a[2]))); break;
        case 51: _t->processCircle((*reinterpret_cast<std::add_pointer_t<QPoint>>(_a[1])),(*reinterpret_cast<std::add_pointer_t<QPoint>>(_a[2]))); break;
        case 52: _t->move3DTrackingBox((*reinterpret_cast<std::add_pointer_t<int>>(_a[1])),(*reinterpret_cast<std::add_pointer_t<int>>(_a[2]))); break;
        case 53: _t->resizeTrackingBox((*reinterpret_cast<std::add_pointer_t<int>>(_a[1]))); break;
        case 54: _t->processRectangle((*reinterpret_cast<std::add_pointer_t<QPoint>>(_a[1])),(*reinterpret_cast<std::add_pointer_t<QPoint>>(_a[2])),(*reinterpret_cast<std::add_pointer_t<bool>>(_a[3]))); break;
        case 55: _t->processRectangle((*reinterpret_cast<std::add_pointer_t<QPoint>>(_a[1])),(*reinterpret_cast<std::add_pointer_t<QPoint>>(_a[2]))); break;
        case 56: _t->processRectangleFixed((*reinterpret_cast<std::add_pointer_t<int>>(_a[1]))); break;
        case 57: _t->syncWCSState(); break;
        case 58: { bool _r = _t->event((*reinterpret_cast<std::add_pointer_t<QEvent*>>(_a[1])));
            if (_a[0]) *reinterpret_cast<bool*>(_a[0]) = std::move(_r); }  break;
        case 59: { bool _r = _t->gestureEvent((*reinterpret_cast<std::add_pointer_t<QGestureEvent*>>(_a[1])));
            if (_a[0]) *reinterpret_cast<bool*>(_a[0]) = std::move(_r); }  break;
        case 60: _t->pinchTriggered((*reinterpret_cast<std::add_pointer_t<QPinchGesture*>>(_a[1]))); break;
        case 61: _t->setStretchValues((*reinterpret_cast<std::add_pointer_t<double>>(_a[1])),(*reinterpret_cast<std::add_pointer_t<double>>(_a[2])),(*reinterpret_cast<std::add_pointer_t<double>>(_a[3]))); break;
        case 62: _t->setAutoStretch(); break;
        default: ;
        }
    }
    if (_c == QMetaObject::IndexOfMethod) {
        if (QtMocHelpers::indexOfMethod<void (FITSView::*)(const QString & , FITSBar )>(_a, &FITSView::newStatus, 0))
            return;
        if (QtMocHelpers::indexOfMethod<void (FITSView::*)(const StretchParams & )>(_a, &FITSView::newStretch, 1))
            return;
        if (QtMocHelpers::indexOfMethod<void (FITSView::*)(bool )>(_a, &FITSView::debayerToggled, 2))
            return;
        if (QtMocHelpers::indexOfMethod<void (FITSView::*)(bool )>(_a, &FITSView::wcsToggled, 3))
            return;
        if (QtMocHelpers::indexOfMethod<void (FITSView::*)(const QString & , bool )>(_a, &FITSView::actionUpdated, 4))
            return;
        if (QtMocHelpers::indexOfMethod<void (FITSView::*)(int , int )>(_a, &FITSView::trackingStarSelected, 5))
            return;
        if (QtMocHelpers::indexOfMethod<void (FITSView::*)()>(_a, &FITSView::loaded, 6))
            return;
        if (QtMocHelpers::indexOfMethod<void (FITSView::*)()>(_a, &FITSView::updated, 7))
            return;
        if (QtMocHelpers::indexOfMethod<void (FITSView::*)(const QString & )>(_a, &FITSView::failed, 8))
            return;
        if (QtMocHelpers::indexOfMethod<void (FITSView::*)()>(_a, &FITSView::starProfileWindowClosed, 9))
            return;
        if (QtMocHelpers::indexOfMethod<void (FITSView::*)(QRect )>(_a, &FITSView::rectangleUpdated, 10))
            return;
        if (QtMocHelpers::indexOfMethod<void (FITSView::*)(QRect )>(_a, &FITSView::setRubberBand, 11))
            return;
        if (QtMocHelpers::indexOfMethod<void (FITSView::*)(bool )>(_a, &FITSView::showRubberBand, 12))
            return;
        if (QtMocHelpers::indexOfMethod<void (FITSView::*)(double )>(_a, &FITSView::zoomRubberBand, 14))
            return;
        if (QtMocHelpers::indexOfMethod<void (FITSView::*)(int , int )>(_a, &FITSView::mouseOverPixel, 15))
            return;
        if (QtMocHelpers::indexOfMethod<void (FITSView::*)()>(_a, &FITSView::catLoaded, 16))
            return;
        if (QtMocHelpers::indexOfMethod<void (FITSView::*)()>(_a, &FITSView::catQueried, 17))
            return;
        if (QtMocHelpers::indexOfMethod<void (FITSView::*)(const QString )>(_a, &FITSView::catQueryFailed, 18))
            return;
        if (QtMocHelpers::indexOfMethod<void (FITSView::*)()>(_a, &FITSView::catReset, 19))
            return;
        if (QtMocHelpers::indexOfMethod<void (FITSView::*)(const int )>(_a, &FITSView::catHighlightChanged, 20))
            return;
        if (QtMocHelpers::indexOfMethod<void (FITSView::*)()>(_a, &FITSView::headerChanged, 21))
            return;
        if (QtMocHelpers::indexOfMethod<void (FITSView::*)(const double , const double , const double , const int , const int , const LiveStackFrameWeighting & )>(_a, &FITSView::plateSolveSub, 22))
            return;
        if (QtMocHelpers::indexOfMethod<void (FITSView::*)()>(_a, &FITSView::stackInProgress, 23))
            return;
        if (QtMocHelpers::indexOfMethod<void (FITSView::*)(const QString & )>(_a, &FITSView::alignMasterChosen, 24))
            return;
        if (QtMocHelpers::indexOfMethod<void (FITSView::*)(const bool , const int , const int , const double , const double , const double )>(_a, &FITSView::stackUpdateStats, 25))
            return;
        if (QtMocHelpers::indexOfMethod<void (FITSView::*)(const double )>(_a, &FITSView::updateStackSNR, 26))
            return;
        if (QtMocHelpers::indexOfMethod<void (FITSView::*)(const bool )>(_a, &FITSView::resetStack, 27))
            return;
        if (QtMocHelpers::indexOfMethod<void (FITSView::*)(int , const QString & )>(_a, &FITSView::stackFrameSaved, 28))
            return;
    }
    if (_c == QMetaObject::ReadProperty) {
        void *_v = _a[0];
        switch (_id) {
        case 0: *reinterpret_cast<bool*>(_v) = _t->m_Suspended; break;
        default: break;
        }
    }
    if (_c == QMetaObject::WriteProperty) {
        void *_v = _a[0];
        switch (_id) {
        case 0: QtMocHelpers::setProperty(_t->m_Suspended, *reinterpret_cast<bool*>(_v)); break;
        default: break;
        }
    }
}

const QMetaObject *FITSView::metaObject() const
{
    return QObject::d_ptr->metaObject ? QObject::d_ptr->dynamicMetaObject() : &staticMetaObject;
}

void *FITSView::qt_metacast(const char *_clname)
{
    if (!_clname) return nullptr;
    if (!strcmp(_clname, qt_staticMetaObjectStaticContent<qt_meta_tag_ZN8FITSViewE_t>.strings))
        return static_cast<void*>(this);
    return QScrollArea::qt_metacast(_clname);
}

int FITSView::qt_metacall(QMetaObject::Call _c, int _id, void **_a)
{
    _id = QScrollArea::qt_metacall(_c, _id, _a);
    if (_id < 0)
        return _id;
    if (_c == QMetaObject::InvokeMetaMethod) {
        if (_id < 63)
            qt_static_metacall(this, _c, _id, _a);
        _id -= 63;
    }
    if (_c == QMetaObject::RegisterMethodArgumentMetaType) {
        if (_id < 63)
            *reinterpret_cast<QMetaType *>(_a[0]) = QMetaType();
        _id -= 63;
    }
    if (_c == QMetaObject::ReadProperty || _c == QMetaObject::WriteProperty
            || _c == QMetaObject::ResetProperty || _c == QMetaObject::BindableProperty
            || _c == QMetaObject::RegisterPropertyMetaType) {
        qt_static_metacall(this, _c, _id, _a);
        _id -= 1;
    }
    return _id;
}

// SIGNAL 0
void FITSView::newStatus(const QString & _t1, FITSBar _t2)
{
    QMetaObject::activate<void>(this, &staticMetaObject, 0, nullptr, _t1, _t2);
}

// SIGNAL 1
void FITSView::newStretch(const StretchParams & _t1)
{
    QMetaObject::activate<void>(this, &staticMetaObject, 1, nullptr, _t1);
}

// SIGNAL 2
void FITSView::debayerToggled(bool _t1)
{
    QMetaObject::activate<void>(this, &staticMetaObject, 2, nullptr, _t1);
}

// SIGNAL 3
void FITSView::wcsToggled(bool _t1)
{
    QMetaObject::activate<void>(this, &staticMetaObject, 3, nullptr, _t1);
}

// SIGNAL 4
void FITSView::actionUpdated(const QString & _t1, bool _t2)
{
    QMetaObject::activate<void>(this, &staticMetaObject, 4, nullptr, _t1, _t2);
}

// SIGNAL 5
void FITSView::trackingStarSelected(int _t1, int _t2)
{
    QMetaObject::activate<void>(this, &staticMetaObject, 5, nullptr, _t1, _t2);
}

// SIGNAL 6
void FITSView::loaded()
{
    QMetaObject::activate(this, &staticMetaObject, 6, nullptr);
}

// SIGNAL 7
void FITSView::updated()
{
    QMetaObject::activate(this, &staticMetaObject, 7, nullptr);
}

// SIGNAL 8
void FITSView::failed(const QString & _t1)
{
    QMetaObject::activate<void>(this, &staticMetaObject, 8, nullptr, _t1);
}

// SIGNAL 9
void FITSView::starProfileWindowClosed()
{
    QMetaObject::activate(this, &staticMetaObject, 9, nullptr);
}

// SIGNAL 10
void FITSView::rectangleUpdated(QRect _t1)
{
    QMetaObject::activate<void>(this, &staticMetaObject, 10, nullptr, _t1);
}

// SIGNAL 11
void FITSView::setRubberBand(QRect _t1)
{
    QMetaObject::activate<void>(this, &staticMetaObject, 11, nullptr, _t1);
}

// SIGNAL 12
void FITSView::showRubberBand(bool _t1)
{
    QMetaObject::activate<void>(this, &staticMetaObject, 12, nullptr, _t1);
}

// SIGNAL 14
void FITSView::zoomRubberBand(double _t1)
{
    QMetaObject::activate<void>(this, &staticMetaObject, 14, nullptr, _t1);
}

// SIGNAL 15
void FITSView::mouseOverPixel(int _t1, int _t2)
{
    QMetaObject::activate<void>(this, &staticMetaObject, 15, nullptr, _t1, _t2);
}

// SIGNAL 16
void FITSView::catLoaded()
{
    QMetaObject::activate(this, &staticMetaObject, 16, nullptr);
}

// SIGNAL 17
void FITSView::catQueried()
{
    QMetaObject::activate(this, &staticMetaObject, 17, nullptr);
}

// SIGNAL 18
void FITSView::catQueryFailed(const QString _t1)
{
    QMetaObject::activate<void>(this, &staticMetaObject, 18, nullptr, _t1);
}

// SIGNAL 19
void FITSView::catReset()
{
    QMetaObject::activate(this, &staticMetaObject, 19, nullptr);
}

// SIGNAL 20
void FITSView::catHighlightChanged(const int _t1)
{
    QMetaObject::activate<void>(this, &staticMetaObject, 20, nullptr, _t1);
}

// SIGNAL 21
void FITSView::headerChanged()
{
    QMetaObject::activate(this, &staticMetaObject, 21, nullptr);
}

// SIGNAL 22
void FITSView::plateSolveSub(const double _t1, const double _t2, const double _t3, const int _t4, const int _t5, const LiveStackFrameWeighting & _t6)
{
    QMetaObject::activate<void>(this, &staticMetaObject, 22, nullptr, _t1, _t2, _t3, _t4, _t5, _t6);
}

// SIGNAL 23
void FITSView::stackInProgress()
{
    QMetaObject::activate(this, &staticMetaObject, 23, nullptr);
}

// SIGNAL 24
void FITSView::alignMasterChosen(const QString & _t1)
{
    QMetaObject::activate<void>(this, &staticMetaObject, 24, nullptr, _t1);
}

// SIGNAL 25
void FITSView::stackUpdateStats(const bool _t1, const int _t2, const int _t3, const double _t4, const double _t5, const double _t6)
{
    QMetaObject::activate<void>(this, &staticMetaObject, 25, nullptr, _t1, _t2, _t3, _t4, _t5, _t6);
}

// SIGNAL 26
void FITSView::updateStackSNR(const double _t1)
{
    QMetaObject::activate<void>(this, &staticMetaObject, 26, nullptr, _t1);
}

// SIGNAL 27
void FITSView::resetStack(const bool _t1)
{
    QMetaObject::activate<void>(this, &staticMetaObject, 27, nullptr, _t1);
}

// SIGNAL 28
void FITSView::stackFrameSaved(int _t1, const QString & _t2)
{
    QMetaObject::activate<void>(this, &staticMetaObject, 28, nullptr, _t1, _t2);
}
QT_WARNING_POP
