/********************************************************************************
** Form generated from reading UI file 'fitsheaderdialog.ui'
**
** Created by: Qt User Interface Compiler version 6.11.1
**
** WARNING! All changes made in this file will be lost when recompiling UI file!
********************************************************************************/

#ifndef UI_FITSHEADERDIALOG_H
#define UI_FITSHEADERDIALOG_H

#include <QtCore/QVariant>
#include <QtWidgets/QApplication>
#include <QtWidgets/QDialog>
#include <QtWidgets/QHeaderView>
#include <QtWidgets/QTableWidget>
#include <QtWidgets/QVBoxLayout>
#include <klocalizedstring.h>

QT_BEGIN_NAMESPACE

class Ui_fitsHeaderDialog
{
public:
    QVBoxLayout *vboxLayout;
    QTableWidget *tableWidget;

    void setupUi(QDialog *fitsHeaderDialog)
    {
        if (fitsHeaderDialog->objectName().isEmpty())
            fitsHeaderDialog->setObjectName("fitsHeaderDialog");
        fitsHeaderDialog->resize(511, 247);
        fitsHeaderDialog->setSizeGripEnabled(true);
        vboxLayout = new QVBoxLayout(fitsHeaderDialog);
        vboxLayout->setSpacing(6);
        vboxLayout->setObjectName("vboxLayout");
        vboxLayout->setContentsMargins(9, 9, 9, 9);
        tableWidget = new QTableWidget(fitsHeaderDialog);
        if (tableWidget->columnCount() < 3)
            tableWidget->setColumnCount(3);
        QTableWidgetItem *__qtablewidgetitem = new QTableWidgetItem();
        tableWidget->setHorizontalHeaderItem(0, __qtablewidgetitem);
        QTableWidgetItem *__qtablewidgetitem1 = new QTableWidgetItem();
        tableWidget->setHorizontalHeaderItem(1, __qtablewidgetitem1);
        QTableWidgetItem *__qtablewidgetitem2 = new QTableWidgetItem();
        tableWidget->setHorizontalHeaderItem(2, __qtablewidgetitem2);
        tableWidget->setObjectName("tableWidget");
        tableWidget->setEditTriggers(QAbstractItemView::NoEditTriggers);
        tableWidget->setAlternatingRowColors(true);
        tableWidget->setShowGrid(true);

        vboxLayout->addWidget(tableWidget);


        retranslateUi(fitsHeaderDialog);

        QMetaObject::connectSlotsByName(fitsHeaderDialog);
    } // setupUi

    void retranslateUi(QDialog *fitsHeaderDialog)
    {
        fitsHeaderDialog->setWindowTitle(tr2i18n("FITS Header", nullptr));
        QTableWidgetItem *___qtablewidgetitem = tableWidget->horizontalHeaderItem(0);
        ___qtablewidgetitem->setText(tr2i18n("Keyword", nullptr));
        QTableWidgetItem *___qtablewidgetitem1 = tableWidget->horizontalHeaderItem(1);
        ___qtablewidgetitem1->setText(tr2i18n("Value", nullptr));
        QTableWidgetItem *___qtablewidgetitem2 = tableWidget->horizontalHeaderItem(2);
        ___qtablewidgetitem2->setText(tr2i18n("Comment", nullptr));
    } // retranslateUi

};

namespace Ui {
    class fitsHeaderDialog: public Ui_fitsHeaderDialog {};
} // namespace Ui

QT_END_NAMESPACE

#endif // FITSHEADERDIALOG_H

