/********************************************************************************
** Form generated from reading UI file 'opsxplanet.ui'
**
** Created by: Qt User Interface Compiler version 6.11.1
**
** WARNING! All changes made in this file will be lost when recompiling UI file!
********************************************************************************/

#ifndef UI_OPSXPLANET_H
#define UI_OPSXPLANET_H

#include <QtCore/QVariant>
#include <QtWidgets/QApplication>
#include <QtWidgets/QCheckBox>
#include <QtWidgets/QComboBox>
#include <QtWidgets/QFormLayout>
#include <QtWidgets/QFrame>
#include <QtWidgets/QGridLayout>
#include <QtWidgets/QGroupBox>
#include <QtWidgets/QHBoxLayout>
#include <QtWidgets/QLabel>
#include <QtWidgets/QLineEdit>
#include <QtWidgets/QPushButton>
#include <QtWidgets/QRadioButton>
#include <QtWidgets/QSpacerItem>
#include <QtWidgets/QSpinBox>
#include <QtWidgets/QTabWidget>
#include <QtWidgets/QVBoxLayout>
#include <QtWidgets/QWidget>
#include <klocalizedstring.h>
#include "kcolorbutton.h"

QT_BEGIN_NAMESPACE

class Ui_OpsXplanet
{
public:
    QGridLayout *gridLayout;
    QTabWidget *tab;
    QWidget *XplanetTabGeneral;
    QGridLayout *gridLayout_2;
    QVBoxLayout *verticalLayout;
    QFormLayout *formLayout;
    QHBoxLayout *horizontalLayout_12;
    QCheckBox *kcfg_xplanetIsInternal;
    QLabel *textLabelXplanetPath;
    QLineEdit *kcfg_XplanetPath;
    QLabel *textLabelXplanetGeometryX;
    QHBoxLayout *horizontalLayout_2;
    QLineEdit *kcfg_XplanetWidth;
    QLabel *textLabelXplanetGeometryY;
    QLineEdit *kcfg_XplanetHeight;
    QLabel *label;
    QSpacerItem *horizontalSpacer;
    QLineEdit *kcfg_XplanetTimeout;
    QLabel *label_3;
    QLabel *label_4;
    QLineEdit *kcfg_XplanetAnimationDelay;
    QSpacerItem *verticalSpacer;
    QFormLayout *formLayout_2;
    QCheckBox *kcfg_XplanetUseFIFO;
    QLabel *label_5;
    QCheckBox *kcfg_XplanetFOV;
    QLabel *textLabelXplanetMagnitude;
    QSpinBox *kcfg_XplanetMagnitude;
    QWidget *widget;
    QCheckBox *kcfg_XplanetConfigFile;
    QHBoxLayout *horizontalLayout_3;
    QLineEdit *kcfg_XplanetConfigFilePath;
    QPushButton *configFileB;
    QCheckBox *kcfg_XplanetStarmap;
    QHBoxLayout *horizontalLayout_10;
    QLineEdit *kcfg_XplanetStarmapPath;
    QPushButton *starmapFileB;
    QCheckBox *kcfg_XplanetArcFile;
    QHBoxLayout *horizontalLayout_11;
    QLineEdit *kcfg_XplanetArcFilePath;
    QPushButton *arcFileB;
    QSpinBox *kcfg_XplanetGlare;
    QLabel *textLabelXplanetGlare;
    QSpacerItem *verticalSpacer_8;
    QHBoxLayout *horizontalLayout_9;
    QLabel *textLabelXplanetQuality;
    QSpinBox *kcfg_XplanetQuality;
    QSpacerItem *horizontalSpacer_4;
    QLabel *label_6;
    QPushButton *openXPlanetMaps;
    QSpacerItem *verticalSpacer_2;
    QWidget *XplanetTabLabel;
    QGridLayout *gridLayout_7;
    QVBoxLayout *verticalLayout_5;
    QGroupBox *groupBox;
    QGridLayout *gridLayout_5;
    QFormLayout *formLayout_3;
    QHBoxLayout *horizontalLayout;
    QRadioButton *kcfg_XplanetLabelLocalTime;
    QRadioButton *kcfg_XplanetLabelGMT;
    QLabel *textLabelXplanetLabelString;
    QLineEdit *kcfg_XplanetLabelString;
    QLabel *textLabelXplanetDateFormat;
    QLineEdit *kcfg_XplanetDateFormat;
    QLabel *textLabelXplanetFontSize;
    QSpinBox *kcfg_XplanetFontSize;
    QLabel *textLabelXplanetColor;
    KColorButton *kcfg_XplanetColor;
    QFrame *frame_2;
    QGridLayout *gridLayout_4;
    QHBoxLayout *horizontalLayout_4;
    QVBoxLayout *verticalLayout_2;
    QRadioButton *kcfg_XplanetLabelTL;
    QRadioButton *kcfg_XplanetLabelBL;
    QVBoxLayout *verticalLayout_3;
    QRadioButton *kcfg_XplanetLabelTR;
    QRadioButton *kcfg_XplanetLabelBR;
    QVBoxLayout *verticalLayout_4;
    QSpacerItem *verticalSpacer_3;
    QLabel *textLabelLabelPos;
    QSpacerItem *verticalSpacer_4;
    QCheckBox *kcfg_XplanetLabel;
    QGroupBox *groupBox_2;
    QGridLayout *gridLayout_6;
    QFormLayout *formLayout_4;
    QCheckBox *kcfg_XplanetMarkerFile;
    QLineEdit *kcfg_XplanetMarkerFilePath;
    QCheckBox *kcfg_XplanetMarkerBounds;
    QLineEdit *kcfg_XplanetMarkerBoundsPath;
    QSpacerItem *verticalSpacer_6;
    QWidget *XplanetTabPosition;
    QGridLayout *gridLayout_3;
    QVBoxLayout *verticalLayout_6;
    QHBoxLayout *horizontalLayout_5;
    QRadioButton *kcfg_XplanetLatLong;
    QSpinBox *kcfg_XplanetLatitude;
    QLabel *textLabelXplanetLongitude;
    QSpinBox *kcfg_XplanetLongitude;
    QLabel *label_2;
    QRadioButton *kcfg_XplanetRandom;
    QSpacerItem *verticalSpacer_5;
    QWidget *XplanetTabProjection;
    QGridLayout *gridLayout_9;
    QVBoxLayout *verticalLayout_8;
    QHBoxLayout *horizontalLayout_6;
    QLabel *textLabelXplanetProjection;
    QComboBox *kcfg_XplanetProjection;
    QSpacerItem *horizontalSpacer_2;
    QGroupBox *groupBoxBackground;
    QGridLayout *gridLayout_8;
    QVBoxLayout *verticalLayout_7;
    QCheckBox *kcfg_XplanetBackground;
    QHBoxLayout *horizontalLayout_7;
    QRadioButton *kcfg_XplanetBackgroundImage;
    QLineEdit *kcfg_XplanetBackgroundImagePath;
    QHBoxLayout *horizontalLayout_8;
    QRadioButton *kcfg_XplanetBackgroundColor;
    KColorButton *kcfg_XplanetBackgroundColorValue;
    QSpacerItem *horizontalSpacer_3;
    QSpacerItem *verticalSpacer_7;

    void setupUi(QWidget *OpsXplanet)
    {
        if (OpsXplanet->objectName().isEmpty())
            OpsXplanet->setObjectName("OpsXplanet");
        OpsXplanet->resize(622, 665);
        gridLayout = new QGridLayout(OpsXplanet);
        gridLayout->setObjectName("gridLayout");
        tab = new QTabWidget(OpsXplanet);
        tab->setObjectName("tab");
        XplanetTabGeneral = new QWidget();
        XplanetTabGeneral->setObjectName("XplanetTabGeneral");
        gridLayout_2 = new QGridLayout(XplanetTabGeneral);
        gridLayout_2->setObjectName("gridLayout_2");
        verticalLayout = new QVBoxLayout();
        verticalLayout->setObjectName("verticalLayout");
        formLayout = new QFormLayout();
        formLayout->setObjectName("formLayout");
        formLayout->setFieldGrowthPolicy(QFormLayout::ExpandingFieldsGrow);
        formLayout->setFormAlignment(Qt::AlignLeading|Qt::AlignLeft|Qt::AlignVCenter);
        horizontalLayout_12 = new QHBoxLayout();
        horizontalLayout_12->setObjectName("horizontalLayout_12");
        horizontalLayout_12->setContentsMargins(-1, 0, 0, -1);
        kcfg_xplanetIsInternal = new QCheckBox(XplanetTabGeneral);
        kcfg_xplanetIsInternal->setObjectName("kcfg_xplanetIsInternal");

        horizontalLayout_12->addWidget(kcfg_xplanetIsInternal);

        textLabelXplanetPath = new QLabel(XplanetTabGeneral);
        textLabelXplanetPath->setObjectName("textLabelXplanetPath");

        horizontalLayout_12->addWidget(textLabelXplanetPath);


        formLayout->setLayout(0, QFormLayout::ItemRole::LabelRole, horizontalLayout_12);

        kcfg_XplanetPath = new QLineEdit(XplanetTabGeneral);
        kcfg_XplanetPath->setObjectName("kcfg_XplanetPath");
        QSizePolicy sizePolicy(QSizePolicy::Policy::MinimumExpanding, QSizePolicy::Policy::Preferred);
        sizePolicy.setHorizontalStretch(0);
        sizePolicy.setVerticalStretch(0);
        sizePolicy.setHeightForWidth(kcfg_XplanetPath->sizePolicy().hasHeightForWidth());
        kcfg_XplanetPath->setSizePolicy(sizePolicy);

        formLayout->setWidget(0, QFormLayout::ItemRole::FieldRole, kcfg_XplanetPath);

        textLabelXplanetGeometryX = new QLabel(XplanetTabGeneral);
        textLabelXplanetGeometryX->setObjectName("textLabelXplanetGeometryX");

        formLayout->setWidget(3, QFormLayout::ItemRole::LabelRole, textLabelXplanetGeometryX);

        horizontalLayout_2 = new QHBoxLayout();
        horizontalLayout_2->setObjectName("horizontalLayout_2");
        horizontalLayout_2->setSizeConstraint(QLayout::SetMaximumSize);
        kcfg_XplanetWidth = new QLineEdit(XplanetTabGeneral);
        kcfg_XplanetWidth->setObjectName("kcfg_XplanetWidth");
        QSizePolicy sizePolicy1(QSizePolicy::Policy::Preferred, QSizePolicy::Policy::Preferred);
        sizePolicy1.setHorizontalStretch(0);
        sizePolicy1.setVerticalStretch(0);
        sizePolicy1.setHeightForWidth(kcfg_XplanetWidth->sizePolicy().hasHeightForWidth());
        kcfg_XplanetWidth->setSizePolicy(sizePolicy1);
        kcfg_XplanetWidth->setMaximumSize(QSize(50, 16777215));

        horizontalLayout_2->addWidget(kcfg_XplanetWidth);

        textLabelXplanetGeometryY = new QLabel(XplanetTabGeneral);
        textLabelXplanetGeometryY->setObjectName("textLabelXplanetGeometryY");

        horizontalLayout_2->addWidget(textLabelXplanetGeometryY);

        kcfg_XplanetHeight = new QLineEdit(XplanetTabGeneral);
        kcfg_XplanetHeight->setObjectName("kcfg_XplanetHeight");
        kcfg_XplanetHeight->setEnabled(true);
        kcfg_XplanetHeight->setMaximumSize(QSize(50, 16777215));

        horizontalLayout_2->addWidget(kcfg_XplanetHeight);

        label = new QLabel(XplanetTabGeneral);
        label->setObjectName("label");

        horizontalLayout_2->addWidget(label);

        horizontalSpacer = new QSpacerItem(40, 20, QSizePolicy::Policy::Expanding, QSizePolicy::Policy::Minimum);

        horizontalLayout_2->addItem(horizontalSpacer);


        formLayout->setLayout(3, QFormLayout::ItemRole::FieldRole, horizontalLayout_2);

        kcfg_XplanetTimeout = new QLineEdit(XplanetTabGeneral);
        kcfg_XplanetTimeout->setObjectName("kcfg_XplanetTimeout");

        formLayout->setWidget(1, QFormLayout::ItemRole::FieldRole, kcfg_XplanetTimeout);

        label_3 = new QLabel(XplanetTabGeneral);
        label_3->setObjectName("label_3");

        formLayout->setWidget(1, QFormLayout::ItemRole::LabelRole, label_3);

        label_4 = new QLabel(XplanetTabGeneral);
        label_4->setObjectName("label_4");

        formLayout->setWidget(2, QFormLayout::ItemRole::LabelRole, label_4);

        kcfg_XplanetAnimationDelay = new QLineEdit(XplanetTabGeneral);
        kcfg_XplanetAnimationDelay->setObjectName("kcfg_XplanetAnimationDelay");

        formLayout->setWidget(2, QFormLayout::ItemRole::FieldRole, kcfg_XplanetAnimationDelay);


        verticalLayout->addLayout(formLayout);

        verticalSpacer = new QSpacerItem(506, 13, QSizePolicy::Policy::Minimum, QSizePolicy::Policy::Fixed);

        verticalLayout->addItem(verticalSpacer);

        formLayout_2 = new QFormLayout();
        formLayout_2->setObjectName("formLayout_2");
        formLayout_2->setFieldGrowthPolicy(QFormLayout::ExpandingFieldsGrow);
        formLayout_2->setLabelAlignment(Qt::AlignLeading|Qt::AlignLeft|Qt::AlignVCenter);
        kcfg_XplanetUseFIFO = new QCheckBox(XplanetTabGeneral);
        kcfg_XplanetUseFIFO->setObjectName("kcfg_XplanetUseFIFO");

        formLayout_2->setWidget(1, QFormLayout::ItemRole::LabelRole, kcfg_XplanetUseFIFO);

        label_5 = new QLabel(XplanetTabGeneral);
        label_5->setObjectName("label_5");

        formLayout_2->setWidget(1, QFormLayout::ItemRole::FieldRole, label_5);

        kcfg_XplanetFOV = new QCheckBox(XplanetTabGeneral);
        kcfg_XplanetFOV->setObjectName("kcfg_XplanetFOV");

        formLayout_2->setWidget(2, QFormLayout::ItemRole::LabelRole, kcfg_XplanetFOV);

        textLabelXplanetMagnitude = new QLabel(XplanetTabGeneral);
        textLabelXplanetMagnitude->setObjectName("textLabelXplanetMagnitude");

        formLayout_2->setWidget(6, QFormLayout::ItemRole::LabelRole, textLabelXplanetMagnitude);

        kcfg_XplanetMagnitude = new QSpinBox(XplanetTabGeneral);
        kcfg_XplanetMagnitude->setObjectName("kcfg_XplanetMagnitude");
        sizePolicy1.setHeightForWidth(kcfg_XplanetMagnitude->sizePolicy().hasHeightForWidth());
        kcfg_XplanetMagnitude->setSizePolicy(sizePolicy1);

        formLayout_2->setWidget(6, QFormLayout::ItemRole::FieldRole, kcfg_XplanetMagnitude);

        widget = new QWidget(XplanetTabGeneral);
        widget->setObjectName("widget");

        formLayout_2->setWidget(8, QFormLayout::ItemRole::FieldRole, widget);

        kcfg_XplanetConfigFile = new QCheckBox(XplanetTabGeneral);
        kcfg_XplanetConfigFile->setObjectName("kcfg_XplanetConfigFile");

        formLayout_2->setWidget(10, QFormLayout::ItemRole::LabelRole, kcfg_XplanetConfigFile);

        horizontalLayout_3 = new QHBoxLayout();
        horizontalLayout_3->setObjectName("horizontalLayout_3");
        horizontalLayout_3->setSizeConstraint(QLayout::SetMaximumSize);
        horizontalLayout_3->setContentsMargins(0, 0, -1, -1);
        kcfg_XplanetConfigFilePath = new QLineEdit(XplanetTabGeneral);
        kcfg_XplanetConfigFilePath->setObjectName("kcfg_XplanetConfigFilePath");
        QSizePolicy sizePolicy2(QSizePolicy::Policy::Expanding, QSizePolicy::Policy::Fixed);
        sizePolicy2.setHorizontalStretch(0);
        sizePolicy2.setVerticalStretch(0);
        sizePolicy2.setHeightForWidth(kcfg_XplanetConfigFilePath->sizePolicy().hasHeightForWidth());
        kcfg_XplanetConfigFilePath->setSizePolicy(sizePolicy2);

        horizontalLayout_3->addWidget(kcfg_XplanetConfigFilePath);

        configFileB = new QPushButton(XplanetTabGeneral);
        configFileB->setObjectName("configFileB");
        configFileB->setMinimumSize(QSize(28, 28));
        configFileB->setMaximumSize(QSize(28, 28));

        horizontalLayout_3->addWidget(configFileB);


        formLayout_2->setLayout(10, QFormLayout::ItemRole::FieldRole, horizontalLayout_3);

        kcfg_XplanetStarmap = new QCheckBox(XplanetTabGeneral);
        kcfg_XplanetStarmap->setObjectName("kcfg_XplanetStarmap");

        formLayout_2->setWidget(11, QFormLayout::ItemRole::LabelRole, kcfg_XplanetStarmap);

        horizontalLayout_10 = new QHBoxLayout();
        horizontalLayout_10->setObjectName("horizontalLayout_10");
        horizontalLayout_10->setSizeConstraint(QLayout::SetMaximumSize);
        horizontalLayout_10->setContentsMargins(0, 0, -1, -1);
        kcfg_XplanetStarmapPath = new QLineEdit(XplanetTabGeneral);
        kcfg_XplanetStarmapPath->setObjectName("kcfg_XplanetStarmapPath");
        sizePolicy2.setHeightForWidth(kcfg_XplanetStarmapPath->sizePolicy().hasHeightForWidth());
        kcfg_XplanetStarmapPath->setSizePolicy(sizePolicy2);

        horizontalLayout_10->addWidget(kcfg_XplanetStarmapPath);

        starmapFileB = new QPushButton(XplanetTabGeneral);
        starmapFileB->setObjectName("starmapFileB");
        starmapFileB->setMinimumSize(QSize(28, 28));
        starmapFileB->setMaximumSize(QSize(28, 28));

        horizontalLayout_10->addWidget(starmapFileB);


        formLayout_2->setLayout(11, QFormLayout::ItemRole::FieldRole, horizontalLayout_10);

        kcfg_XplanetArcFile = new QCheckBox(XplanetTabGeneral);
        kcfg_XplanetArcFile->setObjectName("kcfg_XplanetArcFile");

        formLayout_2->setWidget(12, QFormLayout::ItemRole::LabelRole, kcfg_XplanetArcFile);

        horizontalLayout_11 = new QHBoxLayout();
        horizontalLayout_11->setObjectName("horizontalLayout_11");
        horizontalLayout_11->setSizeConstraint(QLayout::SetMaximumSize);
        horizontalLayout_11->setContentsMargins(0, 0, -1, -1);
        kcfg_XplanetArcFilePath = new QLineEdit(XplanetTabGeneral);
        kcfg_XplanetArcFilePath->setObjectName("kcfg_XplanetArcFilePath");
        sizePolicy2.setHeightForWidth(kcfg_XplanetArcFilePath->sizePolicy().hasHeightForWidth());
        kcfg_XplanetArcFilePath->setSizePolicy(sizePolicy2);

        horizontalLayout_11->addWidget(kcfg_XplanetArcFilePath);

        arcFileB = new QPushButton(XplanetTabGeneral);
        arcFileB->setObjectName("arcFileB");
        arcFileB->setMinimumSize(QSize(28, 28));
        arcFileB->setMaximumSize(QSize(28, 28));

        horizontalLayout_11->addWidget(arcFileB);


        formLayout_2->setLayout(12, QFormLayout::ItemRole::FieldRole, horizontalLayout_11);

        kcfg_XplanetGlare = new QSpinBox(XplanetTabGeneral);
        kcfg_XplanetGlare->setObjectName("kcfg_XplanetGlare");
        sizePolicy1.setHeightForWidth(kcfg_XplanetGlare->sizePolicy().hasHeightForWidth());
        kcfg_XplanetGlare->setSizePolicy(sizePolicy1);

        formLayout_2->setWidget(5, QFormLayout::ItemRole::FieldRole, kcfg_XplanetGlare);

        textLabelXplanetGlare = new QLabel(XplanetTabGeneral);
        textLabelXplanetGlare->setObjectName("textLabelXplanetGlare");

        formLayout_2->setWidget(5, QFormLayout::ItemRole::LabelRole, textLabelXplanetGlare);


        verticalLayout->addLayout(formLayout_2);

        verticalSpacer_8 = new QSpacerItem(506, 13, QSizePolicy::Policy::Minimum, QSizePolicy::Policy::Fixed);

        verticalLayout->addItem(verticalSpacer_8);

        horizontalLayout_9 = new QHBoxLayout();
        horizontalLayout_9->setObjectName("horizontalLayout_9");
        textLabelXplanetQuality = new QLabel(XplanetTabGeneral);
        textLabelXplanetQuality->setObjectName("textLabelXplanetQuality");

        horizontalLayout_9->addWidget(textLabelXplanetQuality);

        kcfg_XplanetQuality = new QSpinBox(XplanetTabGeneral);
        kcfg_XplanetQuality->setObjectName("kcfg_XplanetQuality");
        sizePolicy1.setHeightForWidth(kcfg_XplanetQuality->sizePolicy().hasHeightForWidth());
        kcfg_XplanetQuality->setSizePolicy(sizePolicy1);
        kcfg_XplanetQuality->setMaximum(100);

        horizontalLayout_9->addWidget(kcfg_XplanetQuality);

        horizontalSpacer_4 = new QSpacerItem(40, 20, QSizePolicy::Policy::Expanding, QSizePolicy::Policy::Minimum);

        horizontalLayout_9->addItem(horizontalSpacer_4);


        verticalLayout->addLayout(horizontalLayout_9);

        label_6 = new QLabel(XplanetTabGeneral);
        label_6->setObjectName("label_6");
        label_6->setWordWrap(true);
        label_6->setOpenExternalLinks(true);

        verticalLayout->addWidget(label_6);

        openXPlanetMaps = new QPushButton(XplanetTabGeneral);
        openXPlanetMaps->setObjectName("openXPlanetMaps");

        verticalLayout->addWidget(openXPlanetMaps);

        verticalSpacer_2 = new QSpacerItem(20, 40, QSizePolicy::Policy::Minimum, QSizePolicy::Policy::Expanding);

        verticalLayout->addItem(verticalSpacer_2);


        gridLayout_2->addLayout(verticalLayout, 0, 0, 1, 1);

        tab->addTab(XplanetTabGeneral, QString());
        XplanetTabLabel = new QWidget();
        XplanetTabLabel->setObjectName("XplanetTabLabel");
        gridLayout_7 = new QGridLayout(XplanetTabLabel);
        gridLayout_7->setObjectName("gridLayout_7");
        verticalLayout_5 = new QVBoxLayout();
        verticalLayout_5->setObjectName("verticalLayout_5");
        groupBox = new QGroupBox(XplanetTabLabel);
        groupBox->setObjectName("groupBox");
        gridLayout_5 = new QGridLayout(groupBox);
        gridLayout_5->setObjectName("gridLayout_5");
        formLayout_3 = new QFormLayout();
        formLayout_3->setObjectName("formLayout_3");
        formLayout_3->setFieldGrowthPolicy(QFormLayout::ExpandingFieldsGrow);
        formLayout_3->setLabelAlignment(Qt::AlignBottom|Qt::AlignRight|Qt::AlignTrailing);
        formLayout_3->setFormAlignment(Qt::AlignLeading|Qt::AlignLeft|Qt::AlignVCenter);
        horizontalLayout = new QHBoxLayout();
        horizontalLayout->setObjectName("horizontalLayout");
        kcfg_XplanetLabelLocalTime = new QRadioButton(groupBox);
        kcfg_XplanetLabelLocalTime->setObjectName("kcfg_XplanetLabelLocalTime");
        kcfg_XplanetLabelLocalTime->setChecked(true);

        horizontalLayout->addWidget(kcfg_XplanetLabelLocalTime);

        kcfg_XplanetLabelGMT = new QRadioButton(groupBox);
        kcfg_XplanetLabelGMT->setObjectName("kcfg_XplanetLabelGMT");

        horizontalLayout->addWidget(kcfg_XplanetLabelGMT);


        formLayout_3->setLayout(0, QFormLayout::ItemRole::FieldRole, horizontalLayout);

        textLabelXplanetLabelString = new QLabel(groupBox);
        textLabelXplanetLabelString->setObjectName("textLabelXplanetLabelString");

        formLayout_3->setWidget(1, QFormLayout::ItemRole::LabelRole, textLabelXplanetLabelString);

        kcfg_XplanetLabelString = new QLineEdit(groupBox);
        kcfg_XplanetLabelString->setObjectName("kcfg_XplanetLabelString");

        formLayout_3->setWidget(1, QFormLayout::ItemRole::FieldRole, kcfg_XplanetLabelString);

        textLabelXplanetDateFormat = new QLabel(groupBox);
        textLabelXplanetDateFormat->setObjectName("textLabelXplanetDateFormat");

        formLayout_3->setWidget(2, QFormLayout::ItemRole::LabelRole, textLabelXplanetDateFormat);

        kcfg_XplanetDateFormat = new QLineEdit(groupBox);
        kcfg_XplanetDateFormat->setObjectName("kcfg_XplanetDateFormat");

        formLayout_3->setWidget(2, QFormLayout::ItemRole::FieldRole, kcfg_XplanetDateFormat);

        textLabelXplanetFontSize = new QLabel(groupBox);
        textLabelXplanetFontSize->setObjectName("textLabelXplanetFontSize");
        textLabelXplanetFontSize->setEnabled(true);

        formLayout_3->setWidget(3, QFormLayout::ItemRole::LabelRole, textLabelXplanetFontSize);

        kcfg_XplanetFontSize = new QSpinBox(groupBox);
        kcfg_XplanetFontSize->setObjectName("kcfg_XplanetFontSize");

        formLayout_3->setWidget(3, QFormLayout::ItemRole::FieldRole, kcfg_XplanetFontSize);

        textLabelXplanetColor = new QLabel(groupBox);
        textLabelXplanetColor->setObjectName("textLabelXplanetColor");

        formLayout_3->setWidget(4, QFormLayout::ItemRole::LabelRole, textLabelXplanetColor);

        kcfg_XplanetColor = new KColorButton(groupBox);
        kcfg_XplanetColor->setObjectName("kcfg_XplanetColor");

        formLayout_3->setWidget(4, QFormLayout::ItemRole::FieldRole, kcfg_XplanetColor);

        frame_2 = new QFrame(groupBox);
        frame_2->setObjectName("frame_2");
        gridLayout_4 = new QGridLayout(frame_2);
        gridLayout_4->setObjectName("gridLayout_4");
        horizontalLayout_4 = new QHBoxLayout();
        horizontalLayout_4->setObjectName("horizontalLayout_4");
        verticalLayout_2 = new QVBoxLayout();
        verticalLayout_2->setObjectName("verticalLayout_2");
        kcfg_XplanetLabelTL = new QRadioButton(frame_2);
        kcfg_XplanetLabelTL->setObjectName("kcfg_XplanetLabelTL");
        kcfg_XplanetLabelTL->setChecked(false);

        verticalLayout_2->addWidget(kcfg_XplanetLabelTL);

        kcfg_XplanetLabelBL = new QRadioButton(frame_2);
        kcfg_XplanetLabelBL->setObjectName("kcfg_XplanetLabelBL");
        kcfg_XplanetLabelBL->setChecked(false);

        verticalLayout_2->addWidget(kcfg_XplanetLabelBL);


        horizontalLayout_4->addLayout(verticalLayout_2);

        verticalLayout_3 = new QVBoxLayout();
        verticalLayout_3->setObjectName("verticalLayout_3");
        kcfg_XplanetLabelTR = new QRadioButton(frame_2);
        kcfg_XplanetLabelTR->setObjectName("kcfg_XplanetLabelTR");
        kcfg_XplanetLabelTR->setChecked(true);

        verticalLayout_3->addWidget(kcfg_XplanetLabelTR);

        kcfg_XplanetLabelBR = new QRadioButton(frame_2);
        kcfg_XplanetLabelBR->setObjectName("kcfg_XplanetLabelBR");
        kcfg_XplanetLabelBR->setChecked(false);

        verticalLayout_3->addWidget(kcfg_XplanetLabelBR);


        horizontalLayout_4->addLayout(verticalLayout_3);


        gridLayout_4->addLayout(horizontalLayout_4, 0, 0, 1, 1);


        formLayout_3->setWidget(5, QFormLayout::ItemRole::FieldRole, frame_2);

        verticalLayout_4 = new QVBoxLayout();
        verticalLayout_4->setObjectName("verticalLayout_4");
        verticalSpacer_3 = new QSpacerItem(20, 40, QSizePolicy::Policy::Minimum, QSizePolicy::Policy::Expanding);

        verticalLayout_4->addItem(verticalSpacer_3);

        textLabelLabelPos = new QLabel(groupBox);
        textLabelLabelPos->setObjectName("textLabelLabelPos");

        verticalLayout_4->addWidget(textLabelLabelPos);

        verticalSpacer_4 = new QSpacerItem(20, 40, QSizePolicy::Policy::Minimum, QSizePolicy::Policy::Expanding);

        verticalLayout_4->addItem(verticalSpacer_4);


        formLayout_3->setLayout(5, QFormLayout::ItemRole::LabelRole, verticalLayout_4);

        kcfg_XplanetLabel = new QCheckBox(groupBox);
        kcfg_XplanetLabel->setObjectName("kcfg_XplanetLabel");

        formLayout_3->setWidget(0, QFormLayout::ItemRole::LabelRole, kcfg_XplanetLabel);


        gridLayout_5->addLayout(formLayout_3, 0, 0, 1, 1);


        verticalLayout_5->addWidget(groupBox);

        groupBox_2 = new QGroupBox(XplanetTabLabel);
        groupBox_2->setObjectName("groupBox_2");
        gridLayout_6 = new QGridLayout(groupBox_2);
        gridLayout_6->setObjectName("gridLayout_6");
        formLayout_4 = new QFormLayout();
        formLayout_4->setObjectName("formLayout_4");
        formLayout_4->setLabelAlignment(Qt::AlignLeading|Qt::AlignLeft|Qt::AlignVCenter);
        kcfg_XplanetMarkerFile = new QCheckBox(groupBox_2);
        kcfg_XplanetMarkerFile->setObjectName("kcfg_XplanetMarkerFile");

        formLayout_4->setWidget(0, QFormLayout::ItemRole::LabelRole, kcfg_XplanetMarkerFile);

        kcfg_XplanetMarkerFilePath = new QLineEdit(groupBox_2);
        kcfg_XplanetMarkerFilePath->setObjectName("kcfg_XplanetMarkerFilePath");

        formLayout_4->setWidget(0, QFormLayout::ItemRole::FieldRole, kcfg_XplanetMarkerFilePath);

        kcfg_XplanetMarkerBounds = new QCheckBox(groupBox_2);
        kcfg_XplanetMarkerBounds->setObjectName("kcfg_XplanetMarkerBounds");

        formLayout_4->setWidget(1, QFormLayout::ItemRole::LabelRole, kcfg_XplanetMarkerBounds);

        kcfg_XplanetMarkerBoundsPath = new QLineEdit(groupBox_2);
        kcfg_XplanetMarkerBoundsPath->setObjectName("kcfg_XplanetMarkerBoundsPath");

        formLayout_4->setWidget(1, QFormLayout::ItemRole::FieldRole, kcfg_XplanetMarkerBoundsPath);


        gridLayout_6->addLayout(formLayout_4, 0, 0, 1, 1);


        verticalLayout_5->addWidget(groupBox_2);

        verticalSpacer_6 = new QSpacerItem(20, 40, QSizePolicy::Policy::Minimum, QSizePolicy::Policy::Expanding);

        verticalLayout_5->addItem(verticalSpacer_6);


        gridLayout_7->addLayout(verticalLayout_5, 0, 0, 1, 1);

        tab->addTab(XplanetTabLabel, QString());
        XplanetTabPosition = new QWidget();
        XplanetTabPosition->setObjectName("XplanetTabPosition");
        gridLayout_3 = new QGridLayout(XplanetTabPosition);
        gridLayout_3->setObjectName("gridLayout_3");
        verticalLayout_6 = new QVBoxLayout();
        verticalLayout_6->setObjectName("verticalLayout_6");
        horizontalLayout_5 = new QHBoxLayout();
        horizontalLayout_5->setObjectName("horizontalLayout_5");
        kcfg_XplanetLatLong = new QRadioButton(XplanetTabPosition);
        kcfg_XplanetLatLong->setObjectName("kcfg_XplanetLatLong");
        kcfg_XplanetLatLong->setChecked(true);

        horizontalLayout_5->addWidget(kcfg_XplanetLatLong);

        kcfg_XplanetLatitude = new QSpinBox(XplanetTabPosition);
        kcfg_XplanetLatitude->setObjectName("kcfg_XplanetLatitude");
        kcfg_XplanetLatitude->setMinimum(-360);
        kcfg_XplanetLatitude->setMaximum(360);

        horizontalLayout_5->addWidget(kcfg_XplanetLatitude);

        textLabelXplanetLongitude = new QLabel(XplanetTabPosition);
        textLabelXplanetLongitude->setObjectName("textLabelXplanetLongitude");

        horizontalLayout_5->addWidget(textLabelXplanetLongitude);

        kcfg_XplanetLongitude = new QSpinBox(XplanetTabPosition);
        kcfg_XplanetLongitude->setObjectName("kcfg_XplanetLongitude");
        kcfg_XplanetLongitude->setMinimum(-360);
        kcfg_XplanetLongitude->setMaximum(360);

        horizontalLayout_5->addWidget(kcfg_XplanetLongitude);

        label_2 = new QLabel(XplanetTabPosition);
        label_2->setObjectName("label_2");

        horizontalLayout_5->addWidget(label_2);


        verticalLayout_6->addLayout(horizontalLayout_5);

        kcfg_XplanetRandom = new QRadioButton(XplanetTabPosition);
        kcfg_XplanetRandom->setObjectName("kcfg_XplanetRandom");

        verticalLayout_6->addWidget(kcfg_XplanetRandom);

        verticalSpacer_5 = new QSpacerItem(20, 40, QSizePolicy::Policy::Minimum, QSizePolicy::Policy::Expanding);

        verticalLayout_6->addItem(verticalSpacer_5);


        gridLayout_3->addLayout(verticalLayout_6, 0, 0, 1, 1);

        tab->addTab(XplanetTabPosition, QString());
        XplanetTabProjection = new QWidget();
        XplanetTabProjection->setObjectName("XplanetTabProjection");
        gridLayout_9 = new QGridLayout(XplanetTabProjection);
        gridLayout_9->setObjectName("gridLayout_9");
        verticalLayout_8 = new QVBoxLayout();
        verticalLayout_8->setObjectName("verticalLayout_8");
        horizontalLayout_6 = new QHBoxLayout();
        horizontalLayout_6->setObjectName("horizontalLayout_6");
        textLabelXplanetProjection = new QLabel(XplanetTabProjection);
        textLabelXplanetProjection->setObjectName("textLabelXplanetProjection");

        horizontalLayout_6->addWidget(textLabelXplanetProjection);

        kcfg_XplanetProjection = new QComboBox(XplanetTabProjection);
        kcfg_XplanetProjection->setObjectName("kcfg_XplanetProjection");

        horizontalLayout_6->addWidget(kcfg_XplanetProjection);

        horizontalSpacer_2 = new QSpacerItem(40, 20, QSizePolicy::Policy::Expanding, QSizePolicy::Policy::Minimum);

        horizontalLayout_6->addItem(horizontalSpacer_2);


        verticalLayout_8->addLayout(horizontalLayout_6);

        groupBoxBackground = new QGroupBox(XplanetTabProjection);
        groupBoxBackground->setObjectName("groupBoxBackground");
        groupBoxBackground->setEnabled(true);
        gridLayout_8 = new QGridLayout(groupBoxBackground);
        gridLayout_8->setObjectName("gridLayout_8");
        verticalLayout_7 = new QVBoxLayout();
        verticalLayout_7->setObjectName("verticalLayout_7");
        kcfg_XplanetBackground = new QCheckBox(groupBoxBackground);
        kcfg_XplanetBackground->setObjectName("kcfg_XplanetBackground");

        verticalLayout_7->addWidget(kcfg_XplanetBackground);

        horizontalLayout_7 = new QHBoxLayout();
        horizontalLayout_7->setObjectName("horizontalLayout_7");
        kcfg_XplanetBackgroundImage = new QRadioButton(groupBoxBackground);
        kcfg_XplanetBackgroundImage->setObjectName("kcfg_XplanetBackgroundImage");
        kcfg_XplanetBackgroundImage->setChecked(false);

        horizontalLayout_7->addWidget(kcfg_XplanetBackgroundImage);

        kcfg_XplanetBackgroundImagePath = new QLineEdit(groupBoxBackground);
        kcfg_XplanetBackgroundImagePath->setObjectName("kcfg_XplanetBackgroundImagePath");

        horizontalLayout_7->addWidget(kcfg_XplanetBackgroundImagePath);


        verticalLayout_7->addLayout(horizontalLayout_7);

        horizontalLayout_8 = new QHBoxLayout();
        horizontalLayout_8->setObjectName("horizontalLayout_8");
        kcfg_XplanetBackgroundColor = new QRadioButton(groupBoxBackground);
        kcfg_XplanetBackgroundColor->setObjectName("kcfg_XplanetBackgroundColor");
        kcfg_XplanetBackgroundColor->setChecked(true);

        horizontalLayout_8->addWidget(kcfg_XplanetBackgroundColor);

        kcfg_XplanetBackgroundColorValue = new KColorButton(groupBoxBackground);
        kcfg_XplanetBackgroundColorValue->setObjectName("kcfg_XplanetBackgroundColorValue");

        horizontalLayout_8->addWidget(kcfg_XplanetBackgroundColorValue);

        horizontalSpacer_3 = new QSpacerItem(40, 20, QSizePolicy::Policy::Expanding, QSizePolicy::Policy::Minimum);

        horizontalLayout_8->addItem(horizontalSpacer_3);


        verticalLayout_7->addLayout(horizontalLayout_8);


        gridLayout_8->addLayout(verticalLayout_7, 0, 0, 1, 1);


        verticalLayout_8->addWidget(groupBoxBackground);

        verticalSpacer_7 = new QSpacerItem(20, 40, QSizePolicy::Policy::Minimum, QSizePolicy::Policy::Expanding);

        verticalLayout_8->addItem(verticalSpacer_7);


        gridLayout_9->addLayout(verticalLayout_8, 0, 0, 1, 1);

        tab->addTab(XplanetTabProjection, QString());

        gridLayout->addWidget(tab, 0, 1, 1, 1);

        QWidget::setTabOrder(tab, kcfg_XplanetPath);
        QWidget::setTabOrder(kcfg_XplanetPath, kcfg_XplanetWidth);
        QWidget::setTabOrder(kcfg_XplanetWidth, kcfg_XplanetHeight);
        QWidget::setTabOrder(kcfg_XplanetHeight, kcfg_XplanetFOV);
        QWidget::setTabOrder(kcfg_XplanetFOV, kcfg_XplanetGlare);
        QWidget::setTabOrder(kcfg_XplanetGlare, kcfg_XplanetMagnitude);
        QWidget::setTabOrder(kcfg_XplanetMagnitude, kcfg_XplanetConfigFile);
        QWidget::setTabOrder(kcfg_XplanetConfigFile, kcfg_XplanetStarmap);
        QWidget::setTabOrder(kcfg_XplanetStarmap, kcfg_XplanetArcFile);
        QWidget::setTabOrder(kcfg_XplanetArcFile, kcfg_XplanetQuality);
        QWidget::setTabOrder(kcfg_XplanetQuality, kcfg_XplanetLabel);
        QWidget::setTabOrder(kcfg_XplanetLabel, kcfg_XplanetLabelLocalTime);
        QWidget::setTabOrder(kcfg_XplanetLabelLocalTime, kcfg_XplanetLabelGMT);
        QWidget::setTabOrder(kcfg_XplanetLabelGMT, kcfg_XplanetLabelString);
        QWidget::setTabOrder(kcfg_XplanetLabelString, kcfg_XplanetDateFormat);
        QWidget::setTabOrder(kcfg_XplanetDateFormat, kcfg_XplanetFontSize);
        QWidget::setTabOrder(kcfg_XplanetFontSize, kcfg_XplanetColor);
        QWidget::setTabOrder(kcfg_XplanetColor, kcfg_XplanetLabelTL);
        QWidget::setTabOrder(kcfg_XplanetLabelTL, kcfg_XplanetLabelTR);
        QWidget::setTabOrder(kcfg_XplanetLabelTR, kcfg_XplanetLabelBL);
        QWidget::setTabOrder(kcfg_XplanetLabelBL, kcfg_XplanetLabelBR);
        QWidget::setTabOrder(kcfg_XplanetLabelBR, kcfg_XplanetMarkerFile);
        QWidget::setTabOrder(kcfg_XplanetMarkerFile, kcfg_XplanetMarkerFilePath);
        QWidget::setTabOrder(kcfg_XplanetMarkerFilePath, kcfg_XplanetMarkerBounds);
        QWidget::setTabOrder(kcfg_XplanetMarkerBounds, kcfg_XplanetMarkerBoundsPath);
        QWidget::setTabOrder(kcfg_XplanetMarkerBoundsPath, kcfg_XplanetLatLong);
        QWidget::setTabOrder(kcfg_XplanetLatLong, kcfg_XplanetLatitude);
        QWidget::setTabOrder(kcfg_XplanetLatitude, kcfg_XplanetLongitude);
        QWidget::setTabOrder(kcfg_XplanetLongitude, kcfg_XplanetRandom);
        QWidget::setTabOrder(kcfg_XplanetRandom, kcfg_XplanetProjection);
        QWidget::setTabOrder(kcfg_XplanetProjection, kcfg_XplanetBackground);
        QWidget::setTabOrder(kcfg_XplanetBackground, kcfg_XplanetBackgroundImage);
        QWidget::setTabOrder(kcfg_XplanetBackgroundImage, kcfg_XplanetBackgroundImagePath);
        QWidget::setTabOrder(kcfg_XplanetBackgroundImagePath, kcfg_XplanetBackgroundColor);
        QWidget::setTabOrder(kcfg_XplanetBackgroundColor, kcfg_XplanetBackgroundColorValue);

        retranslateUi(OpsXplanet);

        tab->setCurrentIndex(0);


        QMetaObject::connectSlotsByName(OpsXplanet);
    } // setupUi

    void retranslateUi(QWidget *OpsXplanet)
    {
#if QT_CONFIG(tooltip)
        kcfg_xplanetIsInternal->setToolTip(tr2i18n("Xplanet binary is internal to the application bundle", nullptr));
#endif // QT_CONFIG(tooltip)
        kcfg_xplanetIsInternal->setText(QString());
        textLabelXplanetPath->setText(tr2i18n("Xplanet path:", nullptr));
#if QT_CONFIG(tooltip)
        kcfg_XplanetPath->setToolTip(tr2i18n("Xplanet binary path", nullptr));
#endif // QT_CONFIG(tooltip)
#if QT_CONFIG(whatsthis)
        kcfg_XplanetPath->setWhatsThis(tr2i18n("Enter here the path of xplanet binary.", nullptr));
#endif // QT_CONFIG(whatsthis)
        textLabelXplanetGeometryX->setText(tr2i18n("Window size: ", nullptr));
#if QT_CONFIG(tooltip)
        kcfg_XplanetWidth->setToolTip(tr2i18n("Set the width of window", nullptr));
#endif // QT_CONFIG(tooltip)
#if QT_CONFIG(whatsthis)
        kcfg_XplanetWidth->setWhatsThis(tr2i18n("Set the width of the xplanet image", nullptr));
#endif // QT_CONFIG(whatsthis)
        textLabelXplanetGeometryY->setText(tr2i18n("x", nullptr));
#if QT_CONFIG(tooltip)
        kcfg_XplanetHeight->setToolTip(tr2i18n("Set the height of window", nullptr));
#endif // QT_CONFIG(tooltip)
#if QT_CONFIG(whatsthis)
        kcfg_XplanetHeight->setWhatsThis(tr2i18n("Set the height of the xplanet image", nullptr));
#endif // QT_CONFIG(whatsthis)
        label->setText(tr2i18n("pixels", nullptr));
#if QT_CONFIG(tooltip)
        kcfg_XplanetTimeout->setToolTip(tr2i18n("The time KStars will wait for XPlanet to complete before giving up.", nullptr));
#endif // QT_CONFIG(tooltip)
        label_3->setText(tr2i18n("XPlanet timeout:", nullptr));
        label_4->setText(tr2i18n("Animation delay:", nullptr));
#if QT_CONFIG(tooltip)
        kcfg_XplanetAnimationDelay->setToolTip(tr2i18n("The delay between frames for the animation", nullptr));
#endif // QT_CONFIG(tooltip)
#if QT_CONFIG(tooltip)
        kcfg_XplanetUseFIFO->setToolTip(tr2i18n("Use KStars's FOV?", nullptr));
#endif // QT_CONFIG(tooltip)
#if QT_CONFIG(whatsthis)
        kcfg_XplanetUseFIFO->setWhatsThis(tr2i18n("<html><head/><body><p>If checked, XPlanet will use a FIFO file in the /tmp directory to temporarily save the XPlanet image for KStars to load them and update the view.  If not checked, XPlanet will actually save the files to the XPlanet folder in the KStars data directory.  Using a FIFO file should save the hard disk from excessive reads/writes and may offer a performance enhancement.</p></body></html>", nullptr));
#endif // QT_CONFIG(whatsthis)
        kcfg_XplanetUseFIFO->setText(tr2i18n("Use FIFO File", nullptr));
        label_5->setText(tr2i18n("(saves to memory instead of a hard disk)", nullptr));
#if QT_CONFIG(tooltip)
        kcfg_XplanetFOV->setToolTip(tr2i18n("Use kstars's FOV?", nullptr));
#endif // QT_CONFIG(tooltip)
#if QT_CONFIG(whatsthis)
        kcfg_XplanetFOV->setWhatsThis(tr2i18n("If checked, use kstars's FOV.", nullptr));
#endif // QT_CONFIG(whatsthis)
        kcfg_XplanetFOV->setText(tr2i18n("Use kstars's FOV", nullptr));
        textLabelXplanetMagnitude->setText(tr2i18n("Base magnitude:", nullptr));
#if QT_CONFIG(tooltip)
        kcfg_XplanetMagnitude->setToolTip(tr2i18n("A star of the specified magnitude will have a pixel brightness of 1", nullptr));
#endif // QT_CONFIG(tooltip)
#if QT_CONFIG(whatsthis)
        kcfg_XplanetMagnitude->setWhatsThis(tr2i18n("A star of the specified magnitude will have a pixel brightness of 1. The default value is 10. Stars will be drawn more brightly if this number is larger.", nullptr));
#endif // QT_CONFIG(whatsthis)
        kcfg_XplanetConfigFile->setText(tr2i18n("Config file:", nullptr));
#if QT_CONFIG(tooltip)
        kcfg_XplanetConfigFilePath->setToolTip(tr2i18n("Config file path", nullptr));
#endif // QT_CONFIG(tooltip)
#if QT_CONFIG(whatsthis)
        kcfg_XplanetConfigFilePath->setWhatsThis(tr2i18n("Use the specified configuration file", nullptr));
#endif // QT_CONFIG(whatsthis)
        configFileB->setText(QString());
#if QT_CONFIG(tooltip)
        kcfg_XplanetStarmap->setToolTip(tr2i18n("Use custom star map?", nullptr));
#endif // QT_CONFIG(tooltip)
#if QT_CONFIG(whatsthis)
        kcfg_XplanetStarmap->setWhatsThis(tr2i18n("If checked, use star map file to draw the background stars.", nullptr));
#endif // QT_CONFIG(whatsthis)
        kcfg_XplanetStarmap->setText(tr2i18n("Star map:", nullptr));
#if QT_CONFIG(tooltip)
        kcfg_XplanetStarmapPath->setToolTip(tr2i18n("Star map file path", nullptr));
#endif // QT_CONFIG(tooltip)
#if QT_CONFIG(whatsthis)
        kcfg_XplanetStarmapPath->setWhatsThis(tr2i18n("Star map file path", nullptr));
#endif // QT_CONFIG(whatsthis)
        starmapFileB->setText(QString());
        kcfg_XplanetArcFile->setText(tr2i18n("Arc file:", nullptr));
#if QT_CONFIG(tooltip)
        kcfg_XplanetArcFilePath->setToolTip(tr2i18n("Arc file path", nullptr));
#endif // QT_CONFIG(tooltip)
#if QT_CONFIG(whatsthis)
        kcfg_XplanetArcFilePath->setWhatsThis(tr2i18n("Specify an arc file to be plotted against the background stars.", nullptr));
#endif // QT_CONFIG(whatsthis)
        arcFileB->setText(QString());
#if QT_CONFIG(tooltip)
        kcfg_XplanetGlare->setToolTip(tr2i18n("Radius of the glare around the Sun.", nullptr));
#endif // QT_CONFIG(tooltip)
#if QT_CONFIG(whatsthis)
        kcfg_XplanetGlare->setWhatsThis(tr2i18n("Draw a glare around the sun with a radius of the specified value larger than the Sun.  The default value is 28.", nullptr));
#endif // QT_CONFIG(whatsthis)
        textLabelXplanetGlare->setText(tr2i18n("Glare of sun:", nullptr));
        textLabelXplanetQuality->setText(tr2i18n("Output file quality:", nullptr));
#if QT_CONFIG(tooltip)
        kcfg_XplanetQuality->setToolTip(tr2i18n("JPEG Quality", nullptr));
#endif // QT_CONFIG(tooltip)
#if QT_CONFIG(whatsthis)
        kcfg_XplanetQuality->setWhatsThis(tr2i18n("This option is only used when creating JPEG images. The quality can range from 0 to 100. The default value is 80.", nullptr));
#endif // QT_CONFIG(whatsthis)
        label_6->setText(tr2i18n("XPlanet requires maps in order to function properly.  It does not ship with a lot of planetary maps.  You need to download some in order to get the full benefits of XPlanet.  This is a good place to start: <a href=\"http://xplanet.sourceforge.net/maps.php\">http://xplanet.sourceforge.net/maps.php</a> ", nullptr));
        openXPlanetMaps->setText(tr2i18n("XPlanet Planet Maps", nullptr));
        tab->setTabText(tab->indexOf(XplanetTabGeneral), tr2i18n("General", nullptr));
        groupBox->setTitle(tr2i18n("Labels", nullptr));
        kcfg_XplanetLabelLocalTime->setText(tr2i18n("Local time", nullptr));
        kcfg_XplanetLabelGMT->setText(tr2i18n("GMT", nullptr));
        textLabelXplanetLabelString->setText(tr2i18n("Label string:", nullptr));
#if QT_CONFIG(tooltip)
        kcfg_XplanetLabelString->setToolTip(tr2i18n("Specify the text of the first line of the label.", nullptr));
#endif // QT_CONFIG(tooltip)
#if QT_CONFIG(whatsthis)
        kcfg_XplanetLabelString->setWhatsThis(tr2i18n("Specify the text of the first line of the label. By default, it says something like \"Looking at Earth\".  Any instances of %t will be replaced by the target name, and any instances of %o will be replaced by the origin name.", nullptr));
#endif // QT_CONFIG(whatsthis)
        textLabelXplanetDateFormat->setText(tr2i18n("Date format:", nullptr));
#if QT_CONFIG(tooltip)
        kcfg_XplanetDateFormat->setToolTip(tr2i18n("Specify the format for the date/time label.", nullptr));
#endif // QT_CONFIG(tooltip)
#if QT_CONFIG(whatsthis)
        kcfg_XplanetDateFormat->setWhatsThis(tr2i18n("Specify the format for the date/time label.  This format string is passed to strftime(3).  The default is \"%c %Z\", which shows the date, time, and time zone in the  locale\342\200\231s  appropriate date and time representation.", nullptr));
#endif // QT_CONFIG(whatsthis)
        textLabelXplanetFontSize->setText(tr2i18n("Font size:", nullptr));
#if QT_CONFIG(tooltip)
        kcfg_XplanetFontSize->setToolTip(tr2i18n("Label font size", nullptr));
#endif // QT_CONFIG(tooltip)
#if QT_CONFIG(whatsthis)
        kcfg_XplanetFontSize->setWhatsThis(tr2i18n("Specify the point size.", nullptr));
#endif // QT_CONFIG(whatsthis)
        textLabelXplanetColor->setText(tr2i18n("Color:", nullptr));
#if QT_CONFIG(tooltip)
        kcfg_XplanetColor->setToolTip(tr2i18n("Label color", nullptr));
#endif // QT_CONFIG(tooltip)
#if QT_CONFIG(whatsthis)
        kcfg_XplanetColor->setWhatsThis(tr2i18n("Set the color for the label.", nullptr));
#endif // QT_CONFIG(whatsthis)
        kcfg_XplanetLabelTL->setText(tr2i18n("Top left", nullptr));
        kcfg_XplanetLabelBL->setText(tr2i18n("Bottom left", nullptr));
        kcfg_XplanetLabelTR->setText(tr2i18n("Top right", nullptr));
        kcfg_XplanetLabelBR->setText(tr2i18n("Bottom right", nullptr));
        textLabelLabelPos->setText(tr2i18n("Label position:", nullptr));
#if QT_CONFIG(tooltip)
        kcfg_XplanetLabel->setToolTip(tr2i18n("Show label?", nullptr));
#endif // QT_CONFIG(tooltip)
#if QT_CONFIG(whatsthis)
        kcfg_XplanetLabel->setWhatsThis(tr2i18n("If checked, display a label in the upper right corner.", nullptr));
#endif // QT_CONFIG(whatsthis)
        kcfg_XplanetLabel->setText(tr2i18n("Show label:", nullptr));
        groupBox_2->setTitle(tr2i18n("Markers", nullptr));
#if QT_CONFIG(tooltip)
        kcfg_XplanetMarkerFile->setToolTip(tr2i18n("Use marker file?", nullptr));
#endif // QT_CONFIG(tooltip)
#if QT_CONFIG(whatsthis)
        kcfg_XplanetMarkerFile->setWhatsThis(tr2i18n("If checked, use the specified marker file.", nullptr));
#endif // QT_CONFIG(whatsthis)
        kcfg_XplanetMarkerFile->setText(tr2i18n("Use marker file:", nullptr));
#if QT_CONFIG(tooltip)
        kcfg_XplanetMarkerFilePath->setToolTip(tr2i18n("Marker file path", nullptr));
#endif // QT_CONFIG(tooltip)
#if QT_CONFIG(whatsthis)
        kcfg_XplanetMarkerFilePath->setWhatsThis(tr2i18n("Specify a file containing user defined marker data to display against the background stars.", nullptr));
#endif // QT_CONFIG(whatsthis)
#if QT_CONFIG(tooltip)
        kcfg_XplanetMarkerBounds->setToolTip(tr2i18n("Write marker bounds in a file", nullptr));
#endif // QT_CONFIG(tooltip)
#if QT_CONFIG(whatsthis)
        kcfg_XplanetMarkerBounds->setWhatsThis(tr2i18n("Write coordinates of the bounding box for each marker in a file.", nullptr));
#endif // QT_CONFIG(whatsthis)
        kcfg_XplanetMarkerBounds->setText(tr2i18n("Write marker bounds to:", nullptr));
#if QT_CONFIG(tooltip)
        kcfg_XplanetMarkerBoundsPath->setToolTip(tr2i18n("Marker bounds file path", nullptr));
#endif // QT_CONFIG(tooltip)
#if QT_CONFIG(whatsthis)
        kcfg_XplanetMarkerBoundsPath->setWhatsThis(tr2i18n("Write coordinates of the bounding box for each marker to this file.", nullptr));
#endif // QT_CONFIG(whatsthis)
        tab->setTabText(tab->indexOf(XplanetTabLabel), tr2i18n("Labels and markers", nullptr));
        kcfg_XplanetLatLong->setText(tr2i18n("Place the observer above latitude: ", nullptr));
#if QT_CONFIG(tooltip)
        kcfg_XplanetLatitude->setToolTip(tr2i18n("Latitude in degrees", nullptr));
#endif // QT_CONFIG(tooltip)
#if QT_CONFIG(whatsthis)
        kcfg_XplanetLatitude->setWhatsThis(tr2i18n("Render the target body as seen from above the specified latitude (in degrees).  The default value is 0.", nullptr));
#endif // QT_CONFIG(whatsthis)
        textLabelXplanetLongitude->setText(tr2i18n(" and longitude: ", nullptr));
#if QT_CONFIG(tooltip)
        kcfg_XplanetLongitude->setToolTip(tr2i18n("Longitude in degrees", nullptr));
#endif // QT_CONFIG(tooltip)
#if QT_CONFIG(whatsthis)
        kcfg_XplanetLongitude->setWhatsThis(tr2i18n("Place the observer above the specified longitude (in degrees).  Longitude is positive going east, negative going west (for the earth and moon), so for example Los Angeles is at -118 or 242.  The default value is 0.", nullptr));
#endif // QT_CONFIG(whatsthis)
        label_2->setText(tr2i18n("in degrees", nullptr));
        kcfg_XplanetRandom->setText(tr2i18n("Place the observer above a random latitude and longitude", nullptr));
        tab->setTabText(tab->indexOf(XplanetTabPosition), tr2i18n("Position", nullptr));
        textLabelXplanetProjection->setText(tr2i18n("Projection:", nullptr));
#if QT_CONFIG(tooltip)
        kcfg_XplanetProjection->setToolTip(tr2i18n("The projection type", nullptr));
#endif // QT_CONFIG(tooltip)
#if QT_CONFIG(whatsthis)
        kcfg_XplanetProjection->setWhatsThis(tr2i18n("The default is  no projection.  Multiple bodies will not be shown if this option is specified, although shadows will still be drawn.", nullptr));
#endif // QT_CONFIG(whatsthis)
        groupBoxBackground->setTitle(tr2i18n("Background", nullptr));
#if QT_CONFIG(tooltip)
        kcfg_XplanetBackground->setToolTip(tr2i18n("Use background?", nullptr));
#endif // QT_CONFIG(tooltip)
#if QT_CONFIG(whatsthis)
        kcfg_XplanetBackground->setWhatsThis(tr2i18n("If checked, use a file or a color as background.", nullptr));
#endif // QT_CONFIG(whatsthis)
        kcfg_XplanetBackground->setText(tr2i18n("Use background", nullptr));
        kcfg_XplanetBackgroundImage->setText(tr2i18n("Background image:", nullptr));
#if QT_CONFIG(tooltip)
        kcfg_XplanetBackgroundImagePath->setToolTip(tr2i18n("Use this file as the background image", nullptr));
#endif // QT_CONFIG(tooltip)
#if QT_CONFIG(whatsthis)
        kcfg_XplanetBackgroundImagePath->setWhatsThis(tr2i18n("Enter here the path of background image file.", nullptr));
#endif // QT_CONFIG(whatsthis)
        kcfg_XplanetBackgroundColor->setText(tr2i18n("Background color:", nullptr));
#if QT_CONFIG(tooltip)
        kcfg_XplanetBackgroundColorValue->setToolTip(tr2i18n("Background color", nullptr));
#endif // QT_CONFIG(tooltip)
#if QT_CONFIG(whatsthis)
        kcfg_XplanetBackgroundColorValue->setWhatsThis(tr2i18n("Set the color for the background.", nullptr));
#endif // QT_CONFIG(whatsthis)
        tab->setTabText(tab->indexOf(XplanetTabProjection), tr2i18n("Projection", nullptr));
        (void)OpsXplanet;
    } // retranslateUi

};

namespace Ui {
    class OpsXplanet: public Ui_OpsXplanet {};
} // namespace Ui

QT_END_NAMESPACE

#endif // OPSXPLANET_H

