/********************************************************************************
** Form generated from reading UI file 'mountpositionwidget.ui'
**
** Created by: Qt User Interface Compiler version 6.11.1
**
** WARNING! All changes made in this file will be lost when recompiling UI file!
********************************************************************************/

#ifndef UI_MOUNTPOSITIONWIDGET_H
#define UI_MOUNTPOSITIONWIDGET_H

#include <QtCore/QVariant>
#include <QtWidgets/QApplication>
#include <QtWidgets/QButtonGroup>
#include <QtWidgets/QGridLayout>
#include <QtWidgets/QHBoxLayout>
#include <QtWidgets/QLabel>
#include <QtWidgets/QRadioButton>
#include <QtWidgets/QSpacerItem>
#include <QtWidgets/QWidget>
#include <klocalizedstring.h>

QT_BEGIN_NAMESPACE

class Ui_MountPositionWidget
{
public:
    QGridLayout *gridLayout;
    QLabel *label_11;
    QLabel *raValueObject;
    QLabel *haValueObject;
    QLabel *label_13;
    QLabel *label_3;
    QLabel *zaValueObject;
    QHBoxLayout *horizontalLayout_8;
    QLabel *epochLabel;
    QRadioButton *jnowCheckObject;
    QRadioButton *j2000CheckObject;
    QSpacerItem *horizontalSpacer_2;
    QLabel *deValueObject;
    QLabel *label_7;
    QLabel *label_9;
    QLabel *altValueObject;
    QLabel *azValueObject;
    QLabel *label_5;
    QButtonGroup *coordinateEpochGroup;

    void setupUi(QWidget *MountPositionWidget)
    {
        if (MountPositionWidget->objectName().isEmpty())
            MountPositionWidget->setObjectName("MountPositionWidget");
        MountPositionWidget->resize(240, 120);
        QSizePolicy sizePolicy(QSizePolicy::Policy::Preferred, QSizePolicy::Policy::Preferred);
        sizePolicy.setHorizontalStretch(1);
        sizePolicy.setVerticalStretch(1);
        sizePolicy.setHeightForWidth(MountPositionWidget->sizePolicy().hasHeightForWidth());
        MountPositionWidget->setSizePolicy(sizePolicy);
        MountPositionWidget->setMinimumSize(QSize(240, 120));
        MountPositionWidget->setFocusPolicy(Qt::FocusPolicy::ClickFocus);
        gridLayout = new QGridLayout(MountPositionWidget);
        gridLayout->setObjectName("gridLayout");
        gridLayout->setHorizontalSpacing(3);
        gridLayout->setVerticalSpacing(6);
        gridLayout->setContentsMargins(0, 0, 0, 0);
        label_11 = new QLabel(MountPositionWidget);
        label_11->setObjectName("label_11");
        QFont font;
        font.setPointSize(12);
        font.setBold(true);
        label_11->setFont(font);
        label_11->setAlignment(Qt::AlignmentFlag::AlignRight|Qt::AlignmentFlag::AlignTrailing|Qt::AlignmentFlag::AlignVCenter);

        gridLayout->addWidget(label_11, 2, 0, 1, 1);

        raValueObject = new QLabel(MountPositionWidget);
        raValueObject->setObjectName("raValueObject");
        raValueObject->setMinimumSize(QSize(0, 0));
        QFont font1;
        font1.setFamilies({QString::fromUtf8("Courier")});
        font1.setPointSize(12);
        font1.setBold(true);
        raValueObject->setFont(font1);
        raValueObject->setStyleSheet(QString::fromUtf8("color:\"orange\""));
        raValueObject->setFrameShape(QFrame::Shape::Box);

        gridLayout->addWidget(raValueObject, 0, 1, 1, 1);

        haValueObject = new QLabel(MountPositionWidget);
        haValueObject->setObjectName("haValueObject");
        haValueObject->setMinimumSize(QSize(0, 0));
        haValueObject->setFont(font1);
        haValueObject->setStyleSheet(QString::fromUtf8("color:\"orange\""));
        haValueObject->setFrameShape(QFrame::Shape::Box);

        gridLayout->addWidget(haValueObject, 2, 1, 1, 1);

        label_13 = new QLabel(MountPositionWidget);
        label_13->setObjectName("label_13");
        label_13->setFont(font);
        label_13->setAlignment(Qt::AlignmentFlag::AlignRight|Qt::AlignmentFlag::AlignTrailing|Qt::AlignmentFlag::AlignVCenter);

        gridLayout->addWidget(label_13, 2, 2, 1, 1);

        label_3 = new QLabel(MountPositionWidget);
        label_3->setObjectName("label_3");
        label_3->setFont(font);
        label_3->setAlignment(Qt::AlignmentFlag::AlignRight|Qt::AlignmentFlag::AlignTrailing|Qt::AlignmentFlag::AlignVCenter);

        gridLayout->addWidget(label_3, 0, 0, 1, 1);

        zaValueObject = new QLabel(MountPositionWidget);
        zaValueObject->setObjectName("zaValueObject");
        zaValueObject->setMinimumSize(QSize(0, 0));
        zaValueObject->setFont(font1);
        zaValueObject->setStyleSheet(QString::fromUtf8("color:\"orange\""));
        zaValueObject->setFrameShape(QFrame::Shape::Box);

        gridLayout->addWidget(zaValueObject, 2, 3, 1, 1);

        horizontalLayout_8 = new QHBoxLayout();
        horizontalLayout_8->setSpacing(3);
        horizontalLayout_8->setObjectName("horizontalLayout_8");
        epochLabel = new QLabel(MountPositionWidget);
        epochLabel->setObjectName("epochLabel");

        horizontalLayout_8->addWidget(epochLabel);

        jnowCheckObject = new QRadioButton(MountPositionWidget);
        coordinateEpochGroup = new QButtonGroup(MountPositionWidget);
        coordinateEpochGroup->setObjectName("coordinateEpochGroup");
        coordinateEpochGroup->addButton(jnowCheckObject);
        jnowCheckObject->setObjectName("jnowCheckObject");
        jnowCheckObject->setChecked(true);

        horizontalLayout_8->addWidget(jnowCheckObject);

        j2000CheckObject = new QRadioButton(MountPositionWidget);
        coordinateEpochGroup->addButton(j2000CheckObject);
        j2000CheckObject->setObjectName("j2000CheckObject");

        horizontalLayout_8->addWidget(j2000CheckObject);

        horizontalSpacer_2 = new QSpacerItem(40, 20, QSizePolicy::Policy::Expanding, QSizePolicy::Policy::Minimum);

        horizontalLayout_8->addItem(horizontalSpacer_2);


        gridLayout->addLayout(horizontalLayout_8, 3, 1, 1, 3);

        deValueObject = new QLabel(MountPositionWidget);
        deValueObject->setObjectName("deValueObject");
        deValueObject->setMinimumSize(QSize(0, 0));
        deValueObject->setFont(font1);
        deValueObject->setStyleSheet(QString::fromUtf8("color:\"orange\""));
        deValueObject->setFrameShape(QFrame::Shape::Box);

        gridLayout->addWidget(deValueObject, 0, 3, 1, 1);

        label_7 = new QLabel(MountPositionWidget);
        label_7->setObjectName("label_7");
        label_7->setFont(font);
        label_7->setAlignment(Qt::AlignmentFlag::AlignRight|Qt::AlignmentFlag::AlignTrailing|Qt::AlignmentFlag::AlignVCenter);

        gridLayout->addWidget(label_7, 0, 2, 1, 1);

        label_9 = new QLabel(MountPositionWidget);
        label_9->setObjectName("label_9");
        label_9->setFont(font);
        label_9->setAlignment(Qt::AlignmentFlag::AlignRight|Qt::AlignmentFlag::AlignTrailing|Qt::AlignmentFlag::AlignVCenter);

        gridLayout->addWidget(label_9, 1, 0, 1, 1);

        altValueObject = new QLabel(MountPositionWidget);
        altValueObject->setObjectName("altValueObject");
        altValueObject->setMinimumSize(QSize(0, 0));
        altValueObject->setFont(font1);
        altValueObject->setStyleSheet(QString::fromUtf8("color:\"orange\""));
        altValueObject->setFrameShape(QFrame::Shape::Box);

        gridLayout->addWidget(altValueObject, 1, 1, 1, 1);

        azValueObject = new QLabel(MountPositionWidget);
        azValueObject->setObjectName("azValueObject");
        azValueObject->setMinimumSize(QSize(0, 0));
        azValueObject->setFont(font1);
        azValueObject->setStyleSheet(QString::fromUtf8("color:\"orange\""));
        azValueObject->setFrameShape(QFrame::Shape::Box);

        gridLayout->addWidget(azValueObject, 1, 3, 1, 1);

        label_5 = new QLabel(MountPositionWidget);
        label_5->setObjectName("label_5");
        label_5->setFont(font);
        label_5->setAlignment(Qt::AlignmentFlag::AlignRight|Qt::AlignmentFlag::AlignTrailing|Qt::AlignmentFlag::AlignVCenter);

        gridLayout->addWidget(label_5, 1, 2, 1, 1);

        gridLayout->setColumnStretch(0, 1);
        gridLayout->setColumnStretch(2, 1);

        retranslateUi(MountPositionWidget);

        QMetaObject::connectSlotsByName(MountPositionWidget);
    } // setupUi

    void retranslateUi(QWidget *MountPositionWidget)
    {
        MountPositionWidget->setWindowTitle(tr2i18n("Mount Control Panel", nullptr));
        label_11->setText(tr2i18n("HA:", nullptr));
        raValueObject->setText(tr2i18n("00:00:00", nullptr));
        haValueObject->setText(tr2i18n("00:00:00", nullptr));
        label_13->setText(tr2i18n("ZA:", nullptr));
        label_3->setText(tr2i18n("RA:", nullptr));
        zaValueObject->setText(tr2i18n("00:00:00", nullptr));
        epochLabel->setText(tr2i18n("Epoch:", nullptr));
        jnowCheckObject->setText(tr2i18n("JNow", nullptr));
        j2000CheckObject->setText(tr2i18n("J2000", nullptr));
        deValueObject->setText(tr2i18n("00:00:00", nullptr));
        label_7->setText(tr2i18n("DE:", nullptr));
        label_9->setText(tr2i18n("AL:", nullptr));
        altValueObject->setText(tr2i18n("00:00:00", nullptr));
        azValueObject->setText(tr2i18n("00:00:00", nullptr));
        label_5->setText(tr2i18n("AZ:", nullptr));
    } // retranslateUi

};

namespace Ui {
    class MountPositionWidget: public Ui_MountPositionWidget {};
} // namespace Ui

QT_END_NAMESPACE

#endif // MOUNTPOSITIONWIDGET_H

