/****************************************************************************
** Meta object code from reading C++ file 'camera.h'
**
** Created by: The Qt Meta Object Compiler version 69 (Qt 6.11.1)
**
** WARNING! All changes made in this file will be lost!
*****************************************************************************/

#include "../../../../kstars-3.8.4.1/kstars/ekos/capture/camera.h"
#include <QtNetwork/QSslError>
#include <QtDataVisualization/qbar3dseries.h>
#include <QtDataVisualization/q3dscene.h>
#include <QtGui/qtextcursor.h>
#include <QtCore/qmetatype.h>
#include <QtCore/QSharedPointer>

#include <QtCore/qtmochelpers.h>

#include <memory>


#include <QtCore/qxptype_traits.h>
#if !defined(Q_MOC_OUTPUT_REVISION)
#error "The header file 'camera.h' doesn't include <QObject>."
#elif Q_MOC_OUTPUT_REVISION != 69
#error "This file was generated using the moc from 6.11.1. It"
#error "cannot be used with the include files from this version of Qt."
#error "(The moc has changed too much.)"
#endif

#ifndef Q_CONSTINIT
#define Q_CONSTINIT
#endif

QT_WARNING_PUSH
QT_WARNING_DISABLE_DEPRECATED
QT_WARNING_DISABLE_GCC("-Wuseless-cast")
namespace {
struct qt_meta_tag_ZN4Ekos6CameraE_t {};
} // unnamed namespace

template <> constexpr inline auto Ekos::Camera::qt_create_metaobjectdata<qt_meta_tag_ZN4Ekos6CameraE_t>()
{
    namespace QMC = QtMocConstants;
    QtMocHelpers::StringRefStorage qt_stringData {
        "Ekos::Camera",
        "ready",
        "",
        "requestAction",
        "cameraID",
        "CaptureWorkflowActionType",
        "action",
        "refreshCamera",
        "id",
        "isValid",
        "newExposureProgress",
        "QSharedPointer<SequenceJob>",
        "job",
        "trainname",
        "newDownloadProgress",
        "newImage",
        "QSharedPointer<FITSData>",
        "data",
        "captureTarget",
        "targetName",
        "captureComplete",
        "QVariantMap",
        "metadata",
        "resetNonGuidedDither",
        "runAutoFocus",
        "AutofocusReason",
        "autofocusReason",
        "reasonInfo",
        "resetFocusFrame",
        "abortFocus",
        "adaptiveFocus",
        "settingsUpdated",
        "settings",
        "sequenceChanged",
        "QJsonArray",
        "sequence",
        "newLocalPreview",
        "preview",
        "dslrInfoRequested",
        "cameraName",
        "filterManagerUpdated",
        "ISD::FilterWheel*",
        "device",
        "newFilterStatus",
        "FilterState",
        "state",
        "trainChanged",
        "newLog",
        "text",
        "captureStarting",
        "exposureSeconds",
        "filter",
        "captureAborted",
        "checkFocus",
        "meridianFlipStarted",
        "guideAfterMeridianFlip",
        "newStatus",
        "CaptureState",
        "status",
        "devicename",
        "suspendGuiding",
        "resumeGuiding",
        "driverTimedout",
        "deviceName",
        "setVideoStreamEnabled",
        "enabled",
        "setCoolerToggled",
        "setFilterStatus",
        "filterState",
        "resetJobs",
        "selectJob",
        "QModelIndex",
        "i",
        "editJob",
        "resetJobEdit",
        "cancelled",
        "removeJob",
        "index",
        "modifyJob",
        "editJobFinished",
        "imageCapturingCompleted",
        "captureStopped",
        "processingFITSfinished",
        "success",
        "captureRunning",
        "captureImageStarted",
        "jobExecutionPreparationStarted"
    };

    QtMocHelpers::UintData qt_methods {
        // Signal 'ready'
        QtMocHelpers::SignalData<void()>(1, 2, QMC::AccessPublic, QMetaType::Void),
        // Signal 'requestAction'
        QtMocHelpers::SignalData<void(int, CaptureWorkflowActionType)>(3, 2, QMC::AccessPublic, QMetaType::Void, {{
            { QMetaType::Int, 4 }, { 0x80000000 | 5, 6 },
        }}),
        // Signal 'refreshCamera'
        QtMocHelpers::SignalData<void(uint, bool)>(7, 2, QMC::AccessPublic, QMetaType::Void, {{
            { QMetaType::UInt, 8 }, { QMetaType::Bool, 9 },
        }}),
        // Signal 'newExposureProgress'
        QtMocHelpers::SignalData<void(const QSharedPointer<SequenceJob> &, const QString &)>(10, 2, QMC::AccessPublic, QMetaType::Void, {{
            { 0x80000000 | 11, 12 }, { QMetaType::QString, 13 },
        }}),
        // Signal 'newDownloadProgress'
        QtMocHelpers::SignalData<void(double, const QString &)>(14, 2, QMC::AccessPublic, QMetaType::Void, {{
            { QMetaType::Double, 2 }, { QMetaType::QString, 13 },
        }}),
        // Signal 'newImage'
        QtMocHelpers::SignalData<void(const QSharedPointer<SequenceJob> &, const QSharedPointer<FITSData> &, const QString &)>(15, 2, QMC::AccessPublic, QMetaType::Void, {{
            { 0x80000000 | 11, 12 }, { 0x80000000 | 16, 17 }, { QMetaType::QString, 13 },
        }}),
        // Signal 'captureTarget'
        QtMocHelpers::SignalData<void(QString)>(18, 2, QMC::AccessPublic, QMetaType::Void, {{
            { QMetaType::QString, 19 },
        }}),
        // Signal 'captureComplete'
        QtMocHelpers::SignalData<void(const QVariantMap &, const QString &)>(20, 2, QMC::AccessPublic, QMetaType::Void, {{
            { 0x80000000 | 21, 22 }, { QMetaType::QString, 13 },
        }}),
        // Signal 'resetNonGuidedDither'
        QtMocHelpers::SignalData<void()>(23, 2, QMC::AccessPublic, QMetaType::Void),
        // Signal 'runAutoFocus'
        QtMocHelpers::SignalData<void(AutofocusReason, const QString &, const QString &)>(24, 2, QMC::AccessPublic, QMetaType::Void, {{
            { 0x80000000 | 25, 26 }, { QMetaType::QString, 27 }, { QMetaType::QString, 13 },
        }}),
        // Signal 'resetFocusFrame'
        QtMocHelpers::SignalData<void(const QString &)>(28, 2, QMC::AccessPublic, QMetaType::Void, {{
            { QMetaType::QString, 13 },
        }}),
        // Signal 'abortFocus'
        QtMocHelpers::SignalData<void(const QString &)>(29, 2, QMC::AccessPublic, QMetaType::Void, {{
            { QMetaType::QString, 13 },
        }}),
        // Signal 'adaptiveFocus'
        QtMocHelpers::SignalData<void(const QString &)>(30, 2, QMC::AccessPublic, QMetaType::Void, {{
            { QMetaType::QString, 13 },
        }}),
        // Signal 'settingsUpdated'
        QtMocHelpers::SignalData<void(const QVariantMap &)>(31, 2, QMC::AccessPublic, QMetaType::Void, {{
            { 0x80000000 | 21, 32 },
        }}),
        // Signal 'sequenceChanged'
        QtMocHelpers::SignalData<void(const QJsonArray &)>(33, 2, QMC::AccessPublic, QMetaType::Void, {{
            { 0x80000000 | 34, 35 },
        }}),
        // Signal 'newLocalPreview'
        QtMocHelpers::SignalData<void(const QString &)>(36, 2, QMC::AccessPublic, QMetaType::Void, {{
            { QMetaType::QString, 37 },
        }}),
        // Signal 'dslrInfoRequested'
        QtMocHelpers::SignalData<void(const QString &)>(38, 2, QMC::AccessPublic, QMetaType::Void, {{
            { QMetaType::QString, 39 },
        }}),
        // Signal 'filterManagerUpdated'
        QtMocHelpers::SignalData<void(ISD::FilterWheel *)>(40, 2, QMC::AccessPublic, QMetaType::Void, {{
            { 0x80000000 | 41, 42 },
        }}),
        // Signal 'newFilterStatus'
        QtMocHelpers::SignalData<void(FilterState)>(43, 2, QMC::AccessPublic, QMetaType::Void, {{
            { 0x80000000 | 44, 45 },
        }}),
        // Signal 'trainChanged'
        QtMocHelpers::SignalData<void()>(46, 2, QMC::AccessPublic, QMetaType::Void),
        // Signal 'newLog'
        QtMocHelpers::SignalData<void(const QString &)>(47, 2, QMC::AccessPublic, QMetaType::Void, {{
            { QMetaType::QString, 48 },
        }}),
        // Signal 'captureStarting'
        QtMocHelpers::SignalData<void(double, const QString &)>(49, 2, QMC::AccessPublic, QMetaType::Void, {{
            { QMetaType::Double, 50 }, { QMetaType::QString, 51 },
        }}),
        // Signal 'captureAborted'
        QtMocHelpers::SignalData<void(double)>(52, 2, QMC::AccessPublic, QMetaType::Void, {{
            { QMetaType::Double, 50 },
        }}),
        // Signal 'checkFocus'
        QtMocHelpers::SignalData<void(double, const QString &)>(53, 2, QMC::AccessPublic, QMetaType::Void, {{
            { QMetaType::Double, 2 }, { QMetaType::QString, 13 },
        }}),
        // Signal 'meridianFlipStarted'
        QtMocHelpers::SignalData<void(const QString &)>(54, 2, QMC::AccessPublic, QMetaType::Void, {{
            { QMetaType::QString, 13 },
        }}),
        // Signal 'guideAfterMeridianFlip'
        QtMocHelpers::SignalData<void()>(55, 2, QMC::AccessPublic, QMetaType::Void),
        // Signal 'newStatus'
        QtMocHelpers::SignalData<void(CaptureState, const QString &, int)>(56, 2, QMC::AccessPublic, QMetaType::Void, {{
            { 0x80000000 | 57, 58 }, { QMetaType::QString, 59 }, { QMetaType::Int, 4 },
        }}),
        // Signal 'suspendGuiding'
        QtMocHelpers::SignalData<void()>(60, 2, QMC::AccessPublic, QMetaType::Void),
        // Signal 'resumeGuiding'
        QtMocHelpers::SignalData<void()>(61, 2, QMC::AccessPublic, QMetaType::Void),
        // Signal 'driverTimedout'
        QtMocHelpers::SignalData<void(const QString &)>(62, 2, QMC::AccessPublic, QMetaType::Void, {{
            { QMetaType::QString, 63 },
        }}),
        // Slot 'setVideoStreamEnabled'
        QtMocHelpers::SlotData<void(bool)>(64, 2, QMC::AccessPrivate, QMetaType::Void, {{
            { QMetaType::Bool, 65 },
        }}),
        // Slot 'setCoolerToggled'
        QtMocHelpers::SlotData<void(bool)>(66, 2, QMC::AccessPrivate, QMetaType::Void, {{
            { QMetaType::Bool, 65 },
        }}),
        // Slot 'setFilterStatus'
        QtMocHelpers::SlotData<void(FilterState)>(67, 2, QMC::AccessPrivate, QMetaType::Void, {{
            { 0x80000000 | 44, 68 },
        }}),
        // Slot 'resetJobs'
        QtMocHelpers::SlotData<void()>(69, 2, QMC::AccessPrivate, QMetaType::Void),
        // Slot 'selectJob'
        QtMocHelpers::SlotData<bool(QModelIndex)>(70, 2, QMC::AccessPrivate, QMetaType::Bool, {{
            { 0x80000000 | 71, 72 },
        }}),
        // Slot 'editJob'
        QtMocHelpers::SlotData<void(QModelIndex)>(73, 2, QMC::AccessPrivate, QMetaType::Void, {{
            { 0x80000000 | 71, 72 },
        }}),
        // Slot 'resetJobEdit'
        QtMocHelpers::SlotData<void(bool)>(74, 2, QMC::AccessPrivate, QMetaType::Void, {{
            { QMetaType::Bool, 75 },
        }}),
        // Slot 'resetJobEdit'
        QtMocHelpers::SlotData<void()>(74, 2, QMC::AccessPrivate | QMC::MethodCloned, QMetaType::Void),
        // Method 'removeJob'
        QtMocHelpers::MethodData<bool(int)>(76, 2, QMC::AccessPublic, QMetaType::Bool, {{
            { QMetaType::Int, 77 },
        }}),
        // Method 'removeJob'
        QtMocHelpers::MethodData<bool()>(76, 2, QMC::AccessPublic | QMC::MethodCloned, QMetaType::Bool),
        // Method 'modifyJob'
        QtMocHelpers::MethodData<bool(int)>(78, 2, QMC::AccessPublic, QMetaType::Bool, {{
            { QMetaType::Int, 77 },
        }}),
        // Method 'modifyJob'
        QtMocHelpers::MethodData<bool()>(78, 2, QMC::AccessPublic | QMC::MethodCloned, QMetaType::Bool),
        // Method 'editJobFinished'
        QtMocHelpers::MethodData<void()>(79, 2, QMC::AccessPrivate, QMetaType::Void),
        // Method 'imageCapturingCompleted'
        QtMocHelpers::MethodData<void()>(80, 2, QMC::AccessPrivate, QMetaType::Void),
        // Method 'captureStopped'
        QtMocHelpers::MethodData<void()>(81, 2, QMC::AccessPrivate, QMetaType::Void),
        // Method 'processingFITSfinished'
        QtMocHelpers::MethodData<void(bool)>(82, 2, QMC::AccessPrivate, QMetaType::Void, {{
            { QMetaType::Bool, 83 },
        }}),
        // Method 'captureRunning'
        QtMocHelpers::MethodData<void()>(84, 2, QMC::AccessPrivate, QMetaType::Void),
        // Method 'captureImageStarted'
        QtMocHelpers::MethodData<void()>(85, 2, QMC::AccessPrivate, QMetaType::Void),
        // Method 'jobExecutionPreparationStarted'
        QtMocHelpers::MethodData<void()>(86, 2, QMC::AccessPrivate, QMetaType::Void),
    };
    QtMocHelpers::UintData qt_properties {
    };
    QtMocHelpers::UintData qt_enums {
    };
    return QtMocHelpers::metaObjectData<Camera, qt_meta_tag_ZN4Ekos6CameraE_t>(QMC::MetaObjectFlag{}, qt_stringData,
            qt_methods, qt_properties, qt_enums);
}
Q_CONSTINIT const QMetaObject Ekos::Camera::staticMetaObject = { {
    QMetaObject::SuperData::link<QWidget::staticMetaObject>(),
    qt_staticMetaObjectStaticContent<qt_meta_tag_ZN4Ekos6CameraE_t>.stringdata,
    qt_staticMetaObjectStaticContent<qt_meta_tag_ZN4Ekos6CameraE_t>.data,
    qt_static_metacall,
    nullptr,
    qt_staticMetaObjectRelocatingContent<qt_meta_tag_ZN4Ekos6CameraE_t>.metaTypes,
    nullptr
} };

void Ekos::Camera::qt_static_metacall(QObject *_o, QMetaObject::Call _c, int _id, void **_a)
{
    auto *_t = static_cast<Camera *>(_o);
    if (_c == QMetaObject::InvokeMetaMethod) {
        switch (_id) {
        case 0: _t->ready(); break;
        case 1: _t->requestAction((*reinterpret_cast<std::add_pointer_t<int>>(_a[1])),(*reinterpret_cast<std::add_pointer_t<CaptureWorkflowActionType>>(_a[2]))); break;
        case 2: _t->refreshCamera((*reinterpret_cast<std::add_pointer_t<uint>>(_a[1])),(*reinterpret_cast<std::add_pointer_t<bool>>(_a[2]))); break;
        case 3: _t->newExposureProgress((*reinterpret_cast<std::add_pointer_t<QSharedPointer<SequenceJob>>>(_a[1])),(*reinterpret_cast<std::add_pointer_t<QString>>(_a[2]))); break;
        case 4: _t->newDownloadProgress((*reinterpret_cast<std::add_pointer_t<double>>(_a[1])),(*reinterpret_cast<std::add_pointer_t<QString>>(_a[2]))); break;
        case 5: _t->newImage((*reinterpret_cast<std::add_pointer_t<QSharedPointer<SequenceJob>>>(_a[1])),(*reinterpret_cast<std::add_pointer_t<QSharedPointer<FITSData>>>(_a[2])),(*reinterpret_cast<std::add_pointer_t<QString>>(_a[3]))); break;
        case 6: _t->captureTarget((*reinterpret_cast<std::add_pointer_t<QString>>(_a[1]))); break;
        case 7: _t->captureComplete((*reinterpret_cast<std::add_pointer_t<QVariantMap>>(_a[1])),(*reinterpret_cast<std::add_pointer_t<QString>>(_a[2]))); break;
        case 8: _t->resetNonGuidedDither(); break;
        case 9: _t->runAutoFocus((*reinterpret_cast<std::add_pointer_t<AutofocusReason>>(_a[1])),(*reinterpret_cast<std::add_pointer_t<QString>>(_a[2])),(*reinterpret_cast<std::add_pointer_t<QString>>(_a[3]))); break;
        case 10: _t->resetFocusFrame((*reinterpret_cast<std::add_pointer_t<QString>>(_a[1]))); break;
        case 11: _t->abortFocus((*reinterpret_cast<std::add_pointer_t<QString>>(_a[1]))); break;
        case 12: _t->adaptiveFocus((*reinterpret_cast<std::add_pointer_t<QString>>(_a[1]))); break;
        case 13: _t->settingsUpdated((*reinterpret_cast<std::add_pointer_t<QVariantMap>>(_a[1]))); break;
        case 14: _t->sequenceChanged((*reinterpret_cast<std::add_pointer_t<QJsonArray>>(_a[1]))); break;
        case 15: _t->newLocalPreview((*reinterpret_cast<std::add_pointer_t<QString>>(_a[1]))); break;
        case 16: _t->dslrInfoRequested((*reinterpret_cast<std::add_pointer_t<QString>>(_a[1]))); break;
        case 17: _t->filterManagerUpdated((*reinterpret_cast<std::add_pointer_t<ISD::FilterWheel*>>(_a[1]))); break;
        case 18: _t->newFilterStatus((*reinterpret_cast<std::add_pointer_t<FilterState>>(_a[1]))); break;
        case 19: _t->trainChanged(); break;
        case 20: _t->newLog((*reinterpret_cast<std::add_pointer_t<QString>>(_a[1]))); break;
        case 21: _t->captureStarting((*reinterpret_cast<std::add_pointer_t<double>>(_a[1])),(*reinterpret_cast<std::add_pointer_t<QString>>(_a[2]))); break;
        case 22: _t->captureAborted((*reinterpret_cast<std::add_pointer_t<double>>(_a[1]))); break;
        case 23: _t->checkFocus((*reinterpret_cast<std::add_pointer_t<double>>(_a[1])),(*reinterpret_cast<std::add_pointer_t<QString>>(_a[2]))); break;
        case 24: _t->meridianFlipStarted((*reinterpret_cast<std::add_pointer_t<QString>>(_a[1]))); break;
        case 25: _t->guideAfterMeridianFlip(); break;
        case 26: _t->newStatus((*reinterpret_cast<std::add_pointer_t<CaptureState>>(_a[1])),(*reinterpret_cast<std::add_pointer_t<QString>>(_a[2])),(*reinterpret_cast<std::add_pointer_t<int>>(_a[3]))); break;
        case 27: _t->suspendGuiding(); break;
        case 28: _t->resumeGuiding(); break;
        case 29: _t->driverTimedout((*reinterpret_cast<std::add_pointer_t<QString>>(_a[1]))); break;
        case 30: _t->setVideoStreamEnabled((*reinterpret_cast<std::add_pointer_t<bool>>(_a[1]))); break;
        case 31: _t->setCoolerToggled((*reinterpret_cast<std::add_pointer_t<bool>>(_a[1]))); break;
        case 32: _t->setFilterStatus((*reinterpret_cast<std::add_pointer_t<FilterState>>(_a[1]))); break;
        case 33: _t->resetJobs(); break;
        case 34: { bool _r = _t->selectJob((*reinterpret_cast<std::add_pointer_t<QModelIndex>>(_a[1])));
            if (_a[0]) *reinterpret_cast<bool*>(_a[0]) = std::move(_r); }  break;
        case 35: _t->editJob((*reinterpret_cast<std::add_pointer_t<QModelIndex>>(_a[1]))); break;
        case 36: _t->resetJobEdit((*reinterpret_cast<std::add_pointer_t<bool>>(_a[1]))); break;
        case 37: _t->resetJobEdit(); break;
        case 38: { bool _r = _t->removeJob((*reinterpret_cast<std::add_pointer_t<int>>(_a[1])));
            if (_a[0]) *reinterpret_cast<bool*>(_a[0]) = std::move(_r); }  break;
        case 39: { bool _r = _t->removeJob();
            if (_a[0]) *reinterpret_cast<bool*>(_a[0]) = std::move(_r); }  break;
        case 40: { bool _r = _t->modifyJob((*reinterpret_cast<std::add_pointer_t<int>>(_a[1])));
            if (_a[0]) *reinterpret_cast<bool*>(_a[0]) = std::move(_r); }  break;
        case 41: { bool _r = _t->modifyJob();
            if (_a[0]) *reinterpret_cast<bool*>(_a[0]) = std::move(_r); }  break;
        case 42: _t->editJobFinished(); break;
        case 43: _t->imageCapturingCompleted(); break;
        case 44: _t->captureStopped(); break;
        case 45: _t->processingFITSfinished((*reinterpret_cast<std::add_pointer_t<bool>>(_a[1]))); break;
        case 46: _t->captureRunning(); break;
        case 47: _t->captureImageStarted(); break;
        case 48: _t->jobExecutionPreparationStarted(); break;
        default: ;
        }
    }
    if (_c == QMetaObject::RegisterMethodArgumentMetaType) {
        switch (_id) {
        default: *reinterpret_cast<QMetaType *>(_a[0]) = QMetaType(); break;
        case 3:
            switch (*reinterpret_cast<int*>(_a[1])) {
            default: *reinterpret_cast<QMetaType *>(_a[0]) = QMetaType(); break;
            case 0:
                *reinterpret_cast<QMetaType *>(_a[0]) = QMetaType::fromType< QSharedPointer<SequenceJob> >(); break;
            }
            break;
        case 5:
            switch (*reinterpret_cast<int*>(_a[1])) {
            default: *reinterpret_cast<QMetaType *>(_a[0]) = QMetaType(); break;
            case 1:
                *reinterpret_cast<QMetaType *>(_a[0]) = QMetaType::fromType< QSharedPointer<FITSData> >(); break;
            case 0:
                *reinterpret_cast<QMetaType *>(_a[0]) = QMetaType::fromType< QSharedPointer<SequenceJob> >(); break;
            }
            break;
        case 17:
            switch (*reinterpret_cast<int*>(_a[1])) {
            default: *reinterpret_cast<QMetaType *>(_a[0]) = QMetaType(); break;
            case 0:
                *reinterpret_cast<QMetaType *>(_a[0]) = QMetaType::fromType< ISD::FilterWheel* >(); break;
            }
            break;
        }
    }
    if (_c == QMetaObject::IndexOfMethod) {
        if (QtMocHelpers::indexOfMethod<void (Camera::*)()>(_a, &Camera::ready, 0))
            return;
        if (QtMocHelpers::indexOfMethod<void (Camera::*)(int , CaptureWorkflowActionType )>(_a, &Camera::requestAction, 1))
            return;
        if (QtMocHelpers::indexOfMethod<void (Camera::*)(uint , bool )>(_a, &Camera::refreshCamera, 2))
            return;
        if (QtMocHelpers::indexOfMethod<void (Camera::*)(const QSharedPointer<SequenceJob> & , const QString & )>(_a, &Camera::newExposureProgress, 3))
            return;
        if (QtMocHelpers::indexOfMethod<void (Camera::*)(double , const QString & )>(_a, &Camera::newDownloadProgress, 4))
            return;
        if (QtMocHelpers::indexOfMethod<void (Camera::*)(const QSharedPointer<SequenceJob> & , const QSharedPointer<FITSData> & , const QString & )>(_a, &Camera::newImage, 5))
            return;
        if (QtMocHelpers::indexOfMethod<void (Camera::*)(QString )>(_a, &Camera::captureTarget, 6))
            return;
        if (QtMocHelpers::indexOfMethod<void (Camera::*)(const QVariantMap & , const QString & )>(_a, &Camera::captureComplete, 7))
            return;
        if (QtMocHelpers::indexOfMethod<void (Camera::*)()>(_a, &Camera::resetNonGuidedDither, 8))
            return;
        if (QtMocHelpers::indexOfMethod<void (Camera::*)(AutofocusReason , const QString & , const QString & )>(_a, &Camera::runAutoFocus, 9))
            return;
        if (QtMocHelpers::indexOfMethod<void (Camera::*)(const QString & )>(_a, &Camera::resetFocusFrame, 10))
            return;
        if (QtMocHelpers::indexOfMethod<void (Camera::*)(const QString & )>(_a, &Camera::abortFocus, 11))
            return;
        if (QtMocHelpers::indexOfMethod<void (Camera::*)(const QString & )>(_a, &Camera::adaptiveFocus, 12))
            return;
        if (QtMocHelpers::indexOfMethod<void (Camera::*)(const QVariantMap & )>(_a, &Camera::settingsUpdated, 13))
            return;
        if (QtMocHelpers::indexOfMethod<void (Camera::*)(const QJsonArray & )>(_a, &Camera::sequenceChanged, 14))
            return;
        if (QtMocHelpers::indexOfMethod<void (Camera::*)(const QString & )>(_a, &Camera::newLocalPreview, 15))
            return;
        if (QtMocHelpers::indexOfMethod<void (Camera::*)(const QString & )>(_a, &Camera::dslrInfoRequested, 16))
            return;
        if (QtMocHelpers::indexOfMethod<void (Camera::*)(ISD::FilterWheel * )>(_a, &Camera::filterManagerUpdated, 17))
            return;
        if (QtMocHelpers::indexOfMethod<void (Camera::*)(FilterState )>(_a, &Camera::newFilterStatus, 18))
            return;
        if (QtMocHelpers::indexOfMethod<void (Camera::*)()>(_a, &Camera::trainChanged, 19))
            return;
        if (QtMocHelpers::indexOfMethod<void (Camera::*)(const QString & )>(_a, &Camera::newLog, 20))
            return;
        if (QtMocHelpers::indexOfMethod<void (Camera::*)(double , const QString & )>(_a, &Camera::captureStarting, 21))
            return;
        if (QtMocHelpers::indexOfMethod<void (Camera::*)(double )>(_a, &Camera::captureAborted, 22))
            return;
        if (QtMocHelpers::indexOfMethod<void (Camera::*)(double , const QString & )>(_a, &Camera::checkFocus, 23))
            return;
        if (QtMocHelpers::indexOfMethod<void (Camera::*)(const QString & )>(_a, &Camera::meridianFlipStarted, 24))
            return;
        if (QtMocHelpers::indexOfMethod<void (Camera::*)()>(_a, &Camera::guideAfterMeridianFlip, 25))
            return;
        if (QtMocHelpers::indexOfMethod<void (Camera::*)(CaptureState , const QString & , int )>(_a, &Camera::newStatus, 26))
            return;
        if (QtMocHelpers::indexOfMethod<void (Camera::*)()>(_a, &Camera::suspendGuiding, 27))
            return;
        if (QtMocHelpers::indexOfMethod<void (Camera::*)()>(_a, &Camera::resumeGuiding, 28))
            return;
        if (QtMocHelpers::indexOfMethod<void (Camera::*)(const QString & )>(_a, &Camera::driverTimedout, 29))
            return;
    }
}

const QMetaObject *Ekos::Camera::metaObject() const
{
    return QObject::d_ptr->metaObject ? QObject::d_ptr->dynamicMetaObject() : &staticMetaObject;
}

void *Ekos::Camera::qt_metacast(const char *_clname)
{
    if (!_clname) return nullptr;
    if (!strcmp(_clname, qt_staticMetaObjectStaticContent<qt_meta_tag_ZN4Ekos6CameraE_t>.strings))
        return static_cast<void*>(this);
    if (!strcmp(_clname, "Ui::Camera"))
        return static_cast< Ui::Camera*>(this);
    return QWidget::qt_metacast(_clname);
}

int Ekos::Camera::qt_metacall(QMetaObject::Call _c, int _id, void **_a)
{
    _id = QWidget::qt_metacall(_c, _id, _a);
    if (_id < 0)
        return _id;
    if (_c == QMetaObject::InvokeMetaMethod) {
        if (_id < 49)
            qt_static_metacall(this, _c, _id, _a);
        _id -= 49;
    }
    if (_c == QMetaObject::RegisterMethodArgumentMetaType) {
        if (_id < 49)
            qt_static_metacall(this, _c, _id, _a);
        _id -= 49;
    }
    return _id;
}

// SIGNAL 0
void Ekos::Camera::ready()
{
    QMetaObject::activate(this, &staticMetaObject, 0, nullptr);
}

// SIGNAL 1
void Ekos::Camera::requestAction(int _t1, CaptureWorkflowActionType _t2)
{
    QMetaObject::activate<void>(this, &staticMetaObject, 1, nullptr, _t1, _t2);
}

// SIGNAL 2
void Ekos::Camera::refreshCamera(uint _t1, bool _t2)
{
    QMetaObject::activate<void>(this, &staticMetaObject, 2, nullptr, _t1, _t2);
}

// SIGNAL 3
void Ekos::Camera::newExposureProgress(const QSharedPointer<SequenceJob> & _t1, const QString & _t2)
{
    QMetaObject::activate<void>(this, &staticMetaObject, 3, nullptr, _t1, _t2);
}

// SIGNAL 4
void Ekos::Camera::newDownloadProgress(double _t1, const QString & _t2)
{
    QMetaObject::activate<void>(this, &staticMetaObject, 4, nullptr, _t1, _t2);
}

// SIGNAL 5
void Ekos::Camera::newImage(const QSharedPointer<SequenceJob> & _t1, const QSharedPointer<FITSData> & _t2, const QString & _t3)
{
    QMetaObject::activate<void>(this, &staticMetaObject, 5, nullptr, _t1, _t2, _t3);
}

// SIGNAL 6
void Ekos::Camera::captureTarget(QString _t1)
{
    QMetaObject::activate<void>(this, &staticMetaObject, 6, nullptr, _t1);
}

// SIGNAL 7
void Ekos::Camera::captureComplete(const QVariantMap & _t1, const QString & _t2)
{
    QMetaObject::activate<void>(this, &staticMetaObject, 7, nullptr, _t1, _t2);
}

// SIGNAL 8
void Ekos::Camera::resetNonGuidedDither()
{
    QMetaObject::activate(this, &staticMetaObject, 8, nullptr);
}

// SIGNAL 9
void Ekos::Camera::runAutoFocus(AutofocusReason _t1, const QString & _t2, const QString & _t3)
{
    QMetaObject::activate<void>(this, &staticMetaObject, 9, nullptr, _t1, _t2, _t3);
}

// SIGNAL 10
void Ekos::Camera::resetFocusFrame(const QString & _t1)
{
    QMetaObject::activate<void>(this, &staticMetaObject, 10, nullptr, _t1);
}

// SIGNAL 11
void Ekos::Camera::abortFocus(const QString & _t1)
{
    QMetaObject::activate<void>(this, &staticMetaObject, 11, nullptr, _t1);
}

// SIGNAL 12
void Ekos::Camera::adaptiveFocus(const QString & _t1)
{
    QMetaObject::activate<void>(this, &staticMetaObject, 12, nullptr, _t1);
}

// SIGNAL 13
void Ekos::Camera::settingsUpdated(const QVariantMap & _t1)
{
    QMetaObject::activate<void>(this, &staticMetaObject, 13, nullptr, _t1);
}

// SIGNAL 14
void Ekos::Camera::sequenceChanged(const QJsonArray & _t1)
{
    QMetaObject::activate<void>(this, &staticMetaObject, 14, nullptr, _t1);
}

// SIGNAL 15
void Ekos::Camera::newLocalPreview(const QString & _t1)
{
    QMetaObject::activate<void>(this, &staticMetaObject, 15, nullptr, _t1);
}

// SIGNAL 16
void Ekos::Camera::dslrInfoRequested(const QString & _t1)
{
    QMetaObject::activate<void>(this, &staticMetaObject, 16, nullptr, _t1);
}

// SIGNAL 17
void Ekos::Camera::filterManagerUpdated(ISD::FilterWheel * _t1)
{
    QMetaObject::activate<void>(this, &staticMetaObject, 17, nullptr, _t1);
}

// SIGNAL 18
void Ekos::Camera::newFilterStatus(FilterState _t1)
{
    QMetaObject::activate<void>(this, &staticMetaObject, 18, nullptr, _t1);
}

// SIGNAL 19
void Ekos::Camera::trainChanged()
{
    QMetaObject::activate(this, &staticMetaObject, 19, nullptr);
}

// SIGNAL 20
void Ekos::Camera::newLog(const QString & _t1)
{
    QMetaObject::activate<void>(this, &staticMetaObject, 20, nullptr, _t1);
}

// SIGNAL 21
void Ekos::Camera::captureStarting(double _t1, const QString & _t2)
{
    QMetaObject::activate<void>(this, &staticMetaObject, 21, nullptr, _t1, _t2);
}

// SIGNAL 22
void Ekos::Camera::captureAborted(double _t1)
{
    QMetaObject::activate<void>(this, &staticMetaObject, 22, nullptr, _t1);
}

// SIGNAL 23
void Ekos::Camera::checkFocus(double _t1, const QString & _t2)
{
    QMetaObject::activate<void>(this, &staticMetaObject, 23, nullptr, _t1, _t2);
}

// SIGNAL 24
void Ekos::Camera::meridianFlipStarted(const QString & _t1)
{
    QMetaObject::activate<void>(this, &staticMetaObject, 24, nullptr, _t1);
}

// SIGNAL 25
void Ekos::Camera::guideAfterMeridianFlip()
{
    QMetaObject::activate(this, &staticMetaObject, 25, nullptr);
}

// SIGNAL 26
void Ekos::Camera::newStatus(CaptureState _t1, const QString & _t2, int _t3)
{
    QMetaObject::activate<void>(this, &staticMetaObject, 26, nullptr, _t1, _t2, _t3);
}

// SIGNAL 27
void Ekos::Camera::suspendGuiding()
{
    QMetaObject::activate(this, &staticMetaObject, 27, nullptr);
}

// SIGNAL 28
void Ekos::Camera::resumeGuiding()
{
    QMetaObject::activate(this, &staticMetaObject, 28, nullptr);
}

// SIGNAL 29
void Ekos::Camera::driverTimedout(const QString & _t1)
{
    QMetaObject::activate<void>(this, &staticMetaObject, 29, nullptr, _t1);
}
QT_WARNING_POP
