/********************************************************************************
** Form generated from reading UI file 'profileeditor.ui'
**
** Created by: Qt User Interface Compiler version 6.11.1
**
** WARNING! All changes made in this file will be lost when recompiling UI file!
********************************************************************************/

#ifndef UI_PROFILEEDITOR_H
#define UI_PROFILEEDITOR_H

#include <QtCore/QVariant>
#include <QtGui/QIcon>
#include <QtWidgets/QApplication>
#include <QtWidgets/QCheckBox>
#include <QtWidgets/QComboBox>
#include <QtWidgets/QGridLayout>
#include <QtWidgets/QGroupBox>
#include <QtWidgets/QHBoxLayout>
#include <QtWidgets/QHeaderView>
#include <QtWidgets/QLabel>
#include <QtWidgets/QLineEdit>
#include <QtWidgets/QListView>
#include <QtWidgets/QPushButton>
#include <QtWidgets/QRadioButton>
#include <QtWidgets/QSpacerItem>
#include <QtWidgets/QTreeView>
#include <QtWidgets/QVBoxLayout>
#include <QtWidgets/QWidget>
#include <klocalizedstring.h>

QT_BEGIN_NAMESPACE

class Ui_ProfileEditorUI
{
public:
    QVBoxLayout *verticalLayout_3;
    QGroupBox *profileGroup;
    QVBoxLayout *verticalLayout_2;
    QHBoxLayout *horizontalLayout;
    QLabel *profileNameLabel;
    QLineEdit *profileIN;
    QCheckBox *autoConnectCheck;
    QSpacerItem *horizontalSpacer;
    QCheckBox *portSelectorCheck;
    QCheckBox *loadSiteCheck;
    QGridLayout *gridLayout_2;
    QLabel *INDIWebManagerPortLabel;
    QLineEdit *externalGuidePort;
    QLabel *modeLabel;
    QLabel *remoteHostLabel;
    QPushButton *openWebManagerB;
    QPushButton *scanB;
    QLineEdit *INDIWebManagerPort;
    QRadioButton *localMode;
    QComboBox *guideTypeCombo;
    QLabel *guidingTypeLabel;
    QCheckBox *INDIWebManagerCheck;
    QLabel *remotePortLabel;
    QRadioButton *remoteMode;
    QLineEdit *remoteHost;
    QLabel *externalGuidePortLabel;
    QLineEdit *externalGuideHost;
    QLabel *externalGuideHostLabel;
    QLineEdit *remotePort;
    QGroupBox *driversGroupBox;
    QVBoxLayout *verticalLayout_6;
    QHBoxLayout *horizontalLayout_4;
    QVBoxLayout *verticalLayout_4;
    QLineEdit *driverSearchEdit;
    QTreeView *driversTree;
    QVBoxLayout *verticalLayout;
    QSpacerItem *verticalSpacer;
    QPushButton *addDriverB;
    QPushButton *removeDriverB;
    QSpacerItem *verticalSpacer_2;
    QVBoxLayout *verticalLayout_5;
    QHBoxLayout *horizontalLayout_3;
    QLineEdit *profileSearchEdit;
    QLabel *driverCount;
    QListView *profileDriversList;
    QHBoxLayout *horizontalLayout_2;
    QLabel *remoteDriversLabel;
    QLineEdit *remoteDrivers;
    QPushButton *scriptsB;

    void setupUi(QWidget *ProfileEditorUI)
    {
        if (ProfileEditorUI->objectName().isEmpty())
            ProfileEditorUI->setObjectName("ProfileEditorUI");
        ProfileEditorUI->resize(567, 512);
        verticalLayout_3 = new QVBoxLayout(ProfileEditorUI);
        verticalLayout_3->setSpacing(3);
        verticalLayout_3->setObjectName("verticalLayout_3");
        verticalLayout_3->setContentsMargins(3, 3, 3, 3);
        profileGroup = new QGroupBox(ProfileEditorUI);
        profileGroup->setObjectName("profileGroup");
        verticalLayout_2 = new QVBoxLayout(profileGroup);
        verticalLayout_2->setSpacing(3);
        verticalLayout_2->setObjectName("verticalLayout_2");
        verticalLayout_2->setContentsMargins(3, 3, 3, 3);
        horizontalLayout = new QHBoxLayout();
        horizontalLayout->setObjectName("horizontalLayout");
        profileNameLabel = new QLabel(profileGroup);
        profileNameLabel->setObjectName("profileNameLabel");

        horizontalLayout->addWidget(profileNameLabel);

        profileIN = new QLineEdit(profileGroup);
        profileIN->setObjectName("profileIN");

        horizontalLayout->addWidget(profileIN);

        autoConnectCheck = new QCheckBox(profileGroup);
        autoConnectCheck->setObjectName("autoConnectCheck");
        autoConnectCheck->setChecked(true);

        horizontalLayout->addWidget(autoConnectCheck);

        horizontalSpacer = new QSpacerItem(40, 20, QSizePolicy::Policy::Expanding, QSizePolicy::Policy::Minimum);

        horizontalLayout->addItem(horizontalSpacer);

        portSelectorCheck = new QCheckBox(profileGroup);
        portSelectorCheck->setObjectName("portSelectorCheck");
        portSelectorCheck->setChecked(true);

        horizontalLayout->addWidget(portSelectorCheck);

        loadSiteCheck = new QCheckBox(profileGroup);
        loadSiteCheck->setObjectName("loadSiteCheck");
        loadSiteCheck->setEnabled(false);

        horizontalLayout->addWidget(loadSiteCheck);


        verticalLayout_2->addLayout(horizontalLayout);

        gridLayout_2 = new QGridLayout();
        gridLayout_2->setObjectName("gridLayout_2");
        INDIWebManagerPortLabel = new QLabel(profileGroup);
        INDIWebManagerPortLabel->setObjectName("INDIWebManagerPortLabel");
        INDIWebManagerPortLabel->setEnabled(false);

        gridLayout_2->addWidget(INDIWebManagerPortLabel, 2, 8, 1, 1);

        externalGuidePort = new QLineEdit(profileGroup);
        externalGuidePort->setObjectName("externalGuidePort");
        externalGuidePort->setEnabled(false);
        QSizePolicy sizePolicy(QSizePolicy::Policy::Preferred, QSizePolicy::Policy::Fixed);
        sizePolicy.setHorizontalStretch(0);
        sizePolicy.setVerticalStretch(0);
        sizePolicy.setHeightForWidth(externalGuidePort->sizePolicy().hasHeightForWidth());
        externalGuidePort->setSizePolicy(sizePolicy);

        gridLayout_2->addWidget(externalGuidePort, 1, 9, 1, 1);

        modeLabel = new QLabel(profileGroup);
        modeLabel->setObjectName("modeLabel");

        gridLayout_2->addWidget(modeLabel, 0, 0, 1, 1);

        remoteHostLabel = new QLabel(profileGroup);
        remoteHostLabel->setObjectName("remoteHostLabel");
        remoteHostLabel->setEnabled(false);

        gridLayout_2->addWidget(remoteHostLabel, 0, 3, 1, 1);

        openWebManagerB = new QPushButton(profileGroup);
        openWebManagerB->setObjectName("openWebManagerB");
        openWebManagerB->setEnabled(false);
        sizePolicy.setHeightForWidth(openWebManagerB->sizePolicy().hasHeightForWidth());
        openWebManagerB->setSizePolicy(sizePolicy);
        QIcon icon(QIcon::fromTheme(QString::fromUtf8("applications-internet")));
        openWebManagerB->setIcon(icon);
        openWebManagerB->setIconSize(QSize(20, 20));

        gridLayout_2->addWidget(openWebManagerB, 2, 4, 1, 3);

        scanB = new QPushButton(profileGroup);
        scanB->setObjectName("scanB");
        QIcon icon1(QIcon::fromTheme(QString::fromUtf8("search")));
        scanB->setIcon(icon1);
        scanB->setIconSize(QSize(20, 20));

        gridLayout_2->addWidget(scanB, 2, 7, 1, 1);

        INDIWebManagerPort = new QLineEdit(profileGroup);
        INDIWebManagerPort->setObjectName("INDIWebManagerPort");
        INDIWebManagerPort->setEnabled(false);
        sizePolicy.setHeightForWidth(INDIWebManagerPort->sizePolicy().hasHeightForWidth());
        INDIWebManagerPort->setSizePolicy(sizePolicy);

        gridLayout_2->addWidget(INDIWebManagerPort, 2, 9, 1, 1);

        localMode = new QRadioButton(profileGroup);
        localMode->setObjectName("localMode");
        localMode->setChecked(true);

        gridLayout_2->addWidget(localMode, 0, 1, 1, 1);

        guideTypeCombo = new QComboBox(profileGroup);
        guideTypeCombo->addItem(QString());
        guideTypeCombo->addItem(QString());
        guideTypeCombo->addItem(QString());
        guideTypeCombo->setObjectName("guideTypeCombo");
        QSizePolicy sizePolicy1(QSizePolicy::Policy::Minimum, QSizePolicy::Policy::Fixed);
        sizePolicy1.setHorizontalStretch(0);
        sizePolicy1.setVerticalStretch(0);
        sizePolicy1.setHeightForWidth(guideTypeCombo->sizePolicy().hasHeightForWidth());
        guideTypeCombo->setSizePolicy(sizePolicy1);

        gridLayout_2->addWidget(guideTypeCombo, 1, 1, 1, 2);

        guidingTypeLabel = new QLabel(profileGroup);
        guidingTypeLabel->setObjectName("guidingTypeLabel");

        gridLayout_2->addWidget(guidingTypeLabel, 1, 0, 1, 1);

        INDIWebManagerCheck = new QCheckBox(profileGroup);
        INDIWebManagerCheck->setObjectName("INDIWebManagerCheck");
        INDIWebManagerCheck->setEnabled(false);

        gridLayout_2->addWidget(INDIWebManagerCheck, 2, 0, 1, 4);

        remotePortLabel = new QLabel(profileGroup);
        remotePortLabel->setObjectName("remotePortLabel");
        remotePortLabel->setEnabled(false);

        gridLayout_2->addWidget(remotePortLabel, 0, 8, 1, 1);

        remoteMode = new QRadioButton(profileGroup);
        remoteMode->setObjectName("remoteMode");

        gridLayout_2->addWidget(remoteMode, 0, 2, 1, 1);

        remoteHost = new QLineEdit(profileGroup);
        remoteHost->setObjectName("remoteHost");
        remoteHost->setEnabled(false);
        QSizePolicy sizePolicy2(QSizePolicy::Policy::MinimumExpanding, QSizePolicy::Policy::Fixed);
        sizePolicy2.setHorizontalStretch(0);
        sizePolicy2.setVerticalStretch(0);
        sizePolicy2.setHeightForWidth(remoteHost->sizePolicy().hasHeightForWidth());
        remoteHost->setSizePolicy(sizePolicy2);
        remoteHost->setText(QString::fromUtf8("localhost"));

        gridLayout_2->addWidget(remoteHost, 0, 4, 1, 4);

        externalGuidePortLabel = new QLabel(profileGroup);
        externalGuidePortLabel->setObjectName("externalGuidePortLabel");
        externalGuidePortLabel->setEnabled(false);

        gridLayout_2->addWidget(externalGuidePortLabel, 1, 8, 1, 1);

        externalGuideHost = new QLineEdit(profileGroup);
        externalGuideHost->setObjectName("externalGuideHost");
        externalGuideHost->setEnabled(false);
        sizePolicy2.setHeightForWidth(externalGuideHost->sizePolicy().hasHeightForWidth());
        externalGuideHost->setSizePolicy(sizePolicy2);

        gridLayout_2->addWidget(externalGuideHost, 1, 4, 1, 4);

        externalGuideHostLabel = new QLabel(profileGroup);
        externalGuideHostLabel->setObjectName("externalGuideHostLabel");
        externalGuideHostLabel->setEnabled(false);

        gridLayout_2->addWidget(externalGuideHostLabel, 1, 3, 1, 1);

        remotePort = new QLineEdit(profileGroup);
        remotePort->setObjectName("remotePort");
        remotePort->setEnabled(false);
        sizePolicy.setHeightForWidth(remotePort->sizePolicy().hasHeightForWidth());
        remotePort->setSizePolicy(sizePolicy);

        gridLayout_2->addWidget(remotePort, 0, 9, 1, 1);


        verticalLayout_2->addLayout(gridLayout_2);


        verticalLayout_3->addWidget(profileGroup);

        driversGroupBox = new QGroupBox(ProfileEditorUI);
        driversGroupBox->setObjectName("driversGroupBox");
        verticalLayout_6 = new QVBoxLayout(driversGroupBox);
        verticalLayout_6->setSpacing(3);
        verticalLayout_6->setObjectName("verticalLayout_6");
        verticalLayout_6->setContentsMargins(3, 3, -1, 3);
        horizontalLayout_4 = new QHBoxLayout();
        horizontalLayout_4->setSpacing(3);
        horizontalLayout_4->setObjectName("horizontalLayout_4");
        verticalLayout_4 = new QVBoxLayout();
        verticalLayout_4->setSpacing(3);
        verticalLayout_4->setObjectName("verticalLayout_4");
        driverSearchEdit = new QLineEdit(driversGroupBox);
        driverSearchEdit->setObjectName("driverSearchEdit");
        driverSearchEdit->setClearButtonEnabled(true);

        verticalLayout_4->addWidget(driverSearchEdit);

        driversTree = new QTreeView(driversGroupBox);
        driversTree->setObjectName("driversTree");
        driversTree->header()->setVisible(false);

        verticalLayout_4->addWidget(driversTree);


        horizontalLayout_4->addLayout(verticalLayout_4);

        verticalLayout = new QVBoxLayout();
        verticalLayout->setSpacing(3);
        verticalLayout->setObjectName("verticalLayout");
        verticalSpacer = new QSpacerItem(20, 18, QSizePolicy::Policy::Minimum, QSizePolicy::Policy::Expanding);

        verticalLayout->addItem(verticalSpacer);

        addDriverB = new QPushButton(driversGroupBox);
        addDriverB->setObjectName("addDriverB");
        addDriverB->setMinimumSize(QSize(32, 32));
        addDriverB->setMaximumSize(QSize(32, 32));
        QIcon icon2(QIcon::fromTheme(QString::fromUtf8("arrow-right")));
        addDriverB->setIcon(icon2);
        addDriverB->setIconSize(QSize(28, 28));

        verticalLayout->addWidget(addDriverB);

        removeDriverB = new QPushButton(driversGroupBox);
        removeDriverB->setObjectName("removeDriverB");
        removeDriverB->setMinimumSize(QSize(32, 32));
        removeDriverB->setMaximumSize(QSize(32, 32));
        QIcon icon3(QIcon::fromTheme(QString::fromUtf8("arrow-left")));
        removeDriverB->setIcon(icon3);
        removeDriverB->setIconSize(QSize(28, 28));

        verticalLayout->addWidget(removeDriverB);

        verticalSpacer_2 = new QSpacerItem(20, 18, QSizePolicy::Policy::Minimum, QSizePolicy::Policy::Expanding);

        verticalLayout->addItem(verticalSpacer_2);


        horizontalLayout_4->addLayout(verticalLayout);

        verticalLayout_5 = new QVBoxLayout();
        verticalLayout_5->setSpacing(3);
        verticalLayout_5->setObjectName("verticalLayout_5");
        horizontalLayout_3 = new QHBoxLayout();
        horizontalLayout_3->setSpacing(3);
        horizontalLayout_3->setObjectName("horizontalLayout_3");
        profileSearchEdit = new QLineEdit(driversGroupBox);
        profileSearchEdit->setObjectName("profileSearchEdit");
        profileSearchEdit->setEnabled(true);
        profileSearchEdit->setClearButtonEnabled(true);

        horizontalLayout_3->addWidget(profileSearchEdit);

        driverCount = new QLabel(driversGroupBox);
        driverCount->setObjectName("driverCount");
        driverCount->setMinimumSize(QSize(32, 32));
        driverCount->setMaximumSize(QSize(32, 32));
        driverCount->setStyleSheet(QString::fromUtf8("border: 2px solid green;color: green;font-weight: bold;"));
        driverCount->setAlignment(Qt::AlignmentFlag::AlignCenter);

        horizontalLayout_3->addWidget(driverCount);


        verticalLayout_5->addLayout(horizontalLayout_3);

        profileDriversList = new QListView(driversGroupBox);
        profileDriversList->setObjectName("profileDriversList");

        verticalLayout_5->addWidget(profileDriversList);


        horizontalLayout_4->addLayout(verticalLayout_5);

        horizontalLayout_4->setStretch(0, 5);
        horizontalLayout_4->setStretch(2, 5);

        verticalLayout_6->addLayout(horizontalLayout_4);

        horizontalLayout_2 = new QHBoxLayout();
        horizontalLayout_2->setSpacing(3);
        horizontalLayout_2->setObjectName("horizontalLayout_2");
        remoteDriversLabel = new QLabel(driversGroupBox);
        remoteDriversLabel->setObjectName("remoteDriversLabel");

        horizontalLayout_2->addWidget(remoteDriversLabel);

        remoteDrivers = new QLineEdit(driversGroupBox);
        remoteDrivers->setObjectName("remoteDrivers");

        horizontalLayout_2->addWidget(remoteDrivers);

        scriptsB = new QPushButton(driversGroupBox);
        scriptsB->setObjectName("scriptsB");

        horizontalLayout_2->addWidget(scriptsB);


        verticalLayout_6->addLayout(horizontalLayout_2);


        verticalLayout_3->addWidget(driversGroupBox);

        verticalLayout_3->setStretch(0, 1);
        verticalLayout_3->setStretch(1, 5);
        QWidget::setTabOrder(profileIN, localMode);
        QWidget::setTabOrder(localMode, remoteHost);
        QWidget::setTabOrder(remoteHost, remotePort);
        QWidget::setTabOrder(remotePort, INDIWebManagerCheck);
        QWidget::setTabOrder(INDIWebManagerCheck, INDIWebManagerPort);
        QWidget::setTabOrder(INDIWebManagerPort, loadSiteCheck);

        retranslateUi(ProfileEditorUI);

        QMetaObject::connectSlotsByName(ProfileEditorUI);
    } // setupUi

    void retranslateUi(QWidget *ProfileEditorUI)
    {
        profileGroup->setTitle(tr2i18n("Profile", nullptr));
        profileNameLabel->setText(tr2i18n("Name:", nullptr));
#if QT_CONFIG(tooltip)
        autoConnectCheck->setToolTip(tr2i18n("<html><head/><body><p>After establishing connection with INDI server, automatically connect all devices.</p></body></html>", nullptr));
#endif // QT_CONFIG(tooltip)
        autoConnectCheck->setText(tr2i18n("Auto Connect", nullptr));
#if QT_CONFIG(tooltip)
        portSelectorCheck->setToolTip(tr2i18n("Show port selector dialog when first connecting to equipment. It is automatically disabled after connection is established.", nullptr));
#endif // QT_CONFIG(tooltip)
        portSelectorCheck->setText(tr2i18n("Port Selector", nullptr));
#if QT_CONFIG(tooltip)
        loadSiteCheck->setToolTip(tr2i18n("<html><head/><body>\n"
"<p>Send current KStars geographical site settings to drivers once Ekos is online.</p>\n"
"<p>This option should only be used when connecting to a remote geographic site.</p>\n"
"</body></html>", nullptr));
#endif // QT_CONFIG(tooltip)
        loadSiteCheck->setText(tr2i18n("Site Info", nullptr));
        INDIWebManagerPortLabel->setText(tr2i18n("Port:", nullptr));
#if QT_CONFIG(tooltip)
        externalGuidePort->setToolTip(tr2i18n("<html><body><p>External guider port.</p></body></html>", nullptr));
#endif // QT_CONFIG(tooltip)
#if QT_CONFIG(tooltip)
        modeLabel->setToolTip(tr2i18n("<html><head/><body>\n"
"<p>Connection mode to use for the INDI server:</p>\n"
"<p><span style=\"font-weight:600\">Local</span><br/>Connect to a local INDI server, created when Ekos starts.</p>\n"
"<p><span style=\"font-weight:600\">Remote</span><br/>Connect to a remote INDI server that is already running.</p>\n"
"</body></html>", nullptr));
#endif // QT_CONFIG(tooltip)
        modeLabel->setText(tr2i18n("Mode:", nullptr));
        remoteHostLabel->setText(tr2i18n("Host:", nullptr));
#if QT_CONFIG(tooltip)
        openWebManagerB->setToolTip(tr2i18n("<html><body><p>Open Web Manager in browser.</p></body></html>", nullptr));
#endif // QT_CONFIG(tooltip)
        openWebManagerB->setText(tr2i18n("Web Manager", nullptr));
#if QT_CONFIG(tooltip)
        scanB->setToolTip(tr2i18n("<html><body><p>Scan local network for INDI web managers.</p></body></html>", nullptr));
#endif // QT_CONFIG(tooltip)
        scanB->setText(tr2i18n("Scan", nullptr));
#if QT_CONFIG(tooltip)
        INDIWebManagerPort->setToolTip(tr2i18n("<html><body><p>INDI Web Manager port.</p></body></html>", nullptr));
#endif // QT_CONFIG(tooltip)
        INDIWebManagerPort->setText(tr2i18n("8624", nullptr));
        localMode->setText(tr2i18n("&Local", nullptr));
        guideTypeCombo->setItemText(0, tr2i18n("Internal", nullptr));
        guideTypeCombo->setItemText(1, tr2i18n("PHD2", nullptr));
        guideTypeCombo->setItemText(2, tr2i18n("LinGuider", nullptr));

#if QT_CONFIG(tooltip)
        guidingTypeLabel->setToolTip(tr2i18n("<html><body><p>Select which plug-in the Guider module should use.</p></body></html>", nullptr));
#endif // QT_CONFIG(tooltip)
        guidingTypeLabel->setText(tr2i18n("Guiding:", nullptr));
#if QT_CONFIG(tooltip)
        INDIWebManagerCheck->setToolTip(tr2i18n("<html><body><p>Store profile on remote INDI Web Manager. Use INDI Web Manager on the remote device to start/stop INDI server.</p></body></html>", nullptr));
#endif // QT_CONFIG(tooltip)
        INDIWebManagerCheck->setText(tr2i18n("INDI Web Manager", nullptr));
        remotePortLabel->setText(tr2i18n("Port:", nullptr));
        remoteMode->setText(tr2i18n("Re&mote", nullptr));
#if QT_CONFIG(tooltip)
        remoteHost->setToolTip(tr2i18n("<html><body><p>Remote INDI server host or address.</p></body></html>", nullptr));
#endif // QT_CONFIG(tooltip)
        externalGuidePortLabel->setText(tr2i18n("Port:", nullptr));
#if QT_CONFIG(tooltip)
        externalGuideHost->setToolTip(tr2i18n("<html><body><p>External guider host or address.</p></body></html>", nullptr));
#endif // QT_CONFIG(tooltip)
        externalGuideHost->setText(tr2i18n("localhost", nullptr));
        externalGuideHostLabel->setText(tr2i18n("Host:", nullptr));
#if QT_CONFIG(tooltip)
        remotePort->setToolTip(tr2i18n("<html><body><p>Remote INDI Server Port.</p></body></html>", nullptr));
#endif // QT_CONFIG(tooltip)
        remotePort->setText(tr2i18n("7624", nullptr));
        driversGroupBox->setTitle(tr2i18n("Select Devices", nullptr));
        driverSearchEdit->setPlaceholderText(tr2i18n("Driver Search", nullptr));
        addDriverB->setText(QString());
        removeDriverB->setText(QString());
        profileSearchEdit->setText(QString());
        profileSearchEdit->setPlaceholderText(tr2i18n("Profile Search", nullptr));
        driverCount->setText(QString());
#if QT_CONFIG(tooltip)
        remoteDriversLabel->setToolTip(tr2i18n("<html><head/><body><p>Add remote INDI drivers to chain with the local INDI server configured by this profile. Format this field as a comma-separated list of quoted driver name, host name/address and optional port:</p><p><span style=\" font-weight:600;\">&quot;ZWO ASI120MC&quot;@192.168.1.50:8000</span><br/>Connect to the named camera on 192.168.1.50, port 8000.</p><p><span style=\" font-weight:600;\">&quot;EQMod Mount&quot;@192.168.1.50</span><br/>Connect to the named mount on 192.168.1.50, port 7624.</p><p><span style=\" font-weight:600;\">@192.168.1.50:8000</span><br/>Connect to all drivers found on 192.168.1.50, port 8000.</p><p><span style=\" font-weight:600;\">@192.168.1.50</span><br/>Connect to all drivers found on 192.168.1.50, port 7624.</p><p>When omitted, host defaults to localhost and port defaults to 7624.<br/>Remote INDI drivers must be already running for the connection to succeed.</p></body></html>", nullptr));
#endif // QT_CONFIG(tooltip)
        remoteDriversLabel->setText(tr2i18n("Remote:", nullptr));
        remoteDrivers->setPlaceholderText(tr2i18n("driver@host:port,driver@host,@host:port,@host,driver", nullptr));
        scriptsB->setText(tr2i18n("Scripts", nullptr));
        (void)ProfileEditorUI;
    } // retranslateUi

};

namespace Ui {
    class ProfileEditorUI: public Ui_ProfileEditorUI {};
} // namespace Ui

QT_END_NAMESPACE

#endif // PROFILEEDITOR_H

