/*
 * This file was generated by qdbusxml2cpp version 0.8
 * Source file was org.kde.kstars.Ekos.Observatory.xml
 *
 * qdbusxml2cpp is Copyright (C) The Qt Company Ltd. and other contributors.
 *
 * This is an auto-generated file.
 * This file may have been hand-edited. Look for HAND-EDIT comments
 * before re-generating it.
 */

#ifndef OBSERVATORYADAPTOR_H
#define OBSERVATORYADAPTOR_H

#include <QtCore/QObject>
#include <QtDBus/QtDBus>
#include "ekos/observatory/observatory.h"
#include <QtCore/qcontainerfwd.h>

/*
 * Adaptor class for interface org.kde.kstars.Ekos.Observatory
 */
class ObservatoryAdaptor: public QDBusAbstractAdaptor
{
    Q_OBJECT
    Q_CLASSINFO("D-Bus Interface", "org.kde.kstars.Ekos.Observatory")
    Q_CLASSINFO("D-Bus Introspection", ""
"  <interface name=\"org.kde.kstars.Ekos.Observatory\">\n"
"    <property access=\"read\" type=\"as\" name=\"logText\"/>\n"
"    <property access=\"read\" type=\"i\" name=\"status\">\n"
"      <annotation value=\"ISD::Weather::Status\" name=\"org.qtproject.QtDBus.QtTypeName\"/>\n"
"    </property>\n"
"    <signal name=\"newStatus\">\n"
"      <arg direction=\"out\" type=\"(i)\" name=\"status\"/>\n"
"      <annotation value=\"ISD::Weather::Status\" name=\"org.qtproject.QtDBus.QtTypeName.In0\"/>\n"
"      <annotation value=\"ISD::Weather::Status\" name=\"org.qtproject.QtDBus.QtTypeName.Out0\"/>\n"
"    </signal>\n"
"  </interface>\n"
        "")
public:
    ObservatoryAdaptor(Ekos::Observatory *parent);
    ~ObservatoryAdaptor() override;

    inline Ekos::Observatory *parent() const
    { return static_cast<Ekos::Observatory *>(QObject::parent()); }

public: // PROPERTIES
    Q_PROPERTY(QStringList logText READ logText)
    QStringList logText() const;

    Q_PROPERTY(int status READ status)
    int status() const;

public Q_SLOTS: // METHODS
Q_SIGNALS: // SIGNALS
    void newStatus(ISD::Weather::Status status);
};

#endif
