/********************************************************************************
** Form generated from reading UI file 'camera.ui'
**
** Created by: Qt User Interface Compiler version 6.11.1
**
** WARNING! All changes made in this file will be lost when recompiling UI file!
********************************************************************************/

#ifndef UI_CAMERA_H
#define UI_CAMERA_H

#include <QtCore/QVariant>
#include <QtGui/QIcon>
#include <QtWidgets/QApplication>
#include <QtWidgets/QButtonGroup>
#include <QtWidgets/QCheckBox>
#include <QtWidgets/QComboBox>
#include <QtWidgets/QDoubleSpinBox>
#include <QtWidgets/QFrame>
#include <QtWidgets/QGridLayout>
#include <QtWidgets/QGroupBox>
#include <QtWidgets/QHBoxLayout>
#include <QtWidgets/QHeaderView>
#include <QtWidgets/QLabel>
#include <QtWidgets/QLineEdit>
#include <QtWidgets/QProgressBar>
#include <QtWidgets/QPushButton>
#include <QtWidgets/QSpacerItem>
#include <QtWidgets/QSpinBox>
#include <QtWidgets/QSplitter>
#include <QtWidgets/QStackedWidget>
#include <QtWidgets/QTableWidget>
#include <QtWidgets/QVBoxLayout>
#include <QtWidgets/QWidget>
#include <klocalizedstring.h>
#include "auxiliary/nonlineardoublespinbox.h"
#include "ekos/auxiliary/ledstatuswidget.h"

QT_BEGIN_NAMESPACE

class Ui_Camera
{
public:
    QVBoxLayout *wholeLayout;
    QLabel *sequenceEditorComment;
    QSplitter *splitter;
    QWidget *leftLayoutWidget;
    QVBoxLayout *leftLayout;
    QHBoxLayout *trainLayout;
    QLabel *opticalTrainLabel;
    QComboBox *opticalTrainCombo;
    QPushButton *trainB;
    QSpacerItem *horizontalSpacer_6;
    QPushButton *restartCameraB;
    QPushButton *clearConfigurationB;
    QPushButton *resetFrameB;
    QGroupBox *CaptureSettingsGroup;
    QGridLayout *gridLayout_3;
    QLabel *textLabel1_9;
    QHBoxLayout *formatLayout;
    QComboBox *captureFormatS;
    QComboBox *captureEncodingS;
    QLabel *label_7;
    QLabel *exposureLabel;
    QHBoxLayout *filterLayout;
    QComboBox *FilterPosCombo;
    QPushButton *filterManagerB;
    QPushButton *filterEditB;
    QHBoxLayout *frameSizeLayout;
    QLabel *textLabel1_15;
    QSpinBox *captureFrameWN;
    QLabel *textLabel1_16;
    QSpinBox *captureFrameHN;
    QHBoxLayout *coolerOnOffLayout;
    QPushButton *coolerOnB;
    QPushButton *coolerOffB;
    QHBoxLayout *binningLayout;
    QLabel *captureBinXLabel;
    QSpinBox *captureBinHN;
    QLabel *captureBinYLabel;
    QSpinBox *captureBinVN;
    QLabel *textLabel1_19;
    QLabel *textLabel1_12;
    QLabel *coolerLabel;
    QLabel *FilterPosLabel;
    QHBoxLayout *FrameXYLayout;
    QLabel *textLabel1_13;
    QSpinBox *captureFrameXN;
    QLabel *textLabel1_14;
    QSpinBox *captureFrameYN;
    NonLinearDoubleSpinBox *captureExposureN;
    QLabel *textLabel1_17;
    QComboBox *captureTypeS;
    QLabel *ISOLabel;
    QComboBox *captureISOS;
    QLabel *textLabel1_21;
    QHBoxLayout *gainLayout;
    QLabel *currentGainLabel;
    QDoubleSpinBox *captureGainN;
    QLabel *textLabel1_20;
    QHBoxLayout *offsetLayout;
    QLabel *currentOffsetLabel;
    QDoubleSpinBox *captureOffsetN;
    QWidget *toolsLayout;
    QGridLayout *gridLayout;
    QLabel *darksLibraryLabel;
    QLabel *rotatorLabel;
    QSpacerItem *verticalSpacer_2;
    QPushButton *rotatorB;
    QLabel *exposureCalculationLabel;
    QPushButton *darkLibraryB;
    QPushButton *exposureCalcB;
    QPushButton *calibrationB;
    QLabel *calibrationLabel;
    QPushButton *generateDarkFlatsB;
    QLabel *darksFlatsLabel;
    QPushButton *customValuesB;
    QLabel *customValuesLabel;
    QPushButton *limitsB;
    QLabel *limitsLabel;
    QPushButton *scriptManagerB;
    QLabel *scriptsLabel;
    QSpacerItem *horizontalSpacer_7;
    QHBoxLayout *coolerLayout;
    QLabel *temperatureOUT;
    QDoubleSpinBox *cameraTemperatureN;
    QCheckBox *cameraTemperatureS;
    QPushButton *setTemperatureB;
    QPushButton *temperatureRegulationB;
    QStackedWidget *exposureOptions;
    QWidget *frameExposureOptions;
    QHBoxLayout *horizontalLayout_3;
    QSpinBox *captureCountN;
    QLabel *textLabel1_8;
    QSpinBox *captureDelayN;
    QWidget *videoExposureOptions;
    QHBoxLayout *horizontalLayout_4;
    QDoubleSpinBox *videoDurationSB;
    QComboBox *videoDurationUnitCB;
    QLabel *exposureOptionsLabel;
    QGroupBox *fileSettingsGroup;
    QGridLayout *gridLayout_4;
    QComboBox *fileUploadModeS;
    QLineEdit *fileDirectoryT;
    QLineEdit *targetNameT;
    QLabel *textLabel1_18;
    QPushButton *resetFormatB;
    QLabel *textLabel1_7;
    QLineEdit *fileRemoteDirT;
    QLabel *label_4;
    QLineEdit *placeholderFormatT;
    QSpinBox *formatSuffixN;
    QLabel *formatLabel;
    QPushButton *selectFileDirectoryB;
    QLabel *remoteLabel;
    QHBoxLayout *countDelayLayout;
    QSpacerItem *verticalSpacer;
    QWidget *rightLayoutWidget;
    QVBoxLayout *RightLayout;
    QVBoxLayout *SequenceQueue;
    QGroupBox *sequenceBox;
    QVBoxLayout *verticalLayout_8;
    QHBoxLayout *horizontalLayout_14;
    QPushButton *addToQueueB;
    QPushButton *removeFromQueueB;
    QSpacerItem *horizontalSpacer_SQ1;
    QPushButton *queueUpB;
    QPushButton *queueDownB;
    QPushButton *resetB;
    QPushButton *observerB;
    QSpacerItem *horizontalSpacer_SQ2;
    QPushButton *queueLoadB;
    QPushButton *queueSaveB;
    QPushButton *queueSaveAsB;
    QTableWidget *queueTable;
    QGridLayout *buttonsGrid;
    QLabel *videoLabel;
    QLabel *previewLabel;
    QLabel *loopLabel;
    QPushButton *loopB;
    QPushButton *startB;
    QPushButton *liveVideoB;
    QSpacerItem *buttonSpacer;
    QSpacerItem *horizontalSpacer_4;
    QPushButton *previewB;
    QCheckBox *darkB;
    QPushButton *pauseB;
    QVBoxLayout *verticalLayout;
    QFrame *processGrid;
    QGridLayout *progressGrid;
    QLabel *jobLabel;
    QLabel *frameInfoLabel;
    QSpacerItem *horizontalSpacer_5;
    QLabel *frameRemainingTime;
    QLabel *avgDownloadTime;
    QLabel *progressLabel;
    QLabel *jobRemainingTime;
    QLabel *avgDownloadLabel;
    QLabel *secLabel;
    Ekos::LedStatusWidget *captureStatusWidget;
    QProgressBar *imgProgress;
    QLabel *targetDriftLabel;
    QLabel *targetDrift;
    QLabel *targetDriftUnit;
    QGroupBox *loadSaveBox;
    QHBoxLayout *loadSaveLayout;
    QSpacerItem *loadSaveSpacer;
    QPushButton *esqLoadB;
    QPushButton *esqSaveAsB;
    QButtonGroup *sequenceControlsButtonGroup;
    QButtonGroup *queueEditButtonGroup;

    void setupUi(QWidget *Camera)
    {
        if (Camera->objectName().isEmpty())
            Camera->setObjectName("Camera");
        Camera->resize(774, 481);
        wholeLayout = new QVBoxLayout(Camera);
        wholeLayout->setSpacing(3);
        wholeLayout->setObjectName("wholeLayout");
        wholeLayout->setContentsMargins(3, 3, 3, 3);
        sequenceEditorComment = new QLabel(Camera);
        sequenceEditorComment->setObjectName("sequenceEditorComment");
        sequenceEditorComment->setEnabled(false);
        sequenceEditorComment->setVisible(false);
        sequenceEditorComment->setProperty("WordWrap", QVariant(true));

        wholeLayout->addWidget(sequenceEditorComment);

        splitter = new QSplitter(Camera);
        splitter->setObjectName("splitter");
        splitter->setEnabled(true);
        splitter->setOrientation(Qt::Horizontal);
        leftLayoutWidget = new QWidget(splitter);
        leftLayoutWidget->setObjectName("leftLayoutWidget");
        leftLayout = new QVBoxLayout(leftLayoutWidget);
        leftLayout->setSpacing(3);
        leftLayout->setObjectName("leftLayout");
        leftLayout->setContentsMargins(0, 0, 0, 0);
        trainLayout = new QHBoxLayout();
        trainLayout->setSpacing(3);
        trainLayout->setObjectName("trainLayout");
        opticalTrainLabel = new QLabel(leftLayoutWidget);
        opticalTrainLabel->setObjectName("opticalTrainLabel");

        trainLayout->addWidget(opticalTrainLabel);

        opticalTrainCombo = new QComboBox(leftLayoutWidget);
        opticalTrainCombo->setObjectName("opticalTrainCombo");
        QSizePolicy sizePolicy(QSizePolicy::Policy::MinimumExpanding, QSizePolicy::Policy::Fixed);
        sizePolicy.setHorizontalStretch(0);
        sizePolicy.setVerticalStretch(0);
        sizePolicy.setHeightForWidth(opticalTrainCombo->sizePolicy().hasHeightForWidth());
        opticalTrainCombo->setSizePolicy(sizePolicy);
        opticalTrainCombo->setMinimumSize(QSize(0, 32));

        trainLayout->addWidget(opticalTrainCombo);

        trainB = new QPushButton(leftLayoutWidget);
        trainB->setObjectName("trainB");
        trainB->setEnabled(false);
        trainB->setMinimumSize(QSize(24, 24));
        trainB->setMaximumSize(QSize(16777215, 32));
        QIcon icon(QIcon::fromTheme(QString::fromUtf8("document-edit")));
        trainB->setIcon(icon);
        trainB->setIconSize(QSize(24, 24));

        trainLayout->addWidget(trainB);

        horizontalSpacer_6 = new QSpacerItem(20, 0, QSizePolicy::Policy::Expanding, QSizePolicy::Policy::Minimum);

        trainLayout->addItem(horizontalSpacer_6);

        restartCameraB = new QPushButton(leftLayoutWidget);
        restartCameraB->setObjectName("restartCameraB");
        restartCameraB->setEnabled(true);
        QSizePolicy sizePolicy1(QSizePolicy::Policy::Minimum, QSizePolicy::Policy::Fixed);
        sizePolicy1.setHorizontalStretch(0);
        sizePolicy1.setVerticalStretch(0);
        sizePolicy1.setHeightForWidth(restartCameraB->sizePolicy().hasHeightForWidth());
        restartCameraB->setSizePolicy(sizePolicy1);
        restartCameraB->setMinimumSize(QSize(24, 24));
        restartCameraB->setMaximumSize(QSize(16777215, 32));
        QIcon icon1(QIcon::fromTheme(QString::fromUtf8("system-shutdown")));
        restartCameraB->setIcon(icon1);
        restartCameraB->setIconSize(QSize(24, 24));

        trainLayout->addWidget(restartCameraB);

        clearConfigurationB = new QPushButton(leftLayoutWidget);
        clearConfigurationB->setObjectName("clearConfigurationB");
        clearConfigurationB->setMinimumSize(QSize(24, 24));
        clearConfigurationB->setMaximumSize(QSize(16777215, 32));
        QIcon icon2(QIcon::fromTheme(QString::fromUtf8("delete")));
        clearConfigurationB->setIcon(icon2);
        clearConfigurationB->setIconSize(QSize(24, 24));

        trainLayout->addWidget(clearConfigurationB);

        resetFrameB = new QPushButton(leftLayoutWidget);
        resetFrameB->setObjectName("resetFrameB");
        sizePolicy1.setHeightForWidth(resetFrameB->sizePolicy().hasHeightForWidth());
        resetFrameB->setSizePolicy(sizePolicy1);
        resetFrameB->setMinimumSize(QSize(24, 24));
        QIcon icon3(QIcon::fromTheme(QString::fromUtf8("edit-reset")));
        resetFrameB->setIcon(icon3);
        resetFrameB->setIconSize(QSize(24, 24));

        trainLayout->addWidget(resetFrameB);

        trainLayout->setStretch(1, 3);

        leftLayout->addLayout(trainLayout);

        CaptureSettingsGroup = new QGroupBox(leftLayoutWidget);
        CaptureSettingsGroup->setObjectName("CaptureSettingsGroup");
        CaptureSettingsGroup->setEnabled(true);
        QSizePolicy sizePolicy2(QSizePolicy::Policy::Preferred, QSizePolicy::Policy::Preferred);
        sizePolicy2.setHorizontalStretch(0);
        sizePolicy2.setVerticalStretch(0);
        sizePolicy2.setHeightForWidth(CaptureSettingsGroup->sizePolicy().hasHeightForWidth());
        CaptureSettingsGroup->setSizePolicy(sizePolicy2);
        CaptureSettingsGroup->setMaximumSize(QSize(16777215, 16777215));
        gridLayout_3 = new QGridLayout(CaptureSettingsGroup);
        gridLayout_3->setSpacing(3);
        gridLayout_3->setObjectName("gridLayout_3");
        gridLayout_3->setContentsMargins(3, 3, 3, 3);
        textLabel1_9 = new QLabel(CaptureSettingsGroup);
        textLabel1_9->setObjectName("textLabel1_9");

        gridLayout_3->addWidget(textLabel1_9, 8, 0, 1, 1);

        formatLayout = new QHBoxLayout();
        formatLayout->setSpacing(1);
        formatLayout->setObjectName("formatLayout");
        captureFormatS = new QComboBox(CaptureSettingsGroup);
        captureFormatS->setObjectName("captureFormatS");

        formatLayout->addWidget(captureFormatS);

        captureEncodingS = new QComboBox(CaptureSettingsGroup);
        captureEncodingS->addItem(QString());
        captureEncodingS->addItem(QString());
        captureEncodingS->setObjectName("captureEncodingS");

        formatLayout->addWidget(captureEncodingS);


        gridLayout_3->addLayout(formatLayout, 4, 2, 1, 1);

        label_7 = new QLabel(CaptureSettingsGroup);
        label_7->setObjectName("label_7");

        gridLayout_3->addWidget(label_7, 4, 0, 1, 1);

        exposureLabel = new QLabel(CaptureSettingsGroup);
        exposureLabel->setObjectName("exposureLabel");

        gridLayout_3->addWidget(exposureLabel, 2, 0, 1, 1);

        filterLayout = new QHBoxLayout();
        filterLayout->setSpacing(2);
        filterLayout->setObjectName("filterLayout");
        FilterPosCombo = new QComboBox(CaptureSettingsGroup);
        FilterPosCombo->setObjectName("FilterPosCombo");
        sizePolicy.setHeightForWidth(FilterPosCombo->sizePolicy().hasHeightForWidth());
        FilterPosCombo->setSizePolicy(sizePolicy);
        FilterPosCombo->setEditable(false);

        filterLayout->addWidget(FilterPosCombo);

        filterManagerB = new QPushButton(CaptureSettingsGroup);
        filterManagerB->setObjectName("filterManagerB");
        filterManagerB->setEnabled(false);
        filterManagerB->setMinimumSize(QSize(24, 24));
        QIcon icon4(QIcon::fromTheme(QString::fromUtf8("view-filter")));
        filterManagerB->setIcon(icon4);
        filterManagerB->setIconSize(QSize(24, 24));

        filterLayout->addWidget(filterManagerB);

        filterEditB = new QPushButton(CaptureSettingsGroup);
        filterEditB->setObjectName("filterEditB");
        filterEditB->setEnabled(false);
        filterEditB->setMinimumSize(QSize(24, 24));
        filterEditB->setMaximumSize(QSize(24, 24));
        filterEditB->setIcon(icon);
        filterEditB->setIconSize(QSize(24, 24));

        filterLayout->addWidget(filterEditB);


        gridLayout_3->addLayout(filterLayout, 2, 4, 1, 1);

        frameSizeLayout = new QHBoxLayout();
        frameSizeLayout->setSpacing(2);
        frameSizeLayout->setObjectName("frameSizeLayout");
        textLabel1_15 = new QLabel(CaptureSettingsGroup);
        textLabel1_15->setObjectName("textLabel1_15");

        frameSizeLayout->addWidget(textLabel1_15);

        captureFrameWN = new QSpinBox(CaptureSettingsGroup);
        captureFrameWN->setObjectName("captureFrameWN");
        QSizePolicy sizePolicy3(QSizePolicy::Policy::Expanding, QSizePolicy::Policy::Fixed);
        sizePolicy3.setHorizontalStretch(0);
        sizePolicy3.setVerticalStretch(0);
        sizePolicy3.setHeightForWidth(captureFrameWN->sizePolicy().hasHeightForWidth());
        captureFrameWN->setSizePolicy(sizePolicy3);
        captureFrameWN->setMaximum(9999);

        frameSizeLayout->addWidget(captureFrameWN);

        textLabel1_16 = new QLabel(CaptureSettingsGroup);
        textLabel1_16->setObjectName("textLabel1_16");

        frameSizeLayout->addWidget(textLabel1_16);

        captureFrameHN = new QSpinBox(CaptureSettingsGroup);
        captureFrameHN->setObjectName("captureFrameHN");
        sizePolicy3.setHeightForWidth(captureFrameHN->sizePolicy().hasHeightForWidth());
        captureFrameHN->setSizePolicy(sizePolicy3);
        captureFrameHN->setMaximum(9999);

        frameSizeLayout->addWidget(captureFrameHN);


        gridLayout_3->addLayout(frameSizeLayout, 7, 2, 1, 1);

        coolerOnOffLayout = new QHBoxLayout();
        coolerOnOffLayout->setSpacing(3);
        coolerOnOffLayout->setObjectName("coolerOnOffLayout");
        coolerOnB = new QPushButton(CaptureSettingsGroup);
        coolerOnB->setObjectName("coolerOnB");
        coolerOnB->setEnabled(false);
        QSizePolicy sizePolicy4(QSizePolicy::Policy::Preferred, QSizePolicy::Policy::Fixed);
        sizePolicy4.setHorizontalStretch(0);
        sizePolicy4.setVerticalStretch(0);
        sizePolicy4.setHeightForWidth(coolerOnB->sizePolicy().hasHeightForWidth());
        coolerOnB->setSizePolicy(sizePolicy4);
        coolerOnB->setMinimumSize(QSize(28, 28));
        coolerOnB->setMaximumSize(QSize(16777215, 28));
        coolerOnB->setStyleSheet(QString::fromUtf8("QPushButton:checked\n"
"{\n"
"background-color: maroon;\n"
"border: 1px outset;\n"
"font-weight:bold;\n"
"}"));
        coolerOnB->setCheckable(true);

        coolerOnOffLayout->addWidget(coolerOnB);

        coolerOffB = new QPushButton(CaptureSettingsGroup);
        coolerOffB->setObjectName("coolerOffB");
        coolerOffB->setEnabled(false);
        sizePolicy4.setHeightForWidth(coolerOffB->sizePolicy().hasHeightForWidth());
        coolerOffB->setSizePolicy(sizePolicy4);
        coolerOffB->setMinimumSize(QSize(28, 28));
        coolerOffB->setMaximumSize(QSize(16777215, 28));
        coolerOffB->setStyleSheet(QString::fromUtf8("QPushButton:checked\n"
"{\n"
"background-color: maroon;\n"
"border: 1px outset;\n"
"font-weight:bold;\n"
"}"));
        coolerOffB->setCheckable(true);

        coolerOnOffLayout->addWidget(coolerOffB);


        gridLayout_3->addLayout(coolerOnOffLayout, 1, 2, 1, 1);

        binningLayout = new QHBoxLayout();
        binningLayout->setSpacing(2);
        binningLayout->setObjectName("binningLayout");
        captureBinXLabel = new QLabel(CaptureSettingsGroup);
        captureBinXLabel->setObjectName("captureBinXLabel");

        binningLayout->addWidget(captureBinXLabel);

        captureBinHN = new QSpinBox(CaptureSettingsGroup);
        captureBinHN->setObjectName("captureBinHN");
        sizePolicy.setHeightForWidth(captureBinHN->sizePolicy().hasHeightForWidth());
        captureBinHN->setSizePolicy(sizePolicy);
        captureBinHN->setMinimum(1);
        captureBinHN->setMaximum(10);
        captureBinHN->setValue(1);

        binningLayout->addWidget(captureBinHN);

        captureBinYLabel = new QLabel(CaptureSettingsGroup);
        captureBinYLabel->setObjectName("captureBinYLabel");

        binningLayout->addWidget(captureBinYLabel);

        captureBinVN = new QSpinBox(CaptureSettingsGroup);
        captureBinVN->setObjectName("captureBinVN");
        sizePolicy.setHeightForWidth(captureBinVN->sizePolicy().hasHeightForWidth());
        captureBinVN->setSizePolicy(sizePolicy);
        captureBinVN->setMinimum(1);
        captureBinVN->setMaximum(10);
        captureBinVN->setValue(1);

        binningLayout->addWidget(captureBinVN);


        gridLayout_3->addLayout(binningLayout, 8, 2, 1, 1);

        textLabel1_19 = new QLabel(CaptureSettingsGroup);
        textLabel1_19->setObjectName("textLabel1_19");

        gridLayout_3->addWidget(textLabel1_19, 7, 0, 1, 1);

        textLabel1_12 = new QLabel(CaptureSettingsGroup);
        textLabel1_12->setObjectName("textLabel1_12");

        gridLayout_3->addWidget(textLabel1_12, 6, 0, 1, 1);

        coolerLabel = new QLabel(CaptureSettingsGroup);
        coolerLabel->setObjectName("coolerLabel");

        gridLayout_3->addWidget(coolerLabel, 1, 0, 1, 1);

        FilterPosLabel = new QLabel(CaptureSettingsGroup);
        FilterPosLabel->setObjectName("FilterPosLabel");

        gridLayout_3->addWidget(FilterPosLabel, 2, 3, 1, 1);

        FrameXYLayout = new QHBoxLayout();
        FrameXYLayout->setSpacing(2);
        FrameXYLayout->setObjectName("FrameXYLayout");
        textLabel1_13 = new QLabel(CaptureSettingsGroup);
        textLabel1_13->setObjectName("textLabel1_13");

        FrameXYLayout->addWidget(textLabel1_13);

        captureFrameXN = new QSpinBox(CaptureSettingsGroup);
        captureFrameXN->setObjectName("captureFrameXN");
        sizePolicy3.setHeightForWidth(captureFrameXN->sizePolicy().hasHeightForWidth());
        captureFrameXN->setSizePolicy(sizePolicy3);

        FrameXYLayout->addWidget(captureFrameXN);

        textLabel1_14 = new QLabel(CaptureSettingsGroup);
        textLabel1_14->setObjectName("textLabel1_14");

        FrameXYLayout->addWidget(textLabel1_14);

        captureFrameYN = new QSpinBox(CaptureSettingsGroup);
        captureFrameYN->setObjectName("captureFrameYN");
        sizePolicy3.setHeightForWidth(captureFrameYN->sizePolicy().hasHeightForWidth());
        captureFrameYN->setSizePolicy(sizePolicy3);

        FrameXYLayout->addWidget(captureFrameYN);


        gridLayout_3->addLayout(FrameXYLayout, 6, 2, 1, 1);

        captureExposureN = new NonLinearDoubleSpinBox(CaptureSettingsGroup);
        captureExposureN->setObjectName("captureExposureN");
        sizePolicy.setHeightForWidth(captureExposureN->sizePolicy().hasHeightForWidth());
        captureExposureN->setSizePolicy(sizePolicy);
        captureExposureN->setDecimals(3);
        captureExposureN->setMinimum(0.001000000000000);
        captureExposureN->setMaximum(3600.000000000000000);
        captureExposureN->setValue(1.000000000000000);

        gridLayout_3->addWidget(captureExposureN, 2, 2, 1, 1);

        textLabel1_17 = new QLabel(CaptureSettingsGroup);
        textLabel1_17->setObjectName("textLabel1_17");

        gridLayout_3->addWidget(textLabel1_17, 5, 0, 1, 1);

        captureTypeS = new QComboBox(CaptureSettingsGroup);
        captureTypeS->setObjectName("captureTypeS");
        sizePolicy.setHeightForWidth(captureTypeS->sizePolicy().hasHeightForWidth());
        captureTypeS->setSizePolicy(sizePolicy);

        gridLayout_3->addWidget(captureTypeS, 5, 2, 1, 1);

        ISOLabel = new QLabel(CaptureSettingsGroup);
        ISOLabel->setObjectName("ISOLabel");
        ISOLabel->setAlignment(Qt::AlignLeading|Qt::AlignLeft|Qt::AlignVCenter);

        gridLayout_3->addWidget(ISOLabel, 3, 3, 1, 1);

        captureISOS = new QComboBox(CaptureSettingsGroup);
        captureISOS->setObjectName("captureISOS");

        gridLayout_3->addWidget(captureISOS, 3, 4, 1, 1);

        textLabel1_21 = new QLabel(CaptureSettingsGroup);
        textLabel1_21->setObjectName("textLabel1_21");

        gridLayout_3->addWidget(textLabel1_21, 4, 3, 1, 1);

        gainLayout = new QHBoxLayout();
        gainLayout->setSpacing(2);
        gainLayout->setObjectName("gainLayout");
        currentGainLabel = new QLabel(CaptureSettingsGroup);
        currentGainLabel->setObjectName("currentGainLabel");
        currentGainLabel->setMinimumSize(QSize(50, 0));
        currentGainLabel->setAlignment(Qt::AlignRight|Qt::AlignTrailing|Qt::AlignVCenter);

        gainLayout->addWidget(currentGainLabel);

        captureGainN = new QDoubleSpinBox(CaptureSettingsGroup);
        captureGainN->setObjectName("captureGainN");
        sizePolicy.setHeightForWidth(captureGainN->sizePolicy().hasHeightForWidth());
        captureGainN->setSizePolicy(sizePolicy);
        captureGainN->setDecimals(1);
        captureGainN->setMaximum(10000.000000000000000);
        captureGainN->setSingleStep(10.000000000000000);

        gainLayout->addWidget(captureGainN);


        gridLayout_3->addLayout(gainLayout, 4, 4, 1, 1);

        textLabel1_20 = new QLabel(CaptureSettingsGroup);
        textLabel1_20->setObjectName("textLabel1_20");

        gridLayout_3->addWidget(textLabel1_20, 5, 3, 1, 1);

        offsetLayout = new QHBoxLayout();
        offsetLayout->setSpacing(2);
        offsetLayout->setObjectName("offsetLayout");
        currentOffsetLabel = new QLabel(CaptureSettingsGroup);
        currentOffsetLabel->setObjectName("currentOffsetLabel");
        currentOffsetLabel->setMinimumSize(QSize(50, 0));
        currentOffsetLabel->setAlignment(Qt::AlignRight|Qt::AlignTrailing|Qt::AlignVCenter);

        offsetLayout->addWidget(currentOffsetLabel);

        captureOffsetN = new QDoubleSpinBox(CaptureSettingsGroup);
        captureOffsetN->setObjectName("captureOffsetN");
        sizePolicy.setHeightForWidth(captureOffsetN->sizePolicy().hasHeightForWidth());
        captureOffsetN->setSizePolicy(sizePolicy);
        captureOffsetN->setDecimals(1);
        captureOffsetN->setMaximum(10000.000000000000000);
        captureOffsetN->setSingleStep(10.000000000000000);

        offsetLayout->addWidget(captureOffsetN);


        gridLayout_3->addLayout(offsetLayout, 5, 4, 1, 1);

        toolsLayout = new QWidget(CaptureSettingsGroup);
        toolsLayout->setObjectName("toolsLayout");
        gridLayout = new QGridLayout(toolsLayout);
        gridLayout->setObjectName("gridLayout");
        gridLayout->setHorizontalSpacing(3);
        gridLayout->setVerticalSpacing(0);
        gridLayout->setContentsMargins(0, 3, 0, 0);
        darksLibraryLabel = new QLabel(toolsLayout);
        darksLibraryLabel->setObjectName("darksLibraryLabel");
        QFont font;
        font.setPointSize(7);
        darksLibraryLabel->setFont(font);
        darksLibraryLabel->setAlignment(Qt::AlignCenter);

        gridLayout->addWidget(darksLibraryLabel, 1, 5, 1, 1);

        rotatorLabel = new QLabel(toolsLayout);
        rotatorLabel->setObjectName("rotatorLabel");
        rotatorLabel->setFont(font);
        rotatorLabel->setAlignment(Qt::AlignCenter);

        gridLayout->addWidget(rotatorLabel, 1, 3, 1, 1);

        verticalSpacer_2 = new QSpacerItem(20, 6, QSizePolicy::Policy::Minimum, QSizePolicy::Policy::Expanding);

        gridLayout->addItem(verticalSpacer_2, 2, 4, 1, 1);

        rotatorB = new QPushButton(toolsLayout);
        rotatorB->setObjectName("rotatorB");
        rotatorB->setEnabled(false);
        sizePolicy2.setHeightForWidth(rotatorB->sizePolicy().hasHeightForWidth());
        rotatorB->setSizePolicy(sizePolicy2);
        rotatorB->setMinimumSize(QSize(24, 24));
        rotatorB->setMaximumSize(QSize(48, 28));
        QIcon icon5(QIcon::fromTheme(QString::fromUtf8("rotation-allowed")));
        rotatorB->setIcon(icon5);
        rotatorB->setIconSize(QSize(28, 28));

        gridLayout->addWidget(rotatorB, 0, 3, 1, 1);

        exposureCalculationLabel = new QLabel(toolsLayout);
        exposureCalculationLabel->setObjectName("exposureCalculationLabel");
        exposureCalculationLabel->setFont(font);
        exposureCalculationLabel->setAlignment(Qt::AlignCenter);

        gridLayout->addWidget(exposureCalculationLabel, 1, 4, 1, 1);

        darkLibraryB = new QPushButton(toolsLayout);
        darkLibraryB->setObjectName("darkLibraryB");
        sizePolicy2.setHeightForWidth(darkLibraryB->sizePolicy().hasHeightForWidth());
        darkLibraryB->setSizePolicy(sizePolicy2);
        darkLibraryB->setMaximumSize(QSize(48, 28));
        QIcon icon6(QIcon::fromTheme(QString::fromUtf8("lighttable")));
        darkLibraryB->setIcon(icon6);
        darkLibraryB->setIconSize(QSize(28, 28));

        gridLayout->addWidget(darkLibraryB, 0, 5, 1, 1);

        exposureCalcB = new QPushButton(toolsLayout);
        exposureCalcB->setObjectName("exposureCalcB");
        sizePolicy2.setHeightForWidth(exposureCalcB->sizePolicy().hasHeightForWidth());
        exposureCalcB->setSizePolicy(sizePolicy2);
        exposureCalcB->setMinimumSize(QSize(24, 24));
        exposureCalcB->setMaximumSize(QSize(48, 28));
        QIcon icon7(QIcon::fromTheme(QString::fromUtf8("clock")));
        exposureCalcB->setIcon(icon7);
        exposureCalcB->setIconSize(QSize(28, 28));

        gridLayout->addWidget(exposureCalcB, 0, 4, 1, 1);

        calibrationB = new QPushButton(toolsLayout);
        calibrationB->setObjectName("calibrationB");
        calibrationB->setEnabled(true);
        sizePolicy2.setHeightForWidth(calibrationB->sizePolicy().hasHeightForWidth());
        calibrationB->setSizePolicy(sizePolicy2);
        calibrationB->setMinimumSize(QSize(24, 24));
        calibrationB->setMaximumSize(QSize(48, 28));
        calibrationB->setIcon(icon6);
        calibrationB->setIconSize(QSize(28, 28));

        gridLayout->addWidget(calibrationB, 0, 6, 1, 1);

        calibrationLabel = new QLabel(toolsLayout);
        calibrationLabel->setObjectName("calibrationLabel");
        calibrationLabel->setFont(font);
        calibrationLabel->setAlignment(Qt::AlignCenter);

        gridLayout->addWidget(calibrationLabel, 1, 6, 1, 1);

        generateDarkFlatsB = new QPushButton(toolsLayout);
        generateDarkFlatsB->setObjectName("generateDarkFlatsB");
        generateDarkFlatsB->setEnabled(false);
        sizePolicy2.setHeightForWidth(generateDarkFlatsB->sizePolicy().hasHeightForWidth());
        generateDarkFlatsB->setSizePolicy(sizePolicy2);
        generateDarkFlatsB->setMinimumSize(QSize(24, 24));
        generateDarkFlatsB->setMaximumSize(QSize(48, 28));
        QIcon icon8(QIcon::fromTheme(QString::fromUtf8("tools-wizard")));
        generateDarkFlatsB->setIcon(icon8);
        generateDarkFlatsB->setIconSize(QSize(28, 28));

        gridLayout->addWidget(generateDarkFlatsB, 3, 3, 1, 1);

        darksFlatsLabel = new QLabel(toolsLayout);
        darksFlatsLabel->setObjectName("darksFlatsLabel");
        darksFlatsLabel->setFont(font);
        darksFlatsLabel->setAlignment(Qt::AlignCenter);

        gridLayout->addWidget(darksFlatsLabel, 4, 3, 1, 1);

        customValuesB = new QPushButton(toolsLayout);
        customValuesB->setObjectName("customValuesB");
        sizePolicy2.setHeightForWidth(customValuesB->sizePolicy().hasHeightForWidth());
        customValuesB->setSizePolicy(sizePolicy2);
        customValuesB->setMinimumSize(QSize(24, 24));
        customValuesB->setMaximumSize(QSize(48, 28));
        QIcon icon9(QIcon::fromTheme(QString::fromUtf8("document-properties")));
        customValuesB->setIcon(icon9);
        customValuesB->setIconSize(QSize(28, 28));

        gridLayout->addWidget(customValuesB, 3, 4, 1, 1);

        customValuesLabel = new QLabel(toolsLayout);
        customValuesLabel->setObjectName("customValuesLabel");
        customValuesLabel->setFont(font);
        customValuesLabel->setAlignment(Qt::AlignCenter);

        gridLayout->addWidget(customValuesLabel, 4, 4, 1, 1);

        limitsB = new QPushButton(toolsLayout);
        limitsB->setObjectName("limitsB");
        limitsB->setMaximumSize(QSize(48, 28));
        QIcon icon10(QIcon::fromTheme(QString::fromUtf8("firewall-applet-panic")));
        limitsB->setIcon(icon10);
        limitsB->setIconSize(QSize(28, 28));

        gridLayout->addWidget(limitsB, 3, 5, 1, 1);

        limitsLabel = new QLabel(toolsLayout);
        limitsLabel->setObjectName("limitsLabel");
        limitsLabel->setFont(font);
        limitsLabel->setAlignment(Qt::AlignCenter);

        gridLayout->addWidget(limitsLabel, 4, 5, 1, 1);

        scriptManagerB = new QPushButton(toolsLayout);
        scriptManagerB->setObjectName("scriptManagerB");
        QSizePolicy sizePolicy5(QSizePolicy::Policy::Minimum, QSizePolicy::Policy::Preferred);
        sizePolicy5.setHorizontalStretch(0);
        sizePolicy5.setVerticalStretch(0);
        sizePolicy5.setHeightForWidth(scriptManagerB->sizePolicy().hasHeightForWidth());
        scriptManagerB->setSizePolicy(sizePolicy5);
        scriptManagerB->setMaximumSize(QSize(48, 28));
        QIcon icon11(QIcon::fromTheme(QString::fromUtf8("dialog-scripts")));
        scriptManagerB->setIcon(icon11);
        scriptManagerB->setIconSize(QSize(28, 28));

        gridLayout->addWidget(scriptManagerB, 3, 6, 1, 1);

        scriptsLabel = new QLabel(toolsLayout);
        scriptsLabel->setObjectName("scriptsLabel");
        scriptsLabel->setFont(font);
        scriptsLabel->setAlignment(Qt::AlignCenter);

        gridLayout->addWidget(scriptsLabel, 4, 6, 1, 1);

        horizontalSpacer_7 = new QSpacerItem(40, 20, QSizePolicy::Policy::Expanding, QSizePolicy::Policy::Minimum);

        gridLayout->addItem(horizontalSpacer_7, 0, 0, 1, 1);


        gridLayout_3->addWidget(toolsLayout, 6, 3, 3, 2);

        coolerLayout = new QHBoxLayout();
        coolerLayout->setSpacing(3);
        coolerLayout->setObjectName("coolerLayout");
        temperatureOUT = new QLabel(CaptureSettingsGroup);
        temperatureOUT->setObjectName("temperatureOUT");
        sizePolicy4.setHeightForWidth(temperatureOUT->sizePolicy().hasHeightForWidth());
        temperatureOUT->setSizePolicy(sizePolicy4);
        temperatureOUT->setMinimumSize(QSize(28, 28));
        temperatureOUT->setMaximumSize(QSize(16777215, 28));
        temperatureOUT->setAlignment(Qt::AlignLeading|Qt::AlignLeft|Qt::AlignVCenter);

        coolerLayout->addWidget(temperatureOUT);

        cameraTemperatureN = new QDoubleSpinBox(CaptureSettingsGroup);
        cameraTemperatureN->setObjectName("cameraTemperatureN");
        cameraTemperatureN->setEnabled(false);
        QSizePolicy sizePolicy6(QSizePolicy::Policy::Preferred, QSizePolicy::Policy::Fixed);
        sizePolicy6.setHorizontalStretch(0);
        sizePolicy6.setVerticalStretch(1);
        sizePolicy6.setHeightForWidth(cameraTemperatureN->sizePolicy().hasHeightForWidth());
        cameraTemperatureN->setSizePolicy(sizePolicy6);
        cameraTemperatureN->setMinimumSize(QSize(28, 28));
        cameraTemperatureN->setMaximumSize(QSize(16777215, 28));
        cameraTemperatureN->setDecimals(1);

        coolerLayout->addWidget(cameraTemperatureN);

        cameraTemperatureS = new QCheckBox(CaptureSettingsGroup);
        cameraTemperatureS->setObjectName("cameraTemperatureS");
        QSizePolicy sizePolicy7(QSizePolicy::Policy::Fixed, QSizePolicy::Policy::Fixed);
        sizePolicy7.setHorizontalStretch(0);
        sizePolicy7.setVerticalStretch(0);
        sizePolicy7.setHeightForWidth(cameraTemperatureS->sizePolicy().hasHeightForWidth());
        cameraTemperatureS->setSizePolicy(sizePolicy7);
        cameraTemperatureS->setMinimumSize(QSize(28, 28));
        cameraTemperatureS->setMaximumSize(QSize(16777215, 28));
        cameraTemperatureS->setChecked(false);

        coolerLayout->addWidget(cameraTemperatureS);

        setTemperatureB = new QPushButton(CaptureSettingsGroup);
        setTemperatureB->setObjectName("setTemperatureB");
        setTemperatureB->setEnabled(false);
        sizePolicy7.setHeightForWidth(setTemperatureB->sizePolicy().hasHeightForWidth());
        setTemperatureB->setSizePolicy(sizePolicy7);
        setTemperatureB->setMinimumSize(QSize(28, 28));
        setTemperatureB->setMaximumSize(QSize(28, 28));
        QIcon icon12(QIcon::fromTheme(QString::fromUtf8("checkmark")));
        setTemperatureB->setIcon(icon12);
        setTemperatureB->setIconSize(QSize(24, 24));

        coolerLayout->addWidget(setTemperatureB);

        temperatureRegulationB = new QPushButton(CaptureSettingsGroup);
        temperatureRegulationB->setObjectName("temperatureRegulationB");
        sizePolicy7.setHeightForWidth(temperatureRegulationB->sizePolicy().hasHeightForWidth());
        temperatureRegulationB->setSizePolicy(sizePolicy7);
        temperatureRegulationB->setMinimumSize(QSize(28, 28));
        temperatureRegulationB->setMaximumSize(QSize(28, 28));
        QIcon icon13(QIcon::fromTheme(QString::fromUtf8("colors-chromablue")));
        temperatureRegulationB->setIcon(icon13);
        temperatureRegulationB->setIconSize(QSize(24, 24));

        coolerLayout->addWidget(temperatureRegulationB);


        gridLayout_3->addLayout(coolerLayout, 1, 4, 1, 1);

        exposureOptions = new QStackedWidget(CaptureSettingsGroup);
        exposureOptions->setObjectName("exposureOptions");
        frameExposureOptions = new QWidget();
        frameExposureOptions->setObjectName("frameExposureOptions");
        horizontalLayout_3 = new QHBoxLayout(frameExposureOptions);
        horizontalLayout_3->setSpacing(3);
        horizontalLayout_3->setObjectName("horizontalLayout_3");
        horizontalLayout_3->setContentsMargins(0, 0, 0, 0);
        captureCountN = new QSpinBox(frameExposureOptions);
        captureCountN->setObjectName("captureCountN");
        sizePolicy.setHeightForWidth(captureCountN->sizePolicy().hasHeightForWidth());
        captureCountN->setSizePolicy(sizePolicy);
        captureCountN->setMinimum(1);
        captureCountN->setMaximum(100000);
        captureCountN->setValue(1);

        horizontalLayout_3->addWidget(captureCountN);

        textLabel1_8 = new QLabel(frameExposureOptions);
        textLabel1_8->setObjectName("textLabel1_8");

        horizontalLayout_3->addWidget(textLabel1_8);

        captureDelayN = new QSpinBox(frameExposureOptions);
        captureDelayN->setObjectName("captureDelayN");
        sizePolicy.setHeightForWidth(captureDelayN->sizePolicy().hasHeightForWidth());
        captureDelayN->setSizePolicy(sizePolicy);
        captureDelayN->setMaximum(3600);

        horizontalLayout_3->addWidget(captureDelayN);

        horizontalLayout_3->setStretch(2, 1);
        exposureOptions->addWidget(frameExposureOptions);
        videoExposureOptions = new QWidget();
        videoExposureOptions->setObjectName("videoExposureOptions");
        horizontalLayout_4 = new QHBoxLayout(videoExposureOptions);
        horizontalLayout_4->setSpacing(3);
        horizontalLayout_4->setObjectName("horizontalLayout_4");
        horizontalLayout_4->setContentsMargins(0, 0, 0, 0);
        videoDurationSB = new QDoubleSpinBox(videoExposureOptions);
        videoDurationSB->setObjectName("videoDurationSB");
        videoDurationSB->setMinimum(0.010000000000000);
        videoDurationSB->setMaximum(99999999.000000000000000);
        videoDurationSB->setValue(60.000000000000000);

        horizontalLayout_4->addWidget(videoDurationSB);

        videoDurationUnitCB = new QComboBox(videoExposureOptions);
        videoDurationUnitCB->setObjectName("videoDurationUnitCB");

        horizontalLayout_4->addWidget(videoDurationUnitCB);

        exposureOptions->addWidget(videoExposureOptions);

        gridLayout_3->addWidget(exposureOptions, 3, 2, 1, 1);

        exposureOptionsLabel = new QLabel(CaptureSettingsGroup);
        exposureOptionsLabel->setObjectName("exposureOptionsLabel");

        gridLayout_3->addWidget(exposureOptionsLabel, 3, 0, 1, 1);

        gridLayout_3->setColumnStretch(2, 1);
        gridLayout_3->setColumnStretch(4, 1);

        leftLayout->addWidget(CaptureSettingsGroup);

        fileSettingsGroup = new QGroupBox(leftLayoutWidget);
        fileSettingsGroup->setObjectName("fileSettingsGroup");
        gridLayout_4 = new QGridLayout(fileSettingsGroup);
        gridLayout_4->setSpacing(3);
        gridLayout_4->setObjectName("gridLayout_4");
        gridLayout_4->setContentsMargins(3, 3, 3, 3);
        fileUploadModeS = new QComboBox(fileSettingsGroup);
        fileUploadModeS->addItem(QString());
        fileUploadModeS->addItem(QString());
        fileUploadModeS->addItem(QString());
        fileUploadModeS->setObjectName("fileUploadModeS");
        sizePolicy3.setHeightForWidth(fileUploadModeS->sizePolicy().hasHeightForWidth());
        fileUploadModeS->setSizePolicy(sizePolicy3);

        gridLayout_4->addWidget(fileUploadModeS, 3, 1, 1, 1);

        fileDirectoryT = new QLineEdit(fileSettingsGroup);
        fileDirectoryT->setObjectName("fileDirectoryT");

        gridLayout_4->addWidget(fileDirectoryT, 1, 1, 1, 4);

        targetNameT = new QLineEdit(fileSettingsGroup);
        targetNameT->setObjectName("targetNameT");
        targetNameT->setClearButtonEnabled(true);

        gridLayout_4->addWidget(targetNameT, 0, 1, 1, 5);

        textLabel1_18 = new QLabel(fileSettingsGroup);
        textLabel1_18->setObjectName("textLabel1_18");

        gridLayout_4->addWidget(textLabel1_18, 1, 0, 1, 1);

        resetFormatB = new QPushButton(fileSettingsGroup);
        resetFormatB->setObjectName("resetFormatB");
        sizePolicy1.setHeightForWidth(resetFormatB->sizePolicy().hasHeightForWidth());
        resetFormatB->setSizePolicy(sizePolicy1);
        resetFormatB->setMinimumSize(QSize(24, 24));
        resetFormatB->setMaximumSize(QSize(16777215, 32));
        QIcon icon14(QIcon::fromTheme(QString::fromUtf8("edit-clear")));
        resetFormatB->setIcon(icon14);
        resetFormatB->setIconSize(QSize(24, 24));

        gridLayout_4->addWidget(resetFormatB, 2, 2, 1, 1);

        textLabel1_7 = new QLabel(fileSettingsGroup);
        textLabel1_7->setObjectName("textLabel1_7");

        gridLayout_4->addWidget(textLabel1_7, 0, 0, 1, 1);

        fileRemoteDirT = new QLineEdit(fileSettingsGroup);
        fileRemoteDirT->setObjectName("fileRemoteDirT");
        fileRemoteDirT->setEnabled(false);

        gridLayout_4->addWidget(fileRemoteDirT, 3, 4, 1, 2);

        label_4 = new QLabel(fileSettingsGroup);
        label_4->setObjectName("label_4");

        gridLayout_4->addWidget(label_4, 3, 0, 1, 1);

        placeholderFormatT = new QLineEdit(fileSettingsGroup);
        placeholderFormatT->setObjectName("placeholderFormatT");

        gridLayout_4->addWidget(placeholderFormatT, 2, 1, 1, 1);

        formatSuffixN = new QSpinBox(fileSettingsGroup);
        formatSuffixN->setObjectName("formatSuffixN");
        formatSuffixN->setMinimum(1);
        formatSuffixN->setMaximum(9);
        formatSuffixN->setValue(3);

        gridLayout_4->addWidget(formatSuffixN, 2, 4, 1, 2);

        formatLabel = new QLabel(fileSettingsGroup);
        formatLabel->setObjectName("formatLabel");

        gridLayout_4->addWidget(formatLabel, 2, 0, 1, 1);

        selectFileDirectoryB = new QPushButton(fileSettingsGroup);
        selectFileDirectoryB->setObjectName("selectFileDirectoryB");
        sizePolicy7.setHeightForWidth(selectFileDirectoryB->sizePolicy().hasHeightForWidth());
        selectFileDirectoryB->setSizePolicy(sizePolicy7);
        selectFileDirectoryB->setMinimumSize(QSize(32, 32));
        selectFileDirectoryB->setMaximumSize(QSize(32, 32));

        gridLayout_4->addWidget(selectFileDirectoryB, 1, 5, 1, 1);

        remoteLabel = new QLabel(fileSettingsGroup);
        remoteLabel->setObjectName("remoteLabel");
        remoteLabel->setAlignment(Qt::AlignRight|Qt::AlignTrailing|Qt::AlignVCenter);

        gridLayout_4->addWidget(remoteLabel, 3, 2, 1, 1);


        leftLayout->addWidget(fileSettingsGroup);

        countDelayLayout = new QHBoxLayout();
        countDelayLayout->setObjectName("countDelayLayout");

        leftLayout->addLayout(countDelayLayout);

        verticalSpacer = new QSpacerItem(20, 40, QSizePolicy::Policy::Minimum, QSizePolicy::Policy::Expanding);

        leftLayout->addItem(verticalSpacer);

        splitter->addWidget(leftLayoutWidget);
        rightLayoutWidget = new QWidget(splitter);
        rightLayoutWidget->setObjectName("rightLayoutWidget");
        RightLayout = new QVBoxLayout(rightLayoutWidget);
        RightLayout->setSpacing(2);
        RightLayout->setObjectName("RightLayout");
        RightLayout->setContentsMargins(0, 0, 0, 0);
        SequenceQueue = new QVBoxLayout();
        SequenceQueue->setSpacing(1);
        SequenceQueue->setObjectName("SequenceQueue");
        sequenceBox = new QGroupBox(rightLayoutWidget);
        sequenceBox->setObjectName("sequenceBox");
        QSizePolicy sizePolicy8(QSizePolicy::Policy::Expanding, QSizePolicy::Policy::Expanding);
        sizePolicy8.setHorizontalStretch(0);
        sizePolicy8.setVerticalStretch(0);
        sizePolicy8.setHeightForWidth(sequenceBox->sizePolicy().hasHeightForWidth());
        sequenceBox->setSizePolicy(sizePolicy8);
        verticalLayout_8 = new QVBoxLayout(sequenceBox);
        verticalLayout_8->setSpacing(1);
        verticalLayout_8->setObjectName("verticalLayout_8");
        verticalLayout_8->setContentsMargins(2, 2, 2, 2);
        horizontalLayout_14 = new QHBoxLayout();
        horizontalLayout_14->setSpacing(1);
        horizontalLayout_14->setObjectName("horizontalLayout_14");
        addToQueueB = new QPushButton(sequenceBox);
        queueEditButtonGroup = new QButtonGroup(Camera);
        queueEditButtonGroup->setObjectName("queueEditButtonGroup");
        queueEditButtonGroup->setExclusive(false);
        queueEditButtonGroup->addButton(addToQueueB);
        addToQueueB->setObjectName("addToQueueB");
        sizePolicy7.setHeightForWidth(addToQueueB->sizePolicy().hasHeightForWidth());
        addToQueueB->setSizePolicy(sizePolicy7);
        addToQueueB->setMinimumSize(QSize(32, 32));
        addToQueueB->setMaximumSize(QSize(32, 32));

        horizontalLayout_14->addWidget(addToQueueB);

        removeFromQueueB = new QPushButton(sequenceBox);
        queueEditButtonGroup->addButton(removeFromQueueB);
        removeFromQueueB->setObjectName("removeFromQueueB");
        removeFromQueueB->setEnabled(false);
        sizePolicy7.setHeightForWidth(removeFromQueueB->sizePolicy().hasHeightForWidth());
        removeFromQueueB->setSizePolicy(sizePolicy7);
        removeFromQueueB->setMinimumSize(QSize(32, 32));
        removeFromQueueB->setMaximumSize(QSize(32, 32));

        horizontalLayout_14->addWidget(removeFromQueueB);

        horizontalSpacer_SQ1 = new QSpacerItem(40, 20, QSizePolicy::Policy::Expanding, QSizePolicy::Policy::Minimum);

        horizontalLayout_14->addItem(horizontalSpacer_SQ1);

        queueUpB = new QPushButton(sequenceBox);
        queueEditButtonGroup->addButton(queueUpB);
        queueUpB->setObjectName("queueUpB");
        queueUpB->setEnabled(false);
        sizePolicy7.setHeightForWidth(queueUpB->sizePolicy().hasHeightForWidth());
        queueUpB->setSizePolicy(sizePolicy7);
        queueUpB->setMinimumSize(QSize(32, 32));
        queueUpB->setMaximumSize(QSize(32, 32));

        horizontalLayout_14->addWidget(queueUpB);

        queueDownB = new QPushButton(sequenceBox);
        queueEditButtonGroup->addButton(queueDownB);
        queueDownB->setObjectName("queueDownB");
        queueDownB->setEnabled(false);
        sizePolicy7.setHeightForWidth(queueDownB->sizePolicy().hasHeightForWidth());
        queueDownB->setSizePolicy(sizePolicy7);
        queueDownB->setMinimumSize(QSize(32, 32));
        queueDownB->setMaximumSize(QSize(32, 32));

        horizontalLayout_14->addWidget(queueDownB);

        resetB = new QPushButton(sequenceBox);
        queueEditButtonGroup->addButton(resetB);
        resetB->setObjectName("resetB");
        resetB->setEnabled(false);
        sizePolicy7.setHeightForWidth(resetB->sizePolicy().hasHeightForWidth());
        resetB->setSizePolicy(sizePolicy7);
        resetB->setMinimumSize(QSize(32, 32));
        resetB->setMaximumSize(QSize(32, 32));

        horizontalLayout_14->addWidget(resetB);

        observerB = new QPushButton(sequenceBox);
        observerB->setObjectName("observerB");
        observerB->setMinimumSize(QSize(32, 32));
        observerB->setMaximumSize(QSize(32, 32));

        horizontalLayout_14->addWidget(observerB);

        horizontalSpacer_SQ2 = new QSpacerItem(40, 20, QSizePolicy::Policy::Expanding, QSizePolicy::Policy::Minimum);

        horizontalLayout_14->addItem(horizontalSpacer_SQ2);

        queueLoadB = new QPushButton(sequenceBox);
        queueEditButtonGroup->addButton(queueLoadB);
        queueLoadB->setObjectName("queueLoadB");
        sizePolicy7.setHeightForWidth(queueLoadB->sizePolicy().hasHeightForWidth());
        queueLoadB->setSizePolicy(sizePolicy7);
        queueLoadB->setMinimumSize(QSize(32, 32));
        queueLoadB->setMaximumSize(QSize(32, 32));

        horizontalLayout_14->addWidget(queueLoadB);

        queueSaveB = new QPushButton(sequenceBox);
        queueEditButtonGroup->addButton(queueSaveB);
        queueSaveB->setObjectName("queueSaveB");
        queueSaveB->setEnabled(false);
        sizePolicy7.setHeightForWidth(queueSaveB->sizePolicy().hasHeightForWidth());
        queueSaveB->setSizePolicy(sizePolicy7);
        queueSaveB->setMinimumSize(QSize(32, 32));
        queueSaveB->setMaximumSize(QSize(32, 32));

        horizontalLayout_14->addWidget(queueSaveB);

        queueSaveAsB = new QPushButton(sequenceBox);
        queueEditButtonGroup->addButton(queueSaveAsB);
        queueSaveAsB->setObjectName("queueSaveAsB");
        queueSaveAsB->setEnabled(false);
        sizePolicy7.setHeightForWidth(queueSaveAsB->sizePolicy().hasHeightForWidth());
        queueSaveAsB->setSizePolicy(sizePolicy7);
        queueSaveAsB->setMinimumSize(QSize(32, 32));
        queueSaveAsB->setMaximumSize(QSize(32, 32));

        horizontalLayout_14->addWidget(queueSaveAsB);

        horizontalLayout_14->setStretch(2, 1);
        horizontalLayout_14->setStretch(8, 2);

        verticalLayout_8->addLayout(horizontalLayout_14);

        queueTable = new QTableWidget(sequenceBox);
        if (queueTable->columnCount() < 8)
            queueTable->setColumnCount(8);
        QTableWidgetItem *__qtablewidgetitem = new QTableWidgetItem();
        queueTable->setHorizontalHeaderItem(0, __qtablewidgetitem);
        QTableWidgetItem *__qtablewidgetitem1 = new QTableWidgetItem();
        queueTable->setHorizontalHeaderItem(1, __qtablewidgetitem1);
        QTableWidgetItem *__qtablewidgetitem2 = new QTableWidgetItem();
        queueTable->setHorizontalHeaderItem(2, __qtablewidgetitem2);
        QTableWidgetItem *__qtablewidgetitem3 = new QTableWidgetItem();
        queueTable->setHorizontalHeaderItem(3, __qtablewidgetitem3);
        QTableWidgetItem *__qtablewidgetitem4 = new QTableWidgetItem();
        queueTable->setHorizontalHeaderItem(4, __qtablewidgetitem4);
        QTableWidgetItem *__qtablewidgetitem5 = new QTableWidgetItem();
        queueTable->setHorizontalHeaderItem(5, __qtablewidgetitem5);
        QTableWidgetItem *__qtablewidgetitem6 = new QTableWidgetItem();
        queueTable->setHorizontalHeaderItem(6, __qtablewidgetitem6);
        QTableWidgetItem *__qtablewidgetitem7 = new QTableWidgetItem();
        queueTable->setHorizontalHeaderItem(7, __qtablewidgetitem7);
        queueTable->setObjectName("queueTable");
        QSizePolicy sizePolicy9(QSizePolicy::Policy::MinimumExpanding, QSizePolicy::Policy::MinimumExpanding);
        sizePolicy9.setHorizontalStretch(0);
        sizePolicy9.setVerticalStretch(0);
        sizePolicy9.setHeightForWidth(queueTable->sizePolicy().hasHeightForWidth());
        queueTable->setSizePolicy(sizePolicy9);
        queueTable->setHorizontalScrollBarPolicy(Qt::ScrollBarAsNeeded);
        queueTable->setSelectionBehavior(QAbstractItemView::SelectRows);
        queueTable->horizontalHeader()->setMinimumSectionSize(30);
        queueTable->horizontalHeader()->setDefaultSectionSize(80);

        verticalLayout_8->addWidget(queueTable);


        SequenceQueue->addWidget(sequenceBox);

        buttonsGrid = new QGridLayout();
        buttonsGrid->setObjectName("buttonsGrid");
        buttonsGrid->setVerticalSpacing(0);
        videoLabel = new QLabel(rightLayoutWidget);
        videoLabel->setObjectName("videoLabel");
        videoLabel->setFont(font);
        videoLabel->setAlignment(Qt::AlignCenter);

        buttonsGrid->addWidget(videoLabel, 1, 2, 1, 1);

        previewLabel = new QLabel(rightLayoutWidget);
        previewLabel->setObjectName("previewLabel");
        previewLabel->setFont(font);
        previewLabel->setAlignment(Qt::AlignCenter);

        buttonsGrid->addWidget(previewLabel, 1, 0, 1, 1);

        loopLabel = new QLabel(rightLayoutWidget);
        loopLabel->setObjectName("loopLabel");
        loopLabel->setFont(font);
        loopLabel->setAlignment(Qt::AlignCenter);

        buttonsGrid->addWidget(loopLabel, 1, 1, 1, 1);

        loopB = new QPushButton(rightLayoutWidget);
        sequenceControlsButtonGroup = new QButtonGroup(Camera);
        sequenceControlsButtonGroup->setObjectName("sequenceControlsButtonGroup");
        sequenceControlsButtonGroup->addButton(loopB);
        loopB->setObjectName("loopB");
        loopB->setMinimumSize(QSize(32, 32));
        loopB->setMaximumSize(QSize(32, 32));
        QIcon icon15(QIcon::fromTheme(QString::fromUtf8("media-playlist-repeat")));
        loopB->setIcon(icon15);
        loopB->setIconSize(QSize(28, 28));

        buttonsGrid->addWidget(loopB, 0, 1, 1, 1);

        startB = new QPushButton(rightLayoutWidget);
        sequenceControlsButtonGroup->addButton(startB);
        startB->setObjectName("startB");
        sizePolicy7.setHeightForWidth(startB->sizePolicy().hasHeightForWidth());
        startB->setSizePolicy(sizePolicy7);
        startB->setMinimumSize(QSize(32, 32));
        startB->setMaximumSize(QSize(32, 32));

        buttonsGrid->addWidget(startB, 0, 6, 1, 1);

        liveVideoB = new QPushButton(rightLayoutWidget);
        sequenceControlsButtonGroup->addButton(liveVideoB);
        liveVideoB->setObjectName("liveVideoB");
        liveVideoB->setEnabled(true);
        liveVideoB->setMinimumSize(QSize(32, 32));
        liveVideoB->setMaximumSize(QSize(32, 32));
        liveVideoB->setStyleSheet(QString::fromUtf8(""));
        QIcon icon16(QIcon::fromTheme(QString::fromUtf8("camera-off")));
        liveVideoB->setIcon(icon16);
        liveVideoB->setIconSize(QSize(28, 28));
        liveVideoB->setCheckable(true);

        buttonsGrid->addWidget(liveVideoB, 0, 2, 1, 1);

        buttonSpacer = new QSpacerItem(20, 20, QSizePolicy::Policy::Expanding, QSizePolicy::Policy::Minimum);

        buttonsGrid->addItem(buttonSpacer, 0, 5, 1, 1);

        horizontalSpacer_4 = new QSpacerItem(40, 20, QSizePolicy::Policy::Expanding, QSizePolicy::Policy::Minimum);

        buttonsGrid->addItem(horizontalSpacer_4, 0, 3, 1, 1);

        previewB = new QPushButton(rightLayoutWidget);
        sequenceControlsButtonGroup->addButton(previewB);
        previewB->setObjectName("previewB");
        previewB->setMinimumSize(QSize(32, 32));
        previewB->setMaximumSize(QSize(32, 32));
        QIcon icon17(QIcon::fromTheme(QString::fromUtf8("camera-photo")));
        previewB->setIcon(icon17);
        previewB->setIconSize(QSize(28, 28));
        previewB->setAutoDefault(true);

        buttonsGrid->addWidget(previewB, 0, 0, 1, 1);

        darkB = new QCheckBox(rightLayoutWidget);
        darkB->setObjectName("darkB");
        QSizePolicy sizePolicy10(QSizePolicy::Policy::Minimum, QSizePolicy::Policy::Maximum);
        sizePolicy10.setHorizontalStretch(0);
        sizePolicy10.setVerticalStretch(0);
        sizePolicy10.setHeightForWidth(darkB->sizePolicy().hasHeightForWidth());
        darkB->setSizePolicy(sizePolicy10);
        darkB->setSizeIncrement(QSize(0, 0));
        darkB->setBaseSize(QSize(0, 0));

        buttonsGrid->addWidget(darkB, 0, 4, 1, 1);

        pauseB = new QPushButton(rightLayoutWidget);
        sequenceControlsButtonGroup->addButton(pauseB);
        pauseB->setObjectName("pauseB");
        pauseB->setEnabled(false);
        sizePolicy7.setHeightForWidth(pauseB->sizePolicy().hasHeightForWidth());
        pauseB->setSizePolicy(sizePolicy7);
        pauseB->setMinimumSize(QSize(32, 32));
        pauseB->setMaximumSize(QSize(32, 32));
        pauseB->setAutoDefault(true);

        buttonsGrid->addWidget(pauseB, 0, 7, 1, 1);

        buttonsGrid->setColumnStretch(3, 3);
        buttonsGrid->setColumnStretch(5, 1);

        SequenceQueue->addLayout(buttonsGrid);


        RightLayout->addLayout(SequenceQueue);

        verticalLayout = new QVBoxLayout();
        verticalLayout->setSpacing(2);
        verticalLayout->setObjectName("verticalLayout");
        processGrid = new QFrame(rightLayoutWidget);
        processGrid->setObjectName("processGrid");
        processGrid->setFrameShape(QFrame::Box);
        processGrid->setFrameShadow(QFrame::Sunken);
        processGrid->setLineWidth(0);
        progressGrid = new QGridLayout(processGrid);
        progressGrid->setObjectName("progressGrid");
        progressGrid->setHorizontalSpacing(2);
        jobLabel = new QLabel(processGrid);
        jobLabel->setObjectName("jobLabel");

        progressGrid->addWidget(jobLabel, 2, 0, 1, 1);

        frameInfoLabel = new QLabel(processGrid);
        frameInfoLabel->setObjectName("frameInfoLabel");
        QFont font1;
        font1.setBold(false);
        frameInfoLabel->setFont(font1);

        progressGrid->addWidget(frameInfoLabel, 1, 0, 1, 1);

        horizontalSpacer_5 = new QSpacerItem(40, 20, QSizePolicy::Policy::Expanding, QSizePolicy::Policy::Minimum);

        progressGrid->addItem(horizontalSpacer_5, 2, 2, 1, 1);

        frameRemainingTime = new QLabel(processGrid);
        frameRemainingTime->setObjectName("frameRemainingTime");
        frameRemainingTime->setMinimumSize(QSize(70, 0));
        QFont font2;
        font2.setBold(true);
        frameRemainingTime->setFont(font2);
        frameRemainingTime->setAlignment(Qt::AlignRight|Qt::AlignTrailing|Qt::AlignVCenter);

        progressGrid->addWidget(frameRemainingTime, 1, 1, 1, 1);

        avgDownloadTime = new QLabel(processGrid);
        avgDownloadTime->setObjectName("avgDownloadTime");
        avgDownloadTime->setAlignment(Qt::AlignRight|Qt::AlignTrailing|Qt::AlignVCenter);

        progressGrid->addWidget(avgDownloadTime, 2, 4, 1, 1);

        progressLabel = new QLabel(processGrid);
        progressLabel->setObjectName("progressLabel");

        progressGrid->addWidget(progressLabel, 0, 0, 1, 1);

        jobRemainingTime = new QLabel(processGrid);
        jobRemainingTime->setObjectName("jobRemainingTime");
        jobRemainingTime->setMinimumSize(QSize(70, 0));
        jobRemainingTime->setFont(font2);
        jobRemainingTime->setAlignment(Qt::AlignRight|Qt::AlignTrailing|Qt::AlignVCenter);

        progressGrid->addWidget(jobRemainingTime, 2, 1, 1, 1);

        avgDownloadLabel = new QLabel(processGrid);
        avgDownloadLabel->setObjectName("avgDownloadLabel");
        avgDownloadLabel->setAlignment(Qt::AlignRight|Qt::AlignTrailing|Qt::AlignVCenter);

        progressGrid->addWidget(avgDownloadLabel, 2, 3, 1, 1);

        secLabel = new QLabel(processGrid);
        secLabel->setObjectName("secLabel");

        progressGrid->addWidget(secLabel, 2, 5, 1, 1);

        captureStatusWidget = new Ekos::LedStatusWidget(processGrid);
        captureStatusWidget->setObjectName("captureStatusWidget");
        captureStatusWidget->setMinimumSize(QSize(0, 25));

        progressGrid->addWidget(captureStatusWidget, 0, 1, 1, 5);

        imgProgress = new QProgressBar(processGrid);
        imgProgress->setObjectName("imgProgress");
        imgProgress->setEnabled(false);

        progressGrid->addWidget(imgProgress, 3, 0, 1, 6);

        targetDriftLabel = new QLabel(processGrid);
        targetDriftLabel->setObjectName("targetDriftLabel");
        targetDriftLabel->setAlignment(Qt::AlignRight|Qt::AlignTrailing|Qt::AlignVCenter);

        progressGrid->addWidget(targetDriftLabel, 1, 3, 1, 1);

        targetDrift = new QLabel(processGrid);
        targetDrift->setObjectName("targetDrift");
        targetDrift->setAlignment(Qt::AlignRight|Qt::AlignTrailing|Qt::AlignVCenter);

        progressGrid->addWidget(targetDrift, 1, 4, 1, 1);

        targetDriftUnit = new QLabel(processGrid);
        targetDriftUnit->setObjectName("targetDriftUnit");

        progressGrid->addWidget(targetDriftUnit, 1, 5, 1, 1);

        progressGrid->setColumnStretch(2, 10);
        progressGrid->setColumnStretch(4, 1);

        verticalLayout->addWidget(processGrid);

        loadSaveBox = new QGroupBox(rightLayoutWidget);
        loadSaveBox->setObjectName("loadSaveBox");
        loadSaveBox->setEnabled(false);
        loadSaveBox->setVisible(false);
        loadSaveBox->setFlat(true);
        loadSaveLayout = new QHBoxLayout(loadSaveBox);
        loadSaveLayout->setObjectName("loadSaveLayout");
        loadSaveSpacer = new QSpacerItem(40, 20, QSizePolicy::Policy::Expanding, QSizePolicy::Policy::Minimum);

        loadSaveLayout->addItem(loadSaveSpacer);

        esqLoadB = new QPushButton(loadSaveBox);
        esqLoadB->setObjectName("esqLoadB");
        esqLoadB->setMinimumSize(QSize(85, 24));
        esqLoadB->setMaximumSize(QSize(85, 32));

        loadSaveLayout->addWidget(esqLoadB);

        esqSaveAsB = new QPushButton(loadSaveBox);
        esqSaveAsB->setObjectName("esqSaveAsB");
        esqSaveAsB->setMinimumSize(QSize(85, 24));
        esqSaveAsB->setMaximumSize(QSize(85, 32));

        loadSaveLayout->addWidget(esqSaveAsB);


        verticalLayout->addWidget(loadSaveBox);


        RightLayout->addLayout(verticalLayout);

        splitter->addWidget(rightLayoutWidget);

        wholeLayout->addWidget(splitter);

        QWidget::setTabOrder(opticalTrainCombo, trainB);
        QWidget::setTabOrder(trainB, captureExposureN);
        QWidget::setTabOrder(captureExposureN, FilterPosCombo);
        QWidget::setTabOrder(FilterPosCombo, filterManagerB);
        QWidget::setTabOrder(filterManagerB, filterEditB);
        QWidget::setTabOrder(filterEditB, captureFormatS);
        QWidget::setTabOrder(captureFormatS, captureEncodingS);
        QWidget::setTabOrder(captureEncodingS, captureGainN);
        QWidget::setTabOrder(captureGainN, captureFrameXN);
        QWidget::setTabOrder(captureFrameXN, captureFrameYN);
        QWidget::setTabOrder(captureFrameYN, captureOffsetN);
        QWidget::setTabOrder(captureOffsetN, captureFrameWN);
        QWidget::setTabOrder(captureFrameWN, captureFrameHN);
        QWidget::setTabOrder(captureFrameHN, captureBinHN);
        QWidget::setTabOrder(captureBinHN, captureBinVN);
        QWidget::setTabOrder(captureBinVN, addToQueueB);
        QWidget::setTabOrder(addToQueueB, removeFromQueueB);
        QWidget::setTabOrder(removeFromQueueB, queueUpB);
        QWidget::setTabOrder(queueUpB, queueDownB);
        QWidget::setTabOrder(queueDownB, resetB);
        QWidget::setTabOrder(resetB, observerB);
        QWidget::setTabOrder(observerB, queueLoadB);
        QWidget::setTabOrder(queueLoadB, queueSaveB);
        QWidget::setTabOrder(queueSaveB, queueSaveAsB);
        QWidget::setTabOrder(queueSaveAsB, queueTable);
        QWidget::setTabOrder(queueTable, previewB);
        QWidget::setTabOrder(previewB, loopB);
        QWidget::setTabOrder(loopB, liveVideoB);

        retranslateUi(Camera);

        exposureOptions->setCurrentIndex(0);
        previewB->setDefault(true);
        pauseB->setDefault(true);


        QMetaObject::connectSlotsByName(Camera);
    } // setupUi

    void retranslateUi(QWidget *Camera)
    {
        sequenceEditorComment->setText(QString());
#if QT_CONFIG(tooltip)
        opticalTrainLabel->setToolTip(QString());
#endif // QT_CONFIG(tooltip)
#if QT_CONFIG(whatsthis)
        opticalTrainLabel->setWhatsThis(QString());
#endif // QT_CONFIG(whatsthis)
        opticalTrainLabel->setText(tr2i18n("Train:", nullptr));
        trainB->setText(QString());
#if QT_CONFIG(tooltip)
        restartCameraB->setToolTip(tr2i18n("Restart camera driver", nullptr));
#endif // QT_CONFIG(tooltip)
        restartCameraB->setText(QString());
#if QT_CONFIG(tooltip)
        clearConfigurationB->setToolTip(tr2i18n("Clear camera configuration", nullptr));
#endif // QT_CONFIG(tooltip)
        clearConfigurationB->setText(QString());
#if QT_CONFIG(tooltip)
        resetFrameB->setToolTip(tr2i18n("Reset CCD frame & size values to default values", nullptr));
#endif // QT_CONFIG(tooltip)
        resetFrameB->setText(QString());
        CaptureSettingsGroup->setTitle(tr2i18n("Capture Settings", "camera capture settings section title"));
#if QT_CONFIG(tooltip)
        textLabel1_9->setToolTip(tr2i18n("Horizontal and Vertical binning", nullptr));
#endif // QT_CONFIG(tooltip)
#if QT_CONFIG(whatsthis)
        textLabel1_9->setWhatsThis(QString());
#endif // QT_CONFIG(whatsthis)
        textLabel1_9->setText(tr2i18n("Binning:", nullptr));
#if QT_CONFIG(tooltip)
        captureFormatS->setToolTip(tr2i18n("Image capture format", nullptr));
#endif // QT_CONFIG(tooltip)
        captureEncodingS->setItemText(0, tr2i18n("FITS", nullptr));
        captureEncodingS->setItemText(1, tr2i18n("Native", nullptr));

#if QT_CONFIG(tooltip)
        captureEncodingS->setToolTip(tr2i18n("Image transfer format", nullptr));
#endif // QT_CONFIG(tooltip)
        label_7->setText(tr2i18n("Format:", nullptr));
#if QT_CONFIG(tooltip)
        exposureLabel->setToolTip(QString());
#endif // QT_CONFIG(tooltip)
#if QT_CONFIG(whatsthis)
        exposureLabel->setWhatsThis(QString());
#endif // QT_CONFIG(whatsthis)
        exposureLabel->setText(tr2i18n("Exposure:", nullptr));
#if QT_CONFIG(tooltip)
        filterManagerB->setToolTip(tr2i18n("Filter Settings", nullptr));
#endif // QT_CONFIG(tooltip)
#if QT_CONFIG(statustip)
        filterManagerB->setStatusTip(QString());
#endif // QT_CONFIG(statustip)
        filterManagerB->setText(QString());
#if QT_CONFIG(tooltip)
        filterEditB->setToolTip(tr2i18n("Edit filter names", nullptr));
#endif // QT_CONFIG(tooltip)
        filterEditB->setText(QString());
#if QT_CONFIG(tooltip)
        textLabel1_15->setToolTip(QString());
#endif // QT_CONFIG(tooltip)
#if QT_CONFIG(whatsthis)
        textLabel1_15->setWhatsThis(QString());
#endif // QT_CONFIG(whatsthis)
        textLabel1_15->setText(tr2i18n("W:", nullptr));
#if QT_CONFIG(tooltip)
        textLabel1_16->setToolTip(QString());
#endif // QT_CONFIG(tooltip)
#if QT_CONFIG(whatsthis)
        textLabel1_16->setWhatsThis(QString());
#endif // QT_CONFIG(whatsthis)
        textLabel1_16->setText(tr2i18n("H:", nullptr));
#if QT_CONFIG(tooltip)
        coolerOnB->setToolTip(tr2i18n("Turn cooler on", nullptr));
#endif // QT_CONFIG(tooltip)
        coolerOnB->setText(tr2i18n("On", nullptr));
#if QT_CONFIG(tooltip)
        coolerOffB->setToolTip(tr2i18n("Turn cooler off", nullptr));
#endif // QT_CONFIG(tooltip)
        coolerOffB->setText(tr2i18n("Off", nullptr));
#if QT_CONFIG(tooltip)
        captureBinXLabel->setToolTip(QString());
#endif // QT_CONFIG(tooltip)
#if QT_CONFIG(whatsthis)
        captureBinXLabel->setWhatsThis(QString());
#endif // QT_CONFIG(whatsthis)
        captureBinXLabel->setText(tr2i18n("H:", nullptr));
#if QT_CONFIG(tooltip)
        captureBinHN->setToolTip(tr2i18n("Horizontal binning", nullptr));
#endif // QT_CONFIG(tooltip)
#if QT_CONFIG(tooltip)
        captureBinYLabel->setToolTip(QString());
#endif // QT_CONFIG(tooltip)
#if QT_CONFIG(whatsthis)
        captureBinYLabel->setWhatsThis(QString());
#endif // QT_CONFIG(whatsthis)
        captureBinYLabel->setText(tr2i18n("V:", nullptr));
#if QT_CONFIG(tooltip)
        captureBinVN->setToolTip(tr2i18n("Vertical binning", nullptr));
#endif // QT_CONFIG(tooltip)
#if QT_CONFIG(tooltip)
        textLabel1_19->setToolTip(QString());
#endif // QT_CONFIG(tooltip)
#if QT_CONFIG(whatsthis)
        textLabel1_19->setWhatsThis(QString());
#endif // QT_CONFIG(whatsthis)
        textLabel1_19->setText(tr2i18n("Size:", nullptr));
#if QT_CONFIG(tooltip)
        textLabel1_12->setToolTip(QString());
#endif // QT_CONFIG(tooltip)
#if QT_CONFIG(whatsthis)
        textLabel1_12->setWhatsThis(QString());
#endif // QT_CONFIG(whatsthis)
        textLabel1_12->setText(tr2i18n("Frame:", nullptr));
        coolerLabel->setText(tr2i18n("Cooler:", nullptr));
#if QT_CONFIG(tooltip)
        FilterPosLabel->setToolTip(QString());
#endif // QT_CONFIG(tooltip)
#if QT_CONFIG(whatsthis)
        FilterPosLabel->setWhatsThis(QString());
#endif // QT_CONFIG(whatsthis)
        FilterPosLabel->setText(tr2i18n("Filter:", nullptr));
#if QT_CONFIG(tooltip)
        textLabel1_13->setToolTip(QString());
#endif // QT_CONFIG(tooltip)
#if QT_CONFIG(whatsthis)
        textLabel1_13->setWhatsThis(QString());
#endif // QT_CONFIG(whatsthis)
        textLabel1_13->setText(tr2i18n("X:", nullptr));
#if QT_CONFIG(tooltip)
        textLabel1_14->setToolTip(QString());
#endif // QT_CONFIG(tooltip)
#if QT_CONFIG(whatsthis)
        textLabel1_14->setWhatsThis(QString());
#endif // QT_CONFIG(whatsthis)
        textLabel1_14->setText(tr2i18n("Y:", nullptr));
#if QT_CONFIG(tooltip)
        textLabel1_17->setToolTip(QString());
#endif // QT_CONFIG(tooltip)
#if QT_CONFIG(whatsthis)
        textLabel1_17->setWhatsThis(QString());
#endif // QT_CONFIG(whatsthis)
        textLabel1_17->setText(tr2i18n("Type:", nullptr));
        ISOLabel->setText(tr2i18n("ISO:", nullptr));
#if QT_CONFIG(tooltip)
        captureISOS->setToolTip(tr2i18n("Camera ISO", nullptr));
#endif // QT_CONFIG(tooltip)
#if QT_CONFIG(tooltip)
        textLabel1_21->setToolTip(tr2i18n("Camera Gain", nullptr));
#endif // QT_CONFIG(tooltip)
#if QT_CONFIG(whatsthis)
        textLabel1_21->setWhatsThis(QString());
#endif // QT_CONFIG(whatsthis)
        textLabel1_21->setText(tr2i18n("Gain:", nullptr));
#if QT_CONFIG(tooltip)
        currentGainLabel->setToolTip(tr2i18n("Current camera gain", nullptr));
#endif // QT_CONFIG(tooltip)
#if QT_CONFIG(whatsthis)
        currentGainLabel->setWhatsThis(QString());
#endif // QT_CONFIG(whatsthis)
        currentGainLabel->setText(QString());
#if QT_CONFIG(tooltip)
        captureGainN->setToolTip(tr2i18n("Target camera gain", nullptr));
#endif // QT_CONFIG(tooltip)
#if QT_CONFIG(tooltip)
        textLabel1_20->setToolTip(tr2i18n("Camera Offset", nullptr));
#endif // QT_CONFIG(tooltip)
#if QT_CONFIG(whatsthis)
        textLabel1_20->setWhatsThis(QString());
#endif // QT_CONFIG(whatsthis)
        textLabel1_20->setText(tr2i18n("Offset:", nullptr));
#if QT_CONFIG(tooltip)
        currentOffsetLabel->setToolTip(tr2i18n("Current camera offset", nullptr));
#endif // QT_CONFIG(tooltip)
#if QT_CONFIG(whatsthis)
        currentOffsetLabel->setWhatsThis(QString());
#endif // QT_CONFIG(whatsthis)
        currentOffsetLabel->setText(QString());
#if QT_CONFIG(tooltip)
        captureOffsetN->setToolTip(tr2i18n("Target camera offset", nullptr));
#endif // QT_CONFIG(tooltip)
        darksLibraryLabel->setText(tr2i18n("Dark Lib.", nullptr));
        rotatorLabel->setText(tr2i18n("Rotator", nullptr));
#if QT_CONFIG(tooltip)
        rotatorB->setToolTip(tr2i18n("Rotator Control", nullptr));
#endif // QT_CONFIG(tooltip)
        rotatorB->setText(QString());
        exposureCalculationLabel->setText(tr2i18n("Exp. Calc.", nullptr));
#if QT_CONFIG(tooltip)
        darkLibraryB->setToolTip(tr2i18n("Create and manage Dark Library", nullptr));
#endif // QT_CONFIG(tooltip)
        darkLibraryB->setText(QString());
#if QT_CONFIG(tooltip)
        exposureCalcB->setToolTip(tr2i18n("<html><head/><body><p>Exposure calculator</p></body></html>", nullptr));
#endif // QT_CONFIG(tooltip)
        exposureCalcB->setText(QString());
#if QT_CONFIG(tooltip)
        calibrationB->setToolTip(tr2i18n("Dark & Flat frames automatic calibration options", nullptr));
#endif // QT_CONFIG(tooltip)
        calibrationB->setText(QString());
        calibrationLabel->setText(tr2i18n("Calibration", nullptr));
#if QT_CONFIG(tooltip)
        generateDarkFlatsB->setToolTip(tr2i18n("<html><head/><body><p>Generate Dark Flats after adding Flat frames to the sequence queue.</p></body></html>", nullptr));
#endif // QT_CONFIG(tooltip)
        generateDarkFlatsB->setText(QString());
        darksFlatsLabel->setText(tr2i18n("Dark Flats", nullptr));
#if QT_CONFIG(tooltip)
        customValuesB->setToolTip(tr2i18n("Manage INDI sequence properties", nullptr));
#endif // QT_CONFIG(tooltip)
        customValuesB->setText(QString());
        customValuesLabel->setText(tr2i18n("Custom Val.", nullptr));
#if QT_CONFIG(tooltip)
        limitsB->setToolTip(tr2i18n("Configure Guide & Focus limits", nullptr));
#endif // QT_CONFIG(tooltip)
        limitsB->setText(QString());
        limitsLabel->setText(tr2i18n("Limits", nullptr));
#if QT_CONFIG(tooltip)
        scriptManagerB->setToolTip(tr2i18n("Manage sequence scripts", nullptr));
#endif // QT_CONFIG(tooltip)
        scriptManagerB->setText(QString());
        scriptsLabel->setText(tr2i18n("Scripts", nullptr));
#if QT_CONFIG(tooltip)
        temperatureOUT->setToolTip(tr2i18n("Current CCD temperature", nullptr));
#endif // QT_CONFIG(tooltip)
        temperatureOUT->setText(QString());
#if QT_CONFIG(tooltip)
        cameraTemperatureN->setToolTip(tr2i18n("Desired CCD temperature", nullptr));
#endif // QT_CONFIG(tooltip)
#if QT_CONFIG(tooltip)
        cameraTemperatureS->setToolTip(tr2i18n("<html><head/><body><p>Enforce temperature value before capturing an image</p></body></html>", nullptr));
#endif // QT_CONFIG(tooltip)
        cameraTemperatureS->setText(tr2i18n("T\302\272", nullptr));
#if QT_CONFIG(tooltip)
        setTemperatureB->setToolTip(tr2i18n("Set CCD temperature", nullptr));
#endif // QT_CONFIG(tooltip)
        setTemperatureB->setText(QString());
#if QT_CONFIG(tooltip)
        temperatureRegulationB->setToolTip(tr2i18n("Temperature regulation", nullptr));
#endif // QT_CONFIG(tooltip)
        temperatureRegulationB->setText(QString());
#if QT_CONFIG(tooltip)
        textLabel1_8->setToolTip(tr2i18n("Delay in seconds before capturing an image", nullptr));
#endif // QT_CONFIG(tooltip)
#if QT_CONFIG(whatsthis)
        textLabel1_8->setWhatsThis(QString());
#endif // QT_CONFIG(whatsthis)
        textLabel1_8->setText(tr2i18n("Delay:", nullptr));
#if QT_CONFIG(tooltip)
        videoDurationSB->setToolTip(tr2i18n("<html><head/><body><p>Duration of the video sequence (in seconds or number of frames).</p></body></html>", nullptr));
#endif // QT_CONFIG(tooltip)
#if QT_CONFIG(tooltip)
        videoDurationUnitCB->setToolTip(tr2i18n("<html><head/><body><p>Units of the video duration (seconds or number of frames).</p></body></html>", nullptr));
#endif // QT_CONFIG(tooltip)
#if QT_CONFIG(tooltip)
        exposureOptionsLabel->setToolTip(QString());
#endif // QT_CONFIG(tooltip)
#if QT_CONFIG(whatsthis)
        exposureOptionsLabel->setWhatsThis(QString());
#endif // QT_CONFIG(whatsthis)
        exposureOptionsLabel->setText(tr2i18n("Count:", nullptr));
        fileSettingsGroup->setTitle(tr2i18n("File Settings", nullptr));
        fileUploadModeS->setItemText(0, tr2i18n("Locally", nullptr));
        fileUploadModeS->setItemText(1, tr2i18n("Remotely", nullptr));
        fileUploadModeS->setItemText(2, tr2i18n("Both", nullptr));

        targetNameT->setPlaceholderText(tr2i18n("Target", nullptr));
#if QT_CONFIG(tooltip)
        textLabel1_18->setToolTip(tr2i18n("<html><head/><body><p>Base local capture directory</p></body></html>", nullptr));
#endif // QT_CONFIG(tooltip)
#if QT_CONFIG(whatsthis)
        textLabel1_18->setWhatsThis(QString());
#endif // QT_CONFIG(whatsthis)
        textLabel1_18->setText(tr2i18n("Directory:", nullptr));
#if QT_CONFIG(tooltip)
        resetFormatB->setToolTip(tr2i18n("Reset placeholder format to default", nullptr));
#endif // QT_CONFIG(tooltip)
        resetFormatB->setText(QString());
#if QT_CONFIG(tooltip)
        textLabel1_7->setToolTip(tr2i18n("<html><head/><body><p>Target is the name of the targeted object.</p><p>It is available to be used in the filename Format via the %t or %type placeholder tag.</p></body></html>", nullptr));
#endif // QT_CONFIG(tooltip)
#if QT_CONFIG(whatsthis)
        textLabel1_7->setWhatsThis(QString());
#endif // QT_CONFIG(whatsthis)
        textLabel1_7->setText(tr2i18n("Target:", nullptr));
        fileRemoteDirT->setPlaceholderText(tr2i18n("/home/pi", nullptr));
#if QT_CONFIG(tooltip)
        label_4->setToolTip(tr2i18n("<html><head/><body><p>Select how captured images are uploaded:</p><ol style=\"margin-top: 0px; margin-bottom: 0px; margin-left: 0px; margin-right: 0px; -qt-list-indent: 1;\"><li style=\" margin-top:12px; margin-bottom:0px; margin-left:0px; margin-right:0px; -qt-block-indent:0; text-indent:0px;\"><span style=\" font-weight:600;\">Locally</span>: Captured images are saved locally on disk in the directory specified above.</li><li style=\" margin-top:0px; margin-bottom:0px; margin-left:0px; margin-right:0px; -qt-block-indent:0; text-indent:0px;\"><span style=\" font-weight:600;\">Remotely</span>: When connecting to a remote device, select this option to save images on the remote device only. No images are uploaded to Ekos.</li><li style=\" margin-top:0px; margin-bottom:12px; margin-left:0px; margin-right:0px; -qt-block-indent:0; text-indent:0px;\"><span style=\" font-weight:600;\">Both</span>: Captured images are saved on both the remote computer <span style=\" font-weight:600;\">and</span> on the local disk as we"
                        "ll.</li></ol><p>When selecting <span style=\" font-style:italic;\">Remotely</span> or <span style=\" font-style:italic;\">Both</span>, you must specify the remote directory where the remote images are saved to. By default, all captured images are saved <span style=\" font-style:italic;\">Locally</span>.</p></body></html>", nullptr));
#endif // QT_CONFIG(tooltip)
        label_4->setText(tr2i18n("Save:", nullptr));
#if QT_CONFIG(tooltip)
        formatSuffixN->setToolTip(tr2i18n("<html><head/><body><p>Number of digits used to append the sequence number to the filename.</p></body></html>", nullptr));
#endif // QT_CONFIG(tooltip)
        formatSuffixN->setPrefix(tr2i18n("_%s", nullptr));
#if QT_CONFIG(tooltip)
        formatLabel->setToolTip(tr2i18n("<html><head/><body><p>Format is used to define the image file names by the use of placeholder tags.</p><ul style=\"margin-top: 0px; margin-bottom: 0px; margin-left: 0px; margin-right: 0px; -qt-list-indent: 1;\"><li style=\" margin-top:12px; margin-bottom:0px; margin-left:0px; margin-right:0px; -qt-block-indent:0; text-indent:0px;\">Placeholder<span style=\" font-weight:704;\"> %f</span> or <span style=\" font-weight:704;\">%filename</span>: The name of the .esq file, without extension.</li><li style=\" margin-top:0px; margin-bottom:0px; margin-left:0px; margin-right:0px; -qt-block-indent:0; text-indent:0px;\">Placeholder<span style=\" font-weight:704;\"> %D</span> or <span style=\" font-weight:704;\">%Datetime</span>: The current time and date <span style=\" font-weight:704;\">when the file is saved.</span></li><li style=\" margin-top:0px; margin-bottom:0px; margin-left:0px; margin-right:0px; -qt-block-indent:0; text-indent:0px;\">Placeholder<span style=\" font-weight:704;\"> %T</span> or <span style=\" font-w"
                        "eight:704;\">%Type</span>: The frame type eg: 'Light', 'Bias', 'Dark', 'Flat'...</li><li style=\" margin-top:0px; margin-bottom:0px; margin-left:0px; margin-right:0px; -qt-block-indent:0; text-indent:0px;\">Placeholder<span style=\" font-weight:704;\"> %e</span> or <span style=\" font-weight:704;\">%exposure</span>: The exposure duration in seconds, with '_secs' as suffix.</li><ul style=\"margin-top: 0px; margin-bottom: 0px; margin-left: 0px; margin-right: 0px; -qt-list-indent: 1;\"><li style=\" margin-top:0px; margin-bottom:0px; margin-left:0px; margin-right:0px; -qt-block-indent:0; text-indent:0px;\">Placeholder<span style=\" font-weight:704;\"> %E</span> or <span style=\" font-weight:704;\">%exp</span>: The exposure duration in seconds as plain number, without any unit as suffix.</li></ul><li style=\" margin-top:0px; margin-bottom:0px; margin-left:0px; margin-right:0px; -qt-block-indent:0; text-indent:0px;\">Placeholder<span style=\" font-weight:704;\"> %F</span> or <span style=\" font-weight:704;\">%Filter"
                        "</span>: The active filter name.</li><li style=\" margin-top:0px; margin-bottom:0px; margin-left:0px; margin-right:0px; -qt-block-indent:0; text-indent:0px;\">Placeholder<span style=\" font-weight:704;\"> %t</span> or <span style=\" font-weight:704;\">%target</span>: The Target name.</li><li style=\" margin-top:0px; margin-bottom:0px; margin-left:0px; margin-right:0px; -qt-block-indent:0; text-indent:0px;\">Placeholder <span style=\" font-weight:600;\">%C</span> or <span style=\" font-weight:600;\">%temperature</span>: The camera temperature of capturing.</li><ul style=\"margin-top: 0px; margin-bottom: 0px; margin-left: 0px; margin-right: 0px; -qt-list-indent: 1;\"><li style=\" margin-top:0px; margin-bottom:0px; margin-left:0px; margin-right:0px; -qt-block-indent:0; text-indent:0px;\">Placeholder <span style=\" font-weight:600;\">%B</span> or <span style=\" font-weight:600;\">%bin</span>: The binning configured for capturing.</li><li style=\" margin-top:0px; margin-bottom:0px; margin-left:0px; margin-right:0px"
                        "; -qt-block-indent:0; text-indent:0px;\">Placeholder <span style=\" font-weight:600;\">%G</span> or <span style=\" font-weight:600;\">%gain</span>: The gain configured for capturing.</li></ul><li style=\" margin-top:0px; margin-bottom:0px; margin-left:0px; margin-right:0px; -qt-block-indent:0; text-indent:0px;\">Placeholder <span style=\" font-weight:600;\">%O</span> or <span style=\" font-weight:600;\">%offset</span>: The offset configured for capturing.</li><ul style=\"margin-top: 0px; margin-bottom: 0px; margin-left: 0px; margin-right: 0px; -qt-list-indent: 1;\"><li style=\" margin-top:0px; margin-bottom:0px; margin-left:0px; margin-right:0px; -qt-block-indent:0; text-indent:0px;\">Placeholder <span style=\" font-weight:600;\">%I</span> or <span style=\" font-weight:600;\">%iso</span>: The ISO value (DSLRs only).</li></ul><li style=\" margin-top:0px; margin-bottom:0px; margin-left:0px; margin-right:0px; -qt-block-indent:0; text-indent:0px;\">Placeholder <span style=\" font-weight:600;\">%P</span> or <span s"
                        "tyle=\" font-weight:600;\">%pierside</span>: The current mount's pier side.</li><ul style=\"margin-top: 0px; margin-bottom: 0px; margin-left: 0px; margin-right: 0px; -qt-list-indent: 1;\"><li style=\" margin-top:0px; margin-bottom:0px; margin-left:0px; margin-right:0px; -qt-block-indent:0; text-indent:0px;\">Placeholder <span style=\" font-weight:600;\">%H</span> or <span style=\" font-weight:600;\">%hostname</span>: The hostname running EKOS.</li></ul><li style=\" margin-top:0px; margin-bottom:12px; margin-left:0px; margin-right:0px; -qt-block-indent:0; text-indent:0px;\">Placeholder<span style=\" font-weight:704;\"> %s*</span> or <span style=\" font-weight:704;\">%sequence</span>: The image sequence identifier where * is the number of digits used (1-9). <span style=\" font-weight:704;\">This tag is mandatory and must be the last element in the format.</span></li></ul><p>Arbitrary text may also be included within the Format string, <span style=\" font-weight:704;\">except the % and \\ characters.</span> The /"
                        " path character can be used to define arbitrary directories.</p><p>Notes:</p><ul style=\"margin-top: 0px; margin-bottom: 0px; margin-left: 0px; margin-right: 0px; -qt-list-indent: 1;\"><li style=\" margin-top:0px; margin-bottom:0px; margin-left:0px; margin-right:0px; -qt-block-indent:0; text-indent:0px;\">Tags are case sensitive in both their short and long forms.</li><li style=\" margin-top:0px; margin-bottom:0px; margin-left:0px; margin-right:0px; -qt-block-indent:0; text-indent:0px;\">Only use the %Datetime tag in the filename portion of the format, not in the path definition.</li></ul></body></html>", nullptr));
#endif // QT_CONFIG(tooltip)
        formatLabel->setText(tr2i18n("Format:", nullptr));
        selectFileDirectoryB->setText(QString());
#if QT_CONFIG(tooltip)
        remoteLabel->setToolTip(tr2i18n("When storing images on remote devices, specify the directory where captured images are saved to.", nullptr));
#endif // QT_CONFIG(tooltip)
        remoteLabel->setText(tr2i18n("Remote:", nullptr));
        sequenceBox->setTitle(tr2i18n("Sequence Queue", nullptr));
        addToQueueB->setText(QString());
        removeFromQueueB->setText(QString());
        queueUpB->setText(QString());
        queueDownB->setText(QString());
#if QT_CONFIG(tooltip)
        resetB->setToolTip(tr2i18n("Reset status of all jobs", nullptr));
#endif // QT_CONFIG(tooltip)
        resetB->setText(QString());
#if QT_CONFIG(tooltip)
        observerB->setToolTip(tr2i18n("Select Observer...", nullptr));
#endif // QT_CONFIG(tooltip)
        observerB->setText(QString());
#if QT_CONFIG(tooltip)
        queueLoadB->setToolTip(tr2i18n("Load Capture Sequence from File...", nullptr));
#endif // QT_CONFIG(tooltip)
        queueLoadB->setText(QString());
#if QT_CONFIG(tooltip)
        queueSaveB->setToolTip(tr2i18n("Save Capture Sequence...", nullptr));
#endif // QT_CONFIG(tooltip)
        queueSaveB->setText(QString());
#if QT_CONFIG(tooltip)
        queueSaveAsB->setToolTip(tr2i18n("Save Capture Sequence As...", nullptr));
#endif // QT_CONFIG(tooltip)
        queueSaveAsB->setText(QString());
        QTableWidgetItem *___qtablewidgetitem = queueTable->horizontalHeaderItem(0);
        ___qtablewidgetitem->setText(tr2i18n("Status", nullptr));
        QTableWidgetItem *___qtablewidgetitem1 = queueTable->horizontalHeaderItem(1);
        ___qtablewidgetitem1->setText(tr2i18n("Filter", nullptr));
        QTableWidgetItem *___qtablewidgetitem2 = queueTable->horizontalHeaderItem(2);
        ___qtablewidgetitem2->setText(tr2i18n("Count", nullptr));
        QTableWidgetItem *___qtablewidgetitem3 = queueTable->horizontalHeaderItem(3);
        ___qtablewidgetitem3->setText(tr2i18n("Exp", nullptr));
        QTableWidgetItem *___qtablewidgetitem4 = queueTable->horizontalHeaderItem(4);
        ___qtablewidgetitem4->setText(tr2i18n("Type", nullptr));
        QTableWidgetItem *___qtablewidgetitem5 = queueTable->horizontalHeaderItem(5);
        ___qtablewidgetitem5->setText(tr2i18n("Bin", nullptr));
        QTableWidgetItem *___qtablewidgetitem6 = queueTable->horizontalHeaderItem(6);
        ___qtablewidgetitem6->setText(tr2i18n("ISO/Gain", nullptr));
        QTableWidgetItem *___qtablewidgetitem7 = queueTable->horizontalHeaderItem(7);
        ___qtablewidgetitem7->setText(tr2i18n("Offset", nullptr));
        videoLabel->setText(tr2i18n("Video", nullptr));
        previewLabel->setText(tr2i18n("Preview", nullptr));
        loopLabel->setText(tr2i18n("Loop", nullptr));
#if QT_CONFIG(tooltip)
        loopB->setToolTip(tr2i18n("Start Framing (Looping)...", nullptr));
#endif // QT_CONFIG(tooltip)
        loopB->setText(QString());
#if QT_CONFIG(tooltip)
        startB->setToolTip(tr2i18n("Start Sequence", nullptr));
#endif // QT_CONFIG(tooltip)
        startB->setText(QString());
#if QT_CONFIG(tooltip)
        liveVideoB->setToolTip(tr2i18n("Live Video...", nullptr));
#endif // QT_CONFIG(tooltip)
        liveVideoB->setText(QString());
#if QT_CONFIG(tooltip)
        previewB->setToolTip(tr2i18n("Capture a Preview...", nullptr));
#endif // QT_CONFIG(tooltip)
        previewB->setText(QString());
#if QT_CONFIG(tooltip)
        darkB->setToolTip(tr2i18n("<html><head/><body><p>Automatically apply dark subtraction on preview images if a suitable dark frame is available.</p></body></html>", nullptr));
#endif // QT_CONFIG(tooltip)
        darkB->setText(tr2i18n("Dark", nullptr));
#if QT_CONFIG(tooltip)
        pauseB->setToolTip(tr2i18n("Pause Sequence", nullptr));
#endif // QT_CONFIG(tooltip)
        pauseB->setText(QString());
        jobLabel->setText(tr2i18n("Total remaining:", nullptr));
        frameInfoLabel->setText(tr2i18n("Expose (-/-):", nullptr));
        frameRemainingTime->setText(tr2i18n("--:--:--", nullptr));
        avgDownloadTime->setText(QString());
        progressLabel->setText(tr2i18n("<b>Progress</b>", nullptr));
        jobRemainingTime->setText(tr2i18n("--:--:--", nullptr));
        avgDownloadLabel->setText(tr2i18n("Avg. Download:", nullptr));
        secLabel->setText(tr2i18n("sec", nullptr));
        targetDriftLabel->setText(tr2i18n("Target drift:", nullptr));
        targetDrift->setText(tr2i18n("0.0", nullptr));
        targetDriftUnit->setText(tr2i18n("\"", nullptr));
#if QT_CONFIG(tooltip)
        esqLoadB->setToolTip(tr2i18n("Load a new sequence file", nullptr));
#endif // QT_CONFIG(tooltip)
        esqLoadB->setText(tr2i18n("Load...", nullptr));
#if QT_CONFIG(tooltip)
        esqSaveAsB->setToolTip(tr2i18n("Save to a new sequence file", nullptr));
#endif // QT_CONFIG(tooltip)
        esqSaveAsB->setText(tr2i18n("Save As...", nullptr));
        (void)Camera;
    } // retranslateUi

};

namespace Ui {
    class Camera: public Ui_Camera {};
} // namespace Ui

QT_END_NAMESPACE

#endif // CAMERA_H

