/*
 * This file was generated by qdbusxml2cpp version 0.8
 * Source file was org.kde.kstars.Ekos.Guide.xml
 *
 * qdbusxml2cpp is Copyright (C) The Qt Company Ltd. and other contributors.
 *
 * This is an auto-generated file.
 * This file may have been hand-edited. Look for HAND-EDIT comments
 * before re-generating it.
 */

#ifndef GUIDEADAPTOR_H
#define GUIDEADAPTOR_H

#include <QtCore/QObject>
#include <QtDBus/QtDBus>
#include "ekos/guide/guide.h"
#include <QtCore/qcontainerfwd.h>

/*
 * Adaptor class for interface org.kde.kstars.Ekos.Guide
 */
class GuideAdaptor: public QDBusAbstractAdaptor
{
    Q_OBJECT
    Q_CLASSINFO("D-Bus Interface", "org.kde.kstars.Ekos.Guide")
    Q_CLASSINFO("D-Bus Introspection", ""
"  <interface name=\"org.kde.kstars.Ekos.Guide\">\n"
"    <property access=\"readwrite\" type=\"s\" name=\"opticalTrain\"/>\n"
"    <property access=\"read\" type=\"s\" name=\"camera\"/>\n"
"    <property access=\"read\" type=\"s\" name=\"guider\"/>\n"
"    <property access=\"read\" type=\"as\" name=\"logText\"/>\n"
"    <property access=\"readwrite\" type=\"d\" name=\"exposure\"/>\n"
"    <property access=\"read\" type=\"i\" name=\"status\">\n"
"      <annotation value=\"Ekos::GuideState\" name=\"org.qtproject.QtDBus.QtTypeName\"/>\n"
"    </property>\n"
"    <property access=\"read\" type=\"ad\" name=\"axisDelta\">\n"
"      <annotation value=\"QList&lt;double&gt;\" name=\"org.qtproject.QtDBus.QtTypeName\"/>\n"
"    </property>\n"
"    <property access=\"read\" type=\"ad\" name=\"axisSigma\">\n"
"      <annotation value=\"QList&lt;double&gt;\" name=\"org.qtproject.QtDBus.QtTypeName\"/>\n"
"    </property>\n"
"    <method name=\"connectGuider\">\n"
"      <arg direction=\"out\" type=\"b\"/>\n"
"    </method>\n"
"    <method name=\"disconnectGuider\">\n"
"      <arg direction=\"out\" type=\"b\"/>\n"
"    </method>\n"
"    <method name=\"guide\">\n"
"      <arg direction=\"out\" type=\"b\"/>\n"
"    </method>\n"
"    <method name=\"abort\">\n"
"      <arg direction=\"out\" type=\"b\"/>\n"
"    </method>\n"
"    <method name=\"calibrate\">\n"
"      <arg direction=\"out\" type=\"b\"/>\n"
"    </method>\n"
"    <method name=\"capture\">\n"
"      <arg direction=\"out\" type=\"b\"/>\n"
"    </method>\n"
"    <method name=\"loop\">\n"
"      <annotation value=\"true\" name=\"org.freedesktop.DBus.Method.NoReply\"/>\n"
"    </method>\n"
"    <method name=\"dither\">\n"
"      <arg direction=\"out\" type=\"b\"/>\n"
"    </method>\n"
"    <method name=\"suspend\">\n"
"      <arg direction=\"out\" type=\"b\"/>\n"
"    </method>\n"
"    <method name=\"resume\">\n"
"      <arg direction=\"out\" type=\"b\"/>\n"
"    </method>\n"
"    <method name=\"clearCalibration\">\n"
"      <annotation value=\"true\" name=\"org.freedesktop.DBus.Method.NoReply\"/>\n"
"    </method>\n"
"    <method name=\"reloadAIWeights\">\n"
"      <annotation value=\"true\" name=\"org.freedesktop.DBus.Method.NoReply\"/>\n"
"    </method>\n"
"    <method name=\"setDarkFrameEnabled\">\n"
"      <arg direction=\"in\" type=\"b\" name=\"enable\"/>\n"
"      <annotation value=\"true\" name=\"org.freedesktop.DBus.Method.NoReply\"/>\n"
"    </method>\n"
"    <method name=\"setSubFrameEnabled\">\n"
"      <arg direction=\"in\" type=\"b\" name=\"enable\"/>\n"
"      <annotation value=\"true\" name=\"org.freedesktop.DBus.Method.NoReply\"/>\n"
"    </method>\n"
"    <method name=\"setAutoStarEnabled\">\n"
"      <arg direction=\"in\" type=\"b\" name=\"enable\"/>\n"
"      <annotation value=\"true\" name=\"org.freedesktop.DBus.Method.NoReply\"/>\n"
"    </method>\n"
"    <method name=\"setGuiderType\">\n"
"      <arg direction=\"in\" type=\"i\" name=\"guideType\"/>\n"
"      <arg direction=\"out\" type=\"b\"/>\n"
"    </method>\n"
"    <signal name=\"newStatus\">\n"
"      <arg direction=\"out\" type=\"(i)\" name=\"status\"/>\n"
"      <annotation value=\"Ekos::GuideState\" name=\"org.qtproject.QtDBus.QtTypeName.In0\"/>\n"
"      <annotation value=\"Ekos::GuideState\" name=\"org.qtproject.QtDBus.QtTypeName.Out0\"/>\n"
"    </signal>\n"
"    <signal name=\"newAxisDelta\">\n"
"      <arg direction=\"out\" type=\"d\" name=\"ra\"/>\n"
"      <arg direction=\"out\" type=\"d\" name=\"de\"/>\n"
"    </signal>\n"
"    <signal name=\"newAxisSigma\">\n"
"      <arg direction=\"out\" type=\"d\" name=\"ra\"/>\n"
"      <arg direction=\"out\" type=\"d\" name=\"de\"/>\n"
"    </signal>\n"
"    <signal name=\"newLog\">\n"
"      <arg direction=\"out\" type=\"s\" name=\"text\"/>\n"
"    </signal>\n"
"  </interface>\n"
        "")
public:
    GuideAdaptor(Ekos::Guide *parent);
    ~GuideAdaptor() override;

    inline Ekos::Guide *parent() const
    { return static_cast<Ekos::Guide *>(QObject::parent()); }

public: // PROPERTIES
    Q_PROPERTY(QList<double> axisDelta READ axisDelta)
    QList<double> axisDelta() const;

    Q_PROPERTY(QList<double> axisSigma READ axisSigma)
    QList<double> axisSigma() const;

    Q_PROPERTY(QString camera READ camera)
    QString camera() const;

    Q_PROPERTY(double exposure READ exposure WRITE setExposure)
    double exposure() const;
    void setExposure(double value);

    Q_PROPERTY(QString guider READ guider)
    QString guider() const;

    Q_PROPERTY(QStringList logText READ logText)
    QStringList logText() const;

    Q_PROPERTY(QString opticalTrain READ opticalTrain WRITE setOpticalTrain)
    QString opticalTrain() const;
    void setOpticalTrain(const QString &value);

    Q_PROPERTY(int status READ status)
    int status() const;

public Q_SLOTS: // METHODS
    bool abort();
    bool calibrate();
    bool capture();
    Q_NOREPLY void clearCalibration();
    bool connectGuider();
    bool disconnectGuider();
    bool dither();
    bool guide();
    Q_NOREPLY void loop();
    Q_NOREPLY void reloadAIWeights();
    bool resume();
    Q_NOREPLY void setAutoStarEnabled(bool enable);
    Q_NOREPLY void setDarkFrameEnabled(bool enable);
    bool setGuiderType(int guideType);
    Q_NOREPLY void setSubFrameEnabled(bool enable);
    bool suspend();
Q_SIGNALS: // SIGNALS
    void newAxisDelta(double ra, double de);
    void newAxisSigma(double ra, double de);
    void newLog(const QString &text);
    void newStatus(Ekos::GuideState status);
};

#endif
