/*
 * This file was generated by qdbusxml2cpp version 0.8
 * Source file was org.kde.kstars.Ekos.OpticalTrain.xml
 *
 * qdbusxml2cpp is Copyright (C) The Qt Company Ltd. and other contributors.
 *
 * This is an auto-generated file.
 * Do not edit! All changes made to it will be lost.
 */

#include "opticaltrainadaptor.h"
#include <QtCore/QMetaObject>
#include <QtCore/QByteArray>
#include <QtCore/QList>
#include <QtCore/QMap>
#include <QtCore/QString>
#include <QtCore/QStringList>
#include <QtCore/QVariant>

/*
 * Implementation of adaptor class OpticalTrainAdaptor
 */

OpticalTrainAdaptor::OpticalTrainAdaptor(Ekos::OpticalTrainDBusInterface *parent)
    : QDBusAbstractAdaptor(parent)
{
    // constructor
    setAutoRelaySignals(true);
}

OpticalTrainAdaptor::~OpticalTrainAdaptor()
{
    // destructor
}

QString OpticalTrainAdaptor::camera() const
{
    // get the value of property camera
    return qvariant_cast< QString >(parent()->property("camera"));
}

QString OpticalTrainAdaptor::dustCap() const
{
    // get the value of property dustCap
    return qvariant_cast< QString >(parent()->property("dustCap"));
}

QString OpticalTrainAdaptor::filterWheel() const
{
    // get the value of property filterWheel
    return qvariant_cast< QString >(parent()->property("filterWheel"));
}

QString OpticalTrainAdaptor::focuser() const
{
    // get the value of property focuser
    return qvariant_cast< QString >(parent()->property("focuser"));
}

QString OpticalTrainAdaptor::guider() const
{
    // get the value of property guider
    return qvariant_cast< QString >(parent()->property("guider"));
}

int OpticalTrainAdaptor::id() const
{
    // get the value of property id
    return qvariant_cast< int >(parent()->property("id"));
}

QString OpticalTrainAdaptor::lightBox() const
{
    // get the value of property lightBox
    return qvariant_cast< QString >(parent()->property("lightBox"));
}

QString OpticalTrainAdaptor::mount() const
{
    // get the value of property mount
    return qvariant_cast< QString >(parent()->property("mount"));
}

QString OpticalTrainAdaptor::name() const
{
    // get the value of property name
    return qvariant_cast< QString >(parent()->property("name"));
}

double OpticalTrainAdaptor::reducer() const
{
    // get the value of property reducer
    return qvariant_cast< double >(parent()->property("reducer"));
}

QString OpticalTrainAdaptor::rotator() const
{
    // get the value of property rotator
    return qvariant_cast< QString >(parent()->property("rotator"));
}

QString OpticalTrainAdaptor::scope() const
{
    // get the value of property scope
    return qvariant_cast< QString >(parent()->property("scope"));
}

bool OpticalTrainAdaptor::remove()
{
    // handle method call org.kde.kstars.Ekos.OpticalTrain.remove
    return parent()->remove();
}

void OpticalTrainAdaptor::reset()
{
    // handle method call org.kde.kstars.Ekos.OpticalTrain.reset
    parent()->reset();
}

bool OpticalTrainAdaptor::setCamera(const QString &name)
{
    // handle method call org.kde.kstars.Ekos.OpticalTrain.setCamera
    return parent()->setCamera(name);
}

bool OpticalTrainAdaptor::setDustCap(const QString &name)
{
    // handle method call org.kde.kstars.Ekos.OpticalTrain.setDustCap
    return parent()->setDustCap(name);
}

bool OpticalTrainAdaptor::setFilterWheel(const QString &name)
{
    // handle method call org.kde.kstars.Ekos.OpticalTrain.setFilterWheel
    return parent()->setFilterWheel(name);
}

bool OpticalTrainAdaptor::setFocuser(const QString &name)
{
    // handle method call org.kde.kstars.Ekos.OpticalTrain.setFocuser
    return parent()->setFocuser(name);
}

bool OpticalTrainAdaptor::setGuider(const QString &name)
{
    // handle method call org.kde.kstars.Ekos.OpticalTrain.setGuider
    return parent()->setGuider(name);
}

bool OpticalTrainAdaptor::setLightBox(const QString &name)
{
    // handle method call org.kde.kstars.Ekos.OpticalTrain.setLightBox
    return parent()->setLightBox(name);
}

bool OpticalTrainAdaptor::setMount(const QString &name)
{
    // handle method call org.kde.kstars.Ekos.OpticalTrain.setMount
    return parent()->setMount(name);
}

bool OpticalTrainAdaptor::setReducer(double value)
{
    // handle method call org.kde.kstars.Ekos.OpticalTrain.setReducer
    return parent()->setReducer(value);
}

bool OpticalTrainAdaptor::setRotator(const QString &name)
{
    // handle method call org.kde.kstars.Ekos.OpticalTrain.setRotator
    return parent()->setRotator(name);
}

bool OpticalTrainAdaptor::setScope(const QString &name)
{
    // handle method call org.kde.kstars.Ekos.OpticalTrain.setScope
    return parent()->setScope(name);
}


#include "moc_opticaltrainadaptor.cpp"
