/****************************************************************************
** Meta object code from reading C++ file 'templatelibrarywidget.h'
**
** Created by: The Qt Meta Object Compiler version 69 (Qt 6.11.1)
**
** WARNING! All changes made in this file will be lost!
*****************************************************************************/

#include "../../../../kstars-3.8.4.1/kstars/ekos/scheduler/taskqueue/ui/templatelibrarywidget.h"
#include <QtCore/qmetatype.h>

#include <QtCore/qtmochelpers.h>

#include <memory>


#include <QtCore/qxptype_traits.h>
#if !defined(Q_MOC_OUTPUT_REVISION)
#error "The header file 'templatelibrarywidget.h' doesn't include <QObject>."
#elif Q_MOC_OUTPUT_REVISION != 69
#error "This file was generated using the moc from 6.11.1. It"
#error "cannot be used with the include files from this version of Qt."
#error "(The moc has changed too much.)"
#endif

#ifndef Q_CONSTINIT
#define Q_CONSTINIT
#endif

QT_WARNING_PUSH
QT_WARNING_DISABLE_DEPRECATED
QT_WARNING_DISABLE_GCC("-Wuseless-cast")
namespace {
struct qt_meta_tag_ZN4Ekos21TemplateLibraryWidgetE_t {};
} // unnamed namespace

template <> constexpr inline auto Ekos::TemplateLibraryWidget::qt_create_metaobjectdata<qt_meta_tag_ZN4Ekos21TemplateLibraryWidgetE_t>()
{
    namespace QMC = QtMocConstants;
    QtMocHelpers::StringRefStorage qt_stringData {
        "Ekos::TemplateLibraryWidget",
        "addTemplateRequested",
        "",
        "TaskTemplate*",
        "tmpl",
        "selectionChanged",
        "onSelectionChanged",
        "onItemDoubleClicked",
        "QTreeWidgetItem*",
        "item",
        "column",
        "onAddToQueueClicked",
        "onCreateCustomTemplateClicked",
        "onRefreshClicked",
        "onEditTemplateClicked",
        "onDeleteTemplateClicked"
    };

    QtMocHelpers::UintData qt_methods {
        // Signal 'addTemplateRequested'
        QtMocHelpers::SignalData<void(TaskTemplate *)>(1, 2, QMC::AccessPublic, QMetaType::Void, {{
            { 0x80000000 | 3, 4 },
        }}),
        // Signal 'selectionChanged'
        QtMocHelpers::SignalData<void(TaskTemplate *)>(5, 2, QMC::AccessPublic, QMetaType::Void, {{
            { 0x80000000 | 3, 4 },
        }}),
        // Slot 'onSelectionChanged'
        QtMocHelpers::SlotData<void()>(6, 2, QMC::AccessPrivate, QMetaType::Void),
        // Slot 'onItemDoubleClicked'
        QtMocHelpers::SlotData<void(QTreeWidgetItem *, int)>(7, 2, QMC::AccessPrivate, QMetaType::Void, {{
            { 0x80000000 | 8, 9 }, { QMetaType::Int, 10 },
        }}),
        // Slot 'onAddToQueueClicked'
        QtMocHelpers::SlotData<void()>(11, 2, QMC::AccessPrivate, QMetaType::Void),
        // Slot 'onCreateCustomTemplateClicked'
        QtMocHelpers::SlotData<void()>(12, 2, QMC::AccessPrivate, QMetaType::Void),
        // Slot 'onRefreshClicked'
        QtMocHelpers::SlotData<void()>(13, 2, QMC::AccessPrivate, QMetaType::Void),
        // Slot 'onEditTemplateClicked'
        QtMocHelpers::SlotData<void()>(14, 2, QMC::AccessPrivate, QMetaType::Void),
        // Slot 'onDeleteTemplateClicked'
        QtMocHelpers::SlotData<void()>(15, 2, QMC::AccessPrivate, QMetaType::Void),
    };
    QtMocHelpers::UintData qt_properties {
    };
    QtMocHelpers::UintData qt_enums {
    };
    return QtMocHelpers::metaObjectData<TemplateLibraryWidget, qt_meta_tag_ZN4Ekos21TemplateLibraryWidgetE_t>(QMC::MetaObjectFlag{}, qt_stringData,
            qt_methods, qt_properties, qt_enums);
}
Q_CONSTINIT const QMetaObject Ekos::TemplateLibraryWidget::staticMetaObject = { {
    QMetaObject::SuperData::link<QWidget::staticMetaObject>(),
    qt_staticMetaObjectStaticContent<qt_meta_tag_ZN4Ekos21TemplateLibraryWidgetE_t>.stringdata,
    qt_staticMetaObjectStaticContent<qt_meta_tag_ZN4Ekos21TemplateLibraryWidgetE_t>.data,
    qt_static_metacall,
    nullptr,
    qt_staticMetaObjectRelocatingContent<qt_meta_tag_ZN4Ekos21TemplateLibraryWidgetE_t>.metaTypes,
    nullptr
} };

void Ekos::TemplateLibraryWidget::qt_static_metacall(QObject *_o, QMetaObject::Call _c, int _id, void **_a)
{
    auto *_t = static_cast<TemplateLibraryWidget *>(_o);
    if (_c == QMetaObject::InvokeMetaMethod) {
        switch (_id) {
        case 0: _t->addTemplateRequested((*reinterpret_cast<std::add_pointer_t<TaskTemplate*>>(_a[1]))); break;
        case 1: _t->selectionChanged((*reinterpret_cast<std::add_pointer_t<TaskTemplate*>>(_a[1]))); break;
        case 2: _t->onSelectionChanged(); break;
        case 3: _t->onItemDoubleClicked((*reinterpret_cast<std::add_pointer_t<QTreeWidgetItem*>>(_a[1])),(*reinterpret_cast<std::add_pointer_t<int>>(_a[2]))); break;
        case 4: _t->onAddToQueueClicked(); break;
        case 5: _t->onCreateCustomTemplateClicked(); break;
        case 6: _t->onRefreshClicked(); break;
        case 7: _t->onEditTemplateClicked(); break;
        case 8: _t->onDeleteTemplateClicked(); break;
        default: ;
        }
    }
    if (_c == QMetaObject::IndexOfMethod) {
        if (QtMocHelpers::indexOfMethod<void (TemplateLibraryWidget::*)(TaskTemplate * )>(_a, &TemplateLibraryWidget::addTemplateRequested, 0))
            return;
        if (QtMocHelpers::indexOfMethod<void (TemplateLibraryWidget::*)(TaskTemplate * )>(_a, &TemplateLibraryWidget::selectionChanged, 1))
            return;
    }
}

const QMetaObject *Ekos::TemplateLibraryWidget::metaObject() const
{
    return QObject::d_ptr->metaObject ? QObject::d_ptr->dynamicMetaObject() : &staticMetaObject;
}

void *Ekos::TemplateLibraryWidget::qt_metacast(const char *_clname)
{
    if (!_clname) return nullptr;
    if (!strcmp(_clname, qt_staticMetaObjectStaticContent<qt_meta_tag_ZN4Ekos21TemplateLibraryWidgetE_t>.strings))
        return static_cast<void*>(this);
    return QWidget::qt_metacast(_clname);
}

int Ekos::TemplateLibraryWidget::qt_metacall(QMetaObject::Call _c, int _id, void **_a)
{
    _id = QWidget::qt_metacall(_c, _id, _a);
    if (_id < 0)
        return _id;
    if (_c == QMetaObject::InvokeMetaMethod) {
        if (_id < 9)
            qt_static_metacall(this, _c, _id, _a);
        _id -= 9;
    }
    if (_c == QMetaObject::RegisterMethodArgumentMetaType) {
        if (_id < 9)
            *reinterpret_cast<QMetaType *>(_a[0]) = QMetaType();
        _id -= 9;
    }
    return _id;
}

// SIGNAL 0
void Ekos::TemplateLibraryWidget::addTemplateRequested(TaskTemplate * _t1)
{
    QMetaObject::activate<void>(this, &staticMetaObject, 0, nullptr, _t1);
}

// SIGNAL 1
void Ekos::TemplateLibraryWidget::selectionChanged(TaskTemplate * _t1)
{
    QMetaObject::activate<void>(this, &staticMetaObject, 1, nullptr, _t1);
}
QT_WARNING_POP
