/********************************************************************************
** Form generated from reading UI file 'catalogcsvimport.ui'
**
** Created by: Qt User Interface Compiler version 6.11.1
**
** WARNING! All changes made in this file will be lost when recompiling UI file!
********************************************************************************/

#ifndef UI_CATALOGCSVIMPORT_H
#define UI_CATALOGCSVIMPORT_H

#include <QtCore/QVariant>
#include <QtGui/QIcon>
#include <QtWidgets/QAbstractButton>
#include <QtWidgets/QApplication>
#include <QtWidgets/QComboBox>
#include <QtWidgets/QDialog>
#include <QtWidgets/QDialogButtonBox>
#include <QtWidgets/QGridLayout>
#include <QtWidgets/QGroupBox>
#include <QtWidgets/QHBoxLayout>
#include <QtWidgets/QHeaderView>
#include <QtWidgets/QLabel>
#include <QtWidgets/QLineEdit>
#include <QtWidgets/QPushButton>
#include <QtWidgets/QSpacerItem>
#include <QtWidgets/QSpinBox>
#include <QtWidgets/QTableView>
#include <QtWidgets/QTableWidget>
#include <QtWidgets/QVBoxLayout>
#include <klocalizedstring.h>

QT_BEGIN_NAMESPACE

class Ui_CatalogCSVImport
{
public:
    QVBoxLayout *verticalLayout;
    QHBoxLayout *horizontalLayout_5;
    QGroupBox *groupBox;
    QGridLayout *gridLayout;
    QLabel *obj_count;
    QLabel *label_3;
    QLabel *file_path_label;
    QSpacerItem *horizontalSpacer;
    QLabel *label_2;
    QLabel *label_4;
    QLineEdit *comment_prefix;
    QSpacerItem *horizontalSpacer_2;
    QLineEdit *separator;
    QSpinBox *skip;
    QPushButton *file_select_button;
    QLabel *label;
    QGroupBox *groupBox_2;
    QHBoxLayout *horizontalLayout_4;
    QHBoxLayout *horizontalLayout_3;
    QVBoxLayout *verticalLayout_3;
    QLabel *label_6;
    QComboBox *ra_units;
    QVBoxLayout *verticalLayout_5;
    QLabel *label_7;
    QComboBox *dec_units;
    QHBoxLayout *horizontalLayout_2;
    QGroupBox *column_mapping;
    QGroupBox *type_mapping;
    QHBoxLayout *horizontalLayout;
    QTableWidget *type_table;
    QVBoxLayout *verticalLayout_2;
    QPushButton *add_map;
    QPushButton *remove_map;
    QSpacerItem *verticalSpacer;
    QHBoxLayout *horizontalLayout_6;
    QPushButton *preview_button;
    QSpacerItem *horizontalSpacer_3;
    QTableView *preview;
    QDialogButtonBox *buttonBox;

    void setupUi(QDialog *CatalogCSVImport)
    {
        if (CatalogCSVImport->objectName().isEmpty())
            CatalogCSVImport->setObjectName("CatalogCSVImport");
        CatalogCSVImport->resize(887, 456);
        verticalLayout = new QVBoxLayout(CatalogCSVImport);
        verticalLayout->setObjectName("verticalLayout");
        horizontalLayout_5 = new QHBoxLayout();
        horizontalLayout_5->setObjectName("horizontalLayout_5");
        horizontalLayout_5->setContentsMargins(-1, 0, -1, -1);
        groupBox = new QGroupBox(CatalogCSVImport);
        groupBox->setObjectName("groupBox");
        QSizePolicy sizePolicy(QSizePolicy::Policy::Minimum, QSizePolicy::Policy::Minimum);
        sizePolicy.setHorizontalStretch(0);
        sizePolicy.setVerticalStretch(0);
        sizePolicy.setHeightForWidth(groupBox->sizePolicy().hasHeightForWidth());
        groupBox->setSizePolicy(sizePolicy);
        groupBox->setMinimumSize(QSize(0, 0));
        gridLayout = new QGridLayout(groupBox);
        gridLayout->setObjectName("gridLayout");
        obj_count = new QLabel(groupBox);
        obj_count->setObjectName("obj_count");

        gridLayout->addWidget(obj_count, 2, 4, 1, 1);

        label_3 = new QLabel(groupBox);
        label_3->setObjectName("label_3");

        gridLayout->addWidget(label_3, 1, 8, 1, 1);

        file_path_label = new QLabel(groupBox);
        file_path_label->setObjectName("file_path_label");

        gridLayout->addWidget(file_path_label, 2, 1, 1, 3);

        horizontalSpacer = new QSpacerItem(40, 20, QSizePolicy::Policy::Expanding, QSizePolicy::Policy::Minimum);

        gridLayout->addItem(horizontalSpacer, 1, 5, 1, 1);

        label_2 = new QLabel(groupBox);
        label_2->setObjectName("label_2");

        gridLayout->addWidget(label_2, 1, 6, 1, 1);

        label_4 = new QLabel(groupBox);
        label_4->setObjectName("label_4");

        gridLayout->addWidget(label_4, 1, 3, 1, 1);

        comment_prefix = new QLineEdit(groupBox);
        comment_prefix->setObjectName("comment_prefix");
        QSizePolicy sizePolicy1(QSizePolicy::Policy::Minimum, QSizePolicy::Policy::Fixed);
        sizePolicy1.setHorizontalStretch(0);
        sizePolicy1.setVerticalStretch(0);
        sizePolicy1.setHeightForWidth(comment_prefix->sizePolicy().hasHeightForWidth());
        comment_prefix->setSizePolicy(sizePolicy1);
        comment_prefix->setMinimumSize(QSize(100, 0));
        comment_prefix->setMaximumSize(QSize(1000, 16777215));
        comment_prefix->setMaxLength(1);

        gridLayout->addWidget(comment_prefix, 1, 1, 1, 1);

        horizontalSpacer_2 = new QSpacerItem(40, 20, QSizePolicy::Policy::Expanding, QSizePolicy::Policy::Minimum);

        gridLayout->addItem(horizontalSpacer_2, 1, 2, 1, 1);

        separator = new QLineEdit(groupBox);
        separator->setObjectName("separator");
        separator->setMaximumSize(QSize(16777176, 16777215));
        separator->setMaxLength(1);

        gridLayout->addWidget(separator, 1, 4, 1, 1);

        skip = new QSpinBox(groupBox);
        skip->setObjectName("skip");

        gridLayout->addWidget(skip, 1, 7, 1, 1);

        file_select_button = new QPushButton(groupBox);
        file_select_button->setObjectName("file_select_button");

        gridLayout->addWidget(file_select_button, 2, 0, 1, 1);

        label = new QLabel(groupBox);
        label->setObjectName("label");

        gridLayout->addWidget(label, 1, 0, 1, 1);


        horizontalLayout_5->addWidget(groupBox);

        groupBox_2 = new QGroupBox(CatalogCSVImport);
        groupBox_2->setObjectName("groupBox_2");
        horizontalLayout_4 = new QHBoxLayout(groupBox_2);
        horizontalLayout_4->setObjectName("horizontalLayout_4");
        horizontalLayout_3 = new QHBoxLayout();
        horizontalLayout_3->setObjectName("horizontalLayout_3");
        verticalLayout_3 = new QVBoxLayout();
        verticalLayout_3->setObjectName("verticalLayout_3");
        label_6 = new QLabel(groupBox_2);
        label_6->setObjectName("label_6");

        verticalLayout_3->addWidget(label_6);

        ra_units = new QComboBox(groupBox_2);
        ra_units->setObjectName("ra_units");

        verticalLayout_3->addWidget(ra_units);


        horizontalLayout_3->addLayout(verticalLayout_3);

        verticalLayout_5 = new QVBoxLayout();
        verticalLayout_5->setObjectName("verticalLayout_5");
        label_7 = new QLabel(groupBox_2);
        label_7->setObjectName("label_7");

        verticalLayout_5->addWidget(label_7);

        dec_units = new QComboBox(groupBox_2);
        dec_units->setObjectName("dec_units");

        verticalLayout_5->addWidget(dec_units);


        horizontalLayout_3->addLayout(verticalLayout_5);


        horizontalLayout_4->addLayout(horizontalLayout_3);


        horizontalLayout_5->addWidget(groupBox_2);


        verticalLayout->addLayout(horizontalLayout_5);

        horizontalLayout_2 = new QHBoxLayout();
        horizontalLayout_2->setObjectName("horizontalLayout_2");
        horizontalLayout_2->setContentsMargins(-1, 0, -1, -1);
        column_mapping = new QGroupBox(CatalogCSVImport);
        column_mapping->setObjectName("column_mapping");
        QSizePolicy sizePolicy2(QSizePolicy::Policy::Expanding, QSizePolicy::Policy::Minimum);
        sizePolicy2.setHorizontalStretch(0);
        sizePolicy2.setVerticalStretch(0);
        sizePolicy2.setHeightForWidth(column_mapping->sizePolicy().hasHeightForWidth());
        column_mapping->setSizePolicy(sizePolicy2);

        horizontalLayout_2->addWidget(column_mapping);

        type_mapping = new QGroupBox(CatalogCSVImport);
        type_mapping->setObjectName("type_mapping");
        type_mapping->setMaximumSize(QSize(300, 16777215));
        horizontalLayout = new QHBoxLayout(type_mapping);
        horizontalLayout->setObjectName("horizontalLayout");
        type_table = new QTableWidget(type_mapping);
        type_table->setObjectName("type_table");
        type_table->setMaximumSize(QSize(16777215, 16777215));

        horizontalLayout->addWidget(type_table);

        verticalLayout_2 = new QVBoxLayout();
        verticalLayout_2->setObjectName("verticalLayout_2");
        verticalLayout_2->setContentsMargins(0, -1, -1, -1);
        add_map = new QPushButton(type_mapping);
        add_map->setObjectName("add_map");
        QIcon icon;
        QString iconThemeName = QString::fromUtf8("list-add");
        if (QIcon::hasThemeIcon(iconThemeName)) {
            icon = QIcon::fromTheme(iconThemeName);
        } else {
            icon.addFile(QString::fromUtf8("."), QSize(), QIcon::Mode::Normal, QIcon::State::Off);
        }
        add_map->setIcon(icon);

        verticalLayout_2->addWidget(add_map);

        remove_map = new QPushButton(type_mapping);
        remove_map->setObjectName("remove_map");
        QIcon icon1;
        iconThemeName = QString::fromUtf8("list-remove");
        if (QIcon::hasThemeIcon(iconThemeName)) {
            icon1 = QIcon::fromTheme(iconThemeName);
        } else {
            icon1.addFile(QString::fromUtf8("."), QSize(), QIcon::Mode::Normal, QIcon::State::Off);
        }
        remove_map->setIcon(icon1);

        verticalLayout_2->addWidget(remove_map);

        verticalSpacer = new QSpacerItem(20, 40, QSizePolicy::Policy::Minimum, QSizePolicy::Policy::Expanding);

        verticalLayout_2->addItem(verticalSpacer);


        horizontalLayout->addLayout(verticalLayout_2);


        horizontalLayout_2->addWidget(type_mapping);


        verticalLayout->addLayout(horizontalLayout_2);

        horizontalLayout_6 = new QHBoxLayout();
        horizontalLayout_6->setObjectName("horizontalLayout_6");
        horizontalLayout_6->setContentsMargins(-1, -1, -1, 0);
        preview_button = new QPushButton(CatalogCSVImport);
        preview_button->setObjectName("preview_button");

        horizontalLayout_6->addWidget(preview_button);

        horizontalSpacer_3 = new QSpacerItem(40, 20, QSizePolicy::Policy::Expanding, QSizePolicy::Policy::Minimum);

        horizontalLayout_6->addItem(horizontalSpacer_3);


        verticalLayout->addLayout(horizontalLayout_6);

        preview = new QTableView(CatalogCSVImport);
        preview->setObjectName("preview");

        verticalLayout->addWidget(preview);

        buttonBox = new QDialogButtonBox(CatalogCSVImport);
        buttonBox->setObjectName("buttonBox");
        buttonBox->setOrientation(Qt::Horizontal);
        buttonBox->setStandardButtons(QDialogButtonBox::Cancel|QDialogButtonBox::Ok);

        verticalLayout->addWidget(buttonBox);


        retranslateUi(CatalogCSVImport);
        QObject::connect(buttonBox, &QDialogButtonBox::accepted, CatalogCSVImport, qOverload<>(&QDialog::accept));
        QObject::connect(buttonBox, &QDialogButtonBox::rejected, CatalogCSVImport, qOverload<>(&QDialog::reject));

        QMetaObject::connectSlotsByName(CatalogCSVImport);
    } // setupUi

    void retranslateUi(QDialog *CatalogCSVImport)
    {
        CatalogCSVImport->setWindowTitle(tr2i18n("CSV Import", nullptr));
        groupBox->setTitle(tr2i18n("Input", nullptr));
        obj_count->setText(QString());
        label_3->setText(tr2i18n("lines", nullptr));
        file_path_label->setText(QString());
        label_2->setText(tr2i18n("Skip first:", nullptr));
        label_4->setText(tr2i18n("Separator:", nullptr));
        comment_prefix->setText(tr2i18n("#", nullptr));
        separator->setText(tr2i18n(",", nullptr));
        file_select_button->setText(tr2i18n("Select/Read...", nullptr));
        label->setText(tr2i18n("Comment prefix:", nullptr));
        groupBox_2->setTitle(tr2i18n("Coordinate Units", nullptr));
        label_6->setText(tr2i18n("RA:", nullptr));
        label_7->setText(tr2i18n("Dec:", nullptr));
        column_mapping->setTitle(tr2i18n("Mapping", nullptr));
        type_mapping->setTitle(tr2i18n("Type Mapping", nullptr));
        preview_button->setText(tr2i18n("Preview", nullptr));
    } // retranslateUi

};

namespace Ui {
    class CatalogCSVImport: public Ui_CatalogCSVImport {};
} // namespace Ui

QT_END_NAMESPACE

#endif // CATALOGCSVIMPORT_H

