/********************************************************************************
** Form generated from reading UI file 'modcalcjd.ui'
**
** Created by: Qt User Interface Compiler version 6.11.1
**
** WARNING! All changes made in this file will be lost when recompiling UI file!
********************************************************************************/

#ifndef UI_MODCALCJD_H
#define UI_MODCALCJD_H

#include <QtCore/QVariant>
#include <QtWidgets/QApplication>
#include <QtWidgets/QComboBox>
#include <QtWidgets/QDateTimeEdit>
#include <QtWidgets/QGridLayout>
#include <QtWidgets/QHBoxLayout>
#include <QtWidgets/QLabel>
#include <QtWidgets/QLineEdit>
#include <QtWidgets/QPushButton>
#include <QtWidgets/QSpacerItem>
#include <QtWidgets/QTabWidget>
#include <QtWidgets/QVBoxLayout>
#include <QtWidgets/QWidget>
#include <klocalizedstring.h>
#include "KUrlRequester"

QT_BEGIN_NAMESPACE

class Ui_modCalcJdDlg
{
public:
    QVBoxLayout *vboxLayout;
    QTabWidget *tabWidget;
    QWidget *tab;
    QVBoxLayout *vboxLayout1;
    QGridLayout *gridLayout;
    QLabel *label;
    QHBoxLayout *hboxLayout;
    QDateTimeEdit *DateTimeBox;
    QPushButton *NowButton;
    QLabel *label_2;
    QLineEdit *JDBox;
    QLabel *label_3;
    QLineEdit *ModJDBox;
    QSpacerItem *spacerItem;
    QWidget *tab_2;
    QVBoxLayout *vboxLayout2;
    QHBoxLayout *hboxLayout1;
    QLabel *label_4;
    QComboBox *InputComboBatch;
    QSpacerItem *spacerItem1;
    QSpacerItem *spacerItem2;
    QGridLayout *gridLayout1;
    QLabel *label_5;
    KUrlRequester *InputFileBatch;
    QLabel *label_6;
    KUrlRequester *OutputFileBatch;
    QSpacerItem *spacerItem3;
    QHBoxLayout *hboxLayout2;
    QSpacerItem *spacerItem4;
    QVBoxLayout *vboxLayout3;
    QPushButton *RunButtonBatch;
    QPushButton *ViewButtonBatch;
    QSpacerItem *spacerItem5;
    QSpacerItem *spacerItem6;

    void setupUi(QWidget *modCalcJdDlg)
    {
        if (modCalcJdDlg->objectName().isEmpty())
            modCalcJdDlg->setObjectName("modCalcJdDlg");
        modCalcJdDlg->resize(521, 340);
        vboxLayout = new QVBoxLayout(modCalcJdDlg);
        vboxLayout->setObjectName("vboxLayout");
        tabWidget = new QTabWidget(modCalcJdDlg);
        tabWidget->setObjectName("tabWidget");
        tab = new QWidget();
        tab->setObjectName("tab");
        tab->setGeometry(QRect(0, 0, 501, 294));
        vboxLayout1 = new QVBoxLayout(tab);
        vboxLayout1->setObjectName("vboxLayout1");
        gridLayout = new QGridLayout();
        gridLayout->setObjectName("gridLayout");
        label = new QLabel(tab);
        label->setObjectName("label");

        gridLayout->addWidget(label, 0, 0, 1, 1);

        hboxLayout = new QHBoxLayout();
        hboxLayout->setObjectName("hboxLayout");
        DateTimeBox = new QDateTimeEdit(tab);
        DateTimeBox->setObjectName("DateTimeBox");

        hboxLayout->addWidget(DateTimeBox);

        NowButton = new QPushButton(tab);
        NowButton->setObjectName("NowButton");

        hboxLayout->addWidget(NowButton);


        gridLayout->addLayout(hboxLayout, 0, 1, 1, 1);

        label_2 = new QLabel(tab);
        label_2->setObjectName("label_2");

        gridLayout->addWidget(label_2, 1, 0, 1, 1);

        JDBox = new QLineEdit(tab);
        JDBox->setObjectName("JDBox");

        gridLayout->addWidget(JDBox, 1, 1, 1, 1);

        label_3 = new QLabel(tab);
        label_3->setObjectName("label_3");

        gridLayout->addWidget(label_3, 2, 0, 1, 1);

        ModJDBox = new QLineEdit(tab);
        ModJDBox->setObjectName("ModJDBox");

        gridLayout->addWidget(ModJDBox, 2, 1, 1, 1);


        vboxLayout1->addLayout(gridLayout);

        spacerItem = new QSpacerItem(21, 125, QSizePolicy::Policy::Minimum, QSizePolicy::Policy::Expanding);

        vboxLayout1->addItem(spacerItem);

        tabWidget->addTab(tab, QString());
        tab_2 = new QWidget();
        tab_2->setObjectName("tab_2");
        tab_2->setGeometry(QRect(0, 0, 100, 30));
        vboxLayout2 = new QVBoxLayout(tab_2);
        vboxLayout2->setObjectName("vboxLayout2");
        hboxLayout1 = new QHBoxLayout();
        hboxLayout1->setObjectName("hboxLayout1");
        label_4 = new QLabel(tab_2);
        label_4->setObjectName("label_4");

        hboxLayout1->addWidget(label_4);

        InputComboBatch = new QComboBox(tab_2);
        InputComboBatch->addItem(QString());
        InputComboBatch->addItem(QString());
        InputComboBatch->addItem(QString());
        InputComboBatch->setObjectName("InputComboBatch");
        InputComboBatch->setSizeAdjustPolicy(QComboBox::AdjustToContents);

        hboxLayout1->addWidget(InputComboBatch);

        spacerItem1 = new QSpacerItem(40, 20, QSizePolicy::Policy::Expanding, QSizePolicy::Policy::Minimum);

        hboxLayout1->addItem(spacerItem1);


        vboxLayout2->addLayout(hboxLayout1);

        spacerItem2 = new QSpacerItem(20, 21, QSizePolicy::Policy::Minimum, QSizePolicy::Policy::Minimum);

        vboxLayout2->addItem(spacerItem2);

        gridLayout1 = new QGridLayout();
        gridLayout1->setObjectName("gridLayout1");
        label_5 = new QLabel(tab_2);
        label_5->setObjectName("label_5");

        gridLayout1->addWidget(label_5, 0, 0, 1, 1);

        InputFileBatch = new KUrlRequester(tab_2);
        InputFileBatch->setObjectName("InputFileBatch");

        gridLayout1->addWidget(InputFileBatch, 0, 1, 1, 1);

        label_6 = new QLabel(tab_2);
        label_6->setObjectName("label_6");

        gridLayout1->addWidget(label_6, 1, 0, 1, 1);

        OutputFileBatch = new KUrlRequester(tab_2);
        OutputFileBatch->setObjectName("OutputFileBatch");

        gridLayout1->addWidget(OutputFileBatch, 1, 1, 1, 1);


        vboxLayout2->addLayout(gridLayout1);

        spacerItem3 = new QSpacerItem(20, 20, QSizePolicy::Policy::Minimum, QSizePolicy::Policy::Minimum);

        vboxLayout2->addItem(spacerItem3);

        hboxLayout2 = new QHBoxLayout();
        hboxLayout2->setObjectName("hboxLayout2");
        spacerItem4 = new QSpacerItem(40, 20, QSizePolicy::Policy::Expanding, QSizePolicy::Policy::Minimum);

        hboxLayout2->addItem(spacerItem4);

        vboxLayout3 = new QVBoxLayout();
        vboxLayout3->setObjectName("vboxLayout3");
        RunButtonBatch = new QPushButton(tab_2);
        RunButtonBatch->setObjectName("RunButtonBatch");

        vboxLayout3->addWidget(RunButtonBatch);

        ViewButtonBatch = new QPushButton(tab_2);
        ViewButtonBatch->setObjectName("ViewButtonBatch");

        vboxLayout3->addWidget(ViewButtonBatch);


        hboxLayout2->addLayout(vboxLayout3);

        spacerItem5 = new QSpacerItem(40, 20, QSizePolicy::Policy::Expanding, QSizePolicy::Policy::Minimum);

        hboxLayout2->addItem(spacerItem5);


        vboxLayout2->addLayout(hboxLayout2);

        spacerItem6 = new QSpacerItem(20, 40, QSizePolicy::Policy::Minimum, QSizePolicy::Policy::Expanding);

        vboxLayout2->addItem(spacerItem6);

        tabWidget->addTab(tab_2, QString());

        vboxLayout->addWidget(tabWidget);


        retranslateUi(modCalcJdDlg);

        tabWidget->setCurrentIndex(0);


        QMetaObject::connectSlotsByName(modCalcJdDlg);
    } // setupUi

    void retranslateUi(QWidget *modCalcJdDlg)
    {
        label->setText(tr2i18n("Date and time:", nullptr));
        NowButton->setText(tr2i18n("Now", nullptr));
        label_2->setText(tr2i18n("Julian day:", nullptr));
        label_3->setText(tr2i18n("Modified Julian day:", nullptr));
        tabWidget->setTabText(tabWidget->indexOf(tab), tr2i18n("Interactive Mode", nullptr));
        label_4->setText(tr2i18n("Input parameter: ", nullptr));
        InputComboBatch->setItemText(0, tr2i18n("Date and time", nullptr));
        InputComboBatch->setItemText(1, tr2i18n("Julian day", nullptr));
        InputComboBatch->setItemText(2, tr2i18n("Modified Julian day", nullptr));

        label_5->setText(tr2i18n("Input file: ", nullptr));
        label_6->setText(tr2i18n("Output file: ", nullptr));
        RunButtonBatch->setText(tr2i18n("Compute", nullptr));
        ViewButtonBatch->setText(tr2i18n("View Output...", nullptr));
        tabWidget->setTabText(tabWidget->indexOf(tab_2), tr2i18n("Batch Mode", nullptr));
        (void)modCalcJdDlg;
    } // retranslateUi

};

namespace Ui {
    class modCalcJdDlg: public Ui_modCalcJdDlg {};
} // namespace Ui

QT_END_NAMESPACE

#endif // MODCALCJD_H

