/********************************************************************************
** Form generated from reading UI file 'wilpsettings.ui'
**
** Created by: Qt User Interface Compiler version 6.11.1
**
** WARNING! All changes made in this file will be lost when recompiling UI file!
********************************************************************************/

#ifndef UI_WILPSETTINGS_H
#define UI_WILPSETTINGS_H

#include <QtCore/QVariant>
#include <QtWidgets/QApplication>
#include <QtWidgets/QGridLayout>
#include <QtWidgets/QHBoxLayout>
#include <QtWidgets/QLabel>
#include <QtWidgets/QSlider>
#include <QtWidgets/QSpacerItem>
#include <QtWidgets/QVBoxLayout>
#include <QtWidgets/QWidget>
#include <klocalizedstring.h>

QT_BEGIN_NAMESPACE

class Ui_WILPSettings
{
public:
    QGridLayout *gridLayout;
    QVBoxLayout *lpLayout;
    QLabel *lpText;
    QSpacerItem *verticalSpacer_3;
    QVBoxLayout *bortleLayout;
    QSlider *kcfg_BortleClass;
    QHBoxLayout *bortleLabelsLayout;
    QLabel *bortleClassLabel1;
    QSpacerItem *labelSpacer1;
    QLabel *bortleClassLabel5;
    QSpacerItem *labelSpacer2;
    QLabel *bortleClassLabel9;
    QSpacerItem *verticalSpacer;
    QLabel *bortleHelpText;
    QSpacerItem *verticalSpacer_2;

    void setupUi(QWidget *WILPSettings)
    {
        if (WILPSettings->objectName().isEmpty())
            WILPSettings->setObjectName("WILPSettings");
        WILPSettings->resize(652, 426);
        gridLayout = new QGridLayout(WILPSettings);
        gridLayout->setObjectName("gridLayout");
        gridLayout->setContentsMargins(15, 10, 15, -1);
        lpLayout = new QVBoxLayout();
        lpLayout->setSpacing(14);
        lpLayout->setObjectName("lpLayout");
        lpLayout->setContentsMargins(-1, 34, -1, -1);
        lpText = new QLabel(WILPSettings);
        lpText->setObjectName("lpText");
        lpText->setWordWrap(true);

        lpLayout->addWidget(lpText);

        verticalSpacer_3 = new QSpacerItem(20, 40, QSizePolicy::Policy::Minimum, QSizePolicy::Policy::Expanding);

        lpLayout->addItem(verticalSpacer_3);

        bortleLayout = new QVBoxLayout();
        bortleLayout->setObjectName("bortleLayout");
        kcfg_BortleClass = new QSlider(WILPSettings);
        kcfg_BortleClass->setObjectName("kcfg_BortleClass");
        kcfg_BortleClass->setMinimum(1);
        kcfg_BortleClass->setMaximum(9);
        kcfg_BortleClass->setOrientation(Qt::Horizontal);
        kcfg_BortleClass->setTickPosition(QSlider::TicksBelow);
        kcfg_BortleClass->setTickInterval(1);

        bortleLayout->addWidget(kcfg_BortleClass);

        bortleLabelsLayout = new QHBoxLayout();
        bortleLabelsLayout->setSpacing(2);
        bortleLabelsLayout->setObjectName("bortleLabelsLayout");
        bortleClassLabel1 = new QLabel(WILPSettings);
        bortleClassLabel1->setObjectName("bortleClassLabel1");

        bortleLabelsLayout->addWidget(bortleClassLabel1);

        labelSpacer1 = new QSpacerItem(40, 20, QSizePolicy::Policy::Expanding, QSizePolicy::Policy::Minimum);

        bortleLabelsLayout->addItem(labelSpacer1);

        bortleClassLabel5 = new QLabel(WILPSettings);
        bortleClassLabel5->setObjectName("bortleClassLabel5");

        bortleLabelsLayout->addWidget(bortleClassLabel5);

        labelSpacer2 = new QSpacerItem(40, 20, QSizePolicy::Policy::Expanding, QSizePolicy::Policy::Minimum);

        bortleLabelsLayout->addItem(labelSpacer2);

        bortleClassLabel9 = new QLabel(WILPSettings);
        bortleClassLabel9->setObjectName("bortleClassLabel9");

        bortleLabelsLayout->addWidget(bortleClassLabel9);


        bortleLayout->addLayout(bortleLabelsLayout);


        lpLayout->addLayout(bortleLayout);

        verticalSpacer = new QSpacerItem(20, 77, QSizePolicy::Policy::Minimum, QSizePolicy::Policy::Expanding);

        lpLayout->addItem(verticalSpacer);

        bortleHelpText = new QLabel(WILPSettings);
        bortleHelpText->setObjectName("bortleHelpText");
        bortleHelpText->setTextFormat(Qt::RichText);
        bortleHelpText->setOpenExternalLinks(true);

        lpLayout->addWidget(bortleHelpText);

        verticalSpacer_2 = new QSpacerItem(20, 40, QSizePolicy::Policy::Minimum, QSizePolicy::Policy::Expanding);

        lpLayout->addItem(verticalSpacer_2);


        gridLayout->addLayout(lpLayout, 0, 0, 1, 1);


        retranslateUi(WILPSettings);

        QMetaObject::connectSlotsByName(WILPSettings);
    } // setupUi

    void retranslateUi(QWidget *WILPSettings)
    {
        lpText->setText(tr2i18n("<p>How light-polluted is your night-sky? Rate your night-sky conditions from 1-9 based on the <b>Bortle Dark-Sky Scale</b>. A rating of <b>1</b> represents an <b>excellent dark-sky site</b>, while <b>9</b> represents a <b>brilliantly lit inner-city sky</b>.</p>", nullptr));
        bortleClassLabel1->setText(tr2i18n(" 1 ", nullptr));
        bortleClassLabel5->setText(tr2i18n("5", nullptr));
        bortleClassLabel9->setText(tr2i18n("9  ", nullptr));
        bortleHelpText->setText(tr2i18n("<html><head/><body><p align=\"right\">For help: <a href=\"https://en.wikipedia.org/wiki/Bortle_Dark-Sky_Scale\"><span style=\" text-decoration: underline; color:#004183;\">Wikipedia Link for Bortle dark-sky scale</span></a></p></body></html>", nullptr));
        (void)WILPSettings;
    } // retranslateUi

};

namespace Ui {
    class WILPSettings: public Ui_WILPSettings {};
} // namespace Ui

QT_END_NAMESPACE

#endif // WILPSETTINGS_H

