/********************************************************************************
** Form generated from reading UI file 'framingassistant.ui'
**
** Created by: Qt User Interface Compiler version 6.11.1
**
** WARNING! All changes made in this file will be lost when recompiling UI file!
********************************************************************************/

#ifndef UI_FRAMINGASSISTANT_H
#define UI_FRAMINGASSISTANT_H

#include <QtCore/QVariant>
#include <QtGui/QIcon>
#include <QtWidgets/QApplication>
#include <QtWidgets/QCheckBox>
#include <QtWidgets/QDialog>
#include <QtWidgets/QDoubleSpinBox>
#include <QtWidgets/QGridLayout>
#include <QtWidgets/QGroupBox>
#include <QtWidgets/QHBoxLayout>
#include <QtWidgets/QLabel>
#include <QtWidgets/QLineEdit>
#include <QtWidgets/QPushButton>
#include <QtWidgets/QRadioButton>
#include <QtWidgets/QSlider>
#include <QtWidgets/QSpacerItem>
#include <QtWidgets/QSpinBox>
#include <QtWidgets/QStackedWidget>
#include <QtWidgets/QVBoxLayout>
#include <QtWidgets/QWidget>
#include <klocalizedstring.h>
#include "widgets/dmsbox.h"

QT_BEGIN_NAMESPACE

class Ui_FramingAssistant
{
public:
    QVBoxLayout *verticalLayout_2;
    QStackedWidget *stackedWidget;
    QWidget *equipment;
    QVBoxLayout *verticalLayout;
    QGroupBox *equipmentGroup;
    QVBoxLayout *verticalLayout_6;
    QGridLayout *gridLayout;
    QLabel *label_4;
    QDoubleSpinBox *focalLenSpin;
    QHBoxLayout *horizontalLayout_17;
    QLabel *label_17;
    QDoubleSpinBox *focalReducerSpin;
    QLabel *label_8;
    QHBoxLayout *horizontalLayout;
    QLabel *label_9;
    QSpinBox *cameraWSpin;
    QHBoxLayout *horizontalLayout_2;
    QLabel *label_10;
    QSpinBox *cameraHSpin;
    QLabel *label_11;
    QHBoxLayout *horizontalLayout_3;
    QLabel *label_13;
    QDoubleSpinBox *pixelWSizeSpin;
    QHBoxLayout *horizontalLayout_4;
    QLabel *label_14;
    QDoubleSpinBox *pixelHSizeSpin;
    QSpacerItem *verticalSpacer;
    QHBoxLayout *horizontalLayout_5;
    QSpacerItem *horizontalSpacer;
    QPushButton *fetchB;
    QPushButton *nextToSelectGridB;
    QWidget *createGrid;
    QVBoxLayout *verticalLayout_3;
    QGroupBox *fovGroup;
    QGridLayout *gridLayout_2;
    QLabel *overlapLabel;
    QHBoxLayout *horizontalLayout_15;
    QDoubleSpinBox *overlapSpin;
    QHBoxLayout *horizontalLayout_16;
    QPushButton *resetB;
    QLabel *label;
    QHBoxLayout *horizontalLayout_11;
    QLabel *label_7;
    QSpinBox *mosaicWSpin;
    QHBoxLayout *horizontalLayout_12;
    QLabel *label_12;
    QSpinBox *mosaicHSpin;
    QLabel *targetFOVLabel;
    QHBoxLayout *horizontalLayout_7;
    QLabel *targetFOVWLabel;
    QDoubleSpinBox *targetWFOVSpin;
    QHBoxLayout *horizontalLayout_8;
    QLabel *targetFOVHLabel;
    QDoubleSpinBox *targetHFOVSpin;
    QLabel *cameraFOVLabel;
    QHBoxLayout *horizontalLayout_6;
    QLabel *cameraWFOVLabel;
    QDoubleSpinBox *cameraWFOVSpin;
    QHBoxLayout *horizontalLayout_10;
    QLabel *cameraHFOVLabel;
    QDoubleSpinBox *cameraHFOVSpin;
    QLabel *label_2;
    QPushButton *goRotateB;
    QLabel *label_16;
    QSlider *transparencySlider;
    QCheckBox *transparencyAuto;
    QHBoxLayout *horizontalLayout_9;
    QCheckBox *reverseOddRows;
    QDoubleSpinBox *positionAngleSpin;
    QSpacerItem *verticalSpacer_2;
    QHBoxLayout *horizontalLayout_13;
    QPushButton *backToEquipmentB;
    QSpacerItem *horizontalSpacer_2;
    QPushButton *importB;
    QPushButton *recenterB;
    QPushButton *nextToAdjustGrid;
    QWidget *adjustGrid;
    QVBoxLayout *verticalLayout_5;
    QGroupBox *fovGroup_2;
    QGridLayout *gridLayout_3;
    dmsBox *decBox;
    dmsBox *raBox;
    QLabel *label_6;
    QLabel *label_15;
    QSpacerItem *verticalSpacer_4;
    QHBoxLayout *horizontalLayout_26;
    QPushButton *backToSelectGrid;
    QSpacerItem *horizontalSpacer_4;
    QPushButton *goSolveB;
    QPushButton *nextToJobsB;
    QWidget *jobs;
    QVBoxLayout *verticalLayout_4;
    QGroupBox *jobsGroup;
    QGridLayout *gridLayout_4;
    QCheckBox *guideStepCheck;
    QLineEdit *directoryEdit;
    QLabel *sequenceLabel;
    QCheckBox *alignStepCheck;
    QLabel *label_5;
    QLabel *alignEveryLabel;
    QPushButton *loadSequenceB;
    QLineEdit *targetEdit;
    QCheckBox *trackStepCheck;
    QLabel *label_3;
    QLabel *focusEveryLabel;
    QPushButton *selectJobsDirB;
    QLabel *textLabel1_18;
    QSpinBox *alignEvery;
    QSpinBox *focusEvery;
    QLineEdit *sequenceEdit;
    QCheckBox *focusStepCheck;
    QSpacerItem *verticalSpacer2_group;
    QGroupBox *groupBox;
    QGridLayout *groupLayout;
    QLineEdit *groupEdit;
    QSpacerItem *verticalSpacer_group;
    QGroupBox *completionGroup;
    QGridLayout *completionLayout;
    QRadioButton *repeatCompletionR;
    QRadioButton *sequenceCompletionR;
    QSpinBox *repeatsSpin;
    QRadioButton *loopCompletionR;
    QSpacerItem *verticalSpacer_3;
    QHBoxLayout *horizontalLayout_14;
    QPushButton *backToAdjustGridB;
    QSpacerItem *horizontalSpacer_3;
    QPushButton *createJobsB;

    void setupUi(QDialog *FramingAssistant)
    {
        if (FramingAssistant->objectName().isEmpty())
            FramingAssistant->setObjectName("FramingAssistant");
        FramingAssistant->resize(448, 406);
        verticalLayout_2 = new QVBoxLayout(FramingAssistant);
        verticalLayout_2->setSpacing(3);
        verticalLayout_2->setObjectName("verticalLayout_2");
        verticalLayout_2->setContentsMargins(3, 3, 3, 3);
        stackedWidget = new QStackedWidget(FramingAssistant);
        stackedWidget->setObjectName("stackedWidget");
        equipment = new QWidget();
        equipment->setObjectName("equipment");
        verticalLayout = new QVBoxLayout(equipment);
        verticalLayout->setSpacing(3);
        verticalLayout->setObjectName("verticalLayout");
        verticalLayout->setContentsMargins(3, 3, 3, 3);
        equipmentGroup = new QGroupBox(equipment);
        equipmentGroup->setObjectName("equipmentGroup");
        QSizePolicy sizePolicy(QSizePolicy::Policy::Preferred, QSizePolicy::Policy::Preferred);
        sizePolicy.setHorizontalStretch(0);
        sizePolicy.setVerticalStretch(0);
        sizePolicy.setHeightForWidth(equipmentGroup->sizePolicy().hasHeightForWidth());
        equipmentGroup->setSizePolicy(sizePolicy);
        verticalLayout_6 = new QVBoxLayout(equipmentGroup);
        verticalLayout_6->setObjectName("verticalLayout_6");
        gridLayout = new QGridLayout();
        gridLayout->setSpacing(3);
        gridLayout->setObjectName("gridLayout");
        label_4 = new QLabel(equipmentGroup);
        label_4->setObjectName("label_4");

        gridLayout->addWidget(label_4, 0, 0, 1, 1);

        focalLenSpin = new QDoubleSpinBox(equipmentGroup);
        focalLenSpin->setObjectName("focalLenSpin");
        focalLenSpin->setMinimum(0.000000000000000);
        focalLenSpin->setMaximum(10000.000000000000000);
        focalLenSpin->setValue(0.000000000000000);

        gridLayout->addWidget(focalLenSpin, 0, 1, 1, 1);

        horizontalLayout_17 = new QHBoxLayout();
        horizontalLayout_17->setObjectName("horizontalLayout_17");
        label_17 = new QLabel(equipmentGroup);
        label_17->setObjectName("label_17");

        horizontalLayout_17->addWidget(label_17);

        focalReducerSpin = new QDoubleSpinBox(equipmentGroup);
        focalReducerSpin->setObjectName("focalReducerSpin");
        QSizePolicy sizePolicy1(QSizePolicy::Policy::MinimumExpanding, QSizePolicy::Policy::Fixed);
        sizePolicy1.setHorizontalStretch(0);
        sizePolicy1.setVerticalStretch(0);
        sizePolicy1.setHeightForWidth(focalReducerSpin->sizePolicy().hasHeightForWidth());
        focalReducerSpin->setSizePolicy(sizePolicy1);
        focalReducerSpin->setMinimum(0.100000000000000);
        focalReducerSpin->setMaximum(3.000000000000000);
        focalReducerSpin->setSingleStep(0.100000000000000);
        focalReducerSpin->setValue(1.000000000000000);

        horizontalLayout_17->addWidget(focalReducerSpin);


        gridLayout->addLayout(horizontalLayout_17, 0, 2, 1, 1);

        label_8 = new QLabel(equipmentGroup);
        label_8->setObjectName("label_8");

        gridLayout->addWidget(label_8, 1, 0, 1, 1);

        horizontalLayout = new QHBoxLayout();
        horizontalLayout->setSpacing(3);
        horizontalLayout->setObjectName("horizontalLayout");
        label_9 = new QLabel(equipmentGroup);
        label_9->setObjectName("label_9");

        horizontalLayout->addWidget(label_9);

        cameraWSpin = new QSpinBox(equipmentGroup);
        cameraWSpin->setObjectName("cameraWSpin");
        sizePolicy1.setHeightForWidth(cameraWSpin->sizePolicy().hasHeightForWidth());
        cameraWSpin->setSizePolicy(sizePolicy1);
        cameraWSpin->setMinimum(0);
        cameraWSpin->setMaximum(10000);
        cameraWSpin->setValue(0);

        horizontalLayout->addWidget(cameraWSpin);


        gridLayout->addLayout(horizontalLayout, 1, 1, 1, 1);

        horizontalLayout_2 = new QHBoxLayout();
        horizontalLayout_2->setSpacing(3);
        horizontalLayout_2->setObjectName("horizontalLayout_2");
        label_10 = new QLabel(equipmentGroup);
        label_10->setObjectName("label_10");

        horizontalLayout_2->addWidget(label_10);

        cameraHSpin = new QSpinBox(equipmentGroup);
        cameraHSpin->setObjectName("cameraHSpin");
        sizePolicy1.setHeightForWidth(cameraHSpin->sizePolicy().hasHeightForWidth());
        cameraHSpin->setSizePolicy(sizePolicy1);
        cameraHSpin->setMinimum(0);
        cameraHSpin->setMaximum(10000);
        cameraHSpin->setValue(0);

        horizontalLayout_2->addWidget(cameraHSpin);


        gridLayout->addLayout(horizontalLayout_2, 1, 2, 1, 1);

        label_11 = new QLabel(equipmentGroup);
        label_11->setObjectName("label_11");

        gridLayout->addWidget(label_11, 2, 0, 1, 1);

        horizontalLayout_3 = new QHBoxLayout();
        horizontalLayout_3->setSpacing(3);
        horizontalLayout_3->setObjectName("horizontalLayout_3");
        label_13 = new QLabel(equipmentGroup);
        label_13->setObjectName("label_13");

        horizontalLayout_3->addWidget(label_13);

        pixelWSizeSpin = new QDoubleSpinBox(equipmentGroup);
        pixelWSizeSpin->setObjectName("pixelWSizeSpin");
        sizePolicy1.setHeightForWidth(pixelWSizeSpin->sizePolicy().hasHeightForWidth());
        pixelWSizeSpin->setSizePolicy(sizePolicy1);
        pixelWSizeSpin->setMinimum(0.000000000000000);
        pixelWSizeSpin->setValue(0.000000000000000);

        horizontalLayout_3->addWidget(pixelWSizeSpin);


        gridLayout->addLayout(horizontalLayout_3, 2, 1, 1, 1);

        horizontalLayout_4 = new QHBoxLayout();
        horizontalLayout_4->setSpacing(3);
        horizontalLayout_4->setObjectName("horizontalLayout_4");
        label_14 = new QLabel(equipmentGroup);
        label_14->setObjectName("label_14");

        horizontalLayout_4->addWidget(label_14);

        pixelHSizeSpin = new QDoubleSpinBox(equipmentGroup);
        pixelHSizeSpin->setObjectName("pixelHSizeSpin");
        sizePolicy1.setHeightForWidth(pixelHSizeSpin->sizePolicy().hasHeightForWidth());
        pixelHSizeSpin->setSizePolicy(sizePolicy1);

        horizontalLayout_4->addWidget(pixelHSizeSpin);


        gridLayout->addLayout(horizontalLayout_4, 2, 2, 1, 1);


        verticalLayout_6->addLayout(gridLayout);


        verticalLayout->addWidget(equipmentGroup);

        verticalSpacer = new QSpacerItem(20, 40, QSizePolicy::Policy::Minimum, QSizePolicy::Policy::Expanding);

        verticalLayout->addItem(verticalSpacer);

        horizontalLayout_5 = new QHBoxLayout();
        horizontalLayout_5->setObjectName("horizontalLayout_5");
        horizontalSpacer = new QSpacerItem(40, 20, QSizePolicy::Policy::Expanding, QSizePolicy::Policy::Minimum);

        horizontalLayout_5->addItem(horizontalSpacer);

        fetchB = new QPushButton(equipment);
        fetchB->setObjectName("fetchB");
        QIcon icon(QIcon::fromTheme(QString::fromUtf8("download")));
        fetchB->setIcon(icon);

        horizontalLayout_5->addWidget(fetchB);

        nextToSelectGridB = new QPushButton(equipment);
        nextToSelectGridB->setObjectName("nextToSelectGridB");
        nextToSelectGridB->setEnabled(false);
        QIcon icon1(QIcon::fromTheme(QString::fromUtf8("arrow-right")));
        nextToSelectGridB->setIcon(icon1);

        horizontalLayout_5->addWidget(nextToSelectGridB);


        verticalLayout->addLayout(horizontalLayout_5);

        stackedWidget->addWidget(equipment);
        createGrid = new QWidget();
        createGrid->setObjectName("createGrid");
        verticalLayout_3 = new QVBoxLayout(createGrid);
        verticalLayout_3->setSpacing(3);
        verticalLayout_3->setObjectName("verticalLayout_3");
        verticalLayout_3->setContentsMargins(3, 3, 3, 3);
        fovGroup = new QGroupBox(createGrid);
        fovGroup->setObjectName("fovGroup");
        fovGroup->setEnabled(true);
        sizePolicy.setHeightForWidth(fovGroup->sizePolicy().hasHeightForWidth());
        fovGroup->setSizePolicy(sizePolicy);
        gridLayout_2 = new QGridLayout(fovGroup);
        gridLayout_2->setSpacing(3);
        gridLayout_2->setObjectName("gridLayout_2");
        gridLayout_2->setContentsMargins(3, 3, 3, 3);
        overlapLabel = new QLabel(fovGroup);
        overlapLabel->setObjectName("overlapLabel");
        overlapLabel->setEnabled(true);
        sizePolicy.setHeightForWidth(overlapLabel->sizePolicy().hasHeightForWidth());
        overlapLabel->setSizePolicy(sizePolicy);

        gridLayout_2->addWidget(overlapLabel, 0, 0, 1, 1);

        horizontalLayout_15 = new QHBoxLayout();
        horizontalLayout_15->setSpacing(3);
        horizontalLayout_15->setObjectName("horizontalLayout_15");
        overlapSpin = new QDoubleSpinBox(fovGroup);
        overlapSpin->setObjectName("overlapSpin");
        overlapSpin->setEnabled(true);
        sizePolicy1.setHeightForWidth(overlapSpin->sizePolicy().hasHeightForWidth());
        overlapSpin->setSizePolicy(sizePolicy1);
        overlapSpin->setMaximum(90.000000000000000);
        overlapSpin->setSingleStep(5.000000000000000);
        overlapSpin->setValue(10.000000000000000);

        horizontalLayout_15->addWidget(overlapSpin);


        gridLayout_2->addLayout(horizontalLayout_15, 0, 1, 1, 1);

        horizontalLayout_16 = new QHBoxLayout();
        horizontalLayout_16->setObjectName("horizontalLayout_16");
        resetB = new QPushButton(fovGroup);
        resetB->setObjectName("resetB");
        sizePolicy1.setHeightForWidth(resetB->sizePolicy().hasHeightForWidth());
        resetB->setSizePolicy(sizePolicy1);

        horizontalLayout_16->addWidget(resetB);


        gridLayout_2->addLayout(horizontalLayout_16, 0, 2, 1, 2);

        label = new QLabel(fovGroup);
        label->setObjectName("label");
        sizePolicy.setHeightForWidth(label->sizePolicy().hasHeightForWidth());
        label->setSizePolicy(sizePolicy);

        gridLayout_2->addWidget(label, 1, 0, 1, 1);

        horizontalLayout_11 = new QHBoxLayout();
        horizontalLayout_11->setSpacing(3);
        horizontalLayout_11->setObjectName("horizontalLayout_11");
        label_7 = new QLabel(fovGroup);
        label_7->setObjectName("label_7");
        sizePolicy.setHeightForWidth(label_7->sizePolicy().hasHeightForWidth());
        label_7->setSizePolicy(sizePolicy);

        horizontalLayout_11->addWidget(label_7);

        mosaicWSpin = new QSpinBox(fovGroup);
        mosaicWSpin->setObjectName("mosaicWSpin");
        sizePolicy1.setHeightForWidth(mosaicWSpin->sizePolicy().hasHeightForWidth());
        mosaicWSpin->setSizePolicy(sizePolicy1);
        mosaicWSpin->setMinimum(1);
        mosaicWSpin->setMaximum(10);
        mosaicWSpin->setValue(1);

        horizontalLayout_11->addWidget(mosaicWSpin);


        gridLayout_2->addLayout(horizontalLayout_11, 1, 1, 1, 1);

        horizontalLayout_12 = new QHBoxLayout();
        horizontalLayout_12->setSpacing(3);
        horizontalLayout_12->setObjectName("horizontalLayout_12");
        label_12 = new QLabel(fovGroup);
        label_12->setObjectName("label_12");
        sizePolicy.setHeightForWidth(label_12->sizePolicy().hasHeightForWidth());
        label_12->setSizePolicy(sizePolicy);

        horizontalLayout_12->addWidget(label_12);

        mosaicHSpin = new QSpinBox(fovGroup);
        mosaicHSpin->setObjectName("mosaicHSpin");
        sizePolicy1.setHeightForWidth(mosaicHSpin->sizePolicy().hasHeightForWidth());
        mosaicHSpin->setSizePolicy(sizePolicy1);
        mosaicHSpin->setMinimum(1);
        mosaicHSpin->setMaximum(10);
        mosaicHSpin->setValue(1);

        horizontalLayout_12->addWidget(mosaicHSpin);


        gridLayout_2->addLayout(horizontalLayout_12, 1, 2, 1, 2);

        targetFOVLabel = new QLabel(fovGroup);
        targetFOVLabel->setObjectName("targetFOVLabel");
        targetFOVLabel->setEnabled(true);

        gridLayout_2->addWidget(targetFOVLabel, 2, 0, 1, 1);

        horizontalLayout_7 = new QHBoxLayout();
        horizontalLayout_7->setSpacing(3);
        horizontalLayout_7->setObjectName("horizontalLayout_7");
        targetFOVWLabel = new QLabel(fovGroup);
        targetFOVWLabel->setObjectName("targetFOVWLabel");
        targetFOVWLabel->setEnabled(true);
        sizePolicy.setHeightForWidth(targetFOVWLabel->sizePolicy().hasHeightForWidth());
        targetFOVWLabel->setSizePolicy(sizePolicy);

        horizontalLayout_7->addWidget(targetFOVWLabel);

        targetWFOVSpin = new QDoubleSpinBox(fovGroup);
        targetWFOVSpin->setObjectName("targetWFOVSpin");
        targetWFOVSpin->setEnabled(true);
        sizePolicy1.setHeightForWidth(targetWFOVSpin->sizePolicy().hasHeightForWidth());
        targetWFOVSpin->setSizePolicy(sizePolicy1);
        targetWFOVSpin->setMaximum(3600.000000000000000);

        horizontalLayout_7->addWidget(targetWFOVSpin);

        horizontalLayout_7->setStretch(1, 1);

        gridLayout_2->addLayout(horizontalLayout_7, 2, 1, 1, 1);

        horizontalLayout_8 = new QHBoxLayout();
        horizontalLayout_8->setSpacing(3);
        horizontalLayout_8->setObjectName("horizontalLayout_8");
        targetFOVHLabel = new QLabel(fovGroup);
        targetFOVHLabel->setObjectName("targetFOVHLabel");
        targetFOVHLabel->setEnabled(true);
        sizePolicy.setHeightForWidth(targetFOVHLabel->sizePolicy().hasHeightForWidth());
        targetFOVHLabel->setSizePolicy(sizePolicy);

        horizontalLayout_8->addWidget(targetFOVHLabel);

        targetHFOVSpin = new QDoubleSpinBox(fovGroup);
        targetHFOVSpin->setObjectName("targetHFOVSpin");
        targetHFOVSpin->setEnabled(true);
        sizePolicy1.setHeightForWidth(targetHFOVSpin->sizePolicy().hasHeightForWidth());
        targetHFOVSpin->setSizePolicy(sizePolicy1);
        targetHFOVSpin->setMaximum(3600.000000000000000);

        horizontalLayout_8->addWidget(targetHFOVSpin);


        gridLayout_2->addLayout(horizontalLayout_8, 2, 2, 1, 2);

        cameraFOVLabel = new QLabel(fovGroup);
        cameraFOVLabel->setObjectName("cameraFOVLabel");
        cameraFOVLabel->setEnabled(true);
        sizePolicy.setHeightForWidth(cameraFOVLabel->sizePolicy().hasHeightForWidth());
        cameraFOVLabel->setSizePolicy(sizePolicy);

        gridLayout_2->addWidget(cameraFOVLabel, 3, 0, 1, 1);

        horizontalLayout_6 = new QHBoxLayout();
        horizontalLayout_6->setSpacing(3);
        horizontalLayout_6->setObjectName("horizontalLayout_6");
        horizontalLayout_6->setSizeConstraint(QLayout::SetDefaultConstraint);
        cameraWFOVLabel = new QLabel(fovGroup);
        cameraWFOVLabel->setObjectName("cameraWFOVLabel");
        cameraWFOVLabel->setEnabled(true);
        sizePolicy.setHeightForWidth(cameraWFOVLabel->sizePolicy().hasHeightForWidth());
        cameraWFOVLabel->setSizePolicy(sizePolicy);

        horizontalLayout_6->addWidget(cameraWFOVLabel);

        cameraWFOVSpin = new QDoubleSpinBox(fovGroup);
        cameraWFOVSpin->setObjectName("cameraWFOVSpin");
        cameraWFOVSpin->setEnabled(false);
        sizePolicy1.setHeightForWidth(cameraWFOVSpin->sizePolicy().hasHeightForWidth());
        cameraWFOVSpin->setSizePolicy(sizePolicy1);
        cameraWFOVSpin->setFocusPolicy(Qt::NoFocus);
        cameraWFOVSpin->setReadOnly(true);
        cameraWFOVSpin->setMaximum(3600.000000000000000);

        horizontalLayout_6->addWidget(cameraWFOVSpin);


        gridLayout_2->addLayout(horizontalLayout_6, 3, 1, 1, 1);

        horizontalLayout_10 = new QHBoxLayout();
        horizontalLayout_10->setSpacing(3);
        horizontalLayout_10->setObjectName("horizontalLayout_10");
        cameraHFOVLabel = new QLabel(fovGroup);
        cameraHFOVLabel->setObjectName("cameraHFOVLabel");
        cameraHFOVLabel->setEnabled(true);
        sizePolicy.setHeightForWidth(cameraHFOVLabel->sizePolicy().hasHeightForWidth());
        cameraHFOVLabel->setSizePolicy(sizePolicy);

        horizontalLayout_10->addWidget(cameraHFOVLabel);

        cameraHFOVSpin = new QDoubleSpinBox(fovGroup);
        cameraHFOVSpin->setObjectName("cameraHFOVSpin");
        cameraHFOVSpin->setEnabled(false);
        sizePolicy1.setHeightForWidth(cameraHFOVSpin->sizePolicy().hasHeightForWidth());
        cameraHFOVSpin->setSizePolicy(sizePolicy1);
        cameraHFOVSpin->setFocusPolicy(Qt::NoFocus);
        cameraHFOVSpin->setReadOnly(true);
        cameraHFOVSpin->setMaximum(3600.000000000000000);

        horizontalLayout_10->addWidget(cameraHFOVSpin);


        gridLayout_2->addLayout(horizontalLayout_10, 3, 2, 1, 2);

        label_2 = new QLabel(fovGroup);
        label_2->setObjectName("label_2");

        gridLayout_2->addWidget(label_2, 4, 0, 1, 1);

        goRotateB = new QPushButton(fovGroup);
        goRotateB->setObjectName("goRotateB");
        goRotateB->setMaximumSize(QSize(28, 28));
        QIcon icon2(QIcon::fromTheme(QString::fromUtf8("object-rotate-left")));
        goRotateB->setIcon(icon2);
        goRotateB->setIconSize(QSize(28, 28));

        gridLayout_2->addWidget(goRotateB, 4, 3, 1, 1);

        label_16 = new QLabel(fovGroup);
        label_16->setObjectName("label_16");

        gridLayout_2->addWidget(label_16, 5, 0, 1, 1);

        transparencySlider = new QSlider(fovGroup);
        transparencySlider->setObjectName("transparencySlider");
        transparencySlider->setEnabled(false);
        transparencySlider->setMinimum(5);
        transparencySlider->setMaximum(60);
        transparencySlider->setValue(50);
        transparencySlider->setOrientation(Qt::Horizontal);

        gridLayout_2->addWidget(transparencySlider, 5, 1, 1, 1);

        transparencyAuto = new QCheckBox(fovGroup);
        transparencyAuto->setObjectName("transparencyAuto");
        transparencyAuto->setChecked(true);

        gridLayout_2->addWidget(transparencyAuto, 5, 2, 1, 1);

        horizontalLayout_9 = new QHBoxLayout();
        horizontalLayout_9->setObjectName("horizontalLayout_9");
        reverseOddRows = new QCheckBox(fovGroup);
        reverseOddRows->setObjectName("reverseOddRows");
        QSizePolicy sizePolicy2(QSizePolicy::Policy::Preferred, QSizePolicy::Policy::Fixed);
        sizePolicy2.setHorizontalStretch(0);
        sizePolicy2.setVerticalStretch(0);
        sizePolicy2.setHeightForWidth(reverseOddRows->sizePolicy().hasHeightForWidth());
        reverseOddRows->setSizePolicy(sizePolicy2);
        reverseOddRows->setChecked(true);

        horizontalLayout_9->addWidget(reverseOddRows);


        gridLayout_2->addLayout(horizontalLayout_9, 6, 1, 1, 2);

        positionAngleSpin = new QDoubleSpinBox(fovGroup);
        positionAngleSpin->setObjectName("positionAngleSpin");
        positionAngleSpin->setMinimum(-360.000000000000000);
        positionAngleSpin->setMaximum(360.000000000000000);
        positionAngleSpin->setSingleStep(5.000000000000000);

        gridLayout_2->addWidget(positionAngleSpin, 4, 1, 1, 2);


        verticalLayout_3->addWidget(fovGroup);

        verticalSpacer_2 = new QSpacerItem(20, 17, QSizePolicy::Policy::Minimum, QSizePolicy::Policy::Expanding);

        verticalLayout_3->addItem(verticalSpacer_2);

        horizontalLayout_13 = new QHBoxLayout();
        horizontalLayout_13->setObjectName("horizontalLayout_13");
        backToEquipmentB = new QPushButton(createGrid);
        backToEquipmentB->setObjectName("backToEquipmentB");
        QIcon icon3(QIcon::fromTheme(QString::fromUtf8("arrow-left")));
        backToEquipmentB->setIcon(icon3);

        horizontalLayout_13->addWidget(backToEquipmentB);

        horizontalSpacer_2 = new QSpacerItem(40, 20, QSizePolicy::Policy::Expanding, QSizePolicy::Policy::Minimum);

        horizontalLayout_13->addItem(horizontalSpacer_2);

        importB = new QPushButton(createGrid);
        importB->setObjectName("importB");

        horizontalLayout_13->addWidget(importB);

        recenterB = new QPushButton(createGrid);
        recenterB->setObjectName("recenterB");
        QIcon icon4(QIcon::fromTheme(QString::fromUtf8("arrow")));
        recenterB->setIcon(icon4);

        horizontalLayout_13->addWidget(recenterB);

        nextToAdjustGrid = new QPushButton(createGrid);
        nextToAdjustGrid->setObjectName("nextToAdjustGrid");
        nextToAdjustGrid->setIcon(icon1);

        horizontalLayout_13->addWidget(nextToAdjustGrid);


        verticalLayout_3->addLayout(horizontalLayout_13);

        stackedWidget->addWidget(createGrid);
        adjustGrid = new QWidget();
        adjustGrid->setObjectName("adjustGrid");
        verticalLayout_5 = new QVBoxLayout(adjustGrid);
        verticalLayout_5->setSpacing(3);
        verticalLayout_5->setObjectName("verticalLayout_5");
        verticalLayout_5->setContentsMargins(3, 3, 3, 3);
        fovGroup_2 = new QGroupBox(adjustGrid);
        fovGroup_2->setObjectName("fovGroup_2");
        fovGroup_2->setEnabled(true);
        sizePolicy.setHeightForWidth(fovGroup_2->sizePolicy().hasHeightForWidth());
        fovGroup_2->setSizePolicy(sizePolicy);
        gridLayout_3 = new QGridLayout(fovGroup_2);
        gridLayout_3->setSpacing(3);
        gridLayout_3->setObjectName("gridLayout_3");
        gridLayout_3->setSizeConstraint(QLayout::SetDefaultConstraint);
        gridLayout_3->setContentsMargins(3, 3, 3, 3);
        decBox = new dmsBox(fovGroup_2);
        decBox->setObjectName("decBox");
        QSizePolicy sizePolicy3(QSizePolicy::Policy::Expanding, QSizePolicy::Policy::Preferred);
        sizePolicy3.setHorizontalStretch(0);
        sizePolicy3.setVerticalStretch(0);
        sizePolicy3.setHeightForWidth(decBox->sizePolicy().hasHeightForWidth());
        decBox->setSizePolicy(sizePolicy3);
        decBox->setLayoutDirection(Qt::LeftToRight);

        gridLayout_3->addWidget(decBox, 1, 2, 1, 1);

        raBox = new dmsBox(fovGroup_2);
        raBox->setObjectName("raBox");
        sizePolicy3.setHeightForWidth(raBox->sizePolicy().hasHeightForWidth());
        raBox->setSizePolicy(sizePolicy3);

        gridLayout_3->addWidget(raBox, 1, 1, 1, 1);

        label_6 = new QLabel(fovGroup_2);
        label_6->setObjectName("label_6");
        sizePolicy.setHeightForWidth(label_6->sizePolicy().hasHeightForWidth());
        label_6->setSizePolicy(sizePolicy);

        gridLayout_3->addWidget(label_6, 1, 0, 1, 1);

        gridLayout_3->setColumnStretch(0, 1);

        verticalLayout_5->addWidget(fovGroup_2);

        label_15 = new QLabel(adjustGrid);
        label_15->setObjectName("label_15");
        label_15->setWordWrap(true);

        verticalLayout_5->addWidget(label_15);

        verticalSpacer_4 = new QSpacerItem(20, 204, QSizePolicy::Policy::Minimum, QSizePolicy::Policy::Expanding);

        verticalLayout_5->addItem(verticalSpacer_4);

        horizontalLayout_26 = new QHBoxLayout();
        horizontalLayout_26->setObjectName("horizontalLayout_26");
        backToSelectGrid = new QPushButton(adjustGrid);
        backToSelectGrid->setObjectName("backToSelectGrid");
        backToSelectGrid->setIcon(icon3);

        horizontalLayout_26->addWidget(backToSelectGrid);

        horizontalSpacer_4 = new QSpacerItem(40, 20, QSizePolicy::Policy::Expanding, QSizePolicy::Policy::Minimum);

        horizontalLayout_26->addItem(horizontalSpacer_4);

        goSolveB = new QPushButton(adjustGrid);
        goSolveB->setObjectName("goSolveB");
        goSolveB->setEnabled(true);
        QIcon icon5(QIcon::fromTheme(QString::fromUtf8("crosshairs")));
        goSolveB->setIcon(icon5);

        horizontalLayout_26->addWidget(goSolveB);

        nextToJobsB = new QPushButton(adjustGrid);
        nextToJobsB->setObjectName("nextToJobsB");
        nextToJobsB->setIcon(icon1);

        horizontalLayout_26->addWidget(nextToJobsB);


        verticalLayout_5->addLayout(horizontalLayout_26);

        stackedWidget->addWidget(adjustGrid);
        jobs = new QWidget();
        jobs->setObjectName("jobs");
        verticalLayout_4 = new QVBoxLayout(jobs);
        verticalLayout_4->setSpacing(3);
        verticalLayout_4->setObjectName("verticalLayout_4");
        verticalLayout_4->setContentsMargins(3, 3, 3, 3);
        jobsGroup = new QGroupBox(jobs);
        jobsGroup->setObjectName("jobsGroup");
        sizePolicy.setHeightForWidth(jobsGroup->sizePolicy().hasHeightForWidth());
        jobsGroup->setSizePolicy(sizePolicy);
        gridLayout_4 = new QGridLayout(jobsGroup);
        gridLayout_4->setObjectName("gridLayout_4");
        guideStepCheck = new QCheckBox(jobsGroup);
        guideStepCheck->setObjectName("guideStepCheck");
        sizePolicy.setHeightForWidth(guideStepCheck->sizePolicy().hasHeightForWidth());
        guideStepCheck->setSizePolicy(sizePolicy);
        guideStepCheck->setChecked(true);

        gridLayout_4->addWidget(guideStepCheck, 5, 6, 1, 1);

        directoryEdit = new QLineEdit(jobsGroup);
        directoryEdit->setObjectName("directoryEdit");

        gridLayout_4->addWidget(directoryEdit, 4, 2, 1, 5);

        sequenceLabel = new QLabel(jobsGroup);
        sequenceLabel->setObjectName("sequenceLabel");

        gridLayout_4->addWidget(sequenceLabel, 2, 0, 1, 1);

        alignStepCheck = new QCheckBox(jobsGroup);
        alignStepCheck->setObjectName("alignStepCheck");
        sizePolicy.setHeightForWidth(alignStepCheck->sizePolicy().hasHeightForWidth());
        alignStepCheck->setSizePolicy(sizePolicy);
        alignStepCheck->setChecked(true);

        gridLayout_4->addWidget(alignStepCheck, 5, 5, 1, 1);

        label_5 = new QLabel(jobsGroup);
        label_5->setObjectName("label_5");
        sizePolicy.setHeightForWidth(label_5->sizePolicy().hasHeightForWidth());
        label_5->setSizePolicy(sizePolicy);

        gridLayout_4->addWidget(label_5, 5, 0, 1, 1);

        alignEveryLabel = new QLabel(jobsGroup);
        alignEveryLabel->setObjectName("alignEveryLabel");
        sizePolicy.setHeightForWidth(alignEveryLabel->sizePolicy().hasHeightForWidth());
        alignEveryLabel->setSizePolicy(sizePolicy);

        gridLayout_4->addWidget(alignEveryLabel, 7, 0, 1, 1);

        loadSequenceB = new QPushButton(jobsGroup);
        loadSequenceB->setObjectName("loadSequenceB");
        QSizePolicy sizePolicy4(QSizePolicy::Policy::Fixed, QSizePolicy::Policy::Fixed);
        sizePolicy4.setHorizontalStretch(0);
        sizePolicy4.setVerticalStretch(0);
        sizePolicy4.setHeightForWidth(loadSequenceB->sizePolicy().hasHeightForWidth());
        loadSequenceB->setSizePolicy(sizePolicy4);
        loadSequenceB->setMinimumSize(QSize(32, 32));
        QIcon icon6(QIcon::fromTheme(QString::fromUtf8("folder")));
        loadSequenceB->setIcon(icon6);
        loadSequenceB->setIconSize(QSize(28, 28));

        gridLayout_4->addWidget(loadSequenceB, 2, 7, 1, 1);

        targetEdit = new QLineEdit(jobsGroup);
        targetEdit->setObjectName("targetEdit");

        gridLayout_4->addWidget(targetEdit, 0, 2, 1, 5);

        trackStepCheck = new QCheckBox(jobsGroup);
        trackStepCheck->setObjectName("trackStepCheck");
        sizePolicy.setHeightForWidth(trackStepCheck->sizePolicy().hasHeightForWidth());
        trackStepCheck->setSizePolicy(sizePolicy);
        trackStepCheck->setLayoutDirection(Qt::LeftToRight);
        trackStepCheck->setChecked(true);

        gridLayout_4->addWidget(trackStepCheck, 5, 3, 1, 1);

        label_3 = new QLabel(jobsGroup);
        label_3->setObjectName("label_3");

        gridLayout_4->addWidget(label_3, 0, 0, 1, 1);

        focusEveryLabel = new QLabel(jobsGroup);
        focusEveryLabel->setObjectName("focusEveryLabel");
        sizePolicy.setHeightForWidth(focusEveryLabel->sizePolicy().hasHeightForWidth());
        focusEveryLabel->setSizePolicy(sizePolicy);

        gridLayout_4->addWidget(focusEveryLabel, 7, 5, 1, 1);

        selectJobsDirB = new QPushButton(jobsGroup);
        selectJobsDirB->setObjectName("selectJobsDirB");
        sizePolicy4.setHeightForWidth(selectJobsDirB->sizePolicy().hasHeightForWidth());
        selectJobsDirB->setSizePolicy(sizePolicy4);
        selectJobsDirB->setMinimumSize(QSize(32, 32));
        selectJobsDirB->setIcon(icon6);
        selectJobsDirB->setIconSize(QSize(28, 28));

        gridLayout_4->addWidget(selectJobsDirB, 4, 7, 1, 1);

        textLabel1_18 = new QLabel(jobsGroup);
        textLabel1_18->setObjectName("textLabel1_18");

        gridLayout_4->addWidget(textLabel1_18, 4, 0, 1, 1);

        alignEvery = new QSpinBox(jobsGroup);
        alignEvery->setObjectName("alignEvery");
        alignEvery->setMinimum(1);
        alignEvery->setMaximum(50);
        alignEvery->setValue(1);

        gridLayout_4->addWidget(alignEvery, 7, 2, 1, 2);

        focusEvery = new QSpinBox(jobsGroup);
        focusEvery->setObjectName("focusEvery");
        focusEvery->setMinimum(1);
        focusEvery->setMaximum(50);
        focusEvery->setValue(1);

        gridLayout_4->addWidget(focusEvery, 7, 6, 1, 2);

        sequenceEdit = new QLineEdit(jobsGroup);
        sequenceEdit->setObjectName("sequenceEdit");
        sequenceEdit->setEnabled(true);
        sizePolicy2.setHeightForWidth(sequenceEdit->sizePolicy().hasHeightForWidth());
        sequenceEdit->setSizePolicy(sizePolicy2);
        sequenceEdit->setReadOnly(true);

        gridLayout_4->addWidget(sequenceEdit, 2, 2, 1, 5);

        focusStepCheck = new QCheckBox(jobsGroup);
        focusStepCheck->setObjectName("focusStepCheck");
        sizePolicy.setHeightForWidth(focusStepCheck->sizePolicy().hasHeightForWidth());
        focusStepCheck->setSizePolicy(sizePolicy);
        focusStepCheck->setLayoutDirection(Qt::LeftToRight);
        focusStepCheck->setChecked(true);

        gridLayout_4->addWidget(focusStepCheck, 5, 4, 1, 1);

        verticalSpacer2_group = new QSpacerItem(0, 15, QSizePolicy::Policy::Minimum, QSizePolicy::Policy::Fixed);

        gridLayout_4->addItem(verticalSpacer2_group, 8, 0, 1, 1);

        groupBox = new QGroupBox(jobsGroup);
        groupBox->setObjectName("groupBox");
        sizePolicy.setHeightForWidth(groupBox->sizePolicy().hasHeightForWidth());
        groupBox->setSizePolicy(sizePolicy);
        groupLayout = new QGridLayout(groupBox);
        groupLayout->setObjectName("groupLayout");
        groupEdit = new QLineEdit(groupBox);
        groupEdit->setObjectName("groupEdit");
        sizePolicy.setHeightForWidth(groupEdit->sizePolicy().hasHeightForWidth());
        groupEdit->setSizePolicy(sizePolicy);

        groupLayout->addWidget(groupEdit, 0, 0, 1, 1);

        verticalSpacer_group = new QSpacerItem(20, 40, QSizePolicy::Policy::Minimum, QSizePolicy::Policy::Expanding);

        groupLayout->addItem(verticalSpacer_group, 1, 0, 1, 1);


        gridLayout_4->addWidget(groupBox, 9, 0, 1, 5);

        completionGroup = new QGroupBox(jobsGroup);
        completionGroup->setObjectName("completionGroup");
        sizePolicy.setHeightForWidth(completionGroup->sizePolicy().hasHeightForWidth());
        completionGroup->setSizePolicy(sizePolicy);
        completionLayout = new QGridLayout(completionGroup);
        completionLayout->setObjectName("completionLayout");
        repeatCompletionR = new QRadioButton(completionGroup);
        repeatCompletionR->setObjectName("repeatCompletionR");
        sizePolicy.setHeightForWidth(repeatCompletionR->sizePolicy().hasHeightForWidth());
        repeatCompletionR->setSizePolicy(sizePolicy);

        completionLayout->addWidget(repeatCompletionR, 1, 4, 1, 1);

        sequenceCompletionR = new QRadioButton(completionGroup);
        sequenceCompletionR->setObjectName("sequenceCompletionR");
        sizePolicy.setHeightForWidth(sequenceCompletionR->sizePolicy().hasHeightForWidth());
        sequenceCompletionR->setSizePolicy(sizePolicy);
        sequenceCompletionR->setChecked(true);

        completionLayout->addWidget(sequenceCompletionR, 0, 4, 1, 5);

        repeatsSpin = new QSpinBox(completionGroup);
        repeatsSpin->setObjectName("repeatsSpin");
        sizePolicy.setHeightForWidth(repeatsSpin->sizePolicy().hasHeightForWidth());
        repeatsSpin->setSizePolicy(sizePolicy);
        repeatsSpin->setMinimum(1);
        repeatsSpin->setMaximum(1000);
        repeatsSpin->setValue(1);

        completionLayout->addWidget(repeatsSpin, 1, 6, 1, 5);

        loopCompletionR = new QRadioButton(completionGroup);
        loopCompletionR->setObjectName("loopCompletionR");
        sizePolicy.setHeightForWidth(loopCompletionR->sizePolicy().hasHeightForWidth());
        loopCompletionR->setSizePolicy(sizePolicy);

        completionLayout->addWidget(loopCompletionR, 2, 4, 1, 5);


        gridLayout_4->addWidget(completionGroup, 9, 5, 1, 5);


        verticalLayout_4->addWidget(jobsGroup);

        verticalSpacer_3 = new QSpacerItem(20, 40, QSizePolicy::Policy::Minimum, QSizePolicy::Policy::Expanding);

        verticalLayout_4->addItem(verticalSpacer_3);

        horizontalLayout_14 = new QHBoxLayout();
        horizontalLayout_14->setObjectName("horizontalLayout_14");
        backToAdjustGridB = new QPushButton(jobs);
        backToAdjustGridB->setObjectName("backToAdjustGridB");
        backToAdjustGridB->setIcon(icon3);

        horizontalLayout_14->addWidget(backToAdjustGridB);

        horizontalSpacer_3 = new QSpacerItem(40, 20, QSizePolicy::Policy::Expanding, QSizePolicy::Policy::Minimum);

        horizontalLayout_14->addItem(horizontalSpacer_3);

        createJobsB = new QPushButton(jobs);
        createJobsB->setObjectName("createJobsB");
        createJobsB->setEnabled(false);
        QIcon icon7(QIcon::fromTheme(QString::fromUtf8("checkmark")));
        createJobsB->setIcon(icon7);

        horizontalLayout_14->addWidget(createJobsB);


        verticalLayout_4->addLayout(horizontalLayout_14);

        stackedWidget->addWidget(jobs);

        verticalLayout_2->addWidget(stackedWidget);

        QWidget::setTabOrder(focalLenSpin, focalReducerSpin);
        QWidget::setTabOrder(focalReducerSpin, cameraWSpin);
        QWidget::setTabOrder(cameraWSpin, cameraHSpin);
        QWidget::setTabOrder(cameraHSpin, pixelWSizeSpin);
        QWidget::setTabOrder(pixelWSizeSpin, pixelHSizeSpin);
        QWidget::setTabOrder(pixelHSizeSpin, fetchB);
        QWidget::setTabOrder(fetchB, nextToSelectGridB);
        QWidget::setTabOrder(nextToSelectGridB, overlapSpin);
        QWidget::setTabOrder(overlapSpin, mosaicWSpin);
        QWidget::setTabOrder(mosaicWSpin, mosaicHSpin);
        QWidget::setTabOrder(mosaicHSpin, targetWFOVSpin);
        QWidget::setTabOrder(targetWFOVSpin, targetHFOVSpin);
        QWidget::setTabOrder(targetHFOVSpin, positionAngleSpin);
        QWidget::setTabOrder(positionAngleSpin, transparencySlider);
        QWidget::setTabOrder(transparencySlider, transparencyAuto);
        QWidget::setTabOrder(transparencyAuto, reverseOddRows);
        QWidget::setTabOrder(reverseOddRows, backToEquipmentB);
        QWidget::setTabOrder(backToEquipmentB, importB);
        QWidget::setTabOrder(importB, recenterB);
        QWidget::setTabOrder(recenterB, nextToAdjustGrid);
        QWidget::setTabOrder(nextToAdjustGrid, raBox);
        QWidget::setTabOrder(raBox, decBox);
        QWidget::setTabOrder(decBox, backToSelectGrid);
        QWidget::setTabOrder(backToSelectGrid, goSolveB);
        QWidget::setTabOrder(goSolveB, nextToJobsB);
        QWidget::setTabOrder(nextToJobsB, targetEdit);
        QWidget::setTabOrder(targetEdit, sequenceEdit);
        QWidget::setTabOrder(sequenceEdit, loadSequenceB);
        QWidget::setTabOrder(loadSequenceB, directoryEdit);
        QWidget::setTabOrder(directoryEdit, selectJobsDirB);
        QWidget::setTabOrder(selectJobsDirB, trackStepCheck);
        QWidget::setTabOrder(trackStepCheck, focusStepCheck);
        QWidget::setTabOrder(focusStepCheck, alignStepCheck);
        QWidget::setTabOrder(alignStepCheck, guideStepCheck);
        QWidget::setTabOrder(guideStepCheck, alignEvery);
        QWidget::setTabOrder(alignEvery, focusEvery);
        QWidget::setTabOrder(focusEvery, groupEdit);
        QWidget::setTabOrder(groupEdit, sequenceCompletionR);
        QWidget::setTabOrder(sequenceCompletionR, repeatCompletionR);
        QWidget::setTabOrder(repeatCompletionR, repeatsSpin);
        QWidget::setTabOrder(repeatsSpin, loopCompletionR);
        QWidget::setTabOrder(loopCompletionR, backToAdjustGridB);
        QWidget::setTabOrder(backToAdjustGridB, createJobsB);
        QWidget::setTabOrder(createJobsB, resetB);

        retranslateUi(FramingAssistant);

        stackedWidget->setCurrentIndex(0);


        QMetaObject::connectSlotsByName(FramingAssistant);
    } // setupUi

    void retranslateUi(QDialog *FramingAssistant)
    {
        FramingAssistant->setWindowTitle(tr2i18n("Mosaic Planner", nullptr));
        equipmentGroup->setTitle(tr2i18n("\342\206\223 Confirm Equipment", nullptr));
#if QT_CONFIG(tooltip)
        label_4->setToolTip(tr2i18n("Mount focal length in millimeters", nullptr));
#endif // QT_CONFIG(tooltip)
        label_4->setText(tr2i18n("Focal length:", nullptr));
#if QT_CONFIG(tooltip)
        focalLenSpin->setToolTip(tr2i18n("<html><head/><body><p align=\"justify\">Focal length of the telescope to use for the mosaic.</p></body></html>", nullptr));
#endif // QT_CONFIG(tooltip)
        focalLenSpin->setSuffix(tr2i18n(" mm", nullptr));
        label_17->setText(tr2i18n("Reducer:", nullptr));
#if QT_CONFIG(tooltip)
        label_8->setToolTip(tr2i18n("Camera frame width and height in pixels", nullptr));
#endif // QT_CONFIG(tooltip)
        label_8->setText(tr2i18n("Camera:", nullptr));
        label_9->setText(tr2i18n("W", nullptr));
#if QT_CONFIG(tooltip)
        cameraWSpin->setToolTip(tr2i18n("<html><head/><body><p align=\"justify\">Width of the frame produced by the camera, in pixels.</p></body></html>", nullptr));
#endif // QT_CONFIG(tooltip)
        cameraWSpin->setSuffix(tr2i18n(" pix", nullptr));
        label_10->setText(tr2i18n("H", nullptr));
#if QT_CONFIG(tooltip)
        cameraHSpin->setToolTip(tr2i18n("<html><head/><body><p align=\"justify\">Height of the frame produced by the camera, in pixels.</p></body></html>", nullptr));
#endif // QT_CONFIG(tooltip)
        cameraHSpin->setSuffix(tr2i18n(" pix", nullptr));
#if QT_CONFIG(tooltip)
        label_11->setToolTip(tr2i18n("Camera pixel size in microns", nullptr));
#endif // QT_CONFIG(tooltip)
        label_11->setText(tr2i18n("Pixel Size:", nullptr));
        label_13->setText(tr2i18n("W", nullptr));
#if QT_CONFIG(tooltip)
        pixelWSizeSpin->setToolTip(tr2i18n("<html><head/><body><p align=\"justify\">Width of a single camera photosite, in micrometers.</p></body></html>", nullptr));
#endif // QT_CONFIG(tooltip)
        pixelWSizeSpin->setSuffix(tr2i18n(" \302\265m", nullptr));
        label_14->setText(tr2i18n("H", nullptr));
#if QT_CONFIG(tooltip)
        pixelHSizeSpin->setToolTip(tr2i18n("<html><head/><body><p align=\"justify\">Height of a single camera photosite, in micrometers.</p></body></html>", nullptr));
#endif // QT_CONFIG(tooltip)
        pixelHSizeSpin->setSuffix(tr2i18n(" \302\265m", nullptr));
#if QT_CONFIG(tooltip)
        fetchB->setToolTip(tr2i18n("<html><head/><body><p align=\"justify\">Fetch equipment information from the Ekos active profile, if any.</p></body></html>", nullptr));
#endif // QT_CONFIG(tooltip)
        fetchB->setText(tr2i18n("Fetch", nullptr));
#if QT_CONFIG(tooltip)
        nextToSelectGridB->setToolTip(tr2i18n("Go to Grid Selection page", nullptr));
#endif // QT_CONFIG(tooltip)
        nextToSelectGridB->setText(tr2i18n("Select Grid", nullptr));
        fovGroup->setTitle(tr2i18n("\342\206\223 Select Grid", nullptr));
#if QT_CONFIG(tooltip)
        overlapLabel->setToolTip(tr2i18n("Percentage of overlap between two neighbouring images", nullptr));
#endif // QT_CONFIG(tooltip)
        overlapLabel->setText(tr2i18n("Overlap:", nullptr));
#if QT_CONFIG(tooltip)
        overlapSpin->setToolTip(tr2i18n("<html><head/><body><p align=\"justify\">Overlap between each tile of the mosaic. See the main help icon in the corner of the sky chart.</p></body></html>", nullptr));
#endif // QT_CONFIG(tooltip)
        overlapSpin->setSuffix(tr2i18n(" %", nullptr));
#if QT_CONFIG(tooltip)
        resetB->setToolTip(tr2i18n("<html><head/><body><p align=\"justify\">Recompute the mosaic field from the number of tiles.</p></body></html>", nullptr));
#endif // QT_CONFIG(tooltip)
        resetB->setText(tr2i18n("Cover FOV", nullptr));
#if QT_CONFIG(tooltip)
        label->setToolTip(tr2i18n("Specify the number of rows and columns of the final mosaic image", nullptr));
#endif // QT_CONFIG(tooltip)
        label->setText(tr2i18n("Mosaic Grid:", nullptr));
        label_7->setText(tr2i18n("W", nullptr));
#if QT_CONFIG(tooltip)
        mosaicWSpin->setToolTip(tr2i18n("<html><head/><body><p align=\"justify\">Number of tiles on the mosaic width.</p><p align=\"justify\">Modifying this value immediately changes the width of the field covered by the mosaic.</p></body></html>", nullptr));
#endif // QT_CONFIG(tooltip)
        mosaicWSpin->setSuffix(tr2i18n(" x", nullptr));
        label_12->setText(tr2i18n("H", nullptr));
#if QT_CONFIG(tooltip)
        mosaicHSpin->setToolTip(tr2i18n("<html><head/><body><p align=\"justify\">Number of tiles on the mosaic height.</p><p align=\"justify\">Modifying this value immediately changes the height of the field covered by the mosaic.</p></body></html>", nullptr));
#endif // QT_CONFIG(tooltip)
        mosaicHSpin->setSuffix(tr2i18n(" x", nullptr));
#if QT_CONFIG(tooltip)
        targetFOVLabel->setToolTip(tr2i18n("Final mosaic field of view size in arc minutes. Click update to calculate it or enter it manually.", nullptr));
#endif // QT_CONFIG(tooltip)
        targetFOVLabel->setText(tr2i18n("Mosaic FOV:", nullptr));
        targetFOVWLabel->setText(tr2i18n("W", nullptr));
#if QT_CONFIG(tooltip)
        targetWFOVSpin->setToolTip(tr2i18n("<html><head/><body><p align=\"justify\">Minimum field width that the mosaic must cover, in arcminutes.</p><p align=\"justify\">Modifying this value immediately changes the number of tiles on the mosaic width.</p></body></html>", nullptr));
#endif // QT_CONFIG(tooltip)
        targetWFOVSpin->setSuffix(tr2i18n("'", nullptr));
        targetFOVHLabel->setText(tr2i18n("H", nullptr));
#if QT_CONFIG(tooltip)
        targetHFOVSpin->setToolTip(tr2i18n("<html><head/><body><p align=\"justify\">Minimum field height that the mosaic must cover, in arcminutes.</p><p align=\"justify\">Modifying this value immediately changes the number of tiles on the mosaic height. </p></body></html>", nullptr));
#endif // QT_CONFIG(tooltip)
        targetHFOVSpin->setSuffix(tr2i18n("'", nullptr));
#if QT_CONFIG(tooltip)
        cameraFOVLabel->setToolTip(tr2i18n("Camera FOV in arc minutes as determined from equipment parameters above", nullptr));
#endif // QT_CONFIG(tooltip)
        cameraFOVLabel->setText(tr2i18n("Camera FOV:", nullptr));
        cameraWFOVLabel->setText(tr2i18n("W", nullptr));
#if QT_CONFIG(tooltip)
        cameraWFOVSpin->setToolTip(tr2i18n("<html><head/><body><p align=\"justify\">Field width of the camera in arcminutes.</p><p align=\"justify\">This value is computed from the equipment information, and defines the width of the field covered by one tile of the mosaic.</p></body></html>", nullptr));
#endif // QT_CONFIG(tooltip)
        cameraWFOVSpin->setSuffix(tr2i18n("'", nullptr));
        cameraHFOVLabel->setText(tr2i18n("H", nullptr));
#if QT_CONFIG(tooltip)
        cameraHFOVSpin->setToolTip(tr2i18n("<html><head/><body><p align=\"justify\">Field height of the camera in arcminutes.</p><p align=\"justify\">This value is computed from the equipment information, and defines the height of the field covered by one tile of the mosaic.</p></body></html>", nullptr));
#endif // QT_CONFIG(tooltip)
        cameraHFOVSpin->setSuffix(tr2i18n("'", nullptr));
#if QT_CONFIG(tooltip)
        label_2->setToolTip(tr2i18n("Camera's rotation angle (East of North) in degrees. To measure the angle, solve an image and use the astrometry solver solution's rotation angle", nullptr));
#endif // QT_CONFIG(tooltip)
        label_2->setText(tr2i18n("Position Angle:", nullptr));
#if QT_CONFIG(tooltip)
        goRotateB->setToolTip(tr2i18n("Go to center and rotate to match this position angle", nullptr));
#endif // QT_CONFIG(tooltip)
        goRotateB->setText(QString());
        label_16->setText(tr2i18n("Tile Transparency:", nullptr));
#if QT_CONFIG(whatsthis)
        transparencySlider->setWhatsThis(tr2i18n("Adjust tiles transparency", nullptr));
#endif // QT_CONFIG(whatsthis)
        transparencyAuto->setText(tr2i18n("Auto", "Transparency"));
#if QT_CONFIG(tooltip)
        reverseOddRows->setToolTip(tr2i18n("<html><head/><body><p>When checked, orders mosaic tiles so that the mount moves minimally between jobs (S-shape).</p></body></html>", nullptr));
#endif // QT_CONFIG(tooltip)
        reverseOddRows->setText(tr2i18n("Minimum mount move", nullptr));
#if QT_CONFIG(tooltip)
        positionAngleSpin->setToolTip(tr2i18n("<html><head/><body><p align=\"justify\">Orientation of the camera field of view.</p></body></html>", nullptr));
#endif // QT_CONFIG(tooltip)
        positionAngleSpin->setSuffix(tr2i18n(" East of North", nullptr));
#if QT_CONFIG(tooltip)
        backToEquipmentB->setToolTip(tr2i18n("Go to equipment selection page", nullptr));
#endif // QT_CONFIG(tooltip)
        backToEquipmentB->setText(tr2i18n("Confirm Equipment", nullptr));
#if QT_CONFIG(tooltip)
        importB->setToolTip(tr2i18n("Import Mosaic from Telescopius", nullptr));
#endif // QT_CONFIG(tooltip)
        importB->setText(tr2i18n("Import...", nullptr));
#if QT_CONFIG(tooltip)
        recenterB->setToolTip(tr2i18n("Reset mosaic center to sky map center", nullptr));
#endif // QT_CONFIG(tooltip)
        recenterB->setText(tr2i18n("Recenter", nullptr));
#if QT_CONFIG(tooltip)
        nextToAdjustGrid->setToolTip(tr2i18n("Go to grid adjustment page", nullptr));
#endif // QT_CONFIG(tooltip)
        nextToAdjustGrid->setText(tr2i18n("Adjust Grid", nullptr));
        fovGroup_2->setTitle(tr2i18n("\342\206\223 Adjust Grid", nullptr));
#if QT_CONFIG(tooltip)
        decBox->setToolTip(QString());
#endif // QT_CONFIG(tooltip)
#if QT_CONFIG(tooltip)
        raBox->setToolTip(QString());
#endif // QT_CONFIG(tooltip)
#if QT_CONFIG(tooltip)
        label_6->setToolTip(tr2i18n("Specify the number of rows and columns of the final mosaic image", nullptr));
#endif // QT_CONFIG(tooltip)
        label_6->setText(tr2i18n("J2000 Center", nullptr));
        label_15->setText(tr2i18n("Adjust Grid center by manually entering the J2000 center or by dragging the center of the mosaic on the sky map.", nullptr));
#if QT_CONFIG(tooltip)
        backToSelectGrid->setToolTip(tr2i18n("Go to grid selection page", nullptr));
#endif // QT_CONFIG(tooltip)
        backToSelectGrid->setText(tr2i18n("Select Grid", nullptr));
#if QT_CONFIG(tooltip)
        goSolveB->setToolTip(tr2i18n("Go and plate solve mosaic center", nullptr));
#endif // QT_CONFIG(tooltip)
        goSolveB->setText(tr2i18n("Go && Solve", nullptr));
#if QT_CONFIG(tooltip)
        nextToJobsB->setToolTip(tr2i18n("Go to scheduler job creation page", nullptr));
#endif // QT_CONFIG(tooltip)
        nextToJobsB->setText(tr2i18n("Create Jobs", nullptr));
        jobsGroup->setTitle(tr2i18n("\342\206\223Create  Scheduler Jobs", nullptr));
#if QT_CONFIG(tooltip)
        guideStepCheck->setToolTip(tr2i18n("Perform calibration and autoguiding before proceeding to the next step.", nullptr));
#endif // QT_CONFIG(tooltip)
        guideStepCheck->setText(tr2i18n("Guide", nullptr));
#if QT_CONFIG(tooltip)
        directoryEdit->setToolTip(tr2i18n("<html><head/><body><p align=\"justify\">Filesystem folder where the Scheduler jobs required to cover the mosaic will be created in.</p></body></html>", nullptr));
#endif // QT_CONFIG(tooltip)
#if QT_CONFIG(tooltip)
        sequenceLabel->setToolTip(tr2i18n("Ekos Sequence File", nullptr));
#endif // QT_CONFIG(tooltip)
        sequenceLabel->setText(tr2i18n("<html><head/><body><p>Sequence: <span style=\" color:#ff0000;\">*</span></p></body></html>", nullptr));
#if QT_CONFIG(tooltip)
        alignStepCheck->setToolTip(tr2i18n("Perform alignment using astrometry solver before proceeding to the next step.", nullptr));
#endif // QT_CONFIG(tooltip)
        alignStepCheck->setText(tr2i18n("Align", nullptr));
#if QT_CONFIG(tooltip)
        label_5->setToolTip(tr2i18n("Select which steps to execute before starting the capture process.", nullptr));
#endif // QT_CONFIG(tooltip)
        label_5->setText(tr2i18n("Steps:", nullptr));
        alignEveryLabel->setText(tr2i18n("Align Every", nullptr));
#if QT_CONFIG(tooltip)
        loadSequenceB->setToolTip(tr2i18n("Load the image sequence queue.", nullptr));
#endif // QT_CONFIG(tooltip)
        loadSequenceB->setText(QString());
        targetEdit->setPlaceholderText(tr2i18n("M 31", nullptr));
#if QT_CONFIG(tooltip)
        trackStepCheck->setToolTip(tr2i18n("Slew to the target and track it before proceeding to the next step.", nullptr));
#endif // QT_CONFIG(tooltip)
        trackStepCheck->setText(tr2i18n("Track", nullptr));
        label_3->setText(tr2i18n("<html><head/><body><p>Target: <span style=\" color:#ff0000;\">*</span></p></body></html>", nullptr));
        focusEveryLabel->setText(tr2i18n("Focus Every", nullptr));
        selectJobsDirB->setText(QString());
#if QT_CONFIG(tooltip)
        textLabel1_18->setToolTip(tr2i18n("Directory to save sequence images", nullptr));
#endif // QT_CONFIG(tooltip)
#if QT_CONFIG(whatsthis)
        textLabel1_18->setWhatsThis(QString());
#endif // QT_CONFIG(whatsthis)
        textLabel1_18->setText(tr2i18n("<html><head/><body><p>Directory: <span style=\" color:#ff0000;\">*</span></p></body></html>", nullptr));
#if QT_CONFIG(tooltip)
        alignEvery->setToolTip(tr2i18n("Perform alignment every N jobs.", nullptr));
#endif // QT_CONFIG(tooltip)
        alignEvery->setSuffix(QString());
#if QT_CONFIG(tooltip)
        focusEvery->setToolTip(tr2i18n("Perform autofocus every N jobs.", nullptr));
#endif // QT_CONFIG(tooltip)
        focusEvery->setSuffix(QString());
#if QT_CONFIG(tooltip)
        focusStepCheck->setToolTip(tr2i18n("Perform autofocusing before proceeding to the next step.", nullptr));
#endif // QT_CONFIG(tooltip)
        focusStepCheck->setText(tr2i18n("Focus", nullptr));
        groupBox->setTitle(tr2i18n("Group:", nullptr));
#if QT_CONFIG(tooltip)
        groupEdit->setToolTip(tr2i18n("<html><head/><body><p align=\"justify\">Select a group name. Useful if you want the mosaic jobs to repeat together--assign them a group name, and give them <span style=\" font-style:italic;\">repeat for N (N=2 or more)</span> or <span style=\" font-style:italic;\">repeat until terminated</span> completion conditions. Otherwise leave empty.</p></body></html>", nullptr));
#endif // QT_CONFIG(tooltip)
        completionGroup->setTitle(tr2i18n("Completion Condition:", nullptr));
#if QT_CONFIG(tooltip)
        repeatCompletionR->setToolTip(tr2i18n("Restart job until it is executed this many times.", nullptr));
#endif // QT_CONFIG(tooltip)
        repeatCompletionR->setText(tr2i18n("&Repeat for", nullptr));
#if QT_CONFIG(tooltip)
        sequenceCompletionR->setToolTip(tr2i18n("The observation job is completed when the sequence is complete.", nullptr));
#endif // QT_CONFIG(tooltip)
        sequenceCompletionR->setText(tr2i18n("Se&quence completion", nullptr));
#if QT_CONFIG(tooltip)
        repeatsSpin->setToolTip(tr2i18n("Restart job until it is executed this many times.", nullptr));
#endif // QT_CONFIG(tooltip)
        repeatsSpin->setSuffix(tr2i18n(" runs", nullptr));
#if QT_CONFIG(tooltip)
        loopCompletionR->setToolTip(tr2i18n("Restart the sequence job indefinitely.", nullptr));
#endif // QT_CONFIG(tooltip)
        loopCompletionR->setText(tr2i18n("Repeat &until terminated", nullptr));
#if QT_CONFIG(tooltip)
        backToAdjustGridB->setToolTip(tr2i18n("Go to grid selection page", nullptr));
#endif // QT_CONFIG(tooltip)
        backToAdjustGridB->setText(tr2i18n("Select Grid", nullptr));
#if QT_CONFIG(tooltip)
        createJobsB->setToolTip(tr2i18n("Create scheduler jobs to execute the mosaic plan", nullptr));
#endif // QT_CONFIG(tooltip)
        createJobsB->setText(tr2i18n("Create Jobs", nullptr));
    } // retranslateUi

};

namespace Ui {
    class FramingAssistant: public Ui_FramingAssistant {};
} // namespace Ui

QT_END_NAMESPACE

#endif // FRAMINGASSISTANT_H

