/*
 * This file was generated by qdbusxml2cpp version 0.8
 * Source file was org.kde.kstars.INDI.xml
 *
 * qdbusxml2cpp is Copyright (C) The Qt Company Ltd. and other contributors.
 *
 * This is an auto-generated file.
 * Do not edit! All changes made to it will be lost.
 */

#include "indiadaptor.h"
#include <QtCore/QMetaObject>
#include <QtCore/QByteArray>
#include <QtCore/QList>
#include <QtCore/QMap>
#include <QtCore/QString>
#include <QtCore/QStringList>
#include <QtCore/QVariant>

/*
 * Implementation of adaptor class INDIAdaptor
 */

INDIAdaptor::INDIAdaptor(INDIDBus *parent)
    : QDBusAbstractAdaptor(parent)
{
    // constructor
    setAutoRelaySignals(true);
}

INDIAdaptor::~INDIAdaptor()
{
    // destructor
}

bool INDIAdaptor::connect(const QString &host, int port)
{
    // handle method call org.kde.kstars.INDI.connect
    return parent()->connect(host, port);
}

bool INDIAdaptor::disconnect(const QString &host, int port)
{
    // handle method call org.kde.kstars.INDI.disconnect
    return parent()->disconnect(host, port);
}

QByteArray INDIAdaptor::getBLOBData(const QString &device, const QString &property, const QString &blobName, QString &blobFormat, int &size)
{
    // handle method call org.kde.kstars.INDI.getBLOBData
    return parent()->getBLOBData(device, property, blobName, blobFormat, size);
}

QString INDIAdaptor::getBLOBFile(const QString &device, const QString &property, const QString &blobName, QString &blobFormat, int &size)
{
    // handle method call org.kde.kstars.INDI.getBLOBFile
    return parent()->getBLOBFile(device, property, blobName, blobFormat, size);
}

QStringList INDIAdaptor::getDevices()
{
    // handle method call org.kde.kstars.INDI.getDevices
    return parent()->getDevices();
}

QStringList INDIAdaptor::getDevicesPaths(int interface)
{
    // handle method call org.kde.kstars.INDI.getDevicesPaths
    return parent()->getDevicesPaths(interface);
}

QString INDIAdaptor::getLight(const QString &device, const QString &property, const QString &lightName)
{
    // handle method call org.kde.kstars.INDI.getLight
    return parent()->getLight(device, property, lightName);
}

double INDIAdaptor::getNumber(const QString &device, const QString &property, const QString &numberName)
{
    // handle method call org.kde.kstars.INDI.getNumber
    return parent()->getNumber(device, property, numberName);
}

QStringList INDIAdaptor::getProperties(const QString &device)
{
    // handle method call org.kde.kstars.INDI.getProperties
    return parent()->getProperties(device);
}

QString INDIAdaptor::getPropertyState(const QString &device, const QString &property)
{
    // handle method call org.kde.kstars.INDI.getPropertyState
    return parent()->getPropertyState(device, property);
}

QString INDIAdaptor::getSwitch(const QString &device, const QString &property, const QString &switchName)
{
    // handle method call org.kde.kstars.INDI.getSwitch
    return parent()->getSwitch(device, property, switchName);
}

QString INDIAdaptor::getText(const QString &device, const QString &property, const QString &textName)
{
    // handle method call org.kde.kstars.INDI.getText
    return parent()->getText(device, property, textName);
}

bool INDIAdaptor::sendProperty(const QString &device, const QString &property)
{
    // handle method call org.kde.kstars.INDI.sendProperty
    return parent()->sendProperty(device, property);
}

bool INDIAdaptor::setNumber(const QString &device, const QString &property, const QString &numberName, double value)
{
    // handle method call org.kde.kstars.INDI.setNumber
    return parent()->setNumber(device, property, numberName, value);
}

bool INDIAdaptor::setSwitch(const QString &device, const QString &property, const QString &switchName, const QString &status)
{
    // handle method call org.kde.kstars.INDI.setSwitch
    return parent()->setSwitch(device, property, switchName, status);
}

bool INDIAdaptor::setText(const QString &device, const QString &property, const QString &textName, const QString &text)
{
    // handle method call org.kde.kstars.INDI.setText
    return parent()->setText(device, property, textName, text);
}

bool INDIAdaptor::start(int port, const QStringList &drivers)
{
    // handle method call org.kde.kstars.INDI.start
    return parent()->start(port, drivers);
}

bool INDIAdaptor::stop(const QString &port)
{
    // handle method call org.kde.kstars.INDI.stop
    return parent()->stop(port);
}


#include "moc_indiadaptor.cpp"
