/********************************************************************************
** Form generated from reading UI file 'catalogsdbui.ui'
**
** Created by: Qt User Interface Compiler version 6.11.1
**
** WARNING! All changes made in this file will be lost when recompiling UI file!
********************************************************************************/

#ifndef UI_CATALOGSDBUI_H
#define UI_CATALOGSDBUI_H

#include <QtCore/QVariant>
#include <QtWidgets/QAbstractButton>
#include <QtWidgets/QApplication>
#include <QtWidgets/QDialog>
#include <QtWidgets/QDialogButtonBox>
#include <QtWidgets/QHBoxLayout>
#include <QtWidgets/QHeaderView>
#include <QtWidgets/QPushButton>
#include <QtWidgets/QSpacerItem>
#include <QtWidgets/QTableWidget>
#include <QtWidgets/QVBoxLayout>
#include <klocalizedstring.h>

QT_BEGIN_NAMESPACE

class Ui_CatalogsDBUI
{
public:
    QVBoxLayout *verticalLayout;
    QHBoxLayout *horizontalLayout;
    QTableWidget *objectsTable;
    QVBoxLayout *verticalLayout_2;
    QPushButton *importButton;
    QPushButton *createButton;
    QSpacerItem *verticalSpacer_2;
    QPushButton *activateButton;
    QPushButton *removeButton;
    QPushButton *exportButton;
    QPushButton *dublicateButton;
    QPushButton *colorButton;
    QPushButton *moreButton;
    QDialogButtonBox *buttonBox;

    void setupUi(QDialog *CatalogsDBUI)
    {
        if (CatalogsDBUI->objectName().isEmpty())
            CatalogsDBUI->setObjectName("CatalogsDBUI");
        CatalogsDBUI->resize(783, 580);
        verticalLayout = new QVBoxLayout(CatalogsDBUI);
        verticalLayout->setObjectName("verticalLayout");
        horizontalLayout = new QHBoxLayout();
        horizontalLayout->setObjectName("horizontalLayout");
        objectsTable = new QTableWidget(CatalogsDBUI);
        objectsTable->setObjectName("objectsTable");
        objectsTable->setFrameShadow(QFrame::Sunken);
        objectsTable->setEditTriggers(QAbstractItemView::NoEditTriggers);
        objectsTable->setSelectionMode(QAbstractItemView::SingleSelection);
        objectsTable->setSelectionBehavior(QAbstractItemView::SelectRows);

        horizontalLayout->addWidget(objectsTable);

        verticalLayout_2 = new QVBoxLayout();
        verticalLayout_2->setObjectName("verticalLayout_2");
        verticalLayout_2->setContentsMargins(0, -1, -1, -1);
        importButton = new QPushButton(CatalogsDBUI);
        importButton->setObjectName("importButton");

        verticalLayout_2->addWidget(importButton);

        createButton = new QPushButton(CatalogsDBUI);
        createButton->setObjectName("createButton");

        verticalLayout_2->addWidget(createButton);

        verticalSpacer_2 = new QSpacerItem(20, 40, QSizePolicy::Policy::Minimum, QSizePolicy::Policy::Expanding);

        verticalLayout_2->addItem(verticalSpacer_2);

        activateButton = new QPushButton(CatalogsDBUI);
        activateButton->setObjectName("activateButton");
        activateButton->setEnabled(false);

        verticalLayout_2->addWidget(activateButton);

        removeButton = new QPushButton(CatalogsDBUI);
        removeButton->setObjectName("removeButton");
        removeButton->setEnabled(false);

        verticalLayout_2->addWidget(removeButton);

        exportButton = new QPushButton(CatalogsDBUI);
        exportButton->setObjectName("exportButton");
        exportButton->setEnabled(false);

        verticalLayout_2->addWidget(exportButton);

        dublicateButton = new QPushButton(CatalogsDBUI);
        dublicateButton->setObjectName("dublicateButton");
        dublicateButton->setEnabled(false);

        verticalLayout_2->addWidget(dublicateButton);

        colorButton = new QPushButton(CatalogsDBUI);
        colorButton->setObjectName("colorButton");
        colorButton->setEnabled(false);

        verticalLayout_2->addWidget(colorButton);

        moreButton = new QPushButton(CatalogsDBUI);
        moreButton->setObjectName("moreButton");
        moreButton->setEnabled(false);

        verticalLayout_2->addWidget(moreButton);


        horizontalLayout->addLayout(verticalLayout_2);


        verticalLayout->addLayout(horizontalLayout);

        buttonBox = new QDialogButtonBox(CatalogsDBUI);
        buttonBox->setObjectName("buttonBox");
        buttonBox->setOrientation(Qt::Horizontal);
        buttonBox->setStandardButtons(QDialogButtonBox::Cancel|QDialogButtonBox::Ok);

        verticalLayout->addWidget(buttonBox);


        retranslateUi(CatalogsDBUI);
        QObject::connect(buttonBox, &QDialogButtonBox::accepted, CatalogsDBUI, qOverload<>(&QDialog::accept));
        QObject::connect(buttonBox, &QDialogButtonBox::rejected, CatalogsDBUI, qOverload<>(&QDialog::reject));

        QMetaObject::connectSlotsByName(CatalogsDBUI);
    } // setupUi

    void retranslateUi(QDialog *CatalogsDBUI)
    {
        CatalogsDBUI->setWindowTitle(tr2i18n("DSO Catalogs", nullptr));
        importButton->setText(tr2i18n("Import Catalog...", nullptr));
        createButton->setText(tr2i18n("Create Catalog...", nullptr));
        activateButton->setText(tr2i18n("Enable", nullptr));
        removeButton->setText(tr2i18n("Remove", nullptr));
        exportButton->setText(tr2i18n("Export...", nullptr));
        dublicateButton->setText(tr2i18n("Clone...", nullptr));
        colorButton->setText(tr2i18n("Colors", nullptr));
        moreButton->setText(tr2i18n("More...", nullptr));
    } // retranslateUi

};

namespace Ui {
    class CatalogsDBUI: public Ui_CatalogsDBUI {};
} // namespace Ui

QT_END_NAMESPACE

#endif // CATALOGSDBUI_H

