/********************************************************************************
** Form generated from reading UI file 'viewsdialog.ui'
**
** Created by: Qt User Interface Compiler version 6.11.1
**
** WARNING! All changes made in this file will be lost when recompiling UI file!
********************************************************************************/

#ifndef UI_VIEWSDIALOG_H
#define UI_VIEWSDIALOG_H

#include <QtCore/QVariant>
#include <QtWidgets/QApplication>
#include <QtWidgets/QHBoxLayout>
#include <QtWidgets/QListView>
#include <QtWidgets/QPushButton>
#include <QtWidgets/QSpacerItem>
#include <QtWidgets/QVBoxLayout>
#include <QtWidgets/QWidget>
#include <klocalizedstring.h>

QT_BEGIN_NAMESPACE

class Ui_ViewsDialog
{
public:
    QHBoxLayout *hboxLayout;
    QListView *ViewListBox;
    QVBoxLayout *vboxLayout;
    QPushButton *NewButton;
    QSpacerItem *spacerItem;
    QPushButton *EditButton;
    QPushButton *RemoveButton;
    QSpacerItem *spacerItem1;

    void setupUi(QWidget *ViewsDialog)
    {
        if (ViewsDialog->objectName().isEmpty())
            ViewsDialog->setObjectName("ViewsDialog");
        ViewsDialog->resize(275, 325);
        hboxLayout = new QHBoxLayout(ViewsDialog);
        hboxLayout->setSpacing(6);
        hboxLayout->setObjectName("hboxLayout");
        hboxLayout->setContentsMargins(10, 10, 10, 10);
        ViewListBox = new QListView(ViewsDialog);
        ViewListBox->setObjectName("ViewListBox");
        ViewListBox->setEditTriggers(QAbstractItemView::NoEditTriggers);
        ViewListBox->setDefaultDropAction(Qt::IgnoreAction);
        ViewListBox->setAlternatingRowColors(true);

        hboxLayout->addWidget(ViewListBox);

        vboxLayout = new QVBoxLayout();
        vboxLayout->setSpacing(6);
        vboxLayout->setObjectName("vboxLayout");
        vboxLayout->setContentsMargins(0, 0, 0, 0);
        NewButton = new QPushButton(ViewsDialog);
        NewButton->setObjectName("NewButton");

        vboxLayout->addWidget(NewButton);

        spacerItem = new QSpacerItem(85, 16, QSizePolicy::Policy::Minimum, QSizePolicy::Policy::Fixed);

        vboxLayout->addItem(spacerItem);

        EditButton = new QPushButton(ViewsDialog);
        EditButton->setObjectName("EditButton");

        vboxLayout->addWidget(EditButton);

        RemoveButton = new QPushButton(ViewsDialog);
        RemoveButton->setObjectName("RemoveButton");

        vboxLayout->addWidget(RemoveButton);

        spacerItem1 = new QSpacerItem(85, 126, QSizePolicy::Policy::Minimum, QSizePolicy::Policy::Expanding);

        vboxLayout->addItem(spacerItem1);


        hboxLayout->addLayout(vboxLayout);


        retranslateUi(ViewsDialog);

        QMetaObject::connectSlotsByName(ViewsDialog);
    } // setupUi

    void retranslateUi(QWidget *ViewsDialog)
    {
        ViewsDialog->setWindowTitle(tr2i18n("Edit Sky Map Views", nullptr));
#if QT_CONFIG(tooltip)
        NewButton->setToolTip(tr2i18n("Add a new view", nullptr));
#endif // QT_CONFIG(tooltip)
#if QT_CONFIG(whatsthis)
        NewButton->setWhatsThis(tr2i18n("Add a new View to the list.  You can define the parity, orientation and other parameters.", nullptr));
#endif // QT_CONFIG(whatsthis)
        NewButton->setText(tr2i18n("New...", nullptr));
#if QT_CONFIG(tooltip)
        EditButton->setToolTip(tr2i18n("Modify the highlighted View", nullptr));
#endif // QT_CONFIG(tooltip)
#if QT_CONFIG(whatsthis)
        EditButton->setWhatsThis(tr2i18n("Press this button to modify the highlighted View.  You can change its parameters.", nullptr));
#endif // QT_CONFIG(whatsthis)
        EditButton->setText(tr2i18n("Edit...", nullptr));
#if QT_CONFIG(tooltip)
        RemoveButton->setToolTip(tr2i18n("Remove highlighted View", nullptr));
#endif // QT_CONFIG(tooltip)
#if QT_CONFIG(whatsthis)
        RemoveButton->setWhatsThis(tr2i18n("Press this button to remove the highlighted View from the list.", nullptr));
#endif // QT_CONFIG(whatsthis)
        RemoveButton->setText(tr2i18n("Remove", nullptr));
    } // retranslateUi

};

namespace Ui {
    class ViewsDialog: public Ui_ViewsDialog {};
} // namespace Ui

QT_END_NAMESPACE

#endif // VIEWSDIALOG_H

