/********************************************************************************
** Form generated from reading UI file 'opsweathersettings.ui'
**
** Created by: Qt User Interface Compiler version 6.11.1
**
** WARNING! All changes made in this file will be lost when recompiling UI file!
********************************************************************************/

#ifndef UI_OPSWEATHERSETTINGS_H
#define UI_OPSWEATHERSETTINGS_H

#include <QtCore/QVariant>
#include <QtWidgets/QApplication>
#include <QtWidgets/QCheckBox>
#include <QtWidgets/QFormLayout>
#include <QtWidgets/QHBoxLayout>
#include <QtWidgets/QLabel>
#include <QtWidgets/QLineEdit>
#include <QtWidgets/QSpacerItem>
#include <QtWidgets/QSpinBox>
#include <QtWidgets/QVBoxLayout>
#include <QtWidgets/QWidget>
#include <klocalizedstring.h>

QT_BEGIN_NAMESPACE

class Ui_OpsWeatherSettings
{
public:
    QVBoxLayout *verticalLayout;
    QFormLayout *formLayout;
    QCheckBox *kcfg_SchedulerWeather;
    QHBoxLayout *horizontalLayout;
    QSpinBox *kcfg_SchedulerWeatherGracePeriod;
    QLabel *label_3;
    QSpacerItem *horizontalSpacer;
    QLabel *label;
    QHBoxLayout *horizontalLayout_2;
    QSpinBox *kcfg_SchedulerWeatherShutdownDelay;
    QLabel *label_4;
    QSpacerItem *horizontalSpacer_2;
    QLabel *label_2;
    QLineEdit *kcfg_SchedulerSafetyMonitorConnectionString;
    QSpacerItem *verticalSpacer;

    void setupUi(QWidget *OpsWeatherSettings)
    {
        if (OpsWeatherSettings->objectName().isEmpty())
            OpsWeatherSettings->setObjectName("OpsWeatherSettings");
        OpsWeatherSettings->resize(495, 101);
        verticalLayout = new QVBoxLayout(OpsWeatherSettings);
        verticalLayout->setSpacing(3);
        verticalLayout->setObjectName("verticalLayout");
        verticalLayout->setContentsMargins(3, 3, 3, 3);
        formLayout = new QFormLayout();
        formLayout->setObjectName("formLayout");
        formLayout->setHorizontalSpacing(3);
        formLayout->setVerticalSpacing(3);
        kcfg_SchedulerWeather = new QCheckBox(OpsWeatherSettings);
        kcfg_SchedulerWeather->setObjectName("kcfg_SchedulerWeather");

        formLayout->setWidget(0, QFormLayout::ItemRole::LabelRole, kcfg_SchedulerWeather);

        horizontalLayout = new QHBoxLayout();
        horizontalLayout->setObjectName("horizontalLayout");
        kcfg_SchedulerWeatherGracePeriod = new QSpinBox(OpsWeatherSettings);
        kcfg_SchedulerWeatherGracePeriod->setObjectName("kcfg_SchedulerWeatherGracePeriod");
        kcfg_SchedulerWeatherGracePeriod->setMinimum(0);
        kcfg_SchedulerWeatherGracePeriod->setMaximum(1440);
        kcfg_SchedulerWeatherGracePeriod->setSingleStep(10);
        kcfg_SchedulerWeatherGracePeriod->setValue(10);

        horizontalLayout->addWidget(kcfg_SchedulerWeatherGracePeriod);

        label_3 = new QLabel(OpsWeatherSettings);
        label_3->setObjectName("label_3");

        horizontalLayout->addWidget(label_3);

        horizontalSpacer = new QSpacerItem(40, 20, QSizePolicy::Policy::Expanding, QSizePolicy::Policy::Minimum);

        horizontalLayout->addItem(horizontalSpacer);


        formLayout->setLayout(0, QFormLayout::ItemRole::FieldRole, horizontalLayout);

        label = new QLabel(OpsWeatherSettings);
        label->setObjectName("label");

        formLayout->setWidget(1, QFormLayout::ItemRole::LabelRole, label);

        horizontalLayout_2 = new QHBoxLayout();
        horizontalLayout_2->setObjectName("horizontalLayout_2");
        kcfg_SchedulerWeatherShutdownDelay = new QSpinBox(OpsWeatherSettings);
        kcfg_SchedulerWeatherShutdownDelay->setObjectName("kcfg_SchedulerWeatherShutdownDelay");
        kcfg_SchedulerWeatherShutdownDelay->setMaximum(1440);
        kcfg_SchedulerWeatherShutdownDelay->setValue(10);

        horizontalLayout_2->addWidget(kcfg_SchedulerWeatherShutdownDelay);

        label_4 = new QLabel(OpsWeatherSettings);
        label_4->setObjectName("label_4");

        horizontalLayout_2->addWidget(label_4);

        horizontalSpacer_2 = new QSpacerItem(40, 20, QSizePolicy::Policy::Expanding, QSizePolicy::Policy::Minimum);

        horizontalLayout_2->addItem(horizontalSpacer_2);


        formLayout->setLayout(1, QFormLayout::ItemRole::FieldRole, horizontalLayout_2);

        label_2 = new QLabel(OpsWeatherSettings);
        label_2->setObjectName("label_2");

        formLayout->setWidget(2, QFormLayout::ItemRole::LabelRole, label_2);

        kcfg_SchedulerSafetyMonitorConnectionString = new QLineEdit(OpsWeatherSettings);
        kcfg_SchedulerSafetyMonitorConnectionString->setObjectName("kcfg_SchedulerSafetyMonitorConnectionString");

        formLayout->setWidget(2, QFormLayout::ItemRole::FieldRole, kcfg_SchedulerSafetyMonitorConnectionString);


        verticalLayout->addLayout(formLayout);

        verticalSpacer = new QSpacerItem(20, 40, QSizePolicy::Policy::Minimum, QSizePolicy::Policy::Expanding);

        verticalLayout->addItem(verticalSpacer);


        retranslateUi(OpsWeatherSettings);

        QMetaObject::connectSlotsByName(OpsWeatherSettings);
    } // setupUi

    void retranslateUi(QWidget *OpsWeatherSettings)
    {
        OpsWeatherSettings->setWindowTitle(tr2i18n("TabWidget", nullptr));
#if QT_CONFIG(tooltip)
        kcfg_SchedulerWeather->setToolTip(tr2i18n("<html><head/><body><p><span style=\" font-weight:700;\">Enable Weather-Based Scheduling:</span> Prevents new jobs from starting during weather warnings or alerts. Existing jobs continue during warnings, but are aborted during alerts. System initiates a soft shutdown and waits for improved conditions or grace period expiration, after which the current job is terminated.</p></body></html>", nullptr));
#endif // QT_CONFIG(tooltip)
        kcfg_SchedulerWeather->setText(tr2i18n("Weather grace period", nullptr));
#if QT_CONFIG(tooltip)
        kcfg_SchedulerWeatherGracePeriod->setToolTip(tr2i18n("Wait this many minutes for the weather to improve before giving up. Set to 0 to wait indefinitely (scheduler keeps monitoring until weather improves).", nullptr));
#endif // QT_CONFIG(tooltip)
        label_3->setText(tr2i18n("minutes", nullptr));
#if QT_CONFIG(tooltip)
        label->setToolTip(tr2i18n("<html><head/><body><p>Wait this many seconds when detecting weather alert before starting observatory shutdown.</p></body></html>", nullptr));
#endif // QT_CONFIG(tooltip)
        label->setText(tr2i18n("Weather Alert  Shutdown Delay:", nullptr));
        label_4->setText(tr2i18n("seconds", nullptr));
        label_2->setText(tr2i18n("Standalone Safety Monitor Driver:", nullptr));
#if QT_CONFIG(tooltip)
        kcfg_SchedulerSafetyMonitorConnectionString->setToolTip(tr2i18n("Connection string for the INDI Safety Monitor driver. The scheduler uses this to continuously monitor safety conditions and evaluate whether it is safe to operate the observatory.", nullptr));
#endif // QT_CONFIG(tooltip)
        kcfg_SchedulerSafetyMonitorConnectionString->setPlaceholderText(tr2i18n("localhost:7624", nullptr));
    } // retranslateUi

};

namespace Ui {
    class OpsWeatherSettings: public Ui_OpsWeatherSettings {};
} // namespace Ui

QT_END_NAMESPACE

#endif // OPSWEATHERSETTINGS_H

