/********************************************************************************
** Form generated from reading UI file 'flagmanager.ui'
**
** Created by: Qt User Interface Compiler version 6.11.1
**
** WARNING! All changes made in this file will be lost when recompiling UI file!
********************************************************************************/

#ifndef UI_FLAGMANAGER_H
#define UI_FLAGMANAGER_H

#include <QtCore/QVariant>
#include <QtWidgets/QApplication>
#include <QtWidgets/QComboBox>
#include <QtWidgets/QFormLayout>
#include <QtWidgets/QHBoxLayout>
#include <QtWidgets/QHeaderView>
#include <QtWidgets/QLabel>
#include <QtWidgets/QLineEdit>
#include <QtWidgets/QPushButton>
#include <QtWidgets/QSpacerItem>
#include <QtWidgets/QTableView>
#include <QtWidgets/QVBoxLayout>
#include <QtWidgets/QWidget>
#include <klocalizedstring.h>
#include "kcolorcombo.h"
#include "widgets/dmsbox.h"

QT_BEGIN_NAMESPACE

class Ui_FlagManager
{
public:
    QVBoxLayout *verticalLayout_2;
    QHBoxLayout *horizontalLayout;
    QFormLayout *formLayout;
    QLabel *raLabel;
    dmsBox *raBox;
    QLabel *decLabel;
    dmsBox *decBox;
    QLabel *epochLabel;
    QLineEdit *epochBox;
    QLabel *label;
    QLineEdit *flagLabel;
    QLabel *label_4;
    QLabel *label_2;
    QComboBox *flagCombobox;
    KColorCombo *labelColorcombo;
    QVBoxLayout *verticalLayout_3;
    QPushButton *addButton;
    QPushButton *saveButton;
    QSpacerItem *verticalSpacer_2;
    QLabel *hintLabel;
    QHBoxLayout *horizontalLayout_2;
    QTableView *flagList;
    QVBoxLayout *verticalLayout;
    QPushButton *CenterButton;
    QPushButton *ScopeButton;
    QPushButton *delButton;
    QSpacerItem *verticalSpacer;

    void setupUi(QWidget *FlagManager)
    {
        if (FlagManager->objectName().isEmpty())
            FlagManager->setObjectName("FlagManager");
        FlagManager->resize(497, 473);
        FlagManager->setMinimumSize(QSize(465, 450));
        verticalLayout_2 = new QVBoxLayout(FlagManager);
        verticalLayout_2->setObjectName("verticalLayout_2");
        horizontalLayout = new QHBoxLayout();
        horizontalLayout->setObjectName("horizontalLayout");
        formLayout = new QFormLayout();
        formLayout->setObjectName("formLayout");
        formLayout->setFieldGrowthPolicy(QFormLayout::ExpandingFieldsGrow);
        raLabel = new QLabel(FlagManager);
        raLabel->setObjectName("raLabel");

        formLayout->setWidget(0, QFormLayout::ItemRole::LabelRole, raLabel);

        raBox = new dmsBox(FlagManager);
        raBox->setObjectName("raBox");
        raBox->setMaximumSize(QSize(150, 16777215));

        formLayout->setWidget(0, QFormLayout::ItemRole::FieldRole, raBox);

        decLabel = new QLabel(FlagManager);
        decLabel->setObjectName("decLabel");

        formLayout->setWidget(1, QFormLayout::ItemRole::LabelRole, decLabel);

        decBox = new dmsBox(FlagManager);
        decBox->setObjectName("decBox");
        decBox->setMaximumSize(QSize(150, 16777215));

        formLayout->setWidget(1, QFormLayout::ItemRole::FieldRole, decBox);

        epochLabel = new QLabel(FlagManager);
        epochLabel->setObjectName("epochLabel");

        formLayout->setWidget(2, QFormLayout::ItemRole::LabelRole, epochLabel);

        epochBox = new QLineEdit(FlagManager);
        epochBox->setObjectName("epochBox");
        epochBox->setMaximumSize(QSize(150, 16777215));

        formLayout->setWidget(2, QFormLayout::ItemRole::FieldRole, epochBox);

        label = new QLabel(FlagManager);
        label->setObjectName("label");

        formLayout->setWidget(3, QFormLayout::ItemRole::LabelRole, label);

        flagLabel = new QLineEdit(FlagManager);
        flagLabel->setObjectName("flagLabel");
        flagLabel->setMaximumSize(QSize(150, 16777215));

        formLayout->setWidget(3, QFormLayout::ItemRole::FieldRole, flagLabel);

        label_4 = new QLabel(FlagManager);
        label_4->setObjectName("label_4");

        formLayout->setWidget(4, QFormLayout::ItemRole::LabelRole, label_4);

        label_2 = new QLabel(FlagManager);
        label_2->setObjectName("label_2");

        formLayout->setWidget(5, QFormLayout::ItemRole::LabelRole, label_2);

        flagCombobox = new QComboBox(FlagManager);
        flagCombobox->setObjectName("flagCombobox");

        formLayout->setWidget(5, QFormLayout::ItemRole::FieldRole, flagCombobox);

        labelColorcombo = new KColorCombo(FlagManager);
        labelColorcombo->setObjectName("labelColorcombo");
        labelColorcombo->setProperty("color", QVariant(QColor(255, 0, 0)));

        formLayout->setWidget(4, QFormLayout::ItemRole::FieldRole, labelColorcombo);


        horizontalLayout->addLayout(formLayout);

        verticalLayout_3 = new QVBoxLayout();
        verticalLayout_3->setObjectName("verticalLayout_3");
        addButton = new QPushButton(FlagManager);
        addButton->setObjectName("addButton");

        verticalLayout_3->addWidget(addButton);

        saveButton = new QPushButton(FlagManager);
        saveButton->setObjectName("saveButton");

        verticalLayout_3->addWidget(saveButton);

        verticalSpacer_2 = new QSpacerItem(20, 40, QSizePolicy::Policy::Minimum, QSizePolicy::Policy::Minimum);

        verticalLayout_3->addItem(verticalSpacer_2);


        horizontalLayout->addLayout(verticalLayout_3);


        verticalLayout_2->addLayout(horizontalLayout);

        hintLabel = new QLabel(FlagManager);
        hintLabel->setObjectName("hintLabel");
        hintLabel->setWordWrap(true);

        verticalLayout_2->addWidget(hintLabel);

        horizontalLayout_2 = new QHBoxLayout();
        horizontalLayout_2->setObjectName("horizontalLayout_2");
        flagList = new QTableView(FlagManager);
        flagList->setObjectName("flagList");
        flagList->setMinimumSize(QSize(0, 0));
        flagList->setEditTriggers(QAbstractItemView::NoEditTriggers);
        flagList->setAlternatingRowColors(true);
        flagList->setSelectionMode(QAbstractItemView::SingleSelection);
        flagList->setSelectionBehavior(QAbstractItemView::SelectRows);
        flagList->setSortingEnabled(false);

        horizontalLayout_2->addWidget(flagList);

        verticalLayout = new QVBoxLayout();
        verticalLayout->setObjectName("verticalLayout");
        CenterButton = new QPushButton(FlagManager);
        CenterButton->setObjectName("CenterButton");

        verticalLayout->addWidget(CenterButton);

        ScopeButton = new QPushButton(FlagManager);
        ScopeButton->setObjectName("ScopeButton");

        verticalLayout->addWidget(ScopeButton);

        delButton = new QPushButton(FlagManager);
        delButton->setObjectName("delButton");

        verticalLayout->addWidget(delButton);

        verticalSpacer = new QSpacerItem(20, 40, QSizePolicy::Policy::Minimum, QSizePolicy::Policy::Expanding);

        verticalLayout->addItem(verticalSpacer);


        horizontalLayout_2->addLayout(verticalLayout);


        verticalLayout_2->addLayout(horizontalLayout_2);

        QWidget::setTabOrder(raBox, decBox);
        QWidget::setTabOrder(decBox, epochBox);
        QWidget::setTabOrder(epochBox, flagLabel);
        QWidget::setTabOrder(flagLabel, labelColorcombo);
        QWidget::setTabOrder(labelColorcombo, flagCombobox);
        QWidget::setTabOrder(flagCombobox, addButton);
        QWidget::setTabOrder(addButton, saveButton);
        QWidget::setTabOrder(saveButton, flagList);
        QWidget::setTabOrder(flagList, CenterButton);
        QWidget::setTabOrder(CenterButton, delButton);

        retranslateUi(FlagManager);

        QMetaObject::connectSlotsByName(FlagManager);
    } // setupUi

    void retranslateUi(QWidget *FlagManager)
    {
        raLabel->setText(tr2i18n("Right ascension:", nullptr));
        decLabel->setText(tr2i18n("Declination:", nullptr));
        epochLabel->setText(tr2i18n("Epoch:", nullptr));
        epochBox->setText(tr2i18n("2000.0", nullptr));
        label->setText(tr2i18n("Label:", nullptr));
        label_4->setText(tr2i18n("Label color:", nullptr));
        label_2->setText(tr2i18n("Icon:", nullptr));
        addButton->setText(tr2i18n("Add", nullptr));
        saveButton->setText(tr2i18n("Save Changes", nullptr));
        hintLabel->setText(QString());
        CenterButton->setText(tr2i18n("Center in Map", nullptr));
#if QT_CONFIG(tooltip)
        ScopeButton->setToolTip(tr2i18n("Slew to the flag coordinates", nullptr));
#endif // QT_CONFIG(tooltip)
        ScopeButton->setText(tr2i18n("Center in Telescope", nullptr));
        delButton->setText(tr2i18n("Delete", nullptr));
        (void)FlagManager;
    } // retranslateUi

};

namespace Ui {
    class FlagManager: public Ui_FlagManager {};
} // namespace Ui

QT_END_NAMESPACE

#endif // FLAGMANAGER_H

