/********************************************************************************
** Form generated from reading UI file 'locationdialog.ui'
**
** Created by: Qt User Interface Compiler version 6.11.1
**
** WARNING! All changes made in this file will be lost when recompiling UI file!
********************************************************************************/

#ifndef UI_LOCATIONDIALOG_H
#define UI_LOCATIONDIALOG_H

#include <QtCore/QVariant>
#include <QtGui/QIcon>
#include <QtWidgets/QApplication>
#include <QtWidgets/QComboBox>
#include <QtWidgets/QDoubleSpinBox>
#include <QtWidgets/QGridLayout>
#include <QtWidgets/QGroupBox>
#include <QtWidgets/QHBoxLayout>
#include <QtWidgets/QLabel>
#include <QtWidgets/QLineEdit>
#include <QtWidgets/QListWidget>
#include <QtWidgets/QPushButton>
#include <QtWidgets/QSpacerItem>
#include <QtWidgets/QVBoxLayout>
#include <QtWidgets/QWidget>
#include <klocalizedstring.h>
#include "widgets/dmsbox.h"
#include "widgets/mapcanvas.h"

QT_BEGIN_NAMESPACE

class Ui_LocationDialog
{
public:
    QVBoxLayout *vboxLayout;
    QGroupBox *CityGroupBox;
    QHBoxLayout *hboxLayout;
    QVBoxLayout *MapAndFilters;
    MapCanvas *MapView;
    QGridLayout *Filters;
    QLabel *CountryFiltLabel;
    QLineEdit *ProvinceFilter;
    QLabel *CityFiltLabel;
    QLineEdit *CountryFilter;
    QLineEdit *CityFilter;
    QLabel *ProvinceFiltLabel;
    QLabel *CountLabel;
    QListWidget *GeoBox;
    QGroupBox *EditGroupBox;
    QHBoxLayout *hboxLayout1;
    QGridLayout *gridLayout;
    QLineEdit *NewProvinceName;
    QLineEdit *NewCountryName;
    QLabel *NewCityLabel;
    QLineEdit *NewCityName;
    QLabel *NewProvinceLabel;
    QLabel *NewCountryLabel;
    QVBoxLayout *vboxLayout1;
    QHBoxLayout *hboxLayout2;
    QGridLayout *gridLayout1;
    dmsBox *NewLat;
    QLabel *LongLabel;
    dmsBox *NewLong;
    QLabel *LatLabel;
    QLabel *ElevationLabel;
    QDoubleSpinBox *NewElev;
    QSpacerItem *spacerItem;
    QGridLayout *gridLayout2;
    QLabel *DSTLabel;
    QComboBox *DSTRuleBox;
    QLabel *TZLabel;
    QComboBox *TZBox;
    QHBoxLayout *hboxLayout3;
    QPushButton *GetLocationButton;
    QPushButton *ClearFieldsButton;
    QSpacerItem *spacerItem1;
    QPushButton *AddCityButton;
    QPushButton *UpdateButton;
    QPushButton *RemoveButton;
    QLabel *errorLabel;

    void setupUi(QWidget *LocationDialog)
    {
        if (LocationDialog->objectName().isEmpty())
            LocationDialog->setObjectName("LocationDialog");
        LocationDialog->resize(1299, 643);
        QSizePolicy sizePolicy(QSizePolicy::Policy::MinimumExpanding, QSizePolicy::Policy::MinimumExpanding);
        sizePolicy.setHorizontalStretch(0);
        sizePolicy.setVerticalStretch(0);
        sizePolicy.setHeightForWidth(LocationDialog->sizePolicy().hasHeightForWidth());
        LocationDialog->setSizePolicy(sizePolicy);
        LocationDialog->setMinimumSize(QSize(800, 480));
        LocationDialog->setMaximumSize(QSize(4000, 2000));
        vboxLayout = new QVBoxLayout(LocationDialog);
        vboxLayout->setSpacing(3);
        vboxLayout->setObjectName("vboxLayout");
        vboxLayout->setContentsMargins(3, 3, 3, 3);
        CityGroupBox = new QGroupBox(LocationDialog);
        CityGroupBox->setObjectName("CityGroupBox");
        hboxLayout = new QHBoxLayout(CityGroupBox);
        hboxLayout->setSpacing(3);
        hboxLayout->setObjectName("hboxLayout");
        hboxLayout->setContentsMargins(3, 3, 3, 3);
        MapAndFilters = new QVBoxLayout();
        MapAndFilters->setSpacing(6);
        MapAndFilters->setObjectName("MapAndFilters");
        MapAndFilters->setSizeConstraint(QLayout::SetMinimumSize);
        MapAndFilters->setContentsMargins(0, 0, 0, 0);
        MapView = new MapCanvas(CityGroupBox);
        MapView->setObjectName("MapView");
        sizePolicy.setHeightForWidth(MapView->sizePolicy().hasHeightForWidth());
        MapView->setSizePolicy(sizePolicy);
        MapView->setMinimumSize(QSize(360, 180));
        MapView->setMaximumSize(QSize(4000, 2000));
        MapView->setFrameShape(QFrame::NoFrame);
        MapView->setFrameShadow(QFrame::Plain);

        MapAndFilters->addWidget(MapView);

        Filters = new QGridLayout();
        Filters->setSpacing(3);
        Filters->setObjectName("Filters");
        Filters->setContentsMargins(0, 0, 0, 0);
        CountryFiltLabel = new QLabel(CityGroupBox);
        CountryFiltLabel->setObjectName("CountryFiltLabel");

        Filters->addWidget(CountryFiltLabel, 2, 0, 1, 1);

        ProvinceFilter = new QLineEdit(CityGroupBox);
        ProvinceFilter->setObjectName("ProvinceFilter");

        Filters->addWidget(ProvinceFilter, 1, 1, 1, 1);

        CityFiltLabel = new QLabel(CityGroupBox);
        CityFiltLabel->setObjectName("CityFiltLabel");

        Filters->addWidget(CityFiltLabel, 0, 0, 1, 1);

        CountryFilter = new QLineEdit(CityGroupBox);
        CountryFilter->setObjectName("CountryFilter");

        Filters->addWidget(CountryFilter, 2, 1, 1, 1);

        CityFilter = new QLineEdit(CityGroupBox);
        CityFilter->setObjectName("CityFilter");

        Filters->addWidget(CityFilter, 0, 1, 1, 1);

        ProvinceFiltLabel = new QLabel(CityGroupBox);
        ProvinceFiltLabel->setObjectName("ProvinceFiltLabel");

        Filters->addWidget(ProvinceFiltLabel, 1, 0, 1, 1);


        MapAndFilters->addLayout(Filters);

        CountLabel = new QLabel(CityGroupBox);
        CountLabel->setObjectName("CountLabel");

        MapAndFilters->addWidget(CountLabel);


        hboxLayout->addLayout(MapAndFilters);

        GeoBox = new QListWidget(CityGroupBox);
        GeoBox->setObjectName("GeoBox");
        GeoBox->setMaximumSize(QSize(400, 16777215));

        hboxLayout->addWidget(GeoBox);


        vboxLayout->addWidget(CityGroupBox);

        EditGroupBox = new QGroupBox(LocationDialog);
        EditGroupBox->setObjectName("EditGroupBox");
        QSizePolicy sizePolicy1(QSizePolicy::Policy::Preferred, QSizePolicy::Policy::Preferred);
        sizePolicy1.setHorizontalStretch(0);
        sizePolicy1.setVerticalStretch(0);
        sizePolicy1.setHeightForWidth(EditGroupBox->sizePolicy().hasHeightForWidth());
        EditGroupBox->setSizePolicy(sizePolicy1);
        hboxLayout1 = new QHBoxLayout(EditGroupBox);
        hboxLayout1->setSpacing(3);
        hboxLayout1->setObjectName("hboxLayout1");
        hboxLayout1->setContentsMargins(3, 3, 3, 3);
        gridLayout = new QGridLayout();
        gridLayout->setSpacing(3);
        gridLayout->setObjectName("gridLayout");
        gridLayout->setContentsMargins(0, 0, 0, 0);
        NewProvinceName = new QLineEdit(EditGroupBox);
        NewProvinceName->setObjectName("NewProvinceName");
        NewProvinceName->setMinimumSize(QSize(140, 0));

        gridLayout->addWidget(NewProvinceName, 1, 1, 1, 1);

        NewCountryName = new QLineEdit(EditGroupBox);
        NewCountryName->setObjectName("NewCountryName");
        NewCountryName->setMinimumSize(QSize(140, 0));

        gridLayout->addWidget(NewCountryName, 2, 1, 1, 1);

        NewCityLabel = new QLabel(EditGroupBox);
        NewCityLabel->setObjectName("NewCityLabel");

        gridLayout->addWidget(NewCityLabel, 0, 0, 1, 1);

        NewCityName = new QLineEdit(EditGroupBox);
        NewCityName->setObjectName("NewCityName");
        NewCityName->setMinimumSize(QSize(140, 0));

        gridLayout->addWidget(NewCityName, 0, 1, 1, 1);

        NewProvinceLabel = new QLabel(EditGroupBox);
        NewProvinceLabel->setObjectName("NewProvinceLabel");

        gridLayout->addWidget(NewProvinceLabel, 1, 0, 1, 1);

        NewCountryLabel = new QLabel(EditGroupBox);
        NewCountryLabel->setObjectName("NewCountryLabel");

        gridLayout->addWidget(NewCountryLabel, 2, 0, 1, 1);


        hboxLayout1->addLayout(gridLayout);

        vboxLayout1 = new QVBoxLayout();
        vboxLayout1->setSpacing(3);
        vboxLayout1->setObjectName("vboxLayout1");
        vboxLayout1->setContentsMargins(0, 0, 0, 0);
        hboxLayout2 = new QHBoxLayout();
        hboxLayout2->setSpacing(3);
        hboxLayout2->setObjectName("hboxLayout2");
        hboxLayout2->setContentsMargins(0, 0, 0, 0);
        gridLayout1 = new QGridLayout();
        gridLayout1->setSpacing(3);
        gridLayout1->setObjectName("gridLayout1");
        gridLayout1->setContentsMargins(0, 0, 0, 0);
        NewLat = new dmsBox(EditGroupBox);
        NewLat->setObjectName("NewLat");
        QSizePolicy sizePolicy2(QSizePolicy::Policy::Preferred, QSizePolicy::Policy::Fixed);
        sizePolicy2.setHorizontalStretch(0);
        sizePolicy2.setVerticalStretch(0);
        sizePolicy2.setHeightForWidth(NewLat->sizePolicy().hasHeightForWidth());
        NewLat->setSizePolicy(sizePolicy2);
        NewLat->setMinimumSize(QSize(100, 0));

        gridLayout1->addWidget(NewLat, 0, 2, 1, 1);

        LongLabel = new QLabel(EditGroupBox);
        LongLabel->setObjectName("LongLabel");

        gridLayout1->addWidget(LongLabel, 1, 0, 1, 1);

        NewLong = new dmsBox(EditGroupBox);
        NewLong->setObjectName("NewLong");
        sizePolicy2.setHeightForWidth(NewLong->sizePolicy().hasHeightForWidth());
        NewLong->setSizePolicy(sizePolicy2);
        NewLong->setMinimumSize(QSize(100, 0));

        gridLayout1->addWidget(NewLong, 1, 2, 1, 1);

        LatLabel = new QLabel(EditGroupBox);
        LatLabel->setObjectName("LatLabel");

        gridLayout1->addWidget(LatLabel, 0, 0, 1, 1);

        ElevationLabel = new QLabel(EditGroupBox);
        ElevationLabel->setObjectName("ElevationLabel");

        gridLayout1->addWidget(ElevationLabel, 2, 0, 1, 1);

        NewElev = new QDoubleSpinBox(EditGroupBox);
        NewElev->setObjectName("NewElev");
        NewElev->setMinimum(-420.000000000000000);
        NewElev->setMaximum(10000.000000000000000);
        NewElev->setSingleStep(10.000000000000000);
        NewElev->setValue(-10.000000000000000);

        gridLayout1->addWidget(NewElev, 2, 2, 1, 1);


        hboxLayout2->addLayout(gridLayout1);

        spacerItem = new QSpacerItem(16, 21, QSizePolicy::Policy::Expanding, QSizePolicy::Policy::Minimum);

        hboxLayout2->addItem(spacerItem);

        gridLayout2 = new QGridLayout();
        gridLayout2->setSpacing(3);
        gridLayout2->setObjectName("gridLayout2");
        gridLayout2->setContentsMargins(0, 0, 0, 0);
        DSTLabel = new QLabel(EditGroupBox);
        DSTLabel->setObjectName("DSTLabel");
        sizePolicy1.setHeightForWidth(DSTLabel->sizePolicy().hasHeightForWidth());
        DSTLabel->setSizePolicy(sizePolicy1);
        QFont font;
        font.setFamilies({QString::fromUtf8("Sans Serif")});
        font.setPointSize(9);
        font.setBold(true);
        font.setItalic(false);
        font.setUnderline(true);
        font.setStrikeOut(false);
        DSTLabel->setFont(font);

        gridLayout2->addWidget(DSTLabel, 1, 0, 1, 1);

        DSTRuleBox = new QComboBox(EditGroupBox);
        DSTRuleBox->setObjectName("DSTRuleBox");

        gridLayout2->addWidget(DSTRuleBox, 1, 1, 1, 1);

        TZLabel = new QLabel(EditGroupBox);
        TZLabel->setObjectName("TZLabel");

        gridLayout2->addWidget(TZLabel, 0, 0, 1, 1);

        TZBox = new QComboBox(EditGroupBox);
        TZBox->setObjectName("TZBox");
        TZBox->setEditable(true);

        gridLayout2->addWidget(TZBox, 0, 1, 1, 1);


        hboxLayout2->addLayout(gridLayout2);


        vboxLayout1->addLayout(hboxLayout2);

        hboxLayout3 = new QHBoxLayout();
        hboxLayout3->setSpacing(3);
        hboxLayout3->setObjectName("hboxLayout3");
        hboxLayout3->setContentsMargins(0, 0, 0, 0);
        GetLocationButton = new QPushButton(EditGroupBox);
        GetLocationButton->setObjectName("GetLocationButton");
        GetLocationButton->setEnabled(false);

        hboxLayout3->addWidget(GetLocationButton);

        ClearFieldsButton = new QPushButton(EditGroupBox);
        ClearFieldsButton->setObjectName("ClearFieldsButton");

        hboxLayout3->addWidget(ClearFieldsButton);

        spacerItem1 = new QSpacerItem(40, 20, QSizePolicy::Policy::Expanding, QSizePolicy::Policy::Minimum);

        hboxLayout3->addItem(spacerItem1);

        AddCityButton = new QPushButton(EditGroupBox);
        AddCityButton->setObjectName("AddCityButton");
        AddCityButton->setEnabled(false);
        AddCityButton->setMinimumSize(QSize(16, 16));
        QIcon icon;
        QString iconThemeName = QString::fromUtf8("list-add");
        if (QIcon::hasThemeIcon(iconThemeName)) {
            icon = QIcon::fromTheme(iconThemeName);
        } else {
            icon.addFile(QString::fromUtf8("."), QSize(), QIcon::Mode::Normal, QIcon::State::Off);
        }
        AddCityButton->setIcon(icon);
        AddCityButton->setIconSize(QSize(22, 22));

        hboxLayout3->addWidget(AddCityButton);

        UpdateButton = new QPushButton(EditGroupBox);
        UpdateButton->setObjectName("UpdateButton");
        UpdateButton->setEnabled(false);
        UpdateButton->setMinimumSize(QSize(16, 16));
        QIcon icon1;
        iconThemeName = QString::fromUtf8("document-save");
        if (QIcon::hasThemeIcon(iconThemeName)) {
            icon1 = QIcon::fromTheme(iconThemeName);
        } else {
            icon1.addFile(QString::fromUtf8("."), QSize(), QIcon::Mode::Normal, QIcon::State::Off);
        }
        UpdateButton->setIcon(icon1);
        UpdateButton->setIconSize(QSize(22, 22));

        hboxLayout3->addWidget(UpdateButton);

        RemoveButton = new QPushButton(EditGroupBox);
        RemoveButton->setObjectName("RemoveButton");
        RemoveButton->setEnabled(false);
        RemoveButton->setMinimumSize(QSize(16, 16));
        QIcon icon2;
        iconThemeName = QString::fromUtf8("list-remove");
        if (QIcon::hasThemeIcon(iconThemeName)) {
            icon2 = QIcon::fromTheme(iconThemeName);
        } else {
            icon2.addFile(QString::fromUtf8("."), QSize(), QIcon::Mode::Normal, QIcon::State::Off);
        }
        RemoveButton->setIcon(icon2);
        RemoveButton->setIconSize(QSize(22, 22));

        hboxLayout3->addWidget(RemoveButton);


        vboxLayout1->addLayout(hboxLayout3);

        errorLabel = new QLabel(EditGroupBox);
        errorLabel->setObjectName("errorLabel");
        QPalette palette;
        QBrush brush(QColor(255, 0, 0, 255));
        brush.setStyle(Qt::BrushStyle::SolidPattern);
        palette.setBrush(QPalette::ColorGroup::Active, QPalette::ColorRole::WindowText, brush);
        palette.setBrush(QPalette::ColorGroup::Inactive, QPalette::ColorRole::WindowText, brush);
        QBrush brush1(QColor(190, 190, 190, 255));
        brush1.setStyle(Qt::BrushStyle::SolidPattern);
        palette.setBrush(QPalette::ColorGroup::Disabled, QPalette::ColorRole::WindowText, brush1);
        errorLabel->setPalette(palette);
        QFont font1;
        font1.setBold(true);
        errorLabel->setFont(font1);

        vboxLayout1->addWidget(errorLabel);


        hboxLayout1->addLayout(vboxLayout1);


        vboxLayout->addWidget(EditGroupBox);

        QWidget::setTabOrder(CityFilter, ProvinceFilter);
        QWidget::setTabOrder(ProvinceFilter, CountryFilter);
        QWidget::setTabOrder(CountryFilter, GeoBox);
        QWidget::setTabOrder(GeoBox, NewCityName);
        QWidget::setTabOrder(NewCityName, NewProvinceName);
        QWidget::setTabOrder(NewProvinceName, NewCountryName);
        QWidget::setTabOrder(NewCountryName, NewLat);
        QWidget::setTabOrder(NewLat, NewLong);
        QWidget::setTabOrder(NewLong, TZBox);
        QWidget::setTabOrder(TZBox, DSTRuleBox);
        QWidget::setTabOrder(DSTRuleBox, AddCityButton);
        QWidget::setTabOrder(AddCityButton, UpdateButton);
        QWidget::setTabOrder(UpdateButton, RemoveButton);
        QWidget::setTabOrder(RemoveButton, ClearFieldsButton);

        retranslateUi(LocationDialog);

        QMetaObject::connectSlotsByName(LocationDialog);
    } // setupUi

    void retranslateUi(QWidget *LocationDialog)
    {
        CityGroupBox->setTitle(tr2i18n("Choose City", nullptr));
        CountryFiltLabel->setText(tr2i18n("Country filter:", nullptr));
        CityFiltLabel->setText(tr2i18n("City filter:", nullptr));
        ProvinceFiltLabel->setText(tr2i18n("Province filter:", nullptr));
        CountLabel->setText(tr2i18n("0 cities match search criteria", nullptr));
        EditGroupBox->setTitle(tr2i18n("View/Edit Location Data", nullptr));
        NewCityLabel->setText(tr2i18n("City:", nullptr));
        NewProvinceLabel->setText(tr2i18n("Province:", nullptr));
        NewCountryLabel->setText(tr2i18n("Country:", nullptr));
#if QT_CONFIG(tooltip)
        NewLat->setToolTip(tr2i18n("<html><head/><body><p>Latitude in degrees. North of equator is positive and South is negative.</p></body></html>", nullptr));
#endif // QT_CONFIG(tooltip)
        LongLabel->setText(tr2i18n("Longitude:", nullptr));
#if QT_CONFIG(tooltip)
        NewLong->setToolTip(tr2i18n("<html><head/><body><p>Longitude in degrees. East of Greenwich is positive and West is negative.</p></body></html>", nullptr));
#endif // QT_CONFIG(tooltip)
        LatLabel->setText(tr2i18n("Latitude:", nullptr));
        ElevationLabel->setText(tr2i18n("Elevation", nullptr));
        DSTLabel->setText(tr2i18n("DST rule:", nullptr));
        TZLabel->setText(tr2i18n("UT offset:", nullptr));
        GetLocationButton->setText(tr2i18n("Get Location", nullptr));
        ClearFieldsButton->setText(tr2i18n("&Clear Fields", nullptr));
#if QT_CONFIG(tooltip)
        AddCityButton->setToolTip(tr2i18n("Add City", nullptr));
#endif // QT_CONFIG(tooltip)
        AddCityButton->setText(QString());
#if QT_CONFIG(tooltip)
        UpdateButton->setToolTip(tr2i18n("Update City", nullptr));
#endif // QT_CONFIG(tooltip)
#if QT_CONFIG(statustip)
        UpdateButton->setStatusTip(QString());
#endif // QT_CONFIG(statustip)
        UpdateButton->setText(QString());
#if QT_CONFIG(tooltip)
        RemoveButton->setToolTip(tr2i18n("Remove City", nullptr));
#endif // QT_CONFIG(tooltip)
        RemoveButton->setText(QString());
        errorLabel->setText(QString());
        (void)LocationDialog;
    } // retranslateUi

};

namespace Ui {
    class LocationDialog: public Ui_LocationDialog {};
} // namespace Ui

QT_END_NAMESPACE

#endif // LOCATIONDIALOG_H

