/****************************************************************************
** Meta object code from reading C++ file 'taskaction.h'
**
** Created by: The Qt Meta Object Compiler version 69 (Qt 6.11.1)
**
** WARNING! All changes made in this file will be lost!
*****************************************************************************/

#include "../../../../kstars-3.8.4.1/kstars/ekos/scheduler/taskqueue/actions/taskaction.h"
#include <QtCore/qmetatype.h>

#include <QtCore/qtmochelpers.h>

#include <memory>


#include <QtCore/qxptype_traits.h>
#if !defined(Q_MOC_OUTPUT_REVISION)
#error "The header file 'taskaction.h' doesn't include <QObject>."
#elif Q_MOC_OUTPUT_REVISION != 69
#error "This file was generated using the moc from 6.11.1. It"
#error "cannot be used with the include files from this version of Qt."
#error "(The moc has changed too much.)"
#endif

#ifndef Q_CONSTINIT
#define Q_CONSTINIT
#endif

QT_WARNING_PUSH
QT_WARNING_DISABLE_DEPRECATED
QT_WARNING_DISABLE_GCC("-Wuseless-cast")
namespace {
struct qt_meta_tag_ZN4Ekos10TaskActionE_t {};
} // unnamed namespace

template <> constexpr inline auto Ekos::TaskAction::qt_create_metaobjectdata<qt_meta_tag_ZN4Ekos10TaskActionE_t>()
{
    namespace QMC = QtMocConstants;
    QtMocHelpers::StringRefStorage qt_stringData {
        "Ekos::TaskAction",
        "started",
        "",
        "completed",
        "failed",
        "error",
        "progress",
        "message",
        "statusChanged",
        "Status",
        "newStatus",
        "Type",
        "SET",
        "EVALUATE",
        "DELAY",
        "START",
        "SCRIPT",
        "PENDING",
        "RUNNING",
        "COMPLETED",
        "FAILED",
        "ABORTED",
        "FailureAction",
        "ABORT_QUEUE",
        "CONTINUE",
        "SKIP_TO_NEXT_TASK"
    };

    QtMocHelpers::UintData qt_methods {
        // Signal 'started'
        QtMocHelpers::SignalData<void()>(1, 2, QMC::AccessPublic, QMetaType::Void),
        // Signal 'completed'
        QtMocHelpers::SignalData<void()>(3, 2, QMC::AccessPublic, QMetaType::Void),
        // Signal 'failed'
        QtMocHelpers::SignalData<void(const QString &)>(4, 2, QMC::AccessPublic, QMetaType::Void, {{
            { QMetaType::QString, 5 },
        }}),
        // Signal 'progress'
        QtMocHelpers::SignalData<void(const QString &)>(6, 2, QMC::AccessPublic, QMetaType::Void, {{
            { QMetaType::QString, 7 },
        }}),
        // Signal 'statusChanged'
        QtMocHelpers::SignalData<void(enum Status)>(8, 2, QMC::AccessPublic, QMetaType::Void, {{
            { 0x80000000 | 9, 10 },
        }}),
    };
    QtMocHelpers::UintData qt_properties {
    };
    QtMocHelpers::UintData qt_enums {
        // enum 'Type'
        QtMocHelpers::EnumData<enum Type>(11, 11, QMC::EnumFlags{}).add({
            {   12, Type::SET },
            {   13, Type::EVALUATE },
            {   14, Type::DELAY },
            {   15, Type::START },
            {   16, Type::SCRIPT },
        }),
        // enum 'Status'
        QtMocHelpers::EnumData<enum Status>(9, 9, QMC::EnumFlags{}).add({
            {   17, Status::PENDING },
            {   18, Status::RUNNING },
            {   19, Status::COMPLETED },
            {   20, Status::FAILED },
            {   21, Status::ABORTED },
        }),
        // enum 'FailureAction'
        QtMocHelpers::EnumData<enum FailureAction>(22, 22, QMC::EnumFlags{}).add({
            {   23, FailureAction::ABORT_QUEUE },
            {   24, FailureAction::CONTINUE },
            {   25, FailureAction::SKIP_TO_NEXT_TASK },
        }),
    };
    return QtMocHelpers::metaObjectData<TaskAction, qt_meta_tag_ZN4Ekos10TaskActionE_t>(QMC::MetaObjectFlag{}, qt_stringData,
            qt_methods, qt_properties, qt_enums);
}
Q_CONSTINIT const QMetaObject Ekos::TaskAction::staticMetaObject = { {
    QMetaObject::SuperData::link<QObject::staticMetaObject>(),
    qt_staticMetaObjectStaticContent<qt_meta_tag_ZN4Ekos10TaskActionE_t>.stringdata,
    qt_staticMetaObjectStaticContent<qt_meta_tag_ZN4Ekos10TaskActionE_t>.data,
    qt_static_metacall,
    nullptr,
    qt_staticMetaObjectRelocatingContent<qt_meta_tag_ZN4Ekos10TaskActionE_t>.metaTypes,
    nullptr
} };

void Ekos::TaskAction::qt_static_metacall(QObject *_o, QMetaObject::Call _c, int _id, void **_a)
{
    auto *_t = static_cast<TaskAction *>(_o);
    if (_c == QMetaObject::InvokeMetaMethod) {
        switch (_id) {
        case 0: _t->started(); break;
        case 1: _t->completed(); break;
        case 2: _t->failed((*reinterpret_cast<std::add_pointer_t<QString>>(_a[1]))); break;
        case 3: _t->progress((*reinterpret_cast<std::add_pointer_t<QString>>(_a[1]))); break;
        case 4: _t->statusChanged((*reinterpret_cast<std::add_pointer_t<enum Status>>(_a[1]))); break;
        default: ;
        }
    }
    if (_c == QMetaObject::IndexOfMethod) {
        if (QtMocHelpers::indexOfMethod<void (TaskAction::*)()>(_a, &TaskAction::started, 0))
            return;
        if (QtMocHelpers::indexOfMethod<void (TaskAction::*)()>(_a, &TaskAction::completed, 1))
            return;
        if (QtMocHelpers::indexOfMethod<void (TaskAction::*)(const QString & )>(_a, &TaskAction::failed, 2))
            return;
        if (QtMocHelpers::indexOfMethod<void (TaskAction::*)(const QString & )>(_a, &TaskAction::progress, 3))
            return;
        if (QtMocHelpers::indexOfMethod<void (TaskAction::*)(Status )>(_a, &TaskAction::statusChanged, 4))
            return;
    }
}

const QMetaObject *Ekos::TaskAction::metaObject() const
{
    return QObject::d_ptr->metaObject ? QObject::d_ptr->dynamicMetaObject() : &staticMetaObject;
}

void *Ekos::TaskAction::qt_metacast(const char *_clname)
{
    if (!_clname) return nullptr;
    if (!strcmp(_clname, qt_staticMetaObjectStaticContent<qt_meta_tag_ZN4Ekos10TaskActionE_t>.strings))
        return static_cast<void*>(this);
    return QObject::qt_metacast(_clname);
}

int Ekos::TaskAction::qt_metacall(QMetaObject::Call _c, int _id, void **_a)
{
    _id = QObject::qt_metacall(_c, _id, _a);
    if (_id < 0)
        return _id;
    if (_c == QMetaObject::InvokeMetaMethod) {
        if (_id < 5)
            qt_static_metacall(this, _c, _id, _a);
        _id -= 5;
    }
    if (_c == QMetaObject::RegisterMethodArgumentMetaType) {
        if (_id < 5)
            *reinterpret_cast<QMetaType *>(_a[0]) = QMetaType();
        _id -= 5;
    }
    return _id;
}

// SIGNAL 0
void Ekos::TaskAction::started()
{
    QMetaObject::activate(this, &staticMetaObject, 0, nullptr);
}

// SIGNAL 1
void Ekos::TaskAction::completed()
{
    QMetaObject::activate(this, &staticMetaObject, 1, nullptr);
}

// SIGNAL 2
void Ekos::TaskAction::failed(const QString & _t1)
{
    QMetaObject::activate<void>(this, &staticMetaObject, 2, nullptr, _t1);
}

// SIGNAL 3
void Ekos::TaskAction::progress(const QString & _t1)
{
    QMetaObject::activate<void>(this, &staticMetaObject, 3, nullptr, _t1);
}

// SIGNAL 4
void Ekos::TaskAction::statusChanged(Status _t1)
{
    QMetaObject::activate<void>(this, &staticMetaObject, 4, nullptr, _t1);
}
QT_WARNING_POP
