/****************************************************************************
** Meta object code from reading C++ file 'indistd.h'
**
** Created by: The Qt Meta Object Compiler version 69 (Qt 6.11.1)
**
** WARNING! All changes made in this file will be lost!
*****************************************************************************/

#include "../../../../kstars-3.8.4.1/kstars/indi/indistd.h"
#include <QtCore/qmetatype.h>

#include <QtCore/qtmochelpers.h>

#include <memory>


#include <QtCore/qxptype_traits.h>
#if !defined(Q_MOC_OUTPUT_REVISION)
#error "The header file 'indistd.h' doesn't include <QObject>."
#elif Q_MOC_OUTPUT_REVISION != 69
#error "This file was generated using the moc from 6.11.1. It"
#error "cannot be used with the include files from this version of Qt."
#error "(The moc has changed too much.)"
#endif

#ifndef Q_CONSTINIT
#define Q_CONSTINIT
#endif

QT_WARNING_PUSH
QT_WARNING_DISABLE_DEPRECATED
QT_WARNING_DISABLE_GCC("-Wuseless-cast")
namespace {
struct qt_meta_tag_ZN3ISD12GDSetCommandE_t {};
} // unnamed namespace

template <> constexpr inline auto ISD::GDSetCommand::qt_create_metaobjectdata<qt_meta_tag_ZN3ISD12GDSetCommandE_t>()
{
    namespace QMC = QtMocConstants;
    QtMocHelpers::StringRefStorage qt_stringData {
        "ISD::GDSetCommand"
    };

    QtMocHelpers::UintData qt_methods {
    };
    QtMocHelpers::UintData qt_properties {
    };
    QtMocHelpers::UintData qt_enums {
    };
    return QtMocHelpers::metaObjectData<GDSetCommand, qt_meta_tag_ZN3ISD12GDSetCommandE_t>(QMC::MetaObjectFlag{}, qt_stringData,
            qt_methods, qt_properties, qt_enums);
}
Q_CONSTINIT const QMetaObject ISD::GDSetCommand::staticMetaObject = { {
    QMetaObject::SuperData::link<QObject::staticMetaObject>(),
    qt_staticMetaObjectStaticContent<qt_meta_tag_ZN3ISD12GDSetCommandE_t>.stringdata,
    qt_staticMetaObjectStaticContent<qt_meta_tag_ZN3ISD12GDSetCommandE_t>.data,
    qt_static_metacall,
    nullptr,
    qt_staticMetaObjectRelocatingContent<qt_meta_tag_ZN3ISD12GDSetCommandE_t>.metaTypes,
    nullptr
} };

void ISD::GDSetCommand::qt_static_metacall(QObject *_o, QMetaObject::Call _c, int _id, void **_a)
{
    auto *_t = static_cast<GDSetCommand *>(_o);
    (void)_t;
    (void)_c;
    (void)_id;
    (void)_a;
}

const QMetaObject *ISD::GDSetCommand::metaObject() const
{
    return QObject::d_ptr->metaObject ? QObject::d_ptr->dynamicMetaObject() : &staticMetaObject;
}

void *ISD::GDSetCommand::qt_metacast(const char *_clname)
{
    if (!_clname) return nullptr;
    if (!strcmp(_clname, qt_staticMetaObjectStaticContent<qt_meta_tag_ZN3ISD12GDSetCommandE_t>.strings))
        return static_cast<void*>(this);
    return QObject::qt_metacast(_clname);
}

int ISD::GDSetCommand::qt_metacall(QMetaObject::Call _c, int _id, void **_a)
{
    _id = QObject::qt_metacall(_c, _id, _a);
    return _id;
}
namespace {
struct qt_meta_tag_ZN3ISD11GDInterfaceE_t {};
} // unnamed namespace

template <> constexpr inline auto ISD::GDInterface::qt_create_metaobjectdata<qt_meta_tag_ZN3ISD11GDInterfaceE_t>()
{
    namespace QMC = QtMocConstants;
    QtMocHelpers::StringRefStorage qt_stringData {
        "ISD::GDInterface"
    };

    QtMocHelpers::UintData qt_methods {
    };
    QtMocHelpers::UintData qt_properties {
    };
    QtMocHelpers::UintData qt_enums {
    };
    return QtMocHelpers::metaObjectData<GDInterface, qt_meta_tag_ZN3ISD11GDInterfaceE_t>(QMC::MetaObjectFlag{}, qt_stringData,
            qt_methods, qt_properties, qt_enums);
}
Q_CONSTINIT const QMetaObject ISD::GDInterface::staticMetaObject = { {
    QMetaObject::SuperData::link<QObject::staticMetaObject>(),
    qt_staticMetaObjectStaticContent<qt_meta_tag_ZN3ISD11GDInterfaceE_t>.stringdata,
    qt_staticMetaObjectStaticContent<qt_meta_tag_ZN3ISD11GDInterfaceE_t>.data,
    qt_static_metacall,
    nullptr,
    qt_staticMetaObjectRelocatingContent<qt_meta_tag_ZN3ISD11GDInterfaceE_t>.metaTypes,
    nullptr
} };

void ISD::GDInterface::qt_static_metacall(QObject *_o, QMetaObject::Call _c, int _id, void **_a)
{
    auto *_t = static_cast<GDInterface *>(_o);
    (void)_t;
    (void)_c;
    (void)_id;
    (void)_a;
}

const QMetaObject *ISD::GDInterface::metaObject() const
{
    return QObject::d_ptr->metaObject ? QObject::d_ptr->dynamicMetaObject() : &staticMetaObject;
}

void *ISD::GDInterface::qt_metacast(const char *_clname)
{
    if (!_clname) return nullptr;
    if (!strcmp(_clname, qt_staticMetaObjectStaticContent<qt_meta_tag_ZN3ISD11GDInterfaceE_t>.strings))
        return static_cast<void*>(this);
    return QObject::qt_metacast(_clname);
}

int ISD::GDInterface::qt_metacall(QMetaObject::Call _c, int _id, void **_a)
{
    _id = QObject::qt_metacall(_c, _id, _a);
    return _id;
}
namespace {
struct qt_meta_tag_ZN3ISD13GenericDeviceE_t {};
} // unnamed namespace

template <> constexpr inline auto ISD::GenericDevice::qt_create_metaobjectdata<qt_meta_tag_ZN3ISD13GenericDeviceE_t>()
{
    namespace QMC = QtMocConstants;
    QtMocHelpers::StringRefStorage qt_stringData {
        "ISD::GenericDevice",
        "D-Bus Interface",
        "org.kde.kstars.INDI.GenericDevice",
        "Connected",
        "",
        "Disconnected",
        "propertyUpdated",
        "INDI::Property",
        "prop",
        "messageUpdated",
        "messageText",
        "interfaceDefined",
        "systemPortDetected",
        "propertyDefined",
        "propertyDeleted",
        "ready",
        "newMount",
        "Mount*",
        "device",
        "newCamera",
        "Camera*",
        "newGuider",
        "Guider*",
        "newFocuser",
        "Focuser*",
        "newFilterWheel",
        "FilterWheel*",
        "newDome",
        "Dome*",
        "newGPS",
        "GPS*",
        "newWeather",
        "Weather*",
        "newAdaptiveOptics",
        "AdaptiveOptics*",
        "newDustCap",
        "DustCap*",
        "newLightBox",
        "LightBox*",
        "newPAC",
        "PAC*",
        "newDetector",
        "Detector*",
        "newRotator",
        "Rotator*",
        "newSpectrograph",
        "Spectrograph*",
        "newCorrelator",
        "Correlator*",
        "newAuxiliary",
        "Auxiliary*",
        "resetWatchdog",
        "Connect",
        "Q_NOREPLY",
        "Disconnect",
        "name",
        "driverInterface",
        "uint32_t",
        "driverVersion",
        "connected"
    };

    QtMocHelpers::UintData qt_methods {
        // Signal 'Connected'
        QtMocHelpers::SignalData<void()>(3, 4, QMC::AccessPublic, QMetaType::Void),
        // Signal 'Disconnected'
        QtMocHelpers::SignalData<void()>(5, 4, QMC::AccessPublic, QMetaType::Void),
        // Signal 'propertyUpdated'
        QtMocHelpers::SignalData<void(INDI::Property)>(6, 4, QMC::AccessPublic, QMetaType::Void, {{
            { 0x80000000 | 7, 8 },
        }}),
        // Signal 'messageUpdated'
        QtMocHelpers::SignalData<void(const QString &)>(9, 4, QMC::AccessPublic, QMetaType::Void, {{
            { QMetaType::QString, 10 },
        }}),
        // Signal 'interfaceDefined'
        QtMocHelpers::SignalData<void()>(11, 4, QMC::AccessPublic, QMetaType::Void),
        // Signal 'systemPortDetected'
        QtMocHelpers::SignalData<void()>(12, 4, QMC::AccessPublic, QMetaType::Void),
        // Signal 'propertyDefined'
        QtMocHelpers::SignalData<void(INDI::Property)>(13, 4, QMC::AccessPublic, QMetaType::Void, {{
            { 0x80000000 | 7, 8 },
        }}),
        // Signal 'propertyDeleted'
        QtMocHelpers::SignalData<void(INDI::Property)>(14, 4, QMC::AccessPublic, QMetaType::Void, {{
            { 0x80000000 | 7, 8 },
        }}),
        // Signal 'ready'
        QtMocHelpers::SignalData<void()>(15, 4, QMC::AccessPublic, QMetaType::Void),
        // Signal 'newMount'
        QtMocHelpers::SignalData<void(Mount *)>(16, 4, QMC::AccessPublic, QMetaType::Void, {{
            { 0x80000000 | 17, 18 },
        }}),
        // Signal 'newCamera'
        QtMocHelpers::SignalData<void(Camera *)>(19, 4, QMC::AccessPublic, QMetaType::Void, {{
            { 0x80000000 | 20, 18 },
        }}),
        // Signal 'newGuider'
        QtMocHelpers::SignalData<void(Guider *)>(21, 4, QMC::AccessPublic, QMetaType::Void, {{
            { 0x80000000 | 22, 18 },
        }}),
        // Signal 'newFocuser'
        QtMocHelpers::SignalData<void(Focuser *)>(23, 4, QMC::AccessPublic, QMetaType::Void, {{
            { 0x80000000 | 24, 18 },
        }}),
        // Signal 'newFilterWheel'
        QtMocHelpers::SignalData<void(FilterWheel *)>(25, 4, QMC::AccessPublic, QMetaType::Void, {{
            { 0x80000000 | 26, 18 },
        }}),
        // Signal 'newDome'
        QtMocHelpers::SignalData<void(Dome *)>(27, 4, QMC::AccessPublic, QMetaType::Void, {{
            { 0x80000000 | 28, 18 },
        }}),
        // Signal 'newGPS'
        QtMocHelpers::SignalData<void(GPS *)>(29, 4, QMC::AccessPublic, QMetaType::Void, {{
            { 0x80000000 | 30, 18 },
        }}),
        // Signal 'newWeather'
        QtMocHelpers::SignalData<void(Weather *)>(31, 4, QMC::AccessPublic, QMetaType::Void, {{
            { 0x80000000 | 32, 18 },
        }}),
        // Signal 'newAdaptiveOptics'
        QtMocHelpers::SignalData<void(AdaptiveOptics *)>(33, 4, QMC::AccessPublic, QMetaType::Void, {{
            { 0x80000000 | 34, 18 },
        }}),
        // Signal 'newDustCap'
        QtMocHelpers::SignalData<void(DustCap *)>(35, 4, QMC::AccessPublic, QMetaType::Void, {{
            { 0x80000000 | 36, 18 },
        }}),
        // Signal 'newLightBox'
        QtMocHelpers::SignalData<void(LightBox *)>(37, 4, QMC::AccessPublic, QMetaType::Void, {{
            { 0x80000000 | 38, 18 },
        }}),
        // Signal 'newPAC'
        QtMocHelpers::SignalData<void(PAC *)>(39, 4, QMC::AccessPublic, QMetaType::Void, {{
            { 0x80000000 | 40, 18 },
        }}),
        // Signal 'newDetector'
        QtMocHelpers::SignalData<void(Detector *)>(41, 4, QMC::AccessPublic, QMetaType::Void, {{
            { 0x80000000 | 42, 18 },
        }}),
        // Signal 'newRotator'
        QtMocHelpers::SignalData<void(Rotator *)>(43, 4, QMC::AccessPublic, QMetaType::Void, {{
            { 0x80000000 | 44, 18 },
        }}),
        // Signal 'newSpectrograph'
        QtMocHelpers::SignalData<void(Spectrograph *)>(45, 4, QMC::AccessPublic, QMetaType::Void, {{
            { 0x80000000 | 46, 18 },
        }}),
        // Signal 'newCorrelator'
        QtMocHelpers::SignalData<void(Correlator *)>(47, 4, QMC::AccessPublic, QMetaType::Void, {{
            { 0x80000000 | 48, 18 },
        }}),
        // Signal 'newAuxiliary'
        QtMocHelpers::SignalData<void(Auxiliary *)>(49, 4, QMC::AccessPublic, QMetaType::Void, {{
            { 0x80000000 | 50, 18 },
        }}),
        // Slot 'resetWatchdog'
        QtMocHelpers::SlotData<void()>(51, 4, QMC::AccessProtected, QMetaType::Void),
        // Method 'Connect'
        QtMocHelpers::MethodData<void()>(52, 53, QMC::AccessPublic | QMC::MethodScriptable, QMetaType::Void),
        // Method 'Disconnect'
        QtMocHelpers::MethodData<void()>(54, 53, QMC::AccessPublic | QMC::MethodScriptable, QMetaType::Void),
    };
    QtMocHelpers::UintData qt_properties {
        // property 'name'
        QtMocHelpers::PropertyData<QString>(55, QMetaType::QString, QMC::DefaultPropertyFlags),
        // property 'driverInterface'
        QtMocHelpers::PropertyData<uint32_t>(56, 0x80000000 | 57, QMC::DefaultPropertyFlags | QMC::EnumOrFlag),
        // property 'driverVersion'
        QtMocHelpers::PropertyData<QString>(58, QMetaType::QString, QMC::DefaultPropertyFlags),
        // property 'connected'
        QtMocHelpers::PropertyData<bool>(59, QMetaType::Bool, QMC::DefaultPropertyFlags),
    };
    QtMocHelpers::UintData qt_enums {
    };
    QtMocHelpers::UintData qt_constructors {};
    QtMocHelpers::ClassInfos qt_classinfo({
            {    1,    2 },
    });
    return QtMocHelpers::metaObjectData<GenericDevice, qt_meta_tag_ZN3ISD13GenericDeviceE_t>(QMC::MetaObjectFlag{}, qt_stringData,
            qt_methods, qt_properties, qt_enums, qt_constructors, qt_classinfo);
}
Q_CONSTINIT const QMetaObject ISD::GenericDevice::staticMetaObject = { {
    QMetaObject::SuperData::link<GDInterface::staticMetaObject>(),
    qt_staticMetaObjectStaticContent<qt_meta_tag_ZN3ISD13GenericDeviceE_t>.stringdata,
    qt_staticMetaObjectStaticContent<qt_meta_tag_ZN3ISD13GenericDeviceE_t>.data,
    qt_static_metacall,
    nullptr,
    qt_staticMetaObjectRelocatingContent<qt_meta_tag_ZN3ISD13GenericDeviceE_t>.metaTypes,
    nullptr
} };

void ISD::GenericDevice::qt_static_metacall(QObject *_o, QMetaObject::Call _c, int _id, void **_a)
{
    auto *_t = static_cast<GenericDevice *>(_o);
    if (_c == QMetaObject::InvokeMetaMethod) {
        switch (_id) {
        case 0: _t->Connected(); break;
        case 1: _t->Disconnected(); break;
        case 2: _t->propertyUpdated((*reinterpret_cast<std::add_pointer_t<INDI::Property>>(_a[1]))); break;
        case 3: _t->messageUpdated((*reinterpret_cast<std::add_pointer_t<QString>>(_a[1]))); break;
        case 4: _t->interfaceDefined(); break;
        case 5: _t->systemPortDetected(); break;
        case 6: _t->propertyDefined((*reinterpret_cast<std::add_pointer_t<INDI::Property>>(_a[1]))); break;
        case 7: _t->propertyDeleted((*reinterpret_cast<std::add_pointer_t<INDI::Property>>(_a[1]))); break;
        case 8: _t->ready(); break;
        case 9: _t->newMount((*reinterpret_cast<std::add_pointer_t<Mount*>>(_a[1]))); break;
        case 10: _t->newCamera((*reinterpret_cast<std::add_pointer_t<Camera*>>(_a[1]))); break;
        case 11: _t->newGuider((*reinterpret_cast<std::add_pointer_t<Guider*>>(_a[1]))); break;
        case 12: _t->newFocuser((*reinterpret_cast<std::add_pointer_t<Focuser*>>(_a[1]))); break;
        case 13: _t->newFilterWheel((*reinterpret_cast<std::add_pointer_t<FilterWheel*>>(_a[1]))); break;
        case 14: _t->newDome((*reinterpret_cast<std::add_pointer_t<Dome*>>(_a[1]))); break;
        case 15: _t->newGPS((*reinterpret_cast<std::add_pointer_t<GPS*>>(_a[1]))); break;
        case 16: _t->newWeather((*reinterpret_cast<std::add_pointer_t<Weather*>>(_a[1]))); break;
        case 17: _t->newAdaptiveOptics((*reinterpret_cast<std::add_pointer_t<AdaptiveOptics*>>(_a[1]))); break;
        case 18: _t->newDustCap((*reinterpret_cast<std::add_pointer_t<DustCap*>>(_a[1]))); break;
        case 19: _t->newLightBox((*reinterpret_cast<std::add_pointer_t<LightBox*>>(_a[1]))); break;
        case 20: _t->newPAC((*reinterpret_cast<std::add_pointer_t<PAC*>>(_a[1]))); break;
        case 21: _t->newDetector((*reinterpret_cast<std::add_pointer_t<Detector*>>(_a[1]))); break;
        case 22: _t->newRotator((*reinterpret_cast<std::add_pointer_t<Rotator*>>(_a[1]))); break;
        case 23: _t->newSpectrograph((*reinterpret_cast<std::add_pointer_t<Spectrograph*>>(_a[1]))); break;
        case 24: _t->newCorrelator((*reinterpret_cast<std::add_pointer_t<Correlator*>>(_a[1]))); break;
        case 25: _t->newAuxiliary((*reinterpret_cast<std::add_pointer_t<Auxiliary*>>(_a[1]))); break;
        case 26: _t->resetWatchdog(); break;
        case 27: _t->Connect(); break;
        case 28: _t->Disconnect(); break;
        default: ;
        }
    }
    if (_c == QMetaObject::RegisterMethodArgumentMetaType) {
        switch (_id) {
        default: *reinterpret_cast<QMetaType *>(_a[0]) = QMetaType(); break;
        case 2:
            switch (*reinterpret_cast<int*>(_a[1])) {
            default: *reinterpret_cast<QMetaType *>(_a[0]) = QMetaType(); break;
            case 0:
                *reinterpret_cast<QMetaType *>(_a[0]) = QMetaType::fromType< INDI::Property >(); break;
            }
            break;
        case 6:
            switch (*reinterpret_cast<int*>(_a[1])) {
            default: *reinterpret_cast<QMetaType *>(_a[0]) = QMetaType(); break;
            case 0:
                *reinterpret_cast<QMetaType *>(_a[0]) = QMetaType::fromType< INDI::Property >(); break;
            }
            break;
        case 7:
            switch (*reinterpret_cast<int*>(_a[1])) {
            default: *reinterpret_cast<QMetaType *>(_a[0]) = QMetaType(); break;
            case 0:
                *reinterpret_cast<QMetaType *>(_a[0]) = QMetaType::fromType< INDI::Property >(); break;
            }
            break;
        }
    }
    if (_c == QMetaObject::IndexOfMethod) {
        if (QtMocHelpers::indexOfMethod<void (GenericDevice::*)()>(_a, &GenericDevice::Connected, 0))
            return;
        if (QtMocHelpers::indexOfMethod<void (GenericDevice::*)()>(_a, &GenericDevice::Disconnected, 1))
            return;
        if (QtMocHelpers::indexOfMethod<void (GenericDevice::*)(INDI::Property )>(_a, &GenericDevice::propertyUpdated, 2))
            return;
        if (QtMocHelpers::indexOfMethod<void (GenericDevice::*)(const QString & )>(_a, &GenericDevice::messageUpdated, 3))
            return;
        if (QtMocHelpers::indexOfMethod<void (GenericDevice::*)()>(_a, &GenericDevice::interfaceDefined, 4))
            return;
        if (QtMocHelpers::indexOfMethod<void (GenericDevice::*)()>(_a, &GenericDevice::systemPortDetected, 5))
            return;
        if (QtMocHelpers::indexOfMethod<void (GenericDevice::*)(INDI::Property )>(_a, &GenericDevice::propertyDefined, 6))
            return;
        if (QtMocHelpers::indexOfMethod<void (GenericDevice::*)(INDI::Property )>(_a, &GenericDevice::propertyDeleted, 7))
            return;
        if (QtMocHelpers::indexOfMethod<void (GenericDevice::*)()>(_a, &GenericDevice::ready, 8))
            return;
        if (QtMocHelpers::indexOfMethod<void (GenericDevice::*)(Mount * )>(_a, &GenericDevice::newMount, 9))
            return;
        if (QtMocHelpers::indexOfMethod<void (GenericDevice::*)(Camera * )>(_a, &GenericDevice::newCamera, 10))
            return;
        if (QtMocHelpers::indexOfMethod<void (GenericDevice::*)(Guider * )>(_a, &GenericDevice::newGuider, 11))
            return;
        if (QtMocHelpers::indexOfMethod<void (GenericDevice::*)(Focuser * )>(_a, &GenericDevice::newFocuser, 12))
            return;
        if (QtMocHelpers::indexOfMethod<void (GenericDevice::*)(FilterWheel * )>(_a, &GenericDevice::newFilterWheel, 13))
            return;
        if (QtMocHelpers::indexOfMethod<void (GenericDevice::*)(Dome * )>(_a, &GenericDevice::newDome, 14))
            return;
        if (QtMocHelpers::indexOfMethod<void (GenericDevice::*)(GPS * )>(_a, &GenericDevice::newGPS, 15))
            return;
        if (QtMocHelpers::indexOfMethod<void (GenericDevice::*)(Weather * )>(_a, &GenericDevice::newWeather, 16))
            return;
        if (QtMocHelpers::indexOfMethod<void (GenericDevice::*)(AdaptiveOptics * )>(_a, &GenericDevice::newAdaptiveOptics, 17))
            return;
        if (QtMocHelpers::indexOfMethod<void (GenericDevice::*)(DustCap * )>(_a, &GenericDevice::newDustCap, 18))
            return;
        if (QtMocHelpers::indexOfMethod<void (GenericDevice::*)(LightBox * )>(_a, &GenericDevice::newLightBox, 19))
            return;
        if (QtMocHelpers::indexOfMethod<void (GenericDevice::*)(PAC * )>(_a, &GenericDevice::newPAC, 20))
            return;
        if (QtMocHelpers::indexOfMethod<void (GenericDevice::*)(Detector * )>(_a, &GenericDevice::newDetector, 21))
            return;
        if (QtMocHelpers::indexOfMethod<void (GenericDevice::*)(Rotator * )>(_a, &GenericDevice::newRotator, 22))
            return;
        if (QtMocHelpers::indexOfMethod<void (GenericDevice::*)(Spectrograph * )>(_a, &GenericDevice::newSpectrograph, 23))
            return;
        if (QtMocHelpers::indexOfMethod<void (GenericDevice::*)(Correlator * )>(_a, &GenericDevice::newCorrelator, 24))
            return;
        if (QtMocHelpers::indexOfMethod<void (GenericDevice::*)(Auxiliary * )>(_a, &GenericDevice::newAuxiliary, 25))
            return;
    }
    if (_c == QMetaObject::ReadProperty) {
        void *_v = _a[0];
        switch (_id) {
        case 0: *reinterpret_cast<QString*>(_v) = _t->getDeviceName(); break;
        case 1: *reinterpret_cast<uint32_t*>(_v) = _t->getDriverInterface(); break;
        case 2: *reinterpret_cast<QString*>(_v) = _t->getDriverVersion(); break;
        case 3: *reinterpret_cast<bool*>(_v) = _t->isConnected(); break;
        default: break;
        }
    }
}

const QMetaObject *ISD::GenericDevice::metaObject() const
{
    return QObject::d_ptr->metaObject ? QObject::d_ptr->dynamicMetaObject() : &staticMetaObject;
}

void *ISD::GenericDevice::qt_metacast(const char *_clname)
{
    if (!_clname) return nullptr;
    if (!strcmp(_clname, qt_staticMetaObjectStaticContent<qt_meta_tag_ZN3ISD13GenericDeviceE_t>.strings))
        return static_cast<void*>(this);
    return GDInterface::qt_metacast(_clname);
}

int ISD::GenericDevice::qt_metacall(QMetaObject::Call _c, int _id, void **_a)
{
    _id = GDInterface::qt_metacall(_c, _id, _a);
    if (_id < 0)
        return _id;
    if (_c == QMetaObject::InvokeMetaMethod) {
        if (_id < 29)
            qt_static_metacall(this, _c, _id, _a);
        _id -= 29;
    }
    if (_c == QMetaObject::RegisterMethodArgumentMetaType) {
        if (_id < 29)
            qt_static_metacall(this, _c, _id, _a);
        _id -= 29;
    }
    if (_c == QMetaObject::ReadProperty || _c == QMetaObject::WriteProperty
            || _c == QMetaObject::ResetProperty || _c == QMetaObject::BindableProperty
            || _c == QMetaObject::RegisterPropertyMetaType) {
        qt_static_metacall(this, _c, _id, _a);
        _id -= 4;
    }
    return _id;
}

// SIGNAL 0
void ISD::GenericDevice::Connected()
{
    QMetaObject::activate(this, &staticMetaObject, 0, nullptr);
}

// SIGNAL 1
void ISD::GenericDevice::Disconnected()
{
    QMetaObject::activate(this, &staticMetaObject, 1, nullptr);
}

// SIGNAL 2
void ISD::GenericDevice::propertyUpdated(INDI::Property _t1)
{
    QMetaObject::activate<void>(this, &staticMetaObject, 2, nullptr, _t1);
}

// SIGNAL 3
void ISD::GenericDevice::messageUpdated(const QString & _t1)
{
    QMetaObject::activate<void>(this, &staticMetaObject, 3, nullptr, _t1);
}

// SIGNAL 4
void ISD::GenericDevice::interfaceDefined()
{
    QMetaObject::activate(this, &staticMetaObject, 4, nullptr);
}

// SIGNAL 5
void ISD::GenericDevice::systemPortDetected()
{
    QMetaObject::activate(this, &staticMetaObject, 5, nullptr);
}

// SIGNAL 6
void ISD::GenericDevice::propertyDefined(INDI::Property _t1)
{
    QMetaObject::activate<void>(this, &staticMetaObject, 6, nullptr, _t1);
}

// SIGNAL 7
void ISD::GenericDevice::propertyDeleted(INDI::Property _t1)
{
    QMetaObject::activate<void>(this, &staticMetaObject, 7, nullptr, _t1);
}

// SIGNAL 8
void ISD::GenericDevice::ready()
{
    QMetaObject::activate(this, &staticMetaObject, 8, nullptr);
}

// SIGNAL 9
void ISD::GenericDevice::newMount(Mount * _t1)
{
    QMetaObject::activate<void>(this, &staticMetaObject, 9, nullptr, _t1);
}

// SIGNAL 10
void ISD::GenericDevice::newCamera(Camera * _t1)
{
    QMetaObject::activate<void>(this, &staticMetaObject, 10, nullptr, _t1);
}

// SIGNAL 11
void ISD::GenericDevice::newGuider(Guider * _t1)
{
    QMetaObject::activate<void>(this, &staticMetaObject, 11, nullptr, _t1);
}

// SIGNAL 12
void ISD::GenericDevice::newFocuser(Focuser * _t1)
{
    QMetaObject::activate<void>(this, &staticMetaObject, 12, nullptr, _t1);
}

// SIGNAL 13
void ISD::GenericDevice::newFilterWheel(FilterWheel * _t1)
{
    QMetaObject::activate<void>(this, &staticMetaObject, 13, nullptr, _t1);
}

// SIGNAL 14
void ISD::GenericDevice::newDome(Dome * _t1)
{
    QMetaObject::activate<void>(this, &staticMetaObject, 14, nullptr, _t1);
}

// SIGNAL 15
void ISD::GenericDevice::newGPS(GPS * _t1)
{
    QMetaObject::activate<void>(this, &staticMetaObject, 15, nullptr, _t1);
}

// SIGNAL 16
void ISD::GenericDevice::newWeather(Weather * _t1)
{
    QMetaObject::activate<void>(this, &staticMetaObject, 16, nullptr, _t1);
}

// SIGNAL 17
void ISD::GenericDevice::newAdaptiveOptics(AdaptiveOptics * _t1)
{
    QMetaObject::activate<void>(this, &staticMetaObject, 17, nullptr, _t1);
}

// SIGNAL 18
void ISD::GenericDevice::newDustCap(DustCap * _t1)
{
    QMetaObject::activate<void>(this, &staticMetaObject, 18, nullptr, _t1);
}

// SIGNAL 19
void ISD::GenericDevice::newLightBox(LightBox * _t1)
{
    QMetaObject::activate<void>(this, &staticMetaObject, 19, nullptr, _t1);
}

// SIGNAL 20
void ISD::GenericDevice::newPAC(PAC * _t1)
{
    QMetaObject::activate<void>(this, &staticMetaObject, 20, nullptr, _t1);
}

// SIGNAL 21
void ISD::GenericDevice::newDetector(Detector * _t1)
{
    QMetaObject::activate<void>(this, &staticMetaObject, 21, nullptr, _t1);
}

// SIGNAL 22
void ISD::GenericDevice::newRotator(Rotator * _t1)
{
    QMetaObject::activate<void>(this, &staticMetaObject, 22, nullptr, _t1);
}

// SIGNAL 23
void ISD::GenericDevice::newSpectrograph(Spectrograph * _t1)
{
    QMetaObject::activate<void>(this, &staticMetaObject, 23, nullptr, _t1);
}

// SIGNAL 24
void ISD::GenericDevice::newCorrelator(Correlator * _t1)
{
    QMetaObject::activate<void>(this, &staticMetaObject, 24, nullptr, _t1);
}

// SIGNAL 25
void ISD::GenericDevice::newAuxiliary(Auxiliary * _t1)
{
    QMetaObject::activate<void>(this, &staticMetaObject, 25, nullptr, _t1);
}
QT_WARNING_POP
