/****************************************************************************
** Meta object code from reading C++ file 'guidedriftgraph.h'
**
** Created by: The Qt Meta Object Compiler version 69 (Qt 6.11.1)
**
** WARNING! All changes made in this file will be lost!
*****************************************************************************/

#include "../../../../kstars-3.8.4.1/kstars/ekos/guide/guidedriftgraph.h"
#include <QtGui/qtextcursor.h>
#include <QtGui/qscreen.h>
#include <QtCore/qmetatype.h>

#include <QtCore/qtmochelpers.h>

#include <memory>


#include <QtCore/qxptype_traits.h>
#if !defined(Q_MOC_OUTPUT_REVISION)
#error "The header file 'guidedriftgraph.h' doesn't include <QObject>."
#elif Q_MOC_OUTPUT_REVISION != 69
#error "This file was generated using the moc from 6.11.1. It"
#error "cannot be used with the include files from this version of Qt."
#error "(The moc has changed too much.)"
#endif

#ifndef Q_CONSTINIT
#define Q_CONSTINIT
#endif

QT_WARNING_PUSH
QT_WARNING_DISABLE_DEPRECATED
QT_WARNING_DISABLE_GCC("-Wuseless-cast")
namespace {
struct qt_meta_tag_ZN15GuideDriftGraphE_t {};
} // unnamed namespace

template <> constexpr inline auto GuideDriftGraph::qt_create_metaobjectdata<qt_meta_tag_ZN15GuideDriftGraphE_t>()
{
    namespace QMC = QtMocConstants;
    QtMocHelpers::StringRefStorage qt_stringData {
        "GuideDriftGraph",
        "handleVerticalPlotSizeChange",
        "",
        "handleHorizontalPlotSizeChange",
        "setupNSEWLabels",
        "autoScaleGraphs",
        "zoomX",
        "zoomLevel",
        "zoomInX",
        "zoomOutX",
        "setCorrectionGraphScale",
        "value",
        "setLatestGuidePoint",
        "isChecked",
        "clear",
        "toggleShowPlot",
        "GuideGraph::DRIFT_GRAPH_INDICES",
        "plot",
        "setAxisDelta",
        "ra",
        "de",
        "setAxisSigma",
        "setAxisPulse",
        "setSNR",
        "snr",
        "updateCorrectionsScaleVisibility",
        "mouseOverLine",
        "QMouseEvent*",
        "event",
        "mouseClicked",
        "refreshColorScheme"
    };

    QtMocHelpers::UintData qt_methods {
        // Slot 'handleVerticalPlotSizeChange'
        QtMocHelpers::SlotData<void()>(1, 2, QMC::AccessPublic, QMetaType::Void),
        // Slot 'handleHorizontalPlotSizeChange'
        QtMocHelpers::SlotData<void()>(3, 2, QMC::AccessPublic, QMetaType::Void),
        // Slot 'setupNSEWLabels'
        QtMocHelpers::SlotData<void()>(4, 2, QMC::AccessPublic, QMetaType::Void),
        // Slot 'autoScaleGraphs'
        QtMocHelpers::SlotData<void()>(5, 2, QMC::AccessPublic, QMetaType::Void),
        // Slot 'zoomX'
        QtMocHelpers::SlotData<void(int)>(6, 2, QMC::AccessPublic, QMetaType::Void, {{
            { QMetaType::Int, 7 },
        }}),
        // Slot 'zoomInX'
        QtMocHelpers::SlotData<void()>(8, 2, QMC::AccessPublic, QMetaType::Void),
        // Slot 'zoomOutX'
        QtMocHelpers::SlotData<void()>(9, 2, QMC::AccessPublic, QMetaType::Void),
        // Slot 'setCorrectionGraphScale'
        QtMocHelpers::SlotData<void(int)>(10, 2, QMC::AccessPublic, QMetaType::Void, {{
            { QMetaType::Int, 11 },
        }}),
        // Slot 'setLatestGuidePoint'
        QtMocHelpers::SlotData<void(bool)>(12, 2, QMC::AccessPublic, QMetaType::Void, {{
            { QMetaType::Bool, 13 },
        }}),
        // Slot 'clear'
        QtMocHelpers::SlotData<void()>(14, 2, QMC::AccessPublic, QMetaType::Void),
        // Slot 'toggleShowPlot'
        QtMocHelpers::SlotData<void(GuideGraph::DRIFT_GRAPH_INDICES, bool)>(15, 2, QMC::AccessPublic, QMetaType::Void, {{
            { 0x80000000 | 16, 17 }, { QMetaType::Bool, 13 },
        }}),
        // Slot 'setAxisDelta'
        QtMocHelpers::SlotData<void(double, double)>(18, 2, QMC::AccessPublic, QMetaType::Void, {{
            { QMetaType::Double, 19 }, { QMetaType::Double, 20 },
        }}),
        // Slot 'setAxisSigma'
        QtMocHelpers::SlotData<void(double, double)>(21, 2, QMC::AccessPublic, QMetaType::Void, {{
            { QMetaType::Double, 19 }, { QMetaType::Double, 20 },
        }}),
        // Slot 'setAxisPulse'
        QtMocHelpers::SlotData<void(double, double)>(22, 2, QMC::AccessPublic, QMetaType::Void, {{
            { QMetaType::Double, 19 }, { QMetaType::Double, 20 },
        }}),
        // Slot 'setSNR'
        QtMocHelpers::SlotData<void(double)>(23, 2, QMC::AccessPublic, QMetaType::Void, {{
            { QMetaType::Double, 24 },
        }}),
        // Slot 'updateCorrectionsScaleVisibility'
        QtMocHelpers::SlotData<void()>(25, 2, QMC::AccessPublic, QMetaType::Void),
        // Slot 'mouseOverLine'
        QtMocHelpers::SlotData<void(QMouseEvent *)>(26, 2, QMC::AccessPublic, QMetaType::Void, {{
            { 0x80000000 | 27, 28 },
        }}),
        // Slot 'mouseClicked'
        QtMocHelpers::SlotData<void(QMouseEvent *)>(29, 2, QMC::AccessPublic, QMetaType::Void, {{
            { 0x80000000 | 27, 28 },
        }}),
        // Slot 'refreshColorScheme'
        QtMocHelpers::SlotData<void()>(30, 2, QMC::AccessPublic, QMetaType::Void),
    };
    QtMocHelpers::UintData qt_properties {
    };
    QtMocHelpers::UintData qt_enums {
    };
    return QtMocHelpers::metaObjectData<GuideDriftGraph, qt_meta_tag_ZN15GuideDriftGraphE_t>(QMC::MetaObjectFlag{}, qt_stringData,
            qt_methods, qt_properties, qt_enums);
}
Q_CONSTINIT const QMetaObject GuideDriftGraph::staticMetaObject = { {
    QMetaObject::SuperData::link<QCustomPlot::staticMetaObject>(),
    qt_staticMetaObjectStaticContent<qt_meta_tag_ZN15GuideDriftGraphE_t>.stringdata,
    qt_staticMetaObjectStaticContent<qt_meta_tag_ZN15GuideDriftGraphE_t>.data,
    qt_static_metacall,
    nullptr,
    qt_staticMetaObjectRelocatingContent<qt_meta_tag_ZN15GuideDriftGraphE_t>.metaTypes,
    nullptr
} };

void GuideDriftGraph::qt_static_metacall(QObject *_o, QMetaObject::Call _c, int _id, void **_a)
{
    auto *_t = static_cast<GuideDriftGraph *>(_o);
    if (_c == QMetaObject::InvokeMetaMethod) {
        switch (_id) {
        case 0: _t->handleVerticalPlotSizeChange(); break;
        case 1: _t->handleHorizontalPlotSizeChange(); break;
        case 2: _t->setupNSEWLabels(); break;
        case 3: _t->autoScaleGraphs(); break;
        case 4: _t->zoomX((*reinterpret_cast<std::add_pointer_t<int>>(_a[1]))); break;
        case 5: _t->zoomInX(); break;
        case 6: _t->zoomOutX(); break;
        case 7: _t->setCorrectionGraphScale((*reinterpret_cast<std::add_pointer_t<int>>(_a[1]))); break;
        case 8: _t->setLatestGuidePoint((*reinterpret_cast<std::add_pointer_t<bool>>(_a[1]))); break;
        case 9: _t->clear(); break;
        case 10: _t->toggleShowPlot((*reinterpret_cast<std::add_pointer_t<GuideGraph::DRIFT_GRAPH_INDICES>>(_a[1])),(*reinterpret_cast<std::add_pointer_t<bool>>(_a[2]))); break;
        case 11: _t->setAxisDelta((*reinterpret_cast<std::add_pointer_t<double>>(_a[1])),(*reinterpret_cast<std::add_pointer_t<double>>(_a[2]))); break;
        case 12: _t->setAxisSigma((*reinterpret_cast<std::add_pointer_t<double>>(_a[1])),(*reinterpret_cast<std::add_pointer_t<double>>(_a[2]))); break;
        case 13: _t->setAxisPulse((*reinterpret_cast<std::add_pointer_t<double>>(_a[1])),(*reinterpret_cast<std::add_pointer_t<double>>(_a[2]))); break;
        case 14: _t->setSNR((*reinterpret_cast<std::add_pointer_t<double>>(_a[1]))); break;
        case 15: _t->updateCorrectionsScaleVisibility(); break;
        case 16: _t->mouseOverLine((*reinterpret_cast<std::add_pointer_t<QMouseEvent*>>(_a[1]))); break;
        case 17: _t->mouseClicked((*reinterpret_cast<std::add_pointer_t<QMouseEvent*>>(_a[1]))); break;
        case 18: _t->refreshColorScheme(); break;
        default: ;
        }
    }
}

const QMetaObject *GuideDriftGraph::metaObject() const
{
    return QObject::d_ptr->metaObject ? QObject::d_ptr->dynamicMetaObject() : &staticMetaObject;
}

void *GuideDriftGraph::qt_metacast(const char *_clname)
{
    if (!_clname) return nullptr;
    if (!strcmp(_clname, qt_staticMetaObjectStaticContent<qt_meta_tag_ZN15GuideDriftGraphE_t>.strings))
        return static_cast<void*>(this);
    return QCustomPlot::qt_metacast(_clname);
}

int GuideDriftGraph::qt_metacall(QMetaObject::Call _c, int _id, void **_a)
{
    _id = QCustomPlot::qt_metacall(_c, _id, _a);
    if (_id < 0)
        return _id;
    if (_c == QMetaObject::InvokeMetaMethod) {
        if (_id < 19)
            qt_static_metacall(this, _c, _id, _a);
        _id -= 19;
    }
    if (_c == QMetaObject::RegisterMethodArgumentMetaType) {
        if (_id < 19)
            *reinterpret_cast<QMetaType *>(_a[0]) = QMetaType();
        _id -= 19;
    }
    return _id;
}
QT_WARNING_POP
