/********************************************************************************
** Form generated from reading UI file 'pwizchartcontents.ui'
**
** Created by: Qt User Interface Compiler version 6.11.1
**
** WARNING! All changes made in this file will be lost when recompiling UI file!
********************************************************************************/

#ifndef UI_PWIZCHARTCONTENTS_H
#define UI_PWIZCHARTCONTENTS_H

#include <QtCore/QVariant>
#include <QtWidgets/QApplication>
#include <QtWidgets/QCheckBox>
#include <QtWidgets/QHBoxLayout>
#include <QtWidgets/QLabel>
#include <QtWidgets/QSpacerItem>
#include <QtWidgets/QVBoxLayout>
#include <QtWidgets/QWidget>
#include <klocalizedstring.h>

QT_BEGIN_NAMESPACE

class Ui_PWizChartContents
{
public:
    QHBoxLayout *horizontalLayout;
    QLabel *banner;
    QSpacerItem *horizontalSpacer;
    QVBoxLayout *contentsLayout;
    QLabel *stepTitle;
    QSpacerItem *vertSpacer1;
    QLabel *stepText;
    QSpacerItem *vertSpacer2;
    QLabel *tablesLabel;
    QCheckBox *generalCheckBox;
    QCheckBox *posCheckBox;
    QCheckBox *rstCheckBox;
    QCheckBox *astComCheckBox;
    QSpacerItem *vertSpacer3;
    QLabel *loggingFormLabel;
    QCheckBox *loggingFormBox;
    QSpacerItem *vertSpacer4;

    void setupUi(QWidget *PWizChartContents)
    {
        if (PWizChartContents->objectName().isEmpty())
            PWizChartContents->setObjectName("PWizChartContents");
        PWizChartContents->resize(586, 395);
        PWizChartContents->setMinimumSize(QSize(586, 395));
        horizontalLayout = new QHBoxLayout(PWizChartContents);
        horizontalLayout->setObjectName("horizontalLayout");
        banner = new QLabel(PWizChartContents);
        banner->setObjectName("banner");
        QSizePolicy sizePolicy(QSizePolicy::Policy::Fixed, QSizePolicy::Policy::Fixed);
        sizePolicy.setHorizontalStretch(0);
        sizePolicy.setVerticalStretch(0);
        sizePolicy.setHeightForWidth(banner->sizePolicy().hasHeightForWidth());
        banner->setSizePolicy(sizePolicy);
        banner->setMinimumSize(QSize(120, 360));

        horizontalLayout->addWidget(banner);

        horizontalSpacer = new QSpacerItem(5, 20, QSizePolicy::Policy::Fixed, QSizePolicy::Policy::Minimum);

        horizontalLayout->addItem(horizontalSpacer);

        contentsLayout = new QVBoxLayout();
#ifndef UI_Q_OS_MAC
        contentsLayout->setSpacing(6);
#endif
        contentsLayout->setContentsMargins(0, 0, 0, 0);
        contentsLayout->setObjectName("contentsLayout");
        stepTitle = new QLabel(PWizChartContents);
        stepTitle->setObjectName("stepTitle");
        QFont font;
        font.setFamilies({QString::fromUtf8("Sans Serif")});
        font.setPointSize(11);
        font.setBold(true);
        font.setItalic(false);
        font.setUnderline(false);
        font.setStrikeOut(false);
        stepTitle->setFont(font);

        contentsLayout->addWidget(stepTitle);

        vertSpacer1 = new QSpacerItem(20, 12, QSizePolicy::Policy::Minimum, QSizePolicy::Policy::Fixed);

        contentsLayout->addItem(vertSpacer1);

        stepText = new QLabel(PWizChartContents);
        stepText->setObjectName("stepText");
        stepText->setWordWrap(true);

        contentsLayout->addWidget(stepText);

        vertSpacer2 = new QSpacerItem(20, 12, QSizePolicy::Policy::Minimum, QSizePolicy::Policy::Fixed);

        contentsLayout->addItem(vertSpacer2);

        tablesLabel = new QLabel(PWizChartContents);
        tablesLabel->setObjectName("tablesLabel");
        QFont font1;
        font1.setBold(true);
        tablesLabel->setFont(font1);

        contentsLayout->addWidget(tablesLabel);

        generalCheckBox = new QCheckBox(PWizChartContents);
        generalCheckBox->setObjectName("generalCheckBox");

        contentsLayout->addWidget(generalCheckBox);

        posCheckBox = new QCheckBox(PWizChartContents);
        posCheckBox->setObjectName("posCheckBox");

        contentsLayout->addWidget(posCheckBox);

        rstCheckBox = new QCheckBox(PWizChartContents);
        rstCheckBox->setObjectName("rstCheckBox");

        contentsLayout->addWidget(rstCheckBox);

        astComCheckBox = new QCheckBox(PWizChartContents);
        astComCheckBox->setObjectName("astComCheckBox");

        contentsLayout->addWidget(astComCheckBox);

        vertSpacer3 = new QSpacerItem(20, 12, QSizePolicy::Policy::Minimum, QSizePolicy::Policy::Fixed);

        contentsLayout->addItem(vertSpacer3);

        loggingFormLabel = new QLabel(PWizChartContents);
        loggingFormLabel->setObjectName("loggingFormLabel");
        loggingFormLabel->setFont(font1);

        contentsLayout->addWidget(loggingFormLabel);

        loggingFormBox = new QCheckBox(PWizChartContents);
        loggingFormBox->setObjectName("loggingFormBox");

        contentsLayout->addWidget(loggingFormBox);

        vertSpacer4 = new QSpacerItem(20, 40, QSizePolicy::Policy::Minimum, QSizePolicy::Policy::Expanding);

        contentsLayout->addItem(vertSpacer4);


        horizontalLayout->addLayout(contentsLayout);


        retranslateUi(PWizChartContents);

        QMetaObject::connectSlotsByName(PWizChartContents);
    } // setupUi

    void retranslateUi(QWidget *PWizChartContents)
    {
        banner->setText(QString());
        stepTitle->setText(tr2i18n("Select Additional Finder Chart Contents", nullptr));
        stepText->setText(tr2i18n("<p>Finder chart can contain additional elements such as details tables and logging forms. Select which you want to be included in finder chart and press <b>Next</b> to proceed.</p>", nullptr));
        tablesLabel->setText(tr2i18n("Details tables", nullptr));
        generalCheckBox->setText(tr2i18n("Add general details table", nullptr));
        posCheckBox->setText(tr2i18n("Add position details table", nullptr));
        rstCheckBox->setText(tr2i18n("Add Rise/Set/Transit details table", nullptr));
        astComCheckBox->setText(tr2i18n("Add Asteroid/Comet details table", nullptr));
        loggingFormLabel->setText(tr2i18n("Logging form", nullptr));
        loggingFormBox->setText(tr2i18n("Add basic logging form to finder chart", nullptr));
        (void)PWizChartContents;
    } // retranslateUi

};

namespace Ui {
    class PWizChartContents: public Ui_PWizChartContents {};
} // namespace Ui

QT_END_NAMESPACE

#endif // PWIZCHARTCONTENTS_H

