/****************************************************************************
** Meta object code from reading C++ file 'capture.h'
**
** Created by: The Qt Meta Object Compiler version 69 (Qt 6.11.1)
**
** WARNING! All changes made in this file will be lost!
*****************************************************************************/

#include "../../../../kstars-3.8.4.1/kstars/ekos/capture/capture.h"
#include <QtNetwork/QSslError>
#include <QtDataVisualization/qbar3dseries.h>
#include <QtDataVisualization/q3dscene.h>
#include <QtGui/qtextcursor.h>
#include <QtCore/qmetatype.h>
#include <QtCore/QSharedPointer>

#include <QtCore/qtmochelpers.h>

#include <memory>


#include <QtCore/qxptype_traits.h>
#if !defined(Q_MOC_OUTPUT_REVISION)
#error "The header file 'capture.h' doesn't include <QObject>."
#elif Q_MOC_OUTPUT_REVISION != 69
#error "This file was generated using the moc from 6.11.1. It"
#error "cannot be used with the include files from this version of Qt."
#error "(The moc has changed too much.)"
#endif

#ifndef Q_CONSTINIT
#define Q_CONSTINIT
#endif

QT_WARNING_PUSH
QT_WARNING_DISABLE_DEPRECATED
QT_WARNING_DISABLE_GCC("-Wuseless-cast")
namespace {
struct qt_meta_tag_ZN4Ekos7CaptureE_t {};
} // unnamed namespace

template <> constexpr inline auto Ekos::Capture::qt_create_metaobjectdata<qt_meta_tag_ZN4Ekos7CaptureE_t>()
{
    namespace QMC = QtMocConstants;
    QtMocHelpers::StringRefStorage qt_stringData {
        "Ekos::Capture",
        "D-Bus Interface",
        "org.kde.kstars.Ekos.Capture",
        "newLog",
        "",
        "text",
        "meridianFlipStarted",
        "trainname",
        "guideAfterMeridianFlip",
        "newStatus",
        "CaptureState",
        "status",
        "cameraID",
        "captureComplete",
        "QVariantMap",
        "metadata",
        "newFilterStatus",
        "FilterState",
        "state",
        "ready",
        "checkFocus",
        "opticaltrain",
        "runAutoFocus",
        "AutofocusReason",
        "autofocusReason",
        "reasonInfo",
        "resetFocusFrame",
        "abortFocus",
        "adaptiveFocus",
        "suspendGuiding",
        "resumeGuiding",
        "dither",
        "resetNonGuidedDither",
        "captureTarget",
        "targetName",
        "newImage",
        "QSharedPointer<SequenceJob>",
        "job",
        "QSharedPointer<FITSData>",
        "data",
        "newExposureProgress",
        "newDownloadProgress",
        "sequenceChanged",
        "QJsonArray",
        "sequence",
        "settingsUpdated",
        "settings",
        "newLocalPreview",
        "preview",
        "dslrInfoRequested",
        "cameraName",
        "driverTimedout",
        "deviceName",
        "captureStarting",
        "exposureSeconds",
        "filter",
        "captureAborted",
        "filterManagerUpdated",
        "ISD::FilterWheel*",
        "device",
        "trainChanged",
        "start",
        "train",
        "stop",
        "Q_NOREPLY",
        "targetState",
        "abort",
        "suspend",
        "pause",
        "toggleSequence",
        "toggleVideo",
        "enabled",
        "restartCamera",
        "name",
        "setTargetName",
        "newTargetName",
        "getTargetName",
        "setObserverName",
        "value",
        "getObserverName",
        "setPicturesDirectory",
        "path",
        "getPicturesDirectory",
        "mainCameraDeviceName",
        "process",
        "QSharedPointer<CameraProcess>",
        "updateTargetDistance",
        "targetDiff",
        "setMeridianFlipState",
        "QSharedPointer<MeridianFlipState>",
        "newstate",
        "setGuideDeviation",
        "delta_ra",
        "delta_dec",
        "setGuideChip",
        "ISD::CameraChip*",
        "guideChip",
        "setFocusStatus",
        "FocusState",
        "focusAdaptiveComplete",
        "success",
        "setFocusTemperatureDelta",
        "focusTemperatureDelta",
        "absTemperature",
        "setHFR",
        "newHFR",
        "position",
        "inAutofocus",
        "inSequenceAFRequested",
        "requested",
        "setGuideStatus",
        "GuideState",
        "setAlignStatus",
        "Ekos::AlignState",
        "setAlignResults",
        "solverPA",
        "ra",
        "de",
        "pixscale",
        "commandRotator",
        "targetPA",
        "setMountStatus",
        "ISD::Mount::Status",
        "newState",
        "clearLog",
        "appendLogText",
        "camera",
        "filterWheel",
        "setFilter",
        "clearSequenceQueue",
        "getSequenceQueueStatus",
        "loadSequenceQueue",
        "fileURL",
        "isLead",
        "saveSequenceQueue",
        "setMaximumGuidingDeviation",
        "enable",
        "setInSequenceFocus",
        "HFR",
        "hasCoolerControl",
        "setCoolerControl",
        "getProgressPercentage",
        "isActiveJobPreview",
        "getJobCount",
        "getPendingJobCount",
        "getActiveJobID",
        "getActiveJobRemainingTime",
        "getOverallRemainingTime",
        "getJobState",
        "id",
        "getJobFilterName",
        "getJobImageProgress",
        "getJobImageCount",
        "getJobExposureProgress",
        "getJobExposureDuration",
        "getJobFrameType",
        "CCDFrameType",
        "getJobPlaceholderFormat",
        "getJobPreviewFileName",
        "clearAutoFocusHFR",
        "ignoreSequenceHistory",
        "setCapturedFramesMap",
        "signature",
        "count",
        "logText",
        "getLogText",
        "findCameraPosition",
        "addIfNecessary",
        "Ekos::CaptureState",
        "observerName",
        "opticalTrain",
        "coolerControl"
    };

    QtMocHelpers::UintData qt_methods {
        // Signal 'newLog'
        QtMocHelpers::SignalData<void(const QString &)>(3, 4, QMC::AccessPublic | QMC::MethodScriptable, QMetaType::Void, {{
            { QMetaType::QString, 5 },
        }}),
        // Signal 'meridianFlipStarted'
        QtMocHelpers::SignalData<void(const QString &)>(6, 4, QMC::AccessPublic | QMC::MethodScriptable, QMetaType::Void, {{
            { QMetaType::QString, 7 },
        }}),
        // Signal 'guideAfterMeridianFlip'
        QtMocHelpers::SignalData<void()>(8, 4, QMC::AccessPublic | QMC::MethodScriptable, QMetaType::Void),
        // Signal 'newStatus'
        QtMocHelpers::SignalData<void(CaptureState, const QString &, int)>(9, 4, QMC::AccessPublic | QMC::MethodScriptable, QMetaType::Void, {{
            { 0x80000000 | 10, 11 }, { QMetaType::QString, 7 }, { QMetaType::Int, 12 },
        }}),
        // Signal 'captureComplete'
        QtMocHelpers::SignalData<void(const QVariantMap &, const QString &)>(13, 4, QMC::AccessPublic | QMC::MethodScriptable, QMetaType::Void, {{
            { 0x80000000 | 14, 15 }, { QMetaType::QString, 7 },
        }}),
        // Signal 'newFilterStatus'
        QtMocHelpers::SignalData<void(FilterState)>(16, 4, QMC::AccessPublic, QMetaType::Void, {{
            { 0x80000000 | 17, 18 },
        }}),
        // Signal 'ready'
        QtMocHelpers::SignalData<void()>(19, 4, QMC::AccessPublic, QMetaType::Void),
        // Signal 'checkFocus'
        QtMocHelpers::SignalData<void(double, const QString &)>(20, 4, QMC::AccessPublic, QMetaType::Void, {{
            { QMetaType::Double, 4 }, { QMetaType::QString, 21 },
        }}),
        // Signal 'runAutoFocus'
        QtMocHelpers::SignalData<void(AutofocusReason, const QString &, const QString &)>(22, 4, QMC::AccessPublic, QMetaType::Void, {{
            { 0x80000000 | 23, 24 }, { QMetaType::QString, 25 }, { QMetaType::QString, 7 },
        }}),
        // Signal 'resetFocusFrame'
        QtMocHelpers::SignalData<void(const QString &)>(26, 4, QMC::AccessPublic, QMetaType::Void, {{
            { QMetaType::QString, 7 },
        }}),
        // Signal 'abortFocus'
        QtMocHelpers::SignalData<void(const QString &)>(27, 4, QMC::AccessPublic, QMetaType::Void, {{
            { QMetaType::QString, 7 },
        }}),
        // Signal 'adaptiveFocus'
        QtMocHelpers::SignalData<void(const QString &)>(28, 4, QMC::AccessPublic, QMetaType::Void, {{
            { QMetaType::QString, 7 },
        }}),
        // Signal 'suspendGuiding'
        QtMocHelpers::SignalData<void()>(29, 4, QMC::AccessPublic, QMetaType::Void),
        // Signal 'resumeGuiding'
        QtMocHelpers::SignalData<void()>(30, 4, QMC::AccessPublic, QMetaType::Void),
        // Signal 'dither'
        QtMocHelpers::SignalData<void()>(31, 4, QMC::AccessPublic, QMetaType::Void),
        // Signal 'resetNonGuidedDither'
        QtMocHelpers::SignalData<void()>(32, 4, QMC::AccessPublic, QMetaType::Void),
        // Signal 'captureTarget'
        QtMocHelpers::SignalData<void(QString)>(33, 4, QMC::AccessPublic, QMetaType::Void, {{
            { QMetaType::QString, 34 },
        }}),
        // Signal 'newImage'
        QtMocHelpers::SignalData<void(const QSharedPointer<SequenceJob> &, const QSharedPointer<FITSData> &, const QString &)>(35, 4, QMC::AccessPublic, QMetaType::Void, {{
            { 0x80000000 | 36, 37 }, { 0x80000000 | 38, 39 }, { QMetaType::QString, 7 },
        }}),
        // Signal 'newExposureProgress'
        QtMocHelpers::SignalData<void(const QSharedPointer<SequenceJob> &, const QString &)>(40, 4, QMC::AccessPublic, QMetaType::Void, {{
            { 0x80000000 | 36, 37 }, { QMetaType::QString, 7 },
        }}),
        // Signal 'newDownloadProgress'
        QtMocHelpers::SignalData<void(double, const QString &)>(41, 4, QMC::AccessPublic, QMetaType::Void, {{
            { QMetaType::Double, 4 }, { QMetaType::QString, 7 },
        }}),
        // Signal 'sequenceChanged'
        QtMocHelpers::SignalData<void(const QJsonArray &)>(42, 4, QMC::AccessPublic, QMetaType::Void, {{
            { 0x80000000 | 43, 44 },
        }}),
        // Signal 'settingsUpdated'
        QtMocHelpers::SignalData<void(const QVariantMap &)>(45, 4, QMC::AccessPublic, QMetaType::Void, {{
            { 0x80000000 | 14, 46 },
        }}),
        // Signal 'newLocalPreview'
        QtMocHelpers::SignalData<void(const QString &)>(47, 4, QMC::AccessPublic, QMetaType::Void, {{
            { QMetaType::QString, 48 },
        }}),
        // Signal 'dslrInfoRequested'
        QtMocHelpers::SignalData<void(const QString &)>(49, 4, QMC::AccessPublic, QMetaType::Void, {{
            { QMetaType::QString, 50 },
        }}),
        // Signal 'driverTimedout'
        QtMocHelpers::SignalData<void(const QString &)>(51, 4, QMC::AccessPublic, QMetaType::Void, {{
            { QMetaType::QString, 52 },
        }}),
        // Signal 'captureStarting'
        QtMocHelpers::SignalData<void(double, const QString &)>(53, 4, QMC::AccessPublic, QMetaType::Void, {{
            { QMetaType::Double, 54 }, { QMetaType::QString, 55 },
        }}),
        // Signal 'captureAborted'
        QtMocHelpers::SignalData<void(double)>(56, 4, QMC::AccessPublic, QMetaType::Void, {{
            { QMetaType::Double, 54 },
        }}),
        // Signal 'filterManagerUpdated'
        QtMocHelpers::SignalData<void(ISD::FilterWheel *)>(57, 4, QMC::AccessPublic, QMetaType::Void, {{
            { 0x80000000 | 58, 59 },
        }}),
        // Signal 'trainChanged'
        QtMocHelpers::SignalData<void()>(60, 4, QMC::AccessPublic, QMetaType::Void),
        // Slot 'start'
        QtMocHelpers::SlotData<QString(QString)>(61, 4, QMC::AccessPublic | QMC::MethodScriptable, QMetaType::QString, {{
            { QMetaType::QString, 62 },
        }}),
        // Slot 'start'
        QtMocHelpers::SlotData<QString()>(61, 4, QMC::AccessPublic | QMC::MethodCloned | QMC::MethodScriptable, QMetaType::QString),
        // Slot 'stop'
        QtMocHelpers::SlotData<void(CaptureState)>(63, 64, QMC::AccessPublic | QMC::MethodScriptable, QMetaType::Void, {{
            { 0x80000000 | 10, 65 },
        }}),
        // Slot 'stop'
        QtMocHelpers::SlotData<void()>(63, 64, QMC::AccessPublic | QMC::MethodCloned | QMC::MethodScriptable, QMetaType::Void),
        // Slot 'abort'
        QtMocHelpers::SlotData<void(QString)>(66, 64, QMC::AccessPublic | QMC::MethodScriptable, QMetaType::Void, {{
            { QMetaType::QString, 62 },
        }}),
        // Slot 'abort'
        QtMocHelpers::SlotData<void()>(66, 64, QMC::AccessPublic | QMC::MethodCloned | QMC::MethodScriptable, QMetaType::Void),
        // Slot 'suspend'
        QtMocHelpers::SlotData<void()>(67, 64, QMC::AccessPublic | QMC::MethodScriptable, QMetaType::Void),
        // Slot 'pause'
        QtMocHelpers::SlotData<void()>(68, 64, QMC::AccessPublic | QMC::MethodScriptable, QMetaType::Void),
        // Slot 'toggleSequence'
        QtMocHelpers::SlotData<void()>(69, 64, QMC::AccessPublic | QMC::MethodScriptable, QMetaType::Void),
        // Slot 'toggleVideo'
        QtMocHelpers::SlotData<void(bool)>(70, 64, QMC::AccessPublic | QMC::MethodScriptable, QMetaType::Void, {{
            { QMetaType::Bool, 71 },
        }}),
        // Slot 'restartCamera'
        QtMocHelpers::SlotData<void(const QString &)>(72, 64, QMC::AccessPublic | QMC::MethodScriptable, QMetaType::Void, {{
            { QMetaType::QString, 73 },
        }}),
        // Slot 'setTargetName'
        QtMocHelpers::SlotData<void(const QString &)>(74, 64, QMC::AccessPublic | QMC::MethodScriptable, QMetaType::Void, {{
            { QMetaType::QString, 75 },
        }}),
        // Slot 'getTargetName'
        QtMocHelpers::SlotData<QString()>(76, 4, QMC::AccessPublic | QMC::MethodScriptable, QMetaType::QString),
        // Slot 'setObserverName'
        QtMocHelpers::SlotData<void(const QString &)>(77, 64, QMC::AccessPublic | QMC::MethodScriptable, QMetaType::Void, {{
            { QMetaType::QString, 78 },
        }}),
        // Slot 'getObserverName'
        QtMocHelpers::SlotData<QString()>(79, 4, QMC::AccessPublic | QMC::MethodScriptable, QMetaType::QString),
        // Slot 'setPicturesDirectory'
        QtMocHelpers::SlotData<bool(const QString &)>(80, 4, QMC::AccessPublic | QMC::MethodScriptable, QMetaType::Bool, {{
            { QMetaType::QString, 81 },
        }}),
        // Slot 'getPicturesDirectory'
        QtMocHelpers::SlotData<QString()>(82, 4, QMC::AccessPublic | QMC::MethodScriptable, QMetaType::QString),
        // Slot 'mainCameraDeviceName'
        QtMocHelpers::SlotData<QString()>(83, 4, QMC::AccessPublic | QMC::MethodScriptable, QMetaType::QString),
        // Slot 'process'
        QtMocHelpers::SlotData<QSharedPointer<CameraProcess>() const>(84, 4, QMC::AccessPublic, 0x80000000 | 85),
        // Slot 'updateTargetDistance'
        QtMocHelpers::SlotData<void(double)>(86, 4, QMC::AccessPublic, QMetaType::Void, {{
            { QMetaType::Double, 87 },
        }}),
        // Slot 'setMeridianFlipState'
        QtMocHelpers::SlotData<void(QSharedPointer<MeridianFlipState>)>(88, 4, QMC::AccessPublic, QMetaType::Void, {{
            { 0x80000000 | 89, 90 },
        }}),
        // Slot 'setGuideDeviation'
        QtMocHelpers::SlotData<void(double, double)>(91, 4, QMC::AccessPublic, QMetaType::Void, {{
            { QMetaType::Double, 92 }, { QMetaType::Double, 93 },
        }}),
        // Slot 'setGuideChip'
        QtMocHelpers::SlotData<void(ISD::CameraChip *)>(94, 4, QMC::AccessPublic, QMetaType::Void, {{
            { 0x80000000 | 95, 96 },
        }}),
        // Slot 'setFocusStatus'
        QtMocHelpers::SlotData<void(FocusState, const QString &)>(97, 4, QMC::AccessPublic, QMetaType::Void, {{
            { 0x80000000 | 98, 90 }, { QMetaType::QString, 7 },
        }}),
        // Slot 'focusAdaptiveComplete'
        QtMocHelpers::SlotData<void(bool, const QString &)>(99, 4, QMC::AccessPublic, QMetaType::Void, {{
            { QMetaType::Bool, 100 }, { QMetaType::QString, 7 },
        }}),
        // Slot 'setFocusTemperatureDelta'
        QtMocHelpers::SlotData<void(double, double, const QString &)>(101, 4, QMC::AccessPublic, QMetaType::Void, {{
            { QMetaType::Double, 102 }, { QMetaType::Double, 103 }, { QMetaType::QString, 7 },
        }}),
        // Slot 'setHFR'
        QtMocHelpers::SlotData<void(double, int, bool, const QString &)>(104, 4, QMC::AccessPublic, QMetaType::Void, {{
            { QMetaType::Double, 105 }, { QMetaType::Int, 106 }, { QMetaType::Bool, 107 }, { QMetaType::QString, 7 },
        }}),
        // Slot 'inSequenceAFRequested'
        QtMocHelpers::SlotData<void(bool, const QString &)>(108, 4, QMC::AccessPublic, QMetaType::Void, {{
            { QMetaType::Bool, 109 }, { QMetaType::QString, 7 },
        }}),
        // Slot 'setGuideStatus'
        QtMocHelpers::SlotData<void(GuideState)>(110, 4, QMC::AccessPublic, QMetaType::Void, {{
            { 0x80000000 | 111, 90 },
        }}),
        // Slot 'setAlignStatus'
        QtMocHelpers::SlotData<void(Ekos::AlignState)>(112, 4, QMC::AccessPublic, QMetaType::Void, {{
            { 0x80000000 | 113, 90 },
        }}),
        // Slot 'setAlignResults'
        QtMocHelpers::SlotData<void(double, double, double, double)>(114, 4, QMC::AccessPublic, QMetaType::Void, {{
            { QMetaType::Double, 115 }, { QMetaType::Double, 116 }, { QMetaType::Double, 117 }, { QMetaType::Double, 118 },
        }}),
        // Slot 'commandRotator'
        QtMocHelpers::SlotData<void(double)>(119, 4, QMC::AccessPublic, QMetaType::Void, {{
            { QMetaType::Double, 120 },
        }}),
        // Slot 'setMountStatus'
        QtMocHelpers::SlotData<void(ISD::Mount::Status)>(121, 4, QMC::AccessPublic, QMetaType::Void, {{
            { 0x80000000 | 122, 123 },
        }}),
        // Slot 'clearLog'
        QtMocHelpers::SlotData<void()>(124, 4, QMC::AccessPublic | QMC::MethodScriptable, QMetaType::Void),
        // Slot 'appendLogText'
        QtMocHelpers::SlotData<void(const QString &)>(125, 4, QMC::AccessPublic, QMetaType::Void, {{
            { QMetaType::QString, 4 },
        }}),
        // Method 'camera'
        QtMocHelpers::MethodData<QString()>(126, 4, QMC::AccessPublic | QMC::MethodScriptable, QMetaType::QString),
        // Method 'filterWheel'
        QtMocHelpers::MethodData<QString()>(127, 4, QMC::AccessPublic | QMC::MethodScriptable, QMetaType::QString),
        // Method 'setFilter'
        QtMocHelpers::MethodData<bool(const QString &)>(128, 4, QMC::AccessPublic | QMC::MethodScriptable, QMetaType::Bool, {{
            { QMetaType::QString, 55 },
        }}),
        // Method 'filter'
        QtMocHelpers::MethodData<QString()>(55, 4, QMC::AccessPublic | QMC::MethodScriptable, QMetaType::QString),
        // Method 'clearSequenceQueue'
        QtMocHelpers::MethodData<void()>(129, 64, QMC::AccessPublic | QMC::MethodScriptable, QMetaType::Void),
        // Method 'getSequenceQueueStatus'
        QtMocHelpers::MethodData<QString()>(130, 4, QMC::AccessPublic | QMC::MethodScriptable, QMetaType::QString),
        // Method 'loadSequenceQueue'
        QtMocHelpers::MethodData<bool(const QString &, const QString &, bool, const QString &)>(131, 4, QMC::AccessPublic | QMC::MethodScriptable, QMetaType::Bool, {{
            { QMetaType::QString, 132 }, { QMetaType::QString, 62 }, { QMetaType::Bool, 133 }, { QMetaType::QString, 34 },
        }}),
        // Method 'loadSequenceQueue'
        QtMocHelpers::MethodData<bool(const QString &, const QString &, bool)>(131, 4, QMC::AccessPublic | QMC::MethodCloned | QMC::MethodScriptable, QMetaType::Bool, {{
            { QMetaType::QString, 132 }, { QMetaType::QString, 62 }, { QMetaType::Bool, 133 },
        }}),
        // Method 'loadSequenceQueue'
        QtMocHelpers::MethodData<bool(const QString &, const QString &)>(131, 4, QMC::AccessPublic | QMC::MethodCloned | QMC::MethodScriptable, QMetaType::Bool, {{
            { QMetaType::QString, 132 }, { QMetaType::QString, 62 },
        }}),
        // Method 'loadSequenceQueue'
        QtMocHelpers::MethodData<bool(const QString &)>(131, 4, QMC::AccessPublic | QMC::MethodCloned | QMC::MethodScriptable, QMetaType::Bool, {{
            { QMetaType::QString, 132 },
        }}),
        // Method 'saveSequenceQueue'
        QtMocHelpers::MethodData<bool(const QString &)>(134, 4, QMC::AccessPublic | QMC::MethodScriptable, QMetaType::Bool, {{
            { QMetaType::QString, 81 },
        }}),
        // Method 'setMaximumGuidingDeviation'
        QtMocHelpers::MethodData<void(bool, double)>(135, 64, QMC::AccessPublic | QMC::MethodScriptable, QMetaType::Void, {{
            { QMetaType::Bool, 136 }, { QMetaType::Double, 78 },
        }}),
        // Method 'setInSequenceFocus'
        QtMocHelpers::MethodData<void(bool, double)>(137, 64, QMC::AccessPublic | QMC::MethodScriptable, QMetaType::Void, {{
            { QMetaType::Bool, 136 }, { QMetaType::Double, 138 },
        }}),
        // Method 'hasCoolerControl'
        QtMocHelpers::MethodData<bool()>(139, 4, QMC::AccessPublic | QMC::MethodScriptable, QMetaType::Bool),
        // Method 'setCoolerControl'
        QtMocHelpers::MethodData<bool(bool)>(140, 4, QMC::AccessPublic | QMC::MethodScriptable, QMetaType::Bool, {{
            { QMetaType::Bool, 136 },
        }}),
        // Method 'getProgressPercentage'
        QtMocHelpers::MethodData<double()>(141, 4, QMC::AccessPublic | QMC::MethodScriptable, QMetaType::Double),
        // Method 'isActiveJobPreview'
        QtMocHelpers::MethodData<bool()>(142, 4, QMC::AccessPublic | QMC::MethodScriptable, QMetaType::Bool),
        // Method 'getJobCount'
        QtMocHelpers::MethodData<int()>(143, 4, QMC::AccessPublic | QMC::MethodScriptable, QMetaType::Int),
        // Method 'getPendingJobCount'
        QtMocHelpers::MethodData<int()>(144, 4, QMC::AccessPublic | QMC::MethodScriptable, QMetaType::Int),
        // Method 'getActiveJobID'
        QtMocHelpers::MethodData<int()>(145, 4, QMC::AccessPublic | QMC::MethodScriptable, QMetaType::Int),
        // Method 'getActiveJobRemainingTime'
        QtMocHelpers::MethodData<int()>(146, 4, QMC::AccessPublic | QMC::MethodScriptable, QMetaType::Int),
        // Method 'getOverallRemainingTime'
        QtMocHelpers::MethodData<int()>(147, 4, QMC::AccessPublic | QMC::MethodScriptable, QMetaType::Int),
        // Method 'getJobState'
        QtMocHelpers::MethodData<QString(int)>(148, 4, QMC::AccessPublic | QMC::MethodScriptable, QMetaType::QString, {{
            { QMetaType::Int, 149 },
        }}),
        // Method 'getJobFilterName'
        QtMocHelpers::MethodData<QString(int)>(150, 4, QMC::AccessPublic | QMC::MethodScriptable, QMetaType::QString, {{
            { QMetaType::Int, 149 },
        }}),
        // Method 'getJobImageProgress'
        QtMocHelpers::MethodData<int(int)>(151, 4, QMC::AccessPublic | QMC::MethodScriptable, QMetaType::Int, {{
            { QMetaType::Int, 149 },
        }}),
        // Method 'getJobImageCount'
        QtMocHelpers::MethodData<int(int)>(152, 4, QMC::AccessPublic | QMC::MethodScriptable, QMetaType::Int, {{
            { QMetaType::Int, 149 },
        }}),
        // Method 'getJobExposureProgress'
        QtMocHelpers::MethodData<double(int)>(153, 4, QMC::AccessPublic | QMC::MethodScriptable, QMetaType::Double, {{
            { QMetaType::Int, 149 },
        }}),
        // Method 'getJobExposureDuration'
        QtMocHelpers::MethodData<double(int)>(154, 4, QMC::AccessPublic | QMC::MethodScriptable, QMetaType::Double, {{
            { QMetaType::Int, 149 },
        }}),
        // Method 'getJobFrameType'
        QtMocHelpers::MethodData<CCDFrameType(int)>(155, 4, QMC::AccessPublic | QMC::MethodScriptable, 0x80000000 | 156, {{
            { QMetaType::Int, 149 },
        }}),
        // Method 'getJobPlaceholderFormat'
        QtMocHelpers::MethodData<QString()>(157, 4, QMC::AccessPublic | QMC::MethodScriptable, QMetaType::QString),
        // Method 'getJobPreviewFileName'
        QtMocHelpers::MethodData<QString()>(158, 4, QMC::AccessPublic | QMC::MethodScriptable, QMetaType::QString),
        // Method 'clearAutoFocusHFR'
        QtMocHelpers::MethodData<void(const QString &)>(159, 64, QMC::AccessPublic | QMC::MethodScriptable, QMetaType::Void, {{
            { QMetaType::QString, 7 },
        }}),
        // Method 'ignoreSequenceHistory'
        QtMocHelpers::MethodData<void()>(160, 64, QMC::AccessPublic | QMC::MethodScriptable, QMetaType::Void),
        // Method 'setCapturedFramesMap'
        QtMocHelpers::MethodData<void(const QString &, int, QString)>(161, 64, QMC::AccessPublic | QMC::MethodScriptable, QMetaType::Void, {{
            { QMetaType::QString, 162 }, { QMetaType::Int, 163 }, { QMetaType::QString, 62 },
        }}),
        // Method 'setCapturedFramesMap'
        QtMocHelpers::MethodData<void(const QString &, int)>(161, 64, QMC::AccessPublic | QMC::MethodCloned | QMC::MethodScriptable, QMetaType::Void, {{
            { QMetaType::QString, 162 }, { QMetaType::Int, 163 },
        }}),
        // Method 'logText'
        QtMocHelpers::MethodData<QStringList()>(164, 4, QMC::AccessPublic | QMC::MethodScriptable, QMetaType::QStringList),
        // Method 'getLogText'
        QtMocHelpers::MethodData<QString()>(165, 4, QMC::AccessPublic | QMC::MethodScriptable, QMetaType::QString),
        // Method 'status'
        QtMocHelpers::MethodData<CaptureState()>(11, 4, QMC::AccessPublic | QMC::MethodScriptable, 0x80000000 | 10),
        // Method 'findCameraPosition'
        QtMocHelpers::MethodData<int(QString, bool)>(166, 4, QMC::AccessPublic | QMC::MethodScriptable, QMetaType::Int, {{
            { QMetaType::QString, 62 }, { QMetaType::Bool, 167 },
        }}),
    };
    QtMocHelpers::UintData qt_properties {
        // property 'status'
        QtMocHelpers::PropertyData<Ekos::CaptureState>(11, 0x80000000 | 168, QMC::DefaultPropertyFlags | QMC::EnumOrFlag, 3),
        // property 'targetName'
        QtMocHelpers::PropertyData<QString>(34, QMetaType::QString, QMC::DefaultPropertyFlags | QMC::Writable | QMC::StdCppSet),
        // property 'observerName'
        QtMocHelpers::PropertyData<QString>(169, QMetaType::QString, QMC::DefaultPropertyFlags | QMC::Writable | QMC::StdCppSet),
        // property 'opticalTrain'
        QtMocHelpers::PropertyData<QString>(170, QMetaType::QString, QMC::DefaultPropertyFlags | QMC::Writable | QMC::StdCppSet),
        // property 'camera'
        QtMocHelpers::PropertyData<QString>(126, QMetaType::QString, QMC::DefaultPropertyFlags),
        // property 'filterWheel'
        QtMocHelpers::PropertyData<QString>(127, QMetaType::QString, QMC::DefaultPropertyFlags),
        // property 'filter'
        QtMocHelpers::PropertyData<QString>(55, QMetaType::QString, QMC::DefaultPropertyFlags | QMC::Writable | QMC::StdCppSet),
        // property 'coolerControl'
        QtMocHelpers::PropertyData<bool>(171, QMetaType::Bool, QMC::DefaultPropertyFlags | QMC::Writable | QMC::StdCppSet),
        // property 'logText'
        QtMocHelpers::PropertyData<QStringList>(164, QMetaType::QStringList, QMC::DefaultPropertyFlags, 0),
    };
    QtMocHelpers::UintData qt_enums {
    };
    QtMocHelpers::UintData qt_constructors {};
    QtMocHelpers::ClassInfos qt_classinfo({
            {    1,    2 },
    });
    return QtMocHelpers::metaObjectData<Capture, qt_meta_tag_ZN4Ekos7CaptureE_t>(QMC::MetaObjectFlag{}, qt_stringData,
            qt_methods, qt_properties, qt_enums, qt_constructors, qt_classinfo);
}
Q_CONSTINIT const QMetaObject Ekos::Capture::staticMetaObject = { {
    QMetaObject::SuperData::link<QWidget::staticMetaObject>(),
    qt_staticMetaObjectStaticContent<qt_meta_tag_ZN4Ekos7CaptureE_t>.stringdata,
    qt_staticMetaObjectStaticContent<qt_meta_tag_ZN4Ekos7CaptureE_t>.data,
    qt_static_metacall,
    nullptr,
    qt_staticMetaObjectRelocatingContent<qt_meta_tag_ZN4Ekos7CaptureE_t>.metaTypes,
    nullptr
} };

void Ekos::Capture::qt_static_metacall(QObject *_o, QMetaObject::Call _c, int _id, void **_a)
{
    auto *_t = static_cast<Capture *>(_o);
    if (_c == QMetaObject::InvokeMetaMethod) {
        switch (_id) {
        case 0: _t->newLog((*reinterpret_cast<std::add_pointer_t<QString>>(_a[1]))); break;
        case 1: _t->meridianFlipStarted((*reinterpret_cast<std::add_pointer_t<QString>>(_a[1]))); break;
        case 2: _t->guideAfterMeridianFlip(); break;
        case 3: _t->newStatus((*reinterpret_cast<std::add_pointer_t<CaptureState>>(_a[1])),(*reinterpret_cast<std::add_pointer_t<QString>>(_a[2])),(*reinterpret_cast<std::add_pointer_t<int>>(_a[3]))); break;
        case 4: _t->captureComplete((*reinterpret_cast<std::add_pointer_t<QVariantMap>>(_a[1])),(*reinterpret_cast<std::add_pointer_t<QString>>(_a[2]))); break;
        case 5: _t->newFilterStatus((*reinterpret_cast<std::add_pointer_t<FilterState>>(_a[1]))); break;
        case 6: _t->ready(); break;
        case 7: _t->checkFocus((*reinterpret_cast<std::add_pointer_t<double>>(_a[1])),(*reinterpret_cast<std::add_pointer_t<QString>>(_a[2]))); break;
        case 8: _t->runAutoFocus((*reinterpret_cast<std::add_pointer_t<AutofocusReason>>(_a[1])),(*reinterpret_cast<std::add_pointer_t<QString>>(_a[2])),(*reinterpret_cast<std::add_pointer_t<QString>>(_a[3]))); break;
        case 9: _t->resetFocusFrame((*reinterpret_cast<std::add_pointer_t<QString>>(_a[1]))); break;
        case 10: _t->abortFocus((*reinterpret_cast<std::add_pointer_t<QString>>(_a[1]))); break;
        case 11: _t->adaptiveFocus((*reinterpret_cast<std::add_pointer_t<QString>>(_a[1]))); break;
        case 12: _t->suspendGuiding(); break;
        case 13: _t->resumeGuiding(); break;
        case 14: _t->dither(); break;
        case 15: _t->resetNonGuidedDither(); break;
        case 16: _t->captureTarget((*reinterpret_cast<std::add_pointer_t<QString>>(_a[1]))); break;
        case 17: _t->newImage((*reinterpret_cast<std::add_pointer_t<QSharedPointer<SequenceJob>>>(_a[1])),(*reinterpret_cast<std::add_pointer_t<QSharedPointer<FITSData>>>(_a[2])),(*reinterpret_cast<std::add_pointer_t<QString>>(_a[3]))); break;
        case 18: _t->newExposureProgress((*reinterpret_cast<std::add_pointer_t<QSharedPointer<SequenceJob>>>(_a[1])),(*reinterpret_cast<std::add_pointer_t<QString>>(_a[2]))); break;
        case 19: _t->newDownloadProgress((*reinterpret_cast<std::add_pointer_t<double>>(_a[1])),(*reinterpret_cast<std::add_pointer_t<QString>>(_a[2]))); break;
        case 20: _t->sequenceChanged((*reinterpret_cast<std::add_pointer_t<QJsonArray>>(_a[1]))); break;
        case 21: _t->settingsUpdated((*reinterpret_cast<std::add_pointer_t<QVariantMap>>(_a[1]))); break;
        case 22: _t->newLocalPreview((*reinterpret_cast<std::add_pointer_t<QString>>(_a[1]))); break;
        case 23: _t->dslrInfoRequested((*reinterpret_cast<std::add_pointer_t<QString>>(_a[1]))); break;
        case 24: _t->driverTimedout((*reinterpret_cast<std::add_pointer_t<QString>>(_a[1]))); break;
        case 25: _t->captureStarting((*reinterpret_cast<std::add_pointer_t<double>>(_a[1])),(*reinterpret_cast<std::add_pointer_t<QString>>(_a[2]))); break;
        case 26: _t->captureAborted((*reinterpret_cast<std::add_pointer_t<double>>(_a[1]))); break;
        case 27: _t->filterManagerUpdated((*reinterpret_cast<std::add_pointer_t<ISD::FilterWheel*>>(_a[1]))); break;
        case 28: _t->trainChanged(); break;
        case 29: { QString _r = _t->start((*reinterpret_cast<std::add_pointer_t<QString>>(_a[1])));
            if (_a[0]) *reinterpret_cast<QString*>(_a[0]) = std::move(_r); }  break;
        case 30: { QString _r = _t->start();
            if (_a[0]) *reinterpret_cast<QString*>(_a[0]) = std::move(_r); }  break;
        case 31: _t->stop((*reinterpret_cast<std::add_pointer_t<CaptureState>>(_a[1]))); break;
        case 32: _t->stop(); break;
        case 33: _t->abort((*reinterpret_cast<std::add_pointer_t<QString>>(_a[1]))); break;
        case 34: _t->abort(); break;
        case 35: _t->suspend(); break;
        case 36: _t->pause(); break;
        case 37: _t->toggleSequence(); break;
        case 38: _t->toggleVideo((*reinterpret_cast<std::add_pointer_t<bool>>(_a[1]))); break;
        case 39: _t->restartCamera((*reinterpret_cast<std::add_pointer_t<QString>>(_a[1]))); break;
        case 40: _t->setTargetName((*reinterpret_cast<std::add_pointer_t<QString>>(_a[1]))); break;
        case 41: { QString _r = _t->getTargetName();
            if (_a[0]) *reinterpret_cast<QString*>(_a[0]) = std::move(_r); }  break;
        case 42: _t->setObserverName((*reinterpret_cast<std::add_pointer_t<QString>>(_a[1]))); break;
        case 43: { QString _r = _t->getObserverName();
            if (_a[0]) *reinterpret_cast<QString*>(_a[0]) = std::move(_r); }  break;
        case 44: { bool _r = _t->setPicturesDirectory((*reinterpret_cast<std::add_pointer_t<QString>>(_a[1])));
            if (_a[0]) *reinterpret_cast<bool*>(_a[0]) = std::move(_r); }  break;
        case 45: { QString _r = _t->getPicturesDirectory();
            if (_a[0]) *reinterpret_cast<QString*>(_a[0]) = std::move(_r); }  break;
        case 46: { QString _r = _t->mainCameraDeviceName();
            if (_a[0]) *reinterpret_cast<QString*>(_a[0]) = std::move(_r); }  break;
        case 47: { QSharedPointer<CameraProcess> _r = _t->process();
            if (_a[0]) *reinterpret_cast<QSharedPointer<CameraProcess>*>(_a[0]) = std::move(_r); }  break;
        case 48: _t->updateTargetDistance((*reinterpret_cast<std::add_pointer_t<double>>(_a[1]))); break;
        case 49: _t->setMeridianFlipState((*reinterpret_cast<std::add_pointer_t<QSharedPointer<MeridianFlipState>>>(_a[1]))); break;
        case 50: _t->setGuideDeviation((*reinterpret_cast<std::add_pointer_t<double>>(_a[1])),(*reinterpret_cast<std::add_pointer_t<double>>(_a[2]))); break;
        case 51: _t->setGuideChip((*reinterpret_cast<std::add_pointer_t<ISD::CameraChip*>>(_a[1]))); break;
        case 52: _t->setFocusStatus((*reinterpret_cast<std::add_pointer_t<FocusState>>(_a[1])),(*reinterpret_cast<std::add_pointer_t<QString>>(_a[2]))); break;
        case 53: _t->focusAdaptiveComplete((*reinterpret_cast<std::add_pointer_t<bool>>(_a[1])),(*reinterpret_cast<std::add_pointer_t<QString>>(_a[2]))); break;
        case 54: _t->setFocusTemperatureDelta((*reinterpret_cast<std::add_pointer_t<double>>(_a[1])),(*reinterpret_cast<std::add_pointer_t<double>>(_a[2])),(*reinterpret_cast<std::add_pointer_t<QString>>(_a[3]))); break;
        case 55: _t->setHFR((*reinterpret_cast<std::add_pointer_t<double>>(_a[1])),(*reinterpret_cast<std::add_pointer_t<int>>(_a[2])),(*reinterpret_cast<std::add_pointer_t<bool>>(_a[3])),(*reinterpret_cast<std::add_pointer_t<QString>>(_a[4]))); break;
        case 56: _t->inSequenceAFRequested((*reinterpret_cast<std::add_pointer_t<bool>>(_a[1])),(*reinterpret_cast<std::add_pointer_t<QString>>(_a[2]))); break;
        case 57: _t->setGuideStatus((*reinterpret_cast<std::add_pointer_t<GuideState>>(_a[1]))); break;
        case 58: _t->setAlignStatus((*reinterpret_cast<std::add_pointer_t<Ekos::AlignState>>(_a[1]))); break;
        case 59: _t->setAlignResults((*reinterpret_cast<std::add_pointer_t<double>>(_a[1])),(*reinterpret_cast<std::add_pointer_t<double>>(_a[2])),(*reinterpret_cast<std::add_pointer_t<double>>(_a[3])),(*reinterpret_cast<std::add_pointer_t<double>>(_a[4]))); break;
        case 60: _t->commandRotator((*reinterpret_cast<std::add_pointer_t<double>>(_a[1]))); break;
        case 61: _t->setMountStatus((*reinterpret_cast<std::add_pointer_t<ISD::Mount::Status>>(_a[1]))); break;
        case 62: _t->clearLog(); break;
        case 63: _t->appendLogText((*reinterpret_cast<std::add_pointer_t<QString>>(_a[1]))); break;
        case 64: { QString _r = _t->camera();
            if (_a[0]) *reinterpret_cast<QString*>(_a[0]) = std::move(_r); }  break;
        case 65: { QString _r = _t->filterWheel();
            if (_a[0]) *reinterpret_cast<QString*>(_a[0]) = std::move(_r); }  break;
        case 66: { bool _r = _t->setFilter((*reinterpret_cast<std::add_pointer_t<QString>>(_a[1])));
            if (_a[0]) *reinterpret_cast<bool*>(_a[0]) = std::move(_r); }  break;
        case 67: { QString _r = _t->filter();
            if (_a[0]) *reinterpret_cast<QString*>(_a[0]) = std::move(_r); }  break;
        case 68: _t->clearSequenceQueue(); break;
        case 69: { QString _r = _t->getSequenceQueueStatus();
            if (_a[0]) *reinterpret_cast<QString*>(_a[0]) = std::move(_r); }  break;
        case 70: { bool _r = _t->loadSequenceQueue((*reinterpret_cast<std::add_pointer_t<QString>>(_a[1])),(*reinterpret_cast<std::add_pointer_t<QString>>(_a[2])),(*reinterpret_cast<std::add_pointer_t<bool>>(_a[3])),(*reinterpret_cast<std::add_pointer_t<QString>>(_a[4])));
            if (_a[0]) *reinterpret_cast<bool*>(_a[0]) = std::move(_r); }  break;
        case 71: { bool _r = _t->loadSequenceQueue((*reinterpret_cast<std::add_pointer_t<QString>>(_a[1])),(*reinterpret_cast<std::add_pointer_t<QString>>(_a[2])),(*reinterpret_cast<std::add_pointer_t<bool>>(_a[3])));
            if (_a[0]) *reinterpret_cast<bool*>(_a[0]) = std::move(_r); }  break;
        case 72: { bool _r = _t->loadSequenceQueue((*reinterpret_cast<std::add_pointer_t<QString>>(_a[1])),(*reinterpret_cast<std::add_pointer_t<QString>>(_a[2])));
            if (_a[0]) *reinterpret_cast<bool*>(_a[0]) = std::move(_r); }  break;
        case 73: { bool _r = _t->loadSequenceQueue((*reinterpret_cast<std::add_pointer_t<QString>>(_a[1])));
            if (_a[0]) *reinterpret_cast<bool*>(_a[0]) = std::move(_r); }  break;
        case 74: { bool _r = _t->saveSequenceQueue((*reinterpret_cast<std::add_pointer_t<QString>>(_a[1])));
            if (_a[0]) *reinterpret_cast<bool*>(_a[0]) = std::move(_r); }  break;
        case 75: _t->setMaximumGuidingDeviation((*reinterpret_cast<std::add_pointer_t<bool>>(_a[1])),(*reinterpret_cast<std::add_pointer_t<double>>(_a[2]))); break;
        case 76: _t->setInSequenceFocus((*reinterpret_cast<std::add_pointer_t<bool>>(_a[1])),(*reinterpret_cast<std::add_pointer_t<double>>(_a[2]))); break;
        case 77: { bool _r = _t->hasCoolerControl();
            if (_a[0]) *reinterpret_cast<bool*>(_a[0]) = std::move(_r); }  break;
        case 78: { bool _r = _t->setCoolerControl((*reinterpret_cast<std::add_pointer_t<bool>>(_a[1])));
            if (_a[0]) *reinterpret_cast<bool*>(_a[0]) = std::move(_r); }  break;
        case 79: { double _r = _t->getProgressPercentage();
            if (_a[0]) *reinterpret_cast<double*>(_a[0]) = std::move(_r); }  break;
        case 80: { bool _r = _t->isActiveJobPreview();
            if (_a[0]) *reinterpret_cast<bool*>(_a[0]) = std::move(_r); }  break;
        case 81: { int _r = _t->getJobCount();
            if (_a[0]) *reinterpret_cast<int*>(_a[0]) = std::move(_r); }  break;
        case 82: { int _r = _t->getPendingJobCount();
            if (_a[0]) *reinterpret_cast<int*>(_a[0]) = std::move(_r); }  break;
        case 83: { int _r = _t->getActiveJobID();
            if (_a[0]) *reinterpret_cast<int*>(_a[0]) = std::move(_r); }  break;
        case 84: { int _r = _t->getActiveJobRemainingTime();
            if (_a[0]) *reinterpret_cast<int*>(_a[0]) = std::move(_r); }  break;
        case 85: { int _r = _t->getOverallRemainingTime();
            if (_a[0]) *reinterpret_cast<int*>(_a[0]) = std::move(_r); }  break;
        case 86: { QString _r = _t->getJobState((*reinterpret_cast<std::add_pointer_t<int>>(_a[1])));
            if (_a[0]) *reinterpret_cast<QString*>(_a[0]) = std::move(_r); }  break;
        case 87: { QString _r = _t->getJobFilterName((*reinterpret_cast<std::add_pointer_t<int>>(_a[1])));
            if (_a[0]) *reinterpret_cast<QString*>(_a[0]) = std::move(_r); }  break;
        case 88: { int _r = _t->getJobImageProgress((*reinterpret_cast<std::add_pointer_t<int>>(_a[1])));
            if (_a[0]) *reinterpret_cast<int*>(_a[0]) = std::move(_r); }  break;
        case 89: { int _r = _t->getJobImageCount((*reinterpret_cast<std::add_pointer_t<int>>(_a[1])));
            if (_a[0]) *reinterpret_cast<int*>(_a[0]) = std::move(_r); }  break;
        case 90: { double _r = _t->getJobExposureProgress((*reinterpret_cast<std::add_pointer_t<int>>(_a[1])));
            if (_a[0]) *reinterpret_cast<double*>(_a[0]) = std::move(_r); }  break;
        case 91: { double _r = _t->getJobExposureDuration((*reinterpret_cast<std::add_pointer_t<int>>(_a[1])));
            if (_a[0]) *reinterpret_cast<double*>(_a[0]) = std::move(_r); }  break;
        case 92: { CCDFrameType _r = _t->getJobFrameType((*reinterpret_cast<std::add_pointer_t<int>>(_a[1])));
            if (_a[0]) *reinterpret_cast<CCDFrameType*>(_a[0]) = std::move(_r); }  break;
        case 93: { QString _r = _t->getJobPlaceholderFormat();
            if (_a[0]) *reinterpret_cast<QString*>(_a[0]) = std::move(_r); }  break;
        case 94: { QString _r = _t->getJobPreviewFileName();
            if (_a[0]) *reinterpret_cast<QString*>(_a[0]) = std::move(_r); }  break;
        case 95: _t->clearAutoFocusHFR((*reinterpret_cast<std::add_pointer_t<QString>>(_a[1]))); break;
        case 96: _t->ignoreSequenceHistory(); break;
        case 97: _t->setCapturedFramesMap((*reinterpret_cast<std::add_pointer_t<QString>>(_a[1])),(*reinterpret_cast<std::add_pointer_t<int>>(_a[2])),(*reinterpret_cast<std::add_pointer_t<QString>>(_a[3]))); break;
        case 98: _t->setCapturedFramesMap((*reinterpret_cast<std::add_pointer_t<QString>>(_a[1])),(*reinterpret_cast<std::add_pointer_t<int>>(_a[2]))); break;
        case 99: { QStringList _r = _t->logText();
            if (_a[0]) *reinterpret_cast<QStringList*>(_a[0]) = std::move(_r); }  break;
        case 100: { QString _r = _t->getLogText();
            if (_a[0]) *reinterpret_cast<QString*>(_a[0]) = std::move(_r); }  break;
        case 101: { CaptureState _r = _t->status();
            if (_a[0]) *reinterpret_cast<CaptureState*>(_a[0]) = std::move(_r); }  break;
        case 102: { int _r = _t->findCameraPosition((*reinterpret_cast<std::add_pointer_t<QString>>(_a[1])),(*reinterpret_cast<std::add_pointer_t<bool>>(_a[2])));
            if (_a[0]) *reinterpret_cast<int*>(_a[0]) = std::move(_r); }  break;
        default: ;
        }
    }
    if (_c == QMetaObject::RegisterMethodArgumentMetaType) {
        switch (_id) {
        default: *reinterpret_cast<QMetaType *>(_a[0]) = QMetaType(); break;
        case 17:
            switch (*reinterpret_cast<int*>(_a[1])) {
            default: *reinterpret_cast<QMetaType *>(_a[0]) = QMetaType(); break;
            case 1:
                *reinterpret_cast<QMetaType *>(_a[0]) = QMetaType::fromType< QSharedPointer<FITSData> >(); break;
            case 0:
                *reinterpret_cast<QMetaType *>(_a[0]) = QMetaType::fromType< QSharedPointer<SequenceJob> >(); break;
            }
            break;
        case 18:
            switch (*reinterpret_cast<int*>(_a[1])) {
            default: *reinterpret_cast<QMetaType *>(_a[0]) = QMetaType(); break;
            case 0:
                *reinterpret_cast<QMetaType *>(_a[0]) = QMetaType::fromType< QSharedPointer<SequenceJob> >(); break;
            }
            break;
        case 27:
            switch (*reinterpret_cast<int*>(_a[1])) {
            default: *reinterpret_cast<QMetaType *>(_a[0]) = QMetaType(); break;
            case 0:
                *reinterpret_cast<QMetaType *>(_a[0]) = QMetaType::fromType< ISD::FilterWheel* >(); break;
            }
            break;
        case 49:
            switch (*reinterpret_cast<int*>(_a[1])) {
            default: *reinterpret_cast<QMetaType *>(_a[0]) = QMetaType(); break;
            case 0:
                *reinterpret_cast<QMetaType *>(_a[0]) = QMetaType::fromType< QSharedPointer<MeridianFlipState> >(); break;
            }
            break;
        case 58:
            switch (*reinterpret_cast<int*>(_a[1])) {
            default: *reinterpret_cast<QMetaType *>(_a[0]) = QMetaType(); break;
            case 0:
                *reinterpret_cast<QMetaType *>(_a[0]) = QMetaType::fromType< Ekos::AlignState >(); break;
            }
            break;
        case 61:
            switch (*reinterpret_cast<int*>(_a[1])) {
            default: *reinterpret_cast<QMetaType *>(_a[0]) = QMetaType(); break;
            case 0:
                *reinterpret_cast<QMetaType *>(_a[0]) = QMetaType::fromType< ISD::Mount::Status >(); break;
            }
            break;
        }
    }
    if (_c == QMetaObject::IndexOfMethod) {
        if (QtMocHelpers::indexOfMethod<void (Capture::*)(const QString & )>(_a, &Capture::newLog, 0))
            return;
        if (QtMocHelpers::indexOfMethod<void (Capture::*)(const QString & )>(_a, &Capture::meridianFlipStarted, 1))
            return;
        if (QtMocHelpers::indexOfMethod<void (Capture::*)()>(_a, &Capture::guideAfterMeridianFlip, 2))
            return;
        if (QtMocHelpers::indexOfMethod<void (Capture::*)(CaptureState , const QString & , int )>(_a, &Capture::newStatus, 3))
            return;
        if (QtMocHelpers::indexOfMethod<void (Capture::*)(const QVariantMap & , const QString & )>(_a, &Capture::captureComplete, 4))
            return;
        if (QtMocHelpers::indexOfMethod<void (Capture::*)(FilterState )>(_a, &Capture::newFilterStatus, 5))
            return;
        if (QtMocHelpers::indexOfMethod<void (Capture::*)()>(_a, &Capture::ready, 6))
            return;
        if (QtMocHelpers::indexOfMethod<void (Capture::*)(double , const QString & )>(_a, &Capture::checkFocus, 7))
            return;
        if (QtMocHelpers::indexOfMethod<void (Capture::*)(AutofocusReason , const QString & , const QString & )>(_a, &Capture::runAutoFocus, 8))
            return;
        if (QtMocHelpers::indexOfMethod<void (Capture::*)(const QString & )>(_a, &Capture::resetFocusFrame, 9))
            return;
        if (QtMocHelpers::indexOfMethod<void (Capture::*)(const QString & )>(_a, &Capture::abortFocus, 10))
            return;
        if (QtMocHelpers::indexOfMethod<void (Capture::*)(const QString & )>(_a, &Capture::adaptiveFocus, 11))
            return;
        if (QtMocHelpers::indexOfMethod<void (Capture::*)()>(_a, &Capture::suspendGuiding, 12))
            return;
        if (QtMocHelpers::indexOfMethod<void (Capture::*)()>(_a, &Capture::resumeGuiding, 13))
            return;
        if (QtMocHelpers::indexOfMethod<void (Capture::*)()>(_a, &Capture::dither, 14))
            return;
        if (QtMocHelpers::indexOfMethod<void (Capture::*)()>(_a, &Capture::resetNonGuidedDither, 15))
            return;
        if (QtMocHelpers::indexOfMethod<void (Capture::*)(QString )>(_a, &Capture::captureTarget, 16))
            return;
        if (QtMocHelpers::indexOfMethod<void (Capture::*)(const QSharedPointer<SequenceJob> & , const QSharedPointer<FITSData> & , const QString & )>(_a, &Capture::newImage, 17))
            return;
        if (QtMocHelpers::indexOfMethod<void (Capture::*)(const QSharedPointer<SequenceJob> & , const QString & )>(_a, &Capture::newExposureProgress, 18))
            return;
        if (QtMocHelpers::indexOfMethod<void (Capture::*)(double , const QString & )>(_a, &Capture::newDownloadProgress, 19))
            return;
        if (QtMocHelpers::indexOfMethod<void (Capture::*)(const QJsonArray & )>(_a, &Capture::sequenceChanged, 20))
            return;
        if (QtMocHelpers::indexOfMethod<void (Capture::*)(const QVariantMap & )>(_a, &Capture::settingsUpdated, 21))
            return;
        if (QtMocHelpers::indexOfMethod<void (Capture::*)(const QString & )>(_a, &Capture::newLocalPreview, 22))
            return;
        if (QtMocHelpers::indexOfMethod<void (Capture::*)(const QString & )>(_a, &Capture::dslrInfoRequested, 23))
            return;
        if (QtMocHelpers::indexOfMethod<void (Capture::*)(const QString & )>(_a, &Capture::driverTimedout, 24))
            return;
        if (QtMocHelpers::indexOfMethod<void (Capture::*)(double , const QString & )>(_a, &Capture::captureStarting, 25))
            return;
        if (QtMocHelpers::indexOfMethod<void (Capture::*)(double )>(_a, &Capture::captureAborted, 26))
            return;
        if (QtMocHelpers::indexOfMethod<void (Capture::*)(ISD::FilterWheel * )>(_a, &Capture::filterManagerUpdated, 27))
            return;
        if (QtMocHelpers::indexOfMethod<void (Capture::*)()>(_a, &Capture::trainChanged, 28))
            return;
    }
    if (_c == QMetaObject::RegisterPropertyMetaType) {
        switch (_id) {
        default: *reinterpret_cast<int*>(_a[0]) = -1; break;
        case 0:
            *reinterpret_cast<int*>(_a[0]) = qRegisterMetaType< Ekos::CaptureState >(); break;
        }
    }
    if (_c == QMetaObject::ReadProperty) {
        void *_v = _a[0];
        switch (_id) {
        case 0: *reinterpret_cast<Ekos::CaptureState*>(_v) = _t->status(); break;
        case 1: *reinterpret_cast<QString*>(_v) = _t->getTargetName(); break;
        case 2: *reinterpret_cast<QString*>(_v) = _t->getObserverName(); break;
        case 3: *reinterpret_cast<QString*>(_v) = _t->opticalTrain(); break;
        case 4: *reinterpret_cast<QString*>(_v) = _t->camera(); break;
        case 5: *reinterpret_cast<QString*>(_v) = _t->filterWheel(); break;
        case 6: *reinterpret_cast<QString*>(_v) = _t->filter(); break;
        case 7: *reinterpret_cast<bool*>(_v) = _t->hasCoolerControl(); break;
        case 8: *reinterpret_cast<QStringList*>(_v) = _t->logText(); break;
        default: break;
        }
    }
    if (_c == QMetaObject::WriteProperty) {
        void *_v = _a[0];
        switch (_id) {
        case 1: _t->setTargetName(*reinterpret_cast<QString*>(_v)); break;
        case 2: _t->setObserverName(*reinterpret_cast<QString*>(_v)); break;
        case 3: _t->setOpticalTrain(*reinterpret_cast<QString*>(_v)); break;
        case 6: _t->setFilter(*reinterpret_cast<QString*>(_v)); break;
        case 7: _t->setCoolerControl(*reinterpret_cast<bool*>(_v)); break;
        default: break;
        }
    }
}

const QMetaObject *Ekos::Capture::metaObject() const
{
    return QObject::d_ptr->metaObject ? QObject::d_ptr->dynamicMetaObject() : &staticMetaObject;
}

void *Ekos::Capture::qt_metacast(const char *_clname)
{
    if (!_clname) return nullptr;
    if (!strcmp(_clname, qt_staticMetaObjectStaticContent<qt_meta_tag_ZN4Ekos7CaptureE_t>.strings))
        return static_cast<void*>(this);
    if (!strcmp(_clname, "Ui::Capture"))
        return static_cast< Ui::Capture*>(this);
    return QWidget::qt_metacast(_clname);
}

int Ekos::Capture::qt_metacall(QMetaObject::Call _c, int _id, void **_a)
{
    _id = QWidget::qt_metacall(_c, _id, _a);
    if (_id < 0)
        return _id;
    if (_c == QMetaObject::InvokeMetaMethod) {
        if (_id < 103)
            qt_static_metacall(this, _c, _id, _a);
        _id -= 103;
    }
    if (_c == QMetaObject::RegisterMethodArgumentMetaType) {
        if (_id < 103)
            qt_static_metacall(this, _c, _id, _a);
        _id -= 103;
    }
    if (_c == QMetaObject::ReadProperty || _c == QMetaObject::WriteProperty
            || _c == QMetaObject::ResetProperty || _c == QMetaObject::BindableProperty
            || _c == QMetaObject::RegisterPropertyMetaType) {
        qt_static_metacall(this, _c, _id, _a);
        _id -= 9;
    }
    return _id;
}

// SIGNAL 0
void Ekos::Capture::newLog(const QString & _t1)
{
    QMetaObject::activate<void>(this, &staticMetaObject, 0, nullptr, _t1);
}

// SIGNAL 1
void Ekos::Capture::meridianFlipStarted(const QString & _t1)
{
    QMetaObject::activate<void>(this, &staticMetaObject, 1, nullptr, _t1);
}

// SIGNAL 2
void Ekos::Capture::guideAfterMeridianFlip()
{
    QMetaObject::activate(this, &staticMetaObject, 2, nullptr);
}

// SIGNAL 3
void Ekos::Capture::newStatus(CaptureState _t1, const QString & _t2, int _t3)
{
    QMetaObject::activate<void>(this, &staticMetaObject, 3, nullptr, _t1, _t2, _t3);
}

// SIGNAL 4
void Ekos::Capture::captureComplete(const QVariantMap & _t1, const QString & _t2)
{
    QMetaObject::activate<void>(this, &staticMetaObject, 4, nullptr, _t1, _t2);
}

// SIGNAL 5
void Ekos::Capture::newFilterStatus(FilterState _t1)
{
    QMetaObject::activate<void>(this, &staticMetaObject, 5, nullptr, _t1);
}

// SIGNAL 6
void Ekos::Capture::ready()
{
    QMetaObject::activate(this, &staticMetaObject, 6, nullptr);
}

// SIGNAL 7
void Ekos::Capture::checkFocus(double _t1, const QString & _t2)
{
    QMetaObject::activate<void>(this, &staticMetaObject, 7, nullptr, _t1, _t2);
}

// SIGNAL 8
void Ekos::Capture::runAutoFocus(AutofocusReason _t1, const QString & _t2, const QString & _t3)
{
    QMetaObject::activate<void>(this, &staticMetaObject, 8, nullptr, _t1, _t2, _t3);
}

// SIGNAL 9
void Ekos::Capture::resetFocusFrame(const QString & _t1)
{
    QMetaObject::activate<void>(this, &staticMetaObject, 9, nullptr, _t1);
}

// SIGNAL 10
void Ekos::Capture::abortFocus(const QString & _t1)
{
    QMetaObject::activate<void>(this, &staticMetaObject, 10, nullptr, _t1);
}

// SIGNAL 11
void Ekos::Capture::adaptiveFocus(const QString & _t1)
{
    QMetaObject::activate<void>(this, &staticMetaObject, 11, nullptr, _t1);
}

// SIGNAL 12
void Ekos::Capture::suspendGuiding()
{
    QMetaObject::activate(this, &staticMetaObject, 12, nullptr);
}

// SIGNAL 13
void Ekos::Capture::resumeGuiding()
{
    QMetaObject::activate(this, &staticMetaObject, 13, nullptr);
}

// SIGNAL 14
void Ekos::Capture::dither()
{
    QMetaObject::activate(this, &staticMetaObject, 14, nullptr);
}

// SIGNAL 15
void Ekos::Capture::resetNonGuidedDither()
{
    QMetaObject::activate(this, &staticMetaObject, 15, nullptr);
}

// SIGNAL 16
void Ekos::Capture::captureTarget(QString _t1)
{
    QMetaObject::activate<void>(this, &staticMetaObject, 16, nullptr, _t1);
}

// SIGNAL 17
void Ekos::Capture::newImage(const QSharedPointer<SequenceJob> & _t1, const QSharedPointer<FITSData> & _t2, const QString & _t3)
{
    QMetaObject::activate<void>(this, &staticMetaObject, 17, nullptr, _t1, _t2, _t3);
}

// SIGNAL 18
void Ekos::Capture::newExposureProgress(const QSharedPointer<SequenceJob> & _t1, const QString & _t2)
{
    QMetaObject::activate<void>(this, &staticMetaObject, 18, nullptr, _t1, _t2);
}

// SIGNAL 19
void Ekos::Capture::newDownloadProgress(double _t1, const QString & _t2)
{
    QMetaObject::activate<void>(this, &staticMetaObject, 19, nullptr, _t1, _t2);
}

// SIGNAL 20
void Ekos::Capture::sequenceChanged(const QJsonArray & _t1)
{
    QMetaObject::activate<void>(this, &staticMetaObject, 20, nullptr, _t1);
}

// SIGNAL 21
void Ekos::Capture::settingsUpdated(const QVariantMap & _t1)
{
    QMetaObject::activate<void>(this, &staticMetaObject, 21, nullptr, _t1);
}

// SIGNAL 22
void Ekos::Capture::newLocalPreview(const QString & _t1)
{
    QMetaObject::activate<void>(this, &staticMetaObject, 22, nullptr, _t1);
}

// SIGNAL 23
void Ekos::Capture::dslrInfoRequested(const QString & _t1)
{
    QMetaObject::activate<void>(this, &staticMetaObject, 23, nullptr, _t1);
}

// SIGNAL 24
void Ekos::Capture::driverTimedout(const QString & _t1)
{
    QMetaObject::activate<void>(this, &staticMetaObject, 24, nullptr, _t1);
}

// SIGNAL 25
void Ekos::Capture::captureStarting(double _t1, const QString & _t2)
{
    QMetaObject::activate<void>(this, &staticMetaObject, 25, nullptr, _t1, _t2);
}

// SIGNAL 26
void Ekos::Capture::captureAborted(double _t1)
{
    QMetaObject::activate<void>(this, &staticMetaObject, 26, nullptr, _t1);
}

// SIGNAL 27
void Ekos::Capture::filterManagerUpdated(ISD::FilterWheel * _t1)
{
    QMetaObject::activate<void>(this, &staticMetaObject, 27, nullptr, _t1);
}

// SIGNAL 28
void Ekos::Capture::trainChanged()
{
    QMetaObject::activate(this, &staticMetaObject, 28, nullptr);
}
QT_WARNING_POP
