/********************************************************************************
** Form generated from reading UI file 'capture.ui'
**
** Created by: Qt User Interface Compiler version 6.11.1
**
** WARNING! All changes made in this file will be lost when recompiling UI file!
********************************************************************************/

#ifndef UI_CAPTURE_H
#define UI_CAPTURE_H

#include <QtCore/QVariant>
#include <QtWidgets/QApplication>
#include <QtWidgets/QTabWidget>
#include <QtWidgets/QVBoxLayout>
#include <QtWidgets/QWidget>
#include <klocalizedstring.h>

QT_BEGIN_NAMESPACE

class Ui_Capture
{
public:
    QVBoxLayout *wholeLayout;
    QTabWidget *cameraTabs;

    void setupUi(QWidget *Capture)
    {
        if (Capture->objectName().isEmpty())
            Capture->setObjectName("Capture");
        Capture->resize(815, 539);
        wholeLayout = new QVBoxLayout(Capture);
        wholeLayout->setObjectName("wholeLayout");
        cameraTabs = new QTabWidget(Capture);
        cameraTabs->setObjectName("cameraTabs");
        cameraTabs->setTabsClosable(true);

        wholeLayout->addWidget(cameraTabs);


        retranslateUi(Capture);

        cameraTabs->setCurrentIndex(-1);


        QMetaObject::connectSlotsByName(Capture);
    } // setupUi

    void retranslateUi(QWidget *Capture)
    {
        (void)Capture;
    } // retranslateUi

};

namespace Ui {
    class Capture: public Ui_Capture {};
} // namespace Ui

QT_END_NAMESPACE

#endif // CAPTURE_H

