/********************************************************************************
** Form generated from reading UI file 'captureprocessoverlay.ui'
**
** Created by: Qt User Interface Compiler version 6.11.1
**
** WARNING! All changes made in this file will be lost when recompiling UI file!
********************************************************************************/

#ifndef UI_CAPTUREPROCESSOVERLAY_H
#define UI_CAPTUREPROCESSOVERLAY_H

#include <QtCore/QVariant>
#include <QtGui/QIcon>
#include <QtWidgets/QApplication>
#include <QtWidgets/QGridLayout>
#include <QtWidgets/QHBoxLayout>
#include <QtWidgets/QLabel>
#include <QtWidgets/QPushButton>
#include <QtWidgets/QSpacerItem>
#include <QtWidgets/QTextEdit>
#include <QtWidgets/QVBoxLayout>
#include <QtWidgets/QWidget>
#include <klocalizedstring.h>

QT_BEGIN_NAMESPACE

class Ui_CaptureProcessOverlay
{
public:
    QVBoxLayout *verticalLayout;
    QHBoxLayout *horizontalLayout_2;
    QLabel *captureStatisticsHeader;
    QPushButton *updateStatisticsButton;
    QSpacerItem *horizontalSpacer_2;
    QTextEdit *captureStatisticsLabel;
    QWidget *frameDataWidget;
    QGridLayout *gridLayout;
    QLabel *offsetLabel;
    QLabel *offsetValue;
    QLabel *gainValue;
    QHBoxLayout *horizontalLayout;
    QPushButton *historyBackwardButton;
    QLabel *captureDate;
    QLabel *historyCountsLabel;
    QPushButton *historyForwardButton;
    QLabel *exposureLabel;
    QLabel *gainLabel;
    QLabel *exposureValue;
    QLabel *filenameValue;
    QLabel *isoValue;
    QHBoxLayout *horizontalLayout_3;
    QLabel *frameTypeLabel;
    QPushButton *deleteCurrentFrameButton;
    QSpacerItem *horizontalSpacer_3;
    QSpacerItem *horizontalSpacer;
    QLabel *geometryValue;
    QLabel *binningLabel;
    QLabel *binningValue;
    QLabel *targetDriftLabel;
    QLabel *targetDriftValue;

    void setupUi(QWidget *CaptureProcessOverlay)
    {
        if (CaptureProcessOverlay->objectName().isEmpty())
            CaptureProcessOverlay->setObjectName("CaptureProcessOverlay");
        CaptureProcessOverlay->resize(400, 276);
        CaptureProcessOverlay->setStyleSheet(QString::fromUtf8(""));
        verticalLayout = new QVBoxLayout(CaptureProcessOverlay);
        verticalLayout->setSpacing(2);
        verticalLayout->setObjectName("verticalLayout");
        verticalLayout->setContentsMargins(0, 30, 0, 0);
        horizontalLayout_2 = new QHBoxLayout();
        horizontalLayout_2->setSpacing(10);
        horizontalLayout_2->setObjectName("horizontalLayout_2");
        captureStatisticsHeader = new QLabel(CaptureProcessOverlay);
        captureStatisticsHeader->setObjectName("captureStatisticsHeader");
        QFont font;
        font.setBold(true);
        captureStatisticsHeader->setFont(font);

        horizontalLayout_2->addWidget(captureStatisticsHeader);

        updateStatisticsButton = new QPushButton(CaptureProcessOverlay);
        updateStatisticsButton->setObjectName("updateStatisticsButton");
        updateStatisticsButton->setMinimumSize(QSize(24, 24));
        updateStatisticsButton->setMaximumSize(QSize(24, 24));
        QIcon icon;
        QString iconThemeName = QString::fromUtf8("system-reboot");
        if (QIcon::hasThemeIcon(iconThemeName)) {
            icon = QIcon::fromTheme(iconThemeName);
        } else {
            icon.addFile(QString::fromUtf8("."), QSize(), QIcon::Mode::Normal, QIcon::State::Off);
        }
        updateStatisticsButton->setIcon(icon);
        updateStatisticsButton->setFlat(true);

        horizontalLayout_2->addWidget(updateStatisticsButton);

        horizontalSpacer_2 = new QSpacerItem(40, 20, QSizePolicy::Policy::Expanding, QSizePolicy::Policy::Minimum);

        horizontalLayout_2->addItem(horizontalSpacer_2);


        verticalLayout->addLayout(horizontalLayout_2);

        captureStatisticsLabel = new QTextEdit(CaptureProcessOverlay);
        captureStatisticsLabel->setObjectName("captureStatisticsLabel");
        captureStatisticsLabel->setAutoFillBackground(false);
        captureStatisticsLabel->setStyleSheet(QString::fromUtf8("background: transparent;"));
        captureStatisticsLabel->setFrameShape(QFrame::NoFrame);
        captureStatisticsLabel->setLineWidth(0);
        captureStatisticsLabel->setSizeAdjustPolicy(QAbstractScrollArea::AdjustToContents);
        captureStatisticsLabel->setUndoRedoEnabled(false);
        captureStatisticsLabel->setReadOnly(true);

        verticalLayout->addWidget(captureStatisticsLabel);

        frameDataWidget = new QWidget(CaptureProcessOverlay);
        frameDataWidget->setObjectName("frameDataWidget");
        frameDataWidget->setBaseSize(QSize(0, 0));
        gridLayout = new QGridLayout(frameDataWidget);
        gridLayout->setObjectName("gridLayout");
        gridLayout->setHorizontalSpacing(6);
        gridLayout->setVerticalSpacing(0);
        gridLayout->setContentsMargins(0, 0, 0, 0);
        offsetLabel = new QLabel(frameDataWidget);
        offsetLabel->setObjectName("offsetLabel");
        QFont font1;
        font1.setPointSize(8);
        offsetLabel->setFont(font1);

        gridLayout->addWidget(offsetLabel, 4, 2, 1, 1);

        offsetValue = new QLabel(frameDataWidget);
        offsetValue->setObjectName("offsetValue");
        offsetValue->setFont(font1);

        gridLayout->addWidget(offsetValue, 4, 3, 1, 2);

        gainValue = new QLabel(frameDataWidget);
        gainValue->setObjectName("gainValue");
        gainValue->setFont(font1);

        gridLayout->addWidget(gainValue, 4, 1, 1, 1);

        horizontalLayout = new QHBoxLayout();
        horizontalLayout->setSpacing(10);
        horizontalLayout->setObjectName("horizontalLayout");
        historyBackwardButton = new QPushButton(frameDataWidget);
        historyBackwardButton->setObjectName("historyBackwardButton");
        historyBackwardButton->setMinimumSize(QSize(24, 24));
        historyBackwardButton->setMaximumSize(QSize(24, 24));
        QIcon icon1;
        iconThemeName = QString::fromUtf8("media-seek-backward");
        if (QIcon::hasThemeIcon(iconThemeName)) {
            icon1 = QIcon::fromTheme(iconThemeName);
        } else {
            icon1.addFile(QString::fromUtf8("."), QSize(), QIcon::Mode::Normal, QIcon::State::Off);
        }
        historyBackwardButton->setIcon(icon1);
        historyBackwardButton->setFlat(true);

        horizontalLayout->addWidget(historyBackwardButton);

        captureDate = new QLabel(frameDataWidget);
        captureDate->setObjectName("captureDate");
        captureDate->setMinimumSize(QSize(0, 0));
        captureDate->setFont(font1);
        captureDate->setAlignment(Qt::AlignCenter);

        horizontalLayout->addWidget(captureDate);

        historyCountsLabel = new QLabel(frameDataWidget);
        historyCountsLabel->setObjectName("historyCountsLabel");
        historyCountsLabel->setFont(font1);

        horizontalLayout->addWidget(historyCountsLabel);

        historyForwardButton = new QPushButton(frameDataWidget);
        historyForwardButton->setObjectName("historyForwardButton");
        historyForwardButton->setMinimumSize(QSize(24, 24));
        historyForwardButton->setMaximumSize(QSize(24, 24));
        QIcon icon2;
        iconThemeName = QString::fromUtf8("media-seek-forward");
        if (QIcon::hasThemeIcon(iconThemeName)) {
            icon2 = QIcon::fromTheme(iconThemeName);
        } else {
            icon2.addFile(QString::fromUtf8("."), QSize(), QIcon::Mode::Normal, QIcon::State::Off);
        }
        historyForwardButton->setIcon(icon2);
        historyForwardButton->setFlat(true);

        horizontalLayout->addWidget(historyForwardButton);

        horizontalLayout->setStretch(1, 1);
        horizontalLayout->setStretch(2, 1);

        gridLayout->addLayout(horizontalLayout, 7, 0, 1, 5);

        exposureLabel = new QLabel(frameDataWidget);
        exposureLabel->setObjectName("exposureLabel");
        QFont font2;
        font2.setPointSize(8);
        font2.setBold(true);
        exposureLabel->setFont(font2);

        gridLayout->addWidget(exposureLabel, 2, 0, 1, 1);

        gainLabel = new QLabel(frameDataWidget);
        gainLabel->setObjectName("gainLabel");
        gainLabel->setFont(font1);

        gridLayout->addWidget(gainLabel, 4, 0, 1, 1);

        exposureValue = new QLabel(frameDataWidget);
        exposureValue->setObjectName("exposureValue");
        exposureValue->setFont(font2);

        gridLayout->addWidget(exposureValue, 2, 1, 1, 1);

        filenameValue = new QLabel(frameDataWidget);
        filenameValue->setObjectName("filenameValue");
        filenameValue->setFont(font1);

        gridLayout->addWidget(filenameValue, 6, 0, 1, 6);

        isoValue = new QLabel(frameDataWidget);
        isoValue->setObjectName("isoValue");
        isoValue->setFont(font1);

        gridLayout->addWidget(isoValue, 5, 0, 1, 5);

        horizontalLayout_3 = new QHBoxLayout();
        horizontalLayout_3->setSpacing(10);
        horizontalLayout_3->setObjectName("horizontalLayout_3");
        frameTypeLabel = new QLabel(frameDataWidget);
        frameTypeLabel->setObjectName("frameTypeLabel");
        frameTypeLabel->setFont(font);

        horizontalLayout_3->addWidget(frameTypeLabel);

        deleteCurrentFrameButton = new QPushButton(frameDataWidget);
        deleteCurrentFrameButton->setObjectName("deleteCurrentFrameButton");
        deleteCurrentFrameButton->setMinimumSize(QSize(24, 24));
        deleteCurrentFrameButton->setMaximumSize(QSize(24, 24));
        QIcon icon3;
        iconThemeName = QString::fromUtf8("user-trash");
        if (QIcon::hasThemeIcon(iconThemeName)) {
            icon3 = QIcon::fromTheme(iconThemeName);
        } else {
            icon3.addFile(QString::fromUtf8("."), QSize(), QIcon::Mode::Normal, QIcon::State::Off);
        }
        deleteCurrentFrameButton->setIcon(icon3);
        deleteCurrentFrameButton->setFlat(true);

        horizontalLayout_3->addWidget(deleteCurrentFrameButton);

        horizontalSpacer_3 = new QSpacerItem(40, 20, QSizePolicy::Policy::Expanding, QSizePolicy::Policy::Minimum);

        horizontalLayout_3->addItem(horizontalSpacer_3);


        gridLayout->addLayout(horizontalLayout_3, 0, 0, 1, 5);

        horizontalSpacer = new QSpacerItem(40, 20, QSizePolicy::Policy::Expanding, QSizePolicy::Policy::Minimum);

        gridLayout->addItem(horizontalSpacer, 0, 5, 1, 1);

        geometryValue = new QLabel(frameDataWidget);
        geometryValue->setObjectName("geometryValue");
        geometryValue->setFont(font1);

        gridLayout->addWidget(geometryValue, 3, 0, 1, 2);

        binningLabel = new QLabel(frameDataWidget);
        binningLabel->setObjectName("binningLabel");
        binningLabel->setFont(font1);

        gridLayout->addWidget(binningLabel, 3, 2, 1, 1);

        binningValue = new QLabel(frameDataWidget);
        binningValue->setObjectName("binningValue");
        binningValue->setFont(font1);

        gridLayout->addWidget(binningValue, 3, 3, 1, 1);

        targetDriftLabel = new QLabel(frameDataWidget);
        targetDriftLabel->setObjectName("targetDriftLabel");
        targetDriftLabel->setFont(font1);

        gridLayout->addWidget(targetDriftLabel, 2, 2, 1, 1);

        targetDriftValue = new QLabel(frameDataWidget);
        targetDriftValue->setObjectName("targetDriftValue");
        targetDriftValue->setFont(font1);

        gridLayout->addWidget(targetDriftValue, 2, 3, 1, 1);


        verticalLayout->addWidget(frameDataWidget);


        retranslateUi(CaptureProcessOverlay);

        QMetaObject::connectSlotsByName(CaptureProcessOverlay);
    } // setupUi

    void retranslateUi(QWidget *CaptureProcessOverlay)
    {
        CaptureProcessOverlay->setWindowTitle(QString());
        captureStatisticsHeader->setText(tr2i18n("Capture statistics", nullptr));
        updateStatisticsButton->setText(QString());
        offsetLabel->setText(tr2i18n("Offset:", nullptr));
        offsetValue->setText(tr2i18n("<offset>", nullptr));
        gainValue->setText(tr2i18n("<gain>", nullptr));
        historyBackwardButton->setText(QString());
        captureDate->setText(tr2i18n("dd.mm.yyyy hh:mm", nullptr));
        historyCountsLabel->setText(tr2i18n("(xx/yy)", nullptr));
        historyForwardButton->setText(QString());
        exposureLabel->setText(tr2i18n("Exposure:", nullptr));
        gainLabel->setText(tr2i18n("Gain:", nullptr));
        exposureValue->setText(tr2i18n("<exp>", nullptr));
        filenameValue->setText(tr2i18n("<Filename>", nullptr));
        isoValue->setText(tr2i18n("<ISO>", nullptr));
        frameTypeLabel->setText(tr2i18n("Light Red", nullptr));
#if QT_CONFIG(tooltip)
        deleteCurrentFrameButton->setToolTip(tr2i18n("<html><head/><body><p>Delete current frame</p></body></html>", nullptr));
#endif // QT_CONFIG(tooltip)
        deleteCurrentFrameButton->setText(QString());
        geometryValue->setText(tr2i18n("<width x height>", nullptr));
        binningLabel->setText(tr2i18n("Binning:", nullptr));
        binningValue->setText(tr2i18n("<bin>", nullptr));
        targetDriftLabel->setText(tr2i18n("Target Drift:", nullptr));
        targetDriftValue->setText(tr2i18n("<drift>", nullptr));
    } // retranslateUi

};

namespace Ui {
    class CaptureProcessOverlay: public Ui_CaptureProcessOverlay {};
} // namespace Ui

QT_END_NAMESPACE

#endif // CAPTUREPROCESSOVERLAY_H

