/********************************************************************************
** Form generated from reading UI file 'catalogobjecttypefilter.ui'
**
** Created by: Qt User Interface Compiler version 6.11.1
**
** WARNING! All changes made in this file will be lost when recompiling UI file!
********************************************************************************/

#ifndef UI_CATALOGOBJECTTYPEFILTER_H
#define UI_CATALOGOBJECTTYPEFILTER_H

#include <QtCore/QVariant>
#include <QtWidgets/QAbstractButton>
#include <QtWidgets/QApplication>
#include <QtWidgets/QDialog>
#include <QtWidgets/QDialogButtonBox>
#include <QtWidgets/QHBoxLayout>
#include <QtWidgets/QHeaderView>
#include <QtWidgets/QTreeWidget>
#include <QtWidgets/QVBoxLayout>
#include <klocalizedstring.h>

QT_BEGIN_NAMESPACE

class Ui_CatalogObjectTypeFilterUI
{
public:
    QVBoxLayout *verticalLayout;
    QTreeWidget *tree;
    QHBoxLayout *horizontalLayout;
    QDialogButtonBox *buttonBox;

    void setupUi(QDialog *CatalogObjectTypeFilterUI)
    {
        if (CatalogObjectTypeFilterUI->objectName().isEmpty())
            CatalogObjectTypeFilterUI->setObjectName("CatalogObjectTypeFilterUI");
        CatalogObjectTypeFilterUI->resize(444, 263);
        verticalLayout = new QVBoxLayout(CatalogObjectTypeFilterUI);
        verticalLayout->setObjectName("verticalLayout");
        tree = new QTreeWidget(CatalogObjectTypeFilterUI);
        QTreeWidgetItem *__qtreewidgetitem = new QTreeWidgetItem();
        __qtreewidgetitem->setText(3, QString::fromUtf8("Description"));
        __qtreewidgetitem->setText(2, QString::fromUtf8("Label"));
        __qtreewidgetitem->setText(0, QString::fromUtf8("Code"));
        tree->setHeaderItem(__qtreewidgetitem);
        tree->setObjectName("tree");
        tree->setSizeAdjustPolicy(QAbstractScrollArea::AdjustToContents);
        tree->setEditTriggers(QAbstractItemView::NoEditTriggers);
        tree->setAlternatingRowColors(true);
        tree->setSelectionMode(QAbstractItemView::NoSelection);
        tree->setIndentation(10);
        tree->setColumnCount(5);
        tree->header()->setCascadingSectionResizes(true);
        tree->header()->setProperty("showSortIndicator", QVariant(true));

        verticalLayout->addWidget(tree);

        horizontalLayout = new QHBoxLayout();
        horizontalLayout->setObjectName("horizontalLayout");
        buttonBox = new QDialogButtonBox(CatalogObjectTypeFilterUI);
        buttonBox->setObjectName("buttonBox");
        buttonBox->setOrientation(Qt::Horizontal);
        buttonBox->setStandardButtons(QDialogButtonBox::Apply|QDialogButtonBox::Close);
        buttonBox->setCenterButtons(false);

        horizontalLayout->addWidget(buttonBox);


        verticalLayout->addLayout(horizontalLayout);


        retranslateUi(CatalogObjectTypeFilterUI);
        QObject::connect(buttonBox, &QDialogButtonBox::accepted, CatalogObjectTypeFilterUI, qOverload<>(&QDialog::accept));
        QObject::connect(buttonBox, &QDialogButtonBox::rejected, CatalogObjectTypeFilterUI, qOverload<>(&QDialog::reject));

        QMetaObject::connectSlotsByName(CatalogObjectTypeFilterUI);
    } // setupUi

    void retranslateUi(QDialog *CatalogObjectTypeFilterUI)
    {
        CatalogObjectTypeFilterUI->setWindowTitle(tr2i18n("Catalog Object Type Filter", nullptr));
        QTreeWidgetItem *___qtreewidgetitem = tree->headerItem();
        ___qtreewidgetitem->setText(4, tr2i18n("Comments", nullptr));
        ___qtreewidgetitem->setText(1, tr2i18n("Cand Code", nullptr));
#if QT_CONFIG(tooltip)
        ___qtreewidgetitem->setToolTip(4, tr2i18n("Object Type Comments", nullptr));
        ___qtreewidgetitem->setToolTip(3, tr2i18n("Object Type Description", nullptr));
        ___qtreewidgetitem->setToolTip(2, tr2i18n("Object Type Label", nullptr));
        ___qtreewidgetitem->setToolTip(1, tr2i18n("Candidate Object Type Code", nullptr));
        ___qtreewidgetitem->setToolTip(0, tr2i18n("Object Type Code", nullptr));
#endif // QT_CONFIG(tooltip)
    } // retranslateUi

};

namespace Ui {
    class CatalogObjectTypeFilterUI: public Ui_CatalogObjectTypeFilterUI {};
} // namespace Ui

QT_END_NAMESPACE

#endif // CATALOGOBJECTTYPEFILTER_H

