/****************************************************************************
** Meta object code from reading C++ file 'fov.h'
**
** Created by: The Qt Meta Object Compiler version 69 (Qt 6.11.1)
**
** WARNING! All changes made in this file will be lost!
*****************************************************************************/

#include "../../../../kstars-3.8.4.1/kstars/auxiliary/fov.h"
#include <QtCore/qmetatype.h>

#include <QtCore/qtmochelpers.h>

#include <memory>


#include <QtCore/qxptype_traits.h>
#if !defined(Q_MOC_OUTPUT_REVISION)
#error "The header file 'fov.h' doesn't include <QObject>."
#elif Q_MOC_OUTPUT_REVISION != 69
#error "This file was generated using the moc from 6.11.1. It"
#error "cannot be used with the include files from this version of Qt."
#error "(The moc has changed too much.)"
#endif

#ifndef Q_CONSTINIT
#define Q_CONSTINIT
#endif

QT_WARNING_PUSH
QT_WARNING_DISABLE_DEPRECATED
QT_WARNING_DISABLE_GCC("-Wuseless-cast")
namespace {
struct qt_meta_tag_ZN3FOVE_t {};
} // unnamed namespace

template <> constexpr inline auto FOV::qt_create_metaobjectdata<qt_meta_tag_ZN3FOVE_t>()
{
    namespace QMC = QtMocConstants;
    QtMocHelpers::StringRefStorage qt_stringData {
        "FOV",
        "D-Bus Interface",
        "org.kde.kstars.fov",
        "name",
        "",
        "shape",
        "FOV::Shape",
        "sizeX",
        "sizeY",
        "offsetX",
        "offsetY",
        "PA",
        "color",
        "cpLock"
    };

    QtMocHelpers::UintData qt_methods {
        // Method 'name'
        QtMocHelpers::MethodData<QString() const>(3, 4, QMC::AccessPublic | QMC::MethodScriptable, QMetaType::QString),
    };
    QtMocHelpers::UintData qt_properties {
        // property 'name'
        QtMocHelpers::PropertyData<QString>(3, QMetaType::QString, QMC::DefaultPropertyFlags | QMC::Writable),
        // property 'shape'
        QtMocHelpers::PropertyData<FOV::Shape>(5, 0x80000000 | 6, QMC::DefaultPropertyFlags | QMC::Writable | QMC::EnumOrFlag),
        // property 'sizeX'
        QtMocHelpers::PropertyData<float>(7, QMetaType::Float, QMC::DefaultPropertyFlags | QMC::Writable),
        // property 'sizeY'
        QtMocHelpers::PropertyData<float>(8, QMetaType::Float, QMC::DefaultPropertyFlags | QMC::Writable),
        // property 'offsetX'
        QtMocHelpers::PropertyData<float>(9, QMetaType::Float, QMC::DefaultPropertyFlags | QMC::Writable),
        // property 'offsetY'
        QtMocHelpers::PropertyData<float>(10, QMetaType::Float, QMC::DefaultPropertyFlags | QMC::Writable),
        // property 'PA'
        QtMocHelpers::PropertyData<float>(11, QMetaType::Float, QMC::DefaultPropertyFlags | QMC::Writable),
        // property 'color'
        QtMocHelpers::PropertyData<QString>(12, QMetaType::QString, QMC::DefaultPropertyFlags | QMC::Writable),
        // property 'cpLock'
        QtMocHelpers::PropertyData<bool>(13, QMetaType::Bool, QMC::DefaultPropertyFlags | QMC::Writable),
    };
    QtMocHelpers::UintData qt_enums {
    };
    QtMocHelpers::UintData qt_constructors {};
    QtMocHelpers::ClassInfos qt_classinfo({
            {    1,    2 },
    });
    return QtMocHelpers::metaObjectData<FOV, qt_meta_tag_ZN3FOVE_t>(QMC::MetaObjectFlag{}, qt_stringData,
            qt_methods, qt_properties, qt_enums, qt_constructors, qt_classinfo);
}
Q_CONSTINIT const QMetaObject FOV::staticMetaObject = { {
    QMetaObject::SuperData::link<QObject::staticMetaObject>(),
    qt_staticMetaObjectStaticContent<qt_meta_tag_ZN3FOVE_t>.stringdata,
    qt_staticMetaObjectStaticContent<qt_meta_tag_ZN3FOVE_t>.data,
    qt_static_metacall,
    nullptr,
    qt_staticMetaObjectRelocatingContent<qt_meta_tag_ZN3FOVE_t>.metaTypes,
    nullptr
} };

void FOV::qt_static_metacall(QObject *_o, QMetaObject::Call _c, int _id, void **_a)
{
    auto *_t = static_cast<FOV *>(_o);
    if (_c == QMetaObject::InvokeMetaMethod) {
        switch (_id) {
        case 0: { QString _r = _t->name();
            if (_a[0]) *reinterpret_cast<QString*>(_a[0]) = std::move(_r); }  break;
        default: ;
        }
    }
    if (_c == QMetaObject::RegisterPropertyMetaType) {
        switch (_id) {
        default: *reinterpret_cast<int*>(_a[0]) = -1; break;
        case 1:
            *reinterpret_cast<int*>(_a[0]) = qRegisterMetaType< FOV::Shape >(); break;
        }
    }
    if (_c == QMetaObject::ReadProperty) {
        void *_v = _a[0];
        switch (_id) {
        case 0: *reinterpret_cast<QString*>(_v) = _t->m_name; break;
        case 1: *reinterpret_cast<FOV::Shape*>(_v) = _t->m_shape; break;
        case 2: *reinterpret_cast<float*>(_v) = _t->m_sizeX; break;
        case 3: *reinterpret_cast<float*>(_v) = _t->m_sizeY; break;
        case 4: *reinterpret_cast<float*>(_v) = _t->m_offsetX; break;
        case 5: *reinterpret_cast<float*>(_v) = _t->m_offsetY; break;
        case 6: *reinterpret_cast<float*>(_v) = _t->m_PA; break;
        case 7: *reinterpret_cast<QString*>(_v) = _t->m_color; break;
        case 8: *reinterpret_cast<bool*>(_v) = _t->m_lockCelestialPole; break;
        default: break;
        }
    }
    if (_c == QMetaObject::WriteProperty) {
        void *_v = _a[0];
        switch (_id) {
        case 0: QtMocHelpers::setProperty(_t->m_name, *reinterpret_cast<QString*>(_v)); break;
        case 1: QtMocHelpers::setProperty(_t->m_shape, *reinterpret_cast<FOV::Shape*>(_v)); break;
        case 2: QtMocHelpers::setProperty(_t->m_sizeX, *reinterpret_cast<float*>(_v)); break;
        case 3: QtMocHelpers::setProperty(_t->m_sizeY, *reinterpret_cast<float*>(_v)); break;
        case 4: QtMocHelpers::setProperty(_t->m_offsetX, *reinterpret_cast<float*>(_v)); break;
        case 5: QtMocHelpers::setProperty(_t->m_offsetY, *reinterpret_cast<float*>(_v)); break;
        case 6: QtMocHelpers::setProperty(_t->m_PA, *reinterpret_cast<float*>(_v)); break;
        case 7: QtMocHelpers::setProperty(_t->m_color, *reinterpret_cast<QString*>(_v)); break;
        case 8: QtMocHelpers::setProperty(_t->m_lockCelestialPole, *reinterpret_cast<bool*>(_v)); break;
        default: break;
        }
    }
}

const QMetaObject *FOV::metaObject() const
{
    return QObject::d_ptr->metaObject ? QObject::d_ptr->dynamicMetaObject() : &staticMetaObject;
}

void *FOV::qt_metacast(const char *_clname)
{
    if (!_clname) return nullptr;
    if (!strcmp(_clname, qt_staticMetaObjectStaticContent<qt_meta_tag_ZN3FOVE_t>.strings))
        return static_cast<void*>(this);
    return QObject::qt_metacast(_clname);
}

int FOV::qt_metacall(QMetaObject::Call _c, int _id, void **_a)
{
    _id = QObject::qt_metacall(_c, _id, _a);
    if (_id < 0)
        return _id;
    if (_c == QMetaObject::InvokeMetaMethod) {
        if (_id < 1)
            qt_static_metacall(this, _c, _id, _a);
        _id -= 1;
    }
    if (_c == QMetaObject::RegisterMethodArgumentMetaType) {
        if (_id < 1)
            *reinterpret_cast<QMetaType *>(_a[0]) = QMetaType();
        _id -= 1;
    }
    if (_c == QMetaObject::ReadProperty || _c == QMetaObject::WriteProperty
            || _c == QMetaObject::ResetProperty || _c == QMetaObject::BindableProperty
            || _c == QMetaObject::RegisterPropertyMetaType) {
        qt_static_metacall(this, _c, _id, _a);
        _id -= 9;
    }
    return _id;
}
QT_WARNING_POP
