/********************************************************************************
** Form generated from reading UI file 'mountmotionwidget.ui'
**
** Created by: Qt User Interface Compiler version 6.11.1
**
** WARNING! All changes made in this file will be lost when recompiling UI file!
********************************************************************************/

#ifndef UI_MOUNTMOTIONWIDGET_H
#define UI_MOUNTMOTIONWIDGET_H

#include <QtCore/QVariant>
#include <QtWidgets/QApplication>
#include <QtWidgets/QCheckBox>
#include <QtWidgets/QGridLayout>
#include <QtWidgets/QHBoxLayout>
#include <QtWidgets/QLabel>
#include <QtWidgets/QPushButton>
#include <QtWidgets/QSlider>
#include <QtWidgets/QVBoxLayout>
#include <QtWidgets/QWidget>
#include <klocalizedstring.h>

QT_BEGIN_NAMESPACE

class Ui_MountMotionWidget
{
public:
    QVBoxLayout *verticalLayout_2;
    QVBoxLayout *verticalLayout;
    QGridLayout *gridLayout;
    QPushButton *northWest;
    QPushButton *north;
    QPushButton *northEast;
    QPushButton *west;
    QPushButton *stop;
    QPushButton *east;
    QPushButton *southWest;
    QPushButton *south;
    QPushButton *southEast;
    QHBoxLayout *horizontalLayout;
    QLabel *label_2;
    QCheckBox *upDownCheckObject;
    QCheckBox *leftRightCheckObject;
    QHBoxLayout *horizontalLayout_2;
    QSlider *speedSliderObject;
    QLabel *speedLabelObject;

    void setupUi(QWidget *MountMotionWidget)
    {
        if (MountMotionWidget->objectName().isEmpty())
            MountMotionWidget->setObjectName("MountMotionWidget");
        MountMotionWidget->resize(262, 210);
        MountMotionWidget->setMinimumSize(QSize(262, 0));
        MountMotionWidget->setFocusPolicy(Qt::ClickFocus);
        verticalLayout_2 = new QVBoxLayout(MountMotionWidget);
        verticalLayout_2->setSpacing(3);
        verticalLayout_2->setObjectName("verticalLayout_2");
        verticalLayout_2->setContentsMargins(3, 3, 3, 3);
        verticalLayout = new QVBoxLayout();
        verticalLayout->setSpacing(3);
        verticalLayout->setObjectName("verticalLayout");
        gridLayout = new QGridLayout();
        gridLayout->setSpacing(3);
        gridLayout->setObjectName("gridLayout");
        gridLayout->setSizeConstraint(QLayout::SetDefaultConstraint);
        northWest = new QPushButton(MountMotionWidget);
        northWest->setObjectName("northWest");
        northWest->setMinimumSize(QSize(48, 48));
        northWest->setMaximumSize(QSize(48, 48));
        northWest->setStyleSheet(QString::fromUtf8("QPushButton:pressed\n"
"{\n"
"  background-color: \"red\"\n"
"}\n"
"\n"
"QPushButton:!pressed\n"
"{\n"
"  background-color: \"#ccc7ba\"\n"
"}\n"
"\n"
""));
        northWest->setIconSize(QSize(40, 40));
        northWest->setAutoDefault(false);

        gridLayout->addWidget(northWest, 0, 0, 1, 1);

        north = new QPushButton(MountMotionWidget);
        north->setObjectName("north");
        north->setMinimumSize(QSize(48, 48));
        north->setMaximumSize(QSize(48, 48));
        north->setStyleSheet(QString::fromUtf8("QPushButton:pressed\n"
"{\n"
"  background-color: \"red\"\n"
"}\n"
"\n"
"QPushButton:!pressed\n"
"{\n"
"  background-color: \"#ccc7ba\"\n"
"}\n"
"\n"
""));
        north->setIconSize(QSize(40, 40));
        north->setAutoDefault(false);

        gridLayout->addWidget(north, 0, 1, 1, 1);

        northEast = new QPushButton(MountMotionWidget);
        northEast->setObjectName("northEast");
        northEast->setMinimumSize(QSize(48, 48));
        northEast->setMaximumSize(QSize(48, 48));
        northEast->setStyleSheet(QString::fromUtf8("QPushButton:pressed\n"
"{\n"
"  background-color: \"red\"\n"
"}\n"
"\n"
"QPushButton:!pressed\n"
"{\n"
"  background-color: \"#ccc7ba\"\n"
"}\n"
"\n"
""));
        northEast->setIconSize(QSize(40, 40));
        northEast->setAutoDefault(false);

        gridLayout->addWidget(northEast, 0, 2, 1, 1);

        west = new QPushButton(MountMotionWidget);
        west->setObjectName("west");
        west->setMinimumSize(QSize(48, 48));
        west->setMaximumSize(QSize(48, 48));
        west->setStyleSheet(QString::fromUtf8("QPushButton:pressed\n"
"{\n"
"  background-color: \"red\"\n"
"}\n"
"\n"
"QPushButton:!pressed\n"
"{\n"
"  background-color: \"#ccc7ba\"\n"
"}\n"
"\n"
""));
        west->setIconSize(QSize(40, 40));
        west->setAutoDefault(false);

        gridLayout->addWidget(west, 1, 0, 1, 1);

        stop = new QPushButton(MountMotionWidget);
        stop->setObjectName("stop");
        stop->setMinimumSize(QSize(48, 48));
        stop->setMaximumSize(QSize(48, 48));
        stop->setStyleSheet(QString::fromUtf8("QPushButton:pressed\n"
"{\n"
"  background-color: \"red\"\n"
"}\n"
"\n"
"QPushButton:!pressed\n"
"{\n"
"  background-color: \"#ccc7ba\"\n"
"}\n"
"\n"
""));
        stop->setIconSize(QSize(40, 40));

        gridLayout->addWidget(stop, 1, 1, 1, 1);

        east = new QPushButton(MountMotionWidget);
        east->setObjectName("east");
        east->setMinimumSize(QSize(48, 48));
        east->setMaximumSize(QSize(48, 48));
        east->setStyleSheet(QString::fromUtf8("QPushButton:pressed\n"
"{\n"
"  background-color: \"red\"\n"
"}\n"
"\n"
"QPushButton:!pressed\n"
"{\n"
"  background-color: \"#ccc7ba\"\n"
"}\n"
"\n"
""));
        east->setIconSize(QSize(40, 40));
        east->setAutoDefault(false);

        gridLayout->addWidget(east, 1, 2, 1, 1);

        southWest = new QPushButton(MountMotionWidget);
        southWest->setObjectName("southWest");
        southWest->setMinimumSize(QSize(48, 48));
        southWest->setMaximumSize(QSize(48, 48));
        southWest->setStyleSheet(QString::fromUtf8("QPushButton:pressed\n"
"{\n"
"  background-color: \"red\"\n"
"}\n"
"\n"
"QPushButton:!pressed\n"
"{\n"
"  background-color: \"#ccc7ba\"\n"
"}\n"
"\n"
""));
        southWest->setIconSize(QSize(40, 40));
        southWest->setAutoDefault(false);

        gridLayout->addWidget(southWest, 2, 0, 1, 1);

        south = new QPushButton(MountMotionWidget);
        south->setObjectName("south");
        south->setMinimumSize(QSize(48, 48));
        south->setMaximumSize(QSize(48, 48));
        south->setStyleSheet(QString::fromUtf8("QPushButton:pressed\n"
"{\n"
"  background-color: \"red\"\n"
"}\n"
"\n"
"QPushButton:!pressed\n"
"{\n"
"  background-color: \"#ccc7ba\"\n"
"}\n"
"\n"
""));
        south->setIconSize(QSize(40, 40));

        gridLayout->addWidget(south, 2, 1, 1, 1);

        southEast = new QPushButton(MountMotionWidget);
        southEast->setObjectName("southEast");
        southEast->setMinimumSize(QSize(48, 48));
        southEast->setMaximumSize(QSize(48, 48));
        southEast->setStyleSheet(QString::fromUtf8("QPushButton:pressed\n"
"{\n"
"  background-color: \"red\"\n"
"}\n"
"\n"
"QPushButton:!pressed\n"
"{\n"
"  background-color: \"#ccc7ba\"\n"
"}\n"
"\n"
""));
        southEast->setIconSize(QSize(40, 40));
        southEast->setAutoDefault(false);

        gridLayout->addWidget(southEast, 2, 2, 1, 1);


        verticalLayout->addLayout(gridLayout);

        horizontalLayout = new QHBoxLayout();
        horizontalLayout->setObjectName("horizontalLayout");
        label_2 = new QLabel(MountMotionWidget);
        label_2->setObjectName("label_2");

        horizontalLayout->addWidget(label_2);

        upDownCheckObject = new QCheckBox(MountMotionWidget);
        upDownCheckObject->setObjectName("upDownCheckObject");

        horizontalLayout->addWidget(upDownCheckObject);

        leftRightCheckObject = new QCheckBox(MountMotionWidget);
        leftRightCheckObject->setObjectName("leftRightCheckObject");

        horizontalLayout->addWidget(leftRightCheckObject);


        verticalLayout->addLayout(horizontalLayout);

        horizontalLayout_2 = new QHBoxLayout();
        horizontalLayout_2->setObjectName("horizontalLayout_2");
        speedSliderObject = new QSlider(MountMotionWidget);
        speedSliderObject->setObjectName("speedSliderObject");
        speedSliderObject->setMaximum(4);
        speedSliderObject->setOrientation(Qt::Horizontal);

        horizontalLayout_2->addWidget(speedSliderObject);

        speedLabelObject = new QLabel(MountMotionWidget);
        speedLabelObject->setObjectName("speedLabelObject");

        horizontalLayout_2->addWidget(speedLabelObject);


        verticalLayout->addLayout(horizontalLayout_2);


        verticalLayout_2->addLayout(verticalLayout);


        retranslateUi(MountMotionWidget);

        QMetaObject::connectSlotsByName(MountMotionWidget);
    } // setupUi

    void retranslateUi(QWidget *MountMotionWidget)
    {
        MountMotionWidget->setWindowTitle(tr2i18n("Mount Control Panel", nullptr));
        northWest->setText(QString());
        north->setText(QString());
        northEast->setText(QString());
        west->setText(QString());
        stop->setText(QString());
        east->setText(QString());
        southWest->setText(QString());
        south->setText(QString());
        southEast->setText(QString());
        label_2->setText(tr2i18n("Reverse", nullptr));
        upDownCheckObject->setText(tr2i18n("Up/Down", nullptr));
        leftRightCheckObject->setText(tr2i18n("Left/Right", nullptr));
        speedLabelObject->setText(tr2i18n("Speed", nullptr));
    } // retranslateUi

};

namespace Ui {
    class MountMotionWidget: public Ui_MountMotionWidget {};
} // namespace Ui

QT_END_NAMESPACE

#endif // MOUNTMOTIONWIDGET_H

