/****************************************************************************
** Meta object code from reading C++ file 'kstars.h'
**
** Created by: The Qt Meta Object Compiler version 69 (Qt 6.11.1)
**
** WARNING! All changes made in this file will be lost!
*****************************************************************************/

#include "../../../../kstars-3.8.4.1/kstars/kstars.h"
#include <QtGui/qtextcursor.h>
#include <QtCore/qmetatype.h>

#include <QtCore/qtmochelpers.h>

#include <memory>


#include <QtCore/qxptype_traits.h>
#if !defined(Q_MOC_OUTPUT_REVISION)
#error "The header file 'kstars.h' doesn't include <QObject>."
#elif Q_MOC_OUTPUT_REVISION != 69
#error "This file was generated using the moc from 6.11.1. It"
#error "cannot be used with the include files from this version of Qt."
#error "(The moc has changed too much.)"
#endif

#ifndef Q_CONSTINIT
#define Q_CONSTINIT
#endif

QT_WARNING_PUSH
QT_WARNING_DISABLE_DEPRECATED
QT_WARNING_DISABLE_GCC("-Wuseless-cast")
namespace {
struct qt_meta_tag_ZN6KStarsE_t {};
} // unnamed namespace

template <> constexpr inline auto KStars::qt_create_metaobjectdata<qt_meta_tag_ZN6KStarsE_t>()
{
    namespace QMC = QtMocConstants;
    QtMocHelpers::StringRefStorage qt_stringData {
        "KStars",
        "D-Bus Interface",
        "org.kde.kstars",
        "colorSchemeChanged",
        "",
        "setRaDec",
        "Q_NOREPLY",
        "ra",
        "dec",
        "setRaDecJ2000",
        "ra0",
        "dec0",
        "setAltAz",
        "alt",
        "az",
        "altIsRefracted",
        "lookTowards",
        "direction",
        "addLabel",
        "name",
        "removeLabel",
        "addTrail",
        "removeTrail",
        "zoomIn",
        "zoomOut",
        "defaultZoom",
        "zoom",
        "z",
        "setLocalTime",
        "yr",
        "mth",
        "day",
        "hr",
        "min",
        "sec",
        "setTimeToNow",
        "waitFor",
        "t",
        "waitForKey",
        "k",
        "setTracking",
        "track",
        "changeViewOption",
        "option",
        "value",
        "getOption",
        "QDBusVariant",
        "setOption",
        "getFocusInformationXML",
        "readConfig",
        "writeConfig",
        "popupMessage",
        "x",
        "y",
        "message",
        "drawLine",
        "x1",
        "y1",
        "x2",
        "y2",
        "speed",
        "setGeoLocation",
        "city",
        "province",
        "country",
        "location",
        "setGPSLocation",
        "longitude",
        "latitude",
        "elevation",
        "tz0",
        "setColor",
        "colorName",
        "loadColorScheme",
        "exportImage",
        "filename",
        "width",
        "height",
        "includeLegend",
        "getDSSURL",
        "objectName",
        "RA_J2000",
        "Dec_J2000",
        "getObjectDataXML",
        "fallbackToInternet",
        "storeInternetResolved",
        "getObjectPositionInfo",
        "renderEyepieceView",
        "destPathChart",
        "fovWidth",
        "fovHeight",
        "rotation",
        "scale",
        "flip",
        "invert",
        "imagePath",
        "destPathImage",
        "overlay",
        "invertColors",
        "setApproxFOV",
        "FOV_Degrees",
        "getSkyMapDimensions",
        "getObservingWishListObjectNames",
        "getObservingSessionPlanObjectNames",
        "printImage",
        "usePrintDialog",
        "useChartColors",
        "openFITS",
        "QUrl",
        "imageUrl",
        "listSkyMapViews",
        "setSkyMapView",
        "viewName",
        "setFOVIndicatorVisibility",
        "fovName",
        "visibility",
        "getFOVIndicatorVisibility",
        "getFOVIndicators",
        "setSkyMapRotation",
        "viewAngle",
        "getSkyMapRotation",
        "skyMapIsMirrored",
        "setSkyMapMirrored",
        "mirrored",
        "getToggleableActionStates",
        "activateAction",
        "actionName",
        "getActions",
        "setToggleableActionState",
        "state",
        "updateTime",
        "automaticDSTchange",
        "slotSetTimeToNow",
        "slotApplyConfigChanges",
        "slotApplyWIConfigChanges",
        "slotZoomChanged",
        "slotSetZoom",
        "slotTrack",
        "slotGeoLocator",
        "slotSetTelescopeEnabled",
        "enable",
        "slotSetDomeEnabled",
        "clearCachedFindDialog",
        "slotClearAllTrails",
        "slotShowPositionBar",
        "SkyPoint*",
        "slotFlagManager",
        "slotDSOCatalogGUI",
        "slotWizard",
        "updateLocationFromWizard",
        "GeoLocation",
        "geo",
        "wiView",
        "WIView*",
        "isWIVisible",
        "slotWISettings",
        "slotToggleWIView",
        "slotDownload",
        "slotSetTime",
        "slotToggleTimer",
        "slotRealTimeToogled",
        "checked",
        "slotStepForward",
        "slotStepBackward",
        "slotFind",
        "slotCalculator",
        "slotAVT",
        "slotWUT",
        "slotCalendar",
        "slotGlossary",
        "slotScriptBuilder",
        "slotSolarSystem",
        "slotJMoonTool",
        "slotMoonPhaseTool",
        "slotINDIDriver",
        "slotINDIPanel",
        "slotEkos",
        "slotPushToAssistant",
        "slotINDITelescopeTrack",
        "slotINDITelescopeSlew",
        "focused_object",
        "slotINDITelescopeSlewMousePointer",
        "slotINDITelescopeSync",
        "slotINDITelescopeSyncMousePointer",
        "slotINDITelescopeAbort",
        "slotINDITelescopePark",
        "slotINDITelescopeUnpark",
        "slotINDIDomePark",
        "slotINDIDomeUnpark",
        "slotViewOps",
        "datainitFinished",
        "slotOpenFITS",
        "slotBlink",
        "slotStack",
        "slotExportImage",
        "slotRunScript",
        "slotPrint",
        "slotPrintingWizard",
        "slotManualFocus",
        "slotPointFocus",
        "slotColorScheme",
        "slotThemeChanged",
        "slotTargetSymbol",
        "flag",
        "slotApplySkyMapView",
        "slotHIPSSource",
        "slotEditViews",
        "slotFOVEdit",
        "slotCoordSys",
        "slotMapProjection",
        "slotSkyMapOrientation",
        "slotObsList",
        "slotImagingPlanner",
        "slotViewToolBar",
        "slotINDIToolBar",
        "slotShowGUIItem",
        "slotFullScreen",
        "slotTerrain",
        "slotImageOverlays",
        "slotAboutToQuit",
        "slotEquipmentWriter",
        "slotObserverManager",
        "slotHorizonManager",
        "slotExecute",
        "slotPolarisHourAngle",
        "slotUpdateComets",
        "isAutoUpdate",
        "slotUpdateAsteroids",
        "slotUpdateSupernovae",
        "slotUpdateSatellites",
        "slotConfigureNotifications",
        "colorScheme",
        "version",
        "release"
    };

    QtMocHelpers::UintData qt_methods {
        // Signal 'colorSchemeChanged'
        QtMocHelpers::SignalData<void()>(3, 4, QMC::AccessPublic, QMetaType::Void),
        // Slot 'setRaDec'
        QtMocHelpers::SlotData<void(double, double)>(5, 6, QMC::AccessPublic | QMC::MethodScriptable, QMetaType::Void, {{
            { QMetaType::Double, 7 }, { QMetaType::Double, 8 },
        }}),
        // Slot 'setRaDecJ2000'
        QtMocHelpers::SlotData<void(double, double)>(9, 6, QMC::AccessPublic | QMC::MethodScriptable, QMetaType::Void, {{
            { QMetaType::Double, 10 }, { QMetaType::Double, 11 },
        }}),
        // Slot 'setAltAz'
        QtMocHelpers::SlotData<void(double, double, bool)>(12, 6, QMC::AccessPublic | QMC::MethodScriptable, QMetaType::Void, {{
            { QMetaType::Double, 13 }, { QMetaType::Double, 14 }, { QMetaType::Bool, 15 },
        }}),
        // Slot 'setAltAz'
        QtMocHelpers::SlotData<void(double, double)>(12, 6, QMC::AccessPublic | QMC::MethodCloned | QMC::MethodScriptable, QMetaType::Void, {{
            { QMetaType::Double, 13 }, { QMetaType::Double, 14 },
        }}),
        // Slot 'lookTowards'
        QtMocHelpers::SlotData<void(const QString &)>(16, 6, QMC::AccessPublic | QMC::MethodScriptable, QMetaType::Void, {{
            { QMetaType::QString, 17 },
        }}),
        // Slot 'addLabel'
        QtMocHelpers::SlotData<void(const QString &)>(18, 6, QMC::AccessPublic | QMC::MethodScriptable, QMetaType::Void, {{
            { QMetaType::QString, 19 },
        }}),
        // Slot 'removeLabel'
        QtMocHelpers::SlotData<void(const QString &)>(20, 6, QMC::AccessPublic | QMC::MethodScriptable, QMetaType::Void, {{
            { QMetaType::QString, 19 },
        }}),
        // Slot 'addTrail'
        QtMocHelpers::SlotData<void(const QString &)>(21, 6, QMC::AccessPublic | QMC::MethodScriptable, QMetaType::Void, {{
            { QMetaType::QString, 19 },
        }}),
        // Slot 'removeTrail'
        QtMocHelpers::SlotData<void(const QString &)>(22, 6, QMC::AccessPublic | QMC::MethodScriptable, QMetaType::Void, {{
            { QMetaType::QString, 19 },
        }}),
        // Slot 'zoomIn'
        QtMocHelpers::SlotData<void()>(23, 6, QMC::AccessPublic | QMC::MethodScriptable, QMetaType::Void),
        // Slot 'zoomOut'
        QtMocHelpers::SlotData<void()>(24, 6, QMC::AccessPublic | QMC::MethodScriptable, QMetaType::Void),
        // Slot 'defaultZoom'
        QtMocHelpers::SlotData<void()>(25, 6, QMC::AccessPublic | QMC::MethodScriptable, QMetaType::Void),
        // Slot 'zoom'
        QtMocHelpers::SlotData<void(double)>(26, 6, QMC::AccessPublic | QMC::MethodScriptable, QMetaType::Void, {{
            { QMetaType::Double, 27 },
        }}),
        // Slot 'setLocalTime'
        QtMocHelpers::SlotData<void(int, int, int, int, int, int)>(28, 6, QMC::AccessPublic | QMC::MethodScriptable, QMetaType::Void, {{
            { QMetaType::Int, 29 }, { QMetaType::Int, 30 }, { QMetaType::Int, 31 }, { QMetaType::Int, 32 },
            { QMetaType::Int, 33 }, { QMetaType::Int, 34 },
        }}),
        // Slot 'setTimeToNow'
        QtMocHelpers::SlotData<void()>(35, 6, QMC::AccessPublic | QMC::MethodScriptable, QMetaType::Void),
        // Slot 'waitFor'
        QtMocHelpers::SlotData<void(double)>(36, 6, QMC::AccessPublic | QMC::MethodScriptable, QMetaType::Void, {{
            { QMetaType::Double, 37 },
        }}),
        // Slot 'waitForKey'
        QtMocHelpers::SlotData<void(const QString &)>(38, 6, QMC::AccessPublic | QMC::MethodScriptable, QMetaType::Void, {{
            { QMetaType::QString, 39 },
        }}),
        // Slot 'setTracking'
        QtMocHelpers::SlotData<void(bool)>(40, 6, QMC::AccessPublic | QMC::MethodScriptable, QMetaType::Void, {{
            { QMetaType::Bool, 41 },
        }}),
        // Slot 'changeViewOption'
        QtMocHelpers::SlotData<void(const QString &, const QString &)>(42, 6, QMC::AccessPublic | QMC::MethodScriptable, QMetaType::Void, {{
            { QMetaType::QString, 43 }, { QMetaType::QString, 44 },
        }}),
        // Slot 'getOption'
        QtMocHelpers::SlotData<QDBusVariant(const QString &)>(45, 4, QMC::AccessPublic | QMC::MethodScriptable, 0x80000000 | 46, {{
            { QMetaType::QString, 19 },
        }}),
        // Slot 'setOption'
        QtMocHelpers::SlotData<void(const QString &, const QDBusVariant &)>(47, 6, QMC::AccessPublic | QMC::MethodScriptable, QMetaType::Void, {{
            { QMetaType::QString, 19 }, { 0x80000000 | 46, 44 },
        }}),
        // Slot 'getFocusInformationXML'
        QtMocHelpers::SlotData<QString()>(48, 4, QMC::AccessPublic | QMC::MethodScriptable, QMetaType::QString),
        // Slot 'readConfig'
        QtMocHelpers::SlotData<void()>(49, 6, QMC::AccessPublic | QMC::MethodScriptable, QMetaType::Void),
        // Slot 'writeConfig'
        QtMocHelpers::SlotData<void()>(50, 6, QMC::AccessPublic | QMC::MethodScriptable, QMetaType::Void),
        // Slot 'popupMessage'
        QtMocHelpers::SlotData<void(int, int, const QString &)>(51, 6, QMC::AccessPublic | QMC::MethodScriptable, QMetaType::Void, {{
            { QMetaType::Int, 52 }, { QMetaType::Int, 53 }, { QMetaType::QString, 54 },
        }}),
        // Slot 'drawLine'
        QtMocHelpers::SlotData<void(int, int, int, int, int)>(55, 6, QMC::AccessPublic | QMC::MethodScriptable, QMetaType::Void, {{
            { QMetaType::Int, 56 }, { QMetaType::Int, 57 }, { QMetaType::Int, 58 }, { QMetaType::Int, 59 },
            { QMetaType::Int, 60 },
        }}),
        // Slot 'setGeoLocation'
        QtMocHelpers::SlotData<bool(const QString &, const QString &, const QString &)>(61, 4, QMC::AccessPublic | QMC::MethodScriptable, QMetaType::Bool, {{
            { QMetaType::QString, 62 }, { QMetaType::QString, 63 }, { QMetaType::QString, 64 },
        }}),
        // Slot 'location'
        QtMocHelpers::SlotData<QString()>(65, 4, QMC::AccessPublic | QMC::MethodScriptable, QMetaType::QString),
        // Slot 'setGPSLocation'
        QtMocHelpers::SlotData<bool(double, double, double, double)>(66, 4, QMC::AccessPublic | QMC::MethodScriptable, QMetaType::Bool, {{
            { QMetaType::Double, 67 }, { QMetaType::Double, 68 }, { QMetaType::Double, 69 }, { QMetaType::Double, 70 },
        }}),
        // Slot 'setColor'
        QtMocHelpers::SlotData<void(const QString &, const QString &)>(71, 6, QMC::AccessPublic | QMC::MethodScriptable, QMetaType::Void, {{
            { QMetaType::QString, 72 }, { QMetaType::QString, 44 },
        }}),
        // Slot 'loadColorScheme'
        QtMocHelpers::SlotData<void(const QString &)>(73, 6, QMC::AccessPublic | QMC::MethodScriptable, QMetaType::Void, {{
            { QMetaType::QString, 19 },
        }}),
        // Slot 'exportImage'
        QtMocHelpers::SlotData<void(const QString &, int, int, bool)>(74, 6, QMC::AccessPublic | QMC::MethodScriptable, QMetaType::Void, {{
            { QMetaType::QString, 75 }, { QMetaType::Int, 76 }, { QMetaType::Int, 77 }, { QMetaType::Bool, 78 },
        }}),
        // Slot 'exportImage'
        QtMocHelpers::SlotData<void(const QString &, int, int)>(74, 6, QMC::AccessPublic | QMC::MethodCloned | QMC::MethodScriptable, QMetaType::Void, {{
            { QMetaType::QString, 75 }, { QMetaType::Int, 76 }, { QMetaType::Int, 77 },
        }}),
        // Slot 'exportImage'
        QtMocHelpers::SlotData<void(const QString &, int)>(74, 6, QMC::AccessPublic | QMC::MethodCloned | QMC::MethodScriptable, QMetaType::Void, {{
            { QMetaType::QString, 75 }, { QMetaType::Int, 76 },
        }}),
        // Slot 'exportImage'
        QtMocHelpers::SlotData<void(const QString &)>(74, 6, QMC::AccessPublic | QMC::MethodCloned | QMC::MethodScriptable, QMetaType::Void, {{
            { QMetaType::QString, 75 },
        }}),
        // Slot 'getDSSURL'
        QtMocHelpers::SlotData<QString(const QString &)>(79, 4, QMC::AccessPublic | QMC::MethodScriptable, QMetaType::QString, {{
            { QMetaType::QString, 80 },
        }}),
        // Slot 'getDSSURL'
        QtMocHelpers::SlotData<QString(double, double, double, double)>(79, 4, QMC::AccessPublic | QMC::MethodScriptable, QMetaType::QString, {{
            { QMetaType::Double, 81 }, { QMetaType::Double, 82 }, { QMetaType::Double, 76 }, { QMetaType::Double, 77 },
        }}),
        // Slot 'getDSSURL'
        QtMocHelpers::SlotData<QString(double, double, double)>(79, 4, QMC::AccessPublic | QMC::MethodCloned | QMC::MethodScriptable, QMetaType::QString, {{
            { QMetaType::Double, 81 }, { QMetaType::Double, 82 }, { QMetaType::Double, 76 },
        }}),
        // Slot 'getDSSURL'
        QtMocHelpers::SlotData<QString(double, double)>(79, 4, QMC::AccessPublic | QMC::MethodCloned | QMC::MethodScriptable, QMetaType::QString, {{
            { QMetaType::Double, 81 }, { QMetaType::Double, 82 },
        }}),
        // Slot 'getObjectDataXML'
        QtMocHelpers::SlotData<QString(const QString &, bool, bool)>(83, 4, QMC::AccessPublic | QMC::MethodScriptable, QMetaType::QString, {{
            { QMetaType::QString, 80 }, { QMetaType::Bool, 84 }, { QMetaType::Bool, 85 },
        }}),
        // Slot 'getObjectDataXML'
        QtMocHelpers::SlotData<QString(const QString &, bool)>(83, 4, QMC::AccessPublic | QMC::MethodCloned | QMC::MethodScriptable, QMetaType::QString, {{
            { QMetaType::QString, 80 }, { QMetaType::Bool, 84 },
        }}),
        // Slot 'getObjectDataXML'
        QtMocHelpers::SlotData<QString(const QString &)>(83, 4, QMC::AccessPublic | QMC::MethodCloned | QMC::MethodScriptable, QMetaType::QString, {{
            { QMetaType::QString, 80 },
        }}),
        // Slot 'getObjectPositionInfo'
        QtMocHelpers::SlotData<QString(const QString &)>(86, 4, QMC::AccessPublic | QMC::MethodScriptable, QMetaType::QString, {{
            { QMetaType::QString, 80 },
        }}),
        // Slot 'renderEyepieceView'
        QtMocHelpers::SlotData<void(const QString &, const QString &, const double, const double, const double, const double, const bool, const bool, QString, const QString &, const bool, const bool)>(87, 6, QMC::AccessPublic | QMC::MethodScriptable, QMetaType::Void, {{
            { QMetaType::QString, 80 }, { QMetaType::QString, 88 }, { QMetaType::Double, 89 }, { QMetaType::Double, 90 },
            { QMetaType::Double, 91 }, { QMetaType::Double, 92 }, { QMetaType::Bool, 93 }, { QMetaType::Bool, 94 },
            { QMetaType::QString, 95 }, { QMetaType::QString, 96 }, { QMetaType::Bool, 97 }, { QMetaType::Bool, 98 },
        }}),
        // Slot 'renderEyepieceView'
        QtMocHelpers::SlotData<void(const QString &, const QString &, const double, const double, const double, const double, const bool, const bool, QString, const QString &, const bool)>(87, 6, QMC::AccessPublic | QMC::MethodCloned | QMC::MethodScriptable, QMetaType::Void, {{
            { QMetaType::QString, 80 }, { QMetaType::QString, 88 }, { QMetaType::Double, 89 }, { QMetaType::Double, 90 },
            { QMetaType::Double, 91 }, { QMetaType::Double, 92 }, { QMetaType::Bool, 93 }, { QMetaType::Bool, 94 },
            { QMetaType::QString, 95 }, { QMetaType::QString, 96 }, { QMetaType::Bool, 97 },
        }}),
        // Slot 'renderEyepieceView'
        QtMocHelpers::SlotData<void(const QString &, const QString &, const double, const double, const double, const double, const bool, const bool, QString, const QString &)>(87, 6, QMC::AccessPublic | QMC::MethodCloned | QMC::MethodScriptable, QMetaType::Void, {{
            { QMetaType::QString, 80 }, { QMetaType::QString, 88 }, { QMetaType::Double, 89 }, { QMetaType::Double, 90 },
            { QMetaType::Double, 91 }, { QMetaType::Double, 92 }, { QMetaType::Bool, 93 }, { QMetaType::Bool, 94 },
            { QMetaType::QString, 95 }, { QMetaType::QString, 96 },
        }}),
        // Slot 'renderEyepieceView'
        QtMocHelpers::SlotData<void(const QString &, const QString &, const double, const double, const double, const double, const bool, const bool, QString)>(87, 6, QMC::AccessPublic | QMC::MethodCloned | QMC::MethodScriptable, QMetaType::Void, {{
            { QMetaType::QString, 80 }, { QMetaType::QString, 88 }, { QMetaType::Double, 89 }, { QMetaType::Double, 90 },
            { QMetaType::Double, 91 }, { QMetaType::Double, 92 }, { QMetaType::Bool, 93 }, { QMetaType::Bool, 94 },
            { QMetaType::QString, 95 },
        }}),
        // Slot 'renderEyepieceView'
        QtMocHelpers::SlotData<void(const QString &, const QString &, const double, const double, const double, const double, const bool, const bool)>(87, 6, QMC::AccessPublic | QMC::MethodCloned | QMC::MethodScriptable, QMetaType::Void, {{
            { QMetaType::QString, 80 }, { QMetaType::QString, 88 }, { QMetaType::Double, 89 }, { QMetaType::Double, 90 },
            { QMetaType::Double, 91 }, { QMetaType::Double, 92 }, { QMetaType::Bool, 93 }, { QMetaType::Bool, 94 },
        }}),
        // Slot 'renderEyepieceView'
        QtMocHelpers::SlotData<void(const QString &, const QString &, const double, const double, const double, const double, const bool)>(87, 6, QMC::AccessPublic | QMC::MethodCloned | QMC::MethodScriptable, QMetaType::Void, {{
            { QMetaType::QString, 80 }, { QMetaType::QString, 88 }, { QMetaType::Double, 89 }, { QMetaType::Double, 90 },
            { QMetaType::Double, 91 }, { QMetaType::Double, 92 }, { QMetaType::Bool, 93 },
        }}),
        // Slot 'renderEyepieceView'
        QtMocHelpers::SlotData<void(const QString &, const QString &, const double, const double, const double, const double)>(87, 6, QMC::AccessPublic | QMC::MethodCloned | QMC::MethodScriptable, QMetaType::Void, {{
            { QMetaType::QString, 80 }, { QMetaType::QString, 88 }, { QMetaType::Double, 89 }, { QMetaType::Double, 90 },
            { QMetaType::Double, 91 }, { QMetaType::Double, 92 },
        }}),
        // Slot 'renderEyepieceView'
        QtMocHelpers::SlotData<void(const QString &, const QString &, const double, const double, const double)>(87, 6, QMC::AccessPublic | QMC::MethodCloned | QMC::MethodScriptable, QMetaType::Void, {{
            { QMetaType::QString, 80 }, { QMetaType::QString, 88 }, { QMetaType::Double, 89 }, { QMetaType::Double, 90 },
            { QMetaType::Double, 91 },
        }}),
        // Slot 'renderEyepieceView'
        QtMocHelpers::SlotData<void(const QString &, const QString &, const double, const double)>(87, 6, QMC::AccessPublic | QMC::MethodCloned | QMC::MethodScriptable, QMetaType::Void, {{
            { QMetaType::QString, 80 }, { QMetaType::QString, 88 }, { QMetaType::Double, 89 }, { QMetaType::Double, 90 },
        }}),
        // Slot 'renderEyepieceView'
        QtMocHelpers::SlotData<void(const QString &, const QString &, const double)>(87, 6, QMC::AccessPublic | QMC::MethodCloned | QMC::MethodScriptable, QMetaType::Void, {{
            { QMetaType::QString, 80 }, { QMetaType::QString, 88 }, { QMetaType::Double, 89 },
        }}),
        // Slot 'renderEyepieceView'
        QtMocHelpers::SlotData<void(const QString &, const QString &)>(87, 6, QMC::AccessPublic | QMC::MethodCloned | QMC::MethodScriptable, QMetaType::Void, {{
            { QMetaType::QString, 80 }, { QMetaType::QString, 88 },
        }}),
        // Slot 'setApproxFOV'
        QtMocHelpers::SlotData<void(double)>(99, 6, QMC::AccessPublic | QMC::MethodScriptable, QMetaType::Void, {{
            { QMetaType::Double, 100 },
        }}),
        // Slot 'getSkyMapDimensions'
        QtMocHelpers::SlotData<QString()>(101, 4, QMC::AccessPublic | QMC::MethodScriptable, QMetaType::QString),
        // Slot 'getObservingWishListObjectNames'
        QtMocHelpers::SlotData<QString()>(102, 4, QMC::AccessPublic | QMC::MethodScriptable, QMetaType::QString),
        // Slot 'getObservingSessionPlanObjectNames'
        QtMocHelpers::SlotData<QString()>(103, 4, QMC::AccessPublic | QMC::MethodScriptable, QMetaType::QString),
        // Slot 'printImage'
        QtMocHelpers::SlotData<void(bool, bool)>(104, 6, QMC::AccessPublic | QMC::MethodScriptable, QMetaType::Void, {{
            { QMetaType::Bool, 105 }, { QMetaType::Bool, 106 },
        }}),
        // Slot 'openFITS'
        QtMocHelpers::SlotData<void(const QUrl &)>(107, 6, QMC::AccessPublic | QMC::MethodScriptable, QMetaType::Void, {{
            { 0x80000000 | 108, 109 },
        }}),
        // Slot 'listSkyMapViews'
        QtMocHelpers::SlotData<QStringList()>(110, 4, QMC::AccessPublic | QMC::MethodScriptable, QMetaType::QStringList),
        // Slot 'setSkyMapView'
        QtMocHelpers::SlotData<bool(const QString &)>(111, 4, QMC::AccessPublic | QMC::MethodScriptable, QMetaType::Bool, {{
            { QMetaType::QString, 112 },
        }}),
        // Slot 'setFOVIndicatorVisibility'
        QtMocHelpers::SlotData<bool(const QString &, bool)>(113, 4, QMC::AccessPublic | QMC::MethodScriptable, QMetaType::Bool, {{
            { QMetaType::QString, 114 }, { QMetaType::Bool, 115 },
        }}),
        // Slot 'getFOVIndicatorVisibility'
        QtMocHelpers::SlotData<bool(const QString &)>(116, 4, QMC::AccessPublic | QMC::MethodScriptable, QMetaType::Bool, {{
            { QMetaType::QString, 114 },
        }}),
        // Slot 'getFOVIndicators'
        QtMocHelpers::SlotData<QStringList()>(117, 4, QMC::AccessPublic | QMC::MethodScriptable, QMetaType::QStringList),
        // Slot 'setSkyMapRotation'
        QtMocHelpers::SlotData<void(const double)>(118, 6, QMC::AccessPublic | QMC::MethodScriptable, QMetaType::Void, {{
            { QMetaType::Double, 119 },
        }}),
        // Slot 'getSkyMapRotation'
        QtMocHelpers::SlotData<double()>(120, 4, QMC::AccessPublic | QMC::MethodScriptable, QMetaType::Double),
        // Slot 'skyMapIsMirrored'
        QtMocHelpers::SlotData<bool()>(121, 4, QMC::AccessPublic | QMC::MethodScriptable, QMetaType::Bool),
        // Slot 'setSkyMapMirrored'
        QtMocHelpers::SlotData<void(bool)>(122, 6, QMC::AccessPublic | QMC::MethodScriptable, QMetaType::Void, {{
            { QMetaType::Bool, 123 },
        }}),
        // Slot 'getToggleableActionStates'
        QtMocHelpers::SlotData<QString()>(124, 4, QMC::AccessPublic | QMC::MethodScriptable, QMetaType::QString),
        // Slot 'activateAction'
        QtMocHelpers::SlotData<bool(const QString &)>(125, 4, QMC::AccessPublic | QMC::MethodScriptable, QMetaType::Bool, {{
            { QMetaType::QString, 126 },
        }}),
        // Slot 'getActions'
        QtMocHelpers::SlotData<QStringList()>(127, 4, QMC::AccessPublic | QMC::MethodScriptable, QMetaType::QStringList),
        // Slot 'setToggleableActionState'
        QtMocHelpers::SlotData<bool(const QString &, const bool)>(128, 4, QMC::AccessPublic | QMC::MethodScriptable, QMetaType::Bool, {{
            { QMetaType::QString, 126 }, { QMetaType::Bool, 129 },
        }}),
        // Slot 'updateTime'
        QtMocHelpers::SlotData<void(const bool)>(130, 4, QMC::AccessPublic, QMetaType::Void, {{
            { QMetaType::Bool, 131 },
        }}),
        // Slot 'updateTime'
        QtMocHelpers::SlotData<void()>(130, 4, QMC::AccessPublic | QMC::MethodCloned, QMetaType::Void),
        // Slot 'slotSetTimeToNow'
        QtMocHelpers::SlotData<void()>(132, 4, QMC::AccessPublic, QMetaType::Void),
        // Slot 'slotApplyConfigChanges'
        QtMocHelpers::SlotData<void()>(133, 4, QMC::AccessPublic, QMetaType::Void),
        // Slot 'slotApplyWIConfigChanges'
        QtMocHelpers::SlotData<void()>(134, 4, QMC::AccessPublic, QMetaType::Void),
        // Slot 'slotZoomChanged'
        QtMocHelpers::SlotData<void()>(135, 4, QMC::AccessPublic, QMetaType::Void),
        // Slot 'slotSetZoom'
        QtMocHelpers::SlotData<void()>(136, 4, QMC::AccessPublic, QMetaType::Void),
        // Slot 'slotTrack'
        QtMocHelpers::SlotData<void()>(137, 4, QMC::AccessPublic, QMetaType::Void),
        // Slot 'slotGeoLocator'
        QtMocHelpers::SlotData<void()>(138, 4, QMC::AccessPublic, QMetaType::Void),
        // Slot 'slotSetTelescopeEnabled'
        QtMocHelpers::SlotData<void(bool)>(139, 4, QMC::AccessPublic, QMetaType::Void, {{
            { QMetaType::Bool, 140 },
        }}),
        // Slot 'slotSetDomeEnabled'
        QtMocHelpers::SlotData<void(bool)>(141, 4, QMC::AccessPublic, QMetaType::Void, {{
            { QMetaType::Bool, 140 },
        }}),
        // Slot 'clearCachedFindDialog'
        QtMocHelpers::SlotData<void()>(142, 4, QMC::AccessPublic, QMetaType::Void),
        // Slot 'slotClearAllTrails'
        QtMocHelpers::SlotData<void()>(143, 4, QMC::AccessPublic, QMetaType::Void),
        // Slot 'slotShowPositionBar'
        QtMocHelpers::SlotData<void(SkyPoint *)>(144, 4, QMC::AccessPublic, QMetaType::Void, {{
            { 0x80000000 | 145, 4 },
        }}),
        // Slot 'slotFlagManager'
        QtMocHelpers::SlotData<void()>(146, 4, QMC::AccessPublic, QMetaType::Void),
        // Slot 'slotDSOCatalogGUI'
        QtMocHelpers::SlotData<void()>(147, 4, QMC::AccessPublic, QMetaType::Void),
        // Slot 'slotWizard'
        QtMocHelpers::SlotData<void()>(148, 4, QMC::AccessPublic, QMetaType::Void),
        // Slot 'updateLocationFromWizard'
        QtMocHelpers::SlotData<void(const GeoLocation &)>(149, 4, QMC::AccessPublic, QMetaType::Void, {{
            { 0x80000000 | 150, 151 },
        }}),
        // Slot 'wiView'
        QtMocHelpers::SlotData<WIView *()>(152, 4, QMC::AccessPublic, 0x80000000 | 153),
        // Slot 'isWIVisible'
        QtMocHelpers::SlotData<bool()>(154, 4, QMC::AccessPublic, QMetaType::Bool),
        // Slot 'slotWISettings'
        QtMocHelpers::SlotData<void()>(155, 4, QMC::AccessPublic, QMetaType::Void),
        // Slot 'slotToggleWIView'
        QtMocHelpers::SlotData<void()>(156, 4, QMC::AccessPublic, QMetaType::Void),
        // Slot 'slotDownload'
        QtMocHelpers::SlotData<void()>(157, 4, QMC::AccessPublic, QMetaType::Void),
        // Slot 'slotSetTime'
        QtMocHelpers::SlotData<void()>(158, 4, QMC::AccessPrivate, QMetaType::Void),
        // Slot 'slotToggleTimer'
        QtMocHelpers::SlotData<void()>(159, 4, QMC::AccessPrivate, QMetaType::Void),
        // Slot 'slotRealTimeToogled'
        QtMocHelpers::SlotData<void(bool)>(160, 4, QMC::AccessPrivate, QMetaType::Void, {{
            { QMetaType::Bool, 161 },
        }}),
        // Slot 'slotStepForward'
        QtMocHelpers::SlotData<void()>(162, 4, QMC::AccessPrivate, QMetaType::Void),
        // Slot 'slotStepBackward'
        QtMocHelpers::SlotData<void()>(163, 4, QMC::AccessPrivate, QMetaType::Void),
        // Slot 'slotFind'
        QtMocHelpers::SlotData<void()>(164, 4, QMC::AccessPrivate, QMetaType::Void),
        // Slot 'slotCalculator'
        QtMocHelpers::SlotData<void()>(165, 4, QMC::AccessPrivate, QMetaType::Void),
        // Slot 'slotAVT'
        QtMocHelpers::SlotData<void()>(166, 4, QMC::AccessPrivate, QMetaType::Void),
        // Slot 'slotWUT'
        QtMocHelpers::SlotData<void()>(167, 4, QMC::AccessPrivate, QMetaType::Void),
        // Slot 'slotCalendar'
        QtMocHelpers::SlotData<void()>(168, 4, QMC::AccessPrivate, QMetaType::Void),
        // Slot 'slotGlossary'
        QtMocHelpers::SlotData<void()>(169, 4, QMC::AccessPrivate, QMetaType::Void),
        // Slot 'slotScriptBuilder'
        QtMocHelpers::SlotData<void()>(170, 4, QMC::AccessPrivate, QMetaType::Void),
        // Slot 'slotSolarSystem'
        QtMocHelpers::SlotData<void()>(171, 4, QMC::AccessPrivate, QMetaType::Void),
        // Slot 'slotJMoonTool'
        QtMocHelpers::SlotData<void()>(172, 4, QMC::AccessPrivate, QMetaType::Void),
        // Slot 'slotMoonPhaseTool'
        QtMocHelpers::SlotData<void()>(173, 4, QMC::AccessPrivate, QMetaType::Void),
        // Slot 'slotINDIDriver'
        QtMocHelpers::SlotData<void()>(174, 4, QMC::AccessPrivate, QMetaType::Void),
        // Slot 'slotINDIPanel'
        QtMocHelpers::SlotData<void()>(175, 4, QMC::AccessPrivate, QMetaType::Void),
        // Slot 'slotEkos'
        QtMocHelpers::SlotData<void()>(176, 4, QMC::AccessPrivate, QMetaType::Void),
        // Slot 'slotPushToAssistant'
        QtMocHelpers::SlotData<void()>(177, 4, QMC::AccessPrivate, QMetaType::Void),
        // Slot 'slotINDITelescopeTrack'
        QtMocHelpers::SlotData<void()>(178, 4, QMC::AccessPrivate, QMetaType::Void),
        // Slot 'slotINDITelescopeSlew'
        QtMocHelpers::SlotData<void(bool)>(179, 4, QMC::AccessPrivate, QMetaType::Void, {{
            { QMetaType::Bool, 180 },
        }}),
        // Slot 'slotINDITelescopeSlew'
        QtMocHelpers::SlotData<void()>(179, 4, QMC::AccessPrivate | QMC::MethodCloned, QMetaType::Void),
        // Slot 'slotINDITelescopeSlewMousePointer'
        QtMocHelpers::SlotData<void()>(181, 4, QMC::AccessPrivate, QMetaType::Void),
        // Slot 'slotINDITelescopeSync'
        QtMocHelpers::SlotData<void(bool)>(182, 4, QMC::AccessPrivate, QMetaType::Void, {{
            { QMetaType::Bool, 180 },
        }}),
        // Slot 'slotINDITelescopeSync'
        QtMocHelpers::SlotData<void()>(182, 4, QMC::AccessPrivate | QMC::MethodCloned, QMetaType::Void),
        // Slot 'slotINDITelescopeSyncMousePointer'
        QtMocHelpers::SlotData<void()>(183, 4, QMC::AccessPrivate, QMetaType::Void),
        // Slot 'slotINDITelescopeAbort'
        QtMocHelpers::SlotData<void()>(184, 4, QMC::AccessPrivate, QMetaType::Void),
        // Slot 'slotINDITelescopePark'
        QtMocHelpers::SlotData<void()>(185, 4, QMC::AccessPrivate, QMetaType::Void),
        // Slot 'slotINDITelescopeUnpark'
        QtMocHelpers::SlotData<void()>(186, 4, QMC::AccessPrivate, QMetaType::Void),
        // Slot 'slotINDIDomePark'
        QtMocHelpers::SlotData<void()>(187, 4, QMC::AccessPrivate, QMetaType::Void),
        // Slot 'slotINDIDomeUnpark'
        QtMocHelpers::SlotData<void()>(188, 4, QMC::AccessPrivate, QMetaType::Void),
        // Slot 'slotViewOps'
        QtMocHelpers::SlotData<void()>(189, 4, QMC::AccessPrivate, QMetaType::Void),
        // Slot 'datainitFinished'
        QtMocHelpers::SlotData<void()>(190, 4, QMC::AccessPrivate, QMetaType::Void),
        // Slot 'slotOpenFITS'
        QtMocHelpers::SlotData<void()>(191, 4, QMC::AccessPrivate, QMetaType::Void),
        // Slot 'slotBlink'
        QtMocHelpers::SlotData<void()>(192, 4, QMC::AccessPrivate, QMetaType::Void),
        // Slot 'slotStack'
        QtMocHelpers::SlotData<void()>(193, 4, QMC::AccessPrivate, QMetaType::Void),
        // Slot 'slotExportImage'
        QtMocHelpers::SlotData<void()>(194, 4, QMC::AccessPrivate, QMetaType::Void),
        // Slot 'slotRunScript'
        QtMocHelpers::SlotData<void()>(195, 4, QMC::AccessPrivate, QMetaType::Void),
        // Slot 'slotPrint'
        QtMocHelpers::SlotData<void()>(196, 4, QMC::AccessPrivate, QMetaType::Void),
        // Slot 'slotPrintingWizard'
        QtMocHelpers::SlotData<void()>(197, 4, QMC::AccessPrivate, QMetaType::Void),
        // Slot 'slotManualFocus'
        QtMocHelpers::SlotData<void()>(198, 4, QMC::AccessPrivate, QMetaType::Void),
        // Slot 'slotPointFocus'
        QtMocHelpers::SlotData<void()>(199, 4, QMC::AccessPrivate, QMetaType::Void),
        // Slot 'slotColorScheme'
        QtMocHelpers::SlotData<void()>(200, 4, QMC::AccessPrivate, QMetaType::Void),
        // Slot 'slotThemeChanged'
        QtMocHelpers::SlotData<void()>(201, 4, QMC::AccessPrivate, QMetaType::Void),
        // Slot 'slotTargetSymbol'
        QtMocHelpers::SlotData<void(bool)>(202, 4, QMC::AccessPrivate, QMetaType::Void, {{
            { QMetaType::Bool, 203 },
        }}),
        // Slot 'slotApplySkyMapView'
        QtMocHelpers::SlotData<bool(const QString &)>(204, 4, QMC::AccessPrivate, QMetaType::Bool, {{
            { QMetaType::QString, 112 },
        }}),
        // Slot 'slotHIPSSource'
        QtMocHelpers::SlotData<void()>(205, 4, QMC::AccessPrivate, QMetaType::Void),
        // Slot 'slotEditViews'
        QtMocHelpers::SlotData<void()>(206, 4, QMC::AccessPrivate, QMetaType::Void),
        // Slot 'slotFOVEdit'
        QtMocHelpers::SlotData<void()>(207, 4, QMC::AccessPrivate, QMetaType::Void),
        // Slot 'slotCoordSys'
        QtMocHelpers::SlotData<void()>(208, 4, QMC::AccessPrivate, QMetaType::Void),
        // Slot 'slotMapProjection'
        QtMocHelpers::SlotData<void()>(209, 4, QMC::AccessPrivate, QMetaType::Void),
        // Slot 'slotSkyMapOrientation'
        QtMocHelpers::SlotData<void()>(210, 4, QMC::AccessPrivate, QMetaType::Void),
        // Slot 'slotObsList'
        QtMocHelpers::SlotData<void()>(211, 4, QMC::AccessPrivate, QMetaType::Void),
        // Slot 'slotImagingPlanner'
        QtMocHelpers::SlotData<void()>(212, 4, QMC::AccessPrivate, QMetaType::Void),
        // Slot 'slotViewToolBar'
        QtMocHelpers::SlotData<void()>(213, 4, QMC::AccessPrivate, QMetaType::Void),
        // Slot 'slotINDIToolBar'
        QtMocHelpers::SlotData<void()>(214, 4, QMC::AccessPrivate, QMetaType::Void),
        // Slot 'slotShowGUIItem'
        QtMocHelpers::SlotData<void(bool)>(215, 4, QMC::AccessPrivate, QMetaType::Void, {{
            { QMetaType::Bool, 4 },
        }}),
        // Slot 'slotFullScreen'
        QtMocHelpers::SlotData<void()>(216, 4, QMC::AccessPrivate, QMetaType::Void),
        // Slot 'slotTerrain'
        QtMocHelpers::SlotData<void()>(217, 4, QMC::AccessPrivate, QMetaType::Void),
        // Slot 'slotImageOverlays'
        QtMocHelpers::SlotData<void()>(218, 4, QMC::AccessPrivate, QMetaType::Void),
        // Slot 'slotAboutToQuit'
        QtMocHelpers::SlotData<void()>(219, 4, QMC::AccessPrivate, QMetaType::Void),
        // Slot 'slotEquipmentWriter'
        QtMocHelpers::SlotData<void()>(220, 4, QMC::AccessPrivate, QMetaType::Void),
        // Slot 'slotObserverManager'
        QtMocHelpers::SlotData<void()>(221, 4, QMC::AccessPrivate, QMetaType::Void),
        // Slot 'slotHorizonManager'
        QtMocHelpers::SlotData<void()>(222, 4, QMC::AccessPrivate, QMetaType::Void),
        // Slot 'slotExecute'
        QtMocHelpers::SlotData<void()>(223, 4, QMC::AccessPrivate, QMetaType::Void),
        // Slot 'slotPolarisHourAngle'
        QtMocHelpers::SlotData<void()>(224, 4, QMC::AccessPrivate, QMetaType::Void),
        // Slot 'slotUpdateComets'
        QtMocHelpers::SlotData<void(bool)>(225, 4, QMC::AccessPrivate, QMetaType::Void, {{
            { QMetaType::Bool, 226 },
        }}),
        // Slot 'slotUpdateComets'
        QtMocHelpers::SlotData<void()>(225, 4, QMC::AccessPrivate | QMC::MethodCloned, QMetaType::Void),
        // Slot 'slotUpdateAsteroids'
        QtMocHelpers::SlotData<void(bool)>(227, 4, QMC::AccessPrivate, QMetaType::Void, {{
            { QMetaType::Bool, 226 },
        }}),
        // Slot 'slotUpdateAsteroids'
        QtMocHelpers::SlotData<void()>(227, 4, QMC::AccessPrivate | QMC::MethodCloned, QMetaType::Void),
        // Slot 'slotUpdateSupernovae'
        QtMocHelpers::SlotData<void()>(228, 4, QMC::AccessPrivate, QMetaType::Void),
        // Slot 'slotUpdateSatellites'
        QtMocHelpers::SlotData<void()>(229, 4, QMC::AccessPrivate, QMetaType::Void),
        // Slot 'slotConfigureNotifications'
        QtMocHelpers::SlotData<void()>(230, 4, QMC::AccessPrivate, QMetaType::Void),
        // Method 'colorScheme'
        QtMocHelpers::MethodData<QString() const>(231, 4, QMC::AccessPublic | QMC::MethodScriptable, QMetaType::QString),
        // Method 'version'
        QtMocHelpers::MethodData<QString() const>(232, 4, QMC::AccessPublic | QMC::MethodScriptable, QMetaType::QString),
        // Method 'release'
        QtMocHelpers::MethodData<QString() const>(233, 4, QMC::AccessPublic | QMC::MethodScriptable, QMetaType::QString),
    };
    QtMocHelpers::UintData qt_properties {
        // property 'colorScheme'
        QtMocHelpers::PropertyData<QString>(231, QMetaType::QString, QMC::DefaultPropertyFlags | QMC::Writable, 0),
        // property 'version'
        QtMocHelpers::PropertyData<QString>(232, QMetaType::QString, QMC::DefaultPropertyFlags),
        // property 'release'
        QtMocHelpers::PropertyData<QString>(233, QMetaType::QString, QMC::DefaultPropertyFlags),
    };
    QtMocHelpers::UintData qt_enums {
    };
    QtMocHelpers::UintData qt_constructors {};
    QtMocHelpers::ClassInfos qt_classinfo({
            {    1,    2 },
    });
    return QtMocHelpers::metaObjectData<KStars, qt_meta_tag_ZN6KStarsE_t>(QMC::MetaObjectFlag{}, qt_stringData,
            qt_methods, qt_properties, qt_enums, qt_constructors, qt_classinfo);
}
Q_CONSTINIT const QMetaObject KStars::staticMetaObject = { {
    QMetaObject::SuperData::link<KXmlGuiWindow::staticMetaObject>(),
    qt_staticMetaObjectStaticContent<qt_meta_tag_ZN6KStarsE_t>.stringdata,
    qt_staticMetaObjectStaticContent<qt_meta_tag_ZN6KStarsE_t>.data,
    qt_static_metacall,
    nullptr,
    qt_staticMetaObjectRelocatingContent<qt_meta_tag_ZN6KStarsE_t>.metaTypes,
    nullptr
} };

void KStars::qt_static_metacall(QObject *_o, QMetaObject::Call _c, int _id, void **_a)
{
    auto *_t = static_cast<KStars *>(_o);
    if (_c == QMetaObject::InvokeMetaMethod) {
        switch (_id) {
        case 0: _t->colorSchemeChanged(); break;
        case 1: _t->setRaDec((*reinterpret_cast<std::add_pointer_t<double>>(_a[1])),(*reinterpret_cast<std::add_pointer_t<double>>(_a[2]))); break;
        case 2: _t->setRaDecJ2000((*reinterpret_cast<std::add_pointer_t<double>>(_a[1])),(*reinterpret_cast<std::add_pointer_t<double>>(_a[2]))); break;
        case 3: _t->setAltAz((*reinterpret_cast<std::add_pointer_t<double>>(_a[1])),(*reinterpret_cast<std::add_pointer_t<double>>(_a[2])),(*reinterpret_cast<std::add_pointer_t<bool>>(_a[3]))); break;
        case 4: _t->setAltAz((*reinterpret_cast<std::add_pointer_t<double>>(_a[1])),(*reinterpret_cast<std::add_pointer_t<double>>(_a[2]))); break;
        case 5: _t->lookTowards((*reinterpret_cast<std::add_pointer_t<QString>>(_a[1]))); break;
        case 6: _t->addLabel((*reinterpret_cast<std::add_pointer_t<QString>>(_a[1]))); break;
        case 7: _t->removeLabel((*reinterpret_cast<std::add_pointer_t<QString>>(_a[1]))); break;
        case 8: _t->addTrail((*reinterpret_cast<std::add_pointer_t<QString>>(_a[1]))); break;
        case 9: _t->removeTrail((*reinterpret_cast<std::add_pointer_t<QString>>(_a[1]))); break;
        case 10: _t->zoomIn(); break;
        case 11: _t->zoomOut(); break;
        case 12: _t->defaultZoom(); break;
        case 13: _t->zoom((*reinterpret_cast<std::add_pointer_t<double>>(_a[1]))); break;
        case 14: _t->setLocalTime((*reinterpret_cast<std::add_pointer_t<int>>(_a[1])),(*reinterpret_cast<std::add_pointer_t<int>>(_a[2])),(*reinterpret_cast<std::add_pointer_t<int>>(_a[3])),(*reinterpret_cast<std::add_pointer_t<int>>(_a[4])),(*reinterpret_cast<std::add_pointer_t<int>>(_a[5])),(*reinterpret_cast<std::add_pointer_t<int>>(_a[6]))); break;
        case 15: _t->setTimeToNow(); break;
        case 16: _t->waitFor((*reinterpret_cast<std::add_pointer_t<double>>(_a[1]))); break;
        case 17: _t->waitForKey((*reinterpret_cast<std::add_pointer_t<QString>>(_a[1]))); break;
        case 18: _t->setTracking((*reinterpret_cast<std::add_pointer_t<bool>>(_a[1]))); break;
        case 19: _t->changeViewOption((*reinterpret_cast<std::add_pointer_t<QString>>(_a[1])),(*reinterpret_cast<std::add_pointer_t<QString>>(_a[2]))); break;
        case 20: { QDBusVariant _r = _t->getOption((*reinterpret_cast<std::add_pointer_t<QString>>(_a[1])));
            if (_a[0]) *reinterpret_cast<QDBusVariant*>(_a[0]) = std::move(_r); }  break;
        case 21: _t->setOption((*reinterpret_cast<std::add_pointer_t<QString>>(_a[1])),(*reinterpret_cast<std::add_pointer_t<QDBusVariant>>(_a[2]))); break;
        case 22: { QString _r = _t->getFocusInformationXML();
            if (_a[0]) *reinterpret_cast<QString*>(_a[0]) = std::move(_r); }  break;
        case 23: _t->readConfig(); break;
        case 24: _t->writeConfig(); break;
        case 25: _t->popupMessage((*reinterpret_cast<std::add_pointer_t<int>>(_a[1])),(*reinterpret_cast<std::add_pointer_t<int>>(_a[2])),(*reinterpret_cast<std::add_pointer_t<QString>>(_a[3]))); break;
        case 26: _t->drawLine((*reinterpret_cast<std::add_pointer_t<int>>(_a[1])),(*reinterpret_cast<std::add_pointer_t<int>>(_a[2])),(*reinterpret_cast<std::add_pointer_t<int>>(_a[3])),(*reinterpret_cast<std::add_pointer_t<int>>(_a[4])),(*reinterpret_cast<std::add_pointer_t<int>>(_a[5]))); break;
        case 27: { bool _r = _t->setGeoLocation((*reinterpret_cast<std::add_pointer_t<QString>>(_a[1])),(*reinterpret_cast<std::add_pointer_t<QString>>(_a[2])),(*reinterpret_cast<std::add_pointer_t<QString>>(_a[3])));
            if (_a[0]) *reinterpret_cast<bool*>(_a[0]) = std::move(_r); }  break;
        case 28: { QString _r = _t->location();
            if (_a[0]) *reinterpret_cast<QString*>(_a[0]) = std::move(_r); }  break;
        case 29: { bool _r = _t->setGPSLocation((*reinterpret_cast<std::add_pointer_t<double>>(_a[1])),(*reinterpret_cast<std::add_pointer_t<double>>(_a[2])),(*reinterpret_cast<std::add_pointer_t<double>>(_a[3])),(*reinterpret_cast<std::add_pointer_t<double>>(_a[4])));
            if (_a[0]) *reinterpret_cast<bool*>(_a[0]) = std::move(_r); }  break;
        case 30: _t->setColor((*reinterpret_cast<std::add_pointer_t<QString>>(_a[1])),(*reinterpret_cast<std::add_pointer_t<QString>>(_a[2]))); break;
        case 31: _t->loadColorScheme((*reinterpret_cast<std::add_pointer_t<QString>>(_a[1]))); break;
        case 32: _t->exportImage((*reinterpret_cast<std::add_pointer_t<QString>>(_a[1])),(*reinterpret_cast<std::add_pointer_t<int>>(_a[2])),(*reinterpret_cast<std::add_pointer_t<int>>(_a[3])),(*reinterpret_cast<std::add_pointer_t<bool>>(_a[4]))); break;
        case 33: _t->exportImage((*reinterpret_cast<std::add_pointer_t<QString>>(_a[1])),(*reinterpret_cast<std::add_pointer_t<int>>(_a[2])),(*reinterpret_cast<std::add_pointer_t<int>>(_a[3]))); break;
        case 34: _t->exportImage((*reinterpret_cast<std::add_pointer_t<QString>>(_a[1])),(*reinterpret_cast<std::add_pointer_t<int>>(_a[2]))); break;
        case 35: _t->exportImage((*reinterpret_cast<std::add_pointer_t<QString>>(_a[1]))); break;
        case 36: { QString _r = _t->getDSSURL((*reinterpret_cast<std::add_pointer_t<QString>>(_a[1])));
            if (_a[0]) *reinterpret_cast<QString*>(_a[0]) = std::move(_r); }  break;
        case 37: { QString _r = _t->getDSSURL((*reinterpret_cast<std::add_pointer_t<double>>(_a[1])),(*reinterpret_cast<std::add_pointer_t<double>>(_a[2])),(*reinterpret_cast<std::add_pointer_t<double>>(_a[3])),(*reinterpret_cast<std::add_pointer_t<double>>(_a[4])));
            if (_a[0]) *reinterpret_cast<QString*>(_a[0]) = std::move(_r); }  break;
        case 38: { QString _r = _t->getDSSURL((*reinterpret_cast<std::add_pointer_t<double>>(_a[1])),(*reinterpret_cast<std::add_pointer_t<double>>(_a[2])),(*reinterpret_cast<std::add_pointer_t<double>>(_a[3])));
            if (_a[0]) *reinterpret_cast<QString*>(_a[0]) = std::move(_r); }  break;
        case 39: { QString _r = _t->getDSSURL((*reinterpret_cast<std::add_pointer_t<double>>(_a[1])),(*reinterpret_cast<std::add_pointer_t<double>>(_a[2])));
            if (_a[0]) *reinterpret_cast<QString*>(_a[0]) = std::move(_r); }  break;
        case 40: { QString _r = _t->getObjectDataXML((*reinterpret_cast<std::add_pointer_t<QString>>(_a[1])),(*reinterpret_cast<std::add_pointer_t<bool>>(_a[2])),(*reinterpret_cast<std::add_pointer_t<bool>>(_a[3])));
            if (_a[0]) *reinterpret_cast<QString*>(_a[0]) = std::move(_r); }  break;
        case 41: { QString _r = _t->getObjectDataXML((*reinterpret_cast<std::add_pointer_t<QString>>(_a[1])),(*reinterpret_cast<std::add_pointer_t<bool>>(_a[2])));
            if (_a[0]) *reinterpret_cast<QString*>(_a[0]) = std::move(_r); }  break;
        case 42: { QString _r = _t->getObjectDataXML((*reinterpret_cast<std::add_pointer_t<QString>>(_a[1])));
            if (_a[0]) *reinterpret_cast<QString*>(_a[0]) = std::move(_r); }  break;
        case 43: { QString _r = _t->getObjectPositionInfo((*reinterpret_cast<std::add_pointer_t<QString>>(_a[1])));
            if (_a[0]) *reinterpret_cast<QString*>(_a[0]) = std::move(_r); }  break;
        case 44: _t->renderEyepieceView((*reinterpret_cast<std::add_pointer_t<QString>>(_a[1])),(*reinterpret_cast<std::add_pointer_t<QString>>(_a[2])),(*reinterpret_cast<std::add_pointer_t<double>>(_a[3])),(*reinterpret_cast<std::add_pointer_t<double>>(_a[4])),(*reinterpret_cast<std::add_pointer_t<double>>(_a[5])),(*reinterpret_cast<std::add_pointer_t<double>>(_a[6])),(*reinterpret_cast<std::add_pointer_t<bool>>(_a[7])),(*reinterpret_cast<std::add_pointer_t<bool>>(_a[8])),(*reinterpret_cast<std::add_pointer_t<QString>>(_a[9])),(*reinterpret_cast<std::add_pointer_t<QString>>(_a[10])),(*reinterpret_cast<std::add_pointer_t<bool>>(_a[11])),(*reinterpret_cast<std::add_pointer_t<bool>>(_a[12]))); break;
        case 45: _t->renderEyepieceView((*reinterpret_cast<std::add_pointer_t<QString>>(_a[1])),(*reinterpret_cast<std::add_pointer_t<QString>>(_a[2])),(*reinterpret_cast<std::add_pointer_t<double>>(_a[3])),(*reinterpret_cast<std::add_pointer_t<double>>(_a[4])),(*reinterpret_cast<std::add_pointer_t<double>>(_a[5])),(*reinterpret_cast<std::add_pointer_t<double>>(_a[6])),(*reinterpret_cast<std::add_pointer_t<bool>>(_a[7])),(*reinterpret_cast<std::add_pointer_t<bool>>(_a[8])),(*reinterpret_cast<std::add_pointer_t<QString>>(_a[9])),(*reinterpret_cast<std::add_pointer_t<QString>>(_a[10])),(*reinterpret_cast<std::add_pointer_t<bool>>(_a[11]))); break;
        case 46: _t->renderEyepieceView((*reinterpret_cast<std::add_pointer_t<QString>>(_a[1])),(*reinterpret_cast<std::add_pointer_t<QString>>(_a[2])),(*reinterpret_cast<std::add_pointer_t<double>>(_a[3])),(*reinterpret_cast<std::add_pointer_t<double>>(_a[4])),(*reinterpret_cast<std::add_pointer_t<double>>(_a[5])),(*reinterpret_cast<std::add_pointer_t<double>>(_a[6])),(*reinterpret_cast<std::add_pointer_t<bool>>(_a[7])),(*reinterpret_cast<std::add_pointer_t<bool>>(_a[8])),(*reinterpret_cast<std::add_pointer_t<QString>>(_a[9])),(*reinterpret_cast<std::add_pointer_t<QString>>(_a[10]))); break;
        case 47: _t->renderEyepieceView((*reinterpret_cast<std::add_pointer_t<QString>>(_a[1])),(*reinterpret_cast<std::add_pointer_t<QString>>(_a[2])),(*reinterpret_cast<std::add_pointer_t<double>>(_a[3])),(*reinterpret_cast<std::add_pointer_t<double>>(_a[4])),(*reinterpret_cast<std::add_pointer_t<double>>(_a[5])),(*reinterpret_cast<std::add_pointer_t<double>>(_a[6])),(*reinterpret_cast<std::add_pointer_t<bool>>(_a[7])),(*reinterpret_cast<std::add_pointer_t<bool>>(_a[8])),(*reinterpret_cast<std::add_pointer_t<QString>>(_a[9]))); break;
        case 48: _t->renderEyepieceView((*reinterpret_cast<std::add_pointer_t<QString>>(_a[1])),(*reinterpret_cast<std::add_pointer_t<QString>>(_a[2])),(*reinterpret_cast<std::add_pointer_t<double>>(_a[3])),(*reinterpret_cast<std::add_pointer_t<double>>(_a[4])),(*reinterpret_cast<std::add_pointer_t<double>>(_a[5])),(*reinterpret_cast<std::add_pointer_t<double>>(_a[6])),(*reinterpret_cast<std::add_pointer_t<bool>>(_a[7])),(*reinterpret_cast<std::add_pointer_t<bool>>(_a[8]))); break;
        case 49: _t->renderEyepieceView((*reinterpret_cast<std::add_pointer_t<QString>>(_a[1])),(*reinterpret_cast<std::add_pointer_t<QString>>(_a[2])),(*reinterpret_cast<std::add_pointer_t<double>>(_a[3])),(*reinterpret_cast<std::add_pointer_t<double>>(_a[4])),(*reinterpret_cast<std::add_pointer_t<double>>(_a[5])),(*reinterpret_cast<std::add_pointer_t<double>>(_a[6])),(*reinterpret_cast<std::add_pointer_t<bool>>(_a[7]))); break;
        case 50: _t->renderEyepieceView((*reinterpret_cast<std::add_pointer_t<QString>>(_a[1])),(*reinterpret_cast<std::add_pointer_t<QString>>(_a[2])),(*reinterpret_cast<std::add_pointer_t<double>>(_a[3])),(*reinterpret_cast<std::add_pointer_t<double>>(_a[4])),(*reinterpret_cast<std::add_pointer_t<double>>(_a[5])),(*reinterpret_cast<std::add_pointer_t<double>>(_a[6]))); break;
        case 51: _t->renderEyepieceView((*reinterpret_cast<std::add_pointer_t<QString>>(_a[1])),(*reinterpret_cast<std::add_pointer_t<QString>>(_a[2])),(*reinterpret_cast<std::add_pointer_t<double>>(_a[3])),(*reinterpret_cast<std::add_pointer_t<double>>(_a[4])),(*reinterpret_cast<std::add_pointer_t<double>>(_a[5]))); break;
        case 52: _t->renderEyepieceView((*reinterpret_cast<std::add_pointer_t<QString>>(_a[1])),(*reinterpret_cast<std::add_pointer_t<QString>>(_a[2])),(*reinterpret_cast<std::add_pointer_t<double>>(_a[3])),(*reinterpret_cast<std::add_pointer_t<double>>(_a[4]))); break;
        case 53: _t->renderEyepieceView((*reinterpret_cast<std::add_pointer_t<QString>>(_a[1])),(*reinterpret_cast<std::add_pointer_t<QString>>(_a[2])),(*reinterpret_cast<std::add_pointer_t<double>>(_a[3]))); break;
        case 54: _t->renderEyepieceView((*reinterpret_cast<std::add_pointer_t<QString>>(_a[1])),(*reinterpret_cast<std::add_pointer_t<QString>>(_a[2]))); break;
        case 55: _t->setApproxFOV((*reinterpret_cast<std::add_pointer_t<double>>(_a[1]))); break;
        case 56: { QString _r = _t->getSkyMapDimensions();
            if (_a[0]) *reinterpret_cast<QString*>(_a[0]) = std::move(_r); }  break;
        case 57: { QString _r = _t->getObservingWishListObjectNames();
            if (_a[0]) *reinterpret_cast<QString*>(_a[0]) = std::move(_r); }  break;
        case 58: { QString _r = _t->getObservingSessionPlanObjectNames();
            if (_a[0]) *reinterpret_cast<QString*>(_a[0]) = std::move(_r); }  break;
        case 59: _t->printImage((*reinterpret_cast<std::add_pointer_t<bool>>(_a[1])),(*reinterpret_cast<std::add_pointer_t<bool>>(_a[2]))); break;
        case 60: _t->openFITS((*reinterpret_cast<std::add_pointer_t<QUrl>>(_a[1]))); break;
        case 61: { QStringList _r = _t->listSkyMapViews();
            if (_a[0]) *reinterpret_cast<QStringList*>(_a[0]) = std::move(_r); }  break;
        case 62: { bool _r = _t->setSkyMapView((*reinterpret_cast<std::add_pointer_t<QString>>(_a[1])));
            if (_a[0]) *reinterpret_cast<bool*>(_a[0]) = std::move(_r); }  break;
        case 63: { bool _r = _t->setFOVIndicatorVisibility((*reinterpret_cast<std::add_pointer_t<QString>>(_a[1])),(*reinterpret_cast<std::add_pointer_t<bool>>(_a[2])));
            if (_a[0]) *reinterpret_cast<bool*>(_a[0]) = std::move(_r); }  break;
        case 64: { bool _r = _t->getFOVIndicatorVisibility((*reinterpret_cast<std::add_pointer_t<QString>>(_a[1])));
            if (_a[0]) *reinterpret_cast<bool*>(_a[0]) = std::move(_r); }  break;
        case 65: { QStringList _r = _t->getFOVIndicators();
            if (_a[0]) *reinterpret_cast<QStringList*>(_a[0]) = std::move(_r); }  break;
        case 66: _t->setSkyMapRotation((*reinterpret_cast<std::add_pointer_t<double>>(_a[1]))); break;
        case 67: { double _r = _t->getSkyMapRotation();
            if (_a[0]) *reinterpret_cast<double*>(_a[0]) = std::move(_r); }  break;
        case 68: { bool _r = _t->skyMapIsMirrored();
            if (_a[0]) *reinterpret_cast<bool*>(_a[0]) = std::move(_r); }  break;
        case 69: _t->setSkyMapMirrored((*reinterpret_cast<std::add_pointer_t<bool>>(_a[1]))); break;
        case 70: { QString _r = _t->getToggleableActionStates();
            if (_a[0]) *reinterpret_cast<QString*>(_a[0]) = std::move(_r); }  break;
        case 71: { bool _r = _t->activateAction((*reinterpret_cast<std::add_pointer_t<QString>>(_a[1])));
            if (_a[0]) *reinterpret_cast<bool*>(_a[0]) = std::move(_r); }  break;
        case 72: { QStringList _r = _t->getActions();
            if (_a[0]) *reinterpret_cast<QStringList*>(_a[0]) = std::move(_r); }  break;
        case 73: { bool _r = _t->setToggleableActionState((*reinterpret_cast<std::add_pointer_t<QString>>(_a[1])),(*reinterpret_cast<std::add_pointer_t<bool>>(_a[2])));
            if (_a[0]) *reinterpret_cast<bool*>(_a[0]) = std::move(_r); }  break;
        case 74: _t->updateTime((*reinterpret_cast<std::add_pointer_t<bool>>(_a[1]))); break;
        case 75: _t->updateTime(); break;
        case 76: _t->slotSetTimeToNow(); break;
        case 77: _t->slotApplyConfigChanges(); break;
        case 78: _t->slotApplyWIConfigChanges(); break;
        case 79: _t->slotZoomChanged(); break;
        case 80: _t->slotSetZoom(); break;
        case 81: _t->slotTrack(); break;
        case 82: _t->slotGeoLocator(); break;
        case 83: _t->slotSetTelescopeEnabled((*reinterpret_cast<std::add_pointer_t<bool>>(_a[1]))); break;
        case 84: _t->slotSetDomeEnabled((*reinterpret_cast<std::add_pointer_t<bool>>(_a[1]))); break;
        case 85: _t->clearCachedFindDialog(); break;
        case 86: _t->slotClearAllTrails(); break;
        case 87: _t->slotShowPositionBar((*reinterpret_cast<std::add_pointer_t<SkyPoint*>>(_a[1]))); break;
        case 88: _t->slotFlagManager(); break;
        case 89: _t->slotDSOCatalogGUI(); break;
        case 90: _t->slotWizard(); break;
        case 91: _t->updateLocationFromWizard((*reinterpret_cast<std::add_pointer_t<GeoLocation>>(_a[1]))); break;
        case 92: { WIView* _r = _t->wiView();
            if (_a[0]) *reinterpret_cast<WIView**>(_a[0]) = std::move(_r); }  break;
        case 93: { bool _r = _t->isWIVisible();
            if (_a[0]) *reinterpret_cast<bool*>(_a[0]) = std::move(_r); }  break;
        case 94: _t->slotWISettings(); break;
        case 95: _t->slotToggleWIView(); break;
        case 96: _t->slotDownload(); break;
        case 97: _t->slotSetTime(); break;
        case 98: _t->slotToggleTimer(); break;
        case 99: _t->slotRealTimeToogled((*reinterpret_cast<std::add_pointer_t<bool>>(_a[1]))); break;
        case 100: _t->slotStepForward(); break;
        case 101: _t->slotStepBackward(); break;
        case 102: _t->slotFind(); break;
        case 103: _t->slotCalculator(); break;
        case 104: _t->slotAVT(); break;
        case 105: _t->slotWUT(); break;
        case 106: _t->slotCalendar(); break;
        case 107: _t->slotGlossary(); break;
        case 108: _t->slotScriptBuilder(); break;
        case 109: _t->slotSolarSystem(); break;
        case 110: _t->slotJMoonTool(); break;
        case 111: _t->slotMoonPhaseTool(); break;
        case 112: _t->slotINDIDriver(); break;
        case 113: _t->slotINDIPanel(); break;
        case 114: _t->slotEkos(); break;
        case 115: _t->slotPushToAssistant(); break;
        case 116: _t->slotINDITelescopeTrack(); break;
        case 117: _t->slotINDITelescopeSlew((*reinterpret_cast<std::add_pointer_t<bool>>(_a[1]))); break;
        case 118: _t->slotINDITelescopeSlew(); break;
        case 119: _t->slotINDITelescopeSlewMousePointer(); break;
        case 120: _t->slotINDITelescopeSync((*reinterpret_cast<std::add_pointer_t<bool>>(_a[1]))); break;
        case 121: _t->slotINDITelescopeSync(); break;
        case 122: _t->slotINDITelescopeSyncMousePointer(); break;
        case 123: _t->slotINDITelescopeAbort(); break;
        case 124: _t->slotINDITelescopePark(); break;
        case 125: _t->slotINDITelescopeUnpark(); break;
        case 126: _t->slotINDIDomePark(); break;
        case 127: _t->slotINDIDomeUnpark(); break;
        case 128: _t->slotViewOps(); break;
        case 129: _t->datainitFinished(); break;
        case 130: _t->slotOpenFITS(); break;
        case 131: _t->slotBlink(); break;
        case 132: _t->slotStack(); break;
        case 133: _t->slotExportImage(); break;
        case 134: _t->slotRunScript(); break;
        case 135: _t->slotPrint(); break;
        case 136: _t->slotPrintingWizard(); break;
        case 137: _t->slotManualFocus(); break;
        case 138: _t->slotPointFocus(); break;
        case 139: _t->slotColorScheme(); break;
        case 140: _t->slotThemeChanged(); break;
        case 141: _t->slotTargetSymbol((*reinterpret_cast<std::add_pointer_t<bool>>(_a[1]))); break;
        case 142: { bool _r = _t->slotApplySkyMapView((*reinterpret_cast<std::add_pointer_t<QString>>(_a[1])));
            if (_a[0]) *reinterpret_cast<bool*>(_a[0]) = std::move(_r); }  break;
        case 143: _t->slotHIPSSource(); break;
        case 144: _t->slotEditViews(); break;
        case 145: _t->slotFOVEdit(); break;
        case 146: _t->slotCoordSys(); break;
        case 147: _t->slotMapProjection(); break;
        case 148: _t->slotSkyMapOrientation(); break;
        case 149: _t->slotObsList(); break;
        case 150: _t->slotImagingPlanner(); break;
        case 151: _t->slotViewToolBar(); break;
        case 152: _t->slotINDIToolBar(); break;
        case 153: _t->slotShowGUIItem((*reinterpret_cast<std::add_pointer_t<bool>>(_a[1]))); break;
        case 154: _t->slotFullScreen(); break;
        case 155: _t->slotTerrain(); break;
        case 156: _t->slotImageOverlays(); break;
        case 157: _t->slotAboutToQuit(); break;
        case 158: _t->slotEquipmentWriter(); break;
        case 159: _t->slotObserverManager(); break;
        case 160: _t->slotHorizonManager(); break;
        case 161: _t->slotExecute(); break;
        case 162: _t->slotPolarisHourAngle(); break;
        case 163: _t->slotUpdateComets((*reinterpret_cast<std::add_pointer_t<bool>>(_a[1]))); break;
        case 164: _t->slotUpdateComets(); break;
        case 165: _t->slotUpdateAsteroids((*reinterpret_cast<std::add_pointer_t<bool>>(_a[1]))); break;
        case 166: _t->slotUpdateAsteroids(); break;
        case 167: _t->slotUpdateSupernovae(); break;
        case 168: _t->slotUpdateSatellites(); break;
        case 169: _t->slotConfigureNotifications(); break;
        case 170: { QString _r = _t->colorScheme();
            if (_a[0]) *reinterpret_cast<QString*>(_a[0]) = std::move(_r); }  break;
        case 171: { QString _r = _t->version();
            if (_a[0]) *reinterpret_cast<QString*>(_a[0]) = std::move(_r); }  break;
        case 172: { QString _r = _t->release();
            if (_a[0]) *reinterpret_cast<QString*>(_a[0]) = std::move(_r); }  break;
        default: ;
        }
    }
    if (_c == QMetaObject::RegisterMethodArgumentMetaType) {
        switch (_id) {
        default: *reinterpret_cast<QMetaType *>(_a[0]) = QMetaType(); break;
        case 21:
            switch (*reinterpret_cast<int*>(_a[1])) {
            default: *reinterpret_cast<QMetaType *>(_a[0]) = QMetaType(); break;
            case 1:
                *reinterpret_cast<QMetaType *>(_a[0]) = QMetaType::fromType< QDBusVariant >(); break;
            }
            break;
        }
    }
    if (_c == QMetaObject::IndexOfMethod) {
        if (QtMocHelpers::indexOfMethod<void (KStars::*)()>(_a, &KStars::colorSchemeChanged, 0))
            return;
    }
    if (_c == QMetaObject::ReadProperty) {
        void *_v = _a[0];
        switch (_id) {
        case 0: *reinterpret_cast<QString*>(_v) = _t->colorScheme(); break;
        case 1: *reinterpret_cast<QString*>(_v) = _t->version(); break;
        case 2: *reinterpret_cast<QString*>(_v) = _t->release(); break;
        default: break;
        }
    }
    if (_c == QMetaObject::WriteProperty) {
        void *_v = _a[0];
        switch (_id) {
        case 0: _t->loadColorScheme(*reinterpret_cast<QString*>(_v)); break;
        default: break;
        }
    }
}

const QMetaObject *KStars::metaObject() const
{
    return QObject::d_ptr->metaObject ? QObject::d_ptr->dynamicMetaObject() : &staticMetaObject;
}

void *KStars::qt_metacast(const char *_clname)
{
    if (!_clname) return nullptr;
    if (!strcmp(_clname, qt_staticMetaObjectStaticContent<qt_meta_tag_ZN6KStarsE_t>.strings))
        return static_cast<void*>(this);
    return KXmlGuiWindow::qt_metacast(_clname);
}

int KStars::qt_metacall(QMetaObject::Call _c, int _id, void **_a)
{
    _id = KXmlGuiWindow::qt_metacall(_c, _id, _a);
    if (_id < 0)
        return _id;
    if (_c == QMetaObject::InvokeMetaMethod) {
        if (_id < 173)
            qt_static_metacall(this, _c, _id, _a);
        _id -= 173;
    }
    if (_c == QMetaObject::RegisterMethodArgumentMetaType) {
        if (_id < 173)
            qt_static_metacall(this, _c, _id, _a);
        _id -= 173;
    }
    if (_c == QMetaObject::ReadProperty || _c == QMetaObject::WriteProperty
            || _c == QMetaObject::ResetProperty || _c == QMetaObject::BindableProperty
            || _c == QMetaObject::RegisterPropertyMetaType) {
        qt_static_metacall(this, _c, _id, _a);
        _id -= 3;
    }
    return _id;
}

// SIGNAL 0
void KStars::colorSchemeChanged()
{
    QMetaObject::activate(this, &staticMetaObject, 0, nullptr);
}
QT_WARNING_POP
