/****************************************************************************
** Meta object code from reading C++ file 'wiview.h'
**
** Created by: The Qt Meta Object Compiler version 69 (Qt 6.11.1)
**
** WARNING! All changes made in this file will be lost!
*****************************************************************************/

#include "../../../../kstars-3.8.4.1/kstars/tools/whatsinteresting/wiview.h"
#include <QtCore/qmetatype.h>

#include <QtCore/qtmochelpers.h>

#include <memory>


#include <QtCore/qxptype_traits.h>
#if !defined(Q_MOC_OUTPUT_REVISION)
#error "The header file 'wiview.h' doesn't include <QObject>."
#elif Q_MOC_OUTPUT_REVISION != 69
#error "This file was generated using the moc from 6.11.1. It"
#error "cannot be used with the include files from this version of Qt."
#error "(The moc has changed too much.)"
#endif

#ifndef Q_CONSTINIT
#define Q_CONSTINIT
#endif

QT_WARNING_PUSH
QT_WARNING_DISABLE_DEPRECATED
QT_WARNING_DISABLE_GCC("-Wuseless-cast")
namespace {
struct qt_meta_tag_ZN6WIViewE_t {};
} // unnamed namespace

template <> constexpr inline auto WIView::qt_create_metaobjectdata<qt_meta_tag_ZN6WIViewE_t>()
{
    namespace QMC = QtMocConstants;
    QtMocHelpers::StringRefStorage qt_stringData {
        "WIView",
        "onCategorySelected",
        "",
        "model",
        "onSoListItemClicked",
        "index",
        "onNextObjClicked",
        "onPrevObjClicked",
        "onCenterButtonClicked",
        "onSlewTelescopeButtonClicked",
        "onDetailsButtonClicked",
        "onSettingsIconClicked",
        "onInspectIconClicked",
        "checked",
        "onReloadIconClicked",
        "onVisibleIconClicked",
        "onFavoriteIconClicked",
        "onUpdateIconClicked",
        "updateWikipediaDescription",
        "SkyObjItem*",
        "soitem",
        "loadObjectDescription",
        "tryToUpdateWikipediaInfo",
        "name",
        "loadObjectInfoBox",
        "saveImageURL",
        "imageURL",
        "saveInfoURL",
        "infoURL",
        "saveObjectInfoBoxText",
        "type",
        "infoText",
        "downloadWikipediaImage",
        "inspectSkyObject",
        "inspectSkyObjectOnClick",
        "SkyObject*",
        "obj",
        "inspectOnClickIsActive",
        "updateObservingConditions",
        "tryToUpdateWikipediaInfoInModel",
        "onlyMissing",
        "refreshListView",
        "updateProgress",
        "value",
        "setProgressBarVisible",
        "visible",
        "setNightVisionOn",
        "on"
    };

    QtMocHelpers::UintData qt_methods {
        // Slot 'onCategorySelected'
        QtMocHelpers::SlotData<void(QString)>(1, 2, QMC::AccessPublic, QMetaType::Void, {{
            { QMetaType::QString, 3 },
        }}),
        // Slot 'onSoListItemClicked'
        QtMocHelpers::SlotData<void(int)>(4, 2, QMC::AccessPublic, QMetaType::Void, {{
            { QMetaType::Int, 5 },
        }}),
        // Slot 'onNextObjClicked'
        QtMocHelpers::SlotData<void()>(6, 2, QMC::AccessPublic, QMetaType::Void),
        // Slot 'onPrevObjClicked'
        QtMocHelpers::SlotData<void()>(7, 2, QMC::AccessPublic, QMetaType::Void),
        // Slot 'onCenterButtonClicked'
        QtMocHelpers::SlotData<void()>(8, 2, QMC::AccessPublic, QMetaType::Void),
        // Slot 'onSlewTelescopeButtonClicked'
        QtMocHelpers::SlotData<void()>(9, 2, QMC::AccessPublic, QMetaType::Void),
        // Slot 'onDetailsButtonClicked'
        QtMocHelpers::SlotData<void()>(10, 2, QMC::AccessPublic, QMetaType::Void),
        // Slot 'onSettingsIconClicked'
        QtMocHelpers::SlotData<void()>(11, 2, QMC::AccessPublic, QMetaType::Void),
        // Slot 'onInspectIconClicked'
        QtMocHelpers::SlotData<void(bool)>(12, 2, QMC::AccessPublic, QMetaType::Void, {{
            { QMetaType::Bool, 13 },
        }}),
        // Slot 'onReloadIconClicked'
        QtMocHelpers::SlotData<void()>(14, 2, QMC::AccessPublic, QMetaType::Void),
        // Slot 'onVisibleIconClicked'
        QtMocHelpers::SlotData<void(bool)>(15, 2, QMC::AccessPublic, QMetaType::Void, {{
            { QMetaType::Bool, 13 },
        }}),
        // Slot 'onFavoriteIconClicked'
        QtMocHelpers::SlotData<void(bool)>(16, 2, QMC::AccessPublic, QMetaType::Void, {{
            { QMetaType::Bool, 13 },
        }}),
        // Slot 'onUpdateIconClicked'
        QtMocHelpers::SlotData<void()>(17, 2, QMC::AccessPublic, QMetaType::Void),
        // Slot 'updateWikipediaDescription'
        QtMocHelpers::SlotData<void(SkyObjItem *)>(18, 2, QMC::AccessPublic, QMetaType::Void, {{
            { 0x80000000 | 19, 20 },
        }}),
        // Slot 'loadObjectDescription'
        QtMocHelpers::SlotData<void(SkyObjItem *)>(21, 2, QMC::AccessPublic, QMetaType::Void, {{
            { 0x80000000 | 19, 20 },
        }}),
        // Slot 'tryToUpdateWikipediaInfo'
        QtMocHelpers::SlotData<void(SkyObjItem *, QString)>(22, 2, QMC::AccessPublic, QMetaType::Void, {{
            { 0x80000000 | 19, 20 }, { QMetaType::QString, 23 },
        }}),
        // Slot 'loadObjectInfoBox'
        QtMocHelpers::SlotData<void(SkyObjItem *)>(24, 2, QMC::AccessPublic, QMetaType::Void, {{
            { 0x80000000 | 19, 20 },
        }}),
        // Slot 'saveImageURL'
        QtMocHelpers::SlotData<void(SkyObjItem *, QString)>(25, 2, QMC::AccessPublic, QMetaType::Void, {{
            { 0x80000000 | 19, 20 }, { QMetaType::QString, 26 },
        }}),
        // Slot 'saveInfoURL'
        QtMocHelpers::SlotData<void(SkyObjItem *, QString)>(27, 2, QMC::AccessPublic, QMetaType::Void, {{
            { 0x80000000 | 19, 20 }, { QMetaType::QString, 28 },
        }}),
        // Slot 'saveObjectInfoBoxText'
        QtMocHelpers::SlotData<void(SkyObjItem *, QString, QString)>(29, 2, QMC::AccessPublic, QMetaType::Void, {{
            { 0x80000000 | 19, 20 }, { QMetaType::QString, 30 }, { QMetaType::QString, 31 },
        }}),
        // Slot 'downloadWikipediaImage'
        QtMocHelpers::SlotData<void(SkyObjItem *, QString)>(32, 2, QMC::AccessPublic, QMetaType::Void, {{
            { 0x80000000 | 19, 20 }, { QMetaType::QString, 26 },
        }}),
        // Slot 'inspectSkyObject'
        QtMocHelpers::SlotData<void(const QString &)>(33, 2, QMC::AccessPublic, QMetaType::Void, {{
            { QMetaType::QString, 23 },
        }}),
        // Slot 'inspectSkyObjectOnClick'
        QtMocHelpers::SlotData<void(SkyObject *)>(34, 2, QMC::AccessPublic, QMetaType::Void, {{
            { 0x80000000 | 35, 36 },
        }}),
        // Slot 'inspectSkyObject'
        QtMocHelpers::SlotData<void(SkyObject *)>(33, 2, QMC::AccessPublic, QMetaType::Void, {{
            { 0x80000000 | 35, 36 },
        }}),
        // Slot 'inspectOnClickIsActive'
        QtMocHelpers::SlotData<bool()>(37, 2, QMC::AccessPublic, QMetaType::Bool),
        // Slot 'updateObservingConditions'
        QtMocHelpers::SlotData<void()>(38, 2, QMC::AccessPublic, QMetaType::Void),
        // Slot 'tryToUpdateWikipediaInfoInModel'
        QtMocHelpers::SlotData<void(bool)>(39, 2, QMC::AccessPublic, QMetaType::Void, {{
            { QMetaType::Bool, 40 },
        }}),
        // Slot 'refreshListView'
        QtMocHelpers::SlotData<void()>(41, 2, QMC::AccessPublic, QMetaType::Void),
        // Slot 'updateProgress'
        QtMocHelpers::SlotData<void(double)>(42, 2, QMC::AccessPublic, QMetaType::Void, {{
            { QMetaType::Double, 43 },
        }}),
        // Slot 'setProgressBarVisible'
        QtMocHelpers::SlotData<void(bool)>(44, 2, QMC::AccessPublic, QMetaType::Void, {{
            { QMetaType::Bool, 45 },
        }}),
        // Slot 'setNightVisionOn'
        QtMocHelpers::SlotData<void(bool)>(46, 2, QMC::AccessPublic, QMetaType::Void, {{
            { QMetaType::Bool, 47 },
        }}),
    };
    QtMocHelpers::UintData qt_properties {
    };
    QtMocHelpers::UintData qt_enums {
    };
    return QtMocHelpers::metaObjectData<WIView, qt_meta_tag_ZN6WIViewE_t>(QMC::MetaObjectFlag{}, qt_stringData,
            qt_methods, qt_properties, qt_enums);
}
Q_CONSTINIT const QMetaObject WIView::staticMetaObject = { {
    QMetaObject::SuperData::link<QWidget::staticMetaObject>(),
    qt_staticMetaObjectStaticContent<qt_meta_tag_ZN6WIViewE_t>.stringdata,
    qt_staticMetaObjectStaticContent<qt_meta_tag_ZN6WIViewE_t>.data,
    qt_static_metacall,
    nullptr,
    qt_staticMetaObjectRelocatingContent<qt_meta_tag_ZN6WIViewE_t>.metaTypes,
    nullptr
} };

void WIView::qt_static_metacall(QObject *_o, QMetaObject::Call _c, int _id, void **_a)
{
    auto *_t = static_cast<WIView *>(_o);
    if (_c == QMetaObject::InvokeMetaMethod) {
        switch (_id) {
        case 0: _t->onCategorySelected((*reinterpret_cast<std::add_pointer_t<QString>>(_a[1]))); break;
        case 1: _t->onSoListItemClicked((*reinterpret_cast<std::add_pointer_t<int>>(_a[1]))); break;
        case 2: _t->onNextObjClicked(); break;
        case 3: _t->onPrevObjClicked(); break;
        case 4: _t->onCenterButtonClicked(); break;
        case 5: _t->onSlewTelescopeButtonClicked(); break;
        case 6: _t->onDetailsButtonClicked(); break;
        case 7: _t->onSettingsIconClicked(); break;
        case 8: _t->onInspectIconClicked((*reinterpret_cast<std::add_pointer_t<bool>>(_a[1]))); break;
        case 9: _t->onReloadIconClicked(); break;
        case 10: _t->onVisibleIconClicked((*reinterpret_cast<std::add_pointer_t<bool>>(_a[1]))); break;
        case 11: _t->onFavoriteIconClicked((*reinterpret_cast<std::add_pointer_t<bool>>(_a[1]))); break;
        case 12: _t->onUpdateIconClicked(); break;
        case 13: _t->updateWikipediaDescription((*reinterpret_cast<std::add_pointer_t<SkyObjItem*>>(_a[1]))); break;
        case 14: _t->loadObjectDescription((*reinterpret_cast<std::add_pointer_t<SkyObjItem*>>(_a[1]))); break;
        case 15: _t->tryToUpdateWikipediaInfo((*reinterpret_cast<std::add_pointer_t<SkyObjItem*>>(_a[1])),(*reinterpret_cast<std::add_pointer_t<QString>>(_a[2]))); break;
        case 16: _t->loadObjectInfoBox((*reinterpret_cast<std::add_pointer_t<SkyObjItem*>>(_a[1]))); break;
        case 17: _t->saveImageURL((*reinterpret_cast<std::add_pointer_t<SkyObjItem*>>(_a[1])),(*reinterpret_cast<std::add_pointer_t<QString>>(_a[2]))); break;
        case 18: _t->saveInfoURL((*reinterpret_cast<std::add_pointer_t<SkyObjItem*>>(_a[1])),(*reinterpret_cast<std::add_pointer_t<QString>>(_a[2]))); break;
        case 19: _t->saveObjectInfoBoxText((*reinterpret_cast<std::add_pointer_t<SkyObjItem*>>(_a[1])),(*reinterpret_cast<std::add_pointer_t<QString>>(_a[2])),(*reinterpret_cast<std::add_pointer_t<QString>>(_a[3]))); break;
        case 20: _t->downloadWikipediaImage((*reinterpret_cast<std::add_pointer_t<SkyObjItem*>>(_a[1])),(*reinterpret_cast<std::add_pointer_t<QString>>(_a[2]))); break;
        case 21: _t->inspectSkyObject((*reinterpret_cast<std::add_pointer_t<QString>>(_a[1]))); break;
        case 22: _t->inspectSkyObjectOnClick((*reinterpret_cast<std::add_pointer_t<SkyObject*>>(_a[1]))); break;
        case 23: _t->inspectSkyObject((*reinterpret_cast<std::add_pointer_t<SkyObject*>>(_a[1]))); break;
        case 24: { bool _r = _t->inspectOnClickIsActive();
            if (_a[0]) *reinterpret_cast<bool*>(_a[0]) = std::move(_r); }  break;
        case 25: _t->updateObservingConditions(); break;
        case 26: _t->tryToUpdateWikipediaInfoInModel((*reinterpret_cast<std::add_pointer_t<bool>>(_a[1]))); break;
        case 27: _t->refreshListView(); break;
        case 28: _t->updateProgress((*reinterpret_cast<std::add_pointer_t<double>>(_a[1]))); break;
        case 29: _t->setProgressBarVisible((*reinterpret_cast<std::add_pointer_t<bool>>(_a[1]))); break;
        case 30: _t->setNightVisionOn((*reinterpret_cast<std::add_pointer_t<bool>>(_a[1]))); break;
        default: ;
        }
    }
}

const QMetaObject *WIView::metaObject() const
{
    return QObject::d_ptr->metaObject ? QObject::d_ptr->dynamicMetaObject() : &staticMetaObject;
}

void *WIView::qt_metacast(const char *_clname)
{
    if (!_clname) return nullptr;
    if (!strcmp(_clname, qt_staticMetaObjectStaticContent<qt_meta_tag_ZN6WIViewE_t>.strings))
        return static_cast<void*>(this);
    return QWidget::qt_metacast(_clname);
}

int WIView::qt_metacall(QMetaObject::Call _c, int _id, void **_a)
{
    _id = QWidget::qt_metacall(_c, _id, _a);
    if (_id < 0)
        return _id;
    if (_c == QMetaObject::InvokeMetaMethod) {
        if (_id < 31)
            qt_static_metacall(this, _c, _id, _a);
        _id -= 31;
    }
    if (_c == QMetaObject::RegisterMethodArgumentMetaType) {
        if (_id < 31)
            *reinterpret_cast<QMetaType *>(_a[0]) = QMetaType();
        _id -= 31;
    }
    return _id;
}
QT_WARNING_POP
