/********************************************************************************
** Form generated from reading UI file 'opslogs.ui'
**
** Created by: Qt User Interface Compiler version 6.11.1
**
** WARNING! All changes made in this file will be lost when recompiling UI file!
********************************************************************************/

#ifndef UI_OPSLOGS_H
#define UI_OPSLOGS_H

#include <QtCore/QVariant>
#include <QtGui/QIcon>
#include <QtWidgets/QApplication>
#include <QtWidgets/QButtonGroup>
#include <QtWidgets/QCheckBox>
#include <QtWidgets/QFrame>
#include <QtWidgets/QGridLayout>
#include <QtWidgets/QGroupBox>
#include <QtWidgets/QHBoxLayout>
#include <QtWidgets/QLabel>
#include <QtWidgets/QPushButton>
#include <QtWidgets/QRadioButton>
#include <QtWidgets/QSpacerItem>
#include <QtWidgets/QVBoxLayout>
#include <QtWidgets/QWidget>
#include <klocalizedstring.h>

QT_BEGIN_NAMESPACE

class Ui_OpsLogs
{
public:
    QVBoxLayout *verticalLayout;
    QHBoxLayout *horizontalLayout_3;
    QLabel *label;
    QLabel *label_2;
    QGroupBox *groupBox;
    QGridLayout *gridLayout;
    QCheckBox *kcfg_INDIMountLogging;
    QCheckBox *kcfg_SchedulerLogging;
    QCheckBox *kcfg_INDIWeatherLogging;
    QFrame *line_3;
    QCheckBox *kcfg_GuideLogging;
    QLabel *label_6;
    QRadioButton *kcfg_RegularLogging;
    QLabel *label_5;
    QFrame *line;
    QRadioButton *kcfg_DisableLogging;
    QCheckBox *kcfg_INDILogging;
    QCheckBox *kcfg_FITSLogging;
    QRadioButton *kcfg_LogToFile;
    QCheckBox *kcfg_INDIAuxiliaryLogging;
    QRadioButton *kcfg_LogToDefault;
    QCheckBox *kcfg_INDIDomeLogging;
    QCheckBox *kcfg_INDICCDLogging;
    QLabel *label_4;
    QCheckBox *kcfg_INDIFilterWheelLogging;
    QCheckBox *kcfg_CaptureLogging;
    QCheckBox *kcfg_INDIGPSLogging;
    QCheckBox *kcfg_AlignmentLogging;
    QCheckBox *kcfg_ObservatoryLogging;
    QRadioButton *kcfg_VerboseLogging;
    QCheckBox *kcfg_INDIDetectorLogging;
    QCheckBox *kcfg_INDIAOLogging;
    QCheckBox *kcfg_FocusLogging;
    QCheckBox *kcfg_INDIFocuserLogging;
    QCheckBox *kcfg_INDIRotatorLogging;
    QLabel *label_9;
    QCheckBox *kcfg_MountLogging;
    QHBoxLayout *horizontalLayout_2;
    QCheckBox *kcfg_showINDIMessages;
    QSpacerItem *horizontalSpacer_8;
    QPushButton *showLogsB;
    QPushButton *clearLogsB;
    QButtonGroup *driversGroup;
    QButtonGroup *modulesGroup;
    QButtonGroup *verbosityButtonGroup;

    void setupUi(QWidget *OpsLogs)
    {
        if (OpsLogs->objectName().isEmpty())
            OpsLogs->setObjectName("OpsLogs");
        OpsLogs->resize(592, 430);
        verticalLayout = new QVBoxLayout(OpsLogs);
        verticalLayout->setSpacing(3);
        verticalLayout->setObjectName("verticalLayout");
        verticalLayout->setContentsMargins(3, 3, 3, 3);
        horizontalLayout_3 = new QHBoxLayout();
        horizontalLayout_3->setObjectName("horizontalLayout_3");
        label = new QLabel(OpsLogs);
        label->setObjectName("label");
        label->setMinimumSize(QSize(48, 48));
        label->setMaximumSize(QSize(48, 48));
        label->setPixmap(QPixmap(QString::fromUtf8(":/icons/AlignWarning.svg")));
        label->setScaledContents(true);

        horizontalLayout_3->addWidget(label);

        label_2 = new QLabel(OpsLogs);
        label_2->setObjectName("label_2");
        label_2->setWordWrap(true);

        horizontalLayout_3->addWidget(label_2);


        verticalLayout->addLayout(horizontalLayout_3);

        groupBox = new QGroupBox(OpsLogs);
        groupBox->setObjectName("groupBox");
        gridLayout = new QGridLayout(groupBox);
        gridLayout->setObjectName("gridLayout");
        kcfg_INDIMountLogging = new QCheckBox(groupBox);
        driversGroup = new QButtonGroup(OpsLogs);
        driversGroup->setObjectName("driversGroup");
        driversGroup->setExclusive(false);
        driversGroup->addButton(kcfg_INDIMountLogging);
        kcfg_INDIMountLogging->setObjectName("kcfg_INDIMountLogging");

        gridLayout->addWidget(kcfg_INDIMountLogging, 13, 2, 1, 2);

        kcfg_SchedulerLogging = new QCheckBox(groupBox);
        modulesGroup = new QButtonGroup(OpsLogs);
        modulesGroup->setObjectName("modulesGroup");
        modulesGroup->setExclusive(false);
        modulesGroup->addButton(kcfg_SchedulerLogging);
        kcfg_SchedulerLogging->setObjectName("kcfg_SchedulerLogging");

        gridLayout->addWidget(kcfg_SchedulerLogging, 4, 9, 1, 1);

        kcfg_INDIWeatherLogging = new QCheckBox(groupBox);
        driversGroup->addButton(kcfg_INDIWeatherLogging);
        kcfg_INDIWeatherLogging->setObjectName("kcfg_INDIWeatherLogging");

        gridLayout->addWidget(kcfg_INDIWeatherLogging, 14, 7, 1, 1);

        line_3 = new QFrame(groupBox);
        line_3->setObjectName("line_3");
        line_3->setFrameShape(QFrame::Shape::HLine);
        line_3->setFrameShadow(QFrame::Shadow::Sunken);

        gridLayout->addWidget(line_3, 11, 0, 1, 13);

        kcfg_GuideLogging = new QCheckBox(groupBox);
        modulesGroup->addButton(kcfg_GuideLogging);
        kcfg_GuideLogging->setObjectName("kcfg_GuideLogging");

        gridLayout->addWidget(kcfg_GuideLogging, 7, 5, 1, 2);

        label_6 = new QLabel(groupBox);
        label_6->setObjectName("label_6");

        gridLayout->addWidget(label_6, 3, 1, 5, 1);

        kcfg_RegularLogging = new QRadioButton(groupBox);
        verbosityButtonGroup = new QButtonGroup(OpsLogs);
        verbosityButtonGroup->setObjectName("verbosityButtonGroup");
        verbosityButtonGroup->addButton(kcfg_RegularLogging);
        kcfg_RegularLogging->setObjectName("kcfg_RegularLogging");
        kcfg_RegularLogging->setChecked(true);

        gridLayout->addWidget(kcfg_RegularLogging, 0, 6, 1, 2);

        label_5 = new QLabel(groupBox);
        label_5->setObjectName("label_5");

        gridLayout->addWidget(label_5, 1, 1, 1, 2);

        line = new QFrame(groupBox);
        line->setObjectName("line");
        line->setFrameShape(QFrame::Shape::HLine);
        line->setFrameShadow(QFrame::Shadow::Sunken);

        gridLayout->addWidget(line, 2, 0, 2, 13);

        kcfg_DisableLogging = new QRadioButton(groupBox);
        verbosityButtonGroup->addButton(kcfg_DisableLogging);
        kcfg_DisableLogging->setObjectName("kcfg_DisableLogging");
        kcfg_DisableLogging->setChecked(false);

        gridLayout->addWidget(kcfg_DisableLogging, 0, 8, 1, 3);

        kcfg_INDILogging = new QCheckBox(groupBox);
        modulesGroup->addButton(kcfg_INDILogging);
        kcfg_INDILogging->setObjectName("kcfg_INDILogging");

        gridLayout->addWidget(kcfg_INDILogging, 4, 2, 1, 1);

        kcfg_FITSLogging = new QCheckBox(groupBox);
        modulesGroup->addButton(kcfg_FITSLogging);
        kcfg_FITSLogging->setObjectName("kcfg_FITSLogging");

        gridLayout->addWidget(kcfg_FITSLogging, 7, 9, 1, 1);

        kcfg_LogToFile = new QRadioButton(groupBox);
        kcfg_LogToFile->setObjectName("kcfg_LogToFile");

        gridLayout->addWidget(kcfg_LogToFile, 1, 6, 1, 2);

        kcfg_INDIAuxiliaryLogging = new QCheckBox(groupBox);
        driversGroup->addButton(kcfg_INDIAuxiliaryLogging);
        kcfg_INDIAuxiliaryLogging->setObjectName("kcfg_INDIAuxiliaryLogging");

        gridLayout->addWidget(kcfg_INDIAuxiliaryLogging, 14, 9, 1, 1);

        kcfg_LogToDefault = new QRadioButton(groupBox);
        kcfg_LogToDefault->setObjectName("kcfg_LogToDefault");
        kcfg_LogToDefault->setChecked(false);

        gridLayout->addWidget(kcfg_LogToDefault, 1, 3, 1, 3);

        kcfg_INDIDomeLogging = new QCheckBox(groupBox);
        driversGroup->addButton(kcfg_INDIDomeLogging);
        kcfg_INDIDomeLogging->setObjectName("kcfg_INDIDomeLogging");

        gridLayout->addWidget(kcfg_INDIDomeLogging, 14, 2, 1, 1);

        kcfg_INDICCDLogging = new QCheckBox(groupBox);
        driversGroup->addButton(kcfg_INDICCDLogging);
        kcfg_INDICCDLogging->setObjectName("kcfg_INDICCDLogging");

        gridLayout->addWidget(kcfg_INDICCDLogging, 13, 5, 1, 1);

        label_4 = new QLabel(groupBox);
        label_4->setObjectName("label_4");

        gridLayout->addWidget(label_4, 0, 1, 1, 2);

        kcfg_INDIFilterWheelLogging = new QCheckBox(groupBox);
        driversGroup->addButton(kcfg_INDIFilterWheelLogging);
        kcfg_INDIFilterWheelLogging->setObjectName("kcfg_INDIFilterWheelLogging");

        gridLayout->addWidget(kcfg_INDIFilterWheelLogging, 13, 9, 1, 3);

        kcfg_CaptureLogging = new QCheckBox(groupBox);
        modulesGroup->addButton(kcfg_CaptureLogging);
        kcfg_CaptureLogging->setObjectName("kcfg_CaptureLogging");

        gridLayout->addWidget(kcfg_CaptureLogging, 4, 5, 1, 1);

        kcfg_INDIGPSLogging = new QCheckBox(groupBox);
        driversGroup->addButton(kcfg_INDIGPSLogging);
        kcfg_INDIGPSLogging->setObjectName("kcfg_INDIGPSLogging");

        gridLayout->addWidget(kcfg_INDIGPSLogging, 16, 5, 1, 1);

        kcfg_AlignmentLogging = new QCheckBox(groupBox);
        modulesGroup->addButton(kcfg_AlignmentLogging);
        kcfg_AlignmentLogging->setObjectName("kcfg_AlignmentLogging");

        gridLayout->addWidget(kcfg_AlignmentLogging, 7, 2, 1, 3);

        kcfg_ObservatoryLogging = new QCheckBox(groupBox);
        modulesGroup->addButton(kcfg_ObservatoryLogging);
        kcfg_ObservatoryLogging->setObjectName("kcfg_ObservatoryLogging");

        gridLayout->addWidget(kcfg_ObservatoryLogging, 8, 2, 1, 4);

        kcfg_VerboseLogging = new QRadioButton(groupBox);
        verbosityButtonGroup->addButton(kcfg_VerboseLogging);
        kcfg_VerboseLogging->setObjectName("kcfg_VerboseLogging");

        gridLayout->addWidget(kcfg_VerboseLogging, 0, 3, 1, 3);

        kcfg_INDIDetectorLogging = new QCheckBox(groupBox);
        driversGroup->addButton(kcfg_INDIDetectorLogging);
        kcfg_INDIDetectorLogging->setObjectName("kcfg_INDIDetectorLogging");

        gridLayout->addWidget(kcfg_INDIDetectorLogging, 14, 5, 1, 1);

        kcfg_INDIAOLogging = new QCheckBox(groupBox);
        driversGroup->addButton(kcfg_INDIAOLogging);
        kcfg_INDIAOLogging->setObjectName("kcfg_INDIAOLogging");

        gridLayout->addWidget(kcfg_INDIAOLogging, 16, 7, 1, 1);

        kcfg_FocusLogging = new QCheckBox(groupBox);
        modulesGroup->addButton(kcfg_FocusLogging);
        kcfg_FocusLogging->setObjectName("kcfg_FocusLogging");

        gridLayout->addWidget(kcfg_FocusLogging, 4, 7, 1, 1);

        kcfg_INDIFocuserLogging = new QCheckBox(groupBox);
        driversGroup->addButton(kcfg_INDIFocuserLogging);
        kcfg_INDIFocuserLogging->setObjectName("kcfg_INDIFocuserLogging");

        gridLayout->addWidget(kcfg_INDIFocuserLogging, 13, 7, 1, 2);

        kcfg_INDIRotatorLogging = new QCheckBox(groupBox);
        driversGroup->addButton(kcfg_INDIRotatorLogging);
        kcfg_INDIRotatorLogging->setObjectName("kcfg_INDIRotatorLogging");

        gridLayout->addWidget(kcfg_INDIRotatorLogging, 16, 2, 1, 1);

        label_9 = new QLabel(groupBox);
        label_9->setObjectName("label_9");

        gridLayout->addWidget(label_9, 13, 1, 4, 1);

        kcfg_MountLogging = new QCheckBox(groupBox);
        modulesGroup->addButton(kcfg_MountLogging);
        kcfg_MountLogging->setObjectName("kcfg_MountLogging");

        gridLayout->addWidget(kcfg_MountLogging, 7, 7, 1, 2);


        verticalLayout->addWidget(groupBox);

        horizontalLayout_2 = new QHBoxLayout();
        horizontalLayout_2->setObjectName("horizontalLayout_2");
        kcfg_showINDIMessages = new QCheckBox(OpsLogs);
        kcfg_showINDIMessages->setObjectName("kcfg_showINDIMessages");
        kcfg_showINDIMessages->setChecked(true);

        horizontalLayout_2->addWidget(kcfg_showINDIMessages);

        horizontalSpacer_8 = new QSpacerItem(40, 20, QSizePolicy::Policy::Expanding, QSizePolicy::Policy::Minimum);

        horizontalLayout_2->addItem(horizontalSpacer_8);

        showLogsB = new QPushButton(OpsLogs);
        showLogsB->setObjectName("showLogsB");
        showLogsB->setStyleSheet(QString::fromUtf8("font-weight:bold;"));

        horizontalLayout_2->addWidget(showLogsB);

        clearLogsB = new QPushButton(OpsLogs);
        clearLogsB->setObjectName("clearLogsB");
        clearLogsB->setMinimumSize(QSize(22, 22));
        clearLogsB->setMaximumSize(QSize(22, 22));
        QIcon icon;
        QString iconThemeName = QString::fromUtf8("edit-delete");
        if (QIcon::hasThemeIcon(iconThemeName)) {
            icon = QIcon::fromTheme(iconThemeName);
        } else {
            icon.addFile(QString::fromUtf8("."), QSize(), QIcon::Mode::Normal, QIcon::State::Off);
        }
        clearLogsB->setIcon(icon);
        clearLogsB->setIconSize(QSize(22, 22));

        horizontalLayout_2->addWidget(clearLogsB);


        verticalLayout->addLayout(horizontalLayout_2);


        retranslateUi(OpsLogs);

        QMetaObject::connectSlotsByName(OpsLogs);
    } // setupUi

    void retranslateUi(QWidget *OpsLogs)
    {
        label->setText(QString());
        label_2->setText(tr2i18n("<html><head/><body><p>Enable Logs to diagnose issues with Ekos and INDI. If your system is resource limited, e.g. Raspberry Pi with SD Card, then only enable the necessary logs to help in diagnosing specific problems and turn them off when no longer needed. Logs consume resources and may slow the system down.</p></body></html>", nullptr));
        groupBox->setTitle(tr2i18n("Logs", nullptr));
        kcfg_INDIMountLogging->setText(tr2i18n("Mount", nullptr));
#if QT_CONFIG(tooltip)
        kcfg_SchedulerLogging->setToolTip(tr2i18n("Log Ekos Scheduler module activity", nullptr));
#endif // QT_CONFIG(tooltip)
        kcfg_SchedulerLogging->setText(tr2i18n("Scheduler", nullptr));
        kcfg_INDIWeatherLogging->setText(tr2i18n("Weather", nullptr));
#if QT_CONFIG(tooltip)
        kcfg_GuideLogging->setToolTip(tr2i18n("Log Ekos Guide module activity", nullptr));
#endif // QT_CONFIG(tooltip)
        kcfg_GuideLogging->setText(tr2i18n("Guide", nullptr));
#if QT_CONFIG(tooltip)
        label_6->setToolTip(tr2i18n("Have problem with Ekos? Turn on logging for Ekos modules that exhibit issues.", nullptr));
#endif // QT_CONFIG(tooltip)
        label_6->setText(tr2i18n("Ekos:", nullptr));
#if QT_CONFIG(tooltip)
        kcfg_RegularLogging->setToolTip(tr2i18n("Enable regular debug output", nullptr));
#endif // QT_CONFIG(tooltip)
        kcfg_RegularLogging->setText(tr2i18n("Reg&ular", nullptr));
        label_5->setText(tr2i18n("Output:", nullptr));
#if QT_CONFIG(tooltip)
        kcfg_DisableLogging->setToolTip(tr2i18n("Disable all logging output", nullptr));
#endif // QT_CONFIG(tooltip)
        kcfg_DisableLogging->setText(tr2i18n("&Disable", nullptr));
#if QT_CONFIG(tooltip)
        kcfg_INDILogging->setToolTip(tr2i18n("Log INDI devices activity", nullptr));
#endif // QT_CONFIG(tooltip)
        kcfg_INDILogging->setText(tr2i18n("INDI", nullptr));
#if QT_CONFIG(tooltip)
        kcfg_FITSLogging->setToolTip(tr2i18n("Log FITS processing activity", nullptr));
#endif // QT_CONFIG(tooltip)
        kcfg_FITSLogging->setText(tr2i18n("FITS", nullptr));
#if QT_CONFIG(tooltip)
        kcfg_LogToFile->setToolTip(tr2i18n("Log output to log file", nullptr));
#endif // QT_CONFIG(tooltip)
        kcfg_LogToFile->setText(tr2i18n("File", nullptr));
        kcfg_INDIAuxiliaryLogging->setText(tr2i18n("Auxiliary", nullptr));
#if QT_CONFIG(tooltip)
        kcfg_LogToDefault->setToolTip(tr2i18n("Log debug messages to default output device used by the platform (e.g. Standard Error)", nullptr));
#endif // QT_CONFIG(tooltip)
        kcfg_LogToDefault->setText(tr2i18n("Defaul&t", nullptr));
        kcfg_INDIDomeLogging->setText(tr2i18n("Dome", nullptr));
        kcfg_INDICCDLogging->setText(tr2i18n("CCD", nullptr));
        label_4->setText(tr2i18n("Verbosity:", nullptr));
        kcfg_INDIFilterWheelLogging->setText(tr2i18n("Filter Wheel", nullptr));
#if QT_CONFIG(tooltip)
        kcfg_CaptureLogging->setToolTip(tr2i18n("Log Ekos Capture module activity", nullptr));
#endif // QT_CONFIG(tooltip)
        kcfg_CaptureLogging->setText(tr2i18n("Capture", nullptr));
        kcfg_INDIGPSLogging->setText(tr2i18n("GPS", nullptr));
#if QT_CONFIG(tooltip)
        kcfg_AlignmentLogging->setToolTip(tr2i18n("Log Ekos Alignment module activity", nullptr));
#endif // QT_CONFIG(tooltip)
        kcfg_AlignmentLogging->setText(tr2i18n("Alignment", nullptr));
#if QT_CONFIG(tooltip)
        kcfg_ObservatoryLogging->setToolTip(tr2i18n("<html><head/><body><p>Log Ekos Observatory module activity</p></body></html>", nullptr));
#endif // QT_CONFIG(tooltip)
        kcfg_ObservatoryLogging->setText(tr2i18n("Observatory", nullptr));
#if QT_CONFIG(tooltip)
        kcfg_VerboseLogging->setToolTip(tr2i18n("Enable verbose debug output level", nullptr));
#endif // QT_CONFIG(tooltip)
        kcfg_VerboseLogging->setText(tr2i18n("&Verbose", nullptr));
        kcfg_INDIDetectorLogging->setText(tr2i18n("Detector", nullptr));
#if QT_CONFIG(tooltip)
        kcfg_INDIAOLogging->setToolTip(tr2i18n("Adaptive Optics", nullptr));
#endif // QT_CONFIG(tooltip)
        kcfg_INDIAOLogging->setText(tr2i18n("AO", nullptr));
#if QT_CONFIG(tooltip)
        kcfg_FocusLogging->setToolTip(tr2i18n("Log Ekos Focus module activity", nullptr));
#endif // QT_CONFIG(tooltip)
        kcfg_FocusLogging->setText(tr2i18n("Focus", nullptr));
        kcfg_INDIFocuserLogging->setText(tr2i18n("Focuser", nullptr));
        kcfg_INDIRotatorLogging->setText(tr2i18n("Rotator", nullptr));
#if QT_CONFIG(tooltip)
        label_9->setToolTip(tr2i18n("Have problems with INDI drivers? Turn on logging for drivers that exhibit issues.", nullptr));
#endif // QT_CONFIG(tooltip)
        label_9->setText(tr2i18n("Drivers:", nullptr));
#if QT_CONFIG(tooltip)
        kcfg_MountLogging->setToolTip(tr2i18n("Log Ekos Mount module activity", nullptr));
#endif // QT_CONFIG(tooltip)
        kcfg_MountLogging->setText(tr2i18n("Mount", nullptr));
#if QT_CONFIG(tooltip)
        kcfg_showINDIMessages->setToolTip(tr2i18n("Display INDI status messages in the status bar", nullptr));
#endif // QT_CONFIG(tooltip)
#if QT_CONFIG(statustip)
        kcfg_showINDIMessages->setStatusTip(tr2i18n("Display incoming INDI status messages in KStars status bar", nullptr));
#endif // QT_CONFIG(statustip)
#if QT_CONFIG(whatsthis)
        kcfg_showINDIMessages->setWhatsThis(tr2i18n("Display incoming INDI status messages in KStars status bar", nullptr));
#endif // QT_CONFIG(whatsthis)
        kcfg_showINDIMessages->setText(tr2i18n("INDI messages in status &bar", nullptr));
        showLogsB->setText(tr2i18n("Open Logs Directory...", nullptr));
#if QT_CONFIG(tooltip)
        clearLogsB->setToolTip(tr2i18n("Clear all logs", nullptr));
#endif // QT_CONFIG(tooltip)
        clearLogsB->setText(QString());
        (void)OpsLogs;
    } // retranslateUi

};

namespace Ui {
    class OpsLogs: public Ui_OpsLogs {};
} // namespace Ui

QT_END_NAMESPACE

#endif // OPSLOGS_H

