/********************************************************************************
** Form generated from reading UI file 'details_database.ui'
**
** Created by: Qt User Interface Compiler version 6.11.1
**
** WARNING! All changes made in this file will be lost when recompiling UI file!
********************************************************************************/

#ifndef UI_DETAILS_DATABASE_H
#define UI_DETAILS_DATABASE_H

#include <QtCore/QVariant>
#include <QtWidgets/QApplication>
#include <QtWidgets/QHeaderView>
#include <QtWidgets/QTreeWidget>
#include <QtWidgets/QVBoxLayout>
#include <QtWidgets/QWidget>
#include <klocalizedstring.h>

QT_BEGIN_NAMESPACE

class Ui_DetailsDatabase
{
public:
    QVBoxLayout *vboxLayout;
    QTreeWidget *ADVTree;

    void setupUi(QWidget *DetailsDatabase)
    {
        if (DetailsDatabase->objectName().isEmpty())
            DetailsDatabase->setObjectName("DetailsDatabase");
        DetailsDatabase->resize(489, 398);
        vboxLayout = new QVBoxLayout(DetailsDatabase);
#ifndef UI_Q_OS_MAC
        vboxLayout->setSpacing(6);
#endif
        vboxLayout->setContentsMargins(10, 10, 10, 10);
        vboxLayout->setObjectName("vboxLayout");
        ADVTree = new QTreeWidget(DetailsDatabase);
        ADVTree->setObjectName("ADVTree");
        ADVTree->setIndentation(20);

        vboxLayout->addWidget(ADVTree);


        retranslateUi(DetailsDatabase);

        QMetaObject::connectSlotsByName(DetailsDatabase);
    } // setupUi

    void retranslateUi(QWidget *DetailsDatabase)
    {
        DetailsDatabase->setWindowTitle(tr2i18n("Details - Online Databases", nullptr));
        QTreeWidgetItem *___qtreewidgetitem = ADVTree->headerItem();
        ___qtreewidgetitem->setText(0, tr2i18n("Choose Online Database", nullptr));
    } // retranslateUi

};

namespace Ui {
    class DetailsDatabase: public Ui_DetailsDatabase {};
} // namespace Ui

QT_END_NAMESPACE

#endif // DETAILS_DATABASE_H

