/****************************************************************************
** Meta object code from reading C++ file 'domeadaptor.h'
**
** Created by: The Qt Meta Object Compiler version 69 (Qt 6.11.1)
**
** WARNING! All changes made in this file will be lost!
*****************************************************************************/

#include "domeadaptor.h"
#include <QtCore/qmetatype.h>

#include <QtCore/qtmochelpers.h>

#include <memory>


#include <QtCore/qxptype_traits.h>
#if !defined(Q_MOC_OUTPUT_REVISION)
#error "The header file 'domeadaptor.h' doesn't include <QObject>."
#elif Q_MOC_OUTPUT_REVISION != 69
#error "This file was generated using the moc from 6.11.1. It"
#error "cannot be used with the include files from this version of Qt."
#error "(The moc has changed too much.)"
#endif

#ifndef Q_CONSTINIT
#define Q_CONSTINIT
#endif

QT_WARNING_PUSH
QT_WARNING_DISABLE_DEPRECATED
QT_WARNING_DISABLE_GCC("-Wuseless-cast")
namespace {
struct qt_meta_tag_ZN11DomeAdaptorE_t {};
} // unnamed namespace

template <> constexpr inline auto DomeAdaptor::qt_create_metaobjectdata<qt_meta_tag_ZN11DomeAdaptorE_t>()
{
    namespace QMC = QtMocConstants;
    QtMocHelpers::StringRefStorage qt_stringData {
        "DomeAdaptor",
        "D-Bus Interface",
        "org.kde.kstars.INDI.Dome",
        "D-Bus Introspection",
        "  <interface name=\"org.kde.kstars.INDI.Dome\">\n    <property acc"
        "ess=\"read\" type=\"s\" name=\"name\"/>\n    <property access=\"re"
        "ad\" type=\"b\" name=\"connected\"/>\n    <property access=\"read\""
        " type=\"b\" name=\"canPark\"/>\n    <property access=\"read\" type"
        "=\"b\" name=\"canAbsMove\"/>\n    <property access=\"read\" type=\""
        "b\" name=\"canRelMove\"/>\n    <property access=\"read\" type=\"b\""
        " name=\"canAbort\"/>\n    <property access=\"readwrite\" type=\"d\""
        " name=\"position\"/>\n    <property access=\"read\" type=\"b\" nam"
        "e=\"isMoving\"/>\n    <property access=\"read\" type=\"i\" name=\""
        "status\">\n      <annotation value=\"ISD::Dome::Status\" name=\"or"
        "g.qtproject.QtDBus.QtTypeName\"/>\n    </property>\n    <property "
        "access=\"read\" type=\"i\" name=\"shutterStatus\">\n      <annotat"
        "ion value=\"ISD::Dome::ShutterStatus\" name=\"org.qtproject.QtDBus"
        ".QtTypeName\"/>\n    </property>\n    <property access=\"read\" ty"
        "pe=\"i\" name=\"parkStatus\">\n      <annotation value=\"ISD::Park"
        "Status\" name=\"org.qtproject.QtDBus.QtTypeName\"/>\n    </propert"
        "y>\n    <method name=\"Connect\">\n      <annotation value=\"true\""
        " name=\"org.freedesktop.DBus.Method.NoReply\"/>\n    </method>\n  "
        "  <method name=\"Disconnect\">\n      <annotation value=\"true\" n"
        "ame=\"org.freedesktop.DBus.Method.NoReply\"/>\n    </method>\n    "
        "<method name=\"isParked\">\n      <arg direction=\"out\" type=\"b\""
        "/>\n    </method>\n    <method name=\"park\">\n      <arg directio"
        "n=\"out\" type=\"b\"/>\n    </method>\n    <method name=\"unpark\""
        ">\n      <arg direction=\"out\" type=\"b\"/>\n    </method>\n    <"
        "method name=\"abort\">\n      <arg direction=\"out\" type=\"b\"/>\n"
        "    </method>\n    <method name=\"moveCW\">\n      <arg direction="
        "\"out\" type=\"b\"/>\n    </method>\n    <method name=\"moveCCW\">"
        "\n      <arg direction=\"out\" type=\"b\"/>\n    </method>\n    <m"
        "ethod name=\"controlShutter\">\n      <arg direction=\"in\" type=\""
        "b\" name=\"open\"/>\n      <arg direction=\"out\" type=\"b\"/>\n  "
        "  </method>\n    <method name=\"hasShutter\">\n      <arg directio"
        "n=\"out\" type=\"b\"/>\n    </method>\n    <signal name=\"Connecte"
        "d\"/>\n    <signal name=\"Disconnected\"/>\n    <signal name=\"rea"
        "dy\"/>\n    <signal name=\"newStatus\">\n      <arg direction=\"ou"
        "t\" type=\"(i)\" name=\"status\"/>\n      <annotation value=\"ISD:"
        ":Dome::Status\" name=\"org.qtproject.QtDBus.QtTypeName.In0\"/>\n  "
        "    <annotation value=\"ISD::Dome::Status\" name=\"org.qtproject.Q"
        "tDBus.QtTypeName.Out0\"/>\n    </signal>\n    <signal name=\"newPa"
        "rkStatus\">\n      <arg direction=\"out\" type=\"(i)\" name=\"stat"
        "us\"/>\n      <annotation value=\"ISD::ParkStatus\" name=\"org.qtp"
        "roject.QtDBus.QtTypeName.In0\"/>\n      <annotation value=\"ISD::P"
        "arkStatus\" name=\"org.qtproject.QtDBus.QtTypeName.Out0\"/>\n    <"
        "/signal>\n    <signal name=\"newShutterStatus\">\n      <arg direc"
        "tion=\"out\" type=\"(i)\" name=\"status\"/>\n      <annotation val"
        "ue=\"ISD::Dome::ShutterStatus\" name=\"org.qtproject.QtDBus.QtType"
        "Name.In0\"/>\n      <annotation value=\"ISD::Dome::ShutterStatus\""
        " name=\"org.qtproject.QtDBus.QtTypeName.Out0\"/>\n    </signal>\n "
        "   <signal name=\"positionChanged\">\n      <arg direction=\"out\""
        " type=\"d\" name=\"degrees\"/>\n    </signal>\n  </interface>\n",
        "Connected",
        "",
        "Disconnected",
        "newParkStatus",
        "ISD::ParkStatus",
        "status",
        "newShutterStatus",
        "ISD::Dome::ShutterStatus",
        "newStatus",
        "ISD::Dome::Status",
        "positionChanged",
        "degrees",
        "ready",
        "Connect",
        "Q_NOREPLY",
        "Disconnect",
        "abort",
        "controlShutter",
        "open",
        "hasShutter",
        "isParked",
        "moveCCW",
        "moveCW",
        "park",
        "unpark",
        "canAbort",
        "canAbsMove",
        "canPark",
        "canRelMove",
        "connected",
        "isMoving",
        "name",
        "parkStatus",
        "position",
        "shutterStatus"
    };

    QtMocHelpers::UintData qt_methods {
        // Signal 'Connected'
        QtMocHelpers::SignalData<void()>(5, 6, QMC::AccessPublic, QMetaType::Void),
        // Signal 'Disconnected'
        QtMocHelpers::SignalData<void()>(7, 6, QMC::AccessPublic, QMetaType::Void),
        // Signal 'newParkStatus'
        QtMocHelpers::SignalData<void(ISD::ParkStatus)>(8, 6, QMC::AccessPublic, QMetaType::Void, {{
            { 0x80000000 | 9, 10 },
        }}),
        // Signal 'newShutterStatus'
        QtMocHelpers::SignalData<void(ISD::Dome::ShutterStatus)>(11, 6, QMC::AccessPublic, QMetaType::Void, {{
            { 0x80000000 | 12, 10 },
        }}),
        // Signal 'newStatus'
        QtMocHelpers::SignalData<void(ISD::Dome::Status)>(13, 6, QMC::AccessPublic, QMetaType::Void, {{
            { 0x80000000 | 14, 10 },
        }}),
        // Signal 'positionChanged'
        QtMocHelpers::SignalData<void(double)>(15, 6, QMC::AccessPublic, QMetaType::Void, {{
            { QMetaType::Double, 16 },
        }}),
        // Signal 'ready'
        QtMocHelpers::SignalData<void()>(17, 6, QMC::AccessPublic, QMetaType::Void),
        // Slot 'Connect'
        QtMocHelpers::SlotData<void()>(18, 19, QMC::AccessPublic, QMetaType::Void),
        // Slot 'Disconnect'
        QtMocHelpers::SlotData<void()>(20, 19, QMC::AccessPublic, QMetaType::Void),
        // Slot 'abort'
        QtMocHelpers::SlotData<bool()>(21, 6, QMC::AccessPublic, QMetaType::Bool),
        // Slot 'controlShutter'
        QtMocHelpers::SlotData<bool(bool)>(22, 6, QMC::AccessPublic, QMetaType::Bool, {{
            { QMetaType::Bool, 23 },
        }}),
        // Slot 'hasShutter'
        QtMocHelpers::SlotData<bool()>(24, 6, QMC::AccessPublic, QMetaType::Bool),
        // Slot 'isParked'
        QtMocHelpers::SlotData<bool()>(25, 6, QMC::AccessPublic, QMetaType::Bool),
        // Slot 'moveCCW'
        QtMocHelpers::SlotData<bool()>(26, 6, QMC::AccessPublic, QMetaType::Bool),
        // Slot 'moveCW'
        QtMocHelpers::SlotData<bool()>(27, 6, QMC::AccessPublic, QMetaType::Bool),
        // Slot 'park'
        QtMocHelpers::SlotData<bool()>(28, 6, QMC::AccessPublic, QMetaType::Bool),
        // Slot 'unpark'
        QtMocHelpers::SlotData<bool()>(29, 6, QMC::AccessPublic, QMetaType::Bool),
    };
    QtMocHelpers::UintData qt_properties {
        // property 'canAbort'
        QtMocHelpers::PropertyData<bool>(30, QMetaType::Bool, QMC::DefaultPropertyFlags),
        // property 'canAbsMove'
        QtMocHelpers::PropertyData<bool>(31, QMetaType::Bool, QMC::DefaultPropertyFlags),
        // property 'canPark'
        QtMocHelpers::PropertyData<bool>(32, QMetaType::Bool, QMC::DefaultPropertyFlags),
        // property 'canRelMove'
        QtMocHelpers::PropertyData<bool>(33, QMetaType::Bool, QMC::DefaultPropertyFlags),
        // property 'connected'
        QtMocHelpers::PropertyData<bool>(34, QMetaType::Bool, QMC::DefaultPropertyFlags),
        // property 'isMoving'
        QtMocHelpers::PropertyData<bool>(35, QMetaType::Bool, QMC::DefaultPropertyFlags),
        // property 'name'
        QtMocHelpers::PropertyData<QString>(36, QMetaType::QString, QMC::DefaultPropertyFlags),
        // property 'parkStatus'
        QtMocHelpers::PropertyData<int>(37, QMetaType::Int, QMC::DefaultPropertyFlags),
        // property 'position'
        QtMocHelpers::PropertyData<double>(38, QMetaType::Double, QMC::DefaultPropertyFlags | QMC::Writable | QMC::StdCppSet),
        // property 'shutterStatus'
        QtMocHelpers::PropertyData<int>(39, QMetaType::Int, QMC::DefaultPropertyFlags),
        // property 'status'
        QtMocHelpers::PropertyData<int>(10, QMetaType::Int, QMC::DefaultPropertyFlags),
    };
    QtMocHelpers::UintData qt_enums {
    };
    QtMocHelpers::UintData qt_constructors {};
    QtMocHelpers::ClassInfos qt_classinfo({
            {    1,    2 },
            {    3,    4 },
    });
    return QtMocHelpers::metaObjectData<DomeAdaptor, qt_meta_tag_ZN11DomeAdaptorE_t>(QMC::MetaObjectFlag{}, qt_stringData,
            qt_methods, qt_properties, qt_enums, qt_constructors, qt_classinfo);
}
Q_CONSTINIT const QMetaObject DomeAdaptor::staticMetaObject = { {
    QMetaObject::SuperData::link<QDBusAbstractAdaptor::staticMetaObject>(),
    qt_staticMetaObjectStaticContent<qt_meta_tag_ZN11DomeAdaptorE_t>.stringdata,
    qt_staticMetaObjectStaticContent<qt_meta_tag_ZN11DomeAdaptorE_t>.data,
    qt_static_metacall,
    nullptr,
    qt_staticMetaObjectRelocatingContent<qt_meta_tag_ZN11DomeAdaptorE_t>.metaTypes,
    nullptr
} };

void DomeAdaptor::qt_static_metacall(QObject *_o, QMetaObject::Call _c, int _id, void **_a)
{
    auto *_t = static_cast<DomeAdaptor *>(_o);
    if (_c == QMetaObject::InvokeMetaMethod) {
        switch (_id) {
        case 0: _t->Connected(); break;
        case 1: _t->Disconnected(); break;
        case 2: _t->newParkStatus((*reinterpret_cast<std::add_pointer_t<ISD::ParkStatus>>(_a[1]))); break;
        case 3: _t->newShutterStatus((*reinterpret_cast<std::add_pointer_t<ISD::Dome::ShutterStatus>>(_a[1]))); break;
        case 4: _t->newStatus((*reinterpret_cast<std::add_pointer_t<ISD::Dome::Status>>(_a[1]))); break;
        case 5: _t->positionChanged((*reinterpret_cast<std::add_pointer_t<double>>(_a[1]))); break;
        case 6: _t->ready(); break;
        case 7: _t->Connect(); break;
        case 8: _t->Disconnect(); break;
        case 9: { bool _r = _t->abort();
            if (_a[0]) *reinterpret_cast<bool*>(_a[0]) = std::move(_r); }  break;
        case 10: { bool _r = _t->controlShutter((*reinterpret_cast<std::add_pointer_t<bool>>(_a[1])));
            if (_a[0]) *reinterpret_cast<bool*>(_a[0]) = std::move(_r); }  break;
        case 11: { bool _r = _t->hasShutter();
            if (_a[0]) *reinterpret_cast<bool*>(_a[0]) = std::move(_r); }  break;
        case 12: { bool _r = _t->isParked();
            if (_a[0]) *reinterpret_cast<bool*>(_a[0]) = std::move(_r); }  break;
        case 13: { bool _r = _t->moveCCW();
            if (_a[0]) *reinterpret_cast<bool*>(_a[0]) = std::move(_r); }  break;
        case 14: { bool _r = _t->moveCW();
            if (_a[0]) *reinterpret_cast<bool*>(_a[0]) = std::move(_r); }  break;
        case 15: { bool _r = _t->park();
            if (_a[0]) *reinterpret_cast<bool*>(_a[0]) = std::move(_r); }  break;
        case 16: { bool _r = _t->unpark();
            if (_a[0]) *reinterpret_cast<bool*>(_a[0]) = std::move(_r); }  break;
        default: ;
        }
    }
    if (_c == QMetaObject::RegisterMethodArgumentMetaType) {
        switch (_id) {
        default: *reinterpret_cast<QMetaType *>(_a[0]) = QMetaType(); break;
        case 2:
            switch (*reinterpret_cast<int*>(_a[1])) {
            default: *reinterpret_cast<QMetaType *>(_a[0]) = QMetaType(); break;
            case 0:
                *reinterpret_cast<QMetaType *>(_a[0]) = QMetaType::fromType< ISD::ParkStatus >(); break;
            }
            break;
        case 3:
            switch (*reinterpret_cast<int*>(_a[1])) {
            default: *reinterpret_cast<QMetaType *>(_a[0]) = QMetaType(); break;
            case 0:
                *reinterpret_cast<QMetaType *>(_a[0]) = QMetaType::fromType< ISD::Dome::ShutterStatus >(); break;
            }
            break;
        case 4:
            switch (*reinterpret_cast<int*>(_a[1])) {
            default: *reinterpret_cast<QMetaType *>(_a[0]) = QMetaType(); break;
            case 0:
                *reinterpret_cast<QMetaType *>(_a[0]) = QMetaType::fromType< ISD::Dome::Status >(); break;
            }
            break;
        }
    }
    if (_c == QMetaObject::IndexOfMethod) {
        if (QtMocHelpers::indexOfMethod<void (DomeAdaptor::*)()>(_a, &DomeAdaptor::Connected, 0))
            return;
        if (QtMocHelpers::indexOfMethod<void (DomeAdaptor::*)()>(_a, &DomeAdaptor::Disconnected, 1))
            return;
        if (QtMocHelpers::indexOfMethod<void (DomeAdaptor::*)(ISD::ParkStatus )>(_a, &DomeAdaptor::newParkStatus, 2))
            return;
        if (QtMocHelpers::indexOfMethod<void (DomeAdaptor::*)(ISD::Dome::ShutterStatus )>(_a, &DomeAdaptor::newShutterStatus, 3))
            return;
        if (QtMocHelpers::indexOfMethod<void (DomeAdaptor::*)(ISD::Dome::Status )>(_a, &DomeAdaptor::newStatus, 4))
            return;
        if (QtMocHelpers::indexOfMethod<void (DomeAdaptor::*)(double )>(_a, &DomeAdaptor::positionChanged, 5))
            return;
        if (QtMocHelpers::indexOfMethod<void (DomeAdaptor::*)()>(_a, &DomeAdaptor::ready, 6))
            return;
    }
    if (_c == QMetaObject::ReadProperty) {
        void *_v = _a[0];
        switch (_id) {
        case 0: *reinterpret_cast<bool*>(_v) = _t->canAbort(); break;
        case 1: *reinterpret_cast<bool*>(_v) = _t->canAbsMove(); break;
        case 2: *reinterpret_cast<bool*>(_v) = _t->canPark(); break;
        case 3: *reinterpret_cast<bool*>(_v) = _t->canRelMove(); break;
        case 4: *reinterpret_cast<bool*>(_v) = _t->connected(); break;
        case 5: *reinterpret_cast<bool*>(_v) = _t->isMoving(); break;
        case 6: *reinterpret_cast<QString*>(_v) = _t->name(); break;
        case 7: *reinterpret_cast<int*>(_v) = _t->parkStatus(); break;
        case 8: *reinterpret_cast<double*>(_v) = _t->position(); break;
        case 9: *reinterpret_cast<int*>(_v) = _t->shutterStatus(); break;
        case 10: *reinterpret_cast<int*>(_v) = _t->status(); break;
        default: break;
        }
    }
    if (_c == QMetaObject::WriteProperty) {
        void *_v = _a[0];
        switch (_id) {
        case 8: _t->setPosition(*reinterpret_cast<double*>(_v)); break;
        default: break;
        }
    }
}

const QMetaObject *DomeAdaptor::metaObject() const
{
    return QObject::d_ptr->metaObject ? QObject::d_ptr->dynamicMetaObject() : &staticMetaObject;
}

void *DomeAdaptor::qt_metacast(const char *_clname)
{
    if (!_clname) return nullptr;
    if (!strcmp(_clname, qt_staticMetaObjectStaticContent<qt_meta_tag_ZN11DomeAdaptorE_t>.strings))
        return static_cast<void*>(this);
    return QDBusAbstractAdaptor::qt_metacast(_clname);
}

int DomeAdaptor::qt_metacall(QMetaObject::Call _c, int _id, void **_a)
{
    _id = QDBusAbstractAdaptor::qt_metacall(_c, _id, _a);
    if (_id < 0)
        return _id;
    if (_c == QMetaObject::InvokeMetaMethod) {
        if (_id < 17)
            qt_static_metacall(this, _c, _id, _a);
        _id -= 17;
    }
    if (_c == QMetaObject::RegisterMethodArgumentMetaType) {
        if (_id < 17)
            qt_static_metacall(this, _c, _id, _a);
        _id -= 17;
    }
    if (_c == QMetaObject::ReadProperty || _c == QMetaObject::WriteProperty
            || _c == QMetaObject::ResetProperty || _c == QMetaObject::BindableProperty
            || _c == QMetaObject::RegisterPropertyMetaType) {
        qt_static_metacall(this, _c, _id, _a);
        _id -= 11;
    }
    return _id;
}

// SIGNAL 0
void DomeAdaptor::Connected()
{
    QMetaObject::activate(this, &staticMetaObject, 0, nullptr);
}

// SIGNAL 1
void DomeAdaptor::Disconnected()
{
    QMetaObject::activate(this, &staticMetaObject, 1, nullptr);
}

// SIGNAL 2
void DomeAdaptor::newParkStatus(ISD::ParkStatus _t1)
{
    QMetaObject::activate<void>(this, &staticMetaObject, 2, nullptr, _t1);
}

// SIGNAL 3
void DomeAdaptor::newShutterStatus(ISD::Dome::ShutterStatus _t1)
{
    QMetaObject::activate<void>(this, &staticMetaObject, 3, nullptr, _t1);
}

// SIGNAL 4
void DomeAdaptor::newStatus(ISD::Dome::Status _t1)
{
    QMetaObject::activate<void>(this, &staticMetaObject, 4, nullptr, _t1);
}

// SIGNAL 5
void DomeAdaptor::positionChanged(double _t1)
{
    QMetaObject::activate<void>(this, &staticMetaObject, 5, nullptr, _t1);
}

// SIGNAL 6
void DomeAdaptor::ready()
{
    QMetaObject::activate(this, &staticMetaObject, 6, nullptr);
}
QT_WARNING_POP
