/********************************************************************************
** Form generated from reading UI file 'observeradd.ui'
**
** Created by: Qt User Interface Compiler version 6.11.1
**
** WARNING! All changes made in this file will be lost when recompiling UI file!
********************************************************************************/

#ifndef UI_OBSERVERADD_H
#define UI_OBSERVERADD_H

#include <QtCore/QVariant>
#include <QtWidgets/QApplication>
#include <QtWidgets/QGridLayout>
#include <QtWidgets/QHBoxLayout>
#include <QtWidgets/QHeaderView>
#include <QtWidgets/QLabel>
#include <QtWidgets/QLineEdit>
#include <QtWidgets/QPushButton>
#include <QtWidgets/QSpacerItem>
#include <QtWidgets/QTableView>
#include <QtWidgets/QVBoxLayout>
#include <QtWidgets/QWidget>
#include <klocalizedstring.h>

QT_BEGIN_NAMESPACE

class Ui_ObserverAdd
{
public:
    QHBoxLayout *horizontalLayout_2;
    QVBoxLayout *verticalLayout_2;
    QVBoxLayout *verticalLayout;
    QGridLayout *gridLayout;
    QLabel *label;
    QLineEdit *Name;
    QLabel *label_2;
    QLineEdit *Surname;
    QLabel *label_3;
    QLineEdit *Contact;
    QHBoxLayout *horizontalLayout;
    QSpacerItem *horizontalSpacer;
    QPushButton *AddObserverB;
    QPushButton *RemoveObserverB;
    QSpacerItem *verticalSpacer;
    QTableView *tableView;

    void setupUi(QWidget *ObserverAdd)
    {
        if (ObserverAdd->objectName().isEmpty())
            ObserverAdd->setObjectName("ObserverAdd");
        ObserverAdd->resize(455, 190);
        QSizePolicy sizePolicy(QSizePolicy::Policy::MinimumExpanding, QSizePolicy::Policy::MinimumExpanding);
        sizePolicy.setHorizontalStretch(0);
        sizePolicy.setVerticalStretch(0);
        sizePolicy.setHeightForWidth(ObserverAdd->sizePolicy().hasHeightForWidth());
        ObserverAdd->setSizePolicy(sizePolicy);
        ObserverAdd->setMinimumSize(QSize(200, 100));
        horizontalLayout_2 = new QHBoxLayout(ObserverAdd);
        horizontalLayout_2->setSpacing(3);
        horizontalLayout_2->setObjectName("horizontalLayout_2");
        horizontalLayout_2->setContentsMargins(3, 3, 3, 3);
        verticalLayout_2 = new QVBoxLayout();
        verticalLayout_2->setObjectName("verticalLayout_2");
        verticalLayout = new QVBoxLayout();
        verticalLayout->setObjectName("verticalLayout");
        gridLayout = new QGridLayout();
        gridLayout->setObjectName("gridLayout");
        label = new QLabel(ObserverAdd);
        label->setObjectName("label");

        gridLayout->addWidget(label, 0, 0, 1, 1);

        Name = new QLineEdit(ObserverAdd);
        Name->setObjectName("Name");

        gridLayout->addWidget(Name, 0, 1, 1, 1);

        label_2 = new QLabel(ObserverAdd);
        label_2->setObjectName("label_2");

        gridLayout->addWidget(label_2, 1, 0, 1, 1);

        Surname = new QLineEdit(ObserverAdd);
        Surname->setObjectName("Surname");

        gridLayout->addWidget(Surname, 1, 1, 1, 1);

        label_3 = new QLabel(ObserverAdd);
        label_3->setObjectName("label_3");

        gridLayout->addWidget(label_3, 2, 0, 1, 1);

        Contact = new QLineEdit(ObserverAdd);
        Contact->setObjectName("Contact");

        gridLayout->addWidget(Contact, 2, 1, 1, 1);


        verticalLayout->addLayout(gridLayout);

        horizontalLayout = new QHBoxLayout();
        horizontalLayout->setObjectName("horizontalLayout");
        horizontalSpacer = new QSpacerItem(40, 20, QSizePolicy::Policy::Expanding, QSizePolicy::Policy::Minimum);

        horizontalLayout->addItem(horizontalSpacer);

        AddObserverB = new QPushButton(ObserverAdd);
        AddObserverB->setObjectName("AddObserverB");
        AddObserverB->setMinimumSize(QSize(32, 32));
        AddObserverB->setMaximumSize(QSize(32, 32));

        horizontalLayout->addWidget(AddObserverB);

        RemoveObserverB = new QPushButton(ObserverAdd);
        RemoveObserverB->setObjectName("RemoveObserverB");
        RemoveObserverB->setMinimumSize(QSize(32, 32));
        RemoveObserverB->setMaximumSize(QSize(32, 32));

        horizontalLayout->addWidget(RemoveObserverB);


        verticalLayout->addLayout(horizontalLayout);


        verticalLayout_2->addLayout(verticalLayout);

        verticalSpacer = new QSpacerItem(20, 40, QSizePolicy::Policy::Minimum, QSizePolicy::Policy::Expanding);

        verticalLayout_2->addItem(verticalSpacer);


        horizontalLayout_2->addLayout(verticalLayout_2);

        tableView = new QTableView(ObserverAdd);
        tableView->setObjectName("tableView");
        QSizePolicy sizePolicy1(QSizePolicy::Policy::Preferred, QSizePolicy::Policy::Preferred);
        sizePolicy1.setHorizontalStretch(0);
        sizePolicy1.setVerticalStretch(0);
        sizePolicy1.setHeightForWidth(tableView->sizePolicy().hasHeightForWidth());
        tableView->setSizePolicy(sizePolicy1);
        tableView->setSelectionMode(QAbstractItemView::SingleSelection);
        tableView->setSelectionBehavior(QAbstractItemView::SelectRows);

        horizontalLayout_2->addWidget(tableView);

        horizontalLayout_2->setStretch(0, 2);
        horizontalLayout_2->setStretch(1, 3);

        retranslateUi(ObserverAdd);

        QMetaObject::connectSlotsByName(ObserverAdd);
    } // setupUi

    void retranslateUi(QWidget *ObserverAdd)
    {
        ObserverAdd->setWindowTitle(tr2i18n("Manage Observers", nullptr));
        label->setText(tr2i18n("Name:", nullptr));
        label_2->setText(tr2i18n("Surname:", nullptr));
        label_3->setText(tr2i18n("Contact:", nullptr));
        AddObserverB->setText(QString());
        RemoveObserverB->setText(QString());
    } // retranslateUi

};

namespace Ui {
    class ObserverAdd: public Ui_ObserverAdd {};
} // namespace Ui

QT_END_NAMESPACE

#endif // OBSERVERADD_H

