/****************************************************************************
** Meta object code from reading C++ file 'indiadaptor.h'
**
** Created by: The Qt Meta Object Compiler version 69 (Qt 6.11.1)
**
** WARNING! All changes made in this file will be lost!
*****************************************************************************/

#include "indiadaptor.h"
#include <QtCore/qmetatype.h>

#include <QtCore/qtmochelpers.h>

#include <memory>


#include <QtCore/qxptype_traits.h>
#if !defined(Q_MOC_OUTPUT_REVISION)
#error "The header file 'indiadaptor.h' doesn't include <QObject>."
#elif Q_MOC_OUTPUT_REVISION != 69
#error "This file was generated using the moc from 6.11.1. It"
#error "cannot be used with the include files from this version of Qt."
#error "(The moc has changed too much.)"
#endif

#ifndef Q_CONSTINIT
#define Q_CONSTINIT
#endif

QT_WARNING_PUSH
QT_WARNING_DISABLE_DEPRECATED
QT_WARNING_DISABLE_GCC("-Wuseless-cast")
namespace {
struct qt_meta_tag_ZN11INDIAdaptorE_t {};
} // unnamed namespace

template <> constexpr inline auto INDIAdaptor::qt_create_metaobjectdata<qt_meta_tag_ZN11INDIAdaptorE_t>()
{
    namespace QMC = QtMocConstants;
    QtMocHelpers::StringRefStorage qt_stringData {
        "INDIAdaptor",
        "D-Bus Interface",
        "org.kde.kstars.INDI",
        "D-Bus Introspection",
        "  <interface name=\"org.kde.kstars.INDI\">\n    <method name=\"sta"
        "rt\">\n      <arg direction=\"out\" type=\"b\"/>\n      <arg direc"
        "tion=\"in\" type=\"i\" name=\"port\"/>\n      <arg direction=\"in\""
        " type=\"as\" name=\"drivers\"/>\n    </method>\n    <method name=\""
        "stop\">\n      <arg direction=\"out\" type=\"b\"/>\n      <arg dir"
        "ection=\"in\" type=\"s\" name=\"port\"/>\n    </method>\n    <meth"
        "od name=\"connect\">\n      <arg direction=\"out\" type=\"b\"/>\n "
        "     <arg direction=\"in\" type=\"s\" name=\"host\"/>\n      <arg "
        "direction=\"in\" type=\"i\" name=\"port\"/>\n    </method>\n    <m"
        "ethod name=\"disconnect\">\n      <arg direction=\"out\" type=\"b\""
        "/>\n      <arg direction=\"in\" type=\"s\" name=\"host\"/>\n      "
        "<arg direction=\"in\" type=\"i\" name=\"port\"/>\n    </method>\n "
        "   <method name=\"getDevices\">\n      <arg direction=\"out\" type"
        "=\"as\"/>\n    </method>\n    <method name=\"getProperties\">\n   "
        "   <arg direction=\"out\" type=\"as\"/>\n      <arg direction=\"in"
        "\" type=\"s\" name=\"device\"/>\n    </method>\n    <method name=\""
        "getPropertyState\">\n      <arg direction=\"out\" type=\"s\"/>\n  "
        "    <arg direction=\"in\" type=\"s\" name=\"device\"/>\n      <arg"
        " direction=\"in\" type=\"s\" name=\"property\"/>\n    </method>\n "
        "   <method name=\"getDevicesPaths\">\n      <arg direction=\"out\""
        " type=\"as\"/>\n      <arg direction=\"in\" type=\"i\" name=\"inte"
        "rface\"/>\n    </method>\n    <method name=\"sendProperty\">\n    "
        "  <arg direction=\"out\" type=\"b\"/>\n      <arg direction=\"in\""
        " type=\"s\" name=\"device\"/>\n      <arg direction=\"in\" type=\""
        "s\" name=\"property\"/>\n    </method>\n    <method name=\"getLigh"
        "t\">\n      <arg direction=\"out\" type=\"s\"/>\n      <arg direct"
        "ion=\"in\" type=\"s\" name=\"device\"/>\n      <arg direction=\"in"
        "\" type=\"s\" name=\"property\"/>\n      <arg direction=\"in\" typ"
        "e=\"s\" name=\"lightName\"/>\n    </method>\n    <method name=\"se"
        "tSwitch\">\n      <arg direction=\"out\" type=\"b\"/>\n      <arg "
        "direction=\"in\" type=\"s\" name=\"device\"/>\n      <arg directio"
        "n=\"in\" type=\"s\" name=\"property\"/>\n      <arg direction=\"in"
        "\" type=\"s\" name=\"switchName\"/>\n      <arg direction=\"in\" t"
        "ype=\"s\" name=\"status\"/>\n    </method>\n    <method name=\"get"
        "Switch\">\n      <arg direction=\"out\" type=\"s\"/>\n      <arg d"
        "irection=\"in\" type=\"s\" name=\"device\"/>\n      <arg direction"
        "=\"in\" type=\"s\" name=\"property\"/>\n      <arg direction=\"in\""
        " type=\"s\" name=\"switchName\"/>\n    </method>\n    <method name"
        "=\"setText\">\n      <arg direction=\"out\" type=\"b\"/>\n      <a"
        "rg direction=\"in\" type=\"s\" name=\"device\"/>\n      <arg direc"
        "tion=\"in\" type=\"s\" name=\"property\"/>\n      <arg direction=\""
        "in\" type=\"s\" name=\"textName\"/>\n      <arg direction=\"in\" t"
        "ype=\"s\" name=\"text\"/>\n    </method>\n    <method name=\"getTe"
        "xt\">\n      <arg direction=\"out\" type=\"s\"/>\n      <arg direc"
        "tion=\"in\" type=\"s\" name=\"device\"/>\n      <arg direction=\"i"
        "n\" type=\"s\" name=\"property\"/>\n      <arg direction=\"in\" ty"
        "pe=\"s\" name=\"textName\"/>\n    </method>\n    <method name=\"se"
        "tNumber\">\n      <arg direction=\"out\" type=\"b\"/>\n      <arg "
        "direction=\"in\" type=\"s\" name=\"device\"/>\n      <arg directio"
        "n=\"in\" type=\"s\" name=\"property\"/>\n      <arg direction=\"in"
        "\" type=\"s\" name=\"numberName\"/>\n      <arg direction=\"in\" t"
        "ype=\"d\" name=\"value\"/>\n    </method>\n    <method name=\"getN"
        "umber\">\n      <arg direction=\"out\" type=\"d\"/>\n      <arg di"
        "rection=\"in\" type=\"s\" name=\"device\"/>\n      <arg direction="
        "\"in\" type=\"s\" name=\"property\"/>\n      <arg direction=\"in\""
        " type=\"s\" name=\"numberName\"/>\n    </method>\n    <method name"
        "=\"getBLOBData\">\n      <arg direction=\"out\" type=\"ay\"/>\n   "
        "   <arg direction=\"in\" type=\"s\" name=\"device\"/>\n      <arg "
        "direction=\"in\" type=\"s\" name=\"property\"/>\n      <arg direct"
        "ion=\"in\" type=\"s\" name=\"blobName\"/>\n      <arg direction=\""
        "out\" type=\"s\" name=\"blobFormat\"/>\n      <arg direction=\"out"
        "\" type=\"i\" name=\"size\"/>\n    </method>\n    <method name=\"g"
        "etBLOBFile\">\n      <arg direction=\"out\" type=\"s\"/>\n      <a"
        "rg direction=\"in\" type=\"s\" name=\"device\"/>\n      <arg direc"
        "tion=\"in\" type=\"s\" name=\"property\"/>\n      <arg direction=\""
        "in\" type=\"s\" name=\"blobName\"/>\n      <arg direction=\"out\" "
        "type=\"s\" name=\"blobFormat\"/>\n      <arg direction=\"out\" typ"
        "e=\"i\" name=\"size\"/>\n    </method>\n  </interface>\n",
        "connect",
        "",
        "host",
        "port",
        "disconnect",
        "getBLOBData",
        "device",
        "property",
        "blobName",
        "QString&",
        "blobFormat",
        "int&",
        "size",
        "getBLOBFile",
        "getDevices",
        "getDevicesPaths",
        "interface",
        "getLight",
        "lightName",
        "getNumber",
        "numberName",
        "getProperties",
        "getPropertyState",
        "getSwitch",
        "switchName",
        "getText",
        "textName",
        "sendProperty",
        "setNumber",
        "value",
        "setSwitch",
        "status",
        "setText",
        "text",
        "start",
        "drivers",
        "stop"
    };

    QtMocHelpers::UintData qt_methods {
        // Slot 'connect'
        QtMocHelpers::SlotData<bool(const QString &, int)>(5, 6, QMC::AccessPublic, QMetaType::Bool, {{
            { QMetaType::QString, 7 }, { QMetaType::Int, 8 },
        }}),
        // Slot 'disconnect'
        QtMocHelpers::SlotData<bool(const QString &, int)>(9, 6, QMC::AccessPublic, QMetaType::Bool, {{
            { QMetaType::QString, 7 }, { QMetaType::Int, 8 },
        }}),
        // Slot 'getBLOBData'
        QtMocHelpers::SlotData<QByteArray(const QString &, const QString &, const QString &, QString &, int &)>(10, 6, QMC::AccessPublic, QMetaType::QByteArray, {{
            { QMetaType::QString, 11 }, { QMetaType::QString, 12 }, { QMetaType::QString, 13 }, { 0x80000000 | 14, 15 },
            { 0x80000000 | 16, 17 },
        }}),
        // Slot 'getBLOBFile'
        QtMocHelpers::SlotData<QString(const QString &, const QString &, const QString &, QString &, int &)>(18, 6, QMC::AccessPublic, QMetaType::QString, {{
            { QMetaType::QString, 11 }, { QMetaType::QString, 12 }, { QMetaType::QString, 13 }, { 0x80000000 | 14, 15 },
            { 0x80000000 | 16, 17 },
        }}),
        // Slot 'getDevices'
        QtMocHelpers::SlotData<QStringList()>(19, 6, QMC::AccessPublic, QMetaType::QStringList),
        // Slot 'getDevicesPaths'
        QtMocHelpers::SlotData<QStringList(int)>(20, 6, QMC::AccessPublic, QMetaType::QStringList, {{
            { QMetaType::Int, 21 },
        }}),
        // Slot 'getLight'
        QtMocHelpers::SlotData<QString(const QString &, const QString &, const QString &)>(22, 6, QMC::AccessPublic, QMetaType::QString, {{
            { QMetaType::QString, 11 }, { QMetaType::QString, 12 }, { QMetaType::QString, 23 },
        }}),
        // Slot 'getNumber'
        QtMocHelpers::SlotData<double(const QString &, const QString &, const QString &)>(24, 6, QMC::AccessPublic, QMetaType::Double, {{
            { QMetaType::QString, 11 }, { QMetaType::QString, 12 }, { QMetaType::QString, 25 },
        }}),
        // Slot 'getProperties'
        QtMocHelpers::SlotData<QStringList(const QString &)>(26, 6, QMC::AccessPublic, QMetaType::QStringList, {{
            { QMetaType::QString, 11 },
        }}),
        // Slot 'getPropertyState'
        QtMocHelpers::SlotData<QString(const QString &, const QString &)>(27, 6, QMC::AccessPublic, QMetaType::QString, {{
            { QMetaType::QString, 11 }, { QMetaType::QString, 12 },
        }}),
        // Slot 'getSwitch'
        QtMocHelpers::SlotData<QString(const QString &, const QString &, const QString &)>(28, 6, QMC::AccessPublic, QMetaType::QString, {{
            { QMetaType::QString, 11 }, { QMetaType::QString, 12 }, { QMetaType::QString, 29 },
        }}),
        // Slot 'getText'
        QtMocHelpers::SlotData<QString(const QString &, const QString &, const QString &)>(30, 6, QMC::AccessPublic, QMetaType::QString, {{
            { QMetaType::QString, 11 }, { QMetaType::QString, 12 }, { QMetaType::QString, 31 },
        }}),
        // Slot 'sendProperty'
        QtMocHelpers::SlotData<bool(const QString &, const QString &)>(32, 6, QMC::AccessPublic, QMetaType::Bool, {{
            { QMetaType::QString, 11 }, { QMetaType::QString, 12 },
        }}),
        // Slot 'setNumber'
        QtMocHelpers::SlotData<bool(const QString &, const QString &, const QString &, double)>(33, 6, QMC::AccessPublic, QMetaType::Bool, {{
            { QMetaType::QString, 11 }, { QMetaType::QString, 12 }, { QMetaType::QString, 25 }, { QMetaType::Double, 34 },
        }}),
        // Slot 'setSwitch'
        QtMocHelpers::SlotData<bool(const QString &, const QString &, const QString &, const QString &)>(35, 6, QMC::AccessPublic, QMetaType::Bool, {{
            { QMetaType::QString, 11 }, { QMetaType::QString, 12 }, { QMetaType::QString, 29 }, { QMetaType::QString, 36 },
        }}),
        // Slot 'setText'
        QtMocHelpers::SlotData<bool(const QString &, const QString &, const QString &, const QString &)>(37, 6, QMC::AccessPublic, QMetaType::Bool, {{
            { QMetaType::QString, 11 }, { QMetaType::QString, 12 }, { QMetaType::QString, 31 }, { QMetaType::QString, 38 },
        }}),
        // Slot 'start'
        QtMocHelpers::SlotData<bool(int, const QStringList &)>(39, 6, QMC::AccessPublic, QMetaType::Bool, {{
            { QMetaType::Int, 8 }, { QMetaType::QStringList, 40 },
        }}),
        // Slot 'stop'
        QtMocHelpers::SlotData<bool(const QString &)>(41, 6, QMC::AccessPublic, QMetaType::Bool, {{
            { QMetaType::QString, 8 },
        }}),
    };
    QtMocHelpers::UintData qt_properties {
    };
    QtMocHelpers::UintData qt_enums {
    };
    QtMocHelpers::UintData qt_constructors {};
    QtMocHelpers::ClassInfos qt_classinfo({
            {    1,    2 },
            {    3,    4 },
    });
    return QtMocHelpers::metaObjectData<INDIAdaptor, qt_meta_tag_ZN11INDIAdaptorE_t>(QMC::MetaObjectFlag{}, qt_stringData,
            qt_methods, qt_properties, qt_enums, qt_constructors, qt_classinfo);
}
Q_CONSTINIT const QMetaObject INDIAdaptor::staticMetaObject = { {
    QMetaObject::SuperData::link<QDBusAbstractAdaptor::staticMetaObject>(),
    qt_staticMetaObjectStaticContent<qt_meta_tag_ZN11INDIAdaptorE_t>.stringdata,
    qt_staticMetaObjectStaticContent<qt_meta_tag_ZN11INDIAdaptorE_t>.data,
    qt_static_metacall,
    nullptr,
    qt_staticMetaObjectRelocatingContent<qt_meta_tag_ZN11INDIAdaptorE_t>.metaTypes,
    nullptr
} };

void INDIAdaptor::qt_static_metacall(QObject *_o, QMetaObject::Call _c, int _id, void **_a)
{
    auto *_t = static_cast<INDIAdaptor *>(_o);
    if (_c == QMetaObject::InvokeMetaMethod) {
        switch (_id) {
        case 0: { bool _r = _t->connect((*reinterpret_cast<std::add_pointer_t<QString>>(_a[1])),(*reinterpret_cast<std::add_pointer_t<int>>(_a[2])));
            if (_a[0]) *reinterpret_cast<bool*>(_a[0]) = std::move(_r); }  break;
        case 1: { bool _r = _t->disconnect((*reinterpret_cast<std::add_pointer_t<QString>>(_a[1])),(*reinterpret_cast<std::add_pointer_t<int>>(_a[2])));
            if (_a[0]) *reinterpret_cast<bool*>(_a[0]) = std::move(_r); }  break;
        case 2: { QByteArray _r = _t->getBLOBData((*reinterpret_cast<std::add_pointer_t<QString>>(_a[1])),(*reinterpret_cast<std::add_pointer_t<QString>>(_a[2])),(*reinterpret_cast<std::add_pointer_t<QString>>(_a[3])),(*reinterpret_cast<std::add_pointer_t<QString&>>(_a[4])),(*reinterpret_cast<std::add_pointer_t<int&>>(_a[5])));
            if (_a[0]) *reinterpret_cast<QByteArray*>(_a[0]) = std::move(_r); }  break;
        case 3: { QString _r = _t->getBLOBFile((*reinterpret_cast<std::add_pointer_t<QString>>(_a[1])),(*reinterpret_cast<std::add_pointer_t<QString>>(_a[2])),(*reinterpret_cast<std::add_pointer_t<QString>>(_a[3])),(*reinterpret_cast<std::add_pointer_t<QString&>>(_a[4])),(*reinterpret_cast<std::add_pointer_t<int&>>(_a[5])));
            if (_a[0]) *reinterpret_cast<QString*>(_a[0]) = std::move(_r); }  break;
        case 4: { QStringList _r = _t->getDevices();
            if (_a[0]) *reinterpret_cast<QStringList*>(_a[0]) = std::move(_r); }  break;
        case 5: { QStringList _r = _t->getDevicesPaths((*reinterpret_cast<std::add_pointer_t<int>>(_a[1])));
            if (_a[0]) *reinterpret_cast<QStringList*>(_a[0]) = std::move(_r); }  break;
        case 6: { QString _r = _t->getLight((*reinterpret_cast<std::add_pointer_t<QString>>(_a[1])),(*reinterpret_cast<std::add_pointer_t<QString>>(_a[2])),(*reinterpret_cast<std::add_pointer_t<QString>>(_a[3])));
            if (_a[0]) *reinterpret_cast<QString*>(_a[0]) = std::move(_r); }  break;
        case 7: { double _r = _t->getNumber((*reinterpret_cast<std::add_pointer_t<QString>>(_a[1])),(*reinterpret_cast<std::add_pointer_t<QString>>(_a[2])),(*reinterpret_cast<std::add_pointer_t<QString>>(_a[3])));
            if (_a[0]) *reinterpret_cast<double*>(_a[0]) = std::move(_r); }  break;
        case 8: { QStringList _r = _t->getProperties((*reinterpret_cast<std::add_pointer_t<QString>>(_a[1])));
            if (_a[0]) *reinterpret_cast<QStringList*>(_a[0]) = std::move(_r); }  break;
        case 9: { QString _r = _t->getPropertyState((*reinterpret_cast<std::add_pointer_t<QString>>(_a[1])),(*reinterpret_cast<std::add_pointer_t<QString>>(_a[2])));
            if (_a[0]) *reinterpret_cast<QString*>(_a[0]) = std::move(_r); }  break;
        case 10: { QString _r = _t->getSwitch((*reinterpret_cast<std::add_pointer_t<QString>>(_a[1])),(*reinterpret_cast<std::add_pointer_t<QString>>(_a[2])),(*reinterpret_cast<std::add_pointer_t<QString>>(_a[3])));
            if (_a[0]) *reinterpret_cast<QString*>(_a[0]) = std::move(_r); }  break;
        case 11: { QString _r = _t->getText((*reinterpret_cast<std::add_pointer_t<QString>>(_a[1])),(*reinterpret_cast<std::add_pointer_t<QString>>(_a[2])),(*reinterpret_cast<std::add_pointer_t<QString>>(_a[3])));
            if (_a[0]) *reinterpret_cast<QString*>(_a[0]) = std::move(_r); }  break;
        case 12: { bool _r = _t->sendProperty((*reinterpret_cast<std::add_pointer_t<QString>>(_a[1])),(*reinterpret_cast<std::add_pointer_t<QString>>(_a[2])));
            if (_a[0]) *reinterpret_cast<bool*>(_a[0]) = std::move(_r); }  break;
        case 13: { bool _r = _t->setNumber((*reinterpret_cast<std::add_pointer_t<QString>>(_a[1])),(*reinterpret_cast<std::add_pointer_t<QString>>(_a[2])),(*reinterpret_cast<std::add_pointer_t<QString>>(_a[3])),(*reinterpret_cast<std::add_pointer_t<double>>(_a[4])));
            if (_a[0]) *reinterpret_cast<bool*>(_a[0]) = std::move(_r); }  break;
        case 14: { bool _r = _t->setSwitch((*reinterpret_cast<std::add_pointer_t<QString>>(_a[1])),(*reinterpret_cast<std::add_pointer_t<QString>>(_a[2])),(*reinterpret_cast<std::add_pointer_t<QString>>(_a[3])),(*reinterpret_cast<std::add_pointer_t<QString>>(_a[4])));
            if (_a[0]) *reinterpret_cast<bool*>(_a[0]) = std::move(_r); }  break;
        case 15: { bool _r = _t->setText((*reinterpret_cast<std::add_pointer_t<QString>>(_a[1])),(*reinterpret_cast<std::add_pointer_t<QString>>(_a[2])),(*reinterpret_cast<std::add_pointer_t<QString>>(_a[3])),(*reinterpret_cast<std::add_pointer_t<QString>>(_a[4])));
            if (_a[0]) *reinterpret_cast<bool*>(_a[0]) = std::move(_r); }  break;
        case 16: { bool _r = _t->start((*reinterpret_cast<std::add_pointer_t<int>>(_a[1])),(*reinterpret_cast<std::add_pointer_t<QStringList>>(_a[2])));
            if (_a[0]) *reinterpret_cast<bool*>(_a[0]) = std::move(_r); }  break;
        case 17: { bool _r = _t->stop((*reinterpret_cast<std::add_pointer_t<QString>>(_a[1])));
            if (_a[0]) *reinterpret_cast<bool*>(_a[0]) = std::move(_r); }  break;
        default: ;
        }
    }
}

const QMetaObject *INDIAdaptor::metaObject() const
{
    return QObject::d_ptr->metaObject ? QObject::d_ptr->dynamicMetaObject() : &staticMetaObject;
}

void *INDIAdaptor::qt_metacast(const char *_clname)
{
    if (!_clname) return nullptr;
    if (!strcmp(_clname, qt_staticMetaObjectStaticContent<qt_meta_tag_ZN11INDIAdaptorE_t>.strings))
        return static_cast<void*>(this);
    return QDBusAbstractAdaptor::qt_metacast(_clname);
}

int INDIAdaptor::qt_metacall(QMetaObject::Call _c, int _id, void **_a)
{
    _id = QDBusAbstractAdaptor::qt_metacall(_c, _id, _a);
    if (_id < 0)
        return _id;
    if (_c == QMetaObject::InvokeMetaMethod) {
        if (_id < 18)
            qt_static_metacall(this, _c, _id, _a);
        _id -= 18;
    }
    if (_c == QMetaObject::RegisterMethodArgumentMetaType) {
        if (_id < 18)
            *reinterpret_cast<QMetaType *>(_a[0]) = QMetaType();
        _id -= 18;
    }
    return _id;
}
QT_WARNING_POP
