/********************************************************************************
** Form generated from reading UI file 'opsprograms.ui'
**
** Created by: Qt User Interface Compiler version 6.11.1
**
** WARNING! All changes made in this file will be lost when recompiling UI file!
********************************************************************************/

#ifndef UI_OPSPROGRAMS_H
#define UI_OPSPROGRAMS_H

#include <QtCore/QVariant>
#include <QtWidgets/QApplication>
#include <QtWidgets/QComboBox>
#include <QtWidgets/QGridLayout>
#include <QtWidgets/QGroupBox>
#include <QtWidgets/QLabel>
#include <QtWidgets/QLineEdit>
#include <QtWidgets/QSpacerItem>
#include <QtWidgets/QSpinBox>
#include <QtWidgets/QVBoxLayout>
#include <QtWidgets/QWidget>
#include <klocalizedstring.h>

QT_BEGIN_NAMESPACE

class Ui_OpsPrograms
{
public:
    QVBoxLayout *verticalLayout;
    QGroupBox *groupBox_5;
    QVBoxLayout *verticalLayout_2;
    QComboBox *defaultPathSelector;
    QGroupBox *groupBox;
    QGridLayout *gridLayout_2;
    QLabel *label_19;
    QLineEdit *kcfg_SextractorBinary;
    QGroupBox *groupBox_2;
    QGridLayout *gridLayout_3;
    QLineEdit *kcfg_AstrometryConfFile;
    QLineEdit *kcfg_AstrometryWCSInfo;
    QLabel *label_16;
    QLineEdit *kcfg_AstrometrySolverBinary;
    QLabel *label_15;
    QLabel *label_14;
    QGroupBox *groupBox_4;
    QGridLayout *gridLayout;
    QLabel *label_20;
    QLineEdit *kcfg_ASTAPExecutable;
    QGroupBox *groupBox_6;
    QGridLayout *gridLayout_5;
    QLabel *label_21;
    QLineEdit *kcfg_WatneyBinary;
    QGroupBox *groupBox_3;
    QGridLayout *gridLayout_4;
    QLineEdit *kcfg_AstrometryAPIURL;
    QLabel *label_18;
    QLabel *label;
    QSpinBox *kcfg_AstrometryTimeout;
    QLineEdit *kcfg_AstrometryAPIKey;
    QLabel *label_17;
    QSpacerItem *verticalSpacer_6;

    void setupUi(QWidget *OpsPrograms)
    {
        if (OpsPrograms->objectName().isEmpty())
            OpsPrograms->setObjectName("OpsPrograms");
        OpsPrograms->resize(658, 517);
        verticalLayout = new QVBoxLayout(OpsPrograms);
        verticalLayout->setObjectName("verticalLayout");
        groupBox_5 = new QGroupBox(OpsPrograms);
        groupBox_5->setObjectName("groupBox_5");
        verticalLayout_2 = new QVBoxLayout(groupBox_5);
        verticalLayout_2->setObjectName("verticalLayout_2");
        defaultPathSelector = new QComboBox(groupBox_5);
        defaultPathSelector->addItem(QString());
        defaultPathSelector->addItem(QString());
        defaultPathSelector->addItem(QString());
        defaultPathSelector->addItem(QString());
        defaultPathSelector->addItem(QString());
        defaultPathSelector->addItem(QString());
        defaultPathSelector->setObjectName("defaultPathSelector");

        verticalLayout_2->addWidget(defaultPathSelector);


        verticalLayout->addWidget(groupBox_5);

        groupBox = new QGroupBox(OpsPrograms);
        groupBox->setObjectName("groupBox");
        gridLayout_2 = new QGridLayout(groupBox);
        gridLayout_2->setObjectName("gridLayout_2");
        label_19 = new QLabel(groupBox);
        label_19->setObjectName("label_19");

        gridLayout_2->addWidget(label_19, 0, 0, 1, 1);

        kcfg_SextractorBinary = new QLineEdit(groupBox);
        kcfg_SextractorBinary->setObjectName("kcfg_SextractorBinary");

        gridLayout_2->addWidget(kcfg_SextractorBinary, 0, 1, 1, 1);


        verticalLayout->addWidget(groupBox);

        groupBox_2 = new QGroupBox(OpsPrograms);
        groupBox_2->setObjectName("groupBox_2");
        gridLayout_3 = new QGridLayout(groupBox_2);
        gridLayout_3->setObjectName("gridLayout_3");
        kcfg_AstrometryConfFile = new QLineEdit(groupBox_2);
        kcfg_AstrometryConfFile->setObjectName("kcfg_AstrometryConfFile");

        gridLayout_3->addWidget(kcfg_AstrometryConfFile, 1, 2, 1, 1);

        kcfg_AstrometryWCSInfo = new QLineEdit(groupBox_2);
        kcfg_AstrometryWCSInfo->setObjectName("kcfg_AstrometryWCSInfo");

        gridLayout_3->addWidget(kcfg_AstrometryWCSInfo, 0, 4, 1, 1);

        label_16 = new QLabel(groupBox_2);
        label_16->setObjectName("label_16");

        gridLayout_3->addWidget(label_16, 0, 3, 1, 1);

        kcfg_AstrometrySolverBinary = new QLineEdit(groupBox_2);
        kcfg_AstrometrySolverBinary->setObjectName("kcfg_AstrometrySolverBinary");

        gridLayout_3->addWidget(kcfg_AstrometrySolverBinary, 0, 2, 1, 1);

        label_15 = new QLabel(groupBox_2);
        label_15->setObjectName("label_15");

        gridLayout_3->addWidget(label_15, 0, 0, 1, 1);

        label_14 = new QLabel(groupBox_2);
        label_14->setObjectName("label_14");

        gridLayout_3->addWidget(label_14, 1, 0, 1, 1);


        verticalLayout->addWidget(groupBox_2);

        groupBox_4 = new QGroupBox(OpsPrograms);
        groupBox_4->setObjectName("groupBox_4");
        gridLayout = new QGridLayout(groupBox_4);
        gridLayout->setObjectName("gridLayout");
        label_20 = new QLabel(groupBox_4);
        label_20->setObjectName("label_20");

        gridLayout->addWidget(label_20, 0, 0, 1, 1);

        kcfg_ASTAPExecutable = new QLineEdit(groupBox_4);
        kcfg_ASTAPExecutable->setObjectName("kcfg_ASTAPExecutable");

        gridLayout->addWidget(kcfg_ASTAPExecutable, 0, 1, 1, 1);


        verticalLayout->addWidget(groupBox_4);

        groupBox_6 = new QGroupBox(OpsPrograms);
        groupBox_6->setObjectName("groupBox_6");
        gridLayout_5 = new QGridLayout(groupBox_6);
        gridLayout_5->setObjectName("gridLayout_5");
        label_21 = new QLabel(groupBox_6);
        label_21->setObjectName("label_21");

        gridLayout_5->addWidget(label_21, 0, 0, 1, 1);

        kcfg_WatneyBinary = new QLineEdit(groupBox_6);
        kcfg_WatneyBinary->setObjectName("kcfg_WatneyBinary");

        gridLayout_5->addWidget(kcfg_WatneyBinary, 0, 1, 1, 1);


        verticalLayout->addWidget(groupBox_6);

        groupBox_3 = new QGroupBox(OpsPrograms);
        groupBox_3->setObjectName("groupBox_3");
        gridLayout_4 = new QGridLayout(groupBox_3);
        gridLayout_4->setObjectName("gridLayout_4");
        kcfg_AstrometryAPIURL = new QLineEdit(groupBox_3);
        kcfg_AstrometryAPIURL->setObjectName("kcfg_AstrometryAPIURL");

        gridLayout_4->addWidget(kcfg_AstrometryAPIURL, 0, 1, 1, 1);

        label_18 = new QLabel(groupBox_3);
        label_18->setObjectName("label_18");

        gridLayout_4->addWidget(label_18, 0, 0, 1, 1);

        label = new QLabel(groupBox_3);
        label->setObjectName("label");

        gridLayout_4->addWidget(label, 2, 3, 1, 1);

        kcfg_AstrometryTimeout = new QSpinBox(groupBox_3);
        kcfg_AstrometryTimeout->setObjectName("kcfg_AstrometryTimeout");
        kcfg_AstrometryTimeout->setMinimum(30);
        kcfg_AstrometryTimeout->setMaximum(600);

        gridLayout_4->addWidget(kcfg_AstrometryTimeout, 2, 4, 1, 1);

        kcfg_AstrometryAPIKey = new QLineEdit(groupBox_3);
        kcfg_AstrometryAPIKey->setObjectName("kcfg_AstrometryAPIKey");

        gridLayout_4->addWidget(kcfg_AstrometryAPIKey, 0, 4, 1, 1);

        label_17 = new QLabel(groupBox_3);
        label_17->setObjectName("label_17");

        gridLayout_4->addWidget(label_17, 0, 3, 1, 1);


        verticalLayout->addWidget(groupBox_3);

        verticalSpacer_6 = new QSpacerItem(20, 3, QSizePolicy::Policy::Minimum, QSizePolicy::Policy::Expanding);

        verticalLayout->addItem(verticalSpacer_6);


        retranslateUi(OpsPrograms);

        QMetaObject::connectSlotsByName(OpsPrograms);
    } // setupUi

    void retranslateUi(QWidget *OpsPrograms)
    {
        groupBox_5->setTitle(tr2i18n("Load Typical Default Paths", nullptr));
        defaultPathSelector->setItemText(0, tr2i18n("Select to load one of the default sets", nullptr));
        defaultPathSelector->setItemText(1, tr2i18n("Linux Default", nullptr));
        defaultPathSelector->setItemText(2, tr2i18n("Linux KStars Internal ", nullptr));
        defaultPathSelector->setItemText(3, tr2i18n("Mac Homebrew", nullptr));
        defaultPathSelector->setItemText(4, tr2i18n("Windows ANSVR", nullptr));
        defaultPathSelector->setItemText(5, tr2i18n("Windows Cygwin", nullptr));

#if QT_CONFIG(tooltip)
        defaultPathSelector->setToolTip(tr2i18n("Choose your current setup from the list to load the typical paths to those programs for your computer ", nullptr));
#endif // QT_CONFIG(tooltip)
        groupBox->setTitle(tr2i18n("Local Sextractor Program", nullptr));
        label_19->setText(tr2i18n("sextractor binary:", nullptr));
#if QT_CONFIG(tooltip)
        kcfg_SextractorBinary->setToolTip(tr2i18n("Path to Sextractor binary file", nullptr));
#endif // QT_CONFIG(tooltip)
        kcfg_SextractorBinary->setText(QString());
        groupBox_2->setTitle(tr2i18n("Local Astrometry.net or Local ANSVR", nullptr));
#if QT_CONFIG(tooltip)
        kcfg_AstrometryConfFile->setToolTip(tr2i18n("Astrometry.net configuration file", nullptr));
#endif // QT_CONFIG(tooltip)
        kcfg_AstrometryConfFile->setText(QString());
#if QT_CONFIG(tooltip)
        kcfg_AstrometryWCSInfo->setToolTip(tr2i18n("Astrometry.net wcsinfo binary", nullptr));
#endif // QT_CONFIG(tooltip)
        kcfg_AstrometryWCSInfo->setText(QString());
        label_16->setText(tr2i18n("wcsinfo:", nullptr));
#if QT_CONFIG(tooltip)
        kcfg_AstrometrySolverBinary->setToolTip(tr2i18n("Astrometry.net solve-field binary path", nullptr));
#endif // QT_CONFIG(tooltip)
        kcfg_AstrometrySolverBinary->setText(QString());
        label_15->setText(tr2i18n("solver binary:", nullptr));
        label_14->setText(tr2i18n("config:", nullptr));
        groupBox_4->setTitle(tr2i18n("ASTAP", nullptr));
        label_20->setText(tr2i18n("ASTAP binary:", nullptr));
#if QT_CONFIG(tooltip)
        kcfg_ASTAPExecutable->setToolTip(tr2i18n("ASTAP Program binary path", nullptr));
#endif // QT_CONFIG(tooltip)
        kcfg_ASTAPExecutable->setText(QString());
        groupBox_6->setTitle(tr2i18n("Watney Solver", nullptr));
        label_21->setText(tr2i18n("Watney binary:", nullptr));
#if QT_CONFIG(tooltip)
        kcfg_WatneyBinary->setToolTip(tr2i18n("Watney Program binary path", nullptr));
#endif // QT_CONFIG(tooltip)
        kcfg_WatneyBinary->setText(QString());
        groupBox_3->setTitle(tr2i18n("Online Astrometry.net or Remote ANSVR", nullptr));
#if QT_CONFIG(tooltip)
        kcfg_AstrometryAPIURL->setToolTip(tr2i18n("<html><head/><body><p>Scheme and Authority part of URL (e.g. https://nova.astrometry.net)</p></body></html>", nullptr));
#endif // QT_CONFIG(tooltip)
        kcfg_AstrometryAPIURL->setText(QString());
        label_18->setText(tr2i18n("API URL:", nullptr));
        label->setText(tr2i18n("Time out:", nullptr));
#if QT_CONFIG(tooltip)
        kcfg_AstrometryTimeout->setToolTip(tr2i18n("Timeout in seconds to wait for astrometry solver to complete", nullptr));
#endif // QT_CONFIG(tooltip)
#if QT_CONFIG(tooltip)
        kcfg_AstrometryAPIKey->setToolTip(tr2i18n("API Key", nullptr));
#endif // QT_CONFIG(tooltip)
        kcfg_AstrometryAPIKey->setText(QString());
        label_17->setText(tr2i18n("API Key:", nullptr));
        (void)OpsPrograms;
    } // retranslateUi

};

namespace Ui {
    class OpsPrograms: public Ui_OpsPrograms {};
} // namespace Ui

QT_END_NAMESPACE

#endif // OPSPROGRAMS_H

