/********************************************************************************
** Form generated from reading UI file 'drivermanager.ui'
**
** Created by: Qt User Interface Compiler version 6.11.1
**
** WARNING! All changes made in this file will be lost when recompiling UI file!
********************************************************************************/

#ifndef UI_DRIVERMANAGER_H
#define UI_DRIVERMANAGER_H

#include <QtCore/QVariant>
#include <QtWidgets/QApplication>
#include <QtWidgets/QGridLayout>
#include <QtWidgets/QGroupBox>
#include <QtWidgets/QHBoxLayout>
#include <QtWidgets/QHeaderView>
#include <QtWidgets/QPushButton>
#include <QtWidgets/QRadioButton>
#include <QtWidgets/QSpacerItem>
#include <QtWidgets/QTabWidget>
#include <QtWidgets/QTextEdit>
#include <QtWidgets/QTreeWidget>
#include <QtWidgets/QVBoxLayout>
#include <QtWidgets/QWidget>
#include <klocalizedstring.h>

QT_BEGIN_NAMESPACE

class Ui_DriverManager
{
public:
    QVBoxLayout *vboxLayout;
    QTabWidget *ConfTabWidget;
    QWidget *LocalTab;
    QVBoxLayout *verticalLayout;
    QTreeWidget *localTreeWidget;
    QGroupBox *serverLogBox;
    QVBoxLayout *verticalLayout_2;
    QTextEdit *serverLogText;
    QGroupBox *groupBox;
    QHBoxLayout *hboxLayout;
    QRadioButton *localR;
    QRadioButton *serverR;
    QSpacerItem *horizontalSpacer;
    QHBoxLayout *hboxLayout1;
    QPushButton *runServiceB;
    QPushButton *stopServiceB;
    QSpacerItem *spacerItem;
    QWidget *clientTab;
    QGridLayout *gridLayout;
    QSpacerItem *spacerItem1;
    QGroupBox *h;
    QVBoxLayout *vboxLayout1;
    QPushButton *addB;
    QPushButton *modifyB;
    QPushButton *removeB;
    QTreeWidget *clientTreeWidget;
    QGroupBox *groupBox_3;
    QVBoxLayout *vboxLayout2;
    QPushButton *connectHostB;
    QPushButton *disconnectHostB;

    void setupUi(QWidget *DriverManager)
    {
        if (DriverManager->objectName().isEmpty())
            DriverManager->setObjectName("DriverManager");
        DriverManager->resize(519, 492);
        vboxLayout = new QVBoxLayout(DriverManager);
        vboxLayout->setSpacing(2);
        vboxLayout->setObjectName("vboxLayout");
        vboxLayout->setContentsMargins(2, 2, 2, 2);
        ConfTabWidget = new QTabWidget(DriverManager);
        ConfTabWidget->setObjectName("ConfTabWidget");
        LocalTab = new QWidget();
        LocalTab->setObjectName("LocalTab");
        verticalLayout = new QVBoxLayout(LocalTab);
        verticalLayout->setObjectName("verticalLayout");
        localTreeWidget = new QTreeWidget(LocalTab);
        localTreeWidget->setObjectName("localTreeWidget");
        QSizePolicy sizePolicy(QSizePolicy::Policy::Expanding, QSizePolicy::Policy::Expanding);
        sizePolicy.setHorizontalStretch(0);
        sizePolicy.setVerticalStretch(0);
        sizePolicy.setHeightForWidth(localTreeWidget->sizePolicy().hasHeightForWidth());
        localTreeWidget->setSizePolicy(sizePolicy);
        localTreeWidget->setMaximumSize(QSize(16777215, 16777215));
        localTreeWidget->setSelectionMode(QAbstractItemView::ExtendedSelection);

        verticalLayout->addWidget(localTreeWidget);

        serverLogBox = new QGroupBox(LocalTab);
        serverLogBox->setObjectName("serverLogBox");
        serverLogBox->setMaximumSize(QSize(16777215, 180));
        verticalLayout_2 = new QVBoxLayout(serverLogBox);
        verticalLayout_2->setObjectName("verticalLayout_2");
        serverLogText = new QTextEdit(serverLogBox);
        serverLogText->setObjectName("serverLogText");
        QSizePolicy sizePolicy1(QSizePolicy::Policy::Preferred, QSizePolicy::Policy::Preferred);
        sizePolicy1.setHorizontalStretch(0);
        sizePolicy1.setVerticalStretch(0);
        sizePolicy1.setHeightForWidth(serverLogText->sizePolicy().hasHeightForWidth());
        serverLogText->setSizePolicy(sizePolicy1);
        serverLogText->setMaximumSize(QSize(16777215, 16777215));
        serverLogText->setReadOnly(true);

        verticalLayout_2->addWidget(serverLogText);


        verticalLayout->addWidget(serverLogBox);

        groupBox = new QGroupBox(LocalTab);
        groupBox->setObjectName("groupBox");
        QSizePolicy sizePolicy2(QSizePolicy::Policy::Preferred, QSizePolicy::Policy::Minimum);
        sizePolicy2.setHorizontalStretch(0);
        sizePolicy2.setVerticalStretch(0);
        sizePolicy2.setHeightForWidth(groupBox->sizePolicy().hasHeightForWidth());
        groupBox->setSizePolicy(sizePolicy2);
        groupBox->setChecked(false);
        hboxLayout = new QHBoxLayout(groupBox);
        hboxLayout->setSpacing(6);
        hboxLayout->setObjectName("hboxLayout");
        hboxLayout->setContentsMargins(9, 9, 9, 9);
        localR = new QRadioButton(groupBox);
        localR->setObjectName("localR");
        localR->setChecked(true);

        hboxLayout->addWidget(localR);

        serverR = new QRadioButton(groupBox);
        serverR->setObjectName("serverR");
        sizePolicy1.setHeightForWidth(serverR->sizePolicy().hasHeightForWidth());
        serverR->setSizePolicy(sizePolicy1);

        hboxLayout->addWidget(serverR);

        horizontalSpacer = new QSpacerItem(40, 20, QSizePolicy::Policy::Expanding, QSizePolicy::Policy::Minimum);

        hboxLayout->addItem(horizontalSpacer);


        verticalLayout->addWidget(groupBox);

        hboxLayout1 = new QHBoxLayout();
        hboxLayout1->setSpacing(6);
        hboxLayout1->setObjectName("hboxLayout1");
        hboxLayout1->setContentsMargins(0, 0, 0, 0);
        runServiceB = new QPushButton(LocalTab);
        runServiceB->setObjectName("runServiceB");

        hboxLayout1->addWidget(runServiceB);

        stopServiceB = new QPushButton(LocalTab);
        stopServiceB->setObjectName("stopServiceB");

        hboxLayout1->addWidget(stopServiceB);

        spacerItem = new QSpacerItem(61, 20, QSizePolicy::Policy::Expanding, QSizePolicy::Policy::Minimum);

        hboxLayout1->addItem(spacerItem);


        verticalLayout->addLayout(hboxLayout1);

        ConfTabWidget->addTab(LocalTab, QString());
        clientTab = new QWidget();
        clientTab->setObjectName("clientTab");
        gridLayout = new QGridLayout(clientTab);
        gridLayout->setSpacing(6);
        gridLayout->setObjectName("gridLayout");
        gridLayout->setContentsMargins(9, 9, 9, 9);
        spacerItem1 = new QSpacerItem(20, 40, QSizePolicy::Policy::Minimum, QSizePolicy::Policy::Expanding);

        gridLayout->addItem(spacerItem1, 2, 1, 1, 1);

        h = new QGroupBox(clientTab);
        h->setObjectName("h");
        vboxLayout1 = new QVBoxLayout(h);
        vboxLayout1->setSpacing(6);
        vboxLayout1->setObjectName("vboxLayout1");
        vboxLayout1->setContentsMargins(9, 9, 9, 9);
        addB = new QPushButton(h);
        addB->setObjectName("addB");

        vboxLayout1->addWidget(addB);

        modifyB = new QPushButton(h);
        modifyB->setObjectName("modifyB");

        vboxLayout1->addWidget(modifyB);

        removeB = new QPushButton(h);
        removeB->setObjectName("removeB");

        vboxLayout1->addWidget(removeB);


        gridLayout->addWidget(h, 0, 1, 1, 1);

        clientTreeWidget = new QTreeWidget(clientTab);
        clientTreeWidget->setObjectName("clientTreeWidget");

        gridLayout->addWidget(clientTreeWidget, 0, 0, 3, 1);

        groupBox_3 = new QGroupBox(clientTab);
        groupBox_3->setObjectName("groupBox_3");
        vboxLayout2 = new QVBoxLayout(groupBox_3);
        vboxLayout2->setSpacing(6);
        vboxLayout2->setObjectName("vboxLayout2");
        vboxLayout2->setContentsMargins(9, 9, 9, 9);
        connectHostB = new QPushButton(groupBox_3);
        connectHostB->setObjectName("connectHostB");

        vboxLayout2->addWidget(connectHostB);

        disconnectHostB = new QPushButton(groupBox_3);
        disconnectHostB->setObjectName("disconnectHostB");

        vboxLayout2->addWidget(disconnectHostB);


        gridLayout->addWidget(groupBox_3, 1, 1, 1, 1);

        ConfTabWidget->addTab(clientTab, QString());

        vboxLayout->addWidget(ConfTabWidget);


        retranslateUi(DriverManager);

        ConfTabWidget->setCurrentIndex(0);


        QMetaObject::connectSlotsByName(DriverManager);
    } // setupUi

    void retranslateUi(QWidget *DriverManager)
    {
        DriverManager->setWindowTitle(tr2i18n("Device Manager", nullptr));
        QTreeWidgetItem *___qtreewidgetitem = localTreeWidget->headerItem();
        ___qtreewidgetitem->setText(4, tr2i18n("Port", nullptr));
        ___qtreewidgetitem->setText(3, tr2i18n("Version", nullptr));
        ___qtreewidgetitem->setText(2, tr2i18n("Mode", nullptr));
        ___qtreewidgetitem->setText(1, tr2i18n("Status", nullptr));
        ___qtreewidgetitem->setText(0, tr2i18n("Device", nullptr));
        serverLogBox->setTitle(tr2i18n("Server Log", nullptr));
        groupBox->setTitle(tr2i18n("Mode", nullptr));
        localR->setText(tr2i18n("Local", nullptr));
        serverR->setText(tr2i18n("Server", nullptr));
        runServiceB->setText(tr2i18n("Run Service", nullptr));
        stopServiceB->setText(tr2i18n("Stop Service", nullptr));
        ConfTabWidget->setTabText(ConfTabWidget->indexOf(LocalTab), tr2i18n("Local/Server", nullptr));
        h->setTitle(tr2i18n("Hosts", nullptr));
        addB->setText(tr2i18n("Add...", nullptr));
        modifyB->setText(tr2i18n("Modify...", nullptr));
        removeB->setText(tr2i18n("Remove", nullptr));
        QTreeWidgetItem *___qtreewidgetitem1 = clientTreeWidget->headerItem();
        ___qtreewidgetitem1->setText(2, tr2i18n("Port", nullptr));
        ___qtreewidgetitem1->setText(1, tr2i18n("Name", nullptr));
        ___qtreewidgetitem1->setText(0, tr2i18n("Status", nullptr));
        groupBox_3->setTitle(tr2i18n("Connection", nullptr));
        connectHostB->setText(tr2i18n("Connect", nullptr));
        disconnectHostB->setText(tr2i18n("Disconnect", nullptr));
        ConfTabWidget->setTabText(ConfTabWidget->indexOf(clientTab), tr2i18n("Client", nullptr));
    } // retranslateUi

};

namespace Ui {
    class DriverManager: public Ui_DriverManager {};
} // namespace Ui

QT_END_NAMESPACE

#endif // DRIVERMANAGER_H

