/****************************************************************************
** Meta object code from reading C++ file 'filtermanager.h'
**
** Created by: The Qt Meta Object Compiler version 69 (Qt 6.11.1)
**
** WARNING! All changes made in this file will be lost!
*****************************************************************************/

#include "../../../../kstars-3.8.4.1/kstars/ekos/auxiliary/filtermanager.h"
#include <QtCore/qmetatype.h>
#include <QtCore/QSharedPointer>

#include <QtCore/qtmochelpers.h>

#include <memory>


#include <QtCore/qxptype_traits.h>
#if !defined(Q_MOC_OUTPUT_REVISION)
#error "The header file 'filtermanager.h' doesn't include <QObject>."
#elif Q_MOC_OUTPUT_REVISION != 69
#error "This file was generated using the moc from 6.11.1. It"
#error "cannot be used with the include files from this version of Qt."
#error "(The moc has changed too much.)"
#endif

#ifndef Q_CONSTINIT
#define Q_CONSTINIT
#endif

QT_WARNING_PUSH
QT_WARNING_DISABLE_DEPRECATED
QT_WARNING_DISABLE_GCC("-Wuseless-cast")
namespace {
struct qt_meta_tag_ZN4Ekos13FilterManagerE_t {};
} // unnamed namespace

template <> constexpr inline auto Ekos::FilterManager::qt_create_metaobjectdata<qt_meta_tag_ZN4Ekos13FilterManagerE_t>()
{
    namespace QMC = QtMocConstants;
    QtMocHelpers::StringRefStorage qt_stringData {
        "Ekos::FilterManager",
        "positionChanged",
        "",
        "labelsChanged",
        "exposureChanged",
        "ready",
        "failed",
        "newStatus",
        "Ekos::FilterState",
        "state",
        "runAutoFocus",
        "AutofocusReason",
        "autofocusReason",
        "reasonInfo",
        "abortAutoFocus",
        "newFocusOffset",
        "value",
        "useAbsoluteOffset",
        "updated",
        "ticksPerTempChanged",
        "ticksPerAltChanged",
        "wavelengthChanged",
        "autoFocusDone",
        "FocusState",
        "completionState",
        "currentPosition",
        "currentTemperature",
        "currentAlt",
        "progressUpdated",
        "current",
        "total",
        "status",
        "filterOffsetCalculated",
        "filter",
        "newOffset",
        "average",
        "setFilterPosition",
        "uint8_t",
        "position",
        "Ekos::FilterManager::FilterPolicy",
        "policy",
        "setFilterNames",
        "newLabels",
        "setFocusOffsetComplete",
        "removeDevice",
        "QSharedPointer<ISD::GenericDevice>",
        "device",
        "reloadFilters",
        "resizeDialog",
        "setFocusStatus",
        "Ekos::FocusState",
        "focusState",
        "setFocusAbsolutePosition",
        "refreshFilterProperties",
        "autoFocusComplete",
        "updateProperty",
        "INDI::Property",
        "prop",
        "processDisconnect"
    };

    QtMocHelpers::UintData qt_methods {
        // Signal 'positionChanged'
        QtMocHelpers::SignalData<void(int)>(1, 2, QMC::AccessPublic, QMetaType::Void, {{
            { QMetaType::Int, 2 },
        }}),
        // Signal 'labelsChanged'
        QtMocHelpers::SignalData<void(QStringList)>(3, 2, QMC::AccessPublic, QMetaType::Void, {{
            { QMetaType::QStringList, 2 },
        }}),
        // Signal 'exposureChanged'
        QtMocHelpers::SignalData<void(double)>(4, 2, QMC::AccessPublic, QMetaType::Void, {{
            { QMetaType::Double, 2 },
        }}),
        // Signal 'ready'
        QtMocHelpers::SignalData<void()>(5, 2, QMC::AccessPublic, QMetaType::Void),
        // Signal 'failed'
        QtMocHelpers::SignalData<void()>(6, 2, QMC::AccessPublic, QMetaType::Void),
        // Signal 'newStatus'
        QtMocHelpers::SignalData<void(Ekos::FilterState)>(7, 2, QMC::AccessPublic, QMetaType::Void, {{
            { 0x80000000 | 8, 9 },
        }}),
        // Signal 'runAutoFocus'
        QtMocHelpers::SignalData<void(AutofocusReason, const QString &)>(10, 2, QMC::AccessPublic, QMetaType::Void, {{
            { 0x80000000 | 11, 12 }, { QMetaType::QString, 13 },
        }}),
        // Signal 'abortAutoFocus'
        QtMocHelpers::SignalData<void()>(14, 2, QMC::AccessPublic, QMetaType::Void),
        // Signal 'newFocusOffset'
        QtMocHelpers::SignalData<void(int, bool)>(15, 2, QMC::AccessPublic, QMetaType::Void, {{
            { QMetaType::Int, 16 }, { QMetaType::Bool, 17 },
        }}),
        // Signal 'updated'
        QtMocHelpers::SignalData<void()>(18, 2, QMC::AccessPublic, QMetaType::Void),
        // Signal 'ticksPerTempChanged'
        QtMocHelpers::SignalData<void()>(19, 2, QMC::AccessPublic, QMetaType::Void),
        // Signal 'ticksPerAltChanged'
        QtMocHelpers::SignalData<void()>(20, 2, QMC::AccessPublic, QMetaType::Void),
        // Signal 'wavelengthChanged'
        QtMocHelpers::SignalData<void()>(21, 2, QMC::AccessPublic, QMetaType::Void),
        // Signal 'autoFocusDone'
        QtMocHelpers::SignalData<void(FocusState, int, double, double)>(22, 2, QMC::AccessPublic, QMetaType::Void, {{
            { 0x80000000 | 23, 24 }, { QMetaType::Int, 25 }, { QMetaType::Double, 26 }, { QMetaType::Double, 27 },
        }}),
        // Signal 'progressUpdated'
        QtMocHelpers::SignalData<void(int, int, const QString &)>(28, 2, QMC::AccessPublic, QMetaType::Void, {{
            { QMetaType::Int, 29 }, { QMetaType::Int, 30 }, { QMetaType::QString, 31 },
        }}),
        // Signal 'filterOffsetCalculated'
        QtMocHelpers::SignalData<void(const QString &, int, int)>(32, 2, QMC::AccessPublic, QMetaType::Void, {{
            { QMetaType::QString, 33 }, { QMetaType::Int, 34 }, { QMetaType::Int, 35 },
        }}),
        // Slot 'setFilterPosition'
        QtMocHelpers::SlotData<bool(uint8_t, Ekos::FilterManager::FilterPolicy)>(36, 2, QMC::AccessPublic, QMetaType::Bool, {{
            { 0x80000000 | 37, 38 }, { 0x80000000 | 39, 40 },
        }}),
        // Slot 'setFilterPosition'
        QtMocHelpers::SlotData<bool(uint8_t)>(36, 2, QMC::AccessPublic | QMC::MethodCloned, QMetaType::Bool, {{
            { 0x80000000 | 37, 38 },
        }}),
        // Slot 'setFilterNames'
        QtMocHelpers::SlotData<bool(const QStringList &)>(41, 2, QMC::AccessPublic, QMetaType::Bool, {{
            { QMetaType::QStringList, 42 },
        }}),
        // Slot 'setFocusOffsetComplete'
        QtMocHelpers::SlotData<void()>(43, 2, QMC::AccessPublic, QMetaType::Void),
        // Slot 'removeDevice'
        QtMocHelpers::SlotData<void(const QSharedPointer<ISD::GenericDevice> &)>(44, 2, QMC::AccessPublic, QMetaType::Void, {{
            { 0x80000000 | 45, 46 },
        }}),
        // Slot 'reloadFilters'
        QtMocHelpers::SlotData<void()>(47, 2, QMC::AccessPublic, QMetaType::Void),
        // Slot 'resizeDialog'
        QtMocHelpers::SlotData<void()>(48, 2, QMC::AccessPublic, QMetaType::Void),
        // Slot 'setFocusStatus'
        QtMocHelpers::SlotData<void(Ekos::FocusState)>(49, 2, QMC::AccessPublic, QMetaType::Void, {{
            { 0x80000000 | 50, 51 },
        }}),
        // Slot 'setFocusAbsolutePosition'
        QtMocHelpers::SlotData<void(int)>(52, 2, QMC::AccessPublic, QMetaType::Void, {{
            { QMetaType::Int, 16 },
        }}),
        // Slot 'refreshFilterProperties'
        QtMocHelpers::SlotData<void()>(53, 2, QMC::AccessPublic, QMetaType::Void),
        // Slot 'autoFocusComplete'
        QtMocHelpers::SlotData<void(FocusState, int, double, double)>(54, 2, QMC::AccessPublic, QMetaType::Void, {{
            { 0x80000000 | 23, 24 }, { QMetaType::Int, 25 }, { QMetaType::Double, 26 }, { QMetaType::Double, 27 },
        }}),
        // Slot 'updateProperty'
        QtMocHelpers::SlotData<void(INDI::Property)>(55, 2, QMC::AccessPrivate, QMetaType::Void, {{
            { 0x80000000 | 56, 57 },
        }}),
        // Slot 'processDisconnect'
        QtMocHelpers::SlotData<void()>(58, 2, QMC::AccessPrivate, QMetaType::Void),
    };
    QtMocHelpers::UintData qt_properties {
    };
    QtMocHelpers::UintData qt_enums {
    };
    return QtMocHelpers::metaObjectData<FilterManager, qt_meta_tag_ZN4Ekos13FilterManagerE_t>(QMC::MetaObjectFlag{}, qt_stringData,
            qt_methods, qt_properties, qt_enums);
}
Q_CONSTINIT const QMetaObject Ekos::FilterManager::staticMetaObject = { {
    QMetaObject::SuperData::link<QDialog::staticMetaObject>(),
    qt_staticMetaObjectStaticContent<qt_meta_tag_ZN4Ekos13FilterManagerE_t>.stringdata,
    qt_staticMetaObjectStaticContent<qt_meta_tag_ZN4Ekos13FilterManagerE_t>.data,
    qt_static_metacall,
    nullptr,
    qt_staticMetaObjectRelocatingContent<qt_meta_tag_ZN4Ekos13FilterManagerE_t>.metaTypes,
    nullptr
} };

void Ekos::FilterManager::qt_static_metacall(QObject *_o, QMetaObject::Call _c, int _id, void **_a)
{
    auto *_t = static_cast<FilterManager *>(_o);
    if (_c == QMetaObject::InvokeMetaMethod) {
        switch (_id) {
        case 0: _t->positionChanged((*reinterpret_cast<std::add_pointer_t<int>>(_a[1]))); break;
        case 1: _t->labelsChanged((*reinterpret_cast<std::add_pointer_t<QStringList>>(_a[1]))); break;
        case 2: _t->exposureChanged((*reinterpret_cast<std::add_pointer_t<double>>(_a[1]))); break;
        case 3: _t->ready(); break;
        case 4: _t->failed(); break;
        case 5: _t->newStatus((*reinterpret_cast<std::add_pointer_t<Ekos::FilterState>>(_a[1]))); break;
        case 6: _t->runAutoFocus((*reinterpret_cast<std::add_pointer_t<AutofocusReason>>(_a[1])),(*reinterpret_cast<std::add_pointer_t<QString>>(_a[2]))); break;
        case 7: _t->abortAutoFocus(); break;
        case 8: _t->newFocusOffset((*reinterpret_cast<std::add_pointer_t<int>>(_a[1])),(*reinterpret_cast<std::add_pointer_t<bool>>(_a[2]))); break;
        case 9: _t->updated(); break;
        case 10: _t->ticksPerTempChanged(); break;
        case 11: _t->ticksPerAltChanged(); break;
        case 12: _t->wavelengthChanged(); break;
        case 13: _t->autoFocusDone((*reinterpret_cast<std::add_pointer_t<FocusState>>(_a[1])),(*reinterpret_cast<std::add_pointer_t<int>>(_a[2])),(*reinterpret_cast<std::add_pointer_t<double>>(_a[3])),(*reinterpret_cast<std::add_pointer_t<double>>(_a[4]))); break;
        case 14: _t->progressUpdated((*reinterpret_cast<std::add_pointer_t<int>>(_a[1])),(*reinterpret_cast<std::add_pointer_t<int>>(_a[2])),(*reinterpret_cast<std::add_pointer_t<QString>>(_a[3]))); break;
        case 15: _t->filterOffsetCalculated((*reinterpret_cast<std::add_pointer_t<QString>>(_a[1])),(*reinterpret_cast<std::add_pointer_t<int>>(_a[2])),(*reinterpret_cast<std::add_pointer_t<int>>(_a[3]))); break;
        case 16: { bool _r = _t->setFilterPosition((*reinterpret_cast<std::add_pointer_t<uint8_t>>(_a[1])),(*reinterpret_cast<std::add_pointer_t<Ekos::FilterManager::FilterPolicy>>(_a[2])));
            if (_a[0]) *reinterpret_cast<bool*>(_a[0]) = std::move(_r); }  break;
        case 17: { bool _r = _t->setFilterPosition((*reinterpret_cast<std::add_pointer_t<uint8_t>>(_a[1])));
            if (_a[0]) *reinterpret_cast<bool*>(_a[0]) = std::move(_r); }  break;
        case 18: { bool _r = _t->setFilterNames((*reinterpret_cast<std::add_pointer_t<QStringList>>(_a[1])));
            if (_a[0]) *reinterpret_cast<bool*>(_a[0]) = std::move(_r); }  break;
        case 19: _t->setFocusOffsetComplete(); break;
        case 20: _t->removeDevice((*reinterpret_cast<std::add_pointer_t<QSharedPointer<ISD::GenericDevice>>>(_a[1]))); break;
        case 21: _t->reloadFilters(); break;
        case 22: _t->resizeDialog(); break;
        case 23: _t->setFocusStatus((*reinterpret_cast<std::add_pointer_t<Ekos::FocusState>>(_a[1]))); break;
        case 24: _t->setFocusAbsolutePosition((*reinterpret_cast<std::add_pointer_t<int>>(_a[1]))); break;
        case 25: _t->refreshFilterProperties(); break;
        case 26: _t->autoFocusComplete((*reinterpret_cast<std::add_pointer_t<FocusState>>(_a[1])),(*reinterpret_cast<std::add_pointer_t<int>>(_a[2])),(*reinterpret_cast<std::add_pointer_t<double>>(_a[3])),(*reinterpret_cast<std::add_pointer_t<double>>(_a[4]))); break;
        case 27: _t->updateProperty((*reinterpret_cast<std::add_pointer_t<INDI::Property>>(_a[1]))); break;
        case 28: _t->processDisconnect(); break;
        default: ;
        }
    }
    if (_c == QMetaObject::RegisterMethodArgumentMetaType) {
        switch (_id) {
        default: *reinterpret_cast<QMetaType *>(_a[0]) = QMetaType(); break;
        case 20:
            switch (*reinterpret_cast<int*>(_a[1])) {
            default: *reinterpret_cast<QMetaType *>(_a[0]) = QMetaType(); break;
            case 0:
                *reinterpret_cast<QMetaType *>(_a[0]) = QMetaType::fromType< QSharedPointer<ISD::GenericDevice> >(); break;
            }
            break;
        case 23:
            switch (*reinterpret_cast<int*>(_a[1])) {
            default: *reinterpret_cast<QMetaType *>(_a[0]) = QMetaType(); break;
            case 0:
                *reinterpret_cast<QMetaType *>(_a[0]) = QMetaType::fromType< Ekos::FocusState >(); break;
            }
            break;
        case 27:
            switch (*reinterpret_cast<int*>(_a[1])) {
            default: *reinterpret_cast<QMetaType *>(_a[0]) = QMetaType(); break;
            case 0:
                *reinterpret_cast<QMetaType *>(_a[0]) = QMetaType::fromType< INDI::Property >(); break;
            }
            break;
        }
    }
    if (_c == QMetaObject::IndexOfMethod) {
        if (QtMocHelpers::indexOfMethod<void (FilterManager::*)(int )>(_a, &FilterManager::positionChanged, 0))
            return;
        if (QtMocHelpers::indexOfMethod<void (FilterManager::*)(QStringList )>(_a, &FilterManager::labelsChanged, 1))
            return;
        if (QtMocHelpers::indexOfMethod<void (FilterManager::*)(double )>(_a, &FilterManager::exposureChanged, 2))
            return;
        if (QtMocHelpers::indexOfMethod<void (FilterManager::*)()>(_a, &FilterManager::ready, 3))
            return;
        if (QtMocHelpers::indexOfMethod<void (FilterManager::*)()>(_a, &FilterManager::failed, 4))
            return;
        if (QtMocHelpers::indexOfMethod<void (FilterManager::*)(Ekos::FilterState )>(_a, &FilterManager::newStatus, 5))
            return;
        if (QtMocHelpers::indexOfMethod<void (FilterManager::*)(AutofocusReason , const QString & )>(_a, &FilterManager::runAutoFocus, 6))
            return;
        if (QtMocHelpers::indexOfMethod<void (FilterManager::*)()>(_a, &FilterManager::abortAutoFocus, 7))
            return;
        if (QtMocHelpers::indexOfMethod<void (FilterManager::*)(int , bool )>(_a, &FilterManager::newFocusOffset, 8))
            return;
        if (QtMocHelpers::indexOfMethod<void (FilterManager::*)()>(_a, &FilterManager::updated, 9))
            return;
        if (QtMocHelpers::indexOfMethod<void (FilterManager::*)()>(_a, &FilterManager::ticksPerTempChanged, 10))
            return;
        if (QtMocHelpers::indexOfMethod<void (FilterManager::*)()>(_a, &FilterManager::ticksPerAltChanged, 11))
            return;
        if (QtMocHelpers::indexOfMethod<void (FilterManager::*)()>(_a, &FilterManager::wavelengthChanged, 12))
            return;
        if (QtMocHelpers::indexOfMethod<void (FilterManager::*)(FocusState , int , double , double )>(_a, &FilterManager::autoFocusDone, 13))
            return;
        if (QtMocHelpers::indexOfMethod<void (FilterManager::*)(int , int , const QString & )>(_a, &FilterManager::progressUpdated, 14))
            return;
        if (QtMocHelpers::indexOfMethod<void (FilterManager::*)(const QString & , int , int )>(_a, &FilterManager::filterOffsetCalculated, 15))
            return;
    }
}

const QMetaObject *Ekos::FilterManager::metaObject() const
{
    return QObject::d_ptr->metaObject ? QObject::d_ptr->dynamicMetaObject() : &staticMetaObject;
}

void *Ekos::FilterManager::qt_metacast(const char *_clname)
{
    if (!_clname) return nullptr;
    if (!strcmp(_clname, qt_staticMetaObjectStaticContent<qt_meta_tag_ZN4Ekos13FilterManagerE_t>.strings))
        return static_cast<void*>(this);
    if (!strcmp(_clname, "Ui::FilterSettings"))
        return static_cast< Ui::FilterSettings*>(this);
    return QDialog::qt_metacast(_clname);
}

int Ekos::FilterManager::qt_metacall(QMetaObject::Call _c, int _id, void **_a)
{
    _id = QDialog::qt_metacall(_c, _id, _a);
    if (_id < 0)
        return _id;
    if (_c == QMetaObject::InvokeMetaMethod) {
        if (_id < 29)
            qt_static_metacall(this, _c, _id, _a);
        _id -= 29;
    }
    if (_c == QMetaObject::RegisterMethodArgumentMetaType) {
        if (_id < 29)
            qt_static_metacall(this, _c, _id, _a);
        _id -= 29;
    }
    return _id;
}

// SIGNAL 0
void Ekos::FilterManager::positionChanged(int _t1)
{
    QMetaObject::activate<void>(this, &staticMetaObject, 0, nullptr, _t1);
}

// SIGNAL 1
void Ekos::FilterManager::labelsChanged(QStringList _t1)
{
    QMetaObject::activate<void>(this, &staticMetaObject, 1, nullptr, _t1);
}

// SIGNAL 2
void Ekos::FilterManager::exposureChanged(double _t1)
{
    QMetaObject::activate<void>(this, &staticMetaObject, 2, nullptr, _t1);
}

// SIGNAL 3
void Ekos::FilterManager::ready()
{
    QMetaObject::activate(this, &staticMetaObject, 3, nullptr);
}

// SIGNAL 4
void Ekos::FilterManager::failed()
{
    QMetaObject::activate(this, &staticMetaObject, 4, nullptr);
}

// SIGNAL 5
void Ekos::FilterManager::newStatus(Ekos::FilterState _t1)
{
    QMetaObject::activate<void>(this, &staticMetaObject, 5, nullptr, _t1);
}

// SIGNAL 6
void Ekos::FilterManager::runAutoFocus(AutofocusReason _t1, const QString & _t2)
{
    QMetaObject::activate<void>(this, &staticMetaObject, 6, nullptr, _t1, _t2);
}

// SIGNAL 7
void Ekos::FilterManager::abortAutoFocus()
{
    QMetaObject::activate(this, &staticMetaObject, 7, nullptr);
}

// SIGNAL 8
void Ekos::FilterManager::newFocusOffset(int _t1, bool _t2)
{
    QMetaObject::activate<void>(this, &staticMetaObject, 8, nullptr, _t1, _t2);
}

// SIGNAL 9
void Ekos::FilterManager::updated()
{
    QMetaObject::activate(this, &staticMetaObject, 9, nullptr);
}

// SIGNAL 10
void Ekos::FilterManager::ticksPerTempChanged()
{
    QMetaObject::activate(this, &staticMetaObject, 10, nullptr);
}

// SIGNAL 11
void Ekos::FilterManager::ticksPerAltChanged()
{
    QMetaObject::activate(this, &staticMetaObject, 11, nullptr);
}

// SIGNAL 12
void Ekos::FilterManager::wavelengthChanged()
{
    QMetaObject::activate(this, &staticMetaObject, 12, nullptr);
}

// SIGNAL 13
void Ekos::FilterManager::autoFocusDone(FocusState _t1, int _t2, double _t3, double _t4)
{
    QMetaObject::activate<void>(this, &staticMetaObject, 13, nullptr, _t1, _t2, _t3, _t4);
}

// SIGNAL 14
void Ekos::FilterManager::progressUpdated(int _t1, int _t2, const QString & _t3)
{
    QMetaObject::activate<void>(this, &staticMetaObject, 14, nullptr, _t1, _t2, _t3);
}

// SIGNAL 15
void Ekos::FilterManager::filterOffsetCalculated(const QString & _t1, int _t2, int _t3)
{
    QMetaObject::activate<void>(this, &staticMetaObject, 15, nullptr, _t1, _t2, _t3);
}
QT_WARNING_POP
