/********************************************************************************
** Form generated from reading UI file 'arglooktoward.ui'
**
** Created by: Qt User Interface Compiler version 6.11.1
**
** WARNING! All changes made in this file will be lost when recompiling UI file!
********************************************************************************/

#ifndef UI_ARGLOOKTOWARD_H
#define UI_ARGLOOKTOWARD_H

#include <QtCore/QVariant>
#include <QtWidgets/QApplication>
#include <QtWidgets/QComboBox>
#include <QtWidgets/QHBoxLayout>
#include <QtWidgets/QLabel>
#include <QtWidgets/QPushButton>
#include <QtWidgets/QSpacerItem>
#include <QtWidgets/QVBoxLayout>
#include <QtWidgets/QWidget>
#include <klocalizedstring.h>

QT_BEGIN_NAMESPACE

class Ui_ArgLookToward
{
public:
    QVBoxLayout *vboxLayout;
    QHBoxLayout *hboxLayout;
    QLabel *textLabel1;
    QComboBox *FocusEdit;
    QPushButton *FindButton;
    QSpacerItem *spacerItem;
    QSpacerItem *spacerItem1;

    void setupUi(QWidget *ArgLookToward)
    {
        if (ArgLookToward->objectName().isEmpty())
            ArgLookToward->setObjectName("ArgLookToward");
        ArgLookToward->resize(311, 69);
        vboxLayout = new QVBoxLayout(ArgLookToward);
#ifndef UI_Q_OS_MAC
        vboxLayout->setSpacing(6);
#endif
        vboxLayout->setContentsMargins(10, 10, 10, 10);
        vboxLayout->setObjectName("vboxLayout");
        hboxLayout = new QHBoxLayout();
#ifndef UI_Q_OS_MAC
        hboxLayout->setSpacing(6);
#endif
#ifndef UI_Q_OS_MAC
        hboxLayout->setContentsMargins(0, 0, 0, 0);
#endif
        hboxLayout->setObjectName("hboxLayout");
        textLabel1 = new QLabel(ArgLookToward);
        textLabel1->setObjectName("textLabel1");

        hboxLayout->addWidget(textLabel1);

        FocusEdit = new QComboBox(ArgLookToward);
        FocusEdit->addItem(QString());
        FocusEdit->addItem(QString());
        FocusEdit->addItem(QString());
        FocusEdit->addItem(QString());
        FocusEdit->addItem(QString());
        FocusEdit->addItem(QString());
        FocusEdit->addItem(QString());
        FocusEdit->addItem(QString());
        FocusEdit->addItem(QString());
        FocusEdit->addItem(QString());
        FocusEdit->setObjectName("FocusEdit");
        FocusEdit->setEditable(true);

        hboxLayout->addWidget(FocusEdit);

        FindButton = new QPushButton(ArgLookToward);
        FindButton->setObjectName("FindButton");
        QFont font;
        font.setPointSize(9);
        font.setBold(false);
        font.setItalic(false);
        font.setUnderline(false);
        font.setStrikeOut(false);
        FindButton->setFont(font);

        hboxLayout->addWidget(FindButton);

        spacerItem = new QSpacerItem(40, 20, QSizePolicy::Policy::Expanding, QSizePolicy::Policy::Minimum);

        hboxLayout->addItem(spacerItem);


        vboxLayout->addLayout(hboxLayout);

        spacerItem1 = new QSpacerItem(20, 40, QSizePolicy::Policy::Minimum, QSizePolicy::Policy::Expanding);

        vboxLayout->addItem(spacerItem1);


        retranslateUi(ArgLookToward);

        QMetaObject::connectSlotsByName(ArgLookToward);
    } // setupUi

    void retranslateUi(QWidget *ArgLookToward)
    {
        textLabel1->setText(tr2i18n("Dir:", nullptr));
        FocusEdit->setItemText(0, QString());
        FocusEdit->setItemText(1, tr2i18n("north", nullptr));
        FocusEdit->setItemText(2, tr2i18n("northeast", nullptr));
        FocusEdit->setItemText(3, tr2i18n("east", nullptr));
        FocusEdit->setItemText(4, tr2i18n("southeast", nullptr));
        FocusEdit->setItemText(5, tr2i18n("south", nullptr));
        FocusEdit->setItemText(6, tr2i18n("southwest", nullptr));
        FocusEdit->setItemText(7, tr2i18n("west", nullptr));
        FocusEdit->setItemText(8, tr2i18n("northwest", nullptr));
        FocusEdit->setItemText(9, tr2i18n("zenith", nullptr));

#if QT_CONFIG(tooltip)
        FocusEdit->setToolTip(tr2i18n("Target object or direction", nullptr));
#endif // QT_CONFIG(tooltip)
#if QT_CONFIG(whatsthis)
        FocusEdit->setWhatsThis(tr2i18n("Select a direction or object to center on.  The combo box provides a list of known directions including cardinal compass points on the horizon, as well as the Zenith.  You may also enter the name of a known object here, or select an object from the list of known objects by pressing the \"Object\" button.", nullptr));
#endif // QT_CONFIG(whatsthis)
#if QT_CONFIG(tooltip)
        FindButton->setToolTip(tr2i18n("Select object from a list", nullptr));
#endif // QT_CONFIG(tooltip)
#if QT_CONFIG(whatsthis)
        FindButton->setWhatsThis(tr2i18n("Opens the Find Object dialog, which allows you to select an object from the list of known objects.  When an object has been selected, its name will appear in the \"dir\" box at left.", nullptr));
#endif // QT_CONFIG(whatsthis)
        FindButton->setText(tr2i18n("Object...", nullptr));
        (void)ArgLookToward;
    } // retranslateUi

};

namespace Ui {
    class ArgLookToward: public Ui_ArgLookToward {};
} // namespace Ui

QT_END_NAMESPACE

#endif // ARGLOOKTOWARD_H

