/********************************************************************************
** Form generated from reading UI file 'platesolve.ui'
**
** Created by: Qt User Interface Compiler version 6.11.1
**
** WARNING! All changes made in this file will be lost when recompiling UI file!
********************************************************************************/

#ifndef UI_PLATESOLVE_H
#define UI_PLATESOLVE_H

#include <QtCore/QVariant>
#include <QtGui/QIcon>
#include <QtWidgets/QApplication>
#include <QtWidgets/QCheckBox>
#include <QtWidgets/QComboBox>
#include <QtWidgets/QDialog>
#include <QtWidgets/QDoubleSpinBox>
#include <QtWidgets/QGridLayout>
#include <QtWidgets/QGroupBox>
#include <QtWidgets/QLabel>
#include <QtWidgets/QPushButton>
#include <QtWidgets/QSpacerItem>
#include <QtWidgets/QVBoxLayout>
#include <klocalizedstring.h>
#include "widgets/dmsbox.h"

QT_BEGIN_NAMESPACE

class Ui_PlateSolveUI
{
public:
    QVBoxLayout *verticalLayout;
    QGroupBox *groupBox_1;
    QGridLayout *gridLayout_1;
    QPushButton *SolveButton;
    QPushButton *auxButton;
    QCheckBox *kcfg_FitsSolverUseScale;
    QDoubleSpinBox *kcfg_FitsSolverScale;
    QComboBox *kcfg_FitsSolverImageScaleUnits;
    QSpacerItem *hSpacer1;
    QCheckBox *kcfg_FitsSolverUsePosition;
    QPushButton *UpdatePosition;
    QLabel *FitsSolverRALabel;
    dmsBox *FitsSolverEstRA;
    QSpacerItem *hSpacer2;
    QLabel *FitsSolverDECLabel;
    dmsBox *FitsSolverEstDec;
    QSpacerItem *hSpacer3;
    QLabel *FitsSolverRadiusLabel;
    QDoubleSpinBox *kcfg_FitsSolverRadius;
    QSpacerItem *hSpacer4;
    QLabel *FitsSolverAngleLabel;
    QLabel *FitsSolverAngle;
    QSpacerItem *hSpacer6;
    QLabel *FitsSolverIndexfileLabel;
    QLabel *FitsSolverIndexfile;
    QSpacerItem *hSpacer7;
    QLabel *FitsSolverProfileLabel;
    QComboBox *kcfg_FitsSolverProfile;
    QComboBox *kcfg_FitsSolverModule;
    QPushButton *editProfile;
    QSpacerItem *hSpacer5;
    QCheckBox *kcfg_FitsSolverLinear;
    QGroupBox *SolutionGroupBox;
    QVBoxLayout *solutionLayout;
    QLabel *Solution1;
    QLabel *Solution2;
    QLabel *plateSolveImage;
    QSpacerItem *verticalSpacer;

    void setupUi(QDialog *PlateSolveUI)
    {
        if (PlateSolveUI->objectName().isEmpty())
            PlateSolveUI->setObjectName("PlateSolveUI");
        PlateSolveUI->resize(435, 412);
        verticalLayout = new QVBoxLayout(PlateSolveUI);
        verticalLayout->setSpacing(3);
        verticalLayout->setObjectName("verticalLayout");
        verticalLayout->setContentsMargins(3, 3, 3, 3);
        groupBox_1 = new QGroupBox(PlateSolveUI);
        groupBox_1->setObjectName("groupBox_1");
        gridLayout_1 = new QGridLayout(groupBox_1);
        gridLayout_1->setObjectName("gridLayout_1");
        SolveButton = new QPushButton(groupBox_1);
        SolveButton->setObjectName("SolveButton");
        SolveButton->setMaximumSize(QSize(80, 16777215));

        gridLayout_1->addWidget(SolveButton, 0, 0, 1, 1);

        auxButton = new QPushButton(groupBox_1);
        auxButton->setObjectName("auxButton");
        auxButton->setVisible(false);

        gridLayout_1->addWidget(auxButton, 0, 1, 1, 2);

        kcfg_FitsSolverUseScale = new QCheckBox(groupBox_1);
        kcfg_FitsSolverUseScale->setObjectName("kcfg_FitsSolverUseScale");
        kcfg_FitsSolverUseScale->setChecked(false);

        gridLayout_1->addWidget(kcfg_FitsSolverUseScale, 2, 0, 1, 1);

        kcfg_FitsSolverScale = new QDoubleSpinBox(groupBox_1);
        kcfg_FitsSolverScale->setObjectName("kcfg_FitsSolverScale");
        kcfg_FitsSolverScale->setMaximumSize(QSize(70, 16777215));
        kcfg_FitsSolverScale->setDecimals(3);
        kcfg_FitsSolverScale->setMinimum(0.000000000000000);
        kcfg_FitsSolverScale->setMaximum(999.000000000000000);
        kcfg_FitsSolverScale->setValue(30.000000000000000);

        gridLayout_1->addWidget(kcfg_FitsSolverScale, 2, 1, 1, 1);

        kcfg_FitsSolverImageScaleUnits = new QComboBox(groupBox_1);
        kcfg_FitsSolverImageScaleUnits->addItem(QString());
        kcfg_FitsSolverImageScaleUnits->addItem(QString());
        kcfg_FitsSolverImageScaleUnits->addItem(QString());
        kcfg_FitsSolverImageScaleUnits->setObjectName("kcfg_FitsSolverImageScaleUnits");
        QSizePolicy sizePolicy(QSizePolicy::Policy::Minimum, QSizePolicy::Policy::Fixed);
        sizePolicy.setHorizontalStretch(0);
        sizePolicy.setVerticalStretch(0);
        sizePolicy.setHeightForWidth(kcfg_FitsSolverImageScaleUnits->sizePolicy().hasHeightForWidth());
        kcfg_FitsSolverImageScaleUnits->setSizePolicy(sizePolicy);
        kcfg_FitsSolverImageScaleUnits->setMaximumSize(QSize(120, 16777215));

        gridLayout_1->addWidget(kcfg_FitsSolverImageScaleUnits, 2, 2, 1, 2);

        hSpacer1 = new QSpacerItem(-1, -1, QSizePolicy::Policy::Expanding, QSizePolicy::Policy::Minimum);

        gridLayout_1->addItem(hSpacer1, 2, 4, 1, 1);

        kcfg_FitsSolverUsePosition = new QCheckBox(groupBox_1);
        kcfg_FitsSolverUsePosition->setObjectName("kcfg_FitsSolverUsePosition");
        kcfg_FitsSolverUsePosition->setChecked(false);

        gridLayout_1->addWidget(kcfg_FitsSolverUsePosition, 4, 0, 1, 1);

        UpdatePosition = new QPushButton(groupBox_1);
        UpdatePosition->setObjectName("UpdatePosition");
        UpdatePosition->setMinimumSize(QSize(22, 22));
        UpdatePosition->setMaximumSize(QSize(22, 22));
        QIcon icon;
        QString iconThemeName = QString::fromUtf8("snap-orthogonal");
        if (QIcon::hasThemeIcon(iconThemeName)) {
            icon = QIcon::fromTheme(iconThemeName);
        } else {
            icon.addFile(QString::fromUtf8("."), QSize(), QIcon::Mode::Normal, QIcon::State::Off);
        }
        UpdatePosition->setIcon(icon);

        gridLayout_1->addWidget(UpdatePosition, 5, 0, 1, 1);

        FitsSolverRALabel = new QLabel(groupBox_1);
        FitsSolverRALabel->setObjectName("FitsSolverRALabel");

        gridLayout_1->addWidget(FitsSolverRALabel, 4, 1, 1, 1);

        FitsSolverEstRA = new dmsBox(groupBox_1);
        FitsSolverEstRA->setObjectName("FitsSolverEstRA");
        FitsSolverEstRA->setEnabled(true);
        sizePolicy.setHeightForWidth(FitsSolverEstRA->sizePolicy().hasHeightForWidth());
        FitsSolverEstRA->setSizePolicy(sizePolicy);
        FitsSolverEstRA->setMaximumSize(QSize(120, 16777215));

        gridLayout_1->addWidget(FitsSolverEstRA, 4, 2, 1, 2);

        hSpacer2 = new QSpacerItem(-1, -1, QSizePolicy::Policy::Expanding, QSizePolicy::Policy::Minimum);

        gridLayout_1->addItem(hSpacer2, 4, 4, 1, 1);

        FitsSolverDECLabel = new QLabel(groupBox_1);
        FitsSolverDECLabel->setObjectName("FitsSolverDECLabel");

        gridLayout_1->addWidget(FitsSolverDECLabel, 5, 1, 1, 1);

        FitsSolverEstDec = new dmsBox(groupBox_1);
        FitsSolverEstDec->setObjectName("FitsSolverEstDec");
        FitsSolverEstDec->setEnabled(true);
        sizePolicy.setHeightForWidth(FitsSolverEstDec->sizePolicy().hasHeightForWidth());
        FitsSolverEstDec->setSizePolicy(sizePolicy);
        FitsSolverEstDec->setMinimumSize(QSize(0, 0));
        FitsSolverEstDec->setMaximumSize(QSize(120, 16777215));

        gridLayout_1->addWidget(FitsSolverEstDec, 5, 2, 1, 2);

        hSpacer3 = new QSpacerItem(-1, -1, QSizePolicy::Policy::Expanding, QSizePolicy::Policy::Minimum);

        gridLayout_1->addItem(hSpacer3, 5, 4, 1, 1);

        FitsSolverRadiusLabel = new QLabel(groupBox_1);
        FitsSolverRadiusLabel->setObjectName("FitsSolverRadiusLabel");

        gridLayout_1->addWidget(FitsSolverRadiusLabel, 6, 1, 1, 1);

        kcfg_FitsSolverRadius = new QDoubleSpinBox(groupBox_1);
        kcfg_FitsSolverRadius->setObjectName("kcfg_FitsSolverRadius");
        kcfg_FitsSolverRadius->setMaximumSize(QSize(70, 16777215));
        kcfg_FitsSolverRadius->setMinimum(1.000000000000000);
        kcfg_FitsSolverRadius->setMaximum(360.000000000000000);
        kcfg_FitsSolverRadius->setValue(30.000000000000000);

        gridLayout_1->addWidget(kcfg_FitsSolverRadius, 6, 2, 1, 2);

        hSpacer4 = new QSpacerItem(-1, -1, QSizePolicy::Policy::Expanding, QSizePolicy::Policy::Minimum);

        gridLayout_1->addItem(hSpacer4, 6, 4, 1, 1);

        FitsSolverAngleLabel = new QLabel(groupBox_1);
        FitsSolverAngleLabel->setObjectName("FitsSolverAngleLabel");

        gridLayout_1->addWidget(FitsSolverAngleLabel, 7, 1, 1, 1);

        FitsSolverAngle = new QLabel(groupBox_1);
        FitsSolverAngle->setObjectName("FitsSolverAngle");
        FitsSolverAngle->setMaximumSize(QSize(70, 16777215));

        gridLayout_1->addWidget(FitsSolverAngle, 7, 2, 1, 2);

        hSpacer6 = new QSpacerItem(-1, -1, QSizePolicy::Policy::Expanding, QSizePolicy::Policy::Minimum);

        gridLayout_1->addItem(hSpacer6, 7, 4, 1, 1);

        FitsSolverIndexfileLabel = new QLabel(groupBox_1);
        FitsSolverIndexfileLabel->setObjectName("FitsSolverIndexfileLabel");

        gridLayout_1->addWidget(FitsSolverIndexfileLabel, 8, 1, 1, 1);

        FitsSolverIndexfile = new QLabel(groupBox_1);
        FitsSolverIndexfile->setObjectName("FitsSolverIndexfile");
        FitsSolverIndexfile->setMaximumSize(QSize(70, 16777215));

        gridLayout_1->addWidget(FitsSolverIndexfile, 8, 2, 1, 2);

        hSpacer7 = new QSpacerItem(-1, -1, QSizePolicy::Policy::Expanding, QSizePolicy::Policy::Minimum);

        gridLayout_1->addItem(hSpacer7, 8, 4, 1, 1);

        FitsSolverProfileLabel = new QLabel(groupBox_1);
        FitsSolverProfileLabel->setObjectName("FitsSolverProfileLabel");
        QSizePolicy sizePolicy1(QSizePolicy::Policy::Fixed, QSizePolicy::Policy::Preferred);
        sizePolicy1.setHorizontalStretch(0);
        sizePolicy1.setVerticalStretch(0);
        sizePolicy1.setHeightForWidth(FitsSolverProfileLabel->sizePolicy().hasHeightForWidth());
        FitsSolverProfileLabel->setSizePolicy(sizePolicy1);

        gridLayout_1->addWidget(FitsSolverProfileLabel, 9, 0, 1, 1);

        kcfg_FitsSolverProfile = new QComboBox(groupBox_1);
        kcfg_FitsSolverProfile->setObjectName("kcfg_FitsSolverProfile");
        sizePolicy.setHeightForWidth(kcfg_FitsSolverProfile->sizePolicy().hasHeightForWidth());
        kcfg_FitsSolverProfile->setSizePolicy(sizePolicy);
        kcfg_FitsSolverProfile->setMaximumSize(QSize(150, 16777215));

        gridLayout_1->addWidget(kcfg_FitsSolverProfile, 9, 1, 1, 2);

        kcfg_FitsSolverModule = new QComboBox(groupBox_1);
        kcfg_FitsSolverModule->setObjectName("kcfg_FitsSolverModule");
        sizePolicy.setHeightForWidth(kcfg_FitsSolverModule->sizePolicy().hasHeightForWidth());
        kcfg_FitsSolverModule->setSizePolicy(sizePolicy);
        kcfg_FitsSolverModule->setMaximumSize(QSize(150, 16777215));

        gridLayout_1->addWidget(kcfg_FitsSolverModule, 10, 1, 1, 2);

        editProfile = new QPushButton(groupBox_1);
        editProfile->setObjectName("editProfile");
        QSizePolicy sizePolicy2(QSizePolicy::Policy::Preferred, QSizePolicy::Policy::Fixed);
        sizePolicy2.setHorizontalStretch(0);
        sizePolicy2.setVerticalStretch(0);
        sizePolicy2.setHeightForWidth(editProfile->sizePolicy().hasHeightForWidth());
        editProfile->setSizePolicy(sizePolicy2);
        editProfile->setMaximumSize(QSize(32, 16777215));

        gridLayout_1->addWidget(editProfile, 9, 3, 1, 1);

        hSpacer5 = new QSpacerItem(-1, -1, QSizePolicy::Policy::Expanding, QSizePolicy::Policy::Minimum);

        gridLayout_1->addItem(hSpacer5, 9, 4, 1, 1);

        kcfg_FitsSolverLinear = new QCheckBox(groupBox_1);
        kcfg_FitsSolverLinear->setObjectName("kcfg_FitsSolverLinear");
        kcfg_FitsSolverLinear->setChecked(true);

        gridLayout_1->addWidget(kcfg_FitsSolverLinear, 6, 0, 1, 1);


        verticalLayout->addWidget(groupBox_1);

        SolutionGroupBox = new QGroupBox(PlateSolveUI);
        SolutionGroupBox->setObjectName("SolutionGroupBox");
        solutionLayout = new QVBoxLayout(SolutionGroupBox);
        solutionLayout->setObjectName("solutionLayout");
        Solution1 = new QLabel(SolutionGroupBox);
        Solution1->setObjectName("Solution1");

        solutionLayout->addWidget(Solution1);

        Solution2 = new QLabel(SolutionGroupBox);
        Solution2->setObjectName("Solution2");

        solutionLayout->addWidget(Solution2);


        verticalLayout->addWidget(SolutionGroupBox);

        plateSolveImage = new QLabel(PlateSolveUI);
        plateSolveImage->setObjectName("plateSolveImage");
        plateSolveImage->setVisible(false);
        plateSolveImage->setMaximumSize(QSize(100000, 300));

        verticalLayout->addWidget(plateSolveImage);

        verticalSpacer = new QSpacerItem(-1, -1, QSizePolicy::Policy::Minimum, QSizePolicy::Policy::Expanding);

        verticalLayout->addItem(verticalSpacer);


        retranslateUi(PlateSolveUI);

        kcfg_FitsSolverImageScaleUnits->setCurrentIndex(2);
        kcfg_FitsSolverProfile->setCurrentIndex(-1);
        kcfg_FitsSolverModule->setCurrentIndex(-1);


        QMetaObject::connectSlotsByName(PlateSolveUI);
    } // setupUi

    void retranslateUi(QDialog *PlateSolveUI)
    {
        PlateSolveUI->setWindowTitle(tr2i18n("Plate Solving", nullptr));
        groupBox_1->setTitle(QString());
#if QT_CONFIG(tooltip)
        SolveButton->setToolTip(tr2i18n("Plate solve the image using the parameters below.", nullptr));
#endif // QT_CONFIG(tooltip)
        SolveButton->setText(tr2i18n("Solve", nullptr));
#if QT_CONFIG(tooltip)
        auxButton->setToolTip(QString());
#endif // QT_CONFIG(tooltip)
        auxButton->setText(tr2i18n("Aux", nullptr));
#if QT_CONFIG(tooltip)
        kcfg_FitsSolverUseScale->setToolTip(tr2i18n("Set image scale to speed up solver as it does not have to search index files of different image scales.", nullptr));
#endif // QT_CONFIG(tooltip)
        kcfg_FitsSolverUseScale->setText(tr2i18n("Use Scale", nullptr));
#if QT_CONFIG(tooltip)
        kcfg_FitsSolverScale->setToolTip(tr2i18n("Set image scale to speed up solver as it does not have to search index files of different image scales.", nullptr));
#endif // QT_CONFIG(tooltip)
        kcfg_FitsSolverImageScaleUnits->setItemText(0, tr2i18n("image width \302\272", nullptr));
        kcfg_FitsSolverImageScaleUnits->setItemText(1, tr2i18n("image width '", nullptr));
        kcfg_FitsSolverImageScaleUnits->setItemText(2, tr2i18n("arcsec/pixel", nullptr));

#if QT_CONFIG(tooltip)
        kcfg_FitsSolverImageScaleUnits->setToolTip(tr2i18n("<p>The units of the imager scale bounds.", nullptr));
#endif // QT_CONFIG(tooltip)
#if QT_CONFIG(tooltip)
        kcfg_FitsSolverUsePosition->setToolTip(tr2i18n("Use the given position to speed up astrometry solver as it does not have to search in other areas of the sky.", nullptr));
#endif // QT_CONFIG(tooltip)
        kcfg_FitsSolverUsePosition->setText(tr2i18n("Use Position", nullptr));
#if QT_CONFIG(tooltip)
        UpdatePosition->setToolTip(tr2i18n("Set the approximate RA/DEC positions using the center position of the SkyMap.", nullptr));
#endif // QT_CONFIG(tooltip)
        UpdatePosition->setText(QString());
#if QT_CONFIG(tooltip)
        FitsSolverRALabel->setToolTip(tr2i18n("The RA of the Estimated Telescope/Image Field Position in hh:mm:ss notation", nullptr));
#endif // QT_CONFIG(tooltip)
        FitsSolverRALabel->setText(tr2i18n("RA", nullptr));
#if QT_CONFIG(tooltip)
        FitsSolverEstRA->setToolTip(tr2i18n("The RA of the Estimated Telescope/Image Field Position in hh:mm:ss notation", nullptr));
#endif // QT_CONFIG(tooltip)
#if QT_CONFIG(tooltip)
        FitsSolverDECLabel->setToolTip(tr2i18n("The DEC of the Estimated Telescope/Image Field Position in dd:mm:ss notation", nullptr));
#endif // QT_CONFIG(tooltip)
        FitsSolverDECLabel->setText(tr2i18n("DEC", nullptr));
#if QT_CONFIG(tooltip)
        FitsSolverEstDec->setToolTip(tr2i18n("The DEC of the Estimated Telescope/Image Field Position in dd:mm:ss notation", nullptr));
#endif // QT_CONFIG(tooltip)
#if QT_CONFIG(tooltip)
        FitsSolverRadiusLabel->setToolTip(tr2i18n("The Search Radius for the Estimated Telescope/Image Field Position in degrees.", nullptr));
#endif // QT_CONFIG(tooltip)
        FitsSolverRadiusLabel->setText(tr2i18n("Radius", nullptr));
#if QT_CONFIG(tooltip)
        kcfg_FitsSolverRadius->setToolTip(tr2i18n("The Search Radius for the Estimated Telescope/Image Field Position in degrees.", nullptr));
#endif // QT_CONFIG(tooltip)
#if QT_CONFIG(tooltip)
        FitsSolverAngleLabel->setToolTip(tr2i18n("The solved image position angle, East of North (degrees).", nullptr));
#endif // QT_CONFIG(tooltip)
        FitsSolverAngleLabel->setText(tr2i18n("PA", nullptr));
#if QT_CONFIG(tooltip)
        FitsSolverAngle->setToolTip(tr2i18n("The solved image position angle, East of North (degrees).", nullptr));
#endif // QT_CONFIG(tooltip)
#if QT_CONFIG(tooltip)
        FitsSolverIndexfileLabel->setToolTip(tr2i18n("The index file used to solve the image.", nullptr));
#endif // QT_CONFIG(tooltip)
        FitsSolverIndexfileLabel->setText(tr2i18n("Index file", nullptr));
#if QT_CONFIG(tooltip)
        FitsSolverIndexfile->setToolTip(tr2i18n("The index file used to solve the image.", nullptr));
#endif // QT_CONFIG(tooltip)
#if QT_CONFIG(tooltip)
        FitsSolverProfileLabel->setToolTip(tr2i18n("Selects the Options Profile to use for plate solving", nullptr));
#endif // QT_CONFIG(tooltip)
        FitsSolverProfileLabel->setText(tr2i18n("Profile", nullptr));
#if QT_CONFIG(tooltip)
        kcfg_FitsSolverProfile->setToolTip(tr2i18n("Selects the Options Profile to use for plate solving", nullptr));
#endif // QT_CONFIG(tooltip)
#if QT_CONFIG(tooltip)
        kcfg_FitsSolverModule->setToolTip(tr2i18n("Selects the module from which Options Profiles are taken to use for plate solving", nullptr));
#endif // QT_CONFIG(tooltip)
#if QT_CONFIG(tooltip)
        editProfile->setToolTip(tr2i18n("Opens the currently selected Profile in the Options Profile Editor", nullptr));
#endif // QT_CONFIG(tooltip)
        editProfile->setText(QString());
#if QT_CONFIG(tooltip)
        kcfg_FitsSolverLinear->setToolTip(tr2i18n("Check for linear (unstretched) images.  This is the default setting.  Uncheck for non-linear (stretched) images which will help with the star extraction part of plate solving.", nullptr));
#endif // QT_CONFIG(tooltip)
        kcfg_FitsSolverLinear->setText(tr2i18n("Linear Image", nullptr));
        SolutionGroupBox->setTitle(tr2i18n("Solution", nullptr));
        Solution1->setText(QString());
        Solution2->setText(QString());
    } // retranslateUi

};

namespace Ui {
    class PlateSolveUI: public Ui_PlateSolveUI {};
} // namespace Ui

QT_END_NAMESPACE

#endif // PLATESOLVE_H

