/********************************************************************************
** Form generated from reading UI file 'polaralignmentassistant.ui'
**
** Created by: Qt User Interface Compiler version 6.11.1
**
** WARNING! All changes made in this file will be lost when recompiling UI file!
********************************************************************************/

#ifndef UI_POLARALIGNMENTASSISTANT_H
#define UI_POLARALIGNMENTASSISTANT_H

#include <QtCore/QVariant>
#include <QtWidgets/QApplication>
#include <QtWidgets/QCheckBox>
#include <QtWidgets/QComboBox>
#include <QtWidgets/QDoubleSpinBox>
#include <QtWidgets/QGridLayout>
#include <QtWidgets/QHBoxLayout>
#include <QtWidgets/QLabel>
#include <QtWidgets/QPushButton>
#include <QtWidgets/QSpacerItem>
#include <QtWidgets/QSpinBox>
#include <QtWidgets/QStackedWidget>
#include <QtWidgets/QVBoxLayout>
#include <QtWidgets/QWidget>
#include <klocalizedstring.h>

QT_BEGIN_NAMESPACE

class Ui_PolarAlignmentAssistant
{
public:
    QVBoxLayout *mainPALayout;
    QStackedWidget *PAHWidgets;
    QWidget *PAHIntroPage;
    QVBoxLayout *verticalLayout_6;
    QLabel *introText;
    QLabel *FOVDisabledLabel;
    QHBoxLayout *horizontalLayout_4;
    QLabel *directionLabel;
    QComboBox *pAHDirection;
    QSpinBox *pAHRotation;
    QLabel *label;
    QComboBox *pAHMountSpeed;
    QCheckBox *pAHManualSlew;
    QSpacerItem *horizontalSpacer_3;
    QWidget *PAHMessagePage;
    QVBoxLayout *verticalLayout_5;
    QLabel *PAHMessageText;
    QSpacerItem *verticalSpacer_1;
    QWidget *PAHManualRotatePage;
    QVBoxLayout *verticalLayout_manual;
    QHBoxLayout *horizontalLayout_manual;
    QLabel *manualRotateText;
    QPushButton *PAHManualDone;
    QWidget *PAHRefreshPage;
    QVBoxLayout *verticalLayout_15;
    QLabel *refreshText;
    QSpacerItem *verticalSpacer_2;
    QHBoxLayout *horizontalLayout_15;
    QPushButton *PAHRefreshB;
    QDoubleSpinBox *pAHExposure;
    QSpacerItem *horizontalSpacer_7;
    QLabel *PAHIteration;
    QSpacerItem *horizontalSpacer_7c;
    QComboBox *pAHRefreshAlgorithm;
    QSpacerItem *horizontalSpacer_7b;
    QSpacerItem *verticalSpacerBeforeErrors;
    QGridLayout *PAHErrorLines;
    QLabel *label_PAHOrigErrorAlt;
    QLabel *label_PAHOrigErrorTotal;
    QLabel *PAHOrigErrorTotal;
    QLabel *label_PAHUpdatedErrorTotal;
    QSpacerItem *horizontalSpacer_updatedError;
    QLabel *PAHOrigErrorAlt;
    QLabel *label_PAHOrigErrorAz;
    QLabel *PAHOrigErrorAz;
    QLabel *label_PAHUpdatedErrorAz;
    QLabel *arrowAlt;
    QLabel *label_PAHUpdatedErrorAlt;
    QLabel *PAHUpdatedErrorAlt;
    QLabel *PAHUpdatedErrorTotal;
    QLabel *PAHUpdatedErrorAz;
    QSpacerItem *horizontalSpacer_origError;
    QLabel *arrowAz;
    QHBoxLayout *horizontalLayout_2;
    QSpacerItem *horizontalSpacer_2;
    QPushButton *PAHStartB;
    QPushButton *PAHStopB;

    void setupUi(QWidget *PolarAlignmentAssistant)
    {
        if (PolarAlignmentAssistant->objectName().isEmpty())
            PolarAlignmentAssistant->setObjectName("PolarAlignmentAssistant");
        PolarAlignmentAssistant->setEnabled(true);
        PolarAlignmentAssistant->resize(550, 198);
        PolarAlignmentAssistant->setMinimumSize(QSize(0, 150));
        mainPALayout = new QVBoxLayout(PolarAlignmentAssistant);
        mainPALayout->setSpacing(3);
        mainPALayout->setObjectName("mainPALayout");
        mainPALayout->setContentsMargins(3, 3, 3, 3);
        PAHWidgets = new QStackedWidget(PolarAlignmentAssistant);
        PAHWidgets->setObjectName("PAHWidgets");
        PAHWidgets->setEnabled(true);
        PAHWidgets->setFrameShape(QFrame::NoFrame);
        PAHIntroPage = new QWidget();
        PAHIntroPage->setObjectName("PAHIntroPage");
        PAHIntroPage->setEnabled(true);
        verticalLayout_6 = new QVBoxLayout(PAHIntroPage);
        verticalLayout_6->setSpacing(3);
        verticalLayout_6->setObjectName("verticalLayout_6");
        verticalLayout_6->setContentsMargins(3, 3, 3, 3);
        introText = new QLabel(PAHIntroPage);
        introText->setObjectName("introText");
        introText->setEnabled(true);
        introText->setWordWrap(true);

        verticalLayout_6->addWidget(introText);

        FOVDisabledLabel = new QLabel(PAHIntroPage);
        FOVDisabledLabel->setObjectName("FOVDisabledLabel");
        FOVDisabledLabel->setTextFormat(Qt::RichText);

        verticalLayout_6->addWidget(FOVDisabledLabel);

        horizontalLayout_4 = new QHBoxLayout();
        horizontalLayout_4->setSpacing(3);
        horizontalLayout_4->setObjectName("horizontalLayout_4");
        directionLabel = new QLabel(PAHIntroPage);
        directionLabel->setObjectName("directionLabel");
        directionLabel->setEnabled(false);

        horizontalLayout_4->addWidget(directionLabel);

        pAHDirection = new QComboBox(PAHIntroPage);
        pAHDirection->addItem(QString());
        pAHDirection->addItem(QString());
        pAHDirection->setObjectName("pAHDirection");
        pAHDirection->setEnabled(false);

        horizontalLayout_4->addWidget(pAHDirection);

        pAHRotation = new QSpinBox(PAHIntroPage);
        pAHRotation->setObjectName("pAHRotation");
        pAHRotation->setEnabled(false);
        pAHRotation->setMinimum(15);
        pAHRotation->setMaximum(60);
        pAHRotation->setSingleStep(15);
        pAHRotation->setValue(30);

        horizontalLayout_4->addWidget(pAHRotation);

        label = new QLabel(PAHIntroPage);
        label->setObjectName("label");

        horizontalLayout_4->addWidget(label);

        pAHMountSpeed = new QComboBox(PAHIntroPage);
        pAHMountSpeed->setObjectName("pAHMountSpeed");

        horizontalLayout_4->addWidget(pAHMountSpeed);

        pAHManualSlew = new QCheckBox(PAHIntroPage);
        pAHManualSlew->setObjectName("pAHManualSlew");
        pAHManualSlew->setEnabled(false);

        horizontalLayout_4->addWidget(pAHManualSlew);

        horizontalSpacer_3 = new QSpacerItem(40, 20, QSizePolicy::Policy::Expanding, QSizePolicy::Policy::Minimum);

        horizontalLayout_4->addItem(horizontalSpacer_3);


        verticalLayout_6->addLayout(horizontalLayout_4);

        PAHWidgets->addWidget(PAHIntroPage);
        PAHMessagePage = new QWidget();
        PAHMessagePage->setObjectName("PAHMessagePage");
        verticalLayout_5 = new QVBoxLayout(PAHMessagePage);
        verticalLayout_5->setSpacing(3);
        verticalLayout_5->setObjectName("verticalLayout_5");
        verticalLayout_5->setContentsMargins(3, 3, 3, 3);
        PAHMessageText = new QLabel(PAHMessagePage);
        PAHMessageText->setObjectName("PAHMessageText");
        PAHMessageText->setWordWrap(true);

        verticalLayout_5->addWidget(PAHMessageText);

        verticalSpacer_1 = new QSpacerItem(0, 150, QSizePolicy::Policy::Minimum, QSizePolicy::Policy::Expanding);

        verticalLayout_5->addItem(verticalSpacer_1);

        PAHWidgets->addWidget(PAHMessagePage);
        PAHManualRotatePage = new QWidget();
        PAHManualRotatePage->setObjectName("PAHManualRotatePage");
        verticalLayout_manual = new QVBoxLayout(PAHManualRotatePage);
        verticalLayout_manual->setSpacing(3);
        verticalLayout_manual->setObjectName("verticalLayout_manual");
        verticalLayout_manual->setContentsMargins(3, 3, 3, 3);
        horizontalLayout_manual = new QHBoxLayout();
        horizontalLayout_manual->setSpacing(3);
        horizontalLayout_manual->setObjectName("horizontalLayout_manual");
        manualRotateText = new QLabel(PAHManualRotatePage);
        manualRotateText->setObjectName("manualRotateText");
        manualRotateText->setWordWrap(true);

        horizontalLayout_manual->addWidget(manualRotateText);

        PAHManualDone = new QPushButton(PAHManualRotatePage);
        PAHManualDone->setObjectName("PAHManualDone");
        PAHManualDone->setMaximumSize(QSize(80, 16777215));

        horizontalLayout_manual->addWidget(PAHManualDone);


        verticalLayout_manual->addLayout(horizontalLayout_manual);

        PAHWidgets->addWidget(PAHManualRotatePage);
        PAHRefreshPage = new QWidget();
        PAHRefreshPage->setObjectName("PAHRefreshPage");
        verticalLayout_15 = new QVBoxLayout(PAHRefreshPage);
        verticalLayout_15->setSpacing(3);
        verticalLayout_15->setObjectName("verticalLayout_15");
        verticalLayout_15->setContentsMargins(3, 3, 3, 3);
        refreshText = new QLabel(PAHRefreshPage);
        refreshText->setObjectName("refreshText");
        refreshText->setWordWrap(true);

        verticalLayout_15->addWidget(refreshText);

        verticalSpacer_2 = new QSpacerItem(0, 100, QSizePolicy::Policy::Minimum, QSizePolicy::Policy::Maximum);

        verticalLayout_15->addItem(verticalSpacer_2);

        horizontalLayout_15 = new QHBoxLayout();
        horizontalLayout_15->setSpacing(3);
        horizontalLayout_15->setObjectName("horizontalLayout_15");
        PAHRefreshB = new QPushButton(PAHRefreshPage);
        PAHRefreshB->setObjectName("PAHRefreshB");

        horizontalLayout_15->addWidget(PAHRefreshB);

        pAHExposure = new QDoubleSpinBox(PAHRefreshPage);
        pAHExposure->setObjectName("pAHExposure");
        pAHExposure->setDecimals(1);
        pAHExposure->setMinimum(1.000000000000000);
        pAHExposure->setMaximum(30.000000000000000);
        pAHExposure->setValue(2.000000000000000);

        horizontalLayout_15->addWidget(pAHExposure);

        horizontalSpacer_7 = new QSpacerItem(20, 20, QSizePolicy::Policy::Maximum, QSizePolicy::Policy::Minimum);

        horizontalLayout_15->addItem(horizontalSpacer_7);

        PAHIteration = new QLabel(PAHRefreshPage);
        PAHIteration->setObjectName("PAHIteration");
        PAHIteration->setEnabled(true);

        horizontalLayout_15->addWidget(PAHIteration);

        horizontalSpacer_7c = new QSpacerItem(20, 20, QSizePolicy::Policy::Maximum, QSizePolicy::Policy::Minimum);

        horizontalLayout_15->addItem(horizontalSpacer_7c);

        pAHRefreshAlgorithm = new QComboBox(PAHRefreshPage);
        pAHRefreshAlgorithm->addItem(QString());
        pAHRefreshAlgorithm->addItem(QString());
        pAHRefreshAlgorithm->addItem(QString());
        pAHRefreshAlgorithm->setObjectName("pAHRefreshAlgorithm");
        QSizePolicy sizePolicy(QSizePolicy::Policy::Preferred, QSizePolicy::Policy::Preferred);
        sizePolicy.setHorizontalStretch(0);
        sizePolicy.setVerticalStretch(0);
        sizePolicy.setHeightForWidth(pAHRefreshAlgorithm->sizePolicy().hasHeightForWidth());
        pAHRefreshAlgorithm->setSizePolicy(sizePolicy);

        horizontalLayout_15->addWidget(pAHRefreshAlgorithm);

        horizontalSpacer_7b = new QSpacerItem(40, 20, QSizePolicy::Policy::Expanding, QSizePolicy::Policy::Minimum);

        horizontalLayout_15->addItem(horizontalSpacer_7b);


        verticalLayout_15->addLayout(horizontalLayout_15);

        verticalSpacerBeforeErrors = new QSpacerItem(20, 20, QSizePolicy::Policy::Minimum, QSizePolicy::Policy::Expanding);

        verticalLayout_15->addItem(verticalSpacerBeforeErrors);

        PAHErrorLines = new QGridLayout();
        PAHErrorLines->setObjectName("PAHErrorLines");
        label_PAHOrigErrorAlt = new QLabel(PAHRefreshPage);
        label_PAHOrigErrorAlt->setObjectName("label_PAHOrigErrorAlt");
        label_PAHOrigErrorAlt->setMinimumSize(QSize(50, 0));
        label_PAHOrigErrorAlt->setMaximumSize(QSize(50, 16777215));
        label_PAHOrigErrorAlt->setAlignment(Qt::AlignRight|Qt::AlignTrailing|Qt::AlignVCenter);

        PAHErrorLines->addWidget(label_PAHOrigErrorAlt, 0, 2, 1, 1);

        label_PAHOrigErrorTotal = new QLabel(PAHRefreshPage);
        label_PAHOrigErrorTotal->setObjectName("label_PAHOrigErrorTotal");
        label_PAHOrigErrorTotal->setMinimumSize(QSize(100, 0));
        label_PAHOrigErrorTotal->setMaximumSize(QSize(100, 16777215));
        label_PAHOrigErrorTotal->setAlignment(Qt::AlignRight|Qt::AlignTrailing|Qt::AlignVCenter);

        PAHErrorLines->addWidget(label_PAHOrigErrorTotal, 0, 0, 1, 1);

        PAHOrigErrorTotal = new QLabel(PAHRefreshPage);
        PAHOrigErrorTotal->setObjectName("PAHOrigErrorTotal");
        PAHOrigErrorTotal->setMinimumSize(QSize(100, 0));
        PAHOrigErrorTotal->setMaximumSize(QSize(100, 16777215));

        PAHErrorLines->addWidget(PAHOrigErrorTotal, 0, 1, 1, 1);

        label_PAHUpdatedErrorTotal = new QLabel(PAHRefreshPage);
        label_PAHUpdatedErrorTotal->setObjectName("label_PAHUpdatedErrorTotal");
        label_PAHUpdatedErrorTotal->setMinimumSize(QSize(100, 0));
        label_PAHUpdatedErrorTotal->setMaximumSize(QSize(100, 16777215));
        label_PAHUpdatedErrorTotal->setAlignment(Qt::AlignRight|Qt::AlignTrailing|Qt::AlignVCenter);

        PAHErrorLines->addWidget(label_PAHUpdatedErrorTotal, 1, 0, 1, 1);

        horizontalSpacer_updatedError = new QSpacerItem(40, 20, QSizePolicy::Policy::Expanding, QSizePolicy::Policy::Minimum);

        PAHErrorLines->addItem(horizontalSpacer_updatedError, 1, 8, 1, 1);

        PAHOrigErrorAlt = new QLabel(PAHRefreshPage);
        PAHOrigErrorAlt->setObjectName("PAHOrigErrorAlt");
        PAHOrigErrorAlt->setMinimumSize(QSize(100, 0));
        PAHOrigErrorAlt->setMaximumSize(QSize(100, 16777215));

        PAHErrorLines->addWidget(PAHOrigErrorAlt, 0, 3, 1, 1);

        label_PAHOrigErrorAz = new QLabel(PAHRefreshPage);
        label_PAHOrigErrorAz->setObjectName("label_PAHOrigErrorAz");
        label_PAHOrigErrorAz->setMinimumSize(QSize(50, 0));
        label_PAHOrigErrorAz->setMaximumSize(QSize(50, 16777215));
        label_PAHOrigErrorAz->setAlignment(Qt::AlignRight|Qt::AlignTrailing|Qt::AlignVCenter);

        PAHErrorLines->addWidget(label_PAHOrigErrorAz, 0, 5, 1, 1);

        PAHOrigErrorAz = new QLabel(PAHRefreshPage);
        PAHOrigErrorAz->setObjectName("PAHOrigErrorAz");
        PAHOrigErrorAz->setMinimumSize(QSize(100, 0));
        PAHOrigErrorAz->setMaximumSize(QSize(100, 16777215));

        PAHErrorLines->addWidget(PAHOrigErrorAz, 0, 6, 1, 1);

        label_PAHUpdatedErrorAz = new QLabel(PAHRefreshPage);
        label_PAHUpdatedErrorAz->setObjectName("label_PAHUpdatedErrorAz");
        label_PAHUpdatedErrorAz->setMinimumSize(QSize(50, 0));
        label_PAHUpdatedErrorAz->setMaximumSize(QSize(50, 16777215));
        label_PAHUpdatedErrorAz->setAlignment(Qt::AlignRight|Qt::AlignTrailing|Qt::AlignVCenter);

        PAHErrorLines->addWidget(label_PAHUpdatedErrorAz, 1, 5, 1, 1);

        arrowAlt = new QLabel(PAHRefreshPage);
        arrowAlt->setObjectName("arrowAlt");
        arrowAlt->setEnabled(true);

        PAHErrorLines->addWidget(arrowAlt, 0, 4, 2, 1, Qt::AlignVCenter);

        label_PAHUpdatedErrorAlt = new QLabel(PAHRefreshPage);
        label_PAHUpdatedErrorAlt->setObjectName("label_PAHUpdatedErrorAlt");
        label_PAHUpdatedErrorAlt->setMinimumSize(QSize(50, 0));
        label_PAHUpdatedErrorAlt->setMaximumSize(QSize(50, 16777215));
        label_PAHUpdatedErrorAlt->setAlignment(Qt::AlignRight|Qt::AlignTrailing|Qt::AlignVCenter);

        PAHErrorLines->addWidget(label_PAHUpdatedErrorAlt, 1, 2, 1, 1);

        PAHUpdatedErrorAlt = new QLabel(PAHRefreshPage);
        PAHUpdatedErrorAlt->setObjectName("PAHUpdatedErrorAlt");
        PAHUpdatedErrorAlt->setMinimumSize(QSize(100, 0));
        PAHUpdatedErrorAlt->setMaximumSize(QSize(50, 16777215));

        PAHErrorLines->addWidget(PAHUpdatedErrorAlt, 1, 3, 1, 1);

        PAHUpdatedErrorTotal = new QLabel(PAHRefreshPage);
        PAHUpdatedErrorTotal->setObjectName("PAHUpdatedErrorTotal");
        PAHUpdatedErrorTotal->setMinimumSize(QSize(100, 0));
        PAHUpdatedErrorTotal->setMaximumSize(QSize(100, 16777215));

        PAHErrorLines->addWidget(PAHUpdatedErrorTotal, 1, 1, 1, 1);

        PAHUpdatedErrorAz = new QLabel(PAHRefreshPage);
        PAHUpdatedErrorAz->setObjectName("PAHUpdatedErrorAz");
        PAHUpdatedErrorAz->setMinimumSize(QSize(100, 0));
        PAHUpdatedErrorAz->setMaximumSize(QSize(100, 16777215));

        PAHErrorLines->addWidget(PAHUpdatedErrorAz, 1, 6, 1, 1);

        horizontalSpacer_origError = new QSpacerItem(40, 20, QSizePolicy::Policy::Expanding, QSizePolicy::Policy::Minimum);

        PAHErrorLines->addItem(horizontalSpacer_origError, 1, 8, 1, 1);

        arrowAz = new QLabel(PAHRefreshPage);
        arrowAz->setObjectName("arrowAz");
        arrowAz->setEnabled(true);

        PAHErrorLines->addWidget(arrowAz, 0, 7, 2, 1, Qt::AlignVCenter);

        PAHErrorLines->setColumnStretch(8, 1);

        verticalLayout_15->addLayout(PAHErrorLines);

        PAHWidgets->addWidget(PAHRefreshPage);

        mainPALayout->addWidget(PAHWidgets);

        horizontalLayout_2 = new QHBoxLayout();
        horizontalLayout_2->setSpacing(3);
        horizontalLayout_2->setObjectName("horizontalLayout_2");
        horizontalSpacer_2 = new QSpacerItem(40, 20, QSizePolicy::Policy::Expanding, QSizePolicy::Policy::Minimum);

        horizontalLayout_2->addItem(horizontalSpacer_2);

        PAHStartB = new QPushButton(PolarAlignmentAssistant);
        PAHStartB->setObjectName("PAHStartB");
        PAHStartB->setEnabled(false);

        horizontalLayout_2->addWidget(PAHStartB);

        PAHStopB = new QPushButton(PolarAlignmentAssistant);
        PAHStopB->setObjectName("PAHStopB");
        PAHStopB->setEnabled(false);

        horizontalLayout_2->addWidget(PAHStopB);


        mainPALayout->addLayout(horizontalLayout_2);


        retranslateUi(PolarAlignmentAssistant);

        PAHWidgets->setCurrentIndex(0);


        QMetaObject::connectSlotsByName(PolarAlignmentAssistant);
    } // setupUi

    void retranslateUi(QWidget *PolarAlignmentAssistant)
    {
#if QT_CONFIG(tooltip)
        PAHWidgets->setToolTip(tr2i18n("<p>Polar Alignment Helper tool requires the following:</p><p>1. German Equatorial Mount</p><p>2. Wide FOV &gt; 1 degrees</p><p>For small FOVs, use the Legacy Polar Alignment Tool.</p>", nullptr));
#endif // QT_CONFIG(tooltip)
        introText->setText(tr2i18n("<html><head/><body><p>Put your equatorial mount either (a) in the home position pointed toward the celestial pole or (b) pointed anywhere ideally near the meridian. Select <span style=\" font-weight:600;\">mount direction</span> and <span style=\" font-weight:600;\">speed </span>and then click <span style=\" font-weight:600;\">Start</span> to begin the polar alignment process.</p></body></html>", nullptr));
        FOVDisabledLabel->setText(tr2i18n("<html><head/><body><p><span style=\" font-weight:600;\">Disabled: FOV must be 10 arcmins or wider. 60+ arcminutes is recommended.</span></p></body></html>", nullptr));
        directionLabel->setText(tr2i18n("Direction:", nullptr));
        pAHDirection->setItemText(0, tr2i18n("West", nullptr));
        pAHDirection->setItemText(1, tr2i18n("East", nullptr));

#if QT_CONFIG(tooltip)
        pAHDirection->setToolTip(tr2i18n("Mount direction", nullptr));
#endif // QT_CONFIG(tooltip)
#if QT_CONFIG(tooltip)
        pAHRotation->setToolTip(tr2i18n("Rotation magnitude in degrees", nullptr));
#endif // QT_CONFIG(tooltip)
        label->setText(tr2i18n("Speed:", nullptr));
#if QT_CONFIG(tooltip)
        pAHMountSpeed->setToolTip(tr2i18n("Mount slew speed", nullptr));
#endif // QT_CONFIG(tooltip)
#if QT_CONFIG(tooltip)
        pAHManualSlew->setToolTip(tr2i18n("Toggle for manual slewing with non-GOTO mounts", nullptr));
#endif // QT_CONFIG(tooltip)
        pAHManualSlew->setText(tr2i18n("Manual slew", nullptr));
        PAHMessageText->setText(tr2i18n("<p>The assistant requires three images to find a solution.  Ekos is now capturing the first image...</p>", nullptr));
        manualRotateText->setText(tr2i18n("Please rotate your mount in RA", nullptr));
        PAHManualDone->setText(tr2i18n("Done", nullptr));
        refreshText->setText(QString());
#if QT_CONFIG(tooltip)
        PAHRefreshB->setToolTip(tr2i18n("Start the refresh phase--where image captures loop while you adjust the altitude and azimuth knobs to correct polar alignment.", nullptr));
#endif // QT_CONFIG(tooltip)
        PAHRefreshB->setText(tr2i18n("Refresh", nullptr));
#if QT_CONFIG(tooltip)
        pAHExposure->setToolTip(tr2i18n("Exposure duration in seconds during refresh phase", nullptr));
#endif // QT_CONFIG(tooltip)
        PAHIteration->setText(tr2i18n("Image#", nullptr));
        pAHRefreshAlgorithm->setItemText(0, tr2i18n("Plate Solve", nullptr));
        pAHRefreshAlgorithm->setItemText(1, tr2i18n("Move Star", nullptr));
        pAHRefreshAlgorithm->setItemText(2, tr2i18n("Move Star & Calc Error", nullptr));

#if QT_CONFIG(tooltip)
        pAHRefreshAlgorithm->setToolTip(tr2i18n("<html><head/><body><p>Select polar-alignment correction algorithm:</p><ul style=\"margin-top: 0px; margin-bottom: 0px; margin-left: 0px; margin-right: 0px; -qt-list-indent: 1;\"><li style=\" margin-top:12px; margin-bottom:0px; margin-left:0px; margin-right:0px; -qt-block-indent:0; text-indent:0px;\"><span style=\" font-weight:600;\">Plate Solve</span>: Uses plate solving to track what the corrected alignment error is during the Refresh process. User should try to reduce the error in the Updated Err line below and minimize the size of the arrows. This is the only scheme that can fully correct an error larger than the image field-of-view, but depends on reliable plate solving. </li><li style=\" margin-top:0px; margin-bottom:0px; margin-left:0px; margin-right:0px; -qt-block-indent:0; text-indent:0px;\"><span style=\" font-weight:600;\">Move Star</span>: A triangle is overlayed on the above captured image. User selects a star and moves the star along the triangle to improve the polar alignment. Corrected polar-ali"
                        "gnment error is not estimated during the process. If the alignment error is larger than the image field-of-view, this scheme must be used iteratively.</li><li style=\" margin-top:0px; margin-bottom:12px; margin-left:0px; margin-right:0px; -qt-block-indent:0; text-indent:0px;\"><span style=\" font-weight:600;\">Move Star and Calc Error</span>: Like Move Star, but Ekos attempts to track the star being moved and estimates the current alignment error when it can.</li></ul><p></body></html>", nullptr));
#endif // QT_CONFIG(tooltip)
#if QT_CONFIG(tooltip)
        label_PAHOrigErrorAlt->setToolTip(tr2i18n("Polar Alignment altitude error measured by the 3 exposures at the start of the polar-alignment procedure.", nullptr));
#endif // QT_CONFIG(tooltip)
        label_PAHOrigErrorAlt->setText(tr2i18n("Alt:", nullptr));
#if QT_CONFIG(tooltip)
        label_PAHOrigErrorTotal->setToolTip(tr2i18n("Polar Alignment total error measured by the 3 exposures at the start of the polar-alignment procedure.", nullptr));
#endif // QT_CONFIG(tooltip)
        label_PAHOrigErrorTotal->setText(tr2i18n("Measured Err:", nullptr));
#if QT_CONFIG(tooltip)
        PAHOrigErrorTotal->setToolTip(tr2i18n("Polar Alignment total error measured by the 3 exposures at the start of the polar-alignment procedure.", nullptr));
#endif // QT_CONFIG(tooltip)
#if QT_CONFIG(tooltip)
        label_PAHUpdatedErrorTotal->setToolTip(tr2i18n("Polar Alignment total error estimated after recent adjustments.", nullptr));
#endif // QT_CONFIG(tooltip)
        label_PAHUpdatedErrorTotal->setText(tr2i18n("Updated Err:", nullptr));
#if QT_CONFIG(tooltip)
        PAHOrigErrorAlt->setToolTip(tr2i18n("Polar Alignment altitude error measured by the 3 exposures at the start of the polar-alignment procedure.", nullptr));
#endif // QT_CONFIG(tooltip)
#if QT_CONFIG(tooltip)
        label_PAHOrigErrorAz->setToolTip(tr2i18n("Polar Alignment azimuth error measured by the 3 exposures at the start of the polar-alignment procedure.", nullptr));
#endif // QT_CONFIG(tooltip)
        label_PAHOrigErrorAz->setText(tr2i18n("Az:", nullptr));
#if QT_CONFIG(tooltip)
        PAHOrigErrorAz->setToolTip(tr2i18n("Polar Alignment azimuth error measured by the 3 exposures at the start of the polar-alignment procedure.", nullptr));
#endif // QT_CONFIG(tooltip)
#if QT_CONFIG(tooltip)
        label_PAHUpdatedErrorAz->setToolTip(tr2i18n("Polar Alignment azimuth error estimated after recent adjustments.", nullptr));
#endif // QT_CONFIG(tooltip)
        label_PAHUpdatedErrorAz->setText(QString());
        arrowAlt->setText(QString());
#if QT_CONFIG(tooltip)
        label_PAHUpdatedErrorAlt->setToolTip(tr2i18n("Polar Alignment altitude error estimated after recent adjustments.", nullptr));
#endif // QT_CONFIG(tooltip)
        label_PAHUpdatedErrorAlt->setText(QString());
#if QT_CONFIG(tooltip)
        PAHUpdatedErrorAlt->setToolTip(tr2i18n("Polar Alignment altitude error estimated after recent adjustments.", nullptr));
#endif // QT_CONFIG(tooltip)
#if QT_CONFIG(tooltip)
        PAHUpdatedErrorTotal->setToolTip(tr2i18n("Polar Alignment total error estimated after recent adjustments.", nullptr));
#endif // QT_CONFIG(tooltip)
#if QT_CONFIG(tooltip)
        PAHUpdatedErrorAz->setToolTip(tr2i18n("Polar Alignment azimuth error estimated after recent adjustments.", nullptr));
#endif // QT_CONFIG(tooltip)
        arrowAz->setText(QString());
#if QT_CONFIG(tooltip)
        PAHStartB->setToolTip(tr2i18n("Start", nullptr));
#endif // QT_CONFIG(tooltip)
        PAHStartB->setText(tr2i18n("Start", nullptr));
#if QT_CONFIG(tooltip)
        PAHStopB->setToolTip(tr2i18n("Stop", nullptr));
#endif // QT_CONFIG(tooltip)
        PAHStopB->setText(tr2i18n("Stop", nullptr));
        (void)PolarAlignmentAssistant;
    } // retranslateUi

};

namespace Ui {
    class PolarAlignmentAssistant: public Ui_PolarAlignmentAssistant {};
} // namespace Ui

QT_END_NAMESPACE

#endif // POLARALIGNMENTASSISTANT_H

