/****************************************************************************
** Meta object code from reading C++ file 'buildfilteroffsets.h'
**
** Created by: The Qt Meta Object Compiler version 69 (Qt 6.11.1)
**
** WARNING! All changes made in this file will be lost!
*****************************************************************************/

#include "../../../../kstars-3.8.4.1/kstars/ekos/auxiliary/buildfilteroffsets.h"
#include <QtCore/qmetatype.h>

#include <QtCore/qtmochelpers.h>

#include <memory>


#include <QtCore/qxptype_traits.h>
#if !defined(Q_MOC_OUTPUT_REVISION)
#error "The header file 'buildfilteroffsets.h' doesn't include <QObject>."
#elif Q_MOC_OUTPUT_REVISION != 69
#error "This file was generated using the moc from 6.11.1. It"
#error "cannot be used with the include files from this version of Qt."
#error "(The moc has changed too much.)"
#endif

#ifndef Q_CONSTINIT
#define Q_CONSTINIT
#endif

QT_WARNING_PUSH
QT_WARNING_DISABLE_DEPRECATED
QT_WARNING_DISABLE_GCC("-Wuseless-cast")
namespace {
struct qt_meta_tag_ZN4Ekos18BuildFilterOffsetsE_t {};
} // unnamed namespace

template <> constexpr inline auto Ekos::BuildFilterOffsets::qt_create_metaobjectdata<qt_meta_tag_ZN4Ekos18BuildFilterOffsetsE_t>()
{
    namespace QMC = QtMocConstants;
    QtMocHelpers::StringRefStorage qt_stringData {
        "Ekos::BuildFilterOffsets",
        "runAutoFocus",
        "",
        "AutofocusReason",
        "autofocusReason",
        "reasonInfo",
        "abortAutoFocus",
        "newFocusOffset",
        "value",
        "useAbsoluteOffset",
        "ready",
        "processingComplete",
        "offsetCalculated",
        "filter",
        "newOffset",
        "average",
        "progressUpdated",
        "current",
        "total",
        "status",
        "buildTheOffsets",
        "stopProcessing",
        "saveTheOffsets",
        "itemChanged",
        "QStandardItem*",
        "item",
        "refChanged",
        "QModelIndex",
        "index",
        "updateStatusBar",
        "message",
        "showDialog"
    };

    QtMocHelpers::UintData qt_methods {
        // Signal 'runAutoFocus'
        QtMocHelpers::SignalData<void(AutofocusReason, const QString &)>(1, 2, QMC::AccessPublic, QMetaType::Void, {{
            { 0x80000000 | 3, 4 }, { QMetaType::QString, 5 },
        }}),
        // Signal 'abortAutoFocus'
        QtMocHelpers::SignalData<void()>(6, 2, QMC::AccessPublic, QMetaType::Void),
        // Signal 'newFocusOffset'
        QtMocHelpers::SignalData<void(int, bool)>(7, 2, QMC::AccessPublic, QMetaType::Void, {{
            { QMetaType::Int, 8 }, { QMetaType::Bool, 9 },
        }}),
        // Signal 'ready'
        QtMocHelpers::SignalData<void()>(10, 2, QMC::AccessPublic, QMetaType::Void),
        // Signal 'processingComplete'
        QtMocHelpers::SignalData<void()>(11, 2, QMC::AccessPublic, QMetaType::Void),
        // Signal 'offsetCalculated'
        QtMocHelpers::SignalData<void(const QString &, int, int)>(12, 2, QMC::AccessPublic, QMetaType::Void, {{
            { QMetaType::QString, 13 }, { QMetaType::Int, 14 }, { QMetaType::Int, 15 },
        }}),
        // Signal 'progressUpdated'
        QtMocHelpers::SignalData<void(int, int, const QString &)>(16, 2, QMC::AccessPublic, QMetaType::Void, {{
            { QMetaType::Int, 17 }, { QMetaType::Int, 18 }, { QMetaType::QString, 19 },
        }}),
        // Slot 'buildTheOffsets'
        QtMocHelpers::SlotData<void()>(20, 2, QMC::AccessPublic, QMetaType::Void),
        // Slot 'stopProcessing'
        QtMocHelpers::SlotData<void()>(21, 2, QMC::AccessPublic, QMetaType::Void),
        // Slot 'saveTheOffsets'
        QtMocHelpers::SlotData<void()>(22, 2, QMC::AccessPublic, QMetaType::Void),
        // Slot 'itemChanged'
        QtMocHelpers::SlotData<void(QStandardItem *)>(23, 2, QMC::AccessPrivate, QMetaType::Void, {{
            { 0x80000000 | 24, 25 },
        }}),
        // Slot 'refChanged'
        QtMocHelpers::SlotData<void(QModelIndex)>(26, 2, QMC::AccessPrivate, QMetaType::Void, {{
            { 0x80000000 | 27, 28 },
        }}),
        // Slot 'updateStatusBar'
        QtMocHelpers::SlotData<void(const QString &)>(29, 2, QMC::AccessPrivate, QMetaType::Void, {{
            { QMetaType::QString, 30 },
        }}),
        // Method 'showDialog'
        QtMocHelpers::MethodData<void()>(31, 2, QMC::AccessPublic, QMetaType::Void),
    };
    QtMocHelpers::UintData qt_properties {
    };
    QtMocHelpers::UintData qt_enums {
    };
    return QtMocHelpers::metaObjectData<BuildFilterOffsets, qt_meta_tag_ZN4Ekos18BuildFilterOffsetsE_t>(QMC::MetaObjectFlag{}, qt_stringData,
            qt_methods, qt_properties, qt_enums);
}
Q_CONSTINIT const QMetaObject Ekos::BuildFilterOffsets::staticMetaObject = { {
    QMetaObject::SuperData::link<QDialog::staticMetaObject>(),
    qt_staticMetaObjectStaticContent<qt_meta_tag_ZN4Ekos18BuildFilterOffsetsE_t>.stringdata,
    qt_staticMetaObjectStaticContent<qt_meta_tag_ZN4Ekos18BuildFilterOffsetsE_t>.data,
    qt_static_metacall,
    nullptr,
    qt_staticMetaObjectRelocatingContent<qt_meta_tag_ZN4Ekos18BuildFilterOffsetsE_t>.metaTypes,
    nullptr
} };

void Ekos::BuildFilterOffsets::qt_static_metacall(QObject *_o, QMetaObject::Call _c, int _id, void **_a)
{
    auto *_t = static_cast<BuildFilterOffsets *>(_o);
    if (_c == QMetaObject::InvokeMetaMethod) {
        switch (_id) {
        case 0: _t->runAutoFocus((*reinterpret_cast<std::add_pointer_t<AutofocusReason>>(_a[1])),(*reinterpret_cast<std::add_pointer_t<QString>>(_a[2]))); break;
        case 1: _t->abortAutoFocus(); break;
        case 2: _t->newFocusOffset((*reinterpret_cast<std::add_pointer_t<int>>(_a[1])),(*reinterpret_cast<std::add_pointer_t<bool>>(_a[2]))); break;
        case 3: _t->ready(); break;
        case 4: _t->processingComplete(); break;
        case 5: _t->offsetCalculated((*reinterpret_cast<std::add_pointer_t<QString>>(_a[1])),(*reinterpret_cast<std::add_pointer_t<int>>(_a[2])),(*reinterpret_cast<std::add_pointer_t<int>>(_a[3]))); break;
        case 6: _t->progressUpdated((*reinterpret_cast<std::add_pointer_t<int>>(_a[1])),(*reinterpret_cast<std::add_pointer_t<int>>(_a[2])),(*reinterpret_cast<std::add_pointer_t<QString>>(_a[3]))); break;
        case 7: _t->buildTheOffsets(); break;
        case 8: _t->stopProcessing(); break;
        case 9: _t->saveTheOffsets(); break;
        case 10: _t->itemChanged((*reinterpret_cast<std::add_pointer_t<QStandardItem*>>(_a[1]))); break;
        case 11: _t->refChanged((*reinterpret_cast<std::add_pointer_t<QModelIndex>>(_a[1]))); break;
        case 12: _t->updateStatusBar((*reinterpret_cast<std::add_pointer_t<QString>>(_a[1]))); break;
        case 13: _t->showDialog(); break;
        default: ;
        }
    }
    if (_c == QMetaObject::IndexOfMethod) {
        if (QtMocHelpers::indexOfMethod<void (BuildFilterOffsets::*)(AutofocusReason , const QString & )>(_a, &BuildFilterOffsets::runAutoFocus, 0))
            return;
        if (QtMocHelpers::indexOfMethod<void (BuildFilterOffsets::*)()>(_a, &BuildFilterOffsets::abortAutoFocus, 1))
            return;
        if (QtMocHelpers::indexOfMethod<void (BuildFilterOffsets::*)(int , bool )>(_a, &BuildFilterOffsets::newFocusOffset, 2))
            return;
        if (QtMocHelpers::indexOfMethod<void (BuildFilterOffsets::*)()>(_a, &BuildFilterOffsets::ready, 3))
            return;
        if (QtMocHelpers::indexOfMethod<void (BuildFilterOffsets::*)()>(_a, &BuildFilterOffsets::processingComplete, 4))
            return;
        if (QtMocHelpers::indexOfMethod<void (BuildFilterOffsets::*)(const QString & , int , int )>(_a, &BuildFilterOffsets::offsetCalculated, 5))
            return;
        if (QtMocHelpers::indexOfMethod<void (BuildFilterOffsets::*)(int , int , const QString & )>(_a, &BuildFilterOffsets::progressUpdated, 6))
            return;
    }
}

const QMetaObject *Ekos::BuildFilterOffsets::metaObject() const
{
    return QObject::d_ptr->metaObject ? QObject::d_ptr->dynamicMetaObject() : &staticMetaObject;
}

void *Ekos::BuildFilterOffsets::qt_metacast(const char *_clname)
{
    if (!_clname) return nullptr;
    if (!strcmp(_clname, qt_staticMetaObjectStaticContent<qt_meta_tag_ZN4Ekos18BuildFilterOffsetsE_t>.strings))
        return static_cast<void*>(this);
    if (!strcmp(_clname, "Ui::buildOffsetsDialog"))
        return static_cast< Ui::buildOffsetsDialog*>(this);
    return QDialog::qt_metacast(_clname);
}

int Ekos::BuildFilterOffsets::qt_metacall(QMetaObject::Call _c, int _id, void **_a)
{
    _id = QDialog::qt_metacall(_c, _id, _a);
    if (_id < 0)
        return _id;
    if (_c == QMetaObject::InvokeMetaMethod) {
        if (_id < 14)
            qt_static_metacall(this, _c, _id, _a);
        _id -= 14;
    }
    if (_c == QMetaObject::RegisterMethodArgumentMetaType) {
        if (_id < 14)
            *reinterpret_cast<QMetaType *>(_a[0]) = QMetaType();
        _id -= 14;
    }
    return _id;
}

// SIGNAL 0
void Ekos::BuildFilterOffsets::runAutoFocus(AutofocusReason _t1, const QString & _t2)
{
    QMetaObject::activate<void>(this, &staticMetaObject, 0, nullptr, _t1, _t2);
}

// SIGNAL 1
void Ekos::BuildFilterOffsets::abortAutoFocus()
{
    QMetaObject::activate(this, &staticMetaObject, 1, nullptr);
}

// SIGNAL 2
void Ekos::BuildFilterOffsets::newFocusOffset(int _t1, bool _t2)
{
    QMetaObject::activate<void>(this, &staticMetaObject, 2, nullptr, _t1, _t2);
}

// SIGNAL 3
void Ekos::BuildFilterOffsets::ready()
{
    QMetaObject::activate(this, &staticMetaObject, 3, nullptr);
}

// SIGNAL 4
void Ekos::BuildFilterOffsets::processingComplete()
{
    QMetaObject::activate(this, &staticMetaObject, 4, nullptr);
}

// SIGNAL 5
void Ekos::BuildFilterOffsets::offsetCalculated(const QString & _t1, int _t2, int _t3)
{
    QMetaObject::activate<void>(this, &staticMetaObject, 5, nullptr, _t1, _t2, _t3);
}

// SIGNAL 6
void Ekos::BuildFilterOffsets::progressUpdated(int _t1, int _t2, const QString & _t3)
{
    QMetaObject::activate<void>(this, &staticMetaObject, 6, nullptr, _t1, _t2, _t3);
}
QT_WARNING_POP
