/********************************************************************************
** Form generated from reading UI file 'opsalign.ui'
**
** Created by: Qt User Interface Compiler version 6.11.1
**
** WARNING! All changes made in this file will be lost when recompiling UI file!
********************************************************************************/

#ifndef UI_OPSALIGN_H
#define UI_OPSALIGN_H

#include <QtCore/QVariant>
#include <QtWidgets/QApplication>
#include <QtWidgets/QCheckBox>
#include <QtWidgets/QComboBox>
#include <QtWidgets/QDoubleSpinBox>
#include <QtWidgets/QGridLayout>
#include <QtWidgets/QGroupBox>
#include <QtWidgets/QHBoxLayout>
#include <QtWidgets/QLabel>
#include <QtWidgets/QPushButton>
#include <QtWidgets/QRadioButton>
#include <QtWidgets/QSpacerItem>
#include <QtWidgets/QSpinBox>
#include <QtWidgets/QVBoxLayout>
#include <QtWidgets/QWidget>
#include <klocalizedstring.h>

QT_BEGIN_NAMESPACE

class Ui_OpsAlign
{
public:
    QVBoxLayout *verticalLayout;
    QGroupBox *groupBox_6;
    QGridLayout *gridLayout_17;
    QLabel *label_73;
    QComboBox *kcfg_SolveSextractorType;
    QComboBox *kcfg_SolverType;
    QLabel *label_72;
    QLabel *label_71;
    QHBoxLayout *horizontalLayout_4;
    QComboBox *kcfg_SolveOptionsProfile;
    QPushButton *editSolverProfile;
    QGroupBox *groupBox_2;
    QGridLayout *gridLayout_2;
    QCheckBox *kcfg_AstrometrySolverOverlay;
    QCheckBox *kcfg_PAHAutoPark;
    QCheckBox *kcfg_AstrometrySolverWCS;
    QCheckBox *kcfg_AstrometryDynamicThreshold;
    QGroupBox *groupBox;
    QGridLayout *gridLayout;
    QGroupBox *kcfg_AstrometryUseRotator;
    QGridLayout *gridLayout_3;
    QLabel *label;
    QDoubleSpinBox *kcfg_AstrometryRotatorThreshold;
    QLabel *label_2;
    QLabel *label_3;
    QRadioButton *kcfg_AstrometryFlipRotationAllowed;
    QLabel *label_4;
    QRadioButton *FlipRotationNotAllowed;
    QCheckBox *kcfg_RotatorParityReversed;
    QGroupBox *groupBoxAutoPAC;
    QGridLayout *gridLayout_AutoPAC;
    QCheckBox *kcfg_PAHAutoPACCorrection;
    QCheckBox *kcfg_PAHAutoChangeDirection;
    QLabel *labelSuccessThreshold;
    QDoubleSpinBox *kcfg_PAHSuccessThreshold;
    QLabel *labelSuccessThresholdUnit;
    QLabel *labelCorrectionTimeout;
    QSpinBox *kcfg_PAHCorrectionTimeout;
    QLabel *labelCorrectionTimeoutUnit;
    QSpacerItem *verticalSpacer;

    void setupUi(QWidget *OpsAlign)
    {
        if (OpsAlign->objectName().isEmpty())
            OpsAlign->setObjectName("OpsAlign");
        OpsAlign->resize(519, 480);
        verticalLayout = new QVBoxLayout(OpsAlign);
        verticalLayout->setSpacing(3);
        verticalLayout->setObjectName("verticalLayout");
        verticalLayout->setContentsMargins(3, 3, 3, 3);
        groupBox_6 = new QGroupBox(OpsAlign);
        groupBox_6->setObjectName("groupBox_6");
        gridLayout_17 = new QGridLayout(groupBox_6);
        gridLayout_17->setObjectName("gridLayout_17");
        gridLayout_17->setContentsMargins(3, 3, 3, 3);
        label_73 = new QLabel(groupBox_6);
        label_73->setObjectName("label_73");
        QSizePolicy sizePolicy(QSizePolicy::Policy::Fixed, QSizePolicy::Policy::Preferred);
        sizePolicy.setHorizontalStretch(0);
        sizePolicy.setVerticalStretch(0);
        sizePolicy.setHeightForWidth(label_73->sizePolicy().hasHeightForWidth());
        label_73->setSizePolicy(sizePolicy);
        label_73->setMaximumSize(QSize(16777215, 15));
        label_73->setAlignment(Qt::AlignmentFlag::AlignCenter);

        gridLayout_17->addWidget(label_73, 0, 1, 1, 1);

        kcfg_SolveSextractorType = new QComboBox(groupBox_6);
        kcfg_SolveSextractorType->addItem(QString());
        kcfg_SolveSextractorType->addItem(QString());
        kcfg_SolveSextractorType->addItem(QString());
        kcfg_SolveSextractorType->setObjectName("kcfg_SolveSextractorType");

        gridLayout_17->addWidget(kcfg_SolveSextractorType, 1, 1, 1, 1);

        kcfg_SolverType = new QComboBox(groupBox_6);
        kcfg_SolverType->addItem(QString());
        kcfg_SolverType->addItem(QString());
        kcfg_SolverType->addItem(QString());
        kcfg_SolverType->addItem(QString());
        kcfg_SolverType->addItem(QString());
        kcfg_SolverType->setObjectName("kcfg_SolverType");

        gridLayout_17->addWidget(kcfg_SolverType, 1, 2, 1, 1);

        label_72 = new QLabel(groupBox_6);
        label_72->setObjectName("label_72");
        sizePolicy.setHeightForWidth(label_72->sizePolicy().hasHeightForWidth());
        label_72->setSizePolicy(sizePolicy);
        label_72->setMaximumSize(QSize(16777215, 15));
        label_72->setAlignment(Qt::AlignmentFlag::AlignCenter);

        gridLayout_17->addWidget(label_72, 0, 2, 1, 1);

        label_71 = new QLabel(groupBox_6);
        label_71->setObjectName("label_71");
        sizePolicy.setHeightForWidth(label_71->sizePolicy().hasHeightForWidth());
        label_71->setSizePolicy(sizePolicy);
        label_71->setMaximumSize(QSize(16777215, 15));
        label_71->setAlignment(Qt::AlignmentFlag::AlignCenter);

        gridLayout_17->addWidget(label_71, 0, 4, 1, 1);

        horizontalLayout_4 = new QHBoxLayout();
        horizontalLayout_4->setSpacing(3);
        horizontalLayout_4->setObjectName("horizontalLayout_4");
        kcfg_SolveOptionsProfile = new QComboBox(groupBox_6);
        kcfg_SolveOptionsProfile->setObjectName("kcfg_SolveOptionsProfile");
        QSizePolicy sizePolicy1(QSizePolicy::Policy::Preferred, QSizePolicy::Policy::Fixed);
        sizePolicy1.setHorizontalStretch(0);
        sizePolicy1.setVerticalStretch(0);
        sizePolicy1.setHeightForWidth(kcfg_SolveOptionsProfile->sizePolicy().hasHeightForWidth());
        kcfg_SolveOptionsProfile->setSizePolicy(sizePolicy1);

        horizontalLayout_4->addWidget(kcfg_SolveOptionsProfile);

        editSolverProfile = new QPushButton(groupBox_6);
        editSolverProfile->setObjectName("editSolverProfile");
        sizePolicy1.setHeightForWidth(editSolverProfile->sizePolicy().hasHeightForWidth());
        editSolverProfile->setSizePolicy(sizePolicy1);

        horizontalLayout_4->addWidget(editSolverProfile);


        gridLayout_17->addLayout(horizontalLayout_4, 1, 4, 1, 1);


        verticalLayout->addWidget(groupBox_6);

        groupBox_2 = new QGroupBox(OpsAlign);
        groupBox_2->setObjectName("groupBox_2");
        gridLayout_2 = new QGridLayout(groupBox_2);
        gridLayout_2->setObjectName("gridLayout_2");
        gridLayout_2->setContentsMargins(3, 3, 3, 3);
        kcfg_AstrometrySolverOverlay = new QCheckBox(groupBox_2);
        kcfg_AstrometrySolverOverlay->setObjectName("kcfg_AstrometrySolverOverlay");

        gridLayout_2->addWidget(kcfg_AstrometrySolverOverlay, 0, 1, 1, 1);

        kcfg_PAHAutoPark = new QCheckBox(groupBox_2);
        kcfg_PAHAutoPark->setObjectName("kcfg_PAHAutoPark");

        gridLayout_2->addWidget(kcfg_PAHAutoPark, 0, 2, 1, 1);

        kcfg_AstrometrySolverWCS = new QCheckBox(groupBox_2);
        kcfg_AstrometrySolverWCS->setObjectName("kcfg_AstrometrySolverWCS");

        gridLayout_2->addWidget(kcfg_AstrometrySolverWCS, 0, 0, 1, 1);

        kcfg_AstrometryDynamicThreshold = new QCheckBox(groupBox_2);
        kcfg_AstrometryDynamicThreshold->setObjectName("kcfg_AstrometryDynamicThreshold");

        gridLayout_2->addWidget(kcfg_AstrometryDynamicThreshold, 0, 3, 1, 1);


        verticalLayout->addWidget(groupBox_2);

        groupBox = new QGroupBox(OpsAlign);
        groupBox->setObjectName("groupBox");
        gridLayout = new QGridLayout(groupBox);
        gridLayout->setObjectName("gridLayout");
        kcfg_AstrometryUseRotator = new QGroupBox(groupBox);
        kcfg_AstrometryUseRotator->setObjectName("kcfg_AstrometryUseRotator");
        QSizePolicy sizePolicy2(QSizePolicy::Policy::Preferred, QSizePolicy::Policy::Preferred);
        sizePolicy2.setHorizontalStretch(0);
        sizePolicy2.setVerticalStretch(0);
        sizePolicy2.setHeightForWidth(kcfg_AstrometryUseRotator->sizePolicy().hasHeightForWidth());
        kcfg_AstrometryUseRotator->setSizePolicy(sizePolicy2);
        kcfg_AstrometryUseRotator->setCheckable(true);
        gridLayout_3 = new QGridLayout(kcfg_AstrometryUseRotator);
        gridLayout_3->setObjectName("gridLayout_3");
        label = new QLabel(kcfg_AstrometryUseRotator);
        label->setObjectName("label");

        gridLayout_3->addWidget(label, 0, 0, 1, 1);

        kcfg_AstrometryRotatorThreshold = new QDoubleSpinBox(kcfg_AstrometryUseRotator);
        kcfg_AstrometryRotatorThreshold->setObjectName("kcfg_AstrometryRotatorThreshold");
        QSizePolicy sizePolicy3(QSizePolicy::Policy::Minimum, QSizePolicy::Policy::Preferred);
        sizePolicy3.setHorizontalStretch(0);
        sizePolicy3.setVerticalStretch(0);
        sizePolicy3.setHeightForWidth(kcfg_AstrometryRotatorThreshold->sizePolicy().hasHeightForWidth());
        kcfg_AstrometryRotatorThreshold->setSizePolicy(sizePolicy3);
        kcfg_AstrometryRotatorThreshold->setMaximumSize(QSize(80, 25));
        kcfg_AstrometryRotatorThreshold->setMaximum(120.000000000000000);
        kcfg_AstrometryRotatorThreshold->setSingleStep(10.000000000000000);

        gridLayout_3->addWidget(kcfg_AstrometryRotatorThreshold, 0, 1, 1, 1);

        label_2 = new QLabel(kcfg_AstrometryUseRotator);
        label_2->setObjectName("label_2");

        gridLayout_3->addWidget(label_2, 0, 2, 1, 1);

        label_3 = new QLabel(kcfg_AstrometryUseRotator);
        label_3->setObjectName("label_3");

        gridLayout_3->addWidget(label_3, 1, 0, 1, 1);

        kcfg_AstrometryFlipRotationAllowed = new QRadioButton(kcfg_AstrometryUseRotator);
        kcfg_AstrometryFlipRotationAllowed->setObjectName("kcfg_AstrometryFlipRotationAllowed");

        gridLayout_3->addWidget(kcfg_AstrometryFlipRotationAllowed, 1, 1, 1, 2);

        label_4 = new QLabel(kcfg_AstrometryUseRotator);
        label_4->setObjectName("label_4");

        gridLayout_3->addWidget(label_4, 1, 3, 1, 1);

        FlipRotationNotAllowed = new QRadioButton(kcfg_AstrometryUseRotator);
        FlipRotationNotAllowed->setObjectName("FlipRotationNotAllowed");

        gridLayout_3->addWidget(FlipRotationNotAllowed, 2, 1, 1, 2);

        kcfg_RotatorParityReversed = new QCheckBox(kcfg_AstrometryUseRotator);
        kcfg_RotatorParityReversed->setObjectName("kcfg_RotatorParityReversed");

        gridLayout_3->addWidget(kcfg_RotatorParityReversed, 3, 0, 1, 3);


        gridLayout->addWidget(kcfg_AstrometryUseRotator, 0, 0, 1, 1);


        verticalLayout->addWidget(groupBox);

        groupBoxAutoPAC = new QGroupBox(OpsAlign);
        groupBoxAutoPAC->setObjectName("groupBoxAutoPAC");
        gridLayout_AutoPAC = new QGridLayout(groupBoxAutoPAC);
        gridLayout_AutoPAC->setObjectName("gridLayout_AutoPAC");
        gridLayout_AutoPAC->setContentsMargins(3, 3, 3, 3);
        kcfg_PAHAutoPACCorrection = new QCheckBox(groupBoxAutoPAC);
        kcfg_PAHAutoPACCorrection->setObjectName("kcfg_PAHAutoPACCorrection");

        gridLayout_AutoPAC->addWidget(kcfg_PAHAutoPACCorrection, 0, 0, 1, 3);

        kcfg_PAHAutoChangeDirection = new QCheckBox(groupBoxAutoPAC);
        kcfg_PAHAutoChangeDirection->setObjectName("kcfg_PAHAutoChangeDirection");

        gridLayout_AutoPAC->addWidget(kcfg_PAHAutoChangeDirection, 1, 0, 1, 3);

        labelSuccessThreshold = new QLabel(groupBoxAutoPAC);
        labelSuccessThreshold->setObjectName("labelSuccessThreshold");

        gridLayout_AutoPAC->addWidget(labelSuccessThreshold, 2, 0, 1, 1);

        kcfg_PAHSuccessThreshold = new QDoubleSpinBox(groupBoxAutoPAC);
        kcfg_PAHSuccessThreshold->setObjectName("kcfg_PAHSuccessThreshold");
        kcfg_PAHSuccessThreshold->setMinimum(0.100000000000000);
        kcfg_PAHSuccessThreshold->setMaximum(60.000000000000000);
        kcfg_PAHSuccessThreshold->setSingleStep(1.000000000000000);
        kcfg_PAHSuccessThreshold->setValue(30.000000000000000);

        gridLayout_AutoPAC->addWidget(kcfg_PAHSuccessThreshold, 2, 1, 1, 1);

        labelSuccessThresholdUnit = new QLabel(groupBoxAutoPAC);
        labelSuccessThresholdUnit->setObjectName("labelSuccessThresholdUnit");

        gridLayout_AutoPAC->addWidget(labelSuccessThresholdUnit, 2, 2, 1, 1);

        labelCorrectionTimeout = new QLabel(groupBoxAutoPAC);
        labelCorrectionTimeout->setObjectName("labelCorrectionTimeout");

        gridLayout_AutoPAC->addWidget(labelCorrectionTimeout, 3, 0, 1, 1);

        kcfg_PAHCorrectionTimeout = new QSpinBox(groupBoxAutoPAC);
        kcfg_PAHCorrectionTimeout->setObjectName("kcfg_PAHCorrectionTimeout");
        kcfg_PAHCorrectionTimeout->setMinimum(30);
        kcfg_PAHCorrectionTimeout->setMaximum(3600);
        kcfg_PAHCorrectionTimeout->setSingleStep(30);
        kcfg_PAHCorrectionTimeout->setValue(300);

        gridLayout_AutoPAC->addWidget(kcfg_PAHCorrectionTimeout, 3, 1, 1, 1);

        labelCorrectionTimeoutUnit = new QLabel(groupBoxAutoPAC);
        labelCorrectionTimeoutUnit->setObjectName("labelCorrectionTimeoutUnit");

        gridLayout_AutoPAC->addWidget(labelCorrectionTimeoutUnit, 3, 2, 1, 1);


        verticalLayout->addWidget(groupBoxAutoPAC);

        verticalSpacer = new QSpacerItem(20, 40, QSizePolicy::Policy::Minimum, QSizePolicy::Policy::Expanding);

        verticalLayout->addItem(verticalSpacer);


        retranslateUi(OpsAlign);

        kcfg_SolveOptionsProfile->setCurrentIndex(-1);


        QMetaObject::connectSlotsByName(OpsAlign);
    } // setupUi

    void retranslateUi(QWidget *OpsAlign)
    {
        groupBox_6->setTitle(tr2i18n("StellarSolver Settings", nullptr));
        label_73->setText(tr2i18n("Source Extraction Method", nullptr));
        kcfg_SolveSextractorType->setItemText(0, tr2i18n("Internal SEP", nullptr));
        kcfg_SolveSextractorType->setItemText(1, tr2i18n("External SExtractor", nullptr));
        kcfg_SolveSextractorType->setItemText(2, tr2i18n("BuiltIn method for solver", nullptr));

#if QT_CONFIG(tooltip)
        kcfg_SolveSextractorType->setToolTip(tr2i18n("<html><head/><body><p align=\"center\">Options for the method of Star Extraction</p><ul style=\"margin-top: 0px; margin-bottom: 0px; margin-left: 0px; margin-right: 0px; -qt-list-indent: 1;\"><li style=\" margin-top:12px; margin-bottom:0px; margin-left:0px; margin-right:0px; -qt-block-indent:0; text-indent:0px;\">Internal SEP uses an internal library in KStars.</li><li style=\" margin-top:0px; margin-bottom:0px; margin-left:0px; margin-right:0px; -qt-block-indent:0; text-indent:0px;\">External Sextractor requires an external program.</li><li style=\" margin-top:0px; margin-bottom:12px; margin-left:0px; margin-right:0px; -qt-block-indent:0; text-indent:0px;\">Built In Method uses whatever default Star Extraction process your selected Solving Method uses.</li></ul></body></html>", nullptr));
#endif // QT_CONFIG(tooltip)
        kcfg_SolverType->setItemText(0, tr2i18n("Internal Solver", nullptr));
        kcfg_SolverType->setItemText(1, tr2i18n("Local Astrometry", nullptr));
        kcfg_SolverType->setItemText(2, tr2i18n("Local ASTAP", nullptr));
        kcfg_SolverType->setItemText(3, tr2i18n("Local Watney", nullptr));
        kcfg_SolverType->setItemText(4, tr2i18n("Online Astrometry", nullptr));

#if QT_CONFIG(tooltip)
        kcfg_SolverType->setToolTip(tr2i18n("<html><head/><body><p align=\"center\">Selects the method of plate solving with the StellarSolver Library</p><ul><li>'Internal SEP' option uses StellarSolver's internal build of Astrometry.net and requires no external programs. </li><li>'Local Astrometry' uses a local installation of command line astrometry.net on Linux and Mac or ANSVR on Windows. </li><li>'Local ASTAP' uses a local installation of the ASTAP program. </li><li>'Local Watney' uses a local installation of the Watney Astrometry Solver Program.</li><li>'Online' uses either astrometry.net over the internet or ANSVR on a nearby computer. <span style=\" font-weight:600;\">Note</span>: If bandwidth is a concern, consider using 'Internal SEP' instead of 'Builtin Method of Solver'.</li></ul></body></html>", nullptr));
#endif // QT_CONFIG(tooltip)
        label_72->setText(tr2i18n("Solving Method", nullptr));
        label_71->setText(tr2i18n("Options Profile:", nullptr));
#if QT_CONFIG(tooltip)
        kcfg_SolveOptionsProfile->setToolTip(tr2i18n("Selects the Options Profile to use for Plate Solving", nullptr));
#endif // QT_CONFIG(tooltip)
#if QT_CONFIG(tooltip)
        editSolverProfile->setToolTip(tr2i18n("Opens the currently selected Options Profile in the Options Profile Editor", nullptr));
#endif // QT_CONFIG(tooltip)
        editSolverProfile->setText(QString());
        groupBox_2->setTitle(tr2i18n("Alignment Options", nullptr));
#if QT_CONFIG(tooltip)
        kcfg_AstrometrySolverOverlay->setToolTip(tr2i18n("Display received FITS images unto solver FOV rectangle in the sky map", nullptr));
#endif // QT_CONFIG(tooltip)
        kcfg_AstrometrySolverOverlay->setText(tr2i18n("Overlay", nullptr));
#if QT_CONFIG(tooltip)
        kcfg_PAHAutoPark->setToolTip(tr2i18n("<html><head/><body><p>Automatically park mount after completing Polar Alignment Assistant Tools.</p></body></html>", nullptr));
#endif // QT_CONFIG(tooltip)
        kcfg_PAHAutoPark->setText(tr2i18n("Auto Park", nullptr));
#if QT_CONFIG(tooltip)
        kcfg_AstrometrySolverWCS->setToolTip(tr2i18n("enable World Coordinate System (WCS). WCS is used to encode RA/DEC coordinates in captured CCD images.", nullptr));
#endif // QT_CONFIG(tooltip)
        kcfg_AstrometrySolverWCS->setText(tr2i18n("WCS", nullptr));
#if QT_CONFIG(tooltip)
        kcfg_AstrometryDynamicThreshold->setToolTip(tr2i18n("Adjust StellarSolver threshold dynamically based on source extractor detected stars to expedite solving.", nullptr));
#endif // QT_CONFIG(tooltip)
        kcfg_AstrometryDynamicThreshold->setText(tr2i18n("Dynamic Threshold", nullptr));
        groupBox->setTitle(tr2i18n("Rotator Settings", nullptr));
        kcfg_AstrometryUseRotator->setTitle(tr2i18n("Automatic and Manual Rotator Control", nullptr));
#if QT_CONFIG(tooltip)
        label->setToolTip(tr2i18n("<html><head/><body><p>Rotation deviation threshold in arc-minutes when using [Load &amp; Slew]. If the difference between measured position angle and FITS position angle is below this value, the [Load &amp; Slew] operation is considered successful.</p></body></html>", nullptr));
#endif // QT_CONFIG(tooltip)
        label->setText(tr2i18n("Threshold: ", nullptr));
#if QT_CONFIG(tooltip)
        kcfg_AstrometryRotatorThreshold->setToolTip(tr2i18n("<html><head/><body><p>Rotation angle deviation threshold</p></body></html>", nullptr));
#endif // QT_CONFIG(tooltip)
        label_2->setText(tr2i18n("arcmin", nullptr));
#if QT_CONFIG(tooltip)
        label_3->setToolTip(tr2i18n("<html><head/><body><p><span style=\" font-weight:600;\">Flip Policy</span> determines how the rotator reacts after a flip or if the result of a solved reference image reports a different pierside respective to the actual mount pierside.</p></body></html>", nullptr));
#endif // QT_CONFIG(tooltip)
        label_3->setText(tr2i18n("Flip Policy: ", nullptr));
#if QT_CONFIG(tooltip)
        kcfg_AstrometryFlipRotationAllowed->setToolTip(tr2i18n("<html><head/><body><p><span style=\" font-weight:600;\">Preserve rotator angle</span> will keep the rotator position. The rotator remains inactive and hence the camera is virtually rotated by 180\302\260.</p><p>Most modern astronomic image processing applications can handle &quot;flipped&quot; images.</p></body></html>", nullptr));
#endif // QT_CONFIG(tooltip)
        kcfg_AstrometryFlipRotationAllowed->setText(tr2i18n("Preserve rotator angle", nullptr));
        label_4->setText(QString());
#if QT_CONFIG(tooltip)
        FlipRotationNotAllowed->setToolTip(tr2i18n("<html><head/><body><p><span style=\" font-weight:600;\">Preserve position angle</span> will keep the camera position angle. The rotator always turns the camera to the original position angle and hence the image will show exactly the original star arrangement.</p></body></html>", nullptr));
#endif // QT_CONFIG(tooltip)
        FlipRotationNotAllowed->setText(tr2i18n("Preserve position angle", nullptr));
#if QT_CONFIG(tooltip)
        kcfg_RotatorParityReversed->setToolTip(tr2i18n("<html><head/><body><p>Enable if the rotator physically turns opposite to the direction expected. Detected and set automatically the first time the wrong-direction check confirms it; can also be set manually.</p></body></html>", nullptr));
#endif // QT_CONFIG(tooltip)
        kcfg_RotatorParityReversed->setText(tr2i18n("Rotator direction reversed", nullptr));
        groupBoxAutoPAC->setTitle(tr2i18n("Automatic Polar Alignment", nullptr));
#if QT_CONFIG(tooltip)
        kcfg_PAHAutoPACCorrection->setToolTip(tr2i18n("<html><head/><body><p>When enabled and a PAC (Polar Alignment Corrector) device is connected, the system will automatically send correction commands to the PAC during the refresh phase instead of requiring manual knob adjustments.</p></body></html>", nullptr));
#endif // QT_CONFIG(tooltip)
        kcfg_PAHAutoPACCorrection->setText(tr2i18n("Automatic PAC Correction", nullptr));
#if QT_CONFIG(tooltip)
        kcfg_PAHAutoChangeDirection->setToolTip(tr2i18n("<html><head/><body><p>When enabled, if the polar alignment error in an axis <b>increases</b> after the first PAC correction, the system will automatically reverse the correction direction for that axis on the next attempt.</p></body></html>", nullptr));
#endif // QT_CONFIG(tooltip)
        kcfg_PAHAutoChangeDirection->setText(tr2i18n("Auto Change Direction", nullptr));
#if QT_CONFIG(tooltip)
        labelSuccessThreshold->setToolTip(tr2i18n("If the total polar alignment error drops to or below this threshold, the alignment is considered successful and the process stops.", nullptr));
#endif // QT_CONFIG(tooltip)
        labelSuccessThreshold->setText(tr2i18n("Success Threshold:", nullptr));
#if QT_CONFIG(tooltip)
        kcfg_PAHSuccessThreshold->setToolTip(tr2i18n("Polar alignment success threshold in arcminutes. If the total error is at or below this value, alignment is considered successful.", nullptr));
#endif // QT_CONFIG(tooltip)
        labelSuccessThresholdUnit->setText(tr2i18n("arcmin", nullptr));
#if QT_CONFIG(tooltip)
        labelCorrectionTimeout->setToolTip(tr2i18n("If the system cannot reach the desired threshold within this period, it aborts the automatic correction.", nullptr));
#endif // QT_CONFIG(tooltip)
        labelCorrectionTimeout->setText(tr2i18n("Correction Timeout:", nullptr));
#if QT_CONFIG(tooltip)
        kcfg_PAHCorrectionTimeout->setToolTip(tr2i18n("Timeout in seconds for automatic polar alignment correction.", nullptr));
#endif // QT_CONFIG(tooltip)
        labelCorrectionTimeoutUnit->setText(tr2i18n("sec", nullptr));
        (void)OpsAlign;
    } // retranslateUi

};

namespace Ui {
    class OpsAlign: public Ui_OpsAlign {};
} // namespace Ui

QT_END_NAMESPACE

#endif // OPSALIGN_H

