/****************************************************************************
** Meta object code from reading C++ file 'projector.h'
**
** Created by: The Qt Meta Object Compiler version 69 (Qt 6.11.1)
**
** WARNING! All changes made in this file will be lost!
*****************************************************************************/

#include "../../../../kstars-3.8.4.1/kstars/projections/projector.h"
#include <QtCore/qmetatype.h>

#include <QtCore/qtmochelpers.h>

#include <memory>


#include <QtCore/qxptype_traits.h>
#if !defined(Q_MOC_OUTPUT_REVISION)
#error "The header file 'projector.h' doesn't include <QObject>."
#elif Q_MOC_OUTPUT_REVISION != 69
#error "This file was generated using the moc from 6.11.1. It"
#error "cannot be used with the include files from this version of Qt."
#error "(The moc has changed too much.)"
#endif

#ifndef Q_CONSTINIT
#define Q_CONSTINIT
#endif

QT_WARNING_PUSH
QT_WARNING_DISABLE_DEPRECATED
QT_WARNING_DISABLE_GCC("-Wuseless-cast")
namespace {
struct qt_meta_tag_ZN9ProjectorE_t {};
} // unnamed namespace

template <> constexpr inline auto Projector::qt_create_metaobjectdata<qt_meta_tag_ZN9ProjectorE_t>()
{
    namespace QMC = QtMocConstants;
    QtMocHelpers::StringRefStorage qt_stringData {
        "Projector",
        "type",
        "Projection",
        "",
        "Lambert",
        "AzimuthalEquidistant",
        "Orthographic",
        "Equirectangular",
        "Stereographic",
        "Gnomonic",
        "UnknownProjection"
    };

    QtMocHelpers::UintData qt_methods {
        // Method 'type'
        QtMocHelpers::MethodData<enum Projection() const>(1, 3, QMC::AccessPublic, 0x80000000 | 2),
    };
    QtMocHelpers::UintData qt_properties {
    };
    QtMocHelpers::UintData qt_enums {
        // enum 'Projection'
        QtMocHelpers::EnumData<enum Projection>(2, 2, QMC::EnumFlags{}).add({
            {    4, Projection::Lambert },
            {    5, Projection::AzimuthalEquidistant },
            {    6, Projection::Orthographic },
            {    7, Projection::Equirectangular },
            {    8, Projection::Stereographic },
            {    9, Projection::Gnomonic },
            {   10, Projection::UnknownProjection },
        }),
    };
    return QtMocHelpers::metaObjectData<Projector, qt_meta_tag_ZN9ProjectorE_t>(QMC::PropertyAccessInStaticMetaCall, qt_stringData,
            qt_methods, qt_properties, qt_enums);
}
Q_CONSTINIT const QMetaObject Projector::staticMetaObject = { {
    nullptr,
    qt_staticMetaObjectStaticContent<qt_meta_tag_ZN9ProjectorE_t>.stringdata,
    qt_staticMetaObjectStaticContent<qt_meta_tag_ZN9ProjectorE_t>.data,
    qt_static_metacall,
    nullptr,
    qt_staticMetaObjectRelocatingContent<qt_meta_tag_ZN9ProjectorE_t>.metaTypes,
    nullptr
} };

void Projector::qt_static_metacall(QObject *_o, QMetaObject::Call _c, int _id, void **_a)
{
    auto *_t = reinterpret_cast<Projector *>(_o);
    if (_c == QMetaObject::InvokeMetaMethod) {
        switch (_id) {
        case 0: { enum Projection _r = _t->type();
            if (_a[0]) *reinterpret_cast<enum Projection*>(_a[0]) = std::move(_r); }  break;
        default: ;
        }
    }
}
QT_WARNING_POP
