/****************************************************************************
** Meta object code from reading C++ file 'servermanager.h'
**
** Created by: The Qt Meta Object Compiler version 69 (Qt 6.11.1)
**
** WARNING! All changes made in this file will be lost!
*****************************************************************************/

#include "../../../../kstars-3.8.4.1/kstars/indi/servermanager.h"
#include <QtCore/qmetatype.h>
#include <QtCore/QSharedPointer>

#include <QtCore/qtmochelpers.h>

#include <memory>


#include <QtCore/qxptype_traits.h>
#if !defined(Q_MOC_OUTPUT_REVISION)
#error "The header file 'servermanager.h' doesn't include <QObject>."
#elif Q_MOC_OUTPUT_REVISION != 69
#error "This file was generated using the moc from 6.11.1. It"
#error "cannot be used with the include files from this version of Qt."
#error "(The moc has changed too much.)"
#endif

#ifndef Q_CONSTINIT
#define Q_CONSTINIT
#endif

QT_WARNING_PUSH
QT_WARNING_DISABLE_DEPRECATED
QT_WARNING_DISABLE_GCC("-Wuseless-cast")
namespace {
struct qt_meta_tag_ZN13ServerManagerE_t {};
} // unnamed namespace

template <> constexpr inline auto ServerManager::qt_create_metaobjectdata<qt_meta_tag_ZN13ServerManagerE_t>()
{
    namespace QMC = QtMocConstants;
    QtMocHelpers::StringRefStorage qt_stringData {
        "ServerManager",
        "started",
        "",
        "stopped",
        "failed",
        "message",
        "terminated",
        "newServerLog",
        "driverStarted",
        "QSharedPointer<DriverInfo>",
        "driver",
        "driverStopped",
        "driverRestarted",
        "scriptDriverStarted",
        "driverFailed",
        "processServerError",
        "QProcess::ProcessError",
        "processStandardError",
        "connectScriptDriver"
    };

    QtMocHelpers::UintData qt_methods {
        // Signal 'started'
        QtMocHelpers::SignalData<void()>(1, 2, QMC::AccessPublic, QMetaType::Void),
        // Signal 'stopped'
        QtMocHelpers::SignalData<void()>(3, 2, QMC::AccessPublic, QMetaType::Void),
        // Signal 'failed'
        QtMocHelpers::SignalData<void(const QString &)>(4, 2, QMC::AccessPublic, QMetaType::Void, {{
            { QMetaType::QString, 5 },
        }}),
        // Signal 'terminated'
        QtMocHelpers::SignalData<void(const QString &)>(6, 2, QMC::AccessPublic, QMetaType::Void, {{
            { QMetaType::QString, 5 },
        }}),
        // Signal 'newServerLog'
        QtMocHelpers::SignalData<void()>(7, 2, QMC::AccessPublic, QMetaType::Void),
        // Signal 'driverStarted'
        QtMocHelpers::SignalData<void(const QSharedPointer<DriverInfo> &)>(8, 2, QMC::AccessPublic, QMetaType::Void, {{
            { 0x80000000 | 9, 10 },
        }}),
        // Signal 'driverStopped'
        QtMocHelpers::SignalData<void(const QSharedPointer<DriverInfo> &)>(11, 2, QMC::AccessPublic, QMetaType::Void, {{
            { 0x80000000 | 9, 10 },
        }}),
        // Signal 'driverRestarted'
        QtMocHelpers::SignalData<void(const QSharedPointer<DriverInfo> &)>(12, 2, QMC::AccessPublic, QMetaType::Void, {{
            { 0x80000000 | 9, 10 },
        }}),
        // Signal 'scriptDriverStarted'
        QtMocHelpers::SignalData<void(const QSharedPointer<DriverInfo> &)>(13, 2, QMC::AccessPublic, QMetaType::Void, {{
            { 0x80000000 | 9, 10 },
        }}),
        // Signal 'driverFailed'
        QtMocHelpers::SignalData<void(const QSharedPointer<DriverInfo> &, const QString &)>(14, 2, QMC::AccessPublic, QMetaType::Void, {{
            { 0x80000000 | 9, 10 }, { QMetaType::QString, 5 },
        }}),
        // Slot 'processServerError'
        QtMocHelpers::SlotData<void(QProcess::ProcessError)>(15, 2, QMC::AccessPublic, QMetaType::Void, {{
            { 0x80000000 | 16, 2 },
        }}),
        // Slot 'processStandardError'
        QtMocHelpers::SlotData<void()>(17, 2, QMC::AccessPublic, QMetaType::Void),
        // Slot 'connectScriptDriver'
        QtMocHelpers::SlotData<void(const QSharedPointer<DriverInfo> &)>(18, 2, QMC::AccessPublic, QMetaType::Void, {{
            { 0x80000000 | 9, 10 },
        }}),
    };
    QtMocHelpers::UintData qt_properties {
    };
    QtMocHelpers::UintData qt_enums {
    };
    return QtMocHelpers::metaObjectData<ServerManager, qt_meta_tag_ZN13ServerManagerE_t>(QMC::MetaObjectFlag{}, qt_stringData,
            qt_methods, qt_properties, qt_enums);
}
Q_CONSTINIT const QMetaObject ServerManager::staticMetaObject = { {
    QMetaObject::SuperData::link<QObject::staticMetaObject>(),
    qt_staticMetaObjectStaticContent<qt_meta_tag_ZN13ServerManagerE_t>.stringdata,
    qt_staticMetaObjectStaticContent<qt_meta_tag_ZN13ServerManagerE_t>.data,
    qt_static_metacall,
    nullptr,
    qt_staticMetaObjectRelocatingContent<qt_meta_tag_ZN13ServerManagerE_t>.metaTypes,
    nullptr
} };

void ServerManager::qt_static_metacall(QObject *_o, QMetaObject::Call _c, int _id, void **_a)
{
    auto *_t = static_cast<ServerManager *>(_o);
    if (_c == QMetaObject::InvokeMetaMethod) {
        switch (_id) {
        case 0: _t->started(); break;
        case 1: _t->stopped(); break;
        case 2: _t->failed((*reinterpret_cast<std::add_pointer_t<QString>>(_a[1]))); break;
        case 3: _t->terminated((*reinterpret_cast<std::add_pointer_t<QString>>(_a[1]))); break;
        case 4: _t->newServerLog(); break;
        case 5: _t->driverStarted((*reinterpret_cast<std::add_pointer_t<QSharedPointer<DriverInfo>>>(_a[1]))); break;
        case 6: _t->driverStopped((*reinterpret_cast<std::add_pointer_t<QSharedPointer<DriverInfo>>>(_a[1]))); break;
        case 7: _t->driverRestarted((*reinterpret_cast<std::add_pointer_t<QSharedPointer<DriverInfo>>>(_a[1]))); break;
        case 8: _t->scriptDriverStarted((*reinterpret_cast<std::add_pointer_t<QSharedPointer<DriverInfo>>>(_a[1]))); break;
        case 9: _t->driverFailed((*reinterpret_cast<std::add_pointer_t<QSharedPointer<DriverInfo>>>(_a[1])),(*reinterpret_cast<std::add_pointer_t<QString>>(_a[2]))); break;
        case 10: _t->processServerError((*reinterpret_cast<std::add_pointer_t<QProcess::ProcessError>>(_a[1]))); break;
        case 11: _t->processStandardError(); break;
        case 12: _t->connectScriptDriver((*reinterpret_cast<std::add_pointer_t<QSharedPointer<DriverInfo>>>(_a[1]))); break;
        default: ;
        }
    }
    if (_c == QMetaObject::IndexOfMethod) {
        if (QtMocHelpers::indexOfMethod<void (ServerManager::*)()>(_a, &ServerManager::started, 0))
            return;
        if (QtMocHelpers::indexOfMethod<void (ServerManager::*)()>(_a, &ServerManager::stopped, 1))
            return;
        if (QtMocHelpers::indexOfMethod<void (ServerManager::*)(const QString & )>(_a, &ServerManager::failed, 2))
            return;
        if (QtMocHelpers::indexOfMethod<void (ServerManager::*)(const QString & )>(_a, &ServerManager::terminated, 3))
            return;
        if (QtMocHelpers::indexOfMethod<void (ServerManager::*)()>(_a, &ServerManager::newServerLog, 4))
            return;
        if (QtMocHelpers::indexOfMethod<void (ServerManager::*)(const QSharedPointer<DriverInfo> & )>(_a, &ServerManager::driverStarted, 5))
            return;
        if (QtMocHelpers::indexOfMethod<void (ServerManager::*)(const QSharedPointer<DriverInfo> & )>(_a, &ServerManager::driverStopped, 6))
            return;
        if (QtMocHelpers::indexOfMethod<void (ServerManager::*)(const QSharedPointer<DriverInfo> & )>(_a, &ServerManager::driverRestarted, 7))
            return;
        if (QtMocHelpers::indexOfMethod<void (ServerManager::*)(const QSharedPointer<DriverInfo> & )>(_a, &ServerManager::scriptDriverStarted, 8))
            return;
        if (QtMocHelpers::indexOfMethod<void (ServerManager::*)(const QSharedPointer<DriverInfo> & , const QString & )>(_a, &ServerManager::driverFailed, 9))
            return;
    }
}

const QMetaObject *ServerManager::metaObject() const
{
    return QObject::d_ptr->metaObject ? QObject::d_ptr->dynamicMetaObject() : &staticMetaObject;
}

void *ServerManager::qt_metacast(const char *_clname)
{
    if (!_clname) return nullptr;
    if (!strcmp(_clname, qt_staticMetaObjectStaticContent<qt_meta_tag_ZN13ServerManagerE_t>.strings))
        return static_cast<void*>(this);
    return QObject::qt_metacast(_clname);
}

int ServerManager::qt_metacall(QMetaObject::Call _c, int _id, void **_a)
{
    _id = QObject::qt_metacall(_c, _id, _a);
    if (_id < 0)
        return _id;
    if (_c == QMetaObject::InvokeMetaMethod) {
        if (_id < 13)
            qt_static_metacall(this, _c, _id, _a);
        _id -= 13;
    }
    if (_c == QMetaObject::RegisterMethodArgumentMetaType) {
        if (_id < 13)
            *reinterpret_cast<QMetaType *>(_a[0]) = QMetaType();
        _id -= 13;
    }
    return _id;
}

// SIGNAL 0
void ServerManager::started()
{
    QMetaObject::activate(this, &staticMetaObject, 0, nullptr);
}

// SIGNAL 1
void ServerManager::stopped()
{
    QMetaObject::activate(this, &staticMetaObject, 1, nullptr);
}

// SIGNAL 2
void ServerManager::failed(const QString & _t1)
{
    QMetaObject::activate<void>(this, &staticMetaObject, 2, nullptr, _t1);
}

// SIGNAL 3
void ServerManager::terminated(const QString & _t1)
{
    QMetaObject::activate<void>(this, &staticMetaObject, 3, nullptr, _t1);
}

// SIGNAL 4
void ServerManager::newServerLog()
{
    QMetaObject::activate(this, &staticMetaObject, 4, nullptr);
}

// SIGNAL 5
void ServerManager::driverStarted(const QSharedPointer<DriverInfo> & _t1)
{
    QMetaObject::activate<void>(this, &staticMetaObject, 5, nullptr, _t1);
}

// SIGNAL 6
void ServerManager::driverStopped(const QSharedPointer<DriverInfo> & _t1)
{
    QMetaObject::activate<void>(this, &staticMetaObject, 6, nullptr, _t1);
}

// SIGNAL 7
void ServerManager::driverRestarted(const QSharedPointer<DriverInfo> & _t1)
{
    QMetaObject::activate<void>(this, &staticMetaObject, 7, nullptr, _t1);
}

// SIGNAL 8
void ServerManager::scriptDriverStarted(const QSharedPointer<DriverInfo> & _t1)
{
    QMetaObject::activate<void>(this, &staticMetaObject, 8, nullptr, _t1);
}

// SIGNAL 9
void ServerManager::driverFailed(const QSharedPointer<DriverInfo> & _t1, const QString & _t2)
{
    QMetaObject::activate<void>(this, &staticMetaObject, 9, nullptr, _t1, _t2);
}
QT_WARNING_POP
