/****************************************************************************
** Meta object code from reading C++ file 'fitstab.h'
**
** Created by: The Qt Meta Object Compiler version 69 (Qt 6.11.1)
**
** WARNING! All changes made in this file will be lost!
*****************************************************************************/

#include "../../../../kstars-3.8.4.1/kstars/fitsviewer/fitstab.h"
#include <QtNetwork/QSslError>
#include <QtGui/qtextcursor.h>
#include <QtGui/qscreen.h>
#include <QtCore/qmetatype.h>

#include <QtCore/qtmochelpers.h>

#include <memory>


#include <QtCore/qxptype_traits.h>
#if !defined(Q_MOC_OUTPUT_REVISION)
#error "The header file 'fitstab.h' doesn't include <QObject>."
#elif Q_MOC_OUTPUT_REVISION != 69
#error "This file was generated using the moc from 6.11.1. It"
#error "cannot be used with the include files from this version of Qt."
#error "(The moc has changed too much.)"
#endif

#ifndef Q_CONSTINIT
#define Q_CONSTINIT
#endif

QT_WARNING_PUSH
QT_WARNING_DISABLE_DEPRECATED
QT_WARNING_DISABLE_GCC("-Wuseless-cast")
namespace {
struct qt_meta_tag_ZN7FITSTabE_t {};
} // unnamed namespace

template <> constexpr inline auto FITSTab::qt_create_metaobjectdata<qt_meta_tag_ZN7FITSTabE_t>()
{
    namespace QMC = QtMocConstants;
    QtMocHelpers::StringRefStorage qt_stringData {
        "FITSTab",
        "debayerToggled",
        "",
        "newStatus",
        "msg",
        "FITSBar",
        "id",
        "changeStatus",
        "clean",
        "QUrl",
        "imageUrl",
        "loaded",
        "updated",
        "failed",
        "errorMessage",
        "modifyFITSState",
        "imageURL",
        "ZoomIn",
        "ZoomOut",
        "ZoomDefault",
        "displayStats",
        "roi",
        "extractImage",
        "liveStack",
        "startProgrammatically",
        "dir",
        "LiveStackData",
        "params",
        "stopProgrammatically",
        "setStretchValues",
        "shadows",
        "midtones",
        "highlights",
        "setAutoStretch"
    };

    QtMocHelpers::UintData qt_methods {
        // Signal 'debayerToggled'
        QtMocHelpers::SignalData<void(bool)>(1, 2, QMC::AccessPublic, QMetaType::Void, {{
            { QMetaType::Bool, 2 },
        }}),
        // Signal 'newStatus'
        QtMocHelpers::SignalData<void(const QString &, FITSBar)>(3, 2, QMC::AccessPublic, QMetaType::Void, {{
            { QMetaType::QString, 4 }, { 0x80000000 | 5, 6 },
        }}),
        // Signal 'changeStatus'
        QtMocHelpers::SignalData<void(bool, const QUrl &)>(7, 2, QMC::AccessPublic, QMetaType::Void, {{
            { QMetaType::Bool, 8 }, { 0x80000000 | 9, 10 },
        }}),
        // Signal 'loaded'
        QtMocHelpers::SignalData<void()>(11, 2, QMC::AccessPublic, QMetaType::Void),
        // Signal 'updated'
        QtMocHelpers::SignalData<void()>(12, 2, QMC::AccessPublic, QMetaType::Void),
        // Signal 'failed'
        QtMocHelpers::SignalData<void(const QString &)>(13, 2, QMC::AccessPublic, QMetaType::Void, {{
            { QMetaType::QString, 14 },
        }}),
        // Slot 'modifyFITSState'
        QtMocHelpers::SlotData<void(bool, const QUrl &)>(15, 2, QMC::AccessPublic, QMetaType::Void, {{
            { QMetaType::Bool, 8 }, { 0x80000000 | 9, 16 },
        }}),
        // Slot 'modifyFITSState'
        QtMocHelpers::SlotData<void(bool)>(15, 2, QMC::AccessPublic | QMC::MethodCloned, QMetaType::Void, {{
            { QMetaType::Bool, 8 },
        }}),
        // Slot 'modifyFITSState'
        QtMocHelpers::SlotData<void()>(15, 2, QMC::AccessPublic | QMC::MethodCloned, QMetaType::Void),
        // Slot 'ZoomIn'
        QtMocHelpers::SlotData<void()>(17, 2, QMC::AccessPublic, QMetaType::Void),
        // Slot 'ZoomOut'
        QtMocHelpers::SlotData<void()>(18, 2, QMC::AccessPublic, QMetaType::Void),
        // Slot 'ZoomDefault'
        QtMocHelpers::SlotData<void()>(19, 2, QMC::AccessPublic, QMetaType::Void),
        // Slot 'displayStats'
        QtMocHelpers::SlotData<void(bool)>(20, 2, QMC::AccessPublic, QMetaType::Void, {{
            { QMetaType::Bool, 21 },
        }}),
        // Slot 'displayStats'
        QtMocHelpers::SlotData<void()>(20, 2, QMC::AccessPublic | QMC::MethodCloned, QMetaType::Void),
        // Slot 'extractImage'
        QtMocHelpers::SlotData<void()>(22, 2, QMC::AccessPublic, QMetaType::Void),
        // Slot 'liveStack'
        QtMocHelpers::SlotData<void()>(23, 2, QMC::AccessPublic, QMetaType::Void),
        // Slot 'startProgrammatically'
        QtMocHelpers::SlotData<void(const QString &, const LiveStackData &)>(24, 2, QMC::AccessPublic, QMetaType::Void, {{
            { QMetaType::QString, 25 }, { 0x80000000 | 26, 27 },
        }}),
        // Slot 'stopProgrammatically'
        QtMocHelpers::SlotData<void()>(28, 2, QMC::AccessPublic, QMetaType::Void),
        // Method 'setStretchValues'
        QtMocHelpers::MethodData<void(double, double, double)>(29, 2, QMC::AccessPublic | QMC::MethodScriptable, QMetaType::Void, {{
            { QMetaType::Double, 30 }, { QMetaType::Double, 31 }, { QMetaType::Double, 32 },
        }}),
        // Method 'setAutoStretch'
        QtMocHelpers::MethodData<void()>(33, 2, QMC::AccessPublic | QMC::MethodScriptable, QMetaType::Void),
    };
    QtMocHelpers::UintData qt_properties {
    };
    QtMocHelpers::UintData qt_enums {
    };
    return QtMocHelpers::metaObjectData<FITSTab, qt_meta_tag_ZN7FITSTabE_t>(QMC::MetaObjectFlag{}, qt_stringData,
            qt_methods, qt_properties, qt_enums);
}
Q_CONSTINIT const QMetaObject FITSTab::staticMetaObject = { {
    QMetaObject::SuperData::link<QWidget::staticMetaObject>(),
    qt_staticMetaObjectStaticContent<qt_meta_tag_ZN7FITSTabE_t>.stringdata,
    qt_staticMetaObjectStaticContent<qt_meta_tag_ZN7FITSTabE_t>.data,
    qt_static_metacall,
    nullptr,
    qt_staticMetaObjectRelocatingContent<qt_meta_tag_ZN7FITSTabE_t>.metaTypes,
    nullptr
} };

void FITSTab::qt_static_metacall(QObject *_o, QMetaObject::Call _c, int _id, void **_a)
{
    auto *_t = static_cast<FITSTab *>(_o);
    if (_c == QMetaObject::InvokeMetaMethod) {
        switch (_id) {
        case 0: _t->debayerToggled((*reinterpret_cast<std::add_pointer_t<bool>>(_a[1]))); break;
        case 1: _t->newStatus((*reinterpret_cast<std::add_pointer_t<QString>>(_a[1])),(*reinterpret_cast<std::add_pointer_t<FITSBar>>(_a[2]))); break;
        case 2: _t->changeStatus((*reinterpret_cast<std::add_pointer_t<bool>>(_a[1])),(*reinterpret_cast<std::add_pointer_t<QUrl>>(_a[2]))); break;
        case 3: _t->loaded(); break;
        case 4: _t->updated(); break;
        case 5: _t->failed((*reinterpret_cast<std::add_pointer_t<QString>>(_a[1]))); break;
        case 6: _t->modifyFITSState((*reinterpret_cast<std::add_pointer_t<bool>>(_a[1])),(*reinterpret_cast<std::add_pointer_t<QUrl>>(_a[2]))); break;
        case 7: _t->modifyFITSState((*reinterpret_cast<std::add_pointer_t<bool>>(_a[1]))); break;
        case 8: _t->modifyFITSState(); break;
        case 9: _t->ZoomIn(); break;
        case 10: _t->ZoomOut(); break;
        case 11: _t->ZoomDefault(); break;
        case 12: _t->displayStats((*reinterpret_cast<std::add_pointer_t<bool>>(_a[1]))); break;
        case 13: _t->displayStats(); break;
        case 14: _t->extractImage(); break;
        case 15: _t->liveStack(); break;
        case 16: _t->startProgrammatically((*reinterpret_cast<std::add_pointer_t<QString>>(_a[1])),(*reinterpret_cast<std::add_pointer_t<LiveStackData>>(_a[2]))); break;
        case 17: _t->stopProgrammatically(); break;
        case 18: _t->setStretchValues((*reinterpret_cast<std::add_pointer_t<double>>(_a[1])),(*reinterpret_cast<std::add_pointer_t<double>>(_a[2])),(*reinterpret_cast<std::add_pointer_t<double>>(_a[3]))); break;
        case 19: _t->setAutoStretch(); break;
        default: ;
        }
    }
    if (_c == QMetaObject::IndexOfMethod) {
        if (QtMocHelpers::indexOfMethod<void (FITSTab::*)(bool )>(_a, &FITSTab::debayerToggled, 0))
            return;
        if (QtMocHelpers::indexOfMethod<void (FITSTab::*)(const QString & , FITSBar )>(_a, &FITSTab::newStatus, 1))
            return;
        if (QtMocHelpers::indexOfMethod<void (FITSTab::*)(bool , const QUrl & )>(_a, &FITSTab::changeStatus, 2))
            return;
        if (QtMocHelpers::indexOfMethod<void (FITSTab::*)()>(_a, &FITSTab::loaded, 3))
            return;
        if (QtMocHelpers::indexOfMethod<void (FITSTab::*)()>(_a, &FITSTab::updated, 4))
            return;
        if (QtMocHelpers::indexOfMethod<void (FITSTab::*)(const QString & )>(_a, &FITSTab::failed, 5))
            return;
    }
}

const QMetaObject *FITSTab::metaObject() const
{
    return QObject::d_ptr->metaObject ? QObject::d_ptr->dynamicMetaObject() : &staticMetaObject;
}

void *FITSTab::qt_metacast(const char *_clname)
{
    if (!_clname) return nullptr;
    if (!strcmp(_clname, qt_staticMetaObjectStaticContent<qt_meta_tag_ZN7FITSTabE_t>.strings))
        return static_cast<void*>(this);
    return QWidget::qt_metacast(_clname);
}

int FITSTab::qt_metacall(QMetaObject::Call _c, int _id, void **_a)
{
    _id = QWidget::qt_metacall(_c, _id, _a);
    if (_id < 0)
        return _id;
    if (_c == QMetaObject::InvokeMetaMethod) {
        if (_id < 20)
            qt_static_metacall(this, _c, _id, _a);
        _id -= 20;
    }
    if (_c == QMetaObject::RegisterMethodArgumentMetaType) {
        if (_id < 20)
            *reinterpret_cast<QMetaType *>(_a[0]) = QMetaType();
        _id -= 20;
    }
    return _id;
}

// SIGNAL 0
void FITSTab::debayerToggled(bool _t1)
{
    QMetaObject::activate<void>(this, &staticMetaObject, 0, nullptr, _t1);
}

// SIGNAL 1
void FITSTab::newStatus(const QString & _t1, FITSBar _t2)
{
    QMetaObject::activate<void>(this, &staticMetaObject, 1, nullptr, _t1, _t2);
}

// SIGNAL 2
void FITSTab::changeStatus(bool _t1, const QUrl & _t2)
{
    QMetaObject::activate<void>(this, &staticMetaObject, 2, nullptr, _t1, _t2);
}

// SIGNAL 3
void FITSTab::loaded()
{
    QMetaObject::activate(this, &staticMetaObject, 3, nullptr);
}

// SIGNAL 4
void FITSTab::updated()
{
    QMetaObject::activate(this, &staticMetaObject, 4, nullptr);
}

// SIGNAL 5
void FITSTab::failed(const QString & _t1)
{
    QMetaObject::activate<void>(this, &staticMetaObject, 5, nullptr, _t1);
}
QT_WARNING_POP
