/********************************************************************************
** Form generated from reading UI file 'scheduleraltitudegraph.ui'
**
** Created by: Qt User Interface Compiler version 6.11.1
**
** WARNING! All changes made in this file will be lost when recompiling UI file!
********************************************************************************/

#ifndef UI_SCHEDULERALTITUDEGRAPH_H
#define UI_SCHEDULERALTITUDEGRAPH_H

#include <QtCore/QVariant>
#include <QtWidgets/QApplication>
#include <QtWidgets/QFrame>
#include <QtWidgets/QHBoxLayout>
#include <QtWidgets/QLabel>
#include <QtWidgets/QPushButton>
#include <QtWidgets/QVBoxLayout>
#include <klocalizedstring.h>
#include "kplotwidget.h"
#include "tools/avtplotwidget.h"

QT_BEGIN_NAMESPACE

class Ui_SchedulerAltitudeGraph
{
public:
    QVBoxLayout *altGraphLayoutV;
    QLabel *altGraphLabel;
    QHBoxLayout *altGraphLayoutH;
    QPushButton *altMoveLeftB;
    AVTPlotWidget *altGraph;
    QPushButton *altMoveRightB;

    void setupUi(QFrame *SchedulerAltitudeGraph)
    {
        if (SchedulerAltitudeGraph->objectName().isEmpty())
            SchedulerAltitudeGraph->setObjectName("SchedulerAltitudeGraph");
        SchedulerAltitudeGraph->resize(188, 171);
        SchedulerAltitudeGraph->setStyleSheet(QString::fromUtf8("background-color: black; color: white;"));
        altGraphLayoutV = new QVBoxLayout(SchedulerAltitudeGraph);
        altGraphLayoutV->setSpacing(1);
        altGraphLayoutV->setObjectName("altGraphLayoutV");
        altGraphLayoutV->setContentsMargins(1, 1, 1, 1);
        altGraphLabel = new QLabel(SchedulerAltitudeGraph);
        altGraphLabel->setObjectName("altGraphLabel");
        QSizePolicy sizePolicy(QSizePolicy::Policy::Expanding, QSizePolicy::Policy::Fixed);
        sizePolicy.setHorizontalStretch(0);
        sizePolicy.setVerticalStretch(0);
        sizePolicy.setHeightForWidth(altGraphLabel->sizePolicy().hasHeightForWidth());
        altGraphLabel->setSizePolicy(sizePolicy);
        altGraphLabel->setMinimumSize(QSize(32, 16));
        altGraphLabel->setMaximumSize(QSize(10000, 16));
        altGraphLabel->setStyleSheet(QString::fromUtf8("background-color: black; color: white;"));
        altGraphLabel->setAlignment(Qt::AlignCenter);

        altGraphLayoutV->addWidget(altGraphLabel);

        altGraphLayoutH = new QHBoxLayout();
        altGraphLayoutH->setSpacing(1);
        altGraphLayoutH->setObjectName("altGraphLayoutH");
        altGraphLayoutH->setContentsMargins(1, 0, 1, 0);
        altMoveLeftB = new QPushButton(SchedulerAltitudeGraph);
        altMoveLeftB->setObjectName("altMoveLeftB");
        QSizePolicy sizePolicy1(QSizePolicy::Policy::Fixed, QSizePolicy::Policy::Fixed);
        sizePolicy1.setHorizontalStretch(0);
        sizePolicy1.setVerticalStretch(0);
        sizePolicy1.setHeightForWidth(altMoveLeftB->sizePolicy().hasHeightForWidth());
        altMoveLeftB->setSizePolicy(sizePolicy1);
        altMoveLeftB->setMinimumSize(QSize(16, 16));
        altMoveLeftB->setMaximumSize(QSize(16, 16));

        altGraphLayoutH->addWidget(altMoveLeftB);

        altGraph = new AVTPlotWidget(SchedulerAltitudeGraph);
        altGraph->setObjectName("altGraph");
        altGraph->setEnabled(true);
        QSizePolicy sizePolicy2(QSizePolicy::Policy::Expanding, QSizePolicy::Policy::Expanding);
        sizePolicy2.setHorizontalStretch(0);
        sizePolicy2.setVerticalStretch(0);
        sizePolicy2.setHeightForWidth(altGraph->sizePolicy().hasHeightForWidth());
        altGraph->setSizePolicy(sizePolicy2);

        altGraphLayoutH->addWidget(altGraph);

        altMoveRightB = new QPushButton(SchedulerAltitudeGraph);
        altMoveRightB->setObjectName("altMoveRightB");
        sizePolicy1.setHeightForWidth(altMoveRightB->sizePolicy().hasHeightForWidth());
        altMoveRightB->setSizePolicy(sizePolicy1);
        altMoveRightB->setMinimumSize(QSize(16, 16));
        altMoveRightB->setMaximumSize(QSize(16, 16));

        altGraphLayoutH->addWidget(altMoveRightB);


        altGraphLayoutV->addLayout(altGraphLayoutH);


        retranslateUi(SchedulerAltitudeGraph);

        QMetaObject::connectSlotsByName(SchedulerAltitudeGraph);
    } // setupUi

    void retranslateUi(QFrame *SchedulerAltitudeGraph)
    {
        altGraphLabel->setText(QString());
        (void)SchedulerAltitudeGraph;
    } // retranslateUi

};

namespace Ui {
    class SchedulerAltitudeGraph: public Ui_SchedulerAltitudeGraph {};
} // namespace Ui

QT_END_NAMESPACE

#endif // SCHEDULERALTITUDEGRAPH_H

