/****************************************************************************
** Meta object code from reading C++ file 'opsastrometryindexfiles.h'
**
** Created by: The Qt Meta Object Compiler version 69 (Qt 6.11.1)
**
** WARNING! All changes made in this file will be lost!
*****************************************************************************/

#include "../../../../kstars-3.8.4.1/kstars/ekos/align/opsastrometryindexfiles.h"
#include <QtCore/qmetatype.h>

#include <QtCore/qtmochelpers.h>

#include <memory>


#include <QtCore/qxptype_traits.h>
#if !defined(Q_MOC_OUTPUT_REVISION)
#error "The header file 'opsastrometryindexfiles.h' doesn't include <QObject>."
#elif Q_MOC_OUTPUT_REVISION != 69
#error "This file was generated using the moc from 6.11.1. It"
#error "cannot be used with the include files from this version of Qt."
#error "(The moc has changed too much.)"
#endif

#ifndef Q_CONSTINIT
#define Q_CONSTINIT
#endif

QT_WARNING_PUSH
QT_WARNING_DISABLE_DEPRECATED
QT_WARNING_DISABLE_GCC("-Wuseless-cast")
namespace {
struct qt_meta_tag_ZN4Ekos23OpsAstrometryIndexFilesE_t {};
} // unnamed namespace

template <> constexpr inline auto Ekos::OpsAstrometryIndexFiles::qt_create_metaobjectdata<qt_meta_tag_ZN4Ekos23OpsAstrometryIndexFilesE_t>()
{
    namespace QMC = QtMocConstants;
    QtMocHelpers::StringRefStorage qt_stringData {
        "Ekos::OpsAstrometryIndexFiles",
        "newDownloadProgress",
        "",
        "info",
        "slotUpdate",
        "slotOpenIndexFileDirectory",
        "downloadOrDeleteIndexFiles",
        "checked",
        "addDirectoryToList",
        "directory",
        "removeDirectoryFromList",
        "updateIndexDirectoryList",
        "setCheckBoxStateProgrammatically",
        "QCheckBox*",
        "checkbox",
        "downloadSingleIndexFile",
        "indexFileName",
        "processIndexFile",
        "indexSeriesName",
        "install",
        "showWarnings",
        "installIndexFile",
        "name",
        "removeIndexFile"
    };

    QtMocHelpers::UintData qt_methods {
        // Signal 'newDownloadProgress'
        QtMocHelpers::SignalData<void(QString)>(1, 2, QMC::AccessPublic, QMetaType::Void, {{
            { QMetaType::QString, 3 },
        }}),
        // Slot 'slotUpdate'
        QtMocHelpers::SlotData<void()>(4, 2, QMC::AccessPublic, QMetaType::Void),
        // Slot 'slotOpenIndexFileDirectory'
        QtMocHelpers::SlotData<void()>(5, 2, QMC::AccessPublic, QMetaType::Void),
        // Slot 'downloadOrDeleteIndexFiles'
        QtMocHelpers::SlotData<void(bool)>(6, 2, QMC::AccessPublic, QMetaType::Void, {{
            { QMetaType::Bool, 7 },
        }}),
        // Slot 'addDirectoryToList'
        QtMocHelpers::SlotData<void(QString)>(8, 2, QMC::AccessPublic, QMetaType::Void, {{
            { QMetaType::QString, 9 },
        }}),
        // Slot 'removeDirectoryFromList'
        QtMocHelpers::SlotData<void(QString)>(10, 2, QMC::AccessPublic, QMetaType::Void, {{
            { QMetaType::QString, 9 },
        }}),
        // Slot 'updateIndexDirectoryList'
        QtMocHelpers::SlotData<void()>(11, 2, QMC::AccessPublic, QMetaType::Void),
        // Slot 'setCheckBoxStateProgrammatically'
        QtMocHelpers::SlotData<void(QCheckBox *, bool)>(12, 2, QMC::AccessPublic, QMetaType::Void, {{
            { 0x80000000 | 13, 14 }, { QMetaType::Bool, 7 },
        }}),
        // Method 'downloadSingleIndexFile'
        QtMocHelpers::MethodData<void(const QString &)>(15, 2, QMC::AccessPublic | QMC::MethodScriptable, QMetaType::Void, {{
            { QMetaType::QString, 16 },
        }}),
        // Method 'processIndexFile'
        QtMocHelpers::MethodData<void(const QString &, bool, bool)>(17, 2, QMC::AccessPublic | QMC::MethodScriptable, QMetaType::Void, {{
            { QMetaType::QString, 18 }, { QMetaType::Bool, 19 }, { QMetaType::Bool, 20 },
        }}),
        // Method 'processIndexFile'
        QtMocHelpers::MethodData<void(const QString &, bool)>(17, 2, QMC::AccessPublic | QMC::MethodCloned | QMC::MethodScriptable, QMetaType::Void, {{
            { QMetaType::QString, 18 }, { QMetaType::Bool, 19 },
        }}),
        // Method 'installIndexFile'
        QtMocHelpers::MethodData<void(const QString &)>(21, 2, QMC::AccessPublic | QMC::MethodScriptable, QMetaType::Void, {{
            { QMetaType::QString, 22 },
        }}),
        // Method 'removeIndexFile'
        QtMocHelpers::MethodData<void(const QString &)>(23, 2, QMC::AccessPublic | QMC::MethodScriptable, QMetaType::Void, {{
            { QMetaType::QString, 22 },
        }}),
    };
    QtMocHelpers::UintData qt_properties {
    };
    QtMocHelpers::UintData qt_enums {
    };
    return QtMocHelpers::metaObjectData<OpsAstrometryIndexFiles, qt_meta_tag_ZN4Ekos23OpsAstrometryIndexFilesE_t>(QMC::MetaObjectFlag{}, qt_stringData,
            qt_methods, qt_properties, qt_enums);
}
Q_CONSTINIT const QMetaObject Ekos::OpsAstrometryIndexFiles::staticMetaObject = { {
    QMetaObject::SuperData::link<QDialog::staticMetaObject>(),
    qt_staticMetaObjectStaticContent<qt_meta_tag_ZN4Ekos23OpsAstrometryIndexFilesE_t>.stringdata,
    qt_staticMetaObjectStaticContent<qt_meta_tag_ZN4Ekos23OpsAstrometryIndexFilesE_t>.data,
    qt_static_metacall,
    nullptr,
    qt_staticMetaObjectRelocatingContent<qt_meta_tag_ZN4Ekos23OpsAstrometryIndexFilesE_t>.metaTypes,
    nullptr
} };

void Ekos::OpsAstrometryIndexFiles::qt_static_metacall(QObject *_o, QMetaObject::Call _c, int _id, void **_a)
{
    auto *_t = static_cast<OpsAstrometryIndexFiles *>(_o);
    if (_c == QMetaObject::InvokeMetaMethod) {
        switch (_id) {
        case 0: _t->newDownloadProgress((*reinterpret_cast<std::add_pointer_t<QString>>(_a[1]))); break;
        case 1: _t->slotUpdate(); break;
        case 2: _t->slotOpenIndexFileDirectory(); break;
        case 3: _t->downloadOrDeleteIndexFiles((*reinterpret_cast<std::add_pointer_t<bool>>(_a[1]))); break;
        case 4: _t->addDirectoryToList((*reinterpret_cast<std::add_pointer_t<QString>>(_a[1]))); break;
        case 5: _t->removeDirectoryFromList((*reinterpret_cast<std::add_pointer_t<QString>>(_a[1]))); break;
        case 6: _t->updateIndexDirectoryList(); break;
        case 7: _t->setCheckBoxStateProgrammatically((*reinterpret_cast<std::add_pointer_t<QCheckBox*>>(_a[1])),(*reinterpret_cast<std::add_pointer_t<bool>>(_a[2]))); break;
        case 8: _t->downloadSingleIndexFile((*reinterpret_cast<std::add_pointer_t<QString>>(_a[1]))); break;
        case 9: _t->processIndexFile((*reinterpret_cast<std::add_pointer_t<QString>>(_a[1])),(*reinterpret_cast<std::add_pointer_t<bool>>(_a[2])),(*reinterpret_cast<std::add_pointer_t<bool>>(_a[3]))); break;
        case 10: _t->processIndexFile((*reinterpret_cast<std::add_pointer_t<QString>>(_a[1])),(*reinterpret_cast<std::add_pointer_t<bool>>(_a[2]))); break;
        case 11: _t->installIndexFile((*reinterpret_cast<std::add_pointer_t<QString>>(_a[1]))); break;
        case 12: _t->removeIndexFile((*reinterpret_cast<std::add_pointer_t<QString>>(_a[1]))); break;
        default: ;
        }
    }
    if (_c == QMetaObject::IndexOfMethod) {
        if (QtMocHelpers::indexOfMethod<void (OpsAstrometryIndexFiles::*)(QString )>(_a, &OpsAstrometryIndexFiles::newDownloadProgress, 0))
            return;
    }
}

const QMetaObject *Ekos::OpsAstrometryIndexFiles::metaObject() const
{
    return QObject::d_ptr->metaObject ? QObject::d_ptr->dynamicMetaObject() : &staticMetaObject;
}

void *Ekos::OpsAstrometryIndexFiles::qt_metacast(const char *_clname)
{
    if (!_clname) return nullptr;
    if (!strcmp(_clname, qt_staticMetaObjectStaticContent<qt_meta_tag_ZN4Ekos23OpsAstrometryIndexFilesE_t>.strings))
        return static_cast<void*>(this);
    if (!strcmp(_clname, "Ui::OpsAstrometryIndexFiles"))
        return static_cast< Ui::OpsAstrometryIndexFiles*>(this);
    return QDialog::qt_metacast(_clname);
}

int Ekos::OpsAstrometryIndexFiles::qt_metacall(QMetaObject::Call _c, int _id, void **_a)
{
    _id = QDialog::qt_metacall(_c, _id, _a);
    if (_id < 0)
        return _id;
    if (_c == QMetaObject::InvokeMetaMethod) {
        if (_id < 13)
            qt_static_metacall(this, _c, _id, _a);
        _id -= 13;
    }
    if (_c == QMetaObject::RegisterMethodArgumentMetaType) {
        if (_id < 13)
            *reinterpret_cast<QMetaType *>(_a[0]) = QMetaType();
        _id -= 13;
    }
    return _id;
}

// SIGNAL 0
void Ekos::OpsAstrometryIndexFiles::newDownloadProgress(QString _t1)
{
    QMetaObject::activate<void>(this, &staticMetaObject, 0, nullptr, _t1);
}
QT_WARNING_POP
