/****************************************************************************
** Meta object code from reading C++ file 'scheduler.h'
**
** Created by: The Qt Meta Object Compiler version 69 (Qt 6.11.1)
**
** WARNING! All changes made in this file will be lost!
*****************************************************************************/

#include "../../../../kstars-3.8.4.1/kstars/ekos/scheduler/scheduler.h"
#include <QtNetwork/QSslError>
#include <QtDataVisualization/qbar3dseries.h>
#include <QtDataVisualization/q3dscene.h>
#include <QtGui/qtextcursor.h>
#include <QtCore/qmetatype.h>
#include <QtCore/QList>

#include <QtCore/qtmochelpers.h>

#include <memory>


#include <QtCore/qxptype_traits.h>
#if !defined(Q_MOC_OUTPUT_REVISION)
#error "The header file 'scheduler.h' doesn't include <QObject>."
#elif Q_MOC_OUTPUT_REVISION != 69
#error "This file was generated using the moc from 6.11.1. It"
#error "cannot be used with the include files from this version of Qt."
#error "(The moc has changed too much.)"
#endif

#ifndef Q_CONSTINIT
#define Q_CONSTINIT
#endif

QT_WARNING_PUSH
QT_WARNING_DISABLE_DEPRECATED
QT_WARNING_DISABLE_GCC("-Wuseless-cast")
namespace {
struct qt_meta_tag_ZN4Ekos9SchedulerE_t {};
} // unnamed namespace

template <> constexpr inline auto Ekos::Scheduler::qt_create_metaobjectdata<qt_meta_tag_ZN4Ekos9SchedulerE_t>()
{
    namespace QMC = QtMocConstants;
    QtMocHelpers::StringRefStorage qt_stringData {
        "Ekos::Scheduler",
        "newStatus",
        "",
        "Ekos::SchedulerState",
        "state",
        "weatherChanged",
        "ISD::Weather::Status",
        "newTarget",
        "targetDistance",
        "distance",
        "jobStarted",
        "jobName",
        "jobEnded",
        "endReason",
        "jobsUpdated",
        "QJsonArray",
        "jobsList",
        "settingsUpdated",
        "QVariantMap",
        "settings",
        "interfaceReady",
        "QDBusInterface*",
        "iface",
        "setWeatherStatus",
        "status",
        "selectObject",
        "selectFITS",
        "selectSequence",
        "selectPreStartupQueue",
        "selectPostStartupQueue",
        "selectPreShutdownQueue",
        "selectPostShutdownQueue",
        "clearPreStartupQueue",
        "clearPostStartupQueue",
        "clearPreShutdownQueue",
        "clearPostShutdownQueue",
        "loadJob",
        "QModelIndex",
        "i",
        "modifyJob",
        "index",
        "updateSchedulerURL",
        "fileURL",
        "setJobAddApply",
        "add_mode",
        "setJobManipulation",
        "can_reorder",
        "can_delete",
        "is_lead",
        "syncGUIToJob",
        "SchedulerJob*",
        "job",
        "syncGUIToGeneralSettings",
        "clickQueueTable",
        "clearJobTable",
        "clearLog",
        "queueTableSelectionChanged",
        "QItemSelection",
        "selected",
        "deselected",
        "reorderJobs",
        "QList<SchedulerJob*>",
        "reordered_sublist",
        "moveJobUp",
        "moveJobDown",
        "handleSchedulerSleeping",
        "shutdown",
        "sleep",
        "handleSchedulerStateChanged",
        "SchedulerState",
        "newState",
        "handleSetPaused",
        "pause",
        "save",
        "saveAs",
        "load",
        "clearQueue",
        "filename",
        "resetJobEdit",
        "updateNightTime",
        "const SchedulerJob*",
        "schedulerStopped",
        "resumeCheckStatus",
        "checkTwilightWarning",
        "enabled",
        "sortJobsPerAltitude",
        "addJob",
        "updateJob",
        "setFramingAssistantEnabled"
    };

    QtMocHelpers::UintData qt_methods {
        // Signal 'newStatus'
        QtMocHelpers::SignalData<void(Ekos::SchedulerState)>(1, 2, QMC::AccessPublic, QMetaType::Void, {{
            { 0x80000000 | 3, 4 },
        }}),
        // Signal 'weatherChanged'
        QtMocHelpers::SignalData<void(ISD::Weather::Status)>(5, 2, QMC::AccessPublic, QMetaType::Void, {{
            { 0x80000000 | 6, 4 },
        }}),
        // Signal 'newTarget'
        QtMocHelpers::SignalData<void(const QString &)>(7, 2, QMC::AccessPublic, QMetaType::Void, {{
            { QMetaType::QString, 2 },
        }}),
        // Signal 'targetDistance'
        QtMocHelpers::SignalData<void(double)>(8, 2, QMC::AccessPublic, QMetaType::Void, {{
            { QMetaType::Double, 9 },
        }}),
        // Signal 'jobStarted'
        QtMocHelpers::SignalData<void(const QString &)>(10, 2, QMC::AccessPublic, QMetaType::Void, {{
            { QMetaType::QString, 11 },
        }}),
        // Signal 'jobEnded'
        QtMocHelpers::SignalData<void(const QString &, const QString &)>(12, 2, QMC::AccessPublic, QMetaType::Void, {{
            { QMetaType::QString, 11 }, { QMetaType::QString, 13 },
        }}),
        // Signal 'jobsUpdated'
        QtMocHelpers::SignalData<void(QJsonArray)>(14, 2, QMC::AccessPublic, QMetaType::Void, {{
            { 0x80000000 | 15, 16 },
        }}),
        // Signal 'settingsUpdated'
        QtMocHelpers::SignalData<void(const QVariantMap &)>(17, 2, QMC::AccessPublic, QMetaType::Void, {{
            { 0x80000000 | 18, 19 },
        }}),
        // Slot 'interfaceReady'
        QtMocHelpers::SlotData<void(QDBusInterface *)>(20, 2, QMC::AccessProtected, QMetaType::Void, {{
            { 0x80000000 | 21, 22 },
        }}),
        // Slot 'setWeatherStatus'
        QtMocHelpers::SlotData<void(ISD::Weather::Status)>(23, 2, QMC::AccessProtected, QMetaType::Void, {{
            { 0x80000000 | 6, 24 },
        }}),
        // Slot 'selectObject'
        QtMocHelpers::SlotData<void()>(25, 2, QMC::AccessProtected, QMetaType::Void),
        // Slot 'selectFITS'
        QtMocHelpers::SlotData<void()>(26, 2, QMC::AccessProtected, QMetaType::Void),
        // Slot 'selectSequence'
        QtMocHelpers::SlotData<void()>(27, 2, QMC::AccessProtected, QMetaType::Void),
        // Slot 'selectPreStartupQueue'
        QtMocHelpers::SlotData<void()>(28, 2, QMC::AccessProtected, QMetaType::Void),
        // Slot 'selectPostStartupQueue'
        QtMocHelpers::SlotData<void()>(29, 2, QMC::AccessProtected, QMetaType::Void),
        // Slot 'selectPreShutdownQueue'
        QtMocHelpers::SlotData<void()>(30, 2, QMC::AccessProtected, QMetaType::Void),
        // Slot 'selectPostShutdownQueue'
        QtMocHelpers::SlotData<void()>(31, 2, QMC::AccessProtected, QMetaType::Void),
        // Slot 'clearPreStartupQueue'
        QtMocHelpers::SlotData<void()>(32, 2, QMC::AccessProtected, QMetaType::Void),
        // Slot 'clearPostStartupQueue'
        QtMocHelpers::SlotData<void()>(33, 2, QMC::AccessProtected, QMetaType::Void),
        // Slot 'clearPreShutdownQueue'
        QtMocHelpers::SlotData<void()>(34, 2, QMC::AccessProtected, QMetaType::Void),
        // Slot 'clearPostShutdownQueue'
        QtMocHelpers::SlotData<void()>(35, 2, QMC::AccessProtected, QMetaType::Void),
        // Slot 'loadJob'
        QtMocHelpers::SlotData<void(QModelIndex)>(36, 2, QMC::AccessProtected, QMetaType::Void, {{
            { 0x80000000 | 37, 38 },
        }}),
        // Slot 'modifyJob'
        QtMocHelpers::SlotData<bool(int)>(39, 2, QMC::AccessProtected, QMetaType::Bool, {{
            { QMetaType::Int, 40 },
        }}),
        // Slot 'modifyJob'
        QtMocHelpers::SlotData<bool()>(39, 2, QMC::AccessProtected | QMC::MethodCloned, QMetaType::Bool),
        // Slot 'updateSchedulerURL'
        QtMocHelpers::SlotData<void(const QString &)>(41, 2, QMC::AccessProtected, QMetaType::Void, {{
            { QMetaType::QString, 42 },
        }}),
        // Slot 'setJobAddApply'
        QtMocHelpers::SlotData<void(bool)>(43, 2, QMC::AccessProtected, QMetaType::Void, {{
            { QMetaType::Bool, 44 },
        }}),
        // Slot 'setJobManipulation'
        QtMocHelpers::SlotData<void(bool, bool, bool)>(45, 2, QMC::AccessProtected, QMetaType::Void, {{
            { QMetaType::Bool, 46 }, { QMetaType::Bool, 47 }, { QMetaType::Bool, 48 },
        }}),
        // Slot 'syncGUIToJob'
        QtMocHelpers::SlotData<void(SchedulerJob *)>(49, 2, QMC::AccessProtected, QMetaType::Void, {{
            { 0x80000000 | 50, 51 },
        }}),
        // Slot 'syncGUIToGeneralSettings'
        QtMocHelpers::SlotData<void()>(52, 2, QMC::AccessProtected, QMetaType::Void),
        // Slot 'clickQueueTable'
        QtMocHelpers::SlotData<void(QModelIndex)>(53, 2, QMC::AccessProtected, QMetaType::Void, {{
            { 0x80000000 | 37, 40 },
        }}),
        // Slot 'clearJobTable'
        QtMocHelpers::SlotData<void()>(54, 2, QMC::AccessProtected, QMetaType::Void),
        // Slot 'clearLog'
        QtMocHelpers::SlotData<void()>(55, 2, QMC::AccessProtected, QMetaType::Void),
        // Slot 'queueTableSelectionChanged'
        QtMocHelpers::SlotData<void(const QItemSelection &, const QItemSelection &)>(56, 2, QMC::AccessProtected, QMetaType::Void, {{
            { 0x80000000 | 57, 58 }, { 0x80000000 | 57, 59 },
        }}),
        // Slot 'reorderJobs'
        QtMocHelpers::SlotData<bool(QList<SchedulerJob*>)>(60, 2, QMC::AccessProtected, QMetaType::Bool, {{
            { 0x80000000 | 61, 62 },
        }}),
        // Slot 'moveJobUp'
        QtMocHelpers::SlotData<void()>(63, 2, QMC::AccessProtected, QMetaType::Void),
        // Slot 'moveJobDown'
        QtMocHelpers::SlotData<void()>(64, 2, QMC::AccessProtected, QMetaType::Void),
        // Slot 'handleSchedulerSleeping'
        QtMocHelpers::SlotData<void(bool, bool)>(65, 2, QMC::AccessProtected, QMetaType::Void, {{
            { QMetaType::Bool, 66 }, { QMetaType::Bool, 67 },
        }}),
        // Slot 'handleSchedulerStateChanged'
        QtMocHelpers::SlotData<void(SchedulerState)>(68, 2, QMC::AccessProtected, QMetaType::Void, {{
            { 0x80000000 | 69, 70 },
        }}),
        // Slot 'handleSetPaused'
        QtMocHelpers::SlotData<void()>(71, 2, QMC::AccessProtected, QMetaType::Void),
        // Slot 'pause'
        QtMocHelpers::SlotData<void()>(72, 2, QMC::AccessProtected, QMetaType::Void),
        // Slot 'save'
        QtMocHelpers::SlotData<bool()>(73, 2, QMC::AccessProtected, QMetaType::Bool),
        // Slot 'saveAs'
        QtMocHelpers::SlotData<void()>(74, 2, QMC::AccessProtected, QMetaType::Void),
        // Slot 'load'
        QtMocHelpers::SlotData<bool(bool, const QString &)>(75, 2, QMC::AccessProtected, QMetaType::Bool, {{
            { QMetaType::Bool, 76 }, { QMetaType::QString, 77 },
        }}),
        // Slot 'load'
        QtMocHelpers::SlotData<bool(bool)>(75, 2, QMC::AccessProtected | QMC::MethodCloned, QMetaType::Bool, {{
            { QMetaType::Bool, 76 },
        }}),
        // Slot 'resetJobEdit'
        QtMocHelpers::SlotData<void()>(78, 2, QMC::AccessProtected, QMetaType::Void),
        // Slot 'updateNightTime'
        QtMocHelpers::SlotData<void(SchedulerJob const *)>(79, 2, QMC::AccessProtected, QMetaType::Void, {{
            { 0x80000000 | 80, 51 },
        }}),
        // Slot 'updateNightTime'
        QtMocHelpers::SlotData<void()>(79, 2, QMC::AccessProtected | QMC::MethodCloned, QMetaType::Void),
        // Slot 'schedulerStopped'
        QtMocHelpers::SlotData<void()>(81, 2, QMC::AccessProtected, QMetaType::Void),
        // Slot 'resumeCheckStatus'
        QtMocHelpers::SlotData<void()>(82, 2, QMC::AccessProtected, QMetaType::Void),
        // Slot 'checkTwilightWarning'
        QtMocHelpers::SlotData<void(bool)>(83, 2, QMC::AccessProtected, QMetaType::Void, {{
            { QMetaType::Bool, 84 },
        }}),
        // Method 'sortJobsPerAltitude'
        QtMocHelpers::MethodData<void()>(85, 2, QMC::AccessPublic | QMC::MethodScriptable, QMetaType::Void),
        // Method 'addJob'
        QtMocHelpers::MethodData<void(SchedulerJob *)>(86, 2, QMC::AccessPublic, QMetaType::Void, {{
            { 0x80000000 | 50, 51 },
        }}),
        // Method 'addJob'
        QtMocHelpers::MethodData<void()>(86, 2, QMC::AccessPublic | QMC::MethodCloned, QMetaType::Void),
        // Method 'updateJob'
        QtMocHelpers::MethodData<void(int)>(87, 2, QMC::AccessPublic, QMetaType::Void, {{
            { QMetaType::Int, 40 },
        }}),
        // Method 'updateJob'
        QtMocHelpers::MethodData<void()>(87, 2, QMC::AccessPublic | QMC::MethodCloned, QMetaType::Void),
        // Method 'setFramingAssistantEnabled'
        QtMocHelpers::MethodData<void(bool)>(88, 2, QMC::AccessPublic, QMetaType::Void, {{
            { QMetaType::Bool, 84 },
        }}),
    };
    QtMocHelpers::UintData qt_properties {
    };
    QtMocHelpers::UintData qt_enums {
    };
    return QtMocHelpers::metaObjectData<Scheduler, qt_meta_tag_ZN4Ekos9SchedulerE_t>(QMC::MetaObjectFlag{}, qt_stringData,
            qt_methods, qt_properties, qt_enums);
}
Q_CONSTINIT const QMetaObject Ekos::Scheduler::staticMetaObject = { {
    QMetaObject::SuperData::link<QWidget::staticMetaObject>(),
    qt_staticMetaObjectStaticContent<qt_meta_tag_ZN4Ekos9SchedulerE_t>.stringdata,
    qt_staticMetaObjectStaticContent<qt_meta_tag_ZN4Ekos9SchedulerE_t>.data,
    qt_static_metacall,
    nullptr,
    qt_staticMetaObjectRelocatingContent<qt_meta_tag_ZN4Ekos9SchedulerE_t>.metaTypes,
    nullptr
} };

void Ekos::Scheduler::qt_static_metacall(QObject *_o, QMetaObject::Call _c, int _id, void **_a)
{
    auto *_t = static_cast<Scheduler *>(_o);
    if (_c == QMetaObject::InvokeMetaMethod) {
        switch (_id) {
        case 0: _t->newStatus((*reinterpret_cast<std::add_pointer_t<Ekos::SchedulerState>>(_a[1]))); break;
        case 1: _t->weatherChanged((*reinterpret_cast<std::add_pointer_t<ISD::Weather::Status>>(_a[1]))); break;
        case 2: _t->newTarget((*reinterpret_cast<std::add_pointer_t<QString>>(_a[1]))); break;
        case 3: _t->targetDistance((*reinterpret_cast<std::add_pointer_t<double>>(_a[1]))); break;
        case 4: _t->jobStarted((*reinterpret_cast<std::add_pointer_t<QString>>(_a[1]))); break;
        case 5: _t->jobEnded((*reinterpret_cast<std::add_pointer_t<QString>>(_a[1])),(*reinterpret_cast<std::add_pointer_t<QString>>(_a[2]))); break;
        case 6: _t->jobsUpdated((*reinterpret_cast<std::add_pointer_t<QJsonArray>>(_a[1]))); break;
        case 7: _t->settingsUpdated((*reinterpret_cast<std::add_pointer_t<QVariantMap>>(_a[1]))); break;
        case 8: _t->interfaceReady((*reinterpret_cast<std::add_pointer_t<QDBusInterface*>>(_a[1]))); break;
        case 9: _t->setWeatherStatus((*reinterpret_cast<std::add_pointer_t<ISD::Weather::Status>>(_a[1]))); break;
        case 10: _t->selectObject(); break;
        case 11: _t->selectFITS(); break;
        case 12: _t->selectSequence(); break;
        case 13: _t->selectPreStartupQueue(); break;
        case 14: _t->selectPostStartupQueue(); break;
        case 15: _t->selectPreShutdownQueue(); break;
        case 16: _t->selectPostShutdownQueue(); break;
        case 17: _t->clearPreStartupQueue(); break;
        case 18: _t->clearPostStartupQueue(); break;
        case 19: _t->clearPreShutdownQueue(); break;
        case 20: _t->clearPostShutdownQueue(); break;
        case 21: _t->loadJob((*reinterpret_cast<std::add_pointer_t<QModelIndex>>(_a[1]))); break;
        case 22: { bool _r = _t->modifyJob((*reinterpret_cast<std::add_pointer_t<int>>(_a[1])));
            if (_a[0]) *reinterpret_cast<bool*>(_a[0]) = std::move(_r); }  break;
        case 23: { bool _r = _t->modifyJob();
            if (_a[0]) *reinterpret_cast<bool*>(_a[0]) = std::move(_r); }  break;
        case 24: _t->updateSchedulerURL((*reinterpret_cast<std::add_pointer_t<QString>>(_a[1]))); break;
        case 25: _t->setJobAddApply((*reinterpret_cast<std::add_pointer_t<bool>>(_a[1]))); break;
        case 26: _t->setJobManipulation((*reinterpret_cast<std::add_pointer_t<bool>>(_a[1])),(*reinterpret_cast<std::add_pointer_t<bool>>(_a[2])),(*reinterpret_cast<std::add_pointer_t<bool>>(_a[3]))); break;
        case 27: _t->syncGUIToJob((*reinterpret_cast<std::add_pointer_t<SchedulerJob*>>(_a[1]))); break;
        case 28: _t->syncGUIToGeneralSettings(); break;
        case 29: _t->clickQueueTable((*reinterpret_cast<std::add_pointer_t<QModelIndex>>(_a[1]))); break;
        case 30: _t->clearJobTable(); break;
        case 31: _t->clearLog(); break;
        case 32: _t->queueTableSelectionChanged((*reinterpret_cast<std::add_pointer_t<QItemSelection>>(_a[1])),(*reinterpret_cast<std::add_pointer_t<QItemSelection>>(_a[2]))); break;
        case 33: { bool _r = _t->reorderJobs((*reinterpret_cast<std::add_pointer_t<QList<SchedulerJob*>>>(_a[1])));
            if (_a[0]) *reinterpret_cast<bool*>(_a[0]) = std::move(_r); }  break;
        case 34: _t->moveJobUp(); break;
        case 35: _t->moveJobDown(); break;
        case 36: _t->handleSchedulerSleeping((*reinterpret_cast<std::add_pointer_t<bool>>(_a[1])),(*reinterpret_cast<std::add_pointer_t<bool>>(_a[2]))); break;
        case 37: _t->handleSchedulerStateChanged((*reinterpret_cast<std::add_pointer_t<SchedulerState>>(_a[1]))); break;
        case 38: _t->handleSetPaused(); break;
        case 39: _t->pause(); break;
        case 40: { bool _r = _t->save();
            if (_a[0]) *reinterpret_cast<bool*>(_a[0]) = std::move(_r); }  break;
        case 41: _t->saveAs(); break;
        case 42: { bool _r = _t->load((*reinterpret_cast<std::add_pointer_t<bool>>(_a[1])),(*reinterpret_cast<std::add_pointer_t<QString>>(_a[2])));
            if (_a[0]) *reinterpret_cast<bool*>(_a[0]) = std::move(_r); }  break;
        case 43: { bool _r = _t->load((*reinterpret_cast<std::add_pointer_t<bool>>(_a[1])));
            if (_a[0]) *reinterpret_cast<bool*>(_a[0]) = std::move(_r); }  break;
        case 44: _t->resetJobEdit(); break;
        case 45: _t->updateNightTime((*reinterpret_cast<std::add_pointer_t<const SchedulerJob*>>(_a[1]))); break;
        case 46: _t->updateNightTime(); break;
        case 47: _t->schedulerStopped(); break;
        case 48: _t->resumeCheckStatus(); break;
        case 49: _t->checkTwilightWarning((*reinterpret_cast<std::add_pointer_t<bool>>(_a[1]))); break;
        case 50: _t->sortJobsPerAltitude(); break;
        case 51: _t->addJob((*reinterpret_cast<std::add_pointer_t<SchedulerJob*>>(_a[1]))); break;
        case 52: _t->addJob(); break;
        case 53: _t->updateJob((*reinterpret_cast<std::add_pointer_t<int>>(_a[1]))); break;
        case 54: _t->updateJob(); break;
        case 55: _t->setFramingAssistantEnabled((*reinterpret_cast<std::add_pointer_t<bool>>(_a[1]))); break;
        default: ;
        }
    }
    if (_c == QMetaObject::RegisterMethodArgumentMetaType) {
        switch (_id) {
        default: *reinterpret_cast<QMetaType *>(_a[0]) = QMetaType(); break;
        case 0:
            switch (*reinterpret_cast<int*>(_a[1])) {
            default: *reinterpret_cast<QMetaType *>(_a[0]) = QMetaType(); break;
            case 0:
                *reinterpret_cast<QMetaType *>(_a[0]) = QMetaType::fromType< Ekos::SchedulerState >(); break;
            }
            break;
        case 1:
            switch (*reinterpret_cast<int*>(_a[1])) {
            default: *reinterpret_cast<QMetaType *>(_a[0]) = QMetaType(); break;
            case 0:
                *reinterpret_cast<QMetaType *>(_a[0]) = QMetaType::fromType< ISD::Weather::Status >(); break;
            }
            break;
        case 9:
            switch (*reinterpret_cast<int*>(_a[1])) {
            default: *reinterpret_cast<QMetaType *>(_a[0]) = QMetaType(); break;
            case 0:
                *reinterpret_cast<QMetaType *>(_a[0]) = QMetaType::fromType< ISD::Weather::Status >(); break;
            }
            break;
        case 32:
            switch (*reinterpret_cast<int*>(_a[1])) {
            default: *reinterpret_cast<QMetaType *>(_a[0]) = QMetaType(); break;
            case 1:
            case 0:
                *reinterpret_cast<QMetaType *>(_a[0]) = QMetaType::fromType< QItemSelection >(); break;
            }
            break;
        }
    }
    if (_c == QMetaObject::IndexOfMethod) {
        if (QtMocHelpers::indexOfMethod<void (Scheduler::*)(Ekos::SchedulerState )>(_a, &Scheduler::newStatus, 0))
            return;
        if (QtMocHelpers::indexOfMethod<void (Scheduler::*)(ISD::Weather::Status )>(_a, &Scheduler::weatherChanged, 1))
            return;
        if (QtMocHelpers::indexOfMethod<void (Scheduler::*)(const QString & )>(_a, &Scheduler::newTarget, 2))
            return;
        if (QtMocHelpers::indexOfMethod<void (Scheduler::*)(double )>(_a, &Scheduler::targetDistance, 3))
            return;
        if (QtMocHelpers::indexOfMethod<void (Scheduler::*)(const QString & )>(_a, &Scheduler::jobStarted, 4))
            return;
        if (QtMocHelpers::indexOfMethod<void (Scheduler::*)(const QString & , const QString & )>(_a, &Scheduler::jobEnded, 5))
            return;
        if (QtMocHelpers::indexOfMethod<void (Scheduler::*)(QJsonArray )>(_a, &Scheduler::jobsUpdated, 6))
            return;
        if (QtMocHelpers::indexOfMethod<void (Scheduler::*)(const QVariantMap & )>(_a, &Scheduler::settingsUpdated, 7))
            return;
    }
}

const QMetaObject *Ekos::Scheduler::metaObject() const
{
    return QObject::d_ptr->metaObject ? QObject::d_ptr->dynamicMetaObject() : &staticMetaObject;
}

void *Ekos::Scheduler::qt_metacast(const char *_clname)
{
    if (!_clname) return nullptr;
    if (!strcmp(_clname, qt_staticMetaObjectStaticContent<qt_meta_tag_ZN4Ekos9SchedulerE_t>.strings))
        return static_cast<void*>(this);
    if (!strcmp(_clname, "Ui::Scheduler"))
        return static_cast< Ui::Scheduler*>(this);
    return QWidget::qt_metacast(_clname);
}

int Ekos::Scheduler::qt_metacall(QMetaObject::Call _c, int _id, void **_a)
{
    _id = QWidget::qt_metacall(_c, _id, _a);
    if (_id < 0)
        return _id;
    if (_c == QMetaObject::InvokeMetaMethod) {
        if (_id < 56)
            qt_static_metacall(this, _c, _id, _a);
        _id -= 56;
    }
    if (_c == QMetaObject::RegisterMethodArgumentMetaType) {
        if (_id < 56)
            qt_static_metacall(this, _c, _id, _a);
        _id -= 56;
    }
    return _id;
}

// SIGNAL 0
void Ekos::Scheduler::newStatus(Ekos::SchedulerState _t1)
{
    QMetaObject::activate<void>(this, &staticMetaObject, 0, nullptr, _t1);
}

// SIGNAL 1
void Ekos::Scheduler::weatherChanged(ISD::Weather::Status _t1)
{
    QMetaObject::activate<void>(this, &staticMetaObject, 1, nullptr, _t1);
}

// SIGNAL 2
void Ekos::Scheduler::newTarget(const QString & _t1)
{
    QMetaObject::activate<void>(this, &staticMetaObject, 2, nullptr, _t1);
}

// SIGNAL 3
void Ekos::Scheduler::targetDistance(double _t1)
{
    QMetaObject::activate<void>(this, &staticMetaObject, 3, nullptr, _t1);
}

// SIGNAL 4
void Ekos::Scheduler::jobStarted(const QString & _t1)
{
    QMetaObject::activate<void>(this, &staticMetaObject, 4, nullptr, _t1);
}

// SIGNAL 5
void Ekos::Scheduler::jobEnded(const QString & _t1, const QString & _t2)
{
    QMetaObject::activate<void>(this, &staticMetaObject, 5, nullptr, _t1, _t2);
}

// SIGNAL 6
void Ekos::Scheduler::jobsUpdated(QJsonArray _t1)
{
    QMetaObject::activate<void>(this, &staticMetaObject, 6, nullptr, _t1);
}

// SIGNAL 7
void Ekos::Scheduler::settingsUpdated(const QVariantMap & _t1)
{
    QMetaObject::activate<void>(this, &staticMetaObject, 7, nullptr, _t1);
}
QT_WARNING_POP
