/****************************************************************************
** Meta object code from reading C++ file 'indiconcretedevice.h'
**
** Created by: The Qt Meta Object Compiler version 69 (Qt 6.11.1)
**
** WARNING! All changes made in this file will be lost!
*****************************************************************************/

#include "../../../../kstars-3.8.4.1/kstars/indi/indiconcretedevice.h"
#include <QtCore/qmetatype.h>

#include <QtCore/qtmochelpers.h>

#include <memory>


#include <QtCore/qxptype_traits.h>
#if !defined(Q_MOC_OUTPUT_REVISION)
#error "The header file 'indiconcretedevice.h' doesn't include <QObject>."
#elif Q_MOC_OUTPUT_REVISION != 69
#error "This file was generated using the moc from 6.11.1. It"
#error "cannot be used with the include files from this version of Qt."
#error "(The moc has changed too much.)"
#endif

#ifndef Q_CONSTINIT
#define Q_CONSTINIT
#endif

QT_WARNING_PUSH
QT_WARNING_DISABLE_DEPRECATED
QT_WARNING_DISABLE_GCC("-Wuseless-cast")
namespace {
struct qt_meta_tag_ZN3ISD14ConcreteDeviceE_t {};
} // unnamed namespace

template <> constexpr inline auto ISD::ConcreteDevice::qt_create_metaobjectdata<qt_meta_tag_ZN3ISD14ConcreteDeviceE_t>()
{
    namespace QMC = QtMocConstants;
    QtMocHelpers::StringRefStorage qt_stringData {
        "ISD::ConcreteDevice",
        "Connected",
        "",
        "Disconnected",
        "propertyDefined",
        "INDI::Property",
        "prop",
        "propertyUpdated",
        "propertyDeleted",
        "ready",
        "name",
        "connected"
    };

    QtMocHelpers::UintData qt_methods {
        // Signal 'Connected'
        QtMocHelpers::SignalData<void()>(1, 2, QMC::AccessPublic, QMetaType::Void),
        // Signal 'Disconnected'
        QtMocHelpers::SignalData<void()>(3, 2, QMC::AccessPublic, QMetaType::Void),
        // Signal 'propertyDefined'
        QtMocHelpers::SignalData<void(INDI::Property)>(4, 2, QMC::AccessPublic, QMetaType::Void, {{
            { 0x80000000 | 5, 6 },
        }}),
        // Signal 'propertyUpdated'
        QtMocHelpers::SignalData<void(INDI::Property)>(7, 2, QMC::AccessPublic, QMetaType::Void, {{
            { 0x80000000 | 5, 6 },
        }}),
        // Signal 'propertyDeleted'
        QtMocHelpers::SignalData<void(INDI::Property)>(8, 2, QMC::AccessPublic, QMetaType::Void, {{
            { 0x80000000 | 5, 6 },
        }}),
        // Signal 'ready'
        QtMocHelpers::SignalData<void()>(9, 2, QMC::AccessPublic, QMetaType::Void),
    };
    QtMocHelpers::UintData qt_properties {
        // property 'name'
        QtMocHelpers::PropertyData<QString>(10, QMetaType::QString, QMC::DefaultPropertyFlags),
        // property 'connected'
        QtMocHelpers::PropertyData<bool>(11, QMetaType::Bool, QMC::DefaultPropertyFlags),
    };
    QtMocHelpers::UintData qt_enums {
    };
    return QtMocHelpers::metaObjectData<ConcreteDevice, qt_meta_tag_ZN3ISD14ConcreteDeviceE_t>(QMC::MetaObjectFlag{}, qt_stringData,
            qt_methods, qt_properties, qt_enums);
}
Q_CONSTINIT const QMetaObject ISD::ConcreteDevice::staticMetaObject = { {
    QMetaObject::SuperData::link<GDInterface::staticMetaObject>(),
    qt_staticMetaObjectStaticContent<qt_meta_tag_ZN3ISD14ConcreteDeviceE_t>.stringdata,
    qt_staticMetaObjectStaticContent<qt_meta_tag_ZN3ISD14ConcreteDeviceE_t>.data,
    qt_static_metacall,
    nullptr,
    qt_staticMetaObjectRelocatingContent<qt_meta_tag_ZN3ISD14ConcreteDeviceE_t>.metaTypes,
    nullptr
} };

void ISD::ConcreteDevice::qt_static_metacall(QObject *_o, QMetaObject::Call _c, int _id, void **_a)
{
    auto *_t = static_cast<ConcreteDevice *>(_o);
    if (_c == QMetaObject::InvokeMetaMethod) {
        switch (_id) {
        case 0: _t->Connected(); break;
        case 1: _t->Disconnected(); break;
        case 2: _t->propertyDefined((*reinterpret_cast<std::add_pointer_t<INDI::Property>>(_a[1]))); break;
        case 3: _t->propertyUpdated((*reinterpret_cast<std::add_pointer_t<INDI::Property>>(_a[1]))); break;
        case 4: _t->propertyDeleted((*reinterpret_cast<std::add_pointer_t<INDI::Property>>(_a[1]))); break;
        case 5: _t->ready(); break;
        default: ;
        }
    }
    if (_c == QMetaObject::RegisterMethodArgumentMetaType) {
        switch (_id) {
        default: *reinterpret_cast<QMetaType *>(_a[0]) = QMetaType(); break;
        case 2:
            switch (*reinterpret_cast<int*>(_a[1])) {
            default: *reinterpret_cast<QMetaType *>(_a[0]) = QMetaType(); break;
            case 0:
                *reinterpret_cast<QMetaType *>(_a[0]) = QMetaType::fromType< INDI::Property >(); break;
            }
            break;
        case 3:
            switch (*reinterpret_cast<int*>(_a[1])) {
            default: *reinterpret_cast<QMetaType *>(_a[0]) = QMetaType(); break;
            case 0:
                *reinterpret_cast<QMetaType *>(_a[0]) = QMetaType::fromType< INDI::Property >(); break;
            }
            break;
        case 4:
            switch (*reinterpret_cast<int*>(_a[1])) {
            default: *reinterpret_cast<QMetaType *>(_a[0]) = QMetaType(); break;
            case 0:
                *reinterpret_cast<QMetaType *>(_a[0]) = QMetaType::fromType< INDI::Property >(); break;
            }
            break;
        }
    }
    if (_c == QMetaObject::IndexOfMethod) {
        if (QtMocHelpers::indexOfMethod<void (ConcreteDevice::*)()>(_a, &ConcreteDevice::Connected, 0))
            return;
        if (QtMocHelpers::indexOfMethod<void (ConcreteDevice::*)()>(_a, &ConcreteDevice::Disconnected, 1))
            return;
        if (QtMocHelpers::indexOfMethod<void (ConcreteDevice::*)(INDI::Property )>(_a, &ConcreteDevice::propertyDefined, 2))
            return;
        if (QtMocHelpers::indexOfMethod<void (ConcreteDevice::*)(INDI::Property )>(_a, &ConcreteDevice::propertyUpdated, 3))
            return;
        if (QtMocHelpers::indexOfMethod<void (ConcreteDevice::*)(INDI::Property )>(_a, &ConcreteDevice::propertyDeleted, 4))
            return;
        if (QtMocHelpers::indexOfMethod<void (ConcreteDevice::*)()>(_a, &ConcreteDevice::ready, 5))
            return;
    }
    if (_c == QMetaObject::ReadProperty) {
        void *_v = _a[0];
        switch (_id) {
        case 0: *reinterpret_cast<QString*>(_v) = _t->getDeviceName(); break;
        case 1: *reinterpret_cast<bool*>(_v) = _t->isConnected(); break;
        default: break;
        }
    }
}

const QMetaObject *ISD::ConcreteDevice::metaObject() const
{
    return QObject::d_ptr->metaObject ? QObject::d_ptr->dynamicMetaObject() : &staticMetaObject;
}

void *ISD::ConcreteDevice::qt_metacast(const char *_clname)
{
    if (!_clname) return nullptr;
    if (!strcmp(_clname, qt_staticMetaObjectStaticContent<qt_meta_tag_ZN3ISD14ConcreteDeviceE_t>.strings))
        return static_cast<void*>(this);
    return GDInterface::qt_metacast(_clname);
}

int ISD::ConcreteDevice::qt_metacall(QMetaObject::Call _c, int _id, void **_a)
{
    _id = GDInterface::qt_metacall(_c, _id, _a);
    if (_id < 0)
        return _id;
    if (_c == QMetaObject::InvokeMetaMethod) {
        if (_id < 6)
            qt_static_metacall(this, _c, _id, _a);
        _id -= 6;
    }
    if (_c == QMetaObject::RegisterMethodArgumentMetaType) {
        if (_id < 6)
            qt_static_metacall(this, _c, _id, _a);
        _id -= 6;
    }
    if (_c == QMetaObject::ReadProperty || _c == QMetaObject::WriteProperty
            || _c == QMetaObject::ResetProperty || _c == QMetaObject::BindableProperty
            || _c == QMetaObject::RegisterPropertyMetaType) {
        qt_static_metacall(this, _c, _id, _a);
        _id -= 2;
    }
    return _id;
}

// SIGNAL 0
void ISD::ConcreteDevice::Connected()
{
    QMetaObject::activate(this, &staticMetaObject, 0, nullptr);
}

// SIGNAL 1
void ISD::ConcreteDevice::Disconnected()
{
    QMetaObject::activate(this, &staticMetaObject, 1, nullptr);
}

// SIGNAL 2
void ISD::ConcreteDevice::propertyDefined(INDI::Property _t1)
{
    QMetaObject::activate<void>(this, &staticMetaObject, 2, nullptr, _t1);
}

// SIGNAL 3
void ISD::ConcreteDevice::propertyUpdated(INDI::Property _t1)
{
    QMetaObject::activate<void>(this, &staticMetaObject, 3, nullptr, _t1);
}

// SIGNAL 4
void ISD::ConcreteDevice::propertyDeleted(INDI::Property _t1)
{
    QMetaObject::activate<void>(this, &staticMetaObject, 4, nullptr, _t1);
}

// SIGNAL 5
void ISD::ConcreteDevice::ready()
{
    QMetaObject::activate(this, &staticMetaObject, 5, nullptr);
}
QT_WARNING_POP
