/****************************************************************************
** Meta object code from reading C++ file 'ekosadaptor.h'
**
** Created by: The Qt Meta Object Compiler version 69 (Qt 6.11.1)
**
** WARNING! All changes made in this file will be lost!
*****************************************************************************/

#include "ekosadaptor.h"
#include <QtCore/qmetatype.h>

#include <QtCore/qtmochelpers.h>

#include <memory>


#include <QtCore/qxptype_traits.h>
#if !defined(Q_MOC_OUTPUT_REVISION)
#error "The header file 'ekosadaptor.h' doesn't include <QObject>."
#elif Q_MOC_OUTPUT_REVISION != 69
#error "This file was generated using the moc from 6.11.1. It"
#error "cannot be used with the include files from this version of Qt."
#error "(The moc has changed too much.)"
#endif

#ifndef Q_CONSTINIT
#define Q_CONSTINIT
#endif

QT_WARNING_PUSH
QT_WARNING_DISABLE_DEPRECATED
QT_WARNING_DISABLE_GCC("-Wuseless-cast")
namespace {
struct qt_meta_tag_ZN11EkosAdaptorE_t {};
} // unnamed namespace

template <> constexpr inline auto EkosAdaptor::qt_create_metaobjectdata<qt_meta_tag_ZN11EkosAdaptorE_t>()
{
    namespace QMC = QtMocConstants;
    QtMocHelpers::StringRefStorage qt_stringData {
        "EkosAdaptor",
        "D-Bus Interface",
        "org.kde.kstars.Ekos",
        "D-Bus Introspection",
        "  <interface name=\"org.kde.kstars.Ekos\">\n    <property access=\""
        "read\" type=\"i\" name=\"indiStatus\">\n      <annotation value=\""
        "Ekos::CommunicationStatus\" name=\"org.qtproject.QtDBus.QtTypeName"
        "\"/>\n    </property>\n    <property access=\"read\" type=\"i\" na"
        "me=\"ekosStatus\">\n      <annotation value=\"Ekos::CommunicationS"
        "tatus\" name=\"org.qtproject.QtDBus.QtTypeName\"/>\n    </property"
        ">\n    <property access=\"read\" type=\"u\" name=\"settleStatus\"/"
        ">\n    <property access=\"read\" type=\"b\" name=\"ekosLiveStatus\""
        "/>\n    <property access=\"read\" type=\"i\" name=\"extensionStatu"
        "s\"/>\n    <property access=\"read\" type=\"as\" name=\"logText\"/"
        ">\n    <method name=\"connectDevices\">\n      <annotation value=\""
        "true\" name=\"org.freedesktop.DBus.Method.NoReply\"/>\n    </metho"
        "d>\n    <method name=\"disconnectDevices\">\n      <annotation val"
        "ue=\"true\" name=\"org.freedesktop.DBus.Method.NoReply\"/>\n    </"
        "method>\n    <method name=\"start\">\n      <annotation value=\"tr"
        "ue\" name=\"org.freedesktop.DBus.Method.NoReply\"/>\n    </method>"
        "\n    <method name=\"stop\">\n      <annotation value=\"true\" nam"
        "e=\"org.freedesktop.DBus.Method.NoReply\"/>\n    </method>\n    <m"
        "ethod name=\"getProfiles\">\n      <arg direction=\"out\" type=\"a"
        "s\"/>\n    </method>\n    <method name=\"setProfile\">\n      <arg"
        " direction=\"in\" type=\"s\" name=\"profileName\"/>\n      <arg di"
        "rection=\"out\" type=\"b\"/>\n    </method>\n    <method name=\"ad"
        "dProfile\">\n      <annotation value=\"true\" name=\"org.freedeskt"
        "op.DBus.Method.NoReply\"/>\n      <arg direction=\"in\" type=\"s\""
        " name=\"profileJSON\"/>\n    </method>\n    <method name=\"editPro"
        "file\">\n      <annotation value=\"true\" name=\"org.freedesktop.D"
        "Bus.Method.NoReply\"/>\n      <arg direction=\"in\" type=\"s\" nam"
        "e=\"profileJSON\"/>\n    </method>\n    <method name=\"deleteProfi"
        "le\">\n      <annotation value=\"true\" name=\"org.freedesktop.DBu"
        "s.Method.NoReply\"/>\n      <arg direction=\"in\" type=\"s\" name="
        "\"name\"/>\n    </method>\n    <method name=\"getProfile\">\n     "
        " <arg direction=\"in\" type=\"s\" name=\"name\"/>\n      <arg dire"
        "ction=\"out\" type=\"s\"/>\n    </method>\n    <method name=\"setE"
        "kosLiveConnected\">\n      <arg direction=\"in\" type=\"b\" name=\""
        "enabled\"/>\n    </method>\n    <method name=\"setEkosLiveConfig\""
        ">\n      <arg direction=\"in\" type=\"b\" name=\"rememberCredentia"
        "ls\"/>\n      <arg direction=\"in\" type=\"b\" name=\"autoConnect\""
        "/>\n    </method>\n    <method name=\"setEkosLiveUser\">\n      <a"
        "rg direction=\"in\" type=\"s\" name=\"username\"/>\n      <arg dir"
        "ection=\"in\" type=\"s\" name=\"password\"/>\n    </method>\n    <"
        "method name=\"setEkosLoggingEnabled\">\n      <arg direction=\"in\""
        " type=\"s\" name=\"name\"/>\n      <arg direction=\"in\" type=\"b\""
        " name=\"enabled\"/>\n    </method>\n    <method name=\"setFITSfrom"
        "File\">\n      <arg direction=\"in\" type=\"b\" name=\"previewFrom"
        "File\"/>\n    </method>\n    <method name=\"previewFile\">\n      "
        "<arg direction=\"in\" type=\"s\" name=\"filePath\"/>\n    </method"
        ">\n    <signal name=\"indiStatusChanged\">\n      <arg direction=\""
        "out\" type=\"(i)\" name=\"status\"/>\n      <annotation value=\"Ek"
        "os::CommunicationStatus\" name=\"org.qtproject.QtDBus.QtTypeName.I"
        "n0\"/>\n      <annotation value=\"Ekos::CommunicationStatus\" name"
        "=\"org.qtproject.QtDBus.QtTypeName.Out0\"/>\n    </signal>\n    <s"
        "ignal name=\"ekosStatusChanged\">\n      <arg direction=\"out\" ty"
        "pe=\"(i)\" name=\"status\"/>\n      <annotation value=\"Ekos::Comm"
        "unicationStatus\" name=\"org.qtproject.QtDBus.QtTypeName.In0\"/>\n"
        "      <annotation value=\"Ekos::CommunicationStatus\" name=\"org.q"
        "tproject.QtDBus.QtTypeName.Out0\"/>\n    </signal>\n    <signal na"
        "me=\"settleStatusChanged\">\n      <arg direction=\"out\" type=\"("
        "i)\" name=\"status\"/>\n      <annotation value=\"Ekos::Communicat"
        "ionStatus\" name=\"org.qtproject.QtDBus.QtTypeName.In0\"/>\n      "
        "<annotation value=\"Ekos::CommunicationStatus\" name=\"org.qtproje"
        "ct.QtDBus.QtTypeName.Out0\"/>\n    </signal>\n    <signal name=\"e"
        "kosLiveStatusChanged\">\n      <arg direction=\"out\" type=\"b\" n"
        "ame=\"status\"/>\n    </signal>\n    <signal name=\"extensionStatu"
        "sChanged\">\n      <arg direction=\"out\" type=\"b\" name=\"status"
        "\"/>\n    </signal>\n    <signal name=\"newLog\">\n      <arg dire"
        "ction=\"out\" type=\"s\" name=\"text\"/>\n    </signal>\n    <sign"
        "al name=\"newModule\">\n      <arg direction=\"out\" type=\"s\" na"
        "me=\"name\"/>\n    </signal>\n    <signal name=\"newDevice\">\n   "
        "   <arg direction=\"out\" type=\"s\" name=\"name\"/>\n      <arg d"
        "irection=\"out\" type=\"i\" name=\"interface\"/>\n    </signal>\n "
        " </interface>\n",
        "ekosLiveStatusChanged",
        "",
        "status",
        "ekosStatusChanged",
        "Ekos::CommunicationStatus",
        "extensionStatusChanged",
        "indiStatusChanged",
        "newDevice",
        "name",
        "interface",
        "newLog",
        "text",
        "newModule",
        "settleStatusChanged",
        "addProfile",
        "Q_NOREPLY",
        "profileJSON",
        "connectDevices",
        "deleteProfile",
        "disconnectDevices",
        "editProfile",
        "getProfile",
        "getProfiles",
        "previewFile",
        "filePath",
        "setEkosLiveConfig",
        "rememberCredentials",
        "autoConnect",
        "setEkosLiveConnected",
        "enabled",
        "setEkosLiveUser",
        "username",
        "password",
        "setEkosLoggingEnabled",
        "setFITSfromFile",
        "previewFromFile",
        "setProfile",
        "profileName",
        "start",
        "stop",
        "ekosLiveStatus",
        "ekosStatus",
        "extensionStatus",
        "indiStatus",
        "logText",
        "settleStatus"
    };

    QtMocHelpers::UintData qt_methods {
        // Signal 'ekosLiveStatusChanged'
        QtMocHelpers::SignalData<void(bool)>(5, 6, QMC::AccessPublic, QMetaType::Void, {{
            { QMetaType::Bool, 7 },
        }}),
        // Signal 'ekosStatusChanged'
        QtMocHelpers::SignalData<void(Ekos::CommunicationStatus)>(8, 6, QMC::AccessPublic, QMetaType::Void, {{
            { 0x80000000 | 9, 7 },
        }}),
        // Signal 'extensionStatusChanged'
        QtMocHelpers::SignalData<void(bool)>(10, 6, QMC::AccessPublic, QMetaType::Void, {{
            { QMetaType::Bool, 7 },
        }}),
        // Signal 'indiStatusChanged'
        QtMocHelpers::SignalData<void(Ekos::CommunicationStatus)>(11, 6, QMC::AccessPublic, QMetaType::Void, {{
            { 0x80000000 | 9, 7 },
        }}),
        // Signal 'newDevice'
        QtMocHelpers::SignalData<void(const QString &, int)>(12, 6, QMC::AccessPublic, QMetaType::Void, {{
            { QMetaType::QString, 13 }, { QMetaType::Int, 14 },
        }}),
        // Signal 'newLog'
        QtMocHelpers::SignalData<void(const QString &)>(15, 6, QMC::AccessPublic, QMetaType::Void, {{
            { QMetaType::QString, 16 },
        }}),
        // Signal 'newModule'
        QtMocHelpers::SignalData<void(const QString &)>(17, 6, QMC::AccessPublic, QMetaType::Void, {{
            { QMetaType::QString, 13 },
        }}),
        // Signal 'settleStatusChanged'
        QtMocHelpers::SignalData<void(Ekos::CommunicationStatus)>(18, 6, QMC::AccessPublic, QMetaType::Void, {{
            { 0x80000000 | 9, 7 },
        }}),
        // Slot 'addProfile'
        QtMocHelpers::SlotData<void(const QString &)>(19, 20, QMC::AccessPublic, QMetaType::Void, {{
            { QMetaType::QString, 21 },
        }}),
        // Slot 'connectDevices'
        QtMocHelpers::SlotData<void()>(22, 20, QMC::AccessPublic, QMetaType::Void),
        // Slot 'deleteProfile'
        QtMocHelpers::SlotData<void(const QString &)>(23, 20, QMC::AccessPublic, QMetaType::Void, {{
            { QMetaType::QString, 13 },
        }}),
        // Slot 'disconnectDevices'
        QtMocHelpers::SlotData<void()>(24, 20, QMC::AccessPublic, QMetaType::Void),
        // Slot 'editProfile'
        QtMocHelpers::SlotData<void(const QString &)>(25, 20, QMC::AccessPublic, QMetaType::Void, {{
            { QMetaType::QString, 21 },
        }}),
        // Slot 'getProfile'
        QtMocHelpers::SlotData<QString(const QString &)>(26, 6, QMC::AccessPublic, QMetaType::QString, {{
            { QMetaType::QString, 13 },
        }}),
        // Slot 'getProfiles'
        QtMocHelpers::SlotData<QStringList()>(27, 6, QMC::AccessPublic, QMetaType::QStringList),
        // Slot 'previewFile'
        QtMocHelpers::SlotData<void(const QString &)>(28, 6, QMC::AccessPublic, QMetaType::Void, {{
            { QMetaType::QString, 29 },
        }}),
        // Slot 'setEkosLiveConfig'
        QtMocHelpers::SlotData<void(bool, bool)>(30, 6, QMC::AccessPublic, QMetaType::Void, {{
            { QMetaType::Bool, 31 }, { QMetaType::Bool, 32 },
        }}),
        // Slot 'setEkosLiveConnected'
        QtMocHelpers::SlotData<void(bool)>(33, 6, QMC::AccessPublic, QMetaType::Void, {{
            { QMetaType::Bool, 34 },
        }}),
        // Slot 'setEkosLiveUser'
        QtMocHelpers::SlotData<void(const QString &, const QString &)>(35, 6, QMC::AccessPublic, QMetaType::Void, {{
            { QMetaType::QString, 36 }, { QMetaType::QString, 37 },
        }}),
        // Slot 'setEkosLoggingEnabled'
        QtMocHelpers::SlotData<void(const QString &, bool)>(38, 6, QMC::AccessPublic, QMetaType::Void, {{
            { QMetaType::QString, 13 }, { QMetaType::Bool, 34 },
        }}),
        // Slot 'setFITSfromFile'
        QtMocHelpers::SlotData<void(bool)>(39, 6, QMC::AccessPublic, QMetaType::Void, {{
            { QMetaType::Bool, 40 },
        }}),
        // Slot 'setProfile'
        QtMocHelpers::SlotData<bool(const QString &)>(41, 6, QMC::AccessPublic, QMetaType::Bool, {{
            { QMetaType::QString, 42 },
        }}),
        // Slot 'start'
        QtMocHelpers::SlotData<void()>(43, 20, QMC::AccessPublic, QMetaType::Void),
        // Slot 'stop'
        QtMocHelpers::SlotData<void()>(44, 20, QMC::AccessPublic, QMetaType::Void),
    };
    QtMocHelpers::UintData qt_properties {
        // property 'ekosLiveStatus'
        QtMocHelpers::PropertyData<bool>(45, QMetaType::Bool, QMC::DefaultPropertyFlags),
        // property 'ekosStatus'
        QtMocHelpers::PropertyData<int>(46, QMetaType::Int, QMC::DefaultPropertyFlags),
        // property 'extensionStatus'
        QtMocHelpers::PropertyData<int>(47, QMetaType::Int, QMC::DefaultPropertyFlags),
        // property 'indiStatus'
        QtMocHelpers::PropertyData<int>(48, QMetaType::Int, QMC::DefaultPropertyFlags),
        // property 'logText'
        QtMocHelpers::PropertyData<QStringList>(49, QMetaType::QStringList, QMC::DefaultPropertyFlags),
        // property 'settleStatus'
        QtMocHelpers::PropertyData<uint>(50, QMetaType::UInt, QMC::DefaultPropertyFlags),
    };
    QtMocHelpers::UintData qt_enums {
    };
    QtMocHelpers::UintData qt_constructors {};
    QtMocHelpers::ClassInfos qt_classinfo({
            {    1,    2 },
            {    3,    4 },
    });
    return QtMocHelpers::metaObjectData<EkosAdaptor, qt_meta_tag_ZN11EkosAdaptorE_t>(QMC::MetaObjectFlag{}, qt_stringData,
            qt_methods, qt_properties, qt_enums, qt_constructors, qt_classinfo);
}
Q_CONSTINIT const QMetaObject EkosAdaptor::staticMetaObject = { {
    QMetaObject::SuperData::link<QDBusAbstractAdaptor::staticMetaObject>(),
    qt_staticMetaObjectStaticContent<qt_meta_tag_ZN11EkosAdaptorE_t>.stringdata,
    qt_staticMetaObjectStaticContent<qt_meta_tag_ZN11EkosAdaptorE_t>.data,
    qt_static_metacall,
    nullptr,
    qt_staticMetaObjectRelocatingContent<qt_meta_tag_ZN11EkosAdaptorE_t>.metaTypes,
    nullptr
} };

void EkosAdaptor::qt_static_metacall(QObject *_o, QMetaObject::Call _c, int _id, void **_a)
{
    auto *_t = static_cast<EkosAdaptor *>(_o);
    if (_c == QMetaObject::InvokeMetaMethod) {
        switch (_id) {
        case 0: _t->ekosLiveStatusChanged((*reinterpret_cast<std::add_pointer_t<bool>>(_a[1]))); break;
        case 1: _t->ekosStatusChanged((*reinterpret_cast<std::add_pointer_t<Ekos::CommunicationStatus>>(_a[1]))); break;
        case 2: _t->extensionStatusChanged((*reinterpret_cast<std::add_pointer_t<bool>>(_a[1]))); break;
        case 3: _t->indiStatusChanged((*reinterpret_cast<std::add_pointer_t<Ekos::CommunicationStatus>>(_a[1]))); break;
        case 4: _t->newDevice((*reinterpret_cast<std::add_pointer_t<QString>>(_a[1])),(*reinterpret_cast<std::add_pointer_t<int>>(_a[2]))); break;
        case 5: _t->newLog((*reinterpret_cast<std::add_pointer_t<QString>>(_a[1]))); break;
        case 6: _t->newModule((*reinterpret_cast<std::add_pointer_t<QString>>(_a[1]))); break;
        case 7: _t->settleStatusChanged((*reinterpret_cast<std::add_pointer_t<Ekos::CommunicationStatus>>(_a[1]))); break;
        case 8: _t->addProfile((*reinterpret_cast<std::add_pointer_t<QString>>(_a[1]))); break;
        case 9: _t->connectDevices(); break;
        case 10: _t->deleteProfile((*reinterpret_cast<std::add_pointer_t<QString>>(_a[1]))); break;
        case 11: _t->disconnectDevices(); break;
        case 12: _t->editProfile((*reinterpret_cast<std::add_pointer_t<QString>>(_a[1]))); break;
        case 13: { QString _r = _t->getProfile((*reinterpret_cast<std::add_pointer_t<QString>>(_a[1])));
            if (_a[0]) *reinterpret_cast<QString*>(_a[0]) = std::move(_r); }  break;
        case 14: { QStringList _r = _t->getProfiles();
            if (_a[0]) *reinterpret_cast<QStringList*>(_a[0]) = std::move(_r); }  break;
        case 15: _t->previewFile((*reinterpret_cast<std::add_pointer_t<QString>>(_a[1]))); break;
        case 16: _t->setEkosLiveConfig((*reinterpret_cast<std::add_pointer_t<bool>>(_a[1])),(*reinterpret_cast<std::add_pointer_t<bool>>(_a[2]))); break;
        case 17: _t->setEkosLiveConnected((*reinterpret_cast<std::add_pointer_t<bool>>(_a[1]))); break;
        case 18: _t->setEkosLiveUser((*reinterpret_cast<std::add_pointer_t<QString>>(_a[1])),(*reinterpret_cast<std::add_pointer_t<QString>>(_a[2]))); break;
        case 19: _t->setEkosLoggingEnabled((*reinterpret_cast<std::add_pointer_t<QString>>(_a[1])),(*reinterpret_cast<std::add_pointer_t<bool>>(_a[2]))); break;
        case 20: _t->setFITSfromFile((*reinterpret_cast<std::add_pointer_t<bool>>(_a[1]))); break;
        case 21: { bool _r = _t->setProfile((*reinterpret_cast<std::add_pointer_t<QString>>(_a[1])));
            if (_a[0]) *reinterpret_cast<bool*>(_a[0]) = std::move(_r); }  break;
        case 22: _t->start(); break;
        case 23: _t->stop(); break;
        default: ;
        }
    }
    if (_c == QMetaObject::RegisterMethodArgumentMetaType) {
        switch (_id) {
        default: *reinterpret_cast<QMetaType *>(_a[0]) = QMetaType(); break;
        case 1:
            switch (*reinterpret_cast<int*>(_a[1])) {
            default: *reinterpret_cast<QMetaType *>(_a[0]) = QMetaType(); break;
            case 0:
                *reinterpret_cast<QMetaType *>(_a[0]) = QMetaType::fromType< Ekos::CommunicationStatus >(); break;
            }
            break;
        case 3:
            switch (*reinterpret_cast<int*>(_a[1])) {
            default: *reinterpret_cast<QMetaType *>(_a[0]) = QMetaType(); break;
            case 0:
                *reinterpret_cast<QMetaType *>(_a[0]) = QMetaType::fromType< Ekos::CommunicationStatus >(); break;
            }
            break;
        case 7:
            switch (*reinterpret_cast<int*>(_a[1])) {
            default: *reinterpret_cast<QMetaType *>(_a[0]) = QMetaType(); break;
            case 0:
                *reinterpret_cast<QMetaType *>(_a[0]) = QMetaType::fromType< Ekos::CommunicationStatus >(); break;
            }
            break;
        }
    }
    if (_c == QMetaObject::IndexOfMethod) {
        if (QtMocHelpers::indexOfMethod<void (EkosAdaptor::*)(bool )>(_a, &EkosAdaptor::ekosLiveStatusChanged, 0))
            return;
        if (QtMocHelpers::indexOfMethod<void (EkosAdaptor::*)(Ekos::CommunicationStatus )>(_a, &EkosAdaptor::ekosStatusChanged, 1))
            return;
        if (QtMocHelpers::indexOfMethod<void (EkosAdaptor::*)(bool )>(_a, &EkosAdaptor::extensionStatusChanged, 2))
            return;
        if (QtMocHelpers::indexOfMethod<void (EkosAdaptor::*)(Ekos::CommunicationStatus )>(_a, &EkosAdaptor::indiStatusChanged, 3))
            return;
        if (QtMocHelpers::indexOfMethod<void (EkosAdaptor::*)(const QString & , int )>(_a, &EkosAdaptor::newDevice, 4))
            return;
        if (QtMocHelpers::indexOfMethod<void (EkosAdaptor::*)(const QString & )>(_a, &EkosAdaptor::newLog, 5))
            return;
        if (QtMocHelpers::indexOfMethod<void (EkosAdaptor::*)(const QString & )>(_a, &EkosAdaptor::newModule, 6))
            return;
        if (QtMocHelpers::indexOfMethod<void (EkosAdaptor::*)(Ekos::CommunicationStatus )>(_a, &EkosAdaptor::settleStatusChanged, 7))
            return;
    }
    if (_c == QMetaObject::ReadProperty) {
        void *_v = _a[0];
        switch (_id) {
        case 0: *reinterpret_cast<bool*>(_v) = _t->ekosLiveStatus(); break;
        case 1: *reinterpret_cast<int*>(_v) = _t->ekosStatus(); break;
        case 2: *reinterpret_cast<int*>(_v) = _t->extensionStatus(); break;
        case 3: *reinterpret_cast<int*>(_v) = _t->indiStatus(); break;
        case 4: *reinterpret_cast<QStringList*>(_v) = _t->logText(); break;
        case 5: *reinterpret_cast<uint*>(_v) = _t->settleStatus(); break;
        default: break;
        }
    }
}

const QMetaObject *EkosAdaptor::metaObject() const
{
    return QObject::d_ptr->metaObject ? QObject::d_ptr->dynamicMetaObject() : &staticMetaObject;
}

void *EkosAdaptor::qt_metacast(const char *_clname)
{
    if (!_clname) return nullptr;
    if (!strcmp(_clname, qt_staticMetaObjectStaticContent<qt_meta_tag_ZN11EkosAdaptorE_t>.strings))
        return static_cast<void*>(this);
    return QDBusAbstractAdaptor::qt_metacast(_clname);
}

int EkosAdaptor::qt_metacall(QMetaObject::Call _c, int _id, void **_a)
{
    _id = QDBusAbstractAdaptor::qt_metacall(_c, _id, _a);
    if (_id < 0)
        return _id;
    if (_c == QMetaObject::InvokeMetaMethod) {
        if (_id < 24)
            qt_static_metacall(this, _c, _id, _a);
        _id -= 24;
    }
    if (_c == QMetaObject::RegisterMethodArgumentMetaType) {
        if (_id < 24)
            qt_static_metacall(this, _c, _id, _a);
        _id -= 24;
    }
    if (_c == QMetaObject::ReadProperty || _c == QMetaObject::WriteProperty
            || _c == QMetaObject::ResetProperty || _c == QMetaObject::BindableProperty
            || _c == QMetaObject::RegisterPropertyMetaType) {
        qt_static_metacall(this, _c, _id, _a);
        _id -= 6;
    }
    return _id;
}

// SIGNAL 0
void EkosAdaptor::ekosLiveStatusChanged(bool _t1)
{
    QMetaObject::activate<void>(this, &staticMetaObject, 0, nullptr, _t1);
}

// SIGNAL 1
void EkosAdaptor::ekosStatusChanged(Ekos::CommunicationStatus _t1)
{
    QMetaObject::activate<void>(this, &staticMetaObject, 1, nullptr, _t1);
}

// SIGNAL 2
void EkosAdaptor::extensionStatusChanged(bool _t1)
{
    QMetaObject::activate<void>(this, &staticMetaObject, 2, nullptr, _t1);
}

// SIGNAL 3
void EkosAdaptor::indiStatusChanged(Ekos::CommunicationStatus _t1)
{
    QMetaObject::activate<void>(this, &staticMetaObject, 3, nullptr, _t1);
}

// SIGNAL 4
void EkosAdaptor::newDevice(const QString & _t1, int _t2)
{
    QMetaObject::activate<void>(this, &staticMetaObject, 4, nullptr, _t1, _t2);
}

// SIGNAL 5
void EkosAdaptor::newLog(const QString & _t1)
{
    QMetaObject::activate<void>(this, &staticMetaObject, 5, nullptr, _t1);
}

// SIGNAL 6
void EkosAdaptor::newModule(const QString & _t1)
{
    QMetaObject::activate<void>(this, &staticMetaObject, 6, nullptr, _t1);
}

// SIGNAL 7
void EkosAdaptor::settleStatusChanged(Ekos::CommunicationStatus _t1)
{
    QMetaObject::activate<void>(this, &staticMetaObject, 7, nullptr, _t1);
}
QT_WARNING_POP
