/********************************************************************************
** Form generated from reading UI file 'aberrationinspector.ui'
**
** Created by: Qt User Interface Compiler version 6.11.1
**
** WARNING! All changes made in this file will be lost when recompiling UI file!
********************************************************************************/

#ifndef UI_ABERRATIONINSPECTOR_H
#define UI_ABERRATIONINSPECTOR_H

#include <QtCore/QVariant>
#include <QtWidgets/QAbstractButton>
#include <QtWidgets/QApplication>
#include <QtWidgets/QCheckBox>
#include <QtWidgets/QComboBox>
#include <QtWidgets/QDialog>
#include <QtWidgets/QDialogButtonBox>
#include <QtWidgets/QGridLayout>
#include <QtWidgets/QGroupBox>
#include <QtWidgets/QHBoxLayout>
#include <QtWidgets/QHeaderView>
#include <QtWidgets/QLabel>
#include <QtWidgets/QLineEdit>
#include <QtWidgets/QSlider>
#include <QtWidgets/QSpacerItem>
#include <QtWidgets/QSplitter>
#include <QtWidgets/QVBoxLayout>
#include <QtWidgets/QWidget>
#include <klocalizedstring.h>
#include "ekos/focus/abinstablewidget.h"
#include "ekos/focus/tiltcorrectionwidget.h"

QT_BEGIN_NAMESPACE

class Ui_aberrationInspectorDialog
{
public:
    QVBoxLayout *verticalLayout_3;
    QHBoxLayout *horizontalLayout_2;
    QGridLayout *gridLayout_4;
    QCheckBox *abInsShowLabels;
    QLabel *label_4;
    QComboBox *abInsTileSelection;
    QCheckBox *abInsShowCFZ;
    QCheckBox *abInsOptCentres;
    QCheckBox *abInsTiltPlate;
    QSpacerItem *horizontalSpacer;
    QDialogButtonBox *aberrationInspectorButtonBox;
    QSplitter *abInsVSplitter;
    QWidget *abInsPlot;
    QVBoxLayout *abInsPlotLayout;
    QSplitter *abInsHSplitter;
    QWidget *tableAndResultsWidget;
    QVBoxLayout *verticalLayout;
    AbInsTableWidget *abInsTable;
    QGridLayout *gridLayout_3;
    QLabel *label_2;
    QLabel *label_5;
    QLineEdit *totalTilt;
    QLineEdit *backfocus;
    QLabel *label_3;
    QLabel *label;
    QLineEdit *lrTilt;
    QLineEdit *tbTilt;
    Ekos::TiltCorrectionWidget *tiltCorrectionWidget;
    QWidget *widget;
    QHBoxLayout *hLayout;
    QVBoxLayout *vLayout;
    QLabel *label_6;
    QComboBox *abInsSelection;
    QLabel *label_7;
    QComboBox *abInsTheme;
    QCheckBox *abInsLabels;
    QCheckBox *abInsSensor;
    QCheckBox *abInsPetzvalWire;
    QCheckBox *abInsPetzvalSurface;
    QGroupBox *groupBox;
    QVBoxLayout *verticalLayout_2;
    QCheckBox *abInsSimMode;
    QSlider *abInsBackfocusSlider;
    QSlider *abInsTiltLRSlider;
    QSlider *abInsTiltTBSlider;
    QSpacerItem *verticalSpacer;

    void setupUi(QDialog *aberrationInspectorDialog)
    {
        if (aberrationInspectorDialog->objectName().isEmpty())
            aberrationInspectorDialog->setObjectName("aberrationInspectorDialog");
        aberrationInspectorDialog->setWindowModality(Qt::NonModal);
        aberrationInspectorDialog->resize(897, 666);
        QSizePolicy sizePolicy(QSizePolicy::Policy::Preferred, QSizePolicy::Policy::Preferred);
        sizePolicy.setHorizontalStretch(0);
        sizePolicy.setVerticalStretch(0);
        sizePolicy.setHeightForWidth(aberrationInspectorDialog->sizePolicy().hasHeightForWidth());
        aberrationInspectorDialog->setSizePolicy(sizePolicy);
        aberrationInspectorDialog->setSizeGripEnabled(true);
        aberrationInspectorDialog->setModal(false);
        verticalLayout_3 = new QVBoxLayout(aberrationInspectorDialog);
        verticalLayout_3->setObjectName("verticalLayout_3");
        horizontalLayout_2 = new QHBoxLayout();
        horizontalLayout_2->setObjectName("horizontalLayout_2");
        horizontalLayout_2->setSizeConstraint(QLayout::SetDefaultConstraint);
        gridLayout_4 = new QGridLayout();
        gridLayout_4->setObjectName("gridLayout_4");
        abInsShowLabels = new QCheckBox(aberrationInspectorDialog);
        abInsShowLabels->setObjectName("abInsShowLabels");
        QSizePolicy sizePolicy1(QSizePolicy::Policy::Preferred, QSizePolicy::Policy::Fixed);
        sizePolicy1.setHorizontalStretch(0);
        sizePolicy1.setVerticalStretch(0);
        sizePolicy1.setHeightForWidth(abInsShowLabels->sizePolicy().hasHeightForWidth());
        abInsShowLabels->setSizePolicy(sizePolicy1);

        gridLayout_4->addWidget(abInsShowLabels, 0, 2, 1, 1);

        label_4 = new QLabel(aberrationInspectorDialog);
        label_4->setObjectName("label_4");
        QSizePolicy sizePolicy2(QSizePolicy::Policy::Fixed, QSizePolicy::Policy::Fixed);
        sizePolicy2.setHorizontalStretch(0);
        sizePolicy2.setVerticalStretch(0);
        sizePolicy2.setHeightForWidth(label_4->sizePolicy().hasHeightForWidth());
        label_4->setSizePolicy(sizePolicy2);
        label_4->setAlignment(Qt::AlignLeading|Qt::AlignLeft|Qt::AlignVCenter);

        gridLayout_4->addWidget(label_4, 0, 0, 1, 1);

        abInsTileSelection = new QComboBox(aberrationInspectorDialog);
        abInsTileSelection->addItem(QString());
        abInsTileSelection->addItem(QString());
        abInsTileSelection->addItem(QString());
        abInsTileSelection->setObjectName("abInsTileSelection");

        gridLayout_4->addWidget(abInsTileSelection, 0, 1, 1, 1);

        abInsShowCFZ = new QCheckBox(aberrationInspectorDialog);
        abInsShowCFZ->setObjectName("abInsShowCFZ");
        sizePolicy1.setHeightForWidth(abInsShowCFZ->sizePolicy().hasHeightForWidth());
        abInsShowCFZ->setSizePolicy(sizePolicy1);
        abInsShowCFZ->setChecked(false);

        gridLayout_4->addWidget(abInsShowCFZ, 0, 3, 1, 1);

        abInsOptCentres = new QCheckBox(aberrationInspectorDialog);
        abInsOptCentres->setObjectName("abInsOptCentres");

        gridLayout_4->addWidget(abInsOptCentres, 0, 4, 1, 1);

        abInsTiltPlate = new QCheckBox(aberrationInspectorDialog);
        abInsTiltPlate->setObjectName("abInsTiltPlate");

        gridLayout_4->addWidget(abInsTiltPlate, 0, 5, 1, 1);


        horizontalLayout_2->addLayout(gridLayout_4);

        horizontalSpacer = new QSpacerItem(40, 20, QSizePolicy::Policy::Expanding, QSizePolicy::Policy::Minimum);

        horizontalLayout_2->addItem(horizontalSpacer);

        aberrationInspectorButtonBox = new QDialogButtonBox(aberrationInspectorDialog);
        aberrationInspectorButtonBox->setObjectName("aberrationInspectorButtonBox");
        aberrationInspectorButtonBox->setStandardButtons(QDialogButtonBox::Close);

        horizontalLayout_2->addWidget(aberrationInspectorButtonBox);


        verticalLayout_3->addLayout(horizontalLayout_2);

        abInsVSplitter = new QSplitter(aberrationInspectorDialog);
        abInsVSplitter->setObjectName("abInsVSplitter");
        abInsVSplitter->setOrientation(Qt::Vertical);
        abInsPlot = new QWidget(abInsVSplitter);
        abInsPlot->setObjectName("abInsPlot");
        abInsPlotLayout = new QVBoxLayout(abInsPlot);
        abInsPlotLayout->setObjectName("abInsPlotLayout");
        abInsVSplitter->addWidget(abInsPlot);
        abInsHSplitter = new QSplitter(abInsVSplitter);
        abInsHSplitter->setObjectName("abInsHSplitter");
        abInsHSplitter->setOrientation(Qt::Horizontal);
        tableAndResultsWidget = new QWidget(abInsHSplitter);
        tableAndResultsWidget->setObjectName("tableAndResultsWidget");
        verticalLayout = new QVBoxLayout(tableAndResultsWidget);
        verticalLayout->setObjectName("verticalLayout");
        abInsTable = new AbInsTableWidget(tableAndResultsWidget);
        if (abInsTable->columnCount() < 6)
            abInsTable->setColumnCount(6);
        if (abInsTable->rowCount() < 5)
            abInsTable->setRowCount(5);
        abInsTable->setObjectName("abInsTable");
        sizePolicy.setHeightForWidth(abInsTable->sizePolicy().hasHeightForWidth());
        abInsTable->setSizePolicy(sizePolicy);
        abInsTable->setMinimumSize(QSize(0, 0));
        abInsTable->setMouseTracking(true);
        abInsTable->setSizeAdjustPolicy(QAbstractScrollArea::AdjustToContents);
        abInsTable->setEditTriggers(QAbstractItemView::SelectedClicked);
        abInsTable->setAlternatingRowColors(true);
        abInsTable->setSelectionMode(QAbstractItemView::SingleSelection);
        abInsTable->setSelectionBehavior(QAbstractItemView::SelectItems);
        abInsTable->setSortingEnabled(false);
        abInsTable->setRowCount(5);
        abInsTable->setColumnCount(6);

        verticalLayout->addWidget(abInsTable);

        gridLayout_3 = new QGridLayout();
        gridLayout_3->setObjectName("gridLayout_3");
        gridLayout_3->setSizeConstraint(QLayout::SetDefaultConstraint);
        label_2 = new QLabel(tableAndResultsWidget);
        label_2->setObjectName("label_2");
        sizePolicy2.setHeightForWidth(label_2->sizePolicy().hasHeightForWidth());
        label_2->setSizePolicy(sizePolicy2);

        gridLayout_3->addWidget(label_2, 3, 0, 1, 1);

        label_5 = new QLabel(tableAndResultsWidget);
        label_5->setObjectName("label_5");
        sizePolicy2.setHeightForWidth(label_5->sizePolicy().hasHeightForWidth());
        label_5->setSizePolicy(sizePolicy2);

        gridLayout_3->addWidget(label_5, 4, 0, 1, 1);

        totalTilt = new QLineEdit(tableAndResultsWidget);
        totalTilt->setObjectName("totalTilt");
        totalTilt->setReadOnly(true);

        gridLayout_3->addWidget(totalTilt, 4, 1, 1, 1);

        backfocus = new QLineEdit(tableAndResultsWidget);
        backfocus->setObjectName("backfocus");
        backfocus->setReadOnly(true);

        gridLayout_3->addWidget(backfocus, 1, 1, 1, 1);

        label_3 = new QLabel(tableAndResultsWidget);
        label_3->setObjectName("label_3");
        sizePolicy2.setHeightForWidth(label_3->sizePolicy().hasHeightForWidth());
        label_3->setSizePolicy(sizePolicy2);

        gridLayout_3->addWidget(label_3, 1, 0, 1, 1);

        label = new QLabel(tableAndResultsWidget);
        label->setObjectName("label");
        sizePolicy2.setHeightForWidth(label->sizePolicy().hasHeightForWidth());
        label->setSizePolicy(sizePolicy2);

        gridLayout_3->addWidget(label, 2, 0, 1, 1);

        lrTilt = new QLineEdit(tableAndResultsWidget);
        lrTilt->setObjectName("lrTilt");
        lrTilt->setReadOnly(true);

        gridLayout_3->addWidget(lrTilt, 2, 1, 1, 1);

        tbTilt = new QLineEdit(tableAndResultsWidget);
        tbTilt->setObjectName("tbTilt");
        tbTilt->setReadOnly(true);

        gridLayout_3->addWidget(tbTilt, 3, 1, 1, 1);


        verticalLayout->addLayout(gridLayout_3);

        tiltCorrectionWidget = new Ekos::TiltCorrectionWidget(tableAndResultsWidget);
        tiltCorrectionWidget->setObjectName("tiltCorrectionWidget");

        verticalLayout->addWidget(tiltCorrectionWidget);

        abInsHSplitter->addWidget(tableAndResultsWidget);
        widget = new QWidget(abInsHSplitter);
        widget->setObjectName("widget");
        QSizePolicy sizePolicy3(QSizePolicy::Policy::Expanding, QSizePolicy::Policy::Expanding);
        sizePolicy3.setHorizontalStretch(0);
        sizePolicy3.setVerticalStretch(0);
        sizePolicy3.setHeightForWidth(widget->sizePolicy().hasHeightForWidth());
        widget->setSizePolicy(sizePolicy3);
        hLayout = new QHBoxLayout(widget);
        hLayout->setObjectName("hLayout");
        vLayout = new QVBoxLayout();
        vLayout->setObjectName("vLayout");
        label_6 = new QLabel(widget);
        label_6->setObjectName("label_6");

        vLayout->addWidget(label_6);

        abInsSelection = new QComboBox(widget);
        abInsSelection->addItem(QString());
        abInsSelection->addItem(QString());
        abInsSelection->addItem(QString());
        abInsSelection->setObjectName("abInsSelection");

        vLayout->addWidget(abInsSelection);

        label_7 = new QLabel(widget);
        label_7->setObjectName("label_7");

        vLayout->addWidget(label_7);

        abInsTheme = new QComboBox(widget);
        abInsTheme->addItem(QString());
        abInsTheme->addItem(QString());
        abInsTheme->addItem(QString());
        abInsTheme->addItem(QString());
        abInsTheme->addItem(QString());
        abInsTheme->addItem(QString());
        abInsTheme->addItem(QString());
        abInsTheme->addItem(QString());
        abInsTheme->setObjectName("abInsTheme");

        vLayout->addWidget(abInsTheme);

        abInsLabels = new QCheckBox(widget);
        abInsLabels->setObjectName("abInsLabels");
        abInsLabels->setChecked(true);

        vLayout->addWidget(abInsLabels);

        abInsSensor = new QCheckBox(widget);
        abInsSensor->setObjectName("abInsSensor");
        abInsSensor->setChecked(true);

        vLayout->addWidget(abInsSensor);

        abInsPetzvalWire = new QCheckBox(widget);
        abInsPetzvalWire->setObjectName("abInsPetzvalWire");
        abInsPetzvalWire->setChecked(true);

        vLayout->addWidget(abInsPetzvalWire);

        abInsPetzvalSurface = new QCheckBox(widget);
        abInsPetzvalSurface->setObjectName("abInsPetzvalSurface");

        vLayout->addWidget(abInsPetzvalSurface);

        groupBox = new QGroupBox(widget);
        groupBox->setObjectName("groupBox");
        verticalLayout_2 = new QVBoxLayout(groupBox);
        verticalLayout_2->setObjectName("verticalLayout_2");
        abInsSimMode = new QCheckBox(groupBox);
        abInsSimMode->setObjectName("abInsSimMode");

        verticalLayout_2->addWidget(abInsSimMode);

        abInsBackfocusSlider = new QSlider(groupBox);
        abInsBackfocusSlider->setObjectName("abInsBackfocusSlider");
        abInsBackfocusSlider->setEnabled(false);
        abInsBackfocusSlider->setOrientation(Qt::Horizontal);
        abInsBackfocusSlider->setTickPosition(QSlider::TicksAbove);
        abInsBackfocusSlider->setTickInterval(1);

        verticalLayout_2->addWidget(abInsBackfocusSlider);

        abInsTiltLRSlider = new QSlider(groupBox);
        abInsTiltLRSlider->setObjectName("abInsTiltLRSlider");
        abInsTiltLRSlider->setEnabled(false);
        abInsTiltLRSlider->setOrientation(Qt::Horizontal);
        abInsTiltLRSlider->setTickPosition(QSlider::TicksAbove);
        abInsTiltLRSlider->setTickInterval(1);

        verticalLayout_2->addWidget(abInsTiltLRSlider);

        abInsTiltTBSlider = new QSlider(groupBox);
        abInsTiltTBSlider->setObjectName("abInsTiltTBSlider");
        abInsTiltTBSlider->setEnabled(false);
        abInsTiltTBSlider->setOrientation(Qt::Horizontal);
        abInsTiltTBSlider->setTickPosition(QSlider::TicksAbove);
        abInsTiltTBSlider->setTickInterval(1);

        verticalLayout_2->addWidget(abInsTiltTBSlider);

        verticalSpacer = new QSpacerItem(20, 40, QSizePolicy::Policy::Minimum, QSizePolicy::Policy::Expanding);

        verticalLayout_2->addItem(verticalSpacer);


        vLayout->addWidget(groupBox);


        hLayout->addLayout(vLayout);

        abInsHSplitter->addWidget(widget);
        abInsVSplitter->addWidget(abInsHSplitter);

        verticalLayout_3->addWidget(abInsVSplitter);

        QWidget::setTabOrder(abInsTileSelection, abInsShowLabels);
        QWidget::setTabOrder(abInsShowLabels, abInsShowCFZ);
        QWidget::setTabOrder(abInsShowCFZ, totalTilt);
        QWidget::setTabOrder(totalTilt, tbTilt);
        QWidget::setTabOrder(tbTilt, backfocus);
        QWidget::setTabOrder(backfocus, lrTilt);

        retranslateUi(aberrationInspectorDialog);

        abInsTileSelection->setCurrentIndex(1);
        abInsTheme->setCurrentIndex(1);


        QMetaObject::connectSlotsByName(aberrationInspectorDialog);
    } // setupUi

    void retranslateUi(QDialog *aberrationInspectorDialog)
    {
        aberrationInspectorDialog->setWindowTitle(tr2i18n("Aberration Inspector", nullptr));
#if QT_CONFIG(tooltip)
        abInsShowLabels->setToolTip(tr2i18n("<html><head/><body><p>Check to show labels on the graph.</p></body></html>", nullptr));
#endif // QT_CONFIG(tooltip)
        abInsShowLabels->setText(tr2i18n("Labels", nullptr));
        label_4->setText(tr2i18n("Tiles:", nullptr));
        abInsTileSelection->setItemText(0, tr2i18n("All", nullptr));
        abInsTileSelection->setItemText(1, tr2i18n("Centre and outer corners", nullptr));
        abInsTileSelection->setItemText(2, tr2i18n("Centre and inner diamond", nullptr));

#if QT_CONFIG(tooltip)
        abInsTileSelection->setToolTip(tr2i18n("<html><head/><body><p>Select the Mosaic tile combination to use for Analysis:</p><p>- All displays all 9 tiles.</p><p>- Centre and outer corners.</p><p>- Centre and inner diamond.<br/></p></body></html>", nullptr));
#endif // QT_CONFIG(tooltip)
#if QT_CONFIG(tooltip)
        abInsShowCFZ->setToolTip(tr2i18n("<html><head/><body><p>Check to show the Critical Focus Zone on the graph.</p></body></html>", nullptr));
#endif // QT_CONFIG(tooltip)
        abInsShowCFZ->setText(tr2i18n("CFZ", nullptr));
        abInsOptCentres->setText(tr2i18n("Optimise Tile Centres", nullptr));
#if QT_CONFIG(tooltip)
        abInsTiltPlate->setToolTip(tr2i18n("<html><head/><body><p>Check if you have a tilt adjustment plate installed. Shows the Tilt Correction Advisory panel with suggested adjustments.</p></body></html>", nullptr));
#endif // QT_CONFIG(tooltip)
        abInsTiltPlate->setText(tr2i18n("Tilt Plate", nullptr));
        label_2->setText(tr2i18n("Top-Bottom Tilt:", nullptr));
        label_5->setText(tr2i18n("Total Tilt:", nullptr));
#if QT_CONFIG(tooltip)
        backfocus->setToolTip(tr2i18n("<html><head/><body><p>Backfocus delta is the difference in focus position between the sensor centre and the average of the centre corners.</p></body></html>", nullptr));
#endif // QT_CONFIG(tooltip)
        label_3->setText(tr2i18n("Backfocus \316\224:", nullptr));
        label->setText(tr2i18n("Left-Right Tilt:", nullptr));
        tiltCorrectionWidget->setTitle(tr2i18n("Tilt Correction Advisory", nullptr));
        label_6->setText(tr2i18n("Selection:", nullptr));
        abInsSelection->setItemText(0, tr2i18n("None", nullptr));
        abInsSelection->setItemText(1, tr2i18n("Item", nullptr));
        abInsSelection->setItemText(2, tr2i18n("Slice", nullptr));

#if QT_CONFIG(tooltip)
        abInsSelection->setToolTip(tr2i18n("<!DOCTYPE HTML PUBLIC \"-//W3C//DTD HTML 4.0//EN\" \"http://www.w3.org/TR/REC-html40/strict.dtd\">\n"
"<html><head><meta name=\"qrichtext\" content=\"1\" /><style type=\"text/css\">\n"
"p, li { white-space: pre-wrap; }\n"
"</style></head><body style=\" font-family:'.AppleSystemUIFont'; font-size:13pt; font-weight:400; font-style:normal;\">\n"
"<p style=\" margin-top:0px; margin-bottom:0px; margin-left:0px; margin-right:0px; -qt-block-indent:0; text-indent:0px;\">Selection mode of the 3D Graphic:</p>\n"
"<p style=\" margin-top:0px; margin-bottom:0px; margin-left:0px; margin-right:0px; -qt-block-indent:0; text-indent:0px;\">- None.</p>\n"
"<p style=\" margin-top:0px; margin-bottom:0px; margin-left:0px; margin-right:0px; -qt-block-indent:0; text-indent:0px;\">- Item selects the nearest datapoint.</p>\n"
"<p style=\" margin-top:0px; margin-bottom:0px; margin-left:0px; margin-right:0px; -qt-block-indent:0; text-indent:0px;\">- Slice produces a 2D slice through the graphic.</p></body></html>", nullptr));
#endif // QT_CONFIG(tooltip)
        abInsSelection->setCurrentText(tr2i18n("None", nullptr));
        label_7->setText(tr2i18n("Theme:", nullptr));
        abInsTheme->setItemText(0, tr2i18n("Qt", nullptr));
        abInsTheme->setItemText(1, tr2i18n("Primary Colors", nullptr));
        abInsTheme->setItemText(2, tr2i18n("Digia", nullptr));
        abInsTheme->setItemText(3, tr2i18n("Stone Moss", nullptr));
        abInsTheme->setItemText(4, tr2i18n("Army Blue", nullptr));
        abInsTheme->setItemText(5, tr2i18n("Retro", nullptr));
        abInsTheme->setItemText(6, tr2i18n("Ebony", nullptr));
        abInsTheme->setItemText(7, tr2i18n("Isabelle", nullptr));

#if QT_CONFIG(tooltip)
        abInsTheme->setToolTip(tr2i18n("<html><head/><body><p>Select the colour theme of the 3D Graphic.</p></body></html>", nullptr));
#endif // QT_CONFIG(tooltip)
#if QT_CONFIG(tooltip)
        abInsLabels->setToolTip(tr2i18n("<html><head/><body><p>Check to display mosaic tile sensor labels.</p></body></html>", nullptr));
#endif // QT_CONFIG(tooltip)
        abInsLabels->setText(tr2i18n("Labels", nullptr));
#if QT_CONFIG(tooltip)
        abInsSensor->setToolTip(tr2i18n("<html><head/><body><p>Check to display the Sensor.</p></body></html>", nullptr));
#endif // QT_CONFIG(tooltip)
        abInsSensor->setText(tr2i18n("Sensor", nullptr));
#if QT_CONFIG(tooltip)
        abInsPetzvalWire->setToolTip(tr2i18n("<html><head/><body><p>Check to display the Petzval surface mesh.</p></body></html>", nullptr));
#endif // QT_CONFIG(tooltip)
        abInsPetzvalWire->setText(tr2i18n("Petzval Wire", nullptr));
#if QT_CONFIG(tooltip)
        abInsPetzvalSurface->setToolTip(tr2i18n("<html><head/><body><p>Check to display the Petzval surface.</p></body></html>", nullptr));
#endif // QT_CONFIG(tooltip)
        abInsPetzvalSurface->setText(tr2i18n("Petzval Surface", nullptr));
        groupBox->setTitle(QString());
#if QT_CONFIG(tooltip)
        abInsSimMode->setToolTip(tr2i18n("<html><head/><body><p>Check to set 3D Graphic in Simulation Mode</p></body></html>", nullptr));
#endif // QT_CONFIG(tooltip)
        abInsSimMode->setText(tr2i18n("Sim Mode", nullptr));
#if QT_CONFIG(tooltip)
        abInsBackfocusSlider->setToolTip(tr2i18n("<html><head/><body><p>Backfocus slider</p></body></html>", nullptr));
#endif // QT_CONFIG(tooltip)
#if QT_CONFIG(tooltip)
        abInsTiltLRSlider->setToolTip(tr2i18n("<html><head/><body><p>Left-to-Right Tilt Slider</p></body></html>", nullptr));
#endif // QT_CONFIG(tooltip)
#if QT_CONFIG(tooltip)
        abInsTiltTBSlider->setToolTip(tr2i18n("<html><head/><body><p>Top-to-Bottom Tilt Slider</p></body></html>", nullptr));
#endif // QT_CONFIG(tooltip)
    } // retranslateUi

};

namespace Ui {
    class aberrationInspectorDialog: public Ui_aberrationInspectorDialog {};
} // namespace Ui

QT_END_NAMESPACE

#endif // ABERRATIONINSPECTOR_H

