/*
 * This file was generated by qdbusxml2cpp version 0.8
 * Source file was org.kde.kstars.Ekos.Align.xml
 *
 * qdbusxml2cpp is Copyright (C) The Qt Company Ltd. and other contributors.
 *
 * This is an auto-generated file.
 * Do not edit! All changes made to it will be lost.
 */

#include "alignadaptor.h"
#include <QtCore/QMetaObject>
#include <QtCore/QByteArray>
#include <QtCore/QList>
#include <QtCore/QMap>
#include <QtCore/QString>
#include <QtCore/QStringList>
#include <QtCore/QVariant>

/*
 * Implementation of adaptor class AlignAdaptor
 */

AlignAdaptor::AlignAdaptor(Ekos::Align *parent)
    : QDBusAbstractAdaptor(parent)
{
    // constructor
    setAutoRelaySignals(true);
}

AlignAdaptor::~AlignAdaptor()
{
    // destructor
}

QString AlignAdaptor::camera() const
{
    // get the value of property camera
    return qvariant_cast< QString >(parent()->property("camera"));
}

QString AlignAdaptor::filter() const
{
    // get the value of property filter
    return qvariant_cast< QString >(parent()->property("filter"));
}

void AlignAdaptor::setFilter(const QString &value)
{
    // set the value of property filter
    parent()->setProperty("filter", QVariant::fromValue(value));
}

QString AlignAdaptor::filterWheel() const
{
    // get the value of property filterWheel
    return qvariant_cast< QString >(parent()->property("filterWheel"));
}

QList<double> AlignAdaptor::fov() const
{
    // get the value of property fov
    return qvariant_cast< QList<double> >(parent()->property("fov"));
}

QStringList AlignAdaptor::logText() const
{
    // get the value of property logText
    return qvariant_cast< QStringList >(parent()->property("logText"));
}

QString AlignAdaptor::opticalTrain() const
{
    // get the value of property opticalTrain
    return qvariant_cast< QString >(parent()->property("opticalTrain"));
}

void AlignAdaptor::setOpticalTrain(const QString &value)
{
    // set the value of property opticalTrain
    parent()->setProperty("opticalTrain", QVariant::fromValue(value));
}

QString AlignAdaptor::solverArguments() const
{
    // get the value of property solverArguments
    return qvariant_cast< QString >(parent()->property("solverArguments"));
}

void AlignAdaptor::setSolverArguments(const QString &value)
{
    // set the value of property solverArguments
    parent()->setProperty("solverArguments", QVariant::fromValue(value));
}

int AlignAdaptor::status() const
{
    // get the value of property status
    return qvariant_cast< int >(parent()->property("status"));
}

void AlignAdaptor::abort()
{
    // handle method call org.kde.kstars.Ekos.Align.abort
    parent()->abort();
}

QList<double> AlignAdaptor::cameraInfo()
{
    // handle method call org.kde.kstars.Ekos.Align.cameraInfo
    return parent()->cameraInfo();
}

bool AlignAdaptor::captureAndSolve()
{
    // handle method call org.kde.kstars.Ekos.Align.captureAndSolve
    return parent()->captureAndSolve();
}

int AlignAdaptor::getLoadAndSlewStatus()
{
    // handle method call org.kde.kstars.Ekos.Align.getLoadAndSlewStatus
    return parent()->getLoadAndSlewStatus();
}

QList<double> AlignAdaptor::getSolutionResult()
{
    // handle method call org.kde.kstars.Ekos.Align.getSolutionResult
    return parent()->getSolutionResult();
}

QList<double> AlignAdaptor::getTargetCoords()
{
    // handle method call org.kde.kstars.Ekos.Align.getTargetCoords
    return parent()->getTargetCoords();
}

bool AlignAdaptor::loadAndSlew(const QString &fileURL)
{
    // handle method call org.kde.kstars.Ekos.Align.loadAndSlew
    return parent()->loadAndSlew(fileURL);
}

void AlignAdaptor::setBinningIndex(int binningIndex)
{
    // handle method call org.kde.kstars.Ekos.Align.setBinningIndex
    parent()->setBinningIndex(binningIndex);
}

void AlignAdaptor::setSolverAction(int mode)
{
    // handle method call org.kde.kstars.Ekos.Align.setSolverAction
    parent()->setSolverAction(mode);
}

void AlignAdaptor::setSolverMode(uint mode)
{
    // handle method call org.kde.kstars.Ekos.Align.setSolverMode
    parent()->setSolverMode(mode);
}

void AlignAdaptor::setTargetCoords(double ra, double de)
{
    // handle method call org.kde.kstars.Ekos.Align.setTargetCoords
    parent()->setTargetCoords(ra, de);
}

void AlignAdaptor::setTargetPositionAngle(double value)
{
    // handle method call org.kde.kstars.Ekos.Align.setTargetPositionAngle
    parent()->setTargetPositionAngle(value);
}

QList<double> AlignAdaptor::telescopeInfo()
{
    // handle method call org.kde.kstars.Ekos.Align.telescopeInfo
    return parent()->telescopeInfo();
}


#include "moc_alignadaptor.cpp"
