/****************************************************************************
** Meta object code from reading C++ file 'clientmanager.h'
**
** Created by: The Qt Meta Object Compiler version 69 (Qt 6.11.1)
**
** WARNING! All changes made in this file will be lost!
*****************************************************************************/

#include "../../../../kstars-3.8.4.1/kstars/indi/clientmanager.h"
#include <QtCore/qmetatype.h>

#include <QtCore/qtmochelpers.h>

#include <memory>


#include <QtCore/qxptype_traits.h>
#if !defined(Q_MOC_OUTPUT_REVISION)
#error "The header file 'clientmanager.h' doesn't include <QObject>."
#elif Q_MOC_OUTPUT_REVISION != 69
#error "This file was generated using the moc from 6.11.1. It"
#error "cannot be used with the include files from this version of Qt."
#error "(The moc has changed too much.)"
#endif

#ifndef Q_CONSTINIT
#define Q_CONSTINIT
#endif

QT_WARNING_PUSH
QT_WARNING_DISABLE_DEPRECATED
QT_WARNING_DISABLE_GCC("-Wuseless-cast")
namespace {
struct qt_meta_tag_ZN13ClientManagerE_t {};
} // unnamed namespace

template <> constexpr inline auto ClientManager::qt_create_metaobjectdata<qt_meta_tag_ZN13ClientManagerE_t>()
{
    namespace QMC = QtMocConstants;
    QtMocHelpers::StringRefStorage qt_stringData {
        "ClientManager",
        "started",
        "",
        "failed",
        "message",
        "terminated",
        "newINDIDevice",
        "DeviceInfo*",
        "dv",
        "removeINDIDevice",
        "name",
        "newINDIProperty",
        "INDI::Property",
        "prop",
        "updateINDIProperty",
        "removeINDIProperty",
        "newBLOBManager",
        "const char*",
        "device",
        "removeBLOBManager",
        "property",
        "newINDIMessage",
        "INDI::BaseDevice",
        "dp",
        "messageID",
        "newINDIUniversalMessage"
    };

    QtMocHelpers::UintData qt_methods {
        // Signal 'started'
        QtMocHelpers::SignalData<void()>(1, 2, QMC::AccessPublic, QMetaType::Void),
        // Signal 'failed'
        QtMocHelpers::SignalData<void(const QString &)>(3, 2, QMC::AccessPublic, QMetaType::Void, {{
            { QMetaType::QString, 4 },
        }}),
        // Signal 'terminated'
        QtMocHelpers::SignalData<void(const QString &)>(5, 2, QMC::AccessPublic, QMetaType::Void, {{
            { QMetaType::QString, 4 },
        }}),
        // Signal 'newINDIDevice'
        QtMocHelpers::SignalData<void(DeviceInfo *)>(6, 2, QMC::AccessPublic, QMetaType::Void, {{
            { 0x80000000 | 7, 8 },
        }}),
        // Signal 'removeINDIDevice'
        QtMocHelpers::SignalData<void(const QString &)>(9, 2, QMC::AccessPublic, QMetaType::Void, {{
            { QMetaType::QString, 10 },
        }}),
        // Signal 'newINDIProperty'
        QtMocHelpers::SignalData<void(INDI::Property)>(11, 2, QMC::AccessPublic, QMetaType::Void, {{
            { 0x80000000 | 12, 13 },
        }}),
        // Signal 'updateINDIProperty'
        QtMocHelpers::SignalData<void(INDI::Property)>(14, 2, QMC::AccessPublic, QMetaType::Void, {{
            { 0x80000000 | 12, 13 },
        }}),
        // Signal 'removeINDIProperty'
        QtMocHelpers::SignalData<void(INDI::Property)>(15, 2, QMC::AccessPublic, QMetaType::Void, {{
            { 0x80000000 | 12, 13 },
        }}),
        // Signal 'newBLOBManager'
        QtMocHelpers::SignalData<void(const char *, INDI::Property)>(16, 2, QMC::AccessPublic, QMetaType::Void, {{
            { 0x80000000 | 17, 18 }, { 0x80000000 | 12, 13 },
        }}),
        // Signal 'removeBLOBManager'
        QtMocHelpers::SignalData<void(const QString &, const QString &)>(19, 2, QMC::AccessPublic, QMetaType::Void, {{
            { QMetaType::QString, 18 }, { QMetaType::QString, 20 },
        }}),
        // Signal 'newINDIMessage'
        QtMocHelpers::SignalData<void(INDI::BaseDevice, int)>(21, 2, QMC::AccessPublic, QMetaType::Void, {{
            { 0x80000000 | 22, 23 }, { QMetaType::Int, 24 },
        }}),
        // Signal 'newINDIUniversalMessage'
        QtMocHelpers::SignalData<void(const QString &)>(25, 2, QMC::AccessPublic, QMetaType::Void, {{
            { QMetaType::QString, 4 },
        }}),
    };
    QtMocHelpers::UintData qt_properties {
    };
    QtMocHelpers::UintData qt_enums {
    };
    return QtMocHelpers::metaObjectData<ClientManager, qt_meta_tag_ZN13ClientManagerE_t>(QMC::MetaObjectFlag{}, qt_stringData,
            qt_methods, qt_properties, qt_enums);
}
Q_CONSTINIT const QMetaObject ClientManager::staticMetaObject = { {
    QMetaObject::SuperData::link<QObject::staticMetaObject>(),
    qt_staticMetaObjectStaticContent<qt_meta_tag_ZN13ClientManagerE_t>.stringdata,
    qt_staticMetaObjectStaticContent<qt_meta_tag_ZN13ClientManagerE_t>.data,
    qt_static_metacall,
    nullptr,
    qt_staticMetaObjectRelocatingContent<qt_meta_tag_ZN13ClientManagerE_t>.metaTypes,
    nullptr
} };

void ClientManager::qt_static_metacall(QObject *_o, QMetaObject::Call _c, int _id, void **_a)
{
    auto *_t = static_cast<ClientManager *>(_o);
    if (_c == QMetaObject::InvokeMetaMethod) {
        switch (_id) {
        case 0: _t->started(); break;
        case 1: _t->failed((*reinterpret_cast<std::add_pointer_t<QString>>(_a[1]))); break;
        case 2: _t->terminated((*reinterpret_cast<std::add_pointer_t<QString>>(_a[1]))); break;
        case 3: _t->newINDIDevice((*reinterpret_cast<std::add_pointer_t<DeviceInfo*>>(_a[1]))); break;
        case 4: _t->removeINDIDevice((*reinterpret_cast<std::add_pointer_t<QString>>(_a[1]))); break;
        case 5: _t->newINDIProperty((*reinterpret_cast<std::add_pointer_t<INDI::Property>>(_a[1]))); break;
        case 6: _t->updateINDIProperty((*reinterpret_cast<std::add_pointer_t<INDI::Property>>(_a[1]))); break;
        case 7: _t->removeINDIProperty((*reinterpret_cast<std::add_pointer_t<INDI::Property>>(_a[1]))); break;
        case 8: _t->newBLOBManager((*reinterpret_cast<std::add_pointer_t<const char*>>(_a[1])),(*reinterpret_cast<std::add_pointer_t<INDI::Property>>(_a[2]))); break;
        case 9: _t->removeBLOBManager((*reinterpret_cast<std::add_pointer_t<QString>>(_a[1])),(*reinterpret_cast<std::add_pointer_t<QString>>(_a[2]))); break;
        case 10: _t->newINDIMessage((*reinterpret_cast<std::add_pointer_t<INDI::BaseDevice>>(_a[1])),(*reinterpret_cast<std::add_pointer_t<int>>(_a[2]))); break;
        case 11: _t->newINDIUniversalMessage((*reinterpret_cast<std::add_pointer_t<QString>>(_a[1]))); break;
        default: ;
        }
    }
    if (_c == QMetaObject::RegisterMethodArgumentMetaType) {
        switch (_id) {
        default: *reinterpret_cast<QMetaType *>(_a[0]) = QMetaType(); break;
        case 5:
            switch (*reinterpret_cast<int*>(_a[1])) {
            default: *reinterpret_cast<QMetaType *>(_a[0]) = QMetaType(); break;
            case 0:
                *reinterpret_cast<QMetaType *>(_a[0]) = QMetaType::fromType< INDI::Property >(); break;
            }
            break;
        case 6:
            switch (*reinterpret_cast<int*>(_a[1])) {
            default: *reinterpret_cast<QMetaType *>(_a[0]) = QMetaType(); break;
            case 0:
                *reinterpret_cast<QMetaType *>(_a[0]) = QMetaType::fromType< INDI::Property >(); break;
            }
            break;
        case 7:
            switch (*reinterpret_cast<int*>(_a[1])) {
            default: *reinterpret_cast<QMetaType *>(_a[0]) = QMetaType(); break;
            case 0:
                *reinterpret_cast<QMetaType *>(_a[0]) = QMetaType::fromType< INDI::Property >(); break;
            }
            break;
        case 8:
            switch (*reinterpret_cast<int*>(_a[1])) {
            default: *reinterpret_cast<QMetaType *>(_a[0]) = QMetaType(); break;
            case 1:
                *reinterpret_cast<QMetaType *>(_a[0]) = QMetaType::fromType< INDI::Property >(); break;
            }
            break;
        }
    }
    if (_c == QMetaObject::IndexOfMethod) {
        if (QtMocHelpers::indexOfMethod<void (ClientManager::*)()>(_a, &ClientManager::started, 0))
            return;
        if (QtMocHelpers::indexOfMethod<void (ClientManager::*)(const QString & )>(_a, &ClientManager::failed, 1))
            return;
        if (QtMocHelpers::indexOfMethod<void (ClientManager::*)(const QString & )>(_a, &ClientManager::terminated, 2))
            return;
        if (QtMocHelpers::indexOfMethod<void (ClientManager::*)(DeviceInfo * )>(_a, &ClientManager::newINDIDevice, 3))
            return;
        if (QtMocHelpers::indexOfMethod<void (ClientManager::*)(const QString & )>(_a, &ClientManager::removeINDIDevice, 4))
            return;
        if (QtMocHelpers::indexOfMethod<void (ClientManager::*)(INDI::Property )>(_a, &ClientManager::newINDIProperty, 5))
            return;
        if (QtMocHelpers::indexOfMethod<void (ClientManager::*)(INDI::Property )>(_a, &ClientManager::updateINDIProperty, 6))
            return;
        if (QtMocHelpers::indexOfMethod<void (ClientManager::*)(INDI::Property )>(_a, &ClientManager::removeINDIProperty, 7))
            return;
        if (QtMocHelpers::indexOfMethod<void (ClientManager::*)(const char * , INDI::Property )>(_a, &ClientManager::newBLOBManager, 8))
            return;
        if (QtMocHelpers::indexOfMethod<void (ClientManager::*)(const QString & , const QString & )>(_a, &ClientManager::removeBLOBManager, 9))
            return;
        if (QtMocHelpers::indexOfMethod<void (ClientManager::*)(INDI::BaseDevice , int )>(_a, &ClientManager::newINDIMessage, 10))
            return;
        if (QtMocHelpers::indexOfMethod<void (ClientManager::*)(const QString & )>(_a, &ClientManager::newINDIUniversalMessage, 11))
            return;
    }
}

const QMetaObject *ClientManager::metaObject() const
{
    return QObject::d_ptr->metaObject ? QObject::d_ptr->dynamicMetaObject() : &staticMetaObject;
}

void *ClientManager::qt_metacast(const char *_clname)
{
    if (!_clname) return nullptr;
    if (!strcmp(_clname, qt_staticMetaObjectStaticContent<qt_meta_tag_ZN13ClientManagerE_t>.strings))
        return static_cast<void*>(this);
    if (!strcmp(_clname, "INDI::BaseClient"))
        return static_cast< INDI::BaseClient*>(this);
    return QObject::qt_metacast(_clname);
}

int ClientManager::qt_metacall(QMetaObject::Call _c, int _id, void **_a)
{
    _id = QObject::qt_metacall(_c, _id, _a);
    if (_id < 0)
        return _id;
    if (_c == QMetaObject::InvokeMetaMethod) {
        if (_id < 12)
            qt_static_metacall(this, _c, _id, _a);
        _id -= 12;
    }
    if (_c == QMetaObject::RegisterMethodArgumentMetaType) {
        if (_id < 12)
            qt_static_metacall(this, _c, _id, _a);
        _id -= 12;
    }
    return _id;
}

// SIGNAL 0
void ClientManager::started()
{
    QMetaObject::activate(this, &staticMetaObject, 0, nullptr);
}

// SIGNAL 1
void ClientManager::failed(const QString & _t1)
{
    QMetaObject::activate<void>(this, &staticMetaObject, 1, nullptr, _t1);
}

// SIGNAL 2
void ClientManager::terminated(const QString & _t1)
{
    QMetaObject::activate<void>(this, &staticMetaObject, 2, nullptr, _t1);
}

// SIGNAL 3
void ClientManager::newINDIDevice(DeviceInfo * _t1)
{
    QMetaObject::activate<void>(this, &staticMetaObject, 3, nullptr, _t1);
}

// SIGNAL 4
void ClientManager::removeINDIDevice(const QString & _t1)
{
    QMetaObject::activate<void>(this, &staticMetaObject, 4, nullptr, _t1);
}

// SIGNAL 5
void ClientManager::newINDIProperty(INDI::Property _t1)
{
    QMetaObject::activate<void>(this, &staticMetaObject, 5, nullptr, _t1);
}

// SIGNAL 6
void ClientManager::updateINDIProperty(INDI::Property _t1)
{
    QMetaObject::activate<void>(this, &staticMetaObject, 6, nullptr, _t1);
}

// SIGNAL 7
void ClientManager::removeINDIProperty(INDI::Property _t1)
{
    QMetaObject::activate<void>(this, &staticMetaObject, 7, nullptr, _t1);
}

// SIGNAL 8
void ClientManager::newBLOBManager(const char * _t1, INDI::Property _t2)
{
    QMetaObject::activate<void>(this, &staticMetaObject, 8, nullptr, _t1, _t2);
}

// SIGNAL 9
void ClientManager::removeBLOBManager(const QString & _t1, const QString & _t2)
{
    QMetaObject::activate<void>(this, &staticMetaObject, 9, nullptr, _t1, _t2);
}

// SIGNAL 10
void ClientManager::newINDIMessage(INDI::BaseDevice _t1, int _t2)
{
    QMetaObject::activate<void>(this, &staticMetaObject, 10, nullptr, _t1, _t2);
}

// SIGNAL 11
void ClientManager::newINDIUniversalMessage(const QString & _t1)
{
    QMetaObject::activate<void>(this, &staticMetaObject, 11, nullptr, _t1);
}
QT_WARNING_POP
