/********************************************************************************
** Form generated from reading UI file 'modcalcplanets.ui'
**
** Created by: Qt User Interface Compiler version 6.11.1
**
** WARNING! All changes made in this file will be lost when recompiling UI file!
********************************************************************************/

#ifndef UI_MODCALCPLANETS_H
#define UI_MODCALCPLANETS_H

#include <QtCore/QVariant>
#include <QtWidgets/QApplication>
#include <QtWidgets/QCheckBox>
#include <QtWidgets/QComboBox>
#include <QtWidgets/QDateEdit>
#include <QtWidgets/QDateTimeEdit>
#include <QtWidgets/QGridLayout>
#include <QtWidgets/QGroupBox>
#include <QtWidgets/QHBoxLayout>
#include <QtWidgets/QLabel>
#include <QtWidgets/QLineEdit>
#include <QtWidgets/QPushButton>
#include <QtWidgets/QRadioButton>
#include <QtWidgets/QSpacerItem>
#include <QtWidgets/QTabWidget>
#include <QtWidgets/QTimeEdit>
#include <QtWidgets/QVBoxLayout>
#include <QtWidgets/QWidget>
#include <klocalizedstring.h>
#include "kurlrequester.h"
#include "widgets/dmsbox.h"

QT_BEGIN_NAMESPACE

class Ui_modCalcPlanetsDlg
{
public:
    QVBoxLayout *vboxLayout;
    QTabWidget *tabWidget;
    QWidget *interact;
    QVBoxLayout *vboxLayout1;
    QGroupBox *groupBox;
    QHBoxLayout *hboxLayout;
    QGridLayout *gridLayout;
    QLabel *label;
    QPushButton *LocationButton;
    QLabel *textLabel1;
    QSpacerItem *spacerItem;
    QComboBox *PlanetComboBox;
    QDateTimeEdit *DateTimeBox;
    QHBoxLayout *hboxLayout1;
    QGroupBox *groupBox_2;
    QGridLayout *gridLayout1;
    QLabel *label_6;
    QLabel *label_5;
    dmsBox *RABox;
    dmsBox *DecBox;
    QGroupBox *groupBox_3;
    QGridLayout *gridLayout2;
    QLabel *label_8;
    QLabel *label_7;
    dmsBox *AzBox;
    dmsBox *AltBox;
    QHBoxLayout *hboxLayout2;
    QGroupBox *groupBox_4;
    QGridLayout *gridLayout3;
    QLineEdit *HelioDistBox;
    QLabel *label_11;
    QLabel *label_10;
    QLabel *label_9;
    dmsBox *HelioLongBox;
    dmsBox *HelioLatBox;
    QGroupBox *groupBox_5;
    QGridLayout *gridLayout4;
    QLineEdit *GeoDistBox;
    dmsBox *GeoLatBox;
    QLabel *label_13;
    QLabel *label_14;
    QLabel *label_12;
    dmsBox *GeoLongBox;
    QSpacerItem *spacerItem1;
    QWidget *batch;
    QVBoxLayout *vboxLayout2;
    QGroupBox *groupBox_6;
    QVBoxLayout *vboxLayout3;
    QHBoxLayout *hboxLayout3;
    QCheckBox *PlanetCheckBatch;
    QComboBox *PlanetComboBoxBatch;
    QSpacerItem *spacerItem2;
    QHBoxLayout *hboxLayout4;
    QGridLayout *gridLayout5;
    QCheckBox *UTCheckBatch;
    QTimeEdit *UTBoxBatch;
    QCheckBox *DateCheckBatch;
    QDateEdit *DateBoxBatch;
    QSpacerItem *spacerItem3;
    QGridLayout *gridLayout6;
    QCheckBox *LatCheckBatch;
    QCheckBox *LongCheckBatch;
    dmsBox *LongBoxBatch;
    dmsBox *LatBoxBatch;
    QGroupBox *groupBox_7;
    QGridLayout *gridLayout7;
    QCheckBox *HelioEclCheckBatch;
    QCheckBox *EquatorialCheckBatch;
    QCheckBox *GeoEclCheckBatch;
    QCheckBox *HorizontalCheckBatch;
    QGroupBox *groupBox_8;
    QHBoxLayout *hboxLayout5;
    QRadioButton *AllRadioBatch;
    QRadioButton *InputRadioBatch;
    QGroupBox *groupBox_9;
    QGridLayout *gridLayout8;
    QLabel *label_15;
    KUrlRequester *InputFileBoxBatch;
    QLabel *label_16;
    KUrlRequester *OutputFileBoxBatch;
    QHBoxLayout *horizontalLayout_4;
    QSpacerItem *horizontalSpacer;
    QPushButton *RunButtonBatch;
    QSpacerItem *horizontalSpacer_2;
    QSpacerItem *verticalSpacer;

    void setupUi(QWidget *modCalcPlanetsDlg)
    {
        if (modCalcPlanetsDlg->objectName().isEmpty())
            modCalcPlanetsDlg->setObjectName("modCalcPlanetsDlg");
        modCalcPlanetsDlg->resize(549, 542);
        vboxLayout = new QVBoxLayout(modCalcPlanetsDlg);
        vboxLayout->setSpacing(6);
        vboxLayout->setObjectName("vboxLayout");
        vboxLayout->setContentsMargins(9, 9, 9, 9);
        tabWidget = new QTabWidget(modCalcPlanetsDlg);
        tabWidget->setObjectName("tabWidget");
        interact = new QWidget();
        interact->setObjectName("interact");
        vboxLayout1 = new QVBoxLayout(interact);
        vboxLayout1->setSpacing(6);
        vboxLayout1->setObjectName("vboxLayout1");
        vboxLayout1->setContentsMargins(9, 9, 9, 9);
        groupBox = new QGroupBox(interact);
        groupBox->setObjectName("groupBox");
        hboxLayout = new QHBoxLayout(groupBox);
        hboxLayout->setSpacing(6);
        hboxLayout->setObjectName("hboxLayout");
        hboxLayout->setContentsMargins(9, 9, 9, 9);
        gridLayout = new QGridLayout();
        gridLayout->setSpacing(6);
        gridLayout->setObjectName("gridLayout");
        gridLayout->setContentsMargins(0, 0, 0, 0);
        label = new QLabel(groupBox);
        label->setObjectName("label");

        gridLayout->addWidget(label, 1, 0, 1, 1);

        LocationButton = new QPushButton(groupBox);
        LocationButton->setObjectName("LocationButton");

        gridLayout->addWidget(LocationButton, 0, 0, 1, 3);

        textLabel1 = new QLabel(groupBox);
        textLabel1->setObjectName("textLabel1");
        QSizePolicy sizePolicy(QSizePolicy::Policy::Minimum, QSizePolicy::Policy::Preferred);
        sizePolicy.setHorizontalStretch(0);
        sizePolicy.setVerticalStretch(0);
        sizePolicy.setHeightForWidth(textLabel1->sizePolicy().hasHeightForWidth());
        textLabel1->setSizePolicy(sizePolicy);

        gridLayout->addWidget(textLabel1, 2, 0, 1, 1);

        spacerItem = new QSpacerItem(151, 21, QSizePolicy::Policy::Expanding, QSizePolicy::Policy::Minimum);

        gridLayout->addItem(spacerItem, 2, 2, 1, 1);

        PlanetComboBox = new QComboBox(groupBox);
        PlanetComboBox->addItem(QString());
        PlanetComboBox->addItem(QString());
        PlanetComboBox->addItem(QString());
        PlanetComboBox->addItem(QString());
        PlanetComboBox->addItem(QString());
        PlanetComboBox->addItem(QString());
        PlanetComboBox->addItem(QString());
        PlanetComboBox->addItem(QString());
        PlanetComboBox->addItem(QString());
        PlanetComboBox->addItem(QString());
        PlanetComboBox->setObjectName("PlanetComboBox");
        QSizePolicy sizePolicy1(QSizePolicy::Policy::Preferred, QSizePolicy::Policy::Fixed);
        sizePolicy1.setHorizontalStretch(0);
        sizePolicy1.setVerticalStretch(0);
        sizePolicy1.setHeightForWidth(PlanetComboBox->sizePolicy().hasHeightForWidth());
        PlanetComboBox->setSizePolicy(sizePolicy1);

        gridLayout->addWidget(PlanetComboBox, 2, 1, 1, 1);

        DateTimeBox = new QDateTimeEdit(groupBox);
        DateTimeBox->setObjectName("DateTimeBox");

        gridLayout->addWidget(DateTimeBox, 1, 1, 1, 2);


        hboxLayout->addLayout(gridLayout);


        vboxLayout1->addWidget(groupBox);

        hboxLayout1 = new QHBoxLayout();
        hboxLayout1->setSpacing(6);
        hboxLayout1->setObjectName("hboxLayout1");
        hboxLayout1->setContentsMargins(0, 0, 0, 0);
        groupBox_2 = new QGroupBox(interact);
        groupBox_2->setObjectName("groupBox_2");
        gridLayout1 = new QGridLayout(groupBox_2);
        gridLayout1->setSpacing(6);
        gridLayout1->setObjectName("gridLayout1");
        gridLayout1->setContentsMargins(9, 9, 9, 9);
        label_6 = new QLabel(groupBox_2);
        label_6->setObjectName("label_6");

        gridLayout1->addWidget(label_6, 1, 0, 1, 1);

        label_5 = new QLabel(groupBox_2);
        label_5->setObjectName("label_5");

        gridLayout1->addWidget(label_5, 0, 0, 1, 1);

        RABox = new dmsBox(groupBox_2);
        RABox->setObjectName("RABox");
        RABox->setReadOnly(true);

        gridLayout1->addWidget(RABox, 0, 1, 1, 1);

        DecBox = new dmsBox(groupBox_2);
        DecBox->setObjectName("DecBox");
        DecBox->setReadOnly(true);

        gridLayout1->addWidget(DecBox, 1, 1, 1, 1);


        hboxLayout1->addWidget(groupBox_2);

        groupBox_3 = new QGroupBox(interact);
        groupBox_3->setObjectName("groupBox_3");
        gridLayout2 = new QGridLayout(groupBox_3);
        gridLayout2->setSpacing(6);
        gridLayout2->setObjectName("gridLayout2");
        gridLayout2->setContentsMargins(9, 9, 9, 9);
        label_8 = new QLabel(groupBox_3);
        label_8->setObjectName("label_8");

        gridLayout2->addWidget(label_8, 1, 0, 1, 1);

        label_7 = new QLabel(groupBox_3);
        label_7->setObjectName("label_7");

        gridLayout2->addWidget(label_7, 0, 0, 1, 1);

        AzBox = new dmsBox(groupBox_3);
        AzBox->setObjectName("AzBox");
        AzBox->setReadOnly(true);

        gridLayout2->addWidget(AzBox, 0, 1, 1, 1);

        AltBox = new dmsBox(groupBox_3);
        AltBox->setObjectName("AltBox");
        AltBox->setReadOnly(true);

        gridLayout2->addWidget(AltBox, 1, 1, 1, 1);


        hboxLayout1->addWidget(groupBox_3);


        vboxLayout1->addLayout(hboxLayout1);

        hboxLayout2 = new QHBoxLayout();
        hboxLayout2->setSpacing(6);
        hboxLayout2->setObjectName("hboxLayout2");
        hboxLayout2->setContentsMargins(0, 0, 0, 0);
        groupBox_4 = new QGroupBox(interact);
        groupBox_4->setObjectName("groupBox_4");
        gridLayout3 = new QGridLayout(groupBox_4);
        gridLayout3->setSpacing(6);
        gridLayout3->setObjectName("gridLayout3");
        gridLayout3->setContentsMargins(9, 9, 9, 9);
        HelioDistBox = new QLineEdit(groupBox_4);
        HelioDistBox->setObjectName("HelioDistBox");
        HelioDistBox->setReadOnly(true);

        gridLayout3->addWidget(HelioDistBox, 2, 2, 1, 1);

        label_11 = new QLabel(groupBox_4);
        label_11->setObjectName("label_11");

        gridLayout3->addWidget(label_11, 2, 0, 1, 2);

        label_10 = new QLabel(groupBox_4);
        label_10->setObjectName("label_10");

        gridLayout3->addWidget(label_10, 1, 0, 1, 1);

        label_9 = new QLabel(groupBox_4);
        label_9->setObjectName("label_9");

        gridLayout3->addWidget(label_9, 0, 0, 1, 1);

        HelioLongBox = new dmsBox(groupBox_4);
        HelioLongBox->setObjectName("HelioLongBox");
        HelioLongBox->setReadOnly(true);

        gridLayout3->addWidget(HelioLongBox, 0, 1, 1, 2);

        HelioLatBox = new dmsBox(groupBox_4);
        HelioLatBox->setObjectName("HelioLatBox");
        HelioLatBox->setReadOnly(true);

        gridLayout3->addWidget(HelioLatBox, 1, 1, 1, 2);


        hboxLayout2->addWidget(groupBox_4);

        groupBox_5 = new QGroupBox(interact);
        groupBox_5->setObjectName("groupBox_5");
        gridLayout4 = new QGridLayout(groupBox_5);
        gridLayout4->setSpacing(6);
        gridLayout4->setObjectName("gridLayout4");
        gridLayout4->setContentsMargins(9, 9, 9, 9);
        GeoDistBox = new QLineEdit(groupBox_5);
        GeoDistBox->setObjectName("GeoDistBox");
        GeoDistBox->setReadOnly(true);

        gridLayout4->addWidget(GeoDistBox, 2, 2, 1, 1);

        GeoLatBox = new dmsBox(groupBox_5);
        GeoLatBox->setObjectName("GeoLatBox");
        GeoLatBox->setReadOnly(true);

        gridLayout4->addWidget(GeoLatBox, 1, 1, 1, 2);

        label_13 = new QLabel(groupBox_5);
        label_13->setObjectName("label_13");

        gridLayout4->addWidget(label_13, 0, 0, 1, 1);

        label_14 = new QLabel(groupBox_5);
        label_14->setObjectName("label_14");

        gridLayout4->addWidget(label_14, 1, 0, 1, 1);

        label_12 = new QLabel(groupBox_5);
        label_12->setObjectName("label_12");

        gridLayout4->addWidget(label_12, 2, 0, 1, 2);

        GeoLongBox = new dmsBox(groupBox_5);
        GeoLongBox->setObjectName("GeoLongBox");
        GeoLongBox->setReadOnly(true);

        gridLayout4->addWidget(GeoLongBox, 0, 1, 1, 2);


        hboxLayout2->addWidget(groupBox_5);


        vboxLayout1->addLayout(hboxLayout2);

        spacerItem1 = new QSpacerItem(20, 16, QSizePolicy::Policy::Minimum, QSizePolicy::Policy::Expanding);

        vboxLayout1->addItem(spacerItem1);

        tabWidget->addTab(interact, QString());
        batch = new QWidget();
        batch->setObjectName("batch");
        vboxLayout2 = new QVBoxLayout(batch);
        vboxLayout2->setSpacing(6);
        vboxLayout2->setObjectName("vboxLayout2");
        vboxLayout2->setContentsMargins(9, 9, 9, 9);
        groupBox_6 = new QGroupBox(batch);
        groupBox_6->setObjectName("groupBox_6");
        vboxLayout3 = new QVBoxLayout(groupBox_6);
        vboxLayout3->setSpacing(6);
        vboxLayout3->setObjectName("vboxLayout3");
        vboxLayout3->setContentsMargins(9, 9, 9, 9);
        hboxLayout3 = new QHBoxLayout();
        hboxLayout3->setSpacing(6);
        hboxLayout3->setObjectName("hboxLayout3");
        hboxLayout3->setContentsMargins(0, 0, 0, 0);
        PlanetCheckBatch = new QCheckBox(groupBox_6);
        PlanetCheckBatch->setObjectName("PlanetCheckBatch");
        PlanetCheckBatch->setChecked(false);

        hboxLayout3->addWidget(PlanetCheckBatch);

        PlanetComboBoxBatch = new QComboBox(groupBox_6);
        PlanetComboBoxBatch->addItem(QString());
        PlanetComboBoxBatch->addItem(QString());
        PlanetComboBoxBatch->addItem(QString());
        PlanetComboBoxBatch->addItem(QString());
        PlanetComboBoxBatch->addItem(QString());
        PlanetComboBoxBatch->addItem(QString());
        PlanetComboBoxBatch->addItem(QString());
        PlanetComboBoxBatch->addItem(QString());
        PlanetComboBoxBatch->addItem(QString());
        PlanetComboBoxBatch->addItem(QString());
        PlanetComboBoxBatch->addItem(QString());
        PlanetComboBoxBatch->setObjectName("PlanetComboBoxBatch");

        hboxLayout3->addWidget(PlanetComboBoxBatch);

        spacerItem2 = new QSpacerItem(40, 20, QSizePolicy::Policy::Expanding, QSizePolicy::Policy::Minimum);

        hboxLayout3->addItem(spacerItem2);


        vboxLayout3->addLayout(hboxLayout3);

        hboxLayout4 = new QHBoxLayout();
        hboxLayout4->setSpacing(6);
        hboxLayout4->setObjectName("hboxLayout4");
        hboxLayout4->setContentsMargins(0, 0, 0, 0);
        gridLayout5 = new QGridLayout();
        gridLayout5->setSpacing(6);
        gridLayout5->setObjectName("gridLayout5");
        gridLayout5->setContentsMargins(0, 0, 0, 0);
        UTCheckBatch = new QCheckBox(groupBox_6);
        UTCheckBatch->setObjectName("UTCheckBatch");
        UTCheckBatch->setChecked(false);

        gridLayout5->addWidget(UTCheckBatch, 0, 0, 1, 1);

        UTBoxBatch = new QTimeEdit(groupBox_6);
        UTBoxBatch->setObjectName("UTBoxBatch");

        gridLayout5->addWidget(UTBoxBatch, 0, 1, 1, 1);

        DateCheckBatch = new QCheckBox(groupBox_6);
        DateCheckBatch->setObjectName("DateCheckBatch");
        DateCheckBatch->setChecked(false);

        gridLayout5->addWidget(DateCheckBatch, 1, 0, 1, 1);

        DateBoxBatch = new QDateEdit(groupBox_6);
        DateBoxBatch->setObjectName("DateBoxBatch");

        gridLayout5->addWidget(DateBoxBatch, 1, 1, 1, 1);


        hboxLayout4->addLayout(gridLayout5);

        spacerItem3 = new QSpacerItem(40, 20, QSizePolicy::Policy::Expanding, QSizePolicy::Policy::Minimum);

        hboxLayout4->addItem(spacerItem3);

        gridLayout6 = new QGridLayout();
        gridLayout6->setSpacing(6);
        gridLayout6->setObjectName("gridLayout6");
        gridLayout6->setContentsMargins(0, 0, 0, 0);
        LatCheckBatch = new QCheckBox(groupBox_6);
        LatCheckBatch->setObjectName("LatCheckBatch");
        LatCheckBatch->setChecked(false);

        gridLayout6->addWidget(LatCheckBatch, 1, 0, 1, 1);

        LongCheckBatch = new QCheckBox(groupBox_6);
        LongCheckBatch->setObjectName("LongCheckBatch");
        LongCheckBatch->setChecked(false);

        gridLayout6->addWidget(LongCheckBatch, 0, 0, 1, 1);

        LongBoxBatch = new dmsBox(groupBox_6);
        LongBoxBatch->setObjectName("LongBoxBatch");

        gridLayout6->addWidget(LongBoxBatch, 0, 1, 1, 1);

        LatBoxBatch = new dmsBox(groupBox_6);
        LatBoxBatch->setObjectName("LatBoxBatch");

        gridLayout6->addWidget(LatBoxBatch, 1, 1, 1, 1);


        hboxLayout4->addLayout(gridLayout6);


        vboxLayout3->addLayout(hboxLayout4);


        vboxLayout2->addWidget(groupBox_6);

        groupBox_7 = new QGroupBox(batch);
        groupBox_7->setObjectName("groupBox_7");
        gridLayout7 = new QGridLayout(groupBox_7);
        gridLayout7->setSpacing(6);
        gridLayout7->setObjectName("gridLayout7");
        gridLayout7->setContentsMargins(9, 9, 9, 9);
        HelioEclCheckBatch = new QCheckBox(groupBox_7);
        HelioEclCheckBatch->setObjectName("HelioEclCheckBatch");
        HelioEclCheckBatch->setChecked(false);

        gridLayout7->addWidget(HelioEclCheckBatch, 0, 0, 1, 1);

        EquatorialCheckBatch = new QCheckBox(groupBox_7);
        EquatorialCheckBatch->setObjectName("EquatorialCheckBatch");
        EquatorialCheckBatch->setChecked(true);

        gridLayout7->addWidget(EquatorialCheckBatch, 0, 1, 1, 1);

        GeoEclCheckBatch = new QCheckBox(groupBox_7);
        GeoEclCheckBatch->setObjectName("GeoEclCheckBatch");
        GeoEclCheckBatch->setChecked(false);

        gridLayout7->addWidget(GeoEclCheckBatch, 1, 0, 1, 1);

        HorizontalCheckBatch = new QCheckBox(groupBox_7);
        HorizontalCheckBatch->setObjectName("HorizontalCheckBatch");
        HorizontalCheckBatch->setChecked(false);

        gridLayout7->addWidget(HorizontalCheckBatch, 1, 1, 1, 1);


        vboxLayout2->addWidget(groupBox_7);

        groupBox_8 = new QGroupBox(batch);
        groupBox_8->setObjectName("groupBox_8");
        hboxLayout5 = new QHBoxLayout(groupBox_8);
        hboxLayout5->setSpacing(6);
        hboxLayout5->setObjectName("hboxLayout5");
        hboxLayout5->setContentsMargins(9, 9, 9, 9);
        AllRadioBatch = new QRadioButton(groupBox_8);
        AllRadioBatch->setObjectName("AllRadioBatch");

        hboxLayout5->addWidget(AllRadioBatch);

        InputRadioBatch = new QRadioButton(groupBox_8);
        InputRadioBatch->setObjectName("InputRadioBatch");
        InputRadioBatch->setChecked(true);

        hboxLayout5->addWidget(InputRadioBatch);


        vboxLayout2->addWidget(groupBox_8);

        groupBox_9 = new QGroupBox(batch);
        groupBox_9->setObjectName("groupBox_9");
        gridLayout8 = new QGridLayout(groupBox_9);
        gridLayout8->setSpacing(6);
        gridLayout8->setObjectName("gridLayout8");
        gridLayout8->setContentsMargins(9, 9, 9, 9);
        label_15 = new QLabel(groupBox_9);
        label_15->setObjectName("label_15");

        gridLayout8->addWidget(label_15, 0, 0, 1, 1);

        InputFileBoxBatch = new KUrlRequester(groupBox_9);
        InputFileBoxBatch->setObjectName("InputFileBoxBatch");

        gridLayout8->addWidget(InputFileBoxBatch, 0, 1, 1, 1);

        label_16 = new QLabel(groupBox_9);
        label_16->setObjectName("label_16");

        gridLayout8->addWidget(label_16, 1, 0, 1, 1);

        OutputFileBoxBatch = new KUrlRequester(groupBox_9);
        OutputFileBoxBatch->setObjectName("OutputFileBoxBatch");

        gridLayout8->addWidget(OutputFileBoxBatch, 1, 1, 1, 1);


        vboxLayout2->addWidget(groupBox_9);

        horizontalLayout_4 = new QHBoxLayout();
        horizontalLayout_4->setObjectName("horizontalLayout_4");
        horizontalSpacer = new QSpacerItem(151, 21, QSizePolicy::Policy::Expanding, QSizePolicy::Policy::Minimum);

        horizontalLayout_4->addItem(horizontalSpacer);

        RunButtonBatch = new QPushButton(batch);
        RunButtonBatch->setObjectName("RunButtonBatch");
        QSizePolicy sizePolicy2(QSizePolicy::Policy::Expanding, QSizePolicy::Policy::Preferred);
        sizePolicy2.setHorizontalStretch(0);
        sizePolicy2.setVerticalStretch(0);
        sizePolicy2.setHeightForWidth(RunButtonBatch->sizePolicy().hasHeightForWidth());
        RunButtonBatch->setSizePolicy(sizePolicy2);

        horizontalLayout_4->addWidget(RunButtonBatch);

        horizontalSpacer_2 = new QSpacerItem(131, 21, QSizePolicy::Policy::Expanding, QSizePolicy::Policy::Minimum);

        horizontalLayout_4->addItem(horizontalSpacer_2);


        vboxLayout2->addLayout(horizontalLayout_4);

        verticalSpacer = new QSpacerItem(20, 40, QSizePolicy::Policy::Minimum, QSizePolicy::Policy::Expanding);

        vboxLayout2->addItem(verticalSpacer);

        tabWidget->addTab(batch, QString());

        vboxLayout->addWidget(tabWidget);

        QWidget::setTabOrder(tabWidget, LocationButton);
        QWidget::setTabOrder(LocationButton, PlanetComboBox);
        QWidget::setTabOrder(PlanetComboBox, RABox);
        QWidget::setTabOrder(RABox, DecBox);
        QWidget::setTabOrder(DecBox, AzBox);
        QWidget::setTabOrder(AzBox, AltBox);
        QWidget::setTabOrder(AltBox, HelioLongBox);
        QWidget::setTabOrder(HelioLongBox, HelioLatBox);
        QWidget::setTabOrder(HelioLatBox, HelioDistBox);
        QWidget::setTabOrder(HelioDistBox, GeoLongBox);
        QWidget::setTabOrder(GeoLongBox, GeoLatBox);
        QWidget::setTabOrder(GeoLatBox, GeoDistBox);
        QWidget::setTabOrder(GeoDistBox, PlanetComboBoxBatch);
        QWidget::setTabOrder(PlanetComboBoxBatch, UTCheckBatch);
        QWidget::setTabOrder(UTCheckBatch, UTBoxBatch);
        QWidget::setTabOrder(UTBoxBatch, DateCheckBatch);
        QWidget::setTabOrder(DateCheckBatch, LatCheckBatch);
        QWidget::setTabOrder(LatCheckBatch, LongCheckBatch);
        QWidget::setTabOrder(LongCheckBatch, LongBoxBatch);
        QWidget::setTabOrder(LongBoxBatch, LatBoxBatch);
        QWidget::setTabOrder(LatBoxBatch, HelioEclCheckBatch);
        QWidget::setTabOrder(HelioEclCheckBatch, EquatorialCheckBatch);
        QWidget::setTabOrder(EquatorialCheckBatch, GeoEclCheckBatch);
        QWidget::setTabOrder(GeoEclCheckBatch, HorizontalCheckBatch);
        QWidget::setTabOrder(HorizontalCheckBatch, AllRadioBatch);
        QWidget::setTabOrder(AllRadioBatch, InputRadioBatch);
        QWidget::setTabOrder(InputRadioBatch, OutputFileBoxBatch);
        QWidget::setTabOrder(OutputFileBoxBatch, InputFileBoxBatch);
        QWidget::setTabOrder(InputFileBoxBatch, PlanetCheckBatch);

        retranslateUi(modCalcPlanetsDlg);

        tabWidget->setCurrentIndex(0);


        QMetaObject::connectSlotsByName(modCalcPlanetsDlg);
    } // setupUi

    void retranslateUi(QWidget *modCalcPlanetsDlg)
    {
        groupBox->setTitle(tr2i18n("Input Parameters", nullptr));
        label->setText(tr2i18n("Date and time:", nullptr));
        LocationButton->setText(tr2i18n("Greenwich, United Kingdom", nullptr));
        textLabel1->setText(tr2i18n("Solar system body:", nullptr));
        PlanetComboBox->setItemText(0, tr2i18n("Mercury", nullptr));
        PlanetComboBox->setItemText(1, tr2i18n("Venus", nullptr));
        PlanetComboBox->setItemText(2, tr2i18n("Earth", nullptr));
        PlanetComboBox->setItemText(3, tr2i18n("Mars", nullptr));
        PlanetComboBox->setItemText(4, tr2i18n("Jupiter", nullptr));
        PlanetComboBox->setItemText(5, tr2i18n("Saturn", nullptr));
        PlanetComboBox->setItemText(6, tr2i18n("Uranus", nullptr));
        PlanetComboBox->setItemText(7, tr2i18n("Neptune", nullptr));
        PlanetComboBox->setItemText(8, tr2i18n("Moon", nullptr));
        PlanetComboBox->setItemText(9, tr2i18n("Sun", nullptr));

        groupBox_2->setTitle(tr2i18n("Equatorial Coordinates", nullptr));
        label_6->setText(tr2i18n("Dec:", nullptr));
        label_5->setText(tr2i18n("RA:", nullptr));
        groupBox_3->setTitle(tr2i18n("Horizontal Coordinates", nullptr));
        label_8->setText(tr2i18n("Alt:", nullptr));
        label_7->setText(tr2i18n("Az:", nullptr));
        groupBox_4->setTitle(tr2i18n("Heliocentric Ecliptic Coordinates", nullptr));
        label_11->setText(tr2i18n("Distance (AU):", nullptr));
        label_10->setText(tr2i18n("Latitude:", nullptr));
        label_9->setText(tr2i18n("Longitude:", nullptr));
        groupBox_5->setTitle(tr2i18n("Geocentric Ecliptic Coordinates", nullptr));
        label_13->setText(tr2i18n("Longitude:", nullptr));
        label_14->setText(tr2i18n("Latitude:", nullptr));
        label_12->setText(tr2i18n("Distance (AU):", nullptr));
        tabWidget->setTabText(tabWidget->indexOf(interact), tr2i18n("Interactive Mode", nullptr));
        groupBox_6->setTitle(tr2i18n("Select Parameters in Input File", nullptr));
        PlanetCheckBatch->setText(tr2i18n("Solar system body:", nullptr));
        PlanetComboBoxBatch->setItemText(0, tr2i18n("Mercury", nullptr));
        PlanetComboBoxBatch->setItemText(1, tr2i18n("Venus", nullptr));
        PlanetComboBoxBatch->setItemText(2, tr2i18n("Earth", nullptr));
        PlanetComboBoxBatch->setItemText(3, tr2i18n("Mars", nullptr));
        PlanetComboBoxBatch->setItemText(4, tr2i18n("Jupiter", nullptr));
        PlanetComboBoxBatch->setItemText(5, tr2i18n("Saturn", nullptr));
        PlanetComboBoxBatch->setItemText(6, tr2i18n("Uranus", nullptr));
        PlanetComboBoxBatch->setItemText(7, tr2i18n("Neptune", nullptr));
        PlanetComboBoxBatch->setItemText(8, tr2i18n("Pluto", nullptr));
        PlanetComboBoxBatch->setItemText(9, tr2i18n("Moon", nullptr));
        PlanetComboBoxBatch->setItemText(10, tr2i18n("Sun", nullptr));

        UTCheckBatch->setText(tr2i18n("UT:", nullptr));
        DateCheckBatch->setText(tr2i18n("Date:", nullptr));
        LatCheckBatch->setText(tr2i18n("Latitude:", nullptr));
        LongCheckBatch->setText(tr2i18n("Longitude:", nullptr));
        groupBox_7->setTitle(tr2i18n("Select Coordinate System for Output File", nullptr));
        HelioEclCheckBatch->setText(tr2i18n("Heliocentric ecliptic", nullptr));
        EquatorialCheckBatch->setText(tr2i18n("Equatorial", nullptr));
        GeoEclCheckBatch->setText(tr2i18n("Geocentric ecliptic", nullptr));
        HorizontalCheckBatch->setText(tr2i18n("Horizontal ", nullptr));
        groupBox_8->setTitle(tr2i18n("Other Parameters for Output File", nullptr));
        AllRadioBatch->setText(tr2i18n("All parameters", nullptr));
        InputRadioBatch->setText(tr2i18n("Only parameters in input file", nullptr));
        groupBox_9->setTitle(tr2i18n("Select Filenames", nullptr));
        label_15->setText(tr2i18n("Input file:", nullptr));
        label_16->setText(tr2i18n("Output file:", nullptr));
        RunButtonBatch->setText(tr2i18n("Run", nullptr));
        tabWidget->setTabText(tabWidget->indexOf(batch), tr2i18n("Batch Mode", nullptr));
        (void)modCalcPlanetsDlg;
    } // retranslateUi

};

namespace Ui {
    class modCalcPlanetsDlg: public Ui_modCalcPlanetsDlg {};
} // namespace Ui

QT_END_NAMESPACE

#endif // MODCALCPLANETS_H

