/****************************************************************************
** Meta object code from reading C++ file 'align.h'
**
** Created by: The Qt Meta Object Compiler version 69 (Qt 6.11.1)
**
** WARNING! All changes made in this file will be lost!
*****************************************************************************/

#include "../../../../kstars-3.8.4.1/kstars/ekos/align/align.h"
#include <QtNetwork/QSslError>
#include <QtDataVisualization/qbar3dseries.h>
#include <QtDataVisualization/q3dscene.h>
#include <QtGui/qtextcursor.h>
#include <QtCore/qmetatype.h>
#include <QtCore/QSharedPointer>
#include <QtCore/QList>

#include <QtCore/qtmochelpers.h>

#include <memory>


#include <QtCore/qxptype_traits.h>
#if !defined(Q_MOC_OUTPUT_REVISION)
#error "The header file 'align.h' doesn't include <QObject>."
#elif Q_MOC_OUTPUT_REVISION != 69
#error "This file was generated using the moc from 6.11.1. It"
#error "cannot be used with the include files from this version of Qt."
#error "(The moc has changed too much.)"
#endif

#ifndef Q_CONSTINIT
#define Q_CONSTINIT
#endif

QT_WARNING_PUSH
QT_WARNING_DISABLE_DEPRECATED
QT_WARNING_DISABLE_GCC("-Wuseless-cast")
namespace {
struct qt_meta_tag_ZN4Ekos5AlignE_t {};
} // unnamed namespace

template <> constexpr inline auto Ekos::Align::qt_create_metaobjectdata<qt_meta_tag_ZN4Ekos5AlignE_t>()
{
    namespace QMC = QtMocConstants;
    QtMocHelpers::StringRefStorage qt_stringData {
        "Ekos::Align",
        "D-Bus Interface",
        "org.kde.kstars.Ekos.Align",
        "newLog",
        "",
        "text",
        "newStatus",
        "Ekos::AlignState",
        "state",
        "newPAAStage",
        "stage",
        "newSolution",
        "QVariantMap",
        "solution",
        "newImage",
        "QSharedPointer<FITSView>",
        "view",
        "newFrame",
        "newSolverResults",
        "orientation",
        "ra",
        "dec",
        "pixscale",
        "newRotatorCommand",
        "targetPA",
        "trainChanged",
        "settingsUpdated",
        "settings",
        "manualRotatorChanged",
        "currentPA",
        "newDownloadProgress",
        "info",
        "mountModelProgressUpdated",
        "driverTimedout",
        "deviceName",
        "checkRemoteAlignmentTimeout",
        "setAlignTableResult",
        "AlignResult",
        "result",
        "showFITSViewer",
        "toggleAlignWidgetFullScreen",
        "prepareCapture",
        "ISD::CameraChip*",
        "targetChip",
        "buildTarget",
        "handlePointTooltip",
        "QMouseEvent*",
        "event",
        "handleVerticalPlotSizeChange",
        "handleHorizontalPlotSizeChange",
        "selectSolutionTableRow",
        "row",
        "column",
        "slotClearAllSolutionPoints",
        "slotRemoveSolutionPoint",
        "slotAutoScaleGraph",
        "slotMountModel",
        "processCaptureTimeout",
        "reconnectDriver",
        "camera",
        "checkRotatorTimeout",
        "executeGOTO",
        "refreshAlignOptions",
        "processPAHStage",
        "onDustCapStatusChanged",
        "ISD::DustCap::Status",
        "status",
        "filterWheel",
        "setFilter",
        "filter",
        "startSolving",
        "Q_NOREPLY",
        "setSolverAction",
        "mode",
        "getSolutionResult",
        "QList<double>",
        "getLoadAndSlewStatus",
        "setExposure",
        "value",
        "exposure",
        "cameraInfo",
        "telescopeInfo",
        "clearLog",
        "abort",
        "setSolverMode",
        "captureAndSolve",
        "initialCall",
        "loadAndSlew",
        "fileURL",
        "setTargetCoords",
        "ra0",
        "de0",
        "getTargetCoords",
        "setTargetPositionAngle",
        "setBinningIndex",
        "binIndex",
        "logText",
        "opticalTrain",
        "targetPositionAngle",
        "fov"
    };

    QtMocHelpers::UintData qt_methods {
        // Signal 'newLog'
        QtMocHelpers::SignalData<void(const QString &)>(3, 4, QMC::AccessPublic, QMetaType::Void, {{
            { QMetaType::QString, 5 },
        }}),
        // Signal 'newStatus'
        QtMocHelpers::SignalData<void(Ekos::AlignState)>(6, 4, QMC::AccessPublic, QMetaType::Void, {{
            { 0x80000000 | 7, 8 },
        }}),
        // Signal 'newPAAStage'
        QtMocHelpers::SignalData<void(int)>(9, 4, QMC::AccessPublic, QMetaType::Void, {{
            { QMetaType::Int, 10 },
        }}),
        // Signal 'newSolution'
        QtMocHelpers::SignalData<void(const QVariantMap &)>(11, 4, QMC::AccessPublic, QMetaType::Void, {{
            { 0x80000000 | 12, 13 },
        }}),
        // Signal 'newImage'
        QtMocHelpers::SignalData<void(const QSharedPointer<FITSView> &)>(14, 4, QMC::AccessPublic, QMetaType::Void, {{
            { 0x80000000 | 15, 16 },
        }}),
        // Signal 'newFrame'
        QtMocHelpers::SignalData<void(const QSharedPointer<FITSView> &)>(17, 4, QMC::AccessPublic, QMetaType::Void, {{
            { 0x80000000 | 15, 16 },
        }}),
        // Signal 'newSolverResults'
        QtMocHelpers::SignalData<void(double, double, double, double)>(18, 4, QMC::AccessPublic, QMetaType::Void, {{
            { QMetaType::Double, 19 }, { QMetaType::Double, 20 }, { QMetaType::Double, 21 }, { QMetaType::Double, 22 },
        }}),
        // Signal 'newRotatorCommand'
        QtMocHelpers::SignalData<void(double)>(23, 4, QMC::AccessPublic, QMetaType::Void, {{
            { QMetaType::Double, 24 },
        }}),
        // Signal 'trainChanged'
        QtMocHelpers::SignalData<void()>(25, 4, QMC::AccessPublic, QMetaType::Void),
        // Signal 'settingsUpdated'
        QtMocHelpers::SignalData<void(const QVariantMap &)>(26, 4, QMC::AccessPublic, QMetaType::Void, {{
            { 0x80000000 | 12, 27 },
        }}),
        // Signal 'manualRotatorChanged'
        QtMocHelpers::SignalData<void(double, double, double)>(28, 4, QMC::AccessPublic, QMetaType::Void, {{
            { QMetaType::Double, 29 }, { QMetaType::Double, 24 }, { QMetaType::Double, 22 },
        }}),
        // Signal 'newDownloadProgress'
        QtMocHelpers::SignalData<void(QString)>(30, 4, QMC::AccessPublic, QMetaType::Void, {{
            { QMetaType::QString, 31 },
        }}),
        // Signal 'mountModelProgressUpdated'
        QtMocHelpers::SignalData<void(const QVariantMap &)>(32, 4, QMC::AccessPublic, QMetaType::Void, {{
            { 0x80000000 | 12, 27 },
        }}),
        // Signal 'driverTimedout'
        QtMocHelpers::SignalData<void(const QString &)>(33, 4, QMC::AccessPublic, QMetaType::Void, {{
            { QMetaType::QString, 34 },
        }}),
        // Slot 'checkRemoteAlignmentTimeout'
        QtMocHelpers::SlotData<void()>(35, 4, QMC::AccessPrivate, QMetaType::Void),
        // Slot 'setAlignTableResult'
        QtMocHelpers::SlotData<void(AlignResult)>(36, 4, QMC::AccessPrivate, QMetaType::Void, {{
            { 0x80000000 | 37, 38 },
        }}),
        // Slot 'showFITSViewer'
        QtMocHelpers::SlotData<void()>(39, 4, QMC::AccessPrivate, QMetaType::Void),
        // Slot 'toggleAlignWidgetFullScreen'
        QtMocHelpers::SlotData<void()>(40, 4, QMC::AccessPrivate, QMetaType::Void),
        // Slot 'prepareCapture'
        QtMocHelpers::SlotData<void(ISD::CameraChip *)>(41, 4, QMC::AccessPrivate, QMetaType::Void, {{
            { 0x80000000 | 42, 43 },
        }}),
        // Slot 'buildTarget'
        QtMocHelpers::SlotData<void()>(44, 4, QMC::AccessPrivate, QMetaType::Void),
        // Slot 'handlePointTooltip'
        QtMocHelpers::SlotData<void(QMouseEvent *)>(45, 4, QMC::AccessPrivate, QMetaType::Void, {{
            { 0x80000000 | 46, 47 },
        }}),
        // Slot 'handleVerticalPlotSizeChange'
        QtMocHelpers::SlotData<void()>(48, 4, QMC::AccessPrivate, QMetaType::Void),
        // Slot 'handleHorizontalPlotSizeChange'
        QtMocHelpers::SlotData<void()>(49, 4, QMC::AccessPrivate, QMetaType::Void),
        // Slot 'selectSolutionTableRow'
        QtMocHelpers::SlotData<void(int, int)>(50, 4, QMC::AccessPrivate, QMetaType::Void, {{
            { QMetaType::Int, 51 }, { QMetaType::Int, 52 },
        }}),
        // Slot 'slotClearAllSolutionPoints'
        QtMocHelpers::SlotData<void()>(53, 4, QMC::AccessPrivate, QMetaType::Void),
        // Slot 'slotRemoveSolutionPoint'
        QtMocHelpers::SlotData<void()>(54, 4, QMC::AccessPrivate, QMetaType::Void),
        // Slot 'slotAutoScaleGraph'
        QtMocHelpers::SlotData<void()>(55, 4, QMC::AccessPrivate, QMetaType::Void),
        // Slot 'slotMountModel'
        QtMocHelpers::SlotData<void()>(56, 4, QMC::AccessPrivate, QMetaType::Void),
        // Slot 'processCaptureTimeout'
        QtMocHelpers::SlotData<void()>(57, 4, QMC::AccessPrivate, QMetaType::Void),
        // Slot 'reconnectDriver'
        QtMocHelpers::SlotData<void(const QString &)>(58, 4, QMC::AccessPrivate, QMetaType::Void, {{
            { QMetaType::QString, 59 },
        }}),
        // Slot 'checkRotatorTimeout'
        QtMocHelpers::SlotData<void()>(60, 4, QMC::AccessPrivate, QMetaType::Void),
        // Slot 'executeGOTO'
        QtMocHelpers::SlotData<void()>(61, 4, QMC::AccessProtected, QMetaType::Void),
        // Slot 'refreshAlignOptions'
        QtMocHelpers::SlotData<void()>(62, 4, QMC::AccessProtected, QMetaType::Void),
        // Slot 'processPAHStage'
        QtMocHelpers::SlotData<void(int)>(63, 4, QMC::AccessProtected, QMetaType::Void, {{
            { QMetaType::Int, 10 },
        }}),
        // Slot 'onDustCapStatusChanged'
        QtMocHelpers::SlotData<void(ISD::DustCap::Status)>(64, 4, QMC::AccessPrivate, QMetaType::Void, {{
            { 0x80000000 | 65, 66 },
        }}),
        // Method 'camera'
        QtMocHelpers::MethodData<QString()>(59, 4, QMC::AccessPublic | QMC::MethodScriptable, QMetaType::QString),
        // Method 'filterWheel'
        QtMocHelpers::MethodData<QString()>(67, 4, QMC::AccessPublic | QMC::MethodScriptable, QMetaType::QString),
        // Method 'setFilter'
        QtMocHelpers::MethodData<bool(const QString &)>(68, 4, QMC::AccessPublic | QMC::MethodScriptable, QMetaType::Bool, {{
            { QMetaType::QString, 69 },
        }}),
        // Method 'filter'
        QtMocHelpers::MethodData<QString()>(69, 4, QMC::AccessPublic | QMC::MethodScriptable, QMetaType::QString),
        // Method 'startSolving'
        QtMocHelpers::MethodData<void()>(70, 71, QMC::AccessPublic | QMC::MethodScriptable, QMetaType::Void),
        // Method 'setSolverAction'
        QtMocHelpers::MethodData<void(int)>(72, 71, QMC::AccessPublic | QMC::MethodScriptable, QMetaType::Void, {{
            { QMetaType::Int, 73 },
        }}),
        // Method 'getSolutionResult'
        QtMocHelpers::MethodData<QList<double>()>(74, 4, QMC::AccessPublic | QMC::MethodScriptable, 0x80000000 | 75),
        // Method 'status'
        QtMocHelpers::MethodData<Ekos::AlignState()>(66, 4, QMC::AccessPublic | QMC::MethodScriptable, 0x80000000 | 7),
        // Method 'getLoadAndSlewStatus'
        QtMocHelpers::MethodData<int()>(76, 4, QMC::AccessPublic | QMC::MethodScriptable, QMetaType::Int),
        // Method 'setExposure'
        QtMocHelpers::MethodData<void(double)>(77, 71, QMC::AccessPublic | QMC::MethodScriptable, QMetaType::Void, {{
            { QMetaType::Double, 78 },
        }}),
        // Method 'exposure'
        QtMocHelpers::MethodData<double()>(79, 4, QMC::AccessPublic | QMC::MethodScriptable, QMetaType::Double),
        // Method 'cameraInfo'
        QtMocHelpers::MethodData<QList<double>()>(80, 4, QMC::AccessPublic | QMC::MethodScriptable, 0x80000000 | 75),
        // Method 'telescopeInfo'
        QtMocHelpers::MethodData<QList<double>()>(81, 4, QMC::AccessPublic | QMC::MethodScriptable, 0x80000000 | 75),
        // Method 'clearLog'
        QtMocHelpers::MethodData<void()>(82, 4, QMC::AccessPublic | QMC::MethodScriptable, QMetaType::Void),
        // Method 'abort'
        QtMocHelpers::MethodData<void()>(83, 71, QMC::AccessPublic | QMC::MethodScriptable, QMetaType::Void),
        // Method 'setSolverMode'
        QtMocHelpers::MethodData<void(int)>(84, 71, QMC::AccessPublic | QMC::MethodScriptable, QMetaType::Void, {{
            { QMetaType::Int, 73 },
        }}),
        // Method 'captureAndSolve'
        QtMocHelpers::MethodData<bool(bool)>(85, 4, QMC::AccessPublic | QMC::MethodScriptable, QMetaType::Bool, {{
            { QMetaType::Bool, 86 },
        }}),
        // Method 'captureAndSolve'
        QtMocHelpers::MethodData<bool()>(85, 4, QMC::AccessPublic | QMC::MethodCloned | QMC::MethodScriptable, QMetaType::Bool),
        // Method 'loadAndSlew'
        QtMocHelpers::MethodData<bool(QString)>(87, 4, QMC::AccessPublic | QMC::MethodScriptable, QMetaType::Bool, {{
            { QMetaType::QString, 88 },
        }}),
        // Method 'loadAndSlew'
        QtMocHelpers::MethodData<bool()>(87, 4, QMC::AccessPublic | QMC::MethodCloned | QMC::MethodScriptable, QMetaType::Bool),
        // Method 'setTargetCoords'
        QtMocHelpers::MethodData<void(double, double)>(89, 71, QMC::AccessPublic | QMC::MethodScriptable, QMetaType::Void, {{
            { QMetaType::Double, 90 }, { QMetaType::Double, 91 },
        }}),
        // Method 'getTargetCoords'
        QtMocHelpers::MethodData<QList<double>()>(92, 4, QMC::AccessPublic | QMC::MethodScriptable, 0x80000000 | 75),
        // Method 'setTargetPositionAngle'
        QtMocHelpers::MethodData<void(double)>(93, 71, QMC::AccessPublic | QMC::MethodScriptable, QMetaType::Void, {{
            { QMetaType::Double, 78 },
        }}),
        // Method 'setBinningIndex'
        QtMocHelpers::MethodData<void(int)>(94, 71, QMC::AccessPublic | QMC::MethodScriptable, QMetaType::Void, {{
            { QMetaType::Int, 95 },
        }}),
    };
    QtMocHelpers::UintData qt_properties {
        // property 'status'
        QtMocHelpers::PropertyData<Ekos::AlignState>(66, 0x80000000 | 7, QMC::DefaultPropertyFlags | QMC::EnumOrFlag, 1),
        // property 'logText'
        QtMocHelpers::PropertyData<QStringList>(96, QMetaType::QStringList, QMC::DefaultPropertyFlags, 0),
        // property 'opticalTrain'
        QtMocHelpers::PropertyData<QString>(97, QMetaType::QString, QMC::DefaultPropertyFlags | QMC::Writable | QMC::StdCppSet),
        // property 'camera'
        QtMocHelpers::PropertyData<QString>(59, QMetaType::QString, QMC::DefaultPropertyFlags),
        // property 'filterWheel'
        QtMocHelpers::PropertyData<QString>(67, QMetaType::QString, QMC::DefaultPropertyFlags),
        // property 'filter'
        QtMocHelpers::PropertyData<QString>(69, QMetaType::QString, QMC::DefaultPropertyFlags | QMC::Writable | QMC::StdCppSet),
        // property 'exposure'
        QtMocHelpers::PropertyData<double>(79, QMetaType::Double, QMC::DefaultPropertyFlags | QMC::Writable | QMC::StdCppSet),
        // property 'targetPositionAngle'
        QtMocHelpers::PropertyData<double>(98, QMetaType::Double, QMC::DefaultPropertyFlags | QMC::Writable),
        // property 'fov'
        QtMocHelpers::PropertyData<QList<double>>(99, 0x80000000 | 75, QMC::DefaultPropertyFlags | QMC::EnumOrFlag),
        // property 'cameraInfo'
        QtMocHelpers::PropertyData<QList<double>>(80, 0x80000000 | 75, QMC::DefaultPropertyFlags | QMC::EnumOrFlag),
        // property 'telescopeInfo'
        QtMocHelpers::PropertyData<QList<double>>(81, 0x80000000 | 75, QMC::DefaultPropertyFlags | QMC::EnumOrFlag),
    };
    QtMocHelpers::UintData qt_enums {
    };
    QtMocHelpers::UintData qt_constructors {};
    QtMocHelpers::ClassInfos qt_classinfo({
            {    1,    2 },
    });
    return QtMocHelpers::metaObjectData<Align, qt_meta_tag_ZN4Ekos5AlignE_t>(QMC::MetaObjectFlag{}, qt_stringData,
            qt_methods, qt_properties, qt_enums, qt_constructors, qt_classinfo);
}
Q_CONSTINIT const QMetaObject Ekos::Align::staticMetaObject = { {
    QMetaObject::SuperData::link<QWidget::staticMetaObject>(),
    qt_staticMetaObjectStaticContent<qt_meta_tag_ZN4Ekos5AlignE_t>.stringdata,
    qt_staticMetaObjectStaticContent<qt_meta_tag_ZN4Ekos5AlignE_t>.data,
    qt_static_metacall,
    nullptr,
    qt_staticMetaObjectRelocatingContent<qt_meta_tag_ZN4Ekos5AlignE_t>.metaTypes,
    nullptr
} };

void Ekos::Align::qt_static_metacall(QObject *_o, QMetaObject::Call _c, int _id, void **_a)
{
    auto *_t = static_cast<Align *>(_o);
    if (_c == QMetaObject::InvokeMetaMethod) {
        switch (_id) {
        case 0: _t->newLog((*reinterpret_cast<std::add_pointer_t<QString>>(_a[1]))); break;
        case 1: _t->newStatus((*reinterpret_cast<std::add_pointer_t<Ekos::AlignState>>(_a[1]))); break;
        case 2: _t->newPAAStage((*reinterpret_cast<std::add_pointer_t<int>>(_a[1]))); break;
        case 3: _t->newSolution((*reinterpret_cast<std::add_pointer_t<QVariantMap>>(_a[1]))); break;
        case 4: _t->newImage((*reinterpret_cast<std::add_pointer_t<QSharedPointer<FITSView>>>(_a[1]))); break;
        case 5: _t->newFrame((*reinterpret_cast<std::add_pointer_t<QSharedPointer<FITSView>>>(_a[1]))); break;
        case 6: _t->newSolverResults((*reinterpret_cast<std::add_pointer_t<double>>(_a[1])),(*reinterpret_cast<std::add_pointer_t<double>>(_a[2])),(*reinterpret_cast<std::add_pointer_t<double>>(_a[3])),(*reinterpret_cast<std::add_pointer_t<double>>(_a[4]))); break;
        case 7: _t->newRotatorCommand((*reinterpret_cast<std::add_pointer_t<double>>(_a[1]))); break;
        case 8: _t->trainChanged(); break;
        case 9: _t->settingsUpdated((*reinterpret_cast<std::add_pointer_t<QVariantMap>>(_a[1]))); break;
        case 10: _t->manualRotatorChanged((*reinterpret_cast<std::add_pointer_t<double>>(_a[1])),(*reinterpret_cast<std::add_pointer_t<double>>(_a[2])),(*reinterpret_cast<std::add_pointer_t<double>>(_a[3]))); break;
        case 11: _t->newDownloadProgress((*reinterpret_cast<std::add_pointer_t<QString>>(_a[1]))); break;
        case 12: _t->mountModelProgressUpdated((*reinterpret_cast<std::add_pointer_t<QVariantMap>>(_a[1]))); break;
        case 13: _t->driverTimedout((*reinterpret_cast<std::add_pointer_t<QString>>(_a[1]))); break;
        case 14: _t->checkRemoteAlignmentTimeout(); break;
        case 15: _t->setAlignTableResult((*reinterpret_cast<std::add_pointer_t<AlignResult>>(_a[1]))); break;
        case 16: _t->showFITSViewer(); break;
        case 17: _t->toggleAlignWidgetFullScreen(); break;
        case 18: _t->prepareCapture((*reinterpret_cast<std::add_pointer_t<ISD::CameraChip*>>(_a[1]))); break;
        case 19: _t->buildTarget(); break;
        case 20: _t->handlePointTooltip((*reinterpret_cast<std::add_pointer_t<QMouseEvent*>>(_a[1]))); break;
        case 21: _t->handleVerticalPlotSizeChange(); break;
        case 22: _t->handleHorizontalPlotSizeChange(); break;
        case 23: _t->selectSolutionTableRow((*reinterpret_cast<std::add_pointer_t<int>>(_a[1])),(*reinterpret_cast<std::add_pointer_t<int>>(_a[2]))); break;
        case 24: _t->slotClearAllSolutionPoints(); break;
        case 25: _t->slotRemoveSolutionPoint(); break;
        case 26: _t->slotAutoScaleGraph(); break;
        case 27: _t->slotMountModel(); break;
        case 28: _t->processCaptureTimeout(); break;
        case 29: _t->reconnectDriver((*reinterpret_cast<std::add_pointer_t<QString>>(_a[1]))); break;
        case 30: _t->checkRotatorTimeout(); break;
        case 31: _t->executeGOTO(); break;
        case 32: _t->refreshAlignOptions(); break;
        case 33: _t->processPAHStage((*reinterpret_cast<std::add_pointer_t<int>>(_a[1]))); break;
        case 34: _t->onDustCapStatusChanged((*reinterpret_cast<std::add_pointer_t<ISD::DustCap::Status>>(_a[1]))); break;
        case 35: { QString _r = _t->camera();
            if (_a[0]) *reinterpret_cast<QString*>(_a[0]) = std::move(_r); }  break;
        case 36: { QString _r = _t->filterWheel();
            if (_a[0]) *reinterpret_cast<QString*>(_a[0]) = std::move(_r); }  break;
        case 37: { bool _r = _t->setFilter((*reinterpret_cast<std::add_pointer_t<QString>>(_a[1])));
            if (_a[0]) *reinterpret_cast<bool*>(_a[0]) = std::move(_r); }  break;
        case 38: { QString _r = _t->filter();
            if (_a[0]) *reinterpret_cast<QString*>(_a[0]) = std::move(_r); }  break;
        case 39: _t->startSolving(); break;
        case 40: _t->setSolverAction((*reinterpret_cast<std::add_pointer_t<int>>(_a[1]))); break;
        case 41: { QList<double> _r = _t->getSolutionResult();
            if (_a[0]) *reinterpret_cast<QList<double>*>(_a[0]) = std::move(_r); }  break;
        case 42: { Ekos::AlignState _r = _t->status();
            if (_a[0]) *reinterpret_cast<Ekos::AlignState*>(_a[0]) = std::move(_r); }  break;
        case 43: { int _r = _t->getLoadAndSlewStatus();
            if (_a[0]) *reinterpret_cast<int*>(_a[0]) = std::move(_r); }  break;
        case 44: _t->setExposure((*reinterpret_cast<std::add_pointer_t<double>>(_a[1]))); break;
        case 45: { double _r = _t->exposure();
            if (_a[0]) *reinterpret_cast<double*>(_a[0]) = std::move(_r); }  break;
        case 46: { QList<double> _r = _t->cameraInfo();
            if (_a[0]) *reinterpret_cast<QList<double>*>(_a[0]) = std::move(_r); }  break;
        case 47: { QList<double> _r = _t->telescopeInfo();
            if (_a[0]) *reinterpret_cast<QList<double>*>(_a[0]) = std::move(_r); }  break;
        case 48: _t->clearLog(); break;
        case 49: _t->abort(); break;
        case 50: _t->setSolverMode((*reinterpret_cast<std::add_pointer_t<int>>(_a[1]))); break;
        case 51: { bool _r = _t->captureAndSolve((*reinterpret_cast<std::add_pointer_t<bool>>(_a[1])));
            if (_a[0]) *reinterpret_cast<bool*>(_a[0]) = std::move(_r); }  break;
        case 52: { bool _r = _t->captureAndSolve();
            if (_a[0]) *reinterpret_cast<bool*>(_a[0]) = std::move(_r); }  break;
        case 53: { bool _r = _t->loadAndSlew((*reinterpret_cast<std::add_pointer_t<QString>>(_a[1])));
            if (_a[0]) *reinterpret_cast<bool*>(_a[0]) = std::move(_r); }  break;
        case 54: { bool _r = _t->loadAndSlew();
            if (_a[0]) *reinterpret_cast<bool*>(_a[0]) = std::move(_r); }  break;
        case 55: _t->setTargetCoords((*reinterpret_cast<std::add_pointer_t<double>>(_a[1])),(*reinterpret_cast<std::add_pointer_t<double>>(_a[2]))); break;
        case 56: { QList<double> _r = _t->getTargetCoords();
            if (_a[0]) *reinterpret_cast<QList<double>*>(_a[0]) = std::move(_r); }  break;
        case 57: _t->setTargetPositionAngle((*reinterpret_cast<std::add_pointer_t<double>>(_a[1]))); break;
        case 58: _t->setBinningIndex((*reinterpret_cast<std::add_pointer_t<int>>(_a[1]))); break;
        default: ;
        }
    }
    if (_c == QMetaObject::RegisterMethodArgumentMetaType) {
        switch (_id) {
        default: *reinterpret_cast<QMetaType *>(_a[0]) = QMetaType(); break;
        case 1:
            switch (*reinterpret_cast<int*>(_a[1])) {
            default: *reinterpret_cast<QMetaType *>(_a[0]) = QMetaType(); break;
            case 0:
                *reinterpret_cast<QMetaType *>(_a[0]) = QMetaType::fromType< Ekos::AlignState >(); break;
            }
            break;
        case 4:
            switch (*reinterpret_cast<int*>(_a[1])) {
            default: *reinterpret_cast<QMetaType *>(_a[0]) = QMetaType(); break;
            case 0:
                *reinterpret_cast<QMetaType *>(_a[0]) = QMetaType::fromType< QSharedPointer<FITSView> >(); break;
            }
            break;
        case 5:
            switch (*reinterpret_cast<int*>(_a[1])) {
            default: *reinterpret_cast<QMetaType *>(_a[0]) = QMetaType(); break;
            case 0:
                *reinterpret_cast<QMetaType *>(_a[0]) = QMetaType::fromType< QSharedPointer<FITSView> >(); break;
            }
            break;
        case 34:
            switch (*reinterpret_cast<int*>(_a[1])) {
            default: *reinterpret_cast<QMetaType *>(_a[0]) = QMetaType(); break;
            case 0:
                *reinterpret_cast<QMetaType *>(_a[0]) = QMetaType::fromType< ISD::DustCap::Status >(); break;
            }
            break;
        }
    }
    if (_c == QMetaObject::IndexOfMethod) {
        if (QtMocHelpers::indexOfMethod<void (Align::*)(const QString & )>(_a, &Align::newLog, 0))
            return;
        if (QtMocHelpers::indexOfMethod<void (Align::*)(Ekos::AlignState )>(_a, &Align::newStatus, 1))
            return;
        if (QtMocHelpers::indexOfMethod<void (Align::*)(int )>(_a, &Align::newPAAStage, 2))
            return;
        if (QtMocHelpers::indexOfMethod<void (Align::*)(const QVariantMap & )>(_a, &Align::newSolution, 3))
            return;
        if (QtMocHelpers::indexOfMethod<void (Align::*)(const QSharedPointer<FITSView> & )>(_a, &Align::newImage, 4))
            return;
        if (QtMocHelpers::indexOfMethod<void (Align::*)(const QSharedPointer<FITSView> & )>(_a, &Align::newFrame, 5))
            return;
        if (QtMocHelpers::indexOfMethod<void (Align::*)(double , double , double , double )>(_a, &Align::newSolverResults, 6))
            return;
        if (QtMocHelpers::indexOfMethod<void (Align::*)(double )>(_a, &Align::newRotatorCommand, 7))
            return;
        if (QtMocHelpers::indexOfMethod<void (Align::*)()>(_a, &Align::trainChanged, 8))
            return;
        if (QtMocHelpers::indexOfMethod<void (Align::*)(const QVariantMap & )>(_a, &Align::settingsUpdated, 9))
            return;
        if (QtMocHelpers::indexOfMethod<void (Align::*)(double , double , double )>(_a, &Align::manualRotatorChanged, 10))
            return;
        if (QtMocHelpers::indexOfMethod<void (Align::*)(QString )>(_a, &Align::newDownloadProgress, 11))
            return;
        if (QtMocHelpers::indexOfMethod<void (Align::*)(const QVariantMap & )>(_a, &Align::mountModelProgressUpdated, 12))
            return;
        if (QtMocHelpers::indexOfMethod<void (Align::*)(const QString & )>(_a, &Align::driverTimedout, 13))
            return;
    }
    if (_c == QMetaObject::RegisterPropertyMetaType) {
        switch (_id) {
        default: *reinterpret_cast<int*>(_a[0]) = -1; break;
        case 0:
            *reinterpret_cast<int*>(_a[0]) = qRegisterMetaType< Ekos::AlignState >(); break;
        case 10:
        case 9:
        case 8:
            *reinterpret_cast<int*>(_a[0]) = qRegisterMetaType< QList<double> >(); break;
        }
    }
    if (_c == QMetaObject::ReadProperty) {
        void *_v = _a[0];
        switch (_id) {
        case 0: *reinterpret_cast<Ekos::AlignState*>(_v) = _t->status(); break;
        case 1: *reinterpret_cast<QStringList*>(_v) = _t->logText(); break;
        case 2: *reinterpret_cast<QString*>(_v) = _t->opticalTrain(); break;
        case 3: *reinterpret_cast<QString*>(_v) = _t->camera(); break;
        case 4: *reinterpret_cast<QString*>(_v) = _t->filterWheel(); break;
        case 5: *reinterpret_cast<QString*>(_v) = _t->filter(); break;
        case 6: *reinterpret_cast<double*>(_v) = _t->exposure(); break;
        case 7: *reinterpret_cast<double*>(_v) = _t->m_TargetPositionAngle; break;
        case 8: *reinterpret_cast<QList<double>*>(_v) = _t->fov(); break;
        case 9: *reinterpret_cast<QList<double>*>(_v) = _t->cameraInfo(); break;
        case 10: *reinterpret_cast<QList<double>*>(_v) = _t->telescopeInfo(); break;
        default: break;
        }
    }
    if (_c == QMetaObject::WriteProperty) {
        void *_v = _a[0];
        switch (_id) {
        case 2: _t->setOpticalTrain(*reinterpret_cast<QString*>(_v)); break;
        case 5: _t->setFilter(*reinterpret_cast<QString*>(_v)); break;
        case 6: _t->setExposure(*reinterpret_cast<double*>(_v)); break;
        case 7: QtMocHelpers::setProperty(_t->m_TargetPositionAngle, *reinterpret_cast<double*>(_v)); break;
        default: break;
        }
    }
}

const QMetaObject *Ekos::Align::metaObject() const
{
    return QObject::d_ptr->metaObject ? QObject::d_ptr->dynamicMetaObject() : &staticMetaObject;
}

void *Ekos::Align::qt_metacast(const char *_clname)
{
    if (!_clname) return nullptr;
    if (!strcmp(_clname, qt_staticMetaObjectStaticContent<qt_meta_tag_ZN4Ekos5AlignE_t>.strings))
        return static_cast<void*>(this);
    if (!strcmp(_clname, "Ui::Align"))
        return static_cast< Ui::Align*>(this);
    return QWidget::qt_metacast(_clname);
}

int Ekos::Align::qt_metacall(QMetaObject::Call _c, int _id, void **_a)
{
    _id = QWidget::qt_metacall(_c, _id, _a);
    if (_id < 0)
        return _id;
    if (_c == QMetaObject::InvokeMetaMethod) {
        if (_id < 59)
            qt_static_metacall(this, _c, _id, _a);
        _id -= 59;
    }
    if (_c == QMetaObject::RegisterMethodArgumentMetaType) {
        if (_id < 59)
            qt_static_metacall(this, _c, _id, _a);
        _id -= 59;
    }
    if (_c == QMetaObject::ReadProperty || _c == QMetaObject::WriteProperty
            || _c == QMetaObject::ResetProperty || _c == QMetaObject::BindableProperty
            || _c == QMetaObject::RegisterPropertyMetaType) {
        qt_static_metacall(this, _c, _id, _a);
        _id -= 11;
    }
    return _id;
}

// SIGNAL 0
void Ekos::Align::newLog(const QString & _t1)
{
    QMetaObject::activate<void>(this, &staticMetaObject, 0, nullptr, _t1);
}

// SIGNAL 1
void Ekos::Align::newStatus(Ekos::AlignState _t1)
{
    QMetaObject::activate<void>(this, &staticMetaObject, 1, nullptr, _t1);
}

// SIGNAL 2
void Ekos::Align::newPAAStage(int _t1)
{
    QMetaObject::activate<void>(this, &staticMetaObject, 2, nullptr, _t1);
}

// SIGNAL 3
void Ekos::Align::newSolution(const QVariantMap & _t1)
{
    QMetaObject::activate<void>(this, &staticMetaObject, 3, nullptr, _t1);
}

// SIGNAL 4
void Ekos::Align::newImage(const QSharedPointer<FITSView> & _t1)
{
    QMetaObject::activate<void>(this, &staticMetaObject, 4, nullptr, _t1);
}

// SIGNAL 5
void Ekos::Align::newFrame(const QSharedPointer<FITSView> & _t1)
{
    QMetaObject::activate<void>(this, &staticMetaObject, 5, nullptr, _t1);
}

// SIGNAL 6
void Ekos::Align::newSolverResults(double _t1, double _t2, double _t3, double _t4)
{
    QMetaObject::activate<void>(this, &staticMetaObject, 6, nullptr, _t1, _t2, _t3, _t4);
}

// SIGNAL 7
void Ekos::Align::newRotatorCommand(double _t1)
{
    QMetaObject::activate<void>(this, &staticMetaObject, 7, nullptr, _t1);
}

// SIGNAL 8
void Ekos::Align::trainChanged()
{
    QMetaObject::activate(this, &staticMetaObject, 8, nullptr);
}

// SIGNAL 9
void Ekos::Align::settingsUpdated(const QVariantMap & _t1)
{
    QMetaObject::activate<void>(this, &staticMetaObject, 9, nullptr, _t1);
}

// SIGNAL 10
void Ekos::Align::manualRotatorChanged(double _t1, double _t2, double _t3)
{
    QMetaObject::activate<void>(this, &staticMetaObject, 10, nullptr, _t1, _t2, _t3);
}

// SIGNAL 11
void Ekos::Align::newDownloadProgress(QString _t1)
{
    QMetaObject::activate<void>(this, &staticMetaObject, 11, nullptr, _t1);
}

// SIGNAL 12
void Ekos::Align::mountModelProgressUpdated(const QVariantMap & _t1)
{
    QMetaObject::activate<void>(this, &staticMetaObject, 12, nullptr, _t1);
}

// SIGNAL 13
void Ekos::Align::driverTimedout(const QString & _t1)
{
    QMetaObject::activate<void>(this, &staticMetaObject, 13, nullptr, _t1);
}
QT_WARNING_POP
