/********************************************************************************
** Form generated from reading UI file 'scriptsmanager.ui'
**
** Created by: Qt User Interface Compiler version 6.11.1
**
** WARNING! All changes made in this file will be lost when recompiling UI file!
********************************************************************************/

#ifndef UI_SCRIPTSMANAGER_H
#define UI_SCRIPTSMANAGER_H

#include <QtCore/QVariant>
#include <QtGui/QIcon>
#include <QtWidgets/QAbstractButton>
#include <QtWidgets/QApplication>
#include <QtWidgets/QDialog>
#include <QtWidgets/QDialogButtonBox>
#include <QtWidgets/QGridLayout>
#include <QtWidgets/QLabel>
#include <QtWidgets/QLineEdit>
#include <QtWidgets/QPushButton>
#include <QtWidgets/QSpacerItem>
#include <QtWidgets/QVBoxLayout>
#include <klocalizedstring.h>

QT_BEGIN_NAMESPACE

class Ui_ScriptsManager
{
public:
    QVBoxLayout *verticalLayout;
    QGridLayout *gridLayout;
    QLabel *label;
    QLineEdit *preJobScript;
    QPushButton *preJobB;
    QLabel *label_2;
    QLineEdit *preCaptureScript;
    QPushButton *preCaptureB;
    QLabel *label_3;
    QLineEdit *postCaptureScript;
    QPushButton *postCaptureB;
    QLabel *label_4;
    QLineEdit *postJobScript;
    QPushButton *postJobB;
    QSpacerItem *verticalSpacer;
    QDialogButtonBox *buttonBox;

    void setupUi(QDialog *ScriptsManager)
    {
        if (ScriptsManager->objectName().isEmpty())
            ScriptsManager->setObjectName("ScriptsManager");
        ScriptsManager->resize(437, 203);
        verticalLayout = new QVBoxLayout(ScriptsManager);
        verticalLayout->setObjectName("verticalLayout");
        gridLayout = new QGridLayout();
        gridLayout->setObjectName("gridLayout");
        label = new QLabel(ScriptsManager);
        label->setObjectName("label");

        gridLayout->addWidget(label, 0, 0, 1, 1);

        preJobScript = new QLineEdit(ScriptsManager);
        preJobScript->setObjectName("preJobScript");
        QSizePolicy sizePolicy(QSizePolicy::Policy::Expanding, QSizePolicy::Policy::Preferred);
        sizePolicy.setHorizontalStretch(0);
        sizePolicy.setVerticalStretch(0);
        sizePolicy.setHeightForWidth(preJobScript->sizePolicy().hasHeightForWidth());
        preJobScript->setSizePolicy(sizePolicy);
        preJobScript->setClearButtonEnabled(true);

        gridLayout->addWidget(preJobScript, 0, 1, 1, 1);

        preJobB = new QPushButton(ScriptsManager);
        preJobB->setObjectName("preJobB");
        preJobB->setMinimumSize(QSize(32, 32));
        QIcon icon(QIcon::fromTheme(QString::fromUtf8("document-open")));
        preJobB->setIcon(icon);
        preJobB->setIconSize(QSize(28, 28));

        gridLayout->addWidget(preJobB, 0, 2, 1, 1);

        label_2 = new QLabel(ScriptsManager);
        label_2->setObjectName("label_2");

        gridLayout->addWidget(label_2, 1, 0, 1, 1);

        preCaptureScript = new QLineEdit(ScriptsManager);
        preCaptureScript->setObjectName("preCaptureScript");
        sizePolicy.setHeightForWidth(preCaptureScript->sizePolicy().hasHeightForWidth());
        preCaptureScript->setSizePolicy(sizePolicy);
        preCaptureScript->setClearButtonEnabled(true);

        gridLayout->addWidget(preCaptureScript, 1, 1, 1, 1);

        preCaptureB = new QPushButton(ScriptsManager);
        preCaptureB->setObjectName("preCaptureB");
        preCaptureB->setMinimumSize(QSize(32, 32));
        preCaptureB->setIcon(icon);
        preCaptureB->setIconSize(QSize(28, 28));

        gridLayout->addWidget(preCaptureB, 1, 2, 1, 1);

        label_3 = new QLabel(ScriptsManager);
        label_3->setObjectName("label_3");

        gridLayout->addWidget(label_3, 2, 0, 1, 1);

        postCaptureScript = new QLineEdit(ScriptsManager);
        postCaptureScript->setObjectName("postCaptureScript");
        sizePolicy.setHeightForWidth(postCaptureScript->sizePolicy().hasHeightForWidth());
        postCaptureScript->setSizePolicy(sizePolicy);
        postCaptureScript->setClearButtonEnabled(true);

        gridLayout->addWidget(postCaptureScript, 2, 1, 1, 1);

        postCaptureB = new QPushButton(ScriptsManager);
        postCaptureB->setObjectName("postCaptureB");
        postCaptureB->setMinimumSize(QSize(32, 32));
        postCaptureB->setIcon(icon);
        postCaptureB->setIconSize(QSize(28, 28));

        gridLayout->addWidget(postCaptureB, 2, 2, 2, 1);

        label_4 = new QLabel(ScriptsManager);
        label_4->setObjectName("label_4");

        gridLayout->addWidget(label_4, 3, 0, 2, 1);

        postJobScript = new QLineEdit(ScriptsManager);
        postJobScript->setObjectName("postJobScript");
        sizePolicy.setHeightForWidth(postJobScript->sizePolicy().hasHeightForWidth());
        postJobScript->setSizePolicy(sizePolicy);
        postJobScript->setClearButtonEnabled(true);

        gridLayout->addWidget(postJobScript, 3, 1, 2, 1);

        postJobB = new QPushButton(ScriptsManager);
        postJobB->setObjectName("postJobB");
        postJobB->setMinimumSize(QSize(32, 32));
        postJobB->setIcon(icon);
        postJobB->setIconSize(QSize(28, 28));

        gridLayout->addWidget(postJobB, 4, 2, 1, 1);


        verticalLayout->addLayout(gridLayout);

        verticalSpacer = new QSpacerItem(20, 0, QSizePolicy::Policy::Minimum, QSizePolicy::Policy::Expanding);

        verticalLayout->addItem(verticalSpacer);

        buttonBox = new QDialogButtonBox(ScriptsManager);
        buttonBox->setObjectName("buttonBox");
        buttonBox->setOrientation(Qt::Horizontal);
        buttonBox->setStandardButtons(QDialogButtonBox::Cancel|QDialogButtonBox::Ok);

        verticalLayout->addWidget(buttonBox);


        retranslateUi(ScriptsManager);
        QObject::connect(buttonBox, &QDialogButtonBox::accepted, ScriptsManager, qOverload<>(&QDialog::accept));
        QObject::connect(buttonBox, &QDialogButtonBox::rejected, ScriptsManager, qOverload<>(&QDialog::reject));

        QMetaObject::connectSlotsByName(ScriptsManager);
    } // setupUi

    void retranslateUi(QDialog *ScriptsManager)
    {
        ScriptsManager->setWindowTitle(tr2i18n("Script Manager", nullptr));
        label->setText(tr2i18n("Pre-job script:", nullptr));
        preJobScript->setPlaceholderText(tr2i18n("Script Executable", nullptr));
        preJobB->setText(QString());
        label_2->setText(tr2i18n("Pre-capture script:", nullptr));
        preCaptureScript->setPlaceholderText(tr2i18n("Script Executable", nullptr));
        preCaptureB->setText(QString());
        label_3->setText(tr2i18n("Post-capture script:", nullptr));
        postCaptureScript->setPlaceholderText(tr2i18n("Script Executable", nullptr));
        postCaptureB->setText(QString());
        label_4->setText(tr2i18n("Post-job script:", nullptr));
        postJobScript->setPlaceholderText(tr2i18n("Script Executable", nullptr));
        postJobB->setText(QString());
    } // retranslateUi

};

namespace Ui {
    class ScriptsManager: public Ui_ScriptsManager {};
} // namespace Ui

QT_END_NAMESPACE

#endif // SCRIPTSMANAGER_H

