/********************************************************************************
** Form generated from reading UI file 'modcalcgeod.ui'
**
** Created by: Qt User Interface Compiler version 6.11.1
**
** WARNING! All changes made in this file will be lost when recompiling UI file!
********************************************************************************/

#ifndef UI_MODCALCGEOD_H
#define UI_MODCALCGEOD_H

#include <QtCore/QVariant>
#include <QtWidgets/QApplication>
#include <QtWidgets/QCheckBox>
#include <QtWidgets/QComboBox>
#include <QtWidgets/QGridLayout>
#include <QtWidgets/QGroupBox>
#include <QtWidgets/QHBoxLayout>
#include <QtWidgets/QLabel>
#include <QtWidgets/QLineEdit>
#include <QtWidgets/QPushButton>
#include <QtWidgets/QRadioButton>
#include <QtWidgets/QSpacerItem>
#include <QtWidgets/QTabWidget>
#include <QtWidgets/QVBoxLayout>
#include <QtWidgets/QWidget>
#include <klocalizedstring.h>
#include "kurlrequester.h"
#include "widgets/dmsbox.h"

QT_BEGIN_NAMESPACE

class Ui_modCalcGeodCoordDlg
{
public:
    QVBoxLayout *vboxLayout;
    QTabWidget *tabWidget;
    QWidget *interact;
    QVBoxLayout *vboxLayout1;
    QHBoxLayout *hboxLayout;
    QGroupBox *groupBox;
    QHBoxLayout *hboxLayout1;
    QHBoxLayout *hboxLayout2;
    QRadioButton *cartRadio;
    QRadioButton *spheRadio;
    QGroupBox *groupBox_2;
    QHBoxLayout *hboxLayout3;
    QComboBox *ellipsoidBox;
    QHBoxLayout *hboxLayout4;
    QSpacerItem *spacerItem;
    QPushButton *Compute;
    QSpacerItem *spacerItem1;
    QPushButton *Clear;
    QSpacerItem *spacerItem2;
    QHBoxLayout *hboxLayout5;
    QGroupBox *groupBox_3;
    QGridLayout *gridLayout;
    QLabel *XCartLabel;
    QLabel *YCartLabel;
    QLabel *ZCartLabel;
    QLineEdit *ZGeoBox;
    QLineEdit *XGeoBox;
    QLineEdit *YGeoBox;
    QGroupBox *groupBox_4;
    QGridLayout *gridLayout1;
    QLabel *AltGeoLabel;
    QLineEdit *AltGeoBox;
    QLabel *LongGeoLabel;
    QLabel *LatGeoLabel;
    dmsBox *LongGeoBox;
    dmsBox *LatGeoBox;
    QSpacerItem *spacerItem3;
    QWidget *batch;
    QVBoxLayout *vboxLayout2;
    QGroupBox *groupBox_5;
    QGridLayout *gridLayout2;
    QCheckBox *YGeoCheckBatch;
    QCheckBox *ZGeoCheckBatch;
    QLineEdit *ZGeoBoxBatch;
    QLineEdit *AltGeoBoxBatch;
    QCheckBox *AltGeoCheckBatch;
    QCheckBox *XGeoCheckBatch;
    QCheckBox *LongGeoCheckBatch;
    dmsBox *LongGeoBoxBatch;
    QCheckBox *LatGeoCheckBatch;
    QLineEdit *XGeoBoxBatch;
    dmsBox *LatGeoBoxBatch;
    QLineEdit *YGeoBoxBatch;
    QGroupBox *groupBox_6;
    QHBoxLayout *hboxLayout6;
    QRadioButton *AllRadioBatch;
    QRadioButton *InputRadioBatch;
    QGroupBox *groupBox_7;
    QGridLayout *gridLayout3;
    QLabel *label_2;
    QLabel *label;
    KUrlRequester *InputFileBoxBatch;
    KUrlRequester *OutputFileBoxBatch;
    QHBoxLayout *hboxLayout7;
    QSpacerItem *spacerItem4;
    QPushButton *runButtonBatch;
    QSpacerItem *spacerItem5;
    QSpacerItem *spacerItem6;

    void setupUi(QWidget *modCalcGeodCoordDlg)
    {
        if (modCalcGeodCoordDlg->objectName().isEmpty())
            modCalcGeodCoordDlg->setObjectName("modCalcGeodCoordDlg");
        modCalcGeodCoordDlg->resize(626, 466);
        vboxLayout = new QVBoxLayout(modCalcGeodCoordDlg);
#ifndef UI_Q_OS_MAC
        vboxLayout->setSpacing(6);
#endif
#ifndef UI_Q_OS_MAC
        vboxLayout->setContentsMargins(9, 9, 9, 9);
#endif
        vboxLayout->setObjectName("vboxLayout");
        tabWidget = new QTabWidget(modCalcGeodCoordDlg);
        tabWidget->setObjectName("tabWidget");
        interact = new QWidget();
        interact->setObjectName("interact");
        interact->setGeometry(QRect(0, 0, 596, 410));
        vboxLayout1 = new QVBoxLayout(interact);
#ifndef UI_Q_OS_MAC
        vboxLayout1->setSpacing(6);
#endif
#ifndef UI_Q_OS_MAC
        vboxLayout1->setContentsMargins(9, 9, 9, 9);
#endif
        vboxLayout1->setObjectName("vboxLayout1");
        hboxLayout = new QHBoxLayout();
#ifndef UI_Q_OS_MAC
        hboxLayout->setSpacing(6);
#endif
#ifndef UI_Q_OS_MAC
        hboxLayout->setContentsMargins(0, 0, 0, 0);
#endif
        hboxLayout->setObjectName("hboxLayout");
        groupBox = new QGroupBox(interact);
        groupBox->setObjectName("groupBox");
        hboxLayout1 = new QHBoxLayout(groupBox);
#ifndef UI_Q_OS_MAC
        hboxLayout1->setSpacing(6);
#endif
        hboxLayout1->setContentsMargins(8, 8, 8, 8);
        hboxLayout1->setObjectName("hboxLayout1");
        hboxLayout2 = new QHBoxLayout();
#ifndef UI_Q_OS_MAC
        hboxLayout2->setSpacing(6);
#endif
#ifndef UI_Q_OS_MAC
        hboxLayout2->setContentsMargins(0, 0, 0, 0);
#endif
        hboxLayout2->setObjectName("hboxLayout2");
        cartRadio = new QRadioButton(groupBox);
        cartRadio->setObjectName("cartRadio");

        hboxLayout2->addWidget(cartRadio);

        spheRadio = new QRadioButton(groupBox);
        spheRadio->setObjectName("spheRadio");
        spheRadio->setChecked(true);

        hboxLayout2->addWidget(spheRadio);


        hboxLayout1->addLayout(hboxLayout2);


        hboxLayout->addWidget(groupBox);

        groupBox_2 = new QGroupBox(interact);
        groupBox_2->setObjectName("groupBox_2");
        hboxLayout3 = new QHBoxLayout(groupBox_2);
#ifndef UI_Q_OS_MAC
        hboxLayout3->setSpacing(6);
#endif
        hboxLayout3->setContentsMargins(8, 8, 8, 8);
        hboxLayout3->setObjectName("hboxLayout3");
        ellipsoidBox = new QComboBox(groupBox_2);
        ellipsoidBox->setObjectName("ellipsoidBox");

        hboxLayout3->addWidget(ellipsoidBox);


        hboxLayout->addWidget(groupBox_2);


        vboxLayout1->addLayout(hboxLayout);

        hboxLayout4 = new QHBoxLayout();
#ifndef UI_Q_OS_MAC
        hboxLayout4->setSpacing(6);
#endif
        hboxLayout4->setContentsMargins(0, 0, 0, 0);
        hboxLayout4->setObjectName("hboxLayout4");
        spacerItem = new QSpacerItem(81, 20, QSizePolicy::Policy::Expanding, QSizePolicy::Policy::Minimum);

        hboxLayout4->addItem(spacerItem);

        Compute = new QPushButton(interact);
        Compute->setObjectName("Compute");

        hboxLayout4->addWidget(Compute);

        spacerItem1 = new QSpacerItem(51, 20, QSizePolicy::Policy::Expanding, QSizePolicy::Policy::Minimum);

        hboxLayout4->addItem(spacerItem1);

        Clear = new QPushButton(interact);
        Clear->setObjectName("Clear");

        hboxLayout4->addWidget(Clear);

        spacerItem2 = new QSpacerItem(91, 21, QSizePolicy::Policy::Expanding, QSizePolicy::Policy::Minimum);

        hboxLayout4->addItem(spacerItem2);


        vboxLayout1->addLayout(hboxLayout4);

        hboxLayout5 = new QHBoxLayout();
#ifndef UI_Q_OS_MAC
        hboxLayout5->setSpacing(6);
#endif
        hboxLayout5->setContentsMargins(0, 0, 0, 0);
        hboxLayout5->setObjectName("hboxLayout5");
        groupBox_3 = new QGroupBox(interact);
        groupBox_3->setObjectName("groupBox_3");
        gridLayout = new QGridLayout(groupBox_3);
#ifndef UI_Q_OS_MAC
        gridLayout->setSpacing(6);
#endif
        gridLayout->setContentsMargins(8, 8, 8, 8);
        gridLayout->setObjectName("gridLayout");
        XCartLabel = new QLabel(groupBox_3);
        XCartLabel->setObjectName("XCartLabel");

        gridLayout->addWidget(XCartLabel, 0, 0, 1, 1);

        YCartLabel = new QLabel(groupBox_3);
        YCartLabel->setObjectName("YCartLabel");

        gridLayout->addWidget(YCartLabel, 1, 0, 1, 1);

        ZCartLabel = new QLabel(groupBox_3);
        ZCartLabel->setObjectName("ZCartLabel");

        gridLayout->addWidget(ZCartLabel, 2, 0, 1, 1);

        ZGeoBox = new QLineEdit(groupBox_3);
        ZGeoBox->setObjectName("ZGeoBox");

        gridLayout->addWidget(ZGeoBox, 2, 1, 1, 1);

        XGeoBox = new QLineEdit(groupBox_3);
        XGeoBox->setObjectName("XGeoBox");

        gridLayout->addWidget(XGeoBox, 0, 1, 1, 1);

        YGeoBox = new QLineEdit(groupBox_3);
        YGeoBox->setObjectName("YGeoBox");

        gridLayout->addWidget(YGeoBox, 1, 1, 1, 1);


        hboxLayout5->addWidget(groupBox_3);

        groupBox_4 = new QGroupBox(interact);
        groupBox_4->setObjectName("groupBox_4");
        gridLayout1 = new QGridLayout(groupBox_4);
#ifndef UI_Q_OS_MAC
        gridLayout1->setSpacing(6);
#endif
        gridLayout1->setContentsMargins(8, 8, 8, 8);
        gridLayout1->setObjectName("gridLayout1");
        AltGeoLabel = new QLabel(groupBox_4);
        AltGeoLabel->setObjectName("AltGeoLabel");

        gridLayout1->addWidget(AltGeoLabel, 2, 0, 1, 2);

        AltGeoBox = new QLineEdit(groupBox_4);
        AltGeoBox->setObjectName("AltGeoBox");

        gridLayout1->addWidget(AltGeoBox, 2, 2, 1, 1);

        LongGeoLabel = new QLabel(groupBox_4);
        LongGeoLabel->setObjectName("LongGeoLabel");

        gridLayout1->addWidget(LongGeoLabel, 0, 0, 1, 1);

        LatGeoLabel = new QLabel(groupBox_4);
        LatGeoLabel->setObjectName("LatGeoLabel");

        gridLayout1->addWidget(LatGeoLabel, 1, 0, 1, 1);

        LongGeoBox = new dmsBox(groupBox_4);
        LongGeoBox->setObjectName("LongGeoBox");
        LongGeoBox->setMinimumSize(QSize(70, 0));
        LongGeoBox->setFocusPolicy(Qt::StrongFocus);

        gridLayout1->addWidget(LongGeoBox, 0, 1, 1, 2);

        LatGeoBox = new dmsBox(groupBox_4);
        LatGeoBox->setObjectName("LatGeoBox");
        LatGeoBox->setMinimumSize(QSize(70, 0));
        LatGeoBox->setFocusPolicy(Qt::StrongFocus);

        gridLayout1->addWidget(LatGeoBox, 1, 1, 1, 2);


        hboxLayout5->addWidget(groupBox_4);


        vboxLayout1->addLayout(hboxLayout5);

        spacerItem3 = new QSpacerItem(20, 40, QSizePolicy::Policy::Minimum, QSizePolicy::Policy::Expanding);

        vboxLayout1->addItem(spacerItem3);

        tabWidget->addTab(interact, QString());
        batch = new QWidget();
        batch->setObjectName("batch");
        batch->setGeometry(QRect(0, 0, 100, 30));
        vboxLayout2 = new QVBoxLayout(batch);
#ifndef UI_Q_OS_MAC
        vboxLayout2->setSpacing(6);
#endif
        vboxLayout2->setContentsMargins(8, 8, 8, 8);
        vboxLayout2->setObjectName("vboxLayout2");
        groupBox_5 = new QGroupBox(batch);
        groupBox_5->setObjectName("groupBox_5");
        gridLayout2 = new QGridLayout(groupBox_5);
#ifndef UI_Q_OS_MAC
        gridLayout2->setSpacing(6);
#endif
        gridLayout2->setContentsMargins(8, 8, 8, 8);
        gridLayout2->setObjectName("gridLayout2");
        YGeoCheckBatch = new QCheckBox(groupBox_5);
        YGeoCheckBatch->setObjectName("YGeoCheckBatch");
        YGeoCheckBatch->setEnabled(true);
        YGeoCheckBatch->setChecked(false);

        gridLayout2->addWidget(YGeoCheckBatch, 1, 2, 1, 1);

        ZGeoCheckBatch = new QCheckBox(groupBox_5);
        ZGeoCheckBatch->setObjectName("ZGeoCheckBatch");
        ZGeoCheckBatch->setEnabled(true);
        ZGeoCheckBatch->setChecked(false);

        gridLayout2->addWidget(ZGeoCheckBatch, 2, 2, 1, 1);

        ZGeoBoxBatch = new QLineEdit(groupBox_5);
        ZGeoBoxBatch->setObjectName("ZGeoBoxBatch");
        ZGeoBoxBatch->setEnabled(true);

        gridLayout2->addWidget(ZGeoBoxBatch, 2, 3, 1, 1);

        AltGeoBoxBatch = new QLineEdit(groupBox_5);
        AltGeoBoxBatch->setObjectName("AltGeoBoxBatch");
        AltGeoBoxBatch->setEnabled(false);

        gridLayout2->addWidget(AltGeoBoxBatch, 2, 1, 1, 1);

        AltGeoCheckBatch = new QCheckBox(groupBox_5);
        AltGeoCheckBatch->setObjectName("AltGeoCheckBatch");
        AltGeoCheckBatch->setChecked(true);

        gridLayout2->addWidget(AltGeoCheckBatch, 2, 0, 1, 1);

        XGeoCheckBatch = new QCheckBox(groupBox_5);
        XGeoCheckBatch->setObjectName("XGeoCheckBatch");
        XGeoCheckBatch->setEnabled(true);
        XGeoCheckBatch->setChecked(false);

        gridLayout2->addWidget(XGeoCheckBatch, 0, 2, 1, 1);

        LongGeoCheckBatch = new QCheckBox(groupBox_5);
        LongGeoCheckBatch->setObjectName("LongGeoCheckBatch");
        LongGeoCheckBatch->setChecked(true);

        gridLayout2->addWidget(LongGeoCheckBatch, 0, 0, 1, 1);

        LongGeoBoxBatch = new dmsBox(groupBox_5);
        LongGeoBoxBatch->setObjectName("LongGeoBoxBatch");
        LongGeoBoxBatch->setEnabled(false);
        LongGeoBoxBatch->setFocusPolicy(Qt::StrongFocus);

        gridLayout2->addWidget(LongGeoBoxBatch, 0, 1, 1, 1);

        LatGeoCheckBatch = new QCheckBox(groupBox_5);
        LatGeoCheckBatch->setObjectName("LatGeoCheckBatch");
        LatGeoCheckBatch->setChecked(true);

        gridLayout2->addWidget(LatGeoCheckBatch, 1, 0, 1, 1);

        XGeoBoxBatch = new QLineEdit(groupBox_5);
        XGeoBoxBatch->setObjectName("XGeoBoxBatch");
        XGeoBoxBatch->setEnabled(true);

        gridLayout2->addWidget(XGeoBoxBatch, 0, 3, 1, 1);

        LatGeoBoxBatch = new dmsBox(groupBox_5);
        LatGeoBoxBatch->setObjectName("LatGeoBoxBatch");
        LatGeoBoxBatch->setEnabled(false);
        LatGeoBoxBatch->setFocusPolicy(Qt::StrongFocus);

        gridLayout2->addWidget(LatGeoBoxBatch, 1, 1, 1, 1);

        YGeoBoxBatch = new QLineEdit(groupBox_5);
        YGeoBoxBatch->setObjectName("YGeoBoxBatch");
        YGeoBoxBatch->setEnabled(true);

        gridLayout2->addWidget(YGeoBoxBatch, 1, 3, 1, 1);


        vboxLayout2->addWidget(groupBox_5);

        groupBox_6 = new QGroupBox(batch);
        groupBox_6->setObjectName("groupBox_6");
        hboxLayout6 = new QHBoxLayout(groupBox_6);
#ifndef UI_Q_OS_MAC
        hboxLayout6->setSpacing(6);
#endif
        hboxLayout6->setContentsMargins(8, 8, 8, 8);
        hboxLayout6->setObjectName("hboxLayout6");
        AllRadioBatch = new QRadioButton(groupBox_6);
        AllRadioBatch->setObjectName("AllRadioBatch");

        hboxLayout6->addWidget(AllRadioBatch);

        InputRadioBatch = new QRadioButton(groupBox_6);
        InputRadioBatch->setObjectName("InputRadioBatch");
        InputRadioBatch->setChecked(true);

        hboxLayout6->addWidget(InputRadioBatch);


        vboxLayout2->addWidget(groupBox_6);

        groupBox_7 = new QGroupBox(batch);
        groupBox_7->setObjectName("groupBox_7");
        gridLayout3 = new QGridLayout(groupBox_7);
#ifndef UI_Q_OS_MAC
        gridLayout3->setSpacing(6);
#endif
        gridLayout3->setContentsMargins(8, 8, 8, 8);
        gridLayout3->setObjectName("gridLayout3");
        label_2 = new QLabel(groupBox_7);
        label_2->setObjectName("label_2");

        gridLayout3->addWidget(label_2, 1, 0, 1, 1);

        label = new QLabel(groupBox_7);
        label->setObjectName("label");

        gridLayout3->addWidget(label, 0, 0, 1, 1);

        InputFileBoxBatch = new KUrlRequester(groupBox_7);
        InputFileBoxBatch->setObjectName("InputFileBoxBatch");

        gridLayout3->addWidget(InputFileBoxBatch, 0, 1, 1, 1);

        OutputFileBoxBatch = new KUrlRequester(groupBox_7);
        OutputFileBoxBatch->setObjectName("OutputFileBoxBatch");

        gridLayout3->addWidget(OutputFileBoxBatch, 1, 1, 1, 1);


        vboxLayout2->addWidget(groupBox_7);

        hboxLayout7 = new QHBoxLayout();
#ifndef UI_Q_OS_MAC
        hboxLayout7->setSpacing(6);
#endif
        hboxLayout7->setContentsMargins(0, 0, 0, 0);
        hboxLayout7->setObjectName("hboxLayout7");
        spacerItem4 = new QSpacerItem(151, 21, QSizePolicy::Policy::Expanding, QSizePolicy::Policy::Minimum);

        hboxLayout7->addItem(spacerItem4);

        runButtonBatch = new QPushButton(batch);
        runButtonBatch->setObjectName("runButtonBatch");
        QSizePolicy sizePolicy(QSizePolicy::Policy::Expanding, QSizePolicy::Policy::Preferred);
        sizePolicy.setHorizontalStretch(0);
        sizePolicy.setVerticalStretch(0);
        sizePolicy.setHeightForWidth(runButtonBatch->sizePolicy().hasHeightForWidth());
        runButtonBatch->setSizePolicy(sizePolicy);

        hboxLayout7->addWidget(runButtonBatch);

        spacerItem5 = new QSpacerItem(131, 21, QSizePolicy::Policy::Expanding, QSizePolicy::Policy::Minimum);

        hboxLayout7->addItem(spacerItem5);


        vboxLayout2->addLayout(hboxLayout7);

        spacerItem6 = new QSpacerItem(520, 16, QSizePolicy::Policy::Minimum, QSizePolicy::Policy::Expanding);

        vboxLayout2->addItem(spacerItem6);

        tabWidget->addTab(batch, QString());

        vboxLayout->addWidget(tabWidget);


        retranslateUi(modCalcGeodCoordDlg);

        QMetaObject::connectSlotsByName(modCalcGeodCoordDlg);
    } // setupUi

    void retranslateUi(QWidget *modCalcGeodCoordDlg)
    {
        groupBox->setTitle(tr2i18n("Select Input Coordinates", nullptr));
        cartRadio->setText(tr2i18n("Cartesian", nullptr));
        spheRadio->setText(tr2i18n("Geographic", nullptr));
        groupBox_2->setTitle(tr2i18n("Select Ellipsoid Model", nullptr));
        Compute->setText(tr2i18n("Convert", nullptr));
        Clear->setText(tr2i18n("Clear", nullptr));
        groupBox_3->setTitle(tr2i18n("Cartesian Coordinates", nullptr));
        XCartLabel->setText(tr2i18n("X (km):", nullptr));
        YCartLabel->setText(tr2i18n("Y (km):", nullptr));
        ZCartLabel->setText(tr2i18n("Z (km):", nullptr));
        groupBox_4->setTitle(tr2i18n("Geographic Coordinates", nullptr));
        AltGeoLabel->setText(tr2i18n("Elevation (meters):", nullptr));
        AltGeoBox->setText(tr2i18n("0.0", nullptr));
        LongGeoLabel->setText(tr2i18n("Longitude:", nullptr));
        LatGeoLabel->setText(tr2i18n("Latitude:", nullptr));
        tabWidget->setTabText(tabWidget->indexOf(interact), tr2i18n("Interactive Mode", nullptr));
        groupBox_5->setTitle(tr2i18n("Select Parameters in Input File", nullptr));
        YGeoCheckBatch->setText(tr2i18n("Y (km):", nullptr));
        ZGeoCheckBatch->setText(tr2i18n("Z (km):", nullptr));
        AltGeoCheckBatch->setText(tr2i18n("Elev. (m):", nullptr));
        XGeoCheckBatch->setText(tr2i18n("X (km):", nullptr));
        LongGeoCheckBatch->setText(tr2i18n("Longitude:", nullptr));
        LatGeoCheckBatch->setText(tr2i18n("Latitude:", nullptr));
        groupBox_6->setTitle(tr2i18n("Select Parameters for Output File", nullptr));
        AllRadioBatch->setText(tr2i18n("All parameters", nullptr));
        InputRadioBatch->setText(tr2i18n("Only parameters in input file", nullptr));
        groupBox_7->setTitle(tr2i18n("Select Filenames", nullptr));
        label_2->setText(tr2i18n("Output file:", nullptr));
        label->setText(tr2i18n("Input file:", nullptr));
        runButtonBatch->setText(tr2i18n("Run", nullptr));
        tabWidget->setTabText(tabWidget->indexOf(batch), tr2i18n("Batch Mode", nullptr));
        (void)modCalcGeodCoordDlg;
    } // retranslateUi

};

namespace Ui {
    class modCalcGeodCoordDlg: public Ui_modCalcGeodCoordDlg {};
} // namespace Ui

QT_END_NAMESPACE

#endif // MODCALCGEOD_H

