/********************************************************************************
** Form generated from reading UI file 'modcalcapcoord.ui'
**
** Created by: Qt User Interface Compiler version 6.11.1
**
** WARNING! All changes made in this file will be lost when recompiling UI file!
********************************************************************************/

#ifndef UI_MODCALCAPCOORD_H
#define UI_MODCALCAPCOORD_H

#include <QtCore/QVariant>
#include <QtWidgets/QApplication>
#include <QtWidgets/QCheckBox>
#include <QtWidgets/QDateEdit>
#include <QtWidgets/QDoubleSpinBox>
#include <QtWidgets/QGridLayout>
#include <QtWidgets/QGroupBox>
#include <QtWidgets/QHBoxLayout>
#include <QtWidgets/QLabel>
#include <QtWidgets/QLineEdit>
#include <QtWidgets/QPushButton>
#include <QtWidgets/QRadioButton>
#include <QtWidgets/QSpacerItem>
#include <QtWidgets/QTabWidget>
#include <QtWidgets/QTimeEdit>
#include <QtWidgets/QVBoxLayout>
#include <QtWidgets/QWidget>
#include <klocalizedstring.h>
#include "kurlrequester.h"
#include "widgets/dmsbox.h"

QT_BEGIN_NAMESPACE

class Ui_modCalcApCoordDlg
{
public:
    QVBoxLayout *vboxLayout;
    QTabWidget *InteractiveTab;
    QWidget *tab1;
    QVBoxLayout *vboxLayout1;
    QHBoxLayout *hboxLayout;
    QGroupBox *groupBox_2;
    QGridLayout *gridLayout;
    QDoubleSpinBox *EpochCat;
    QLabel *DecLabel2;
    dmsBox *DecCat;
    QLabel *EpochLabel;
    dmsBox *RACat;
    QLabel *RaLabel;
    QSpacerItem *spacerItem;
    QPushButton *ObjectButton;
    QGroupBox *groupBox_3;
    QGridLayout *gridLayout1;
    QPushButton *NowButton;
    QSpacerItem *spacerItem1;
    QLabel *EpochLabel2;
    QLabel *EpochTarget;
    QLabel *dateLabel;
    QLabel *timeLabel;
    QTimeEdit *UT;
    QDateEdit *Date;
    QSpacerItem *spacerItem2;
    QLabel *ApCoordLabel;
    QHBoxLayout *hboxLayout1;
    QSpacerItem *spacerItem3;
    QGridLayout *gridLayout2;
    QLabel *Dec;
    QLabel *DecLabel;
    QLabel *RA;
    QLabel *RALabel;
    QSpacerItem *spacerItem4;
    QSpacerItem *spacerItem5;
    QWidget *tab2;
    QVBoxLayout *vboxLayout2;
    QGroupBox *groupBox_6;
    QHBoxLayout *hboxLayout2;
    QVBoxLayout *vboxLayout3;
    QCheckBox *utCheckBatch;
    QCheckBox *dateCheckBatch;
    QCheckBox *raCheckBatch;
    QCheckBox *decCheckBatch;
    QCheckBox *epochCheckBatch;
    QVBoxLayout *vboxLayout4;
    QTimeEdit *utBoxBatch;
    QDateEdit *dateBoxBatch;
    dmsBox *raBoxBatch;
    dmsBox *decBoxBatch;
    QLineEdit *epochBoxBatch;
    QGroupBox *groupBox_5;
    QHBoxLayout *hboxLayout3;
    QRadioButton *allRadioBatch;
    QRadioButton *inputRadioBatch;
    QGroupBox *groupBox_4;
    QGridLayout *gridLayout3;
    KUrlRequester *InputLineEditBatch;
    KUrlRequester *OutputLineEditBatch;
    QLabel *label_3;
    QLabel *label_4;
    QHBoxLayout *hboxLayout4;
    QSpacerItem *spacerItem6;
    QPushButton *runButtonBatch;
    QSpacerItem *spacerItem7;
    QSpacerItem *spacerItem8;

    void setupUi(QWidget *modCalcApCoordDlg)
    {
        if (modCalcApCoordDlg->objectName().isEmpty())
            modCalcApCoordDlg->setObjectName("modCalcApCoordDlg");
        modCalcApCoordDlg->resize(524, 534);
        modCalcApCoordDlg->setFocusPolicy(Qt::StrongFocus);
        vboxLayout = new QVBoxLayout(modCalcApCoordDlg);
        vboxLayout->setSpacing(6);
        vboxLayout->setObjectName("vboxLayout");
        vboxLayout->setContentsMargins(9, 9, 9, 9);
        InteractiveTab = new QTabWidget(modCalcApCoordDlg);
        InteractiveTab->setObjectName("InteractiveTab");
        tab1 = new QWidget();
        tab1->setObjectName("tab1");
        vboxLayout1 = new QVBoxLayout(tab1);
        vboxLayout1->setSpacing(6);
        vboxLayout1->setObjectName("vboxLayout1");
        vboxLayout1->setContentsMargins(9, 9, 9, 9);
        hboxLayout = new QHBoxLayout();
        hboxLayout->setSpacing(6);
        hboxLayout->setObjectName("hboxLayout");
        hboxLayout->setContentsMargins(0, 0, 0, 0);
        groupBox_2 = new QGroupBox(tab1);
        groupBox_2->setObjectName("groupBox_2");
        gridLayout = new QGridLayout(groupBox_2);
        gridLayout->setSpacing(6);
        gridLayout->setObjectName("gridLayout");
        gridLayout->setContentsMargins(9, 9, 9, 9);
        EpochCat = new QDoubleSpinBox(groupBox_2);
        EpochCat->setObjectName("EpochCat");
        EpochCat->setFocusPolicy(Qt::StrongFocus);
        EpochCat->setMaximum(50000.000000000000000);
        EpochCat->setValue(2000.000000000000000);
        EpochCat->setProperty("precision", QVariant(2));

        gridLayout->addWidget(EpochCat, 3, 1, 1, 1);

        DecLabel2 = new QLabel(groupBox_2);
        DecLabel2->setObjectName("DecLabel2");

        gridLayout->addWidget(DecLabel2, 2, 0, 1, 1);

        DecCat = new dmsBox(groupBox_2);
        DecCat->setObjectName("DecCat");

        gridLayout->addWidget(DecCat, 2, 1, 1, 1);

        EpochLabel = new QLabel(groupBox_2);
        EpochLabel->setObjectName("EpochLabel");

        gridLayout->addWidget(EpochLabel, 3, 0, 1, 1);

        RACat = new dmsBox(groupBox_2);
        RACat->setObjectName("RACat");
        RACat->setMinimumSize(QSize(80, 0));

        gridLayout->addWidget(RACat, 1, 1, 1, 1);

        RaLabel = new QLabel(groupBox_2);
        RaLabel->setObjectName("RaLabel");

        gridLayout->addWidget(RaLabel, 1, 0, 1, 1);

        spacerItem = new QSpacerItem(71, 20, QSizePolicy::Policy::Expanding, QSizePolicy::Policy::Minimum);

        gridLayout->addItem(spacerItem, 0, 0, 1, 1);

        ObjectButton = new QPushButton(groupBox_2);
        ObjectButton->setObjectName("ObjectButton");

        gridLayout->addWidget(ObjectButton, 0, 1, 1, 1);


        hboxLayout->addWidget(groupBox_2);

        groupBox_3 = new QGroupBox(tab1);
        groupBox_3->setObjectName("groupBox_3");
        gridLayout1 = new QGridLayout(groupBox_3);
        gridLayout1->setSpacing(6);
        gridLayout1->setObjectName("gridLayout1");
        gridLayout1->setContentsMargins(9, 9, 9, 9);
        NowButton = new QPushButton(groupBox_3);
        NowButton->setObjectName("NowButton");

        gridLayout1->addWidget(NowButton, 0, 1, 1, 1);

        spacerItem1 = new QSpacerItem(40, 20, QSizePolicy::Policy::Expanding, QSizePolicy::Policy::Minimum);

        gridLayout1->addItem(spacerItem1, 0, 0, 1, 1);

        EpochLabel2 = new QLabel(groupBox_3);
        EpochLabel2->setObjectName("EpochLabel2");

        gridLayout1->addWidget(EpochLabel2, 3, 0, 1, 1);

        EpochTarget = new QLabel(groupBox_3);
        EpochTarget->setObjectName("EpochTarget");
        QFont font;
        font.setFamilies({QString::fromUtf8("Monospace")});
        font.setPointSize(12);
        font.setBold(true);
        EpochTarget->setFont(font);

        gridLayout1->addWidget(EpochTarget, 3, 1, 1, 1);

        dateLabel = new QLabel(groupBox_3);
        dateLabel->setObjectName("dateLabel");

        gridLayout1->addWidget(dateLabel, 2, 0, 1, 1);

        timeLabel = new QLabel(groupBox_3);
        timeLabel->setObjectName("timeLabel");

        gridLayout1->addWidget(timeLabel, 1, 0, 1, 1);

        UT = new QTimeEdit(groupBox_3);
        UT->setObjectName("UT");

        gridLayout1->addWidget(UT, 1, 1, 1, 1);

        Date = new QDateEdit(groupBox_3);
        Date->setObjectName("Date");

        gridLayout1->addWidget(Date, 2, 1, 1, 1);


        hboxLayout->addWidget(groupBox_3);


        vboxLayout1->addLayout(hboxLayout);

        spacerItem2 = new QSpacerItem(40, 20, QSizePolicy::Policy::Expanding, QSizePolicy::Policy::Minimum);

        vboxLayout1->addItem(spacerItem2);

        ApCoordLabel = new QLabel(tab1);
        ApCoordLabel->setObjectName("ApCoordLabel");
        QFont font1;
        font1.setBold(true);
        ApCoordLabel->setFont(font1);

        vboxLayout1->addWidget(ApCoordLabel);

        hboxLayout1 = new QHBoxLayout();
        hboxLayout1->setSpacing(6);
        hboxLayout1->setObjectName("hboxLayout1");
        hboxLayout1->setContentsMargins(0, 0, 0, 0);
        spacerItem3 = new QSpacerItem(20, 20, QSizePolicy::Policy::Fixed, QSizePolicy::Policy::Minimum);

        hboxLayout1->addItem(spacerItem3);

        gridLayout2 = new QGridLayout();
        gridLayout2->setSpacing(6);
        gridLayout2->setObjectName("gridLayout2");
        gridLayout2->setContentsMargins(0, 0, 0, 0);
        Dec = new QLabel(tab1);
        Dec->setObjectName("Dec");
        Dec->setFont(font);
        Dec->setAlignment(Qt::AlignRight|Qt::AlignTrailing|Qt::AlignVCenter);
        Dec->setTextInteractionFlags(Qt::TextSelectableByMouse);

        gridLayout2->addWidget(Dec, 1, 1, 1, 1);

        DecLabel = new QLabel(tab1);
        DecLabel->setObjectName("DecLabel");

        gridLayout2->addWidget(DecLabel, 1, 0, 1, 1);

        RA = new QLabel(tab1);
        RA->setObjectName("RA");
        RA->setFont(font);
        RA->setAlignment(Qt::AlignRight|Qt::AlignTrailing|Qt::AlignVCenter);
        RA->setTextInteractionFlags(Qt::TextSelectableByMouse);

        gridLayout2->addWidget(RA, 0, 1, 1, 1);

        RALabel = new QLabel(tab1);
        RALabel->setObjectName("RALabel");

        gridLayout2->addWidget(RALabel, 0, 0, 1, 1);


        hboxLayout1->addLayout(gridLayout2);

        spacerItem4 = new QSpacerItem(40, 20, QSizePolicy::Policy::Expanding, QSizePolicy::Policy::Minimum);

        hboxLayout1->addItem(spacerItem4);


        vboxLayout1->addLayout(hboxLayout1);

        spacerItem5 = new QSpacerItem(20, 70, QSizePolicy::Policy::Minimum, QSizePolicy::Policy::Expanding);

        vboxLayout1->addItem(spacerItem5);

        InteractiveTab->addTab(tab1, QString());
        tab2 = new QWidget();
        tab2->setObjectName("tab2");
        vboxLayout2 = new QVBoxLayout(tab2);
        vboxLayout2->setSpacing(6);
        vboxLayout2->setObjectName("vboxLayout2");
        vboxLayout2->setContentsMargins(8, 8, 8, 8);
        groupBox_6 = new QGroupBox(tab2);
        groupBox_6->setObjectName("groupBox_6");
        hboxLayout2 = new QHBoxLayout(groupBox_6);
        hboxLayout2->setSpacing(6);
        hboxLayout2->setObjectName("hboxLayout2");
        hboxLayout2->setContentsMargins(8, 8, 8, 8);
        vboxLayout3 = new QVBoxLayout();
        vboxLayout3->setSpacing(6);
        vboxLayout3->setObjectName("vboxLayout3");
        vboxLayout3->setContentsMargins(0, 0, 0, 0);
        utCheckBatch = new QCheckBox(groupBox_6);
        utCheckBatch->setObjectName("utCheckBatch");
        utCheckBatch->setChecked(true);

        vboxLayout3->addWidget(utCheckBatch);

        dateCheckBatch = new QCheckBox(groupBox_6);
        dateCheckBatch->setObjectName("dateCheckBatch");
        dateCheckBatch->setChecked(true);

        vboxLayout3->addWidget(dateCheckBatch);

        raCheckBatch = new QCheckBox(groupBox_6);
        raCheckBatch->setObjectName("raCheckBatch");
        raCheckBatch->setChecked(true);

        vboxLayout3->addWidget(raCheckBatch);

        decCheckBatch = new QCheckBox(groupBox_6);
        decCheckBatch->setObjectName("decCheckBatch");
        decCheckBatch->setChecked(true);

        vboxLayout3->addWidget(decCheckBatch);

        epochCheckBatch = new QCheckBox(groupBox_6);
        epochCheckBatch->setObjectName("epochCheckBatch");

        vboxLayout3->addWidget(epochCheckBatch);


        hboxLayout2->addLayout(vboxLayout3);

        vboxLayout4 = new QVBoxLayout();
        vboxLayout4->setSpacing(6);
        vboxLayout4->setObjectName("vboxLayout4");
        vboxLayout4->setContentsMargins(0, 0, 0, 0);
        utBoxBatch = new QTimeEdit(groupBox_6);
        utBoxBatch->setObjectName("utBoxBatch");
        utBoxBatch->setEnabled(false);

        vboxLayout4->addWidget(utBoxBatch);

        dateBoxBatch = new QDateEdit(groupBox_6);
        dateBoxBatch->setObjectName("dateBoxBatch");
        dateBoxBatch->setEnabled(false);

        vboxLayout4->addWidget(dateBoxBatch);

        raBoxBatch = new dmsBox(groupBox_6);
        raBoxBatch->setObjectName("raBoxBatch");
        raBoxBatch->setEnabled(false);

        vboxLayout4->addWidget(raBoxBatch);

        decBoxBatch = new dmsBox(groupBox_6);
        decBoxBatch->setObjectName("decBoxBatch");
        decBoxBatch->setEnabled(false);

        vboxLayout4->addWidget(decBoxBatch);

        epochBoxBatch = new QLineEdit(groupBox_6);
        epochBoxBatch->setObjectName("epochBoxBatch");
        QSizePolicy sizePolicy(QSizePolicy::Policy::Fixed, QSizePolicy::Policy::Fixed);
        sizePolicy.setHorizontalStretch(0);
        sizePolicy.setVerticalStretch(0);
        sizePolicy.setHeightForWidth(epochBoxBatch->sizePolicy().hasHeightForWidth());
        epochBoxBatch->setSizePolicy(sizePolicy);

        vboxLayout4->addWidget(epochBoxBatch);


        hboxLayout2->addLayout(vboxLayout4);


        vboxLayout2->addWidget(groupBox_6);

        groupBox_5 = new QGroupBox(tab2);
        groupBox_5->setObjectName("groupBox_5");
        hboxLayout3 = new QHBoxLayout(groupBox_5);
        hboxLayout3->setSpacing(6);
        hboxLayout3->setObjectName("hboxLayout3");
        hboxLayout3->setContentsMargins(8, 8, 8, 8);
        allRadioBatch = new QRadioButton(groupBox_5);
        allRadioBatch->setObjectName("allRadioBatch");

        hboxLayout3->addWidget(allRadioBatch);

        inputRadioBatch = new QRadioButton(groupBox_5);
        inputRadioBatch->setObjectName("inputRadioBatch");
        inputRadioBatch->setChecked(true);

        hboxLayout3->addWidget(inputRadioBatch);


        vboxLayout2->addWidget(groupBox_5);

        groupBox_4 = new QGroupBox(tab2);
        groupBox_4->setObjectName("groupBox_4");
        gridLayout3 = new QGridLayout(groupBox_4);
        gridLayout3->setSpacing(6);
        gridLayout3->setObjectName("gridLayout3");
        gridLayout3->setContentsMargins(8, 8, 8, 8);
        InputLineEditBatch = new KUrlRequester(groupBox_4);
        InputLineEditBatch->setObjectName("InputLineEditBatch");

        gridLayout3->addWidget(InputLineEditBatch, 0, 1, 1, 1);

        OutputLineEditBatch = new KUrlRequester(groupBox_4);
        OutputLineEditBatch->setObjectName("OutputLineEditBatch");

        gridLayout3->addWidget(OutputLineEditBatch, 1, 1, 1, 1);

        label_3 = new QLabel(groupBox_4);
        label_3->setObjectName("label_3");

        gridLayout3->addWidget(label_3, 0, 0, 1, 1);

        label_4 = new QLabel(groupBox_4);
        label_4->setObjectName("label_4");

        gridLayout3->addWidget(label_4, 1, 0, 1, 1);


        vboxLayout2->addWidget(groupBox_4);

        hboxLayout4 = new QHBoxLayout();
        hboxLayout4->setSpacing(6);
        hboxLayout4->setObjectName("hboxLayout4");
        hboxLayout4->setContentsMargins(0, 0, 0, 0);
        spacerItem6 = new QSpacerItem(151, 21, QSizePolicy::Policy::Expanding, QSizePolicy::Policy::Minimum);

        hboxLayout4->addItem(spacerItem6);

        runButtonBatch = new QPushButton(tab2);
        runButtonBatch->setObjectName("runButtonBatch");
        QSizePolicy sizePolicy1(QSizePolicy::Policy::Expanding, QSizePolicy::Policy::Preferred);
        sizePolicy1.setHorizontalStretch(0);
        sizePolicy1.setVerticalStretch(0);
        sizePolicy1.setHeightForWidth(runButtonBatch->sizePolicy().hasHeightForWidth());
        runButtonBatch->setSizePolicy(sizePolicy1);

        hboxLayout4->addWidget(runButtonBatch);

        spacerItem7 = new QSpacerItem(131, 21, QSizePolicy::Policy::Expanding, QSizePolicy::Policy::Minimum);

        hboxLayout4->addItem(spacerItem7);


        vboxLayout2->addLayout(hboxLayout4);

        spacerItem8 = new QSpacerItem(20, 31, QSizePolicy::Policy::Minimum, QSizePolicy::Policy::Expanding);

        vboxLayout2->addItem(spacerItem8);

        InteractiveTab->addTab(tab2, QString());

        vboxLayout->addWidget(InteractiveTab);

        QWidget::setTabOrder(InteractiveTab, ObjectButton);
        QWidget::setTabOrder(ObjectButton, RACat);
        QWidget::setTabOrder(RACat, DecCat);
        QWidget::setTabOrder(DecCat, EpochCat);
        QWidget::setTabOrder(EpochCat, NowButton);
        QWidget::setTabOrder(NowButton, UT);
        QWidget::setTabOrder(UT, InputLineEditBatch);
        QWidget::setTabOrder(InputLineEditBatch, decCheckBatch);
        QWidget::setTabOrder(decCheckBatch, OutputLineEditBatch);
        QWidget::setTabOrder(OutputLineEditBatch, runButtonBatch);
        QWidget::setTabOrder(runButtonBatch, inputRadioBatch);
        QWidget::setTabOrder(inputRadioBatch, raCheckBatch);
        QWidget::setTabOrder(raCheckBatch, dateCheckBatch);
        QWidget::setTabOrder(dateCheckBatch, utBoxBatch);
        QWidget::setTabOrder(utBoxBatch, raBoxBatch);
        QWidget::setTabOrder(raBoxBatch, decBoxBatch);
        QWidget::setTabOrder(decBoxBatch, allRadioBatch);
        QWidget::setTabOrder(allRadioBatch, utCheckBatch);
        QWidget::setTabOrder(utCheckBatch, epochBoxBatch);
        QWidget::setTabOrder(epochBoxBatch, epochCheckBatch);

        retranslateUi(modCalcApCoordDlg);

        InteractiveTab->setCurrentIndex(0);


        QMetaObject::connectSlotsByName(modCalcApCoordDlg);
    } // setupUi

    void retranslateUi(QWidget *modCalcApCoordDlg)
    {
        modCalcApCoordDlg->setWindowTitle(tr2i18n("Apparent Coordinates", nullptr));
        groupBox_2->setTitle(tr2i18n("Catalog Coordinates", nullptr));
        DecLabel2->setText(tr2i18n("Declination:", nullptr));
        EpochLabel->setText(tr2i18n("Epoch:", nullptr));
        RaLabel->setText(tr2i18n("Right ascension:", nullptr));
        ObjectButton->setText(tr2i18n("Select Object...", nullptr));
        groupBox_3->setTitle(tr2i18n("Target Time && Date", nullptr));
        NowButton->setText(tr2i18n("Reset to Now", nullptr));
        EpochLabel2->setText(tr2i18n("Epoch:", nullptr));
        EpochTarget->setText(tr2i18n("2000.0", nullptr));
        dateLabel->setText(tr2i18n("Date:", nullptr));
        timeLabel->setText(tr2i18n("UT:", nullptr));
        ApCoordLabel->setText(tr2i18n("Apparent coordinates:", nullptr));
        Dec->setText(tr2i18n("+00d 00' 00.0\"", nullptr));
        DecLabel->setText(tr2i18n("Declination:", nullptr));
        RA->setText(tr2i18n("00h 00m 00.0s", nullptr));
        RALabel->setText(tr2i18n("Right ascension:", nullptr));
        InteractiveTab->setTabText(InteractiveTab->indexOf(tab1), tr2i18n("Interactive Mode", nullptr));
        groupBox_6->setTitle(tr2i18n("Select Fields in Input File", nullptr));
        utCheckBatch->setText(tr2i18n("UT:", nullptr));
        dateCheckBatch->setText(tr2i18n("Date:", nullptr));
        raCheckBatch->setText(tr2i18n("Right ascension:", nullptr));
        decCheckBatch->setText(tr2i18n("Declination:", nullptr));
        epochCheckBatch->setText(tr2i18n("Epoch:", nullptr));
        groupBox_5->setTitle(tr2i18n("Show in Output File", nullptr));
        allRadioBatch->setText(tr2i18n("All parameters", nullptr));
        inputRadioBatch->setText(tr2i18n("Only parameters in input file", nullptr));
        groupBox_4->setTitle(tr2i18n("Files", nullptr));
        label_3->setText(tr2i18n("Input file:", nullptr));
        label_4->setText(tr2i18n("Output file:", nullptr));
        runButtonBatch->setText(tr2i18n("Run", nullptr));
        InteractiveTab->setTabText(InteractiveTab->indexOf(tab2), tr2i18n("Batch Mode", nullptr));
    } // retranslateUi

};

namespace Ui {
    class modCalcApCoordDlg: public Ui_modCalcApCoordDlg {};
} // namespace Ui

QT_END_NAMESPACE

#endif // MODCALCAPCOORD_H

