/****************************************************************************
** Meta object code from reading C++ file 'equipmentwriter.h'
**
** Created by: The Qt Meta Object Compiler version 69 (Qt 6.11.1)
**
** WARNING! All changes made in this file will be lost!
*****************************************************************************/

#include "../../../../kstars-3.8.4.1/kstars/oal/equipmentwriter.h"
#include <QtGui/qtextcursor.h>
#include <QtCore/qmetatype.h>

#include <QtCore/qtmochelpers.h>

#include <memory>


#include <QtCore/qxptype_traits.h>
#if !defined(Q_MOC_OUTPUT_REVISION)
#error "The header file 'equipmentwriter.h' doesn't include <QObject>."
#elif Q_MOC_OUTPUT_REVISION != 69
#error "This file was generated using the moc from 6.11.1. It"
#error "cannot be used with the include files from this version of Qt."
#error "(The moc has changed too much.)"
#endif

#ifndef Q_CONSTINIT
#define Q_CONSTINIT
#endif

QT_WARNING_PUSH
QT_WARNING_DISABLE_DEPRECATED
QT_WARNING_DISABLE_GCC("-Wuseless-cast")
namespace {
struct qt_meta_tag_ZN15EquipmentWriterE_t {};
} // unnamed namespace

template <> constexpr inline auto EquipmentWriter::qt_create_metaobjectdata<qt_meta_tag_ZN15EquipmentWriterE_t>()
{
    namespace QMC = QtMocConstants;
    QtMocHelpers::StringRefStorage qt_stringData {
        "EquipmentWriter",
        "slotAddScope",
        "",
        "slotAddEyepiece",
        "slotAddLens",
        "slotAddFilter",
        "slotSaveScope",
        "slotSaveEyepiece",
        "slotSaveLens",
        "slotSaveFilter",
        "slotRemoveScope",
        "slotRemoveEyepiece",
        "slotRemoveLens",
        "slotRemoveFilter",
        "slotSetScope",
        "slotSetEyepiece",
        "slotSetLens",
        "slotSetFilter",
        "slotNewScope",
        "slotNewEyepiece",
        "slotNewLens",
        "slotNewFilter",
        "slotClose",
        "slotSave",
        "slotNewDSLRLens",
        "slotAddDSLRLens",
        "slotSaveDSLRLens",
        "slotRemoveDSLRLens",
        "slotSetDSLRLens"
    };

    QtMocHelpers::UintData qt_methods {
        // Slot 'slotAddScope'
        QtMocHelpers::SlotData<void()>(1, 2, QMC::AccessPublic, QMetaType::Void),
        // Slot 'slotAddEyepiece'
        QtMocHelpers::SlotData<void()>(3, 2, QMC::AccessPublic, QMetaType::Void),
        // Slot 'slotAddLens'
        QtMocHelpers::SlotData<void()>(4, 2, QMC::AccessPublic, QMetaType::Void),
        // Slot 'slotAddFilter'
        QtMocHelpers::SlotData<void()>(5, 2, QMC::AccessPublic, QMetaType::Void),
        // Slot 'slotSaveScope'
        QtMocHelpers::SlotData<void()>(6, 2, QMC::AccessPublic, QMetaType::Void),
        // Slot 'slotSaveEyepiece'
        QtMocHelpers::SlotData<void()>(7, 2, QMC::AccessPublic, QMetaType::Void),
        // Slot 'slotSaveLens'
        QtMocHelpers::SlotData<void()>(8, 2, QMC::AccessPublic, QMetaType::Void),
        // Slot 'slotSaveFilter'
        QtMocHelpers::SlotData<void()>(9, 2, QMC::AccessPublic, QMetaType::Void),
        // Slot 'slotRemoveScope'
        QtMocHelpers::SlotData<void()>(10, 2, QMC::AccessPublic, QMetaType::Void),
        // Slot 'slotRemoveEyepiece'
        QtMocHelpers::SlotData<void()>(11, 2, QMC::AccessPublic, QMetaType::Void),
        // Slot 'slotRemoveLens'
        QtMocHelpers::SlotData<void()>(12, 2, QMC::AccessPublic, QMetaType::Void),
        // Slot 'slotRemoveFilter'
        QtMocHelpers::SlotData<void()>(13, 2, QMC::AccessPublic, QMetaType::Void),
        // Slot 'slotSetScope'
        QtMocHelpers::SlotData<void(QString)>(14, 2, QMC::AccessPublic, QMetaType::Void, {{
            { QMetaType::QString, 2 },
        }}),
        // Slot 'slotSetEyepiece'
        QtMocHelpers::SlotData<void(QString)>(15, 2, QMC::AccessPublic, QMetaType::Void, {{
            { QMetaType::QString, 2 },
        }}),
        // Slot 'slotSetLens'
        QtMocHelpers::SlotData<void(QString)>(16, 2, QMC::AccessPublic, QMetaType::Void, {{
            { QMetaType::QString, 2 },
        }}),
        // Slot 'slotSetFilter'
        QtMocHelpers::SlotData<void(QString)>(17, 2, QMC::AccessPublic, QMetaType::Void, {{
            { QMetaType::QString, 2 },
        }}),
        // Slot 'slotNewScope'
        QtMocHelpers::SlotData<void()>(18, 2, QMC::AccessPublic, QMetaType::Void),
        // Slot 'slotNewEyepiece'
        QtMocHelpers::SlotData<void()>(19, 2, QMC::AccessPublic, QMetaType::Void),
        // Slot 'slotNewLens'
        QtMocHelpers::SlotData<void()>(20, 2, QMC::AccessPublic, QMetaType::Void),
        // Slot 'slotNewFilter'
        QtMocHelpers::SlotData<void()>(21, 2, QMC::AccessPublic, QMetaType::Void),
        // Slot 'slotClose'
        QtMocHelpers::SlotData<void()>(22, 2, QMC::AccessPublic, QMetaType::Void),
        // Slot 'slotSave'
        QtMocHelpers::SlotData<void()>(23, 2, QMC::AccessPublic, QMetaType::Void),
        // Slot 'slotNewDSLRLens'
        QtMocHelpers::SlotData<void()>(24, 2, QMC::AccessPublic, QMetaType::Void),
        // Slot 'slotAddDSLRLens'
        QtMocHelpers::SlotData<void()>(25, 2, QMC::AccessPublic, QMetaType::Void),
        // Slot 'slotSaveDSLRLens'
        QtMocHelpers::SlotData<void()>(26, 2, QMC::AccessPublic, QMetaType::Void),
        // Slot 'slotRemoveDSLRLens'
        QtMocHelpers::SlotData<void()>(27, 2, QMC::AccessPublic, QMetaType::Void),
        // Slot 'slotSetDSLRLens'
        QtMocHelpers::SlotData<void(QString)>(28, 2, QMC::AccessPublic, QMetaType::Void, {{
            { QMetaType::QString, 2 },
        }}),
    };
    QtMocHelpers::UintData qt_properties {
    };
    QtMocHelpers::UintData qt_enums {
    };
    return QtMocHelpers::metaObjectData<EquipmentWriter, qt_meta_tag_ZN15EquipmentWriterE_t>(QMC::MetaObjectFlag{}, qt_stringData,
            qt_methods, qt_properties, qt_enums);
}
Q_CONSTINIT const QMetaObject EquipmentWriter::staticMetaObject = { {
    QMetaObject::SuperData::link<QDialog::staticMetaObject>(),
    qt_staticMetaObjectStaticContent<qt_meta_tag_ZN15EquipmentWriterE_t>.stringdata,
    qt_staticMetaObjectStaticContent<qt_meta_tag_ZN15EquipmentWriterE_t>.data,
    qt_static_metacall,
    nullptr,
    qt_staticMetaObjectRelocatingContent<qt_meta_tag_ZN15EquipmentWriterE_t>.metaTypes,
    nullptr
} };

void EquipmentWriter::qt_static_metacall(QObject *_o, QMetaObject::Call _c, int _id, void **_a)
{
    auto *_t = static_cast<EquipmentWriter *>(_o);
    if (_c == QMetaObject::InvokeMetaMethod) {
        switch (_id) {
        case 0: _t->slotAddScope(); break;
        case 1: _t->slotAddEyepiece(); break;
        case 2: _t->slotAddLens(); break;
        case 3: _t->slotAddFilter(); break;
        case 4: _t->slotSaveScope(); break;
        case 5: _t->slotSaveEyepiece(); break;
        case 6: _t->slotSaveLens(); break;
        case 7: _t->slotSaveFilter(); break;
        case 8: _t->slotRemoveScope(); break;
        case 9: _t->slotRemoveEyepiece(); break;
        case 10: _t->slotRemoveLens(); break;
        case 11: _t->slotRemoveFilter(); break;
        case 12: _t->slotSetScope((*reinterpret_cast<std::add_pointer_t<QString>>(_a[1]))); break;
        case 13: _t->slotSetEyepiece((*reinterpret_cast<std::add_pointer_t<QString>>(_a[1]))); break;
        case 14: _t->slotSetLens((*reinterpret_cast<std::add_pointer_t<QString>>(_a[1]))); break;
        case 15: _t->slotSetFilter((*reinterpret_cast<std::add_pointer_t<QString>>(_a[1]))); break;
        case 16: _t->slotNewScope(); break;
        case 17: _t->slotNewEyepiece(); break;
        case 18: _t->slotNewLens(); break;
        case 19: _t->slotNewFilter(); break;
        case 20: _t->slotClose(); break;
        case 21: _t->slotSave(); break;
        case 22: _t->slotNewDSLRLens(); break;
        case 23: _t->slotAddDSLRLens(); break;
        case 24: _t->slotSaveDSLRLens(); break;
        case 25: _t->slotRemoveDSLRLens(); break;
        case 26: _t->slotSetDSLRLens((*reinterpret_cast<std::add_pointer_t<QString>>(_a[1]))); break;
        default: ;
        }
    }
}

const QMetaObject *EquipmentWriter::metaObject() const
{
    return QObject::d_ptr->metaObject ? QObject::d_ptr->dynamicMetaObject() : &staticMetaObject;
}

void *EquipmentWriter::qt_metacast(const char *_clname)
{
    if (!_clname) return nullptr;
    if (!strcmp(_clname, qt_staticMetaObjectStaticContent<qt_meta_tag_ZN15EquipmentWriterE_t>.strings))
        return static_cast<void*>(this);
    return QDialog::qt_metacast(_clname);
}

int EquipmentWriter::qt_metacall(QMetaObject::Call _c, int _id, void **_a)
{
    _id = QDialog::qt_metacall(_c, _id, _a);
    if (_id < 0)
        return _id;
    if (_c == QMetaObject::InvokeMetaMethod) {
        if (_id < 27)
            qt_static_metacall(this, _c, _id, _a);
        _id -= 27;
    }
    if (_c == QMetaObject::RegisterMethodArgumentMetaType) {
        if (_id < 27)
            *reinterpret_cast<QMetaType *>(_a[0]) = QMetaType();
        _id -= 27;
    }
    return _id;
}
QT_WARNING_POP
