/****************************************************************************
** Meta object code from reading C++ file 'horizonmanager.h'
**
** Created by: The Qt Meta Object Compiler version 69 (Qt 6.11.1)
**
** WARNING! All changes made in this file will be lost!
*****************************************************************************/

#include "../../../../kstars-3.8.4.1/kstars/tools/horizonmanager.h"
#include <QtCore/qmetatype.h>

#include <QtCore/qtmochelpers.h>

#include <memory>


#include <QtCore/qxptype_traits.h>
#if !defined(Q_MOC_OUTPUT_REVISION)
#error "The header file 'horizonmanager.h' doesn't include <QObject>."
#elif Q_MOC_OUTPUT_REVISION != 69
#error "This file was generated using the moc from 6.11.1. It"
#error "cannot be used with the include files from this version of Qt."
#error "(The moc has changed too much.)"
#endif

#ifndef Q_CONSTINIT
#define Q_CONSTINIT
#endif

QT_WARNING_PUSH
QT_WARNING_DISABLE_DEPRECATED
QT_WARNING_DISABLE_GCC("-Wuseless-cast")
namespace {
struct qt_meta_tag_ZN16HorizonManagerUIE_t {};
} // unnamed namespace

template <> constexpr inline auto HorizonManagerUI::qt_create_metaobjectdata<qt_meta_tag_ZN16HorizonManagerUIE_t>()
{
    namespace QMC = QtMocConstants;
    QtMocHelpers::StringRefStorage qt_stringData {
        "HorizonManagerUI"
    };

    QtMocHelpers::UintData qt_methods {
    };
    QtMocHelpers::UintData qt_properties {
    };
    QtMocHelpers::UintData qt_enums {
    };
    return QtMocHelpers::metaObjectData<HorizonManagerUI, qt_meta_tag_ZN16HorizonManagerUIE_t>(QMC::MetaObjectFlag{}, qt_stringData,
            qt_methods, qt_properties, qt_enums);
}
Q_CONSTINIT const QMetaObject HorizonManagerUI::staticMetaObject = { {
    QMetaObject::SuperData::link<QFrame::staticMetaObject>(),
    qt_staticMetaObjectStaticContent<qt_meta_tag_ZN16HorizonManagerUIE_t>.stringdata,
    qt_staticMetaObjectStaticContent<qt_meta_tag_ZN16HorizonManagerUIE_t>.data,
    qt_static_metacall,
    nullptr,
    qt_staticMetaObjectRelocatingContent<qt_meta_tag_ZN16HorizonManagerUIE_t>.metaTypes,
    nullptr
} };

void HorizonManagerUI::qt_static_metacall(QObject *_o, QMetaObject::Call _c, int _id, void **_a)
{
    auto *_t = static_cast<HorizonManagerUI *>(_o);
    (void)_t;
    (void)_c;
    (void)_id;
    (void)_a;
}

const QMetaObject *HorizonManagerUI::metaObject() const
{
    return QObject::d_ptr->metaObject ? QObject::d_ptr->dynamicMetaObject() : &staticMetaObject;
}

void *HorizonManagerUI::qt_metacast(const char *_clname)
{
    if (!_clname) return nullptr;
    if (!strcmp(_clname, qt_staticMetaObjectStaticContent<qt_meta_tag_ZN16HorizonManagerUIE_t>.strings))
        return static_cast<void*>(this);
    if (!strcmp(_clname, "Ui::HorizonManager"))
        return static_cast< Ui::HorizonManager*>(this);
    return QFrame::qt_metacast(_clname);
}

int HorizonManagerUI::qt_metacall(QMetaObject::Call _c, int _id, void **_a)
{
    _id = QFrame::qt_metacall(_c, _id, _a);
    return _id;
}
namespace {
struct qt_meta_tag_ZN14HorizonManagerE_t {};
} // unnamed namespace

template <> constexpr inline auto HorizonManager::qt_create_metaobjectdata<qt_meta_tag_ZN14HorizonManagerE_t>()
{
    namespace QMC = QtMocConstants;
    QtMocHelpers::StringRefStorage qt_stringData {
        "HorizonManager",
        "slotAddRegion",
        "",
        "slotRemoveRegion",
        "slotToggleCeiling",
        "addSkyPoint",
        "SkyPoint*",
        "skypoint",
        "slotAddPoint",
        "slotRemovePoint",
        "slotClosed",
        "clearPoints",
        "importHorizon",
        "exportHorizon",
        "setSelectPoints",
        "slotCurrentPointChanged",
        "QModelIndex",
        "current",
        "previous",
        "verifyItemValue",
        "QStandardItem*",
        "item",
        "slotSaveChanges",
        "slotSetShownRegion",
        "idx"
    };

    QtMocHelpers::UintData qt_methods {
        // Slot 'slotAddRegion'
        QtMocHelpers::SlotData<void()>(1, 2, QMC::AccessPublic, QMetaType::Void),
        // Slot 'slotRemoveRegion'
        QtMocHelpers::SlotData<void()>(3, 2, QMC::AccessPublic, QMetaType::Void),
        // Slot 'slotToggleCeiling'
        QtMocHelpers::SlotData<void()>(4, 2, QMC::AccessPublic, QMetaType::Void),
        // Slot 'addSkyPoint'
        QtMocHelpers::SlotData<void(SkyPoint *)>(5, 2, QMC::AccessPublic, QMetaType::Void, {{
            { 0x80000000 | 6, 7 },
        }}),
        // Slot 'slotAddPoint'
        QtMocHelpers::SlotData<void()>(8, 2, QMC::AccessPublic, QMetaType::Void),
        // Slot 'slotRemovePoint'
        QtMocHelpers::SlotData<void()>(9, 2, QMC::AccessPublic, QMetaType::Void),
        // Slot 'slotClosed'
        QtMocHelpers::SlotData<void()>(10, 2, QMC::AccessPublic, QMetaType::Void),
        // Slot 'clearPoints'
        QtMocHelpers::SlotData<void()>(11, 2, QMC::AccessPublic, QMetaType::Void),
        // Slot 'importHorizon'
        QtMocHelpers::SlotData<void()>(12, 2, QMC::AccessPublic, QMetaType::Void),
        // Slot 'exportHorizon'
        QtMocHelpers::SlotData<void()>(13, 2, QMC::AccessPublic, QMetaType::Void),
        // Slot 'setSelectPoints'
        QtMocHelpers::SlotData<void(bool)>(14, 2, QMC::AccessPublic, QMetaType::Void, {{
            { QMetaType::Bool, 2 },
        }}),
        // Slot 'slotCurrentPointChanged'
        QtMocHelpers::SlotData<void(const QModelIndex &, const QModelIndex &)>(15, 2, QMC::AccessPublic, QMetaType::Void, {{
            { 0x80000000 | 16, 17 }, { 0x80000000 | 16, 18 },
        }}),
        // Slot 'verifyItemValue'
        QtMocHelpers::SlotData<void(QStandardItem *)>(19, 2, QMC::AccessPrivate, QMetaType::Void, {{
            { 0x80000000 | 20, 21 },
        }}),
        // Slot 'slotSaveChanges'
        QtMocHelpers::SlotData<void()>(22, 2, QMC::AccessPrivate, QMetaType::Void),
        // Slot 'slotSetShownRegion'
        QtMocHelpers::SlotData<void(QModelIndex)>(23, 2, QMC::AccessPrivate, QMetaType::Void, {{
            { 0x80000000 | 16, 24 },
        }}),
    };
    QtMocHelpers::UintData qt_properties {
    };
    QtMocHelpers::UintData qt_enums {
    };
    return QtMocHelpers::metaObjectData<HorizonManager, qt_meta_tag_ZN14HorizonManagerE_t>(QMC::MetaObjectFlag{}, qt_stringData,
            qt_methods, qt_properties, qt_enums);
}
Q_CONSTINIT const QMetaObject HorizonManager::staticMetaObject = { {
    QMetaObject::SuperData::link<QDialog::staticMetaObject>(),
    qt_staticMetaObjectStaticContent<qt_meta_tag_ZN14HorizonManagerE_t>.stringdata,
    qt_staticMetaObjectStaticContent<qt_meta_tag_ZN14HorizonManagerE_t>.data,
    qt_static_metacall,
    nullptr,
    qt_staticMetaObjectRelocatingContent<qt_meta_tag_ZN14HorizonManagerE_t>.metaTypes,
    nullptr
} };

void HorizonManager::qt_static_metacall(QObject *_o, QMetaObject::Call _c, int _id, void **_a)
{
    auto *_t = static_cast<HorizonManager *>(_o);
    if (_c == QMetaObject::InvokeMetaMethod) {
        switch (_id) {
        case 0: _t->slotAddRegion(); break;
        case 1: _t->slotRemoveRegion(); break;
        case 2: _t->slotToggleCeiling(); break;
        case 3: _t->addSkyPoint((*reinterpret_cast<std::add_pointer_t<SkyPoint*>>(_a[1]))); break;
        case 4: _t->slotAddPoint(); break;
        case 5: _t->slotRemovePoint(); break;
        case 6: _t->slotClosed(); break;
        case 7: _t->clearPoints(); break;
        case 8: _t->importHorizon(); break;
        case 9: _t->exportHorizon(); break;
        case 10: _t->setSelectPoints((*reinterpret_cast<std::add_pointer_t<bool>>(_a[1]))); break;
        case 11: _t->slotCurrentPointChanged((*reinterpret_cast<std::add_pointer_t<QModelIndex>>(_a[1])),(*reinterpret_cast<std::add_pointer_t<QModelIndex>>(_a[2]))); break;
        case 12: _t->verifyItemValue((*reinterpret_cast<std::add_pointer_t<QStandardItem*>>(_a[1]))); break;
        case 13: _t->slotSaveChanges(); break;
        case 14: _t->slotSetShownRegion((*reinterpret_cast<std::add_pointer_t<QModelIndex>>(_a[1]))); break;
        default: ;
        }
    }
}

const QMetaObject *HorizonManager::metaObject() const
{
    return QObject::d_ptr->metaObject ? QObject::d_ptr->dynamicMetaObject() : &staticMetaObject;
}

void *HorizonManager::qt_metacast(const char *_clname)
{
    if (!_clname) return nullptr;
    if (!strcmp(_clname, qt_staticMetaObjectStaticContent<qt_meta_tag_ZN14HorizonManagerE_t>.strings))
        return static_cast<void*>(this);
    return QDialog::qt_metacast(_clname);
}

int HorizonManager::qt_metacall(QMetaObject::Call _c, int _id, void **_a)
{
    _id = QDialog::qt_metacall(_c, _id, _a);
    if (_id < 0)
        return _id;
    if (_c == QMetaObject::InvokeMetaMethod) {
        if (_id < 15)
            qt_static_metacall(this, _c, _id, _a);
        _id -= 15;
    }
    if (_c == QMetaObject::RegisterMethodArgumentMetaType) {
        if (_id < 15)
            *reinterpret_cast<QMetaType *>(_a[0]) = QMetaType();
        _id -= 15;
    }
    return _id;
}
QT_WARNING_POP
