/****************************************************************************
** Meta object code from reading C++ file 'meridianflipstate.h'
**
** Created by: The Qt Meta Object Compiler version 69 (Qt 6.11.1)
**
** WARNING! All changes made in this file will be lost!
*****************************************************************************/

#include "../../../../kstars-3.8.4.1/kstars/ekos/manager/meridianflipstate.h"
#include <QtCore/qmetatype.h>

#include <QtCore/qtmochelpers.h>

#include <memory>


#include <QtCore/qxptype_traits.h>
#if !defined(Q_MOC_OUTPUT_REVISION)
#error "The header file 'meridianflipstate.h' doesn't include <QObject>."
#elif Q_MOC_OUTPUT_REVISION != 69
#error "This file was generated using the moc from 6.11.1. It"
#error "cannot be used with the include files from this version of Qt."
#error "(The moc has changed too much.)"
#endif

#ifndef Q_CONSTINIT
#define Q_CONSTINIT
#endif

QT_WARNING_PUSH
QT_WARNING_DISABLE_DEPRECATED
QT_WARNING_DISABLE_GCC("-Wuseless-cast")
namespace {
struct qt_meta_tag_ZN4Ekos17MeridianFlipStateE_t {};
} // unnamed namespace

template <> constexpr inline auto Ekos::MeridianFlipState::qt_create_metaobjectdata<qt_meta_tag_ZN4Ekos17MeridianFlipStateE_t>()
{
    namespace QMC = QtMocConstants;
    QtMocHelpers::StringRefStorage qt_stringData {
        "Ekos::MeridianFlipState",
        "newMountMFStatus",
        "",
        "MeridianFlipMountState",
        "status",
        "newMeridianFlipMountStatusText",
        "text",
        "slewTelescope",
        "SkyPoint&",
        "target",
        "newLog",
        "setCaptureState",
        "CaptureState",
        "state",
        "setMountStatus",
        "ISD::Mount::Status",
        "setMountParkStatus",
        "ISD::ParkStatus",
        "updateTelescopeCoord",
        "SkyPoint",
        "position",
        "ISD::Mount::PierSide",
        "pierSide",
        "dms",
        "ha"
    };

    QtMocHelpers::UintData qt_methods {
        // Signal 'newMountMFStatus'
        QtMocHelpers::SignalData<void(MeridianFlipMountState)>(1, 2, QMC::AccessPublic, QMetaType::Void, {{
            { 0x80000000 | 3, 4 },
        }}),
        // Signal 'newMeridianFlipMountStatusText'
        QtMocHelpers::SignalData<void(const QString &)>(5, 2, QMC::AccessPublic, QMetaType::Void, {{
            { QMetaType::QString, 6 },
        }}),
        // Signal 'slewTelescope'
        QtMocHelpers::SignalData<void(SkyPoint &)>(7, 2, QMC::AccessPublic, QMetaType::Void, {{
            { 0x80000000 | 8, 9 },
        }}),
        // Signal 'newLog'
        QtMocHelpers::SignalData<void(const QString &)>(10, 2, QMC::AccessPublic, QMetaType::Void, {{
            { QMetaType::QString, 6 },
        }}),
        // Slot 'setCaptureState'
        QtMocHelpers::SlotData<void(CaptureState)>(11, 2, QMC::AccessPublic, QMetaType::Void, {{
            { 0x80000000 | 12, 13 },
        }}),
        // Slot 'setMountStatus'
        QtMocHelpers::SlotData<void(ISD::Mount::Status)>(14, 2, QMC::AccessPublic, QMetaType::Void, {{
            { 0x80000000 | 15, 4 },
        }}),
        // Slot 'setMountParkStatus'
        QtMocHelpers::SlotData<void(ISD::ParkStatus)>(16, 2, QMC::AccessPublic, QMetaType::Void, {{
            { 0x80000000 | 17, 4 },
        }}),
        // Slot 'updateTelescopeCoord'
        QtMocHelpers::SlotData<void(const SkyPoint &, ISD::Mount::PierSide, const dms &)>(18, 2, QMC::AccessPublic, QMetaType::Void, {{
            { 0x80000000 | 19, 20 }, { 0x80000000 | 21, 22 }, { 0x80000000 | 23, 24 },
        }}),
    };
    QtMocHelpers::UintData qt_properties {
    };
    QtMocHelpers::UintData qt_enums {
    };
    return QtMocHelpers::metaObjectData<MeridianFlipState, qt_meta_tag_ZN4Ekos17MeridianFlipStateE_t>(QMC::MetaObjectFlag{}, qt_stringData,
            qt_methods, qt_properties, qt_enums);
}
Q_CONSTINIT const QMetaObject Ekos::MeridianFlipState::staticMetaObject = { {
    QMetaObject::SuperData::link<QObject::staticMetaObject>(),
    qt_staticMetaObjectStaticContent<qt_meta_tag_ZN4Ekos17MeridianFlipStateE_t>.stringdata,
    qt_staticMetaObjectStaticContent<qt_meta_tag_ZN4Ekos17MeridianFlipStateE_t>.data,
    qt_static_metacall,
    nullptr,
    qt_staticMetaObjectRelocatingContent<qt_meta_tag_ZN4Ekos17MeridianFlipStateE_t>.metaTypes,
    nullptr
} };

void Ekos::MeridianFlipState::qt_static_metacall(QObject *_o, QMetaObject::Call _c, int _id, void **_a)
{
    auto *_t = static_cast<MeridianFlipState *>(_o);
    if (_c == QMetaObject::InvokeMetaMethod) {
        switch (_id) {
        case 0: _t->newMountMFStatus((*reinterpret_cast<std::add_pointer_t<MeridianFlipMountState>>(_a[1]))); break;
        case 1: _t->newMeridianFlipMountStatusText((*reinterpret_cast<std::add_pointer_t<QString>>(_a[1]))); break;
        case 2: _t->slewTelescope((*reinterpret_cast<std::add_pointer_t<SkyPoint&>>(_a[1]))); break;
        case 3: _t->newLog((*reinterpret_cast<std::add_pointer_t<QString>>(_a[1]))); break;
        case 4: _t->setCaptureState((*reinterpret_cast<std::add_pointer_t<CaptureState>>(_a[1]))); break;
        case 5: _t->setMountStatus((*reinterpret_cast<std::add_pointer_t<ISD::Mount::Status>>(_a[1]))); break;
        case 6: _t->setMountParkStatus((*reinterpret_cast<std::add_pointer_t<ISD::ParkStatus>>(_a[1]))); break;
        case 7: _t->updateTelescopeCoord((*reinterpret_cast<std::add_pointer_t<SkyPoint>>(_a[1])),(*reinterpret_cast<std::add_pointer_t<ISD::Mount::PierSide>>(_a[2])),(*reinterpret_cast<std::add_pointer_t<dms>>(_a[3]))); break;
        default: ;
        }
    }
    if (_c == QMetaObject::RegisterMethodArgumentMetaType) {
        switch (_id) {
        default: *reinterpret_cast<QMetaType *>(_a[0]) = QMetaType(); break;
        case 5:
            switch (*reinterpret_cast<int*>(_a[1])) {
            default: *reinterpret_cast<QMetaType *>(_a[0]) = QMetaType(); break;
            case 0:
                *reinterpret_cast<QMetaType *>(_a[0]) = QMetaType::fromType< ISD::Mount::Status >(); break;
            }
            break;
        case 6:
            switch (*reinterpret_cast<int*>(_a[1])) {
            default: *reinterpret_cast<QMetaType *>(_a[0]) = QMetaType(); break;
            case 0:
                *reinterpret_cast<QMetaType *>(_a[0]) = QMetaType::fromType< ISD::ParkStatus >(); break;
            }
            break;
        case 7:
            switch (*reinterpret_cast<int*>(_a[1])) {
            default: *reinterpret_cast<QMetaType *>(_a[0]) = QMetaType(); break;
            case 1:
                *reinterpret_cast<QMetaType *>(_a[0]) = QMetaType::fromType< ISD::Mount::PierSide >(); break;
            case 0:
                *reinterpret_cast<QMetaType *>(_a[0]) = QMetaType::fromType< SkyPoint >(); break;
            }
            break;
        }
    }
    if (_c == QMetaObject::IndexOfMethod) {
        if (QtMocHelpers::indexOfMethod<void (MeridianFlipState::*)(MeridianFlipMountState )>(_a, &MeridianFlipState::newMountMFStatus, 0))
            return;
        if (QtMocHelpers::indexOfMethod<void (MeridianFlipState::*)(const QString & )>(_a, &MeridianFlipState::newMeridianFlipMountStatusText, 1))
            return;
        if (QtMocHelpers::indexOfMethod<void (MeridianFlipState::*)(SkyPoint & )>(_a, &MeridianFlipState::slewTelescope, 2))
            return;
        if (QtMocHelpers::indexOfMethod<void (MeridianFlipState::*)(const QString & )>(_a, &MeridianFlipState::newLog, 3))
            return;
    }
}

const QMetaObject *Ekos::MeridianFlipState::metaObject() const
{
    return QObject::d_ptr->metaObject ? QObject::d_ptr->dynamicMetaObject() : &staticMetaObject;
}

void *Ekos::MeridianFlipState::qt_metacast(const char *_clname)
{
    if (!_clname) return nullptr;
    if (!strcmp(_clname, qt_staticMetaObjectStaticContent<qt_meta_tag_ZN4Ekos17MeridianFlipStateE_t>.strings))
        return static_cast<void*>(this);
    return QObject::qt_metacast(_clname);
}

int Ekos::MeridianFlipState::qt_metacall(QMetaObject::Call _c, int _id, void **_a)
{
    _id = QObject::qt_metacall(_c, _id, _a);
    if (_id < 0)
        return _id;
    if (_c == QMetaObject::InvokeMetaMethod) {
        if (_id < 8)
            qt_static_metacall(this, _c, _id, _a);
        _id -= 8;
    }
    if (_c == QMetaObject::RegisterMethodArgumentMetaType) {
        if (_id < 8)
            qt_static_metacall(this, _c, _id, _a);
        _id -= 8;
    }
    return _id;
}

// SIGNAL 0
void Ekos::MeridianFlipState::newMountMFStatus(MeridianFlipMountState _t1)
{
    QMetaObject::activate<void>(this, &staticMetaObject, 0, nullptr, _t1);
}

// SIGNAL 1
void Ekos::MeridianFlipState::newMeridianFlipMountStatusText(const QString & _t1)
{
    QMetaObject::activate<void>(this, &staticMetaObject, 1, nullptr, _t1);
}

// SIGNAL 2
void Ekos::MeridianFlipState::slewTelescope(SkyPoint & _t1)
{
    QMetaObject::activate<void>(this, &staticMetaObject, 2, nullptr, _t1);
}

// SIGNAL 3
void Ekos::MeridianFlipState::newLog(const QString & _t1)
{
    QMetaObject::activate<void>(this, &staticMetaObject, 3, nullptr, _t1);
}
QT_WARNING_POP
