/*
 * This file was generated by qdbusxml2cpp version 0.8
 * Source file was org.kde.kstars.FOV.xml
 *
 * qdbusxml2cpp is Copyright (C) The Qt Company Ltd. and other contributors.
 *
 * This is an auto-generated file.
 * This file may have been hand-edited. Look for HAND-EDIT comments
 * before re-generating it.
 */

#ifndef FOVADAPTOR_H
#define FOVADAPTOR_H

#include <QtCore/QObject>
#include <QtDBus/QtDBus>
#include "fov.h"
#include <QtCore/qcontainerfwd.h>

/*
 * Adaptor class for interface org.kde.kstars.fov
 */
class FovAdaptor: public QDBusAbstractAdaptor
{
    Q_OBJECT
    Q_CLASSINFO("D-Bus Interface", "org.kde.kstars.fov")
    Q_CLASSINFO("D-Bus Introspection", ""
"  <interface name=\"org.kde.kstars.fov\">\n"
"    <property access=\"readwrite\" type=\"s\" name=\"name\"/>\n"
"    <property access=\"readwrite\" type=\"d\" name=\"sizeX\"/>\n"
"    <property access=\"readwrite\" type=\"d\" name=\"sizeY\"/>\n"
"    <property access=\"readwrite\" type=\"d\" name=\"offsetX\"/>\n"
"    <property access=\"readwrite\" type=\"d\" name=\"offsetY\"/>\n"
"    <property access=\"readwrite\" type=\"d\" name=\"PA\"/>\n"
"    <property access=\"readwrite\" type=\"s\" name=\"color\"/>\n"
"    <property access=\"readwrite\" type=\"b\" name=\"cpLock\"/>\n"
"    <property access=\"readwrite\" type=\"(i)\" name=\"shape\">\n"
"      <annotation value=\"FOV::Shape\" name=\"org.qtproject.QtDBus.QtTypeName\"/>\n"
"    </property>\n"
"  </interface>\n"
        "")
public:
    FovAdaptor(FOV *parent);
    ~FovAdaptor() override;

    inline FOV *parent() const
    { return static_cast<FOV *>(QObject::parent()); }

public: // PROPERTIES
    Q_PROPERTY(double PA READ pA WRITE setPA)
    double pA() const;
    void setPA(double value);

    Q_PROPERTY(QString color READ color WRITE setColor)
    QString color() const;
    void setColor(const QString &value);

    Q_PROPERTY(bool cpLock READ cpLock WRITE setCpLock)
    bool cpLock() const;
    void setCpLock(bool value);

    Q_PROPERTY(QString name READ name WRITE setName)
    QString name() const;
    void setName(const QString &value);

    Q_PROPERTY(double offsetX READ offsetX WRITE setOffsetX)
    double offsetX() const;
    void setOffsetX(double value);

    Q_PROPERTY(double offsetY READ offsetY WRITE setOffsetY)
    double offsetY() const;
    void setOffsetY(double value);

    Q_PROPERTY(FOV::Shape shape READ shape WRITE setShape)
    FOV::Shape shape() const;
    void setShape(FOV::Shape value);

    Q_PROPERTY(double sizeX READ sizeX WRITE setSizeX)
    double sizeX() const;
    void setSizeX(double value);

    Q_PROPERTY(double sizeY READ sizeY WRITE setSizeY)
    double sizeY() const;
    void setSizeY(double value);

public Q_SLOTS: // METHODS
Q_SIGNALS: // SIGNALS
};

#endif
