/********************************************************************************
** Form generated from reading UI file 'skycalendar.ui'
**
** Created by: Qt User Interface Compiler version 6.11.1
**
** WARNING! All changes made in this file will be lost when recompiling UI file!
********************************************************************************/

#ifndef UI_SKYCALENDAR_H
#define UI_SKYCALENDAR_H

#include <QtCore/QVariant>
#include <QtWidgets/QApplication>
#include <QtWidgets/QCheckBox>
#include <QtWidgets/QFormLayout>
#include <QtWidgets/QGridLayout>
#include <QtWidgets/QGroupBox>
#include <QtWidgets/QHBoxLayout>
#include <QtWidgets/QLabel>
#include <QtWidgets/QPushButton>
#include <QtWidgets/QSpacerItem>
#include <QtWidgets/QSpinBox>
#include <QtWidgets/QVBoxLayout>
#include <QtWidgets/QWidget>
#include <klocalizedstring.h>
#include "kplotwidget.h"
#include "tools/calendarwidget.h"

QT_BEGIN_NAMESPACE

class Ui_SkyCalendar
{
public:
    QVBoxLayout *verticalLayout;
    QHBoxLayout *horizontalLayout_2;
    QGroupBox *groupBox;
    QGridLayout *gridLayout_2;
    QCheckBox *checkBox_Mercury;
    QCheckBox *checkBox_Venus;
    QCheckBox *checkBox_Mars;
    QCheckBox *checkBox_Jupiter;
    QCheckBox *checkBox_Saturn;
    QCheckBox *checkBox_Neptune;
    QCheckBox *checkBox_Uranus;
    QGroupBox *groupBox_2;
    QHBoxLayout *horizontalLayout_3;
    QVBoxLayout *verticalLayout_6;
    QCheckBox *checkBox_GridMonths;
    QCheckBox *checkBox_GridWeeks;
    QVBoxLayout *verticalLayout_7;
    QCheckBox *checkBox_GridVertical;
    QCheckBox *checkBox_GridToday;
    QSpacerItem *horizontalSpacer_2;
    QGroupBox *groupBox_3;
    QHBoxLayout *horizontalLayout;
    QFormLayout *formLayout;
    QLabel *label_2;
    QSpinBox *Year;
    QLabel *label;
    QHBoxLayout *horizontalLayout_6;
    QSpinBox *spinBox_Interval;
    QLabel *label_3;
    QVBoxLayout *verticalLayout_9;
    QPushButton *LocationButton;
    QHBoxLayout *horizontalLayout_7;
    QSpacerItem *horizontalSpacer;
    QPushButton *CreateButton;
    CalendarWidget *CalendarView;

    void setupUi(QWidget *SkyCalendar)
    {
        if (SkyCalendar->objectName().isEmpty())
            SkyCalendar->setObjectName("SkyCalendar");
        SkyCalendar->resize(972, 725);
        QSizePolicy sizePolicy(QSizePolicy::Policy::Preferred, QSizePolicy::Policy::Expanding);
        sizePolicy.setHorizontalStretch(0);
        sizePolicy.setVerticalStretch(0);
        sizePolicy.setHeightForWidth(SkyCalendar->sizePolicy().hasHeightForWidth());
        SkyCalendar->setSizePolicy(sizePolicy);
        verticalLayout = new QVBoxLayout(SkyCalendar);
        verticalLayout->setObjectName("verticalLayout");
        horizontalLayout_2 = new QHBoxLayout();
        horizontalLayout_2->setObjectName("horizontalLayout_2");
        groupBox = new QGroupBox(SkyCalendar);
        groupBox->setObjectName("groupBox");
        gridLayout_2 = new QGridLayout(groupBox);
        gridLayout_2->setObjectName("gridLayout_2");
        checkBox_Mercury = new QCheckBox(groupBox);
        checkBox_Mercury->setObjectName("checkBox_Mercury");

        gridLayout_2->addWidget(checkBox_Mercury, 0, 0, 1, 1);

        checkBox_Venus = new QCheckBox(groupBox);
        checkBox_Venus->setObjectName("checkBox_Venus");

        gridLayout_2->addWidget(checkBox_Venus, 0, 1, 1, 1);

        checkBox_Mars = new QCheckBox(groupBox);
        checkBox_Mars->setObjectName("checkBox_Mars");

        gridLayout_2->addWidget(checkBox_Mars, 0, 2, 1, 1);

        checkBox_Jupiter = new QCheckBox(groupBox);
        checkBox_Jupiter->setObjectName("checkBox_Jupiter");

        gridLayout_2->addWidget(checkBox_Jupiter, 0, 3, 1, 1);

        checkBox_Saturn = new QCheckBox(groupBox);
        checkBox_Saturn->setObjectName("checkBox_Saturn");

        gridLayout_2->addWidget(checkBox_Saturn, 1, 0, 1, 1);

        checkBox_Neptune = new QCheckBox(groupBox);
        checkBox_Neptune->setObjectName("checkBox_Neptune");

        gridLayout_2->addWidget(checkBox_Neptune, 1, 1, 1, 1);

        checkBox_Uranus = new QCheckBox(groupBox);
        checkBox_Uranus->setObjectName("checkBox_Uranus");

        gridLayout_2->addWidget(checkBox_Uranus, 1, 2, 1, 1);


        horizontalLayout_2->addWidget(groupBox);

        groupBox_2 = new QGroupBox(SkyCalendar);
        groupBox_2->setObjectName("groupBox_2");
        groupBox_2->setFlat(false);
        groupBox_2->setCheckable(false);
        horizontalLayout_3 = new QHBoxLayout(groupBox_2);
        horizontalLayout_3->setObjectName("horizontalLayout_3");
        verticalLayout_6 = new QVBoxLayout();
        verticalLayout_6->setObjectName("verticalLayout_6");
        checkBox_GridMonths = new QCheckBox(groupBox_2);
        checkBox_GridMonths->setObjectName("checkBox_GridMonths");
        checkBox_GridMonths->setChecked(true);

        verticalLayout_6->addWidget(checkBox_GridMonths);

        checkBox_GridWeeks = new QCheckBox(groupBox_2);
        checkBox_GridWeeks->setObjectName("checkBox_GridWeeks");

        verticalLayout_6->addWidget(checkBox_GridWeeks);


        horizontalLayout_3->addLayout(verticalLayout_6);

        verticalLayout_7 = new QVBoxLayout();
        verticalLayout_7->setObjectName("verticalLayout_7");
        checkBox_GridVertical = new QCheckBox(groupBox_2);
        checkBox_GridVertical->setObjectName("checkBox_GridVertical");
        checkBox_GridVertical->setChecked(true);

        verticalLayout_7->addWidget(checkBox_GridVertical);

        checkBox_GridToday = new QCheckBox(groupBox_2);
        checkBox_GridToday->setObjectName("checkBox_GridToday");

        verticalLayout_7->addWidget(checkBox_GridToday);


        horizontalLayout_3->addLayout(verticalLayout_7);


        horizontalLayout_2->addWidget(groupBox_2);

        horizontalSpacer_2 = new QSpacerItem(40, 20, QSizePolicy::Policy::Expanding, QSizePolicy::Policy::Minimum);

        horizontalLayout_2->addItem(horizontalSpacer_2);

        groupBox_3 = new QGroupBox(SkyCalendar);
        groupBox_3->setObjectName("groupBox_3");
        horizontalLayout = new QHBoxLayout(groupBox_3);
        horizontalLayout->setObjectName("horizontalLayout");
        formLayout = new QFormLayout();
        formLayout->setObjectName("formLayout");
        label_2 = new QLabel(groupBox_3);
        label_2->setObjectName("label_2");
        label_2->setAlignment(Qt::AlignRight|Qt::AlignTrailing|Qt::AlignVCenter);

        formLayout->setWidget(0, QFormLayout::ItemRole::LabelRole, label_2);

        Year = new QSpinBox(groupBox_3);
        Year->setObjectName("Year");
        Year->setAlignment(Qt::AlignRight|Qt::AlignTrailing|Qt::AlignVCenter);
        Year->setMinimum(-4713);
        Year->setMaximum(9999);
        Year->setValue(2000);

        formLayout->setWidget(0, QFormLayout::ItemRole::FieldRole, Year);

        label = new QLabel(groupBox_3);
        label->setObjectName("label");

        formLayout->setWidget(1, QFormLayout::ItemRole::LabelRole, label);

        horizontalLayout_6 = new QHBoxLayout();
        horizontalLayout_6->setObjectName("horizontalLayout_6");
        spinBox_Interval = new QSpinBox(groupBox_3);
        spinBox_Interval->setObjectName("spinBox_Interval");
        spinBox_Interval->setMinimum(1);
        spinBox_Interval->setMaximum(31);
        spinBox_Interval->setValue(7);

        horizontalLayout_6->addWidget(spinBox_Interval);

        label_3 = new QLabel(groupBox_3);
        label_3->setObjectName("label_3");

        horizontalLayout_6->addWidget(label_3);


        formLayout->setLayout(1, QFormLayout::ItemRole::FieldRole, horizontalLayout_6);


        horizontalLayout->addLayout(formLayout);

        verticalLayout_9 = new QVBoxLayout();
        verticalLayout_9->setObjectName("verticalLayout_9");
        LocationButton = new QPushButton(groupBox_3);
        LocationButton->setObjectName("LocationButton");

        verticalLayout_9->addWidget(LocationButton);

        horizontalLayout_7 = new QHBoxLayout();
        horizontalLayout_7->setObjectName("horizontalLayout_7");
        horizontalSpacer = new QSpacerItem(40, 20, QSizePolicy::Policy::MinimumExpanding, QSizePolicy::Policy::Minimum);

        horizontalLayout_7->addItem(horizontalSpacer);

        CreateButton = new QPushButton(groupBox_3);
        CreateButton->setObjectName("CreateButton");
        QSizePolicy sizePolicy1(QSizePolicy::Policy::Fixed, QSizePolicy::Policy::Fixed);
        sizePolicy1.setHorizontalStretch(0);
        sizePolicy1.setVerticalStretch(0);
        sizePolicy1.setHeightForWidth(CreateButton->sizePolicy().hasHeightForWidth());
        CreateButton->setSizePolicy(sizePolicy1);

        horizontalLayout_7->addWidget(CreateButton);


        verticalLayout_9->addLayout(horizontalLayout_7);


        horizontalLayout->addLayout(verticalLayout_9);


        horizontalLayout_2->addWidget(groupBox_3);


        verticalLayout->addLayout(horizontalLayout_2);

        CalendarView = new CalendarWidget(SkyCalendar);
        CalendarView->setObjectName("CalendarView");
        sizePolicy.setHeightForWidth(CalendarView->sizePolicy().hasHeightForWidth());
        CalendarView->setSizePolicy(sizePolicy);
        CalendarView->setMinimumSize(QSize(480, 500));
        CalendarView->setProperty("grid", QVariant(false));

        verticalLayout->addWidget(CalendarView);

#if QT_CONFIG(shortcut)
        label_2->setBuddy(Year);
#endif // QT_CONFIG(shortcut)
        QWidget::setTabOrder(checkBox_Mercury, checkBox_Venus);
        QWidget::setTabOrder(checkBox_Venus, checkBox_Mars);
        QWidget::setTabOrder(checkBox_Mars, checkBox_Jupiter);
        QWidget::setTabOrder(checkBox_Jupiter, checkBox_Saturn);
        QWidget::setTabOrder(checkBox_Saturn, checkBox_Neptune);
        QWidget::setTabOrder(checkBox_Neptune, checkBox_Uranus);
        QWidget::setTabOrder(checkBox_Uranus, checkBox_GridMonths);
        QWidget::setTabOrder(checkBox_GridMonths, checkBox_GridWeeks);
        QWidget::setTabOrder(checkBox_GridWeeks, checkBox_GridVertical);

        retranslateUi(SkyCalendar);

        QMetaObject::connectSlotsByName(SkyCalendar);
    } // setupUi

    void retranslateUi(QWidget *SkyCalendar)
    {
        SkyCalendar->setWindowTitle(tr2i18n("Sky Calendar", nullptr));
        groupBox->setTitle(tr2i18n("Planets", nullptr));
        checkBox_Mercury->setText(tr2i18n("Mercury", nullptr));
        checkBox_Venus->setText(tr2i18n("Venus", nullptr));
        checkBox_Mars->setText(tr2i18n("Mars", nullptr));
        checkBox_Jupiter->setText(tr2i18n("Jupiter", nullptr));
        checkBox_Saturn->setText(tr2i18n("Saturn", nullptr));
        checkBox_Neptune->setText(tr2i18n("Neptune", nullptr));
        checkBox_Uranus->setText(tr2i18n("Uranus", nullptr));
        groupBox_2->setTitle(tr2i18n("Grids and Labels", nullptr));
        checkBox_GridMonths->setText(tr2i18n("Month dividers", nullptr));
        checkBox_GridWeeks->setText(tr2i18n("Interval dividers", nullptr));
        checkBox_GridVertical->setText(tr2i18n("Vertical grid", nullptr));
        checkBox_GridToday->setText(tr2i18n("Current day", nullptr));
        groupBox_3->setTitle(QString());
        label_2->setText(tr2i18n("Year:", nullptr));
        label->setText(tr2i18n("Interval:", nullptr));
        label_3->setText(tr2i18n("day(s)", nullptr));
        LocationButton->setText(tr2i18n("Greenwich, United Kingdom", nullptr));
        CreateButton->setText(tr2i18n("Plot Planetary Almanac", nullptr));
    } // retranslateUi

};

namespace Ui {
    class SkyCalendar: public Ui_SkyCalendar {};
} // namespace Ui

QT_END_NAMESPACE

#endif // SKYCALENDAR_H

