/********************************************************************************
** Form generated from reading UI file 'fitsstretchui.ui'
**
** Created by: Qt User Interface Compiler version 6.11.1
**
** WARNING! All changes made in this file will be lost when recompiling UI file!
********************************************************************************/

#ifndef UI_FITSSTRETCHUI_H
#define UI_FITSSTRETCHUI_H

#include <QtCore/QVariant>
#include <QtWidgets/QApplication>
#include <QtWidgets/QDoubleSpinBox>
#include <QtWidgets/QFrame>
#include <QtWidgets/QHBoxLayout>
#include <QtWidgets/QLabel>
#include <QtWidgets/QPushButton>
#include <QtWidgets/QVBoxLayout>
#include <QtWidgets/QWidget>
#include <klocalizedstring.h>
#include "auxiliary/ctk3slider.h"
#include "qcustomplot.h"

QT_BEGIN_NAMESPACE

class Ui_FITSStretchUI
{
public:
    QVBoxLayout *verticalLayout;
    QCustomPlot *histoPlot;
    ctk3Slider *histoSlider;
    QHBoxLayout *horizLayout;
    QPushButton *stretchButton;
    QFrame *line1;
    QLabel *shadowsLabel;
    QDoubleSpinBox *shadowsVal;
    QFrame *line2;
    QLabel *midtonesLabel;
    QDoubleSpinBox *midtonesVal;
    QFrame *line3;
    QLabel *highlightsLabel;
    QDoubleSpinBox *highlightsVal;
    QFrame *line4;
    QPushButton *toggleHistoButton;
    QPushButton *autoButton;
    QPushButton *stretchPreset;

    void setupUi(QWidget *FITSStretchUI)
    {
        if (FITSStretchUI->objectName().isEmpty())
            FITSStretchUI->setObjectName("FITSStretchUI");
        FITSStretchUI->resize(734, 77);
        QSizePolicy sizePolicy(QSizePolicy::Policy::Expanding, QSizePolicy::Policy::Fixed);
        sizePolicy.setHorizontalStretch(0);
        sizePolicy.setVerticalStretch(0);
        sizePolicy.setHeightForWidth(FITSStretchUI->sizePolicy().hasHeightForWidth());
        FITSStretchUI->setSizePolicy(sizePolicy);
        FITSStretchUI->setMaximumSize(QSize(16777215, 16777215));
        verticalLayout = new QVBoxLayout(FITSStretchUI);
        verticalLayout->setSpacing(2);
        verticalLayout->setObjectName("verticalLayout");
        verticalLayout->setContentsMargins(-1, 2, -1, 2);
        histoPlot = new QCustomPlot(FITSStretchUI);
        histoPlot->setObjectName("histoPlot");
        sizePolicy.setHeightForWidth(histoPlot->sizePolicy().hasHeightForWidth());
        histoPlot->setSizePolicy(sizePolicy);
        histoPlot->setMaximumSize(QSize(16777215, 100));

        verticalLayout->addWidget(histoPlot);

        histoSlider = new ctk3Slider(FITSStretchUI);
        histoSlider->setObjectName("histoSlider");
        histoSlider->setMaximumSize(QSize(16777215, 30));
        histoSlider->setOrientation(Qt::Horizontal);

        verticalLayout->addWidget(histoSlider);

        horizLayout = new QHBoxLayout();
        horizLayout->setObjectName("horizLayout");
        stretchButton = new QPushButton(FITSStretchUI);
        stretchButton->setObjectName("stretchButton");
        QSizePolicy sizePolicy1(QSizePolicy::Policy::Fixed, QSizePolicy::Policy::Fixed);
        sizePolicy1.setHorizontalStretch(0);
        sizePolicy1.setVerticalStretch(0);
        sizePolicy1.setHeightForWidth(stretchButton->sizePolicy().hasHeightForWidth());
        stretchButton->setSizePolicy(sizePolicy1);
        stretchButton->setMinimumSize(QSize(30, 30));
        stretchButton->setMaximumSize(QSize(30, 30));
        stretchButton->setIconSize(QSize(22, 22));
        stretchButton->setCheckable(true);
        stretchButton->setChecked(true);

        horizLayout->addWidget(stretchButton);

        line1 = new QFrame(FITSStretchUI);
        line1->setObjectName("line1");
        line1->setMaximumSize(QSize(16777215, 30));
        line1->setFrameShape(QFrame::Shape::VLine);
        line1->setFrameShadow(QFrame::Shadow::Sunken);

        horizLayout->addWidget(line1);

        shadowsLabel = new QLabel(FITSStretchUI);
        shadowsLabel->setObjectName("shadowsLabel");
        sizePolicy1.setHeightForWidth(shadowsLabel->sizePolicy().hasHeightForWidth());
        shadowsLabel->setSizePolicy(sizePolicy1);
        QFont font;
        font.setPointSize(12);
        shadowsLabel->setFont(font);

        horizLayout->addWidget(shadowsLabel);

        shadowsVal = new QDoubleSpinBox(FITSStretchUI);
        shadowsVal->setObjectName("shadowsVal");
        sizePolicy1.setHeightForWidth(shadowsVal->sizePolicy().hasHeightForWidth());
        shadowsVal->setSizePolicy(sizePolicy1);
        shadowsVal->setFont(font);
        shadowsVal->setKeyboardTracking(false);
        shadowsVal->setDecimals(4);
        shadowsVal->setMaximum(1.000000000000000);
        shadowsVal->setSingleStep(0.002000000000000);

        horizLayout->addWidget(shadowsVal);

        line2 = new QFrame(FITSStretchUI);
        line2->setObjectName("line2");
        line2->setMaximumSize(QSize(16777215, 30));
        line2->setFrameShape(QFrame::Shape::VLine);
        line2->setFrameShadow(QFrame::Shadow::Sunken);

        horizLayout->addWidget(line2);

        midtonesLabel = new QLabel(FITSStretchUI);
        midtonesLabel->setObjectName("midtonesLabel");
        sizePolicy1.setHeightForWidth(midtonesLabel->sizePolicy().hasHeightForWidth());
        midtonesLabel->setSizePolicy(sizePolicy1);
        midtonesLabel->setFont(font);

        horizLayout->addWidget(midtonesLabel);

        midtonesVal = new QDoubleSpinBox(FITSStretchUI);
        midtonesVal->setObjectName("midtonesVal");
        sizePolicy1.setHeightForWidth(midtonesVal->sizePolicy().hasHeightForWidth());
        midtonesVal->setSizePolicy(sizePolicy1);
        midtonesVal->setFont(font);
        midtonesVal->setKeyboardTracking(false);
        midtonesVal->setDecimals(4);
        midtonesVal->setMaximum(1.000000000000000);
        midtonesVal->setSingleStep(0.002000000000000);

        horizLayout->addWidget(midtonesVal);

        line3 = new QFrame(FITSStretchUI);
        line3->setObjectName("line3");
        line3->setMaximumSize(QSize(16777215, 30));
        line3->setFrameShape(QFrame::Shape::VLine);
        line3->setFrameShadow(QFrame::Shadow::Sunken);

        horizLayout->addWidget(line3);

        highlightsLabel = new QLabel(FITSStretchUI);
        highlightsLabel->setObjectName("highlightsLabel");
        sizePolicy1.setHeightForWidth(highlightsLabel->sizePolicy().hasHeightForWidth());
        highlightsLabel->setSizePolicy(sizePolicy1);
        highlightsLabel->setMaximumSize(QSize(16777215, 30));
        highlightsLabel->setFont(font);

        horizLayout->addWidget(highlightsLabel);

        highlightsVal = new QDoubleSpinBox(FITSStretchUI);
        highlightsVal->setObjectName("highlightsVal");
        sizePolicy1.setHeightForWidth(highlightsVal->sizePolicy().hasHeightForWidth());
        highlightsVal->setSizePolicy(sizePolicy1);
        highlightsVal->setMaximumSize(QSize(16777215, 30));
        highlightsVal->setFont(font);
        highlightsVal->setKeyboardTracking(false);
        highlightsVal->setDecimals(4);
        highlightsVal->setMaximum(1.000000000000000);
        highlightsVal->setSingleStep(0.002000000000000);

        horizLayout->addWidget(highlightsVal);

        line4 = new QFrame(FITSStretchUI);
        line4->setObjectName("line4");
        line4->setMaximumSize(QSize(16777215, 30));
        line4->setFrameShape(QFrame::Shape::VLine);
        line4->setFrameShadow(QFrame::Shadow::Sunken);

        horizLayout->addWidget(line4);

        toggleHistoButton = new QPushButton(FITSStretchUI);
        toggleHistoButton->setObjectName("toggleHistoButton");
        sizePolicy1.setHeightForWidth(toggleHistoButton->sizePolicy().hasHeightForWidth());
        toggleHistoButton->setSizePolicy(sizePolicy1);
        toggleHistoButton->setMinimumSize(QSize(30, 30));
        toggleHistoButton->setMaximumSize(QSize(30, 30));
        toggleHistoButton->setCheckable(true);

        horizLayout->addWidget(toggleHistoButton);

        autoButton = new QPushButton(FITSStretchUI);
        autoButton->setObjectName("autoButton");
        sizePolicy1.setHeightForWidth(autoButton->sizePolicy().hasHeightForWidth());
        autoButton->setSizePolicy(sizePolicy1);
        autoButton->setMinimumSize(QSize(30, 30));
        autoButton->setMaximumSize(QSize(30, 30));

        horizLayout->addWidget(autoButton);

        stretchPreset = new QPushButton(FITSStretchUI);
        stretchPreset->setObjectName("stretchPreset");
        sizePolicy1.setHeightForWidth(stretchPreset->sizePolicy().hasHeightForWidth());
        stretchPreset->setSizePolicy(sizePolicy1);
        stretchPreset->setMinimumSize(QSize(30, 30));
        stretchPreset->setMaximumSize(QSize(30, 30));
        stretchPreset->setCheckable(false);

        horizLayout->addWidget(stretchPreset);


        verticalLayout->addLayout(horizLayout);


        retranslateUi(FITSStretchUI);

        QMetaObject::connectSlotsByName(FITSStretchUI);
    } // setupUi

    void retranslateUi(QWidget *FITSStretchUI)
    {
#if QT_CONFIG(tooltip)
        stretchButton->setToolTip(tr2i18n("Stretch (or disable stretching) the image.", nullptr));
#endif // QT_CONFIG(tooltip)
#if QT_CONFIG(tooltip)
        shadowsLabel->setToolTip(tr2i18n("Set shadows value for the image stretch.", nullptr));
#endif // QT_CONFIG(tooltip)
        shadowsLabel->setText(tr2i18n("Shadows", nullptr));
#if QT_CONFIG(tooltip)
        shadowsVal->setToolTip(tr2i18n("Set shadows value for the image stretch.", nullptr));
#endif // QT_CONFIG(tooltip)
#if QT_CONFIG(tooltip)
        midtonesLabel->setToolTip(tr2i18n("Set midtones value for the image stretch.", nullptr));
#endif // QT_CONFIG(tooltip)
        midtonesLabel->setText(tr2i18n("Midtones", nullptr));
#if QT_CONFIG(tooltip)
        midtonesVal->setToolTip(tr2i18n("Set midtones value for the image stretch.", nullptr));
#endif // QT_CONFIG(tooltip)
#if QT_CONFIG(tooltip)
        highlightsLabel->setToolTip(tr2i18n("Set highlights value for the image stretch.", nullptr));
#endif // QT_CONFIG(tooltip)
        highlightsLabel->setText(tr2i18n("Highlights", nullptr));
#if QT_CONFIG(tooltip)
        highlightsVal->setToolTip(tr2i18n("Set highlights value for the image stretch.", nullptr));
#endif // QT_CONFIG(tooltip)
#if QT_CONFIG(tooltip)
        toggleHistoButton->setToolTip(tr2i18n("Enable or disable the histogram display.", nullptr));
#endif // QT_CONFIG(tooltip)
#if QT_CONFIG(tooltip)
        autoButton->setToolTip(tr2i18n("Automatically find stretch parameter.", nullptr));
#endif // QT_CONFIG(tooltip)
#if QT_CONFIG(tooltip)
        stretchPreset->setToolTip(tr2i18n("Cycle through stretch presets.", nullptr));
#endif // QT_CONFIG(tooltip)
        (void)FITSStretchUI;
    } // retranslateUi

};

namespace Ui {
    class FITSStretchUI: public Ui_FITSStretchUI {};
} // namespace Ui

QT_END_NAMESPACE

#endif // FITSSTRETCHUI_H

