/********************************************************************************
** Form generated from reading UI file 'ekoslivedialog.ui'
**
** Created by: Qt User Interface Compiler version 6.11.1
**
** WARNING! All changes made in this file will be lost when recompiling UI file!
********************************************************************************/

#ifndef UI_EKOSLIVEDIALOG_H
#define UI_EKOSLIVEDIALOG_H

#include <QtCore/QVariant>
#include <QtGui/QIcon>
#include <QtWidgets/QApplication>
#include <QtWidgets/QCheckBox>
#include <QtWidgets/QDialog>
#include <QtWidgets/QGridLayout>
#include <QtWidgets/QGroupBox>
#include <QtWidgets/QHBoxLayout>
#include <QtWidgets/QLabel>
#include <QtWidgets/QLineEdit>
#include <QtWidgets/QPushButton>
#include <QtWidgets/QSpacerItem>
#include <QtWidgets/QVBoxLayout>
#include <klocalizedstring.h>

QT_BEGIN_NAMESPACE

class Ui_EkosLiveDialog
{
public:
    QHBoxLayout *horizontalLayout_3;
    QLabel *leftBanner;
    QVBoxLayout *verticalLayout;
    QHBoxLayout *horizontalLayout;
    QGroupBox *groupBox_2;
    QGridLayout *gridLayout;
    QLineEdit *username;
    QLabel *label_2;
    QLineEdit *password;
    QCheckBox *rememberCredentialsCheck;
    QLabel *label;
    QGroupBox *groupBox;
    QGridLayout *gridLayout_2;
    QHBoxLayout *statusLayout;
    QSpacerItem *leftSpacer;
    QLabel *connectionState;
    QSpacerItem *rightSpacer;
    QHBoxLayout *horizontalLayout_2;
    QCheckBox *autoStartCheck;
    QLabel *onlineIcon;
    QLabel *onlineLabel;
    QLabel *offlineIcon;
    QLabel *offlineLabel;
    QHBoxLayout *bottomLayout;
    QPushButton *selectServersB;
    QSpacerItem *horizontalSpacer;
    QPushButton *connectB;
    QPushButton *closeB;

    void setupUi(QDialog *EkosLiveDialog)
    {
        if (EkosLiveDialog->objectName().isEmpty())
            EkosLiveDialog->setObjectName("EkosLiveDialog");
        EkosLiveDialog->resize(373, 206);
        horizontalLayout_3 = new QHBoxLayout(EkosLiveDialog);
        horizontalLayout_3->setSpacing(3);
        horizontalLayout_3->setObjectName("horizontalLayout_3");
        horizontalLayout_3->setContentsMargins(3, 3, 3, 3);
        leftBanner = new QLabel(EkosLiveDialog);
        leftBanner->setObjectName("leftBanner");
        leftBanner->setMinimumSize(QSize(100, 200));

        horizontalLayout_3->addWidget(leftBanner);

        verticalLayout = new QVBoxLayout();
        verticalLayout->setSpacing(3);
        verticalLayout->setObjectName("verticalLayout");
        horizontalLayout = new QHBoxLayout();
        horizontalLayout->setSpacing(3);
        horizontalLayout->setObjectName("horizontalLayout");
        groupBox_2 = new QGroupBox(EkosLiveDialog);
        groupBox_2->setObjectName("groupBox_2");
        gridLayout = new QGridLayout(groupBox_2);
        gridLayout->setSpacing(3);
        gridLayout->setObjectName("gridLayout");
        gridLayout->setContentsMargins(3, 3, 3, 3);
        username = new QLineEdit(groupBox_2);
        username->setObjectName("username");

        gridLayout->addWidget(username, 0, 1, 1, 1);

        label_2 = new QLabel(groupBox_2);
        label_2->setObjectName("label_2");

        gridLayout->addWidget(label_2, 1, 0, 1, 1);

        password = new QLineEdit(groupBox_2);
        password->setObjectName("password");
        password->setEchoMode(QLineEdit::Password);

        gridLayout->addWidget(password, 1, 1, 1, 1);

        rememberCredentialsCheck = new QCheckBox(groupBox_2);
        rememberCredentialsCheck->setObjectName("rememberCredentialsCheck");
        rememberCredentialsCheck->setEnabled(true);
        rememberCredentialsCheck->setChecked(true);

        gridLayout->addWidget(rememberCredentialsCheck, 2, 0, 1, 2);

        label = new QLabel(groupBox_2);
        label->setObjectName("label");

        gridLayout->addWidget(label, 0, 0, 1, 1);


        horizontalLayout->addWidget(groupBox_2);

        groupBox = new QGroupBox(EkosLiveDialog);
        groupBox->setObjectName("groupBox");
        gridLayout_2 = new QGridLayout(groupBox);
        gridLayout_2->setSpacing(3);
        gridLayout_2->setObjectName("gridLayout_2");
        gridLayout_2->setContentsMargins(3, 3, 3, 3);
        statusLayout = new QHBoxLayout();
        statusLayout->setObjectName("statusLayout");
        leftSpacer = new QSpacerItem(1, 20, QSizePolicy::Policy::Expanding, QSizePolicy::Policy::Minimum);

        statusLayout->addItem(leftSpacer);

        connectionState = new QLabel(groupBox);
        connectionState->setObjectName("connectionState");
        connectionState->setMinimumSize(QSize(64, 64));
        connectionState->setMaximumSize(QSize(64, 64));
        connectionState->setAlignment(Qt::AlignLeading|Qt::AlignLeft|Qt::AlignVCenter);

        statusLayout->addWidget(connectionState);

        rightSpacer = new QSpacerItem(1, 20, QSizePolicy::Policy::Expanding, QSizePolicy::Policy::Minimum);

        statusLayout->addItem(rightSpacer);


        gridLayout_2->addLayout(statusLayout, 0, 0, 1, 1);


        horizontalLayout->addWidget(groupBox);

        horizontalLayout->setStretch(0, 1);

        verticalLayout->addLayout(horizontalLayout);

        horizontalLayout_2 = new QHBoxLayout();
        horizontalLayout_2->setObjectName("horizontalLayout_2");
        autoStartCheck = new QCheckBox(EkosLiveDialog);
        autoStartCheck->setObjectName("autoStartCheck");

        horizontalLayout_2->addWidget(autoStartCheck);

        onlineIcon = new QLabel(EkosLiveDialog);
        onlineIcon->setObjectName("onlineIcon");
        onlineIcon->setMinimumSize(QSize(32, 32));
        onlineIcon->setMaximumSize(QSize(32, 32));
        onlineIcon->setPixmap(QPixmap(QString::fromUtf8(":/icons/AlignFailure.svg")));
        onlineIcon->setScaledContents(true);

        horizontalLayout_2->addWidget(onlineIcon);

        onlineLabel = new QLabel(EkosLiveDialog);
        onlineLabel->setObjectName("onlineLabel");
        onlineLabel->setStyleSheet(QString::fromUtf8("color:gray"));

        horizontalLayout_2->addWidget(onlineLabel);

        offlineIcon = new QLabel(EkosLiveDialog);
        offlineIcon->setObjectName("offlineIcon");
        offlineIcon->setMinimumSize(QSize(32, 32));
        offlineIcon->setMaximumSize(QSize(32, 32));
        offlineIcon->setPixmap(QPixmap(QString::fromUtf8(":/icons/AlignFailure.svg")));
        offlineIcon->setScaledContents(true);

        horizontalLayout_2->addWidget(offlineIcon);

        offlineLabel = new QLabel(EkosLiveDialog);
        offlineLabel->setObjectName("offlineLabel");
        offlineLabel->setStyleSheet(QString::fromUtf8("color:gray"));

        horizontalLayout_2->addWidget(offlineLabel);


        verticalLayout->addLayout(horizontalLayout_2);

        bottomLayout = new QHBoxLayout();
        bottomLayout->setSpacing(3);
        bottomLayout->setObjectName("bottomLayout");
        selectServersB = new QPushButton(EkosLiveDialog);
        selectServersB->setObjectName("selectServersB");
        selectServersB->setMinimumSize(QSize(32, 32));
        selectServersB->setMaximumSize(QSize(32, 32));
        QIcon icon(QIcon::fromTheme(QString::fromUtf8("network-server")));
        selectServersB->setIcon(icon);
        selectServersB->setIconSize(QSize(28, 28));

        bottomLayout->addWidget(selectServersB);

        horizontalSpacer = new QSpacerItem(40, 20, QSizePolicy::Policy::Expanding, QSizePolicy::Policy::Minimum);

        bottomLayout->addItem(horizontalSpacer);

        connectB = new QPushButton(EkosLiveDialog);
        connectB->setObjectName("connectB");

        bottomLayout->addWidget(connectB);

        closeB = new QPushButton(EkosLiveDialog);
        closeB->setObjectName("closeB");

        bottomLayout->addWidget(closeB);


        verticalLayout->addLayout(bottomLayout);


        horizontalLayout_3->addLayout(verticalLayout);

        QWidget::setTabOrder(username, password);
        QWidget::setTabOrder(password, rememberCredentialsCheck);

        retranslateUi(EkosLiveDialog);

        QMetaObject::connectSlotsByName(EkosLiveDialog);
    } // setupUi

    void retranslateUi(QDialog *EkosLiveDialog)
    {
        EkosLiveDialog->setWindowTitle(tr2i18n("Ekos Live", nullptr));
        leftBanner->setText(QString());
        groupBox_2->setTitle(tr2i18n("Ekos Live Service", nullptr));
        label_2->setText(tr2i18n("Password:", nullptr));
        rememberCredentialsCheck->setText(tr2i18n("Remember Credentials", nullptr));
        label->setText(tr2i18n("Username:", nullptr));
        groupBox->setTitle(tr2i18n("Status", nullptr));
        connectionState->setText(QString());
#if QT_CONFIG(tooltip)
        autoStartCheck->setToolTip(tr2i18n("Automatically connect to EkosLive service on startup.", nullptr));
#endif // QT_CONFIG(tooltip)
        autoStartCheck->setText(tr2i18n("Auto Start", nullptr));
        onlineIcon->setText(QString());
        onlineLabel->setText(tr2i18n("Online", nullptr));
        offlineIcon->setText(QString());
        offlineLabel->setText(tr2i18n("Offline", nullptr));
        selectServersB->setText(QString());
        connectB->setText(tr2i18n("Connect", nullptr));
        closeB->setText(tr2i18n("Close", nullptr));
    } // retranslateUi

};

namespace Ui {
    class EkosLiveDialog: public Ui_EkosLiveDialog {};
} // namespace Ui

QT_END_NAMESPACE

#endif // EKOSLIVEDIALOG_H

