/********************************************************************************
** Form generated from reading UI file 'argprintimage.ui'
**
** Created by: Qt User Interface Compiler version 6.11.1
**
** WARNING! All changes made in this file will be lost when recompiling UI file!
********************************************************************************/

#ifndef UI_ARGPRINTIMAGE_H
#define UI_ARGPRINTIMAGE_H

#include <QtCore/QVariant>
#include <QtWidgets/QApplication>
#include <QtWidgets/QCheckBox>
#include <QtWidgets/QSpacerItem>
#include <QtWidgets/QVBoxLayout>
#include <QtWidgets/QWidget>
#include <klocalizedstring.h>

QT_BEGIN_NAMESPACE

class Ui_ArgPrintImage
{
public:
    QVBoxLayout *vboxLayout;
    QCheckBox *UsePrintDialog;
    QCheckBox *UseChartColors;
    QSpacerItem *spacerItem;

    void setupUi(QWidget *ArgPrintImage)
    {
        if (ArgPrintImage->objectName().isEmpty())
            ArgPrintImage->setObjectName("ArgPrintImage");
        ArgPrintImage->resize(258, 190);
        vboxLayout = new QVBoxLayout(ArgPrintImage);
#ifndef UI_Q_OS_MAC
        vboxLayout->setSpacing(6);
#endif
        vboxLayout->setContentsMargins(10, 10, 10, 10);
        vboxLayout->setObjectName("vboxLayout");
        UsePrintDialog = new QCheckBox(ArgPrintImage);
        UsePrintDialog->setObjectName("UsePrintDialog");

        vboxLayout->addWidget(UsePrintDialog);

        UseChartColors = new QCheckBox(ArgPrintImage);
        UseChartColors->setObjectName("UseChartColors");
        UseChartColors->setChecked(true);

        vboxLayout->addWidget(UseChartColors);

        spacerItem = new QSpacerItem(20, 70, QSizePolicy::Policy::Minimum, QSizePolicy::Policy::Expanding);

        vboxLayout->addItem(spacerItem);


        retranslateUi(ArgPrintImage);

        QMetaObject::connectSlotsByName(ArgPrintImage);
    } // setupUi

    void retranslateUi(QWidget *ArgPrintImage)
    {
        UsePrintDialog->setText(tr2i18n("Show print dialog", nullptr));
        UseChartColors->setText(tr2i18n("Use star chart colors", nullptr));
        (void)ArgPrintImage;
    } // retranslateUi

};

namespace Ui {
    class ArgPrintImage: public Ui_ArgPrintImage {};
} // namespace Ui

QT_END_NAMESPACE

#endif // ARGPRINTIMAGE_H

