/****************************************************************************
** Meta object code from reading C++ file 'kstarsadaptor.h'
**
** Created by: The Qt Meta Object Compiler version 69 (Qt 6.11.1)
**
** WARNING! All changes made in this file will be lost!
*****************************************************************************/

#include "kstarsadaptor.h"
#include <QtCore/qmetatype.h>

#include <QtCore/qtmochelpers.h>

#include <memory>


#include <QtCore/qxptype_traits.h>
#if !defined(Q_MOC_OUTPUT_REVISION)
#error "The header file 'kstarsadaptor.h' doesn't include <QObject>."
#elif Q_MOC_OUTPUT_REVISION != 69
#error "This file was generated using the moc from 6.11.1. It"
#error "cannot be used with the include files from this version of Qt."
#error "(The moc has changed too much.)"
#endif

#ifndef Q_CONSTINIT
#define Q_CONSTINIT
#endif

QT_WARNING_PUSH
QT_WARNING_DISABLE_DEPRECATED
QT_WARNING_DISABLE_GCC("-Wuseless-cast")
namespace {
struct qt_meta_tag_ZN13KstarsAdaptorE_t {};
} // unnamed namespace

template <> constexpr inline auto KstarsAdaptor::qt_create_metaobjectdata<qt_meta_tag_ZN13KstarsAdaptorE_t>()
{
    namespace QMC = QtMocConstants;
    QtMocHelpers::StringRefStorage qt_stringData {
        "KstarsAdaptor",
        "D-Bus Interface",
        "org.kde.kstars",
        "D-Bus Introspection",
        "  <interface name=\"org.kde.kstars\">\n    <property access=\"read"
        "write\" type=\"s\" name=\"colorScheme\"/>\n    <property access=\""
        "read\" type=\"s\" name=\"version\"/>\n    <property access=\"read\""
        " type=\"s\" name=\"release\"/>\n    <method name=\"setRaDec\">\n  "
        "    <arg direction=\"in\" type=\"d\" name=\"ra\"/>\n      <arg dir"
        "ection=\"in\" type=\"d\" name=\"dec\"/>\n      <annotation value=\""
        "true\" name=\"org.freedesktop.DBus.Method.NoReply\"/>\n    </metho"
        "d>\n    <method name=\"setRaDecJ2000\">\n      <arg direction=\"in"
        "\" type=\"d\" name=\"ra0\"/>\n      <arg direction=\"in\" type=\"d"
        "\" name=\"dec0\"/>\n      <annotation value=\"true\" name=\"org.fr"
        "eedesktop.DBus.Method.NoReply\"/>\n    </method>\n    <method name"
        "=\"setAltAz\">\n      <arg direction=\"in\" type=\"d\" name=\"alt\""
        "/>\n      <arg direction=\"in\" type=\"d\" name=\"az\"/>\n      <a"
        "rg direction=\"in\" type=\"b\" name=\"altIsRefracted\"/>\n      <a"
        "nnotation value=\"true\" name=\"org.freedesktop.DBus.Method.NoRepl"
        "y\"/>\n    </method>\n    <method name=\"setAltAz\">\n      <arg d"
        "irection=\"in\" type=\"d\" name=\"alt\"/>\n      <arg direction=\""
        "in\" type=\"d\" name=\"az\"/>\n      <annotation value=\"true\" na"
        "me=\"org.freedesktop.DBus.Method.NoReply\"/>\n    </method>\n    <"
        "method name=\"lookTowards\">\n      <arg direction=\"in\" type=\"s"
        "\" name=\"direction\"/>\n      <annotation value=\"true\" name=\"o"
        "rg.freedesktop.DBus.Method.NoReply\"/>\n    </method>\n    <method"
        " name=\"addLabel\">\n      <arg direction=\"in\" type=\"s\" name=\""
        "name\"/>\n      <annotation value=\"true\" name=\"org.freedesktop."
        "DBus.Method.NoReply\"/>\n    </method>\n    <method name=\"removeL"
        "abel\">\n      <arg direction=\"in\" type=\"s\" name=\"name\"/>\n "
        "     <annotation value=\"true\" name=\"org.freedesktop.DBus.Method"
        ".NoReply\"/>\n    </method>\n    <method name=\"addTrail\">\n     "
        " <arg direction=\"in\" type=\"s\" name=\"name\"/>\n      <annotati"
        "on value=\"true\" name=\"org.freedesktop.DBus.Method.NoReply\"/>\n"
        "    </method>\n    <method name=\"removeTrail\">\n      <arg direc"
        "tion=\"in\" type=\"s\" name=\"name\"/>\n      <annotation value=\""
        "true\" name=\"org.freedesktop.DBus.Method.NoReply\"/>\n    </metho"
        "d>\n    <method name=\"zoomIn\">\n      <annotation value=\"true\""
        " name=\"org.freedesktop.DBus.Method.NoReply\"/>\n    </method>\n  "
        "  <method name=\"zoomOut\">\n      <annotation value=\"true\" name"
        "=\"org.freedesktop.DBus.Method.NoReply\"/>\n    </method>\n    <me"
        "thod name=\"defaultZoom\">\n      <annotation value=\"true\" name="
        "\"org.freedesktop.DBus.Method.NoReply\"/>\n    </method>\n    <met"
        "hod name=\"zoom\">\n      <arg direction=\"in\" type=\"d\" name=\""
        "z\"/>\n      <annotation value=\"true\" name=\"org.freedesktop.DBu"
        "s.Method.NoReply\"/>\n    </method>\n    <method name=\"setLocalTi"
        "me\">\n      <arg direction=\"in\" type=\"i\" name=\"yr\"/>\n     "
        " <arg direction=\"in\" type=\"i\" name=\"mth\"/>\n      <arg direc"
        "tion=\"in\" type=\"i\" name=\"day\"/>\n      <arg direction=\"in\""
        " type=\"i\" name=\"hr\"/>\n      <arg direction=\"in\" type=\"i\" "
        "name=\"min\"/>\n      <arg direction=\"in\" type=\"i\" name=\"sec\""
        "/>\n      <annotation value=\"true\" name=\"org.freedesktop.DBus.M"
        "ethod.NoReply\"/>\n    </method>\n    <method name=\"setTimeToNow\""
        ">\n      <annotation value=\"true\" name=\"org.freedesktop.DBus.Me"
        "thod.NoReply\"/>\n    </method>\n    <method name=\"waitFor\">\n  "
        "    <arg direction=\"in\" type=\"d\" name=\"t\"/>\n      <annotati"
        "on value=\"true\" name=\"org.freedesktop.DBus.Method.NoReply\"/>\n"
        "    </method>\n    <method name=\"waitForKey\">\n      <arg direct"
        "ion=\"in\" type=\"s\" name=\"k\"/>\n      <annotation value=\"true"
        "\" name=\"org.freedesktop.DBus.Method.NoReply\"/>\n    </method>\n"
        "    <method name=\"setTracking\">\n      <arg direction=\"in\" typ"
        "e=\"b\" name=\"track\"/>\n      <annotation value=\"true\" name=\""
        "org.freedesktop.DBus.Method.NoReply\"/>\n    </method>\n    <metho"
        "d name=\"changeViewOption\">\n      <arg direction=\"in\" type=\"s"
        "\" name=\"option\"/>\n      <arg direction=\"in\" type=\"s\" name="
        "\"value\"/>\n      <annotation value=\"true\" name=\"org.freedeskt"
        "op.DBus.Method.NoReply\"/>\n    </method>\n    <method name=\"getO"
        "ption\">\n      <arg direction=\"in\" type=\"s\" name=\"name\"/>\n"
        "      <arg direction=\"out\" type=\"v\"/>\n    </method>\n    <met"
        "hod name=\"setOption\">\n      <arg direction=\"in\" type=\"s\" na"
        "me=\"name\"/>\n      <arg direction=\"in\" type=\"v\" name=\"value"
        "\"/>\n      <annotation value=\"true\" name=\"org.freedesktop.DBus"
        ".Method.NoReply\"/>\n    </method>\n    <method name=\"getFocusInf"
        "ormationXML\">\n      <arg direction=\"out\" type=\"s\"/>\n    </m"
        "ethod>\n    <method name=\"readConfig\">\n      <annotation value="
        "\"true\" name=\"org.freedesktop.DBus.Method.NoReply\"/>\n    </met"
        "hod>\n    <method name=\"writeConfig\">\n      <annotation value=\""
        "true\" name=\"org.freedesktop.DBus.Method.NoReply\"/>\n    </metho"
        "d>\n    <method name=\"popupMessage\">\n      <arg direction=\"in\""
        " type=\"i\" name=\"x\"/>\n      <arg direction=\"in\" type=\"i\" n"
        "ame=\"y\"/>\n      <arg direction=\"in\" type=\"s\" name=\"message"
        "\"/>\n      <annotation value=\"true\" name=\"org.freedesktop.DBus"
        ".Method.NoReply\"/>\n    </method>\n    <method name=\"drawLine\">"
        "\n      <arg direction=\"in\" type=\"i\" name=\"x1\"/>\n      <arg"
        " direction=\"in\" type=\"i\" name=\"y1\"/>\n      <arg direction=\""
        "in\" type=\"i\" name=\"x2\"/>\n      <arg direction=\"in\" type=\""
        "i\" name=\"y2\"/>\n      <arg direction=\"in\" type=\"i\" name=\"s"
        "peed\"/>\n      <annotation value=\"true\" name=\"org.freedesktop."
        "DBus.Method.NoReply\"/>\n    </method>\n    <method name=\"setGeoL"
        "ocation\">\n      <arg direction=\"out\" type=\"b\"/>\n      <arg "
        "direction=\"in\" type=\"s\" name=\"city\"/>\n      <arg direction="
        "\"in\" type=\"s\" name=\"province\"/>\n      <arg direction=\"in\""
        " type=\"s\" name=\"country\"/>\n    </method>\n    <method name=\""
        "location\">\n      <arg direction=\"out\" type=\"s\"/>\n    </meth"
        "od>\n    <method name=\"setGPSLocation\">\n      <arg direction=\""
        "out\" type=\"b\"/>\n      <arg direction=\"in\" type=\"d\" name=\""
        "longitude\"/>\n      <arg direction=\"in\" type=\"d\" name=\"latit"
        "ude\"/>\n      <arg direction=\"in\" type=\"d\" name=\"elevation\""
        "/>\n      <arg direction=\"in\" type=\"d\" name=\"tz0\"/>\n    </m"
        "ethod>\n    <method name=\"setColor\">\n      <arg direction=\"in\""
        " type=\"s\" name=\"colorName\"/>\n      <arg direction=\"in\" type"
        "=\"s\" name=\"value\"/>\n      <annotation value=\"true\" name=\"o"
        "rg.freedesktop.DBus.Method.NoReply\"/>\n    </method>\n    <method"
        " name=\"loadColorScheme\">\n      <arg direction=\"in\" type=\"s\""
        " name=\"name\"/>\n      <annotation value=\"true\" name=\"org.free"
        "desktop.DBus.Method.NoReply\"/>\n    </method>\n    <method name=\""
        "exportImage\">\n      <arg direction=\"in\" type=\"s\" name=\"file"
        "name\"/>\n      <arg direction=\"in\" type=\"i\" name=\"width\"/>\n"
        "      <arg direction=\"in\" type=\"i\" name=\"height\"/>\n      <a"
        "rg direction=\"in\" type=\"b\" name=\"includeLegend\"/>\n      <an"
        "notation value=\"true\" name=\"org.freedesktop.DBus.Method.NoReply"
        "\"/>\n    </method>\n    <method name=\"exportImage\">\n      <arg"
        " direction=\"in\" type=\"s\" name=\"filename\"/>\n      <arg direc"
        "tion=\"in\" type=\"i\" name=\"width\"/>\n      <arg direction=\"in"
        "\" type=\"i\" name=\"height\"/>\n      <annotation value=\"true\" "
        "name=\"org.freedesktop.DBus.Method.NoReply\"/>\n    </method>\n   "
        " <method name=\"exportImage\">\n      <arg direction=\"in\" type=\""
        "s\" name=\"filename\"/>\n      <arg direction=\"in\" type=\"i\" na"
        "me=\"width\"/>\n      <annotation value=\"true\" name=\"org.freede"
        "sktop.DBus.Method.NoReply\"/>\n    </method>\n    <method name=\"e"
        "xportImage\">\n      <arg direction=\"in\" type=\"s\" name=\"filen"
        "ame\"/>\n      <annotation value=\"true\" name=\"org.freedesktop.D"
        "Bus.Method.NoReply\"/>\n    </method>\n    <method name=\"getDSSUR"
        "L\">\n      <arg direction=\"out\" type=\"s\"/>\n      <arg direct"
        "ion=\"in\" type=\"s\" name=\"objectName\"/>\n    </method>\n    <m"
        "ethod name=\"getDSSURL\">\n      <arg direction=\"out\" type=\"s\""
        "/>\n      <arg direction=\"in\" type=\"d\" name=\"RA_J2000\"/>\n  "
        "    <arg direction=\"in\" type=\"d\" name=\"Dec_J2000\"/>\n      <"
        "arg direction=\"in\" type=\"d\" name=\"width\"/>\n      <arg direc"
        "tion=\"in\" type=\"d\" name=\"height\"/>\n    </method>\n    <meth"
        "od name=\"getDSSURL\">\n      <arg direction=\"out\" type=\"s\"/>\n"
        "      <arg direction=\"in\" type=\"d\" name=\"RA_J2000\"/>\n      "
        "<arg direction=\"in\" type=\"d\" name=\"Dec_J2000\"/>\n    </metho"
        "d>\n    <method name=\"getObjectDataXML\">\n      <arg direction=\""
        "out\" type=\"s\"/>\n      <arg direction=\"in\" type=\"s\" name=\""
        "objectName\"/>\n      <arg direction=\"in\" type=\"b\" name=\"fall"
        "backToInternet\"/>\n      <arg direction=\"in\" type=\"b\" name=\""
        "storeInternetResolved\"/>\n    </method>\n    <method name=\"getOb"
        "jectDataXML\">\n      <arg direction=\"out\" type=\"s\"/>\n      <"
        "arg direction=\"in\" type=\"s\" name=\"objectName\"/>\n      <arg "
        "direction=\"in\" type=\"b\" name=\"fallbackToInternet\"/>\n    </m"
        "ethod>\n    <method name=\"getObjectDataXML\">\n      <arg directi"
        "on=\"out\" type=\"s\"/>\n      <arg direction=\"in\" type=\"s\" na"
        "me=\"objectName\"/>\n    </method>\n    <method name=\"getObjectPo"
        "sitionInfo\">\n      <arg direction=\"out\" type=\"s\"/>\n      <a"
        "rg direction=\"in\" type=\"s\" name=\"objectName\"/>\n    </method"
        ">\n    <method name=\"renderEyepieceView\">\n      <arg direction="
        "\"in\" type=\"s\" name=\"objectName\"/>\n      <arg direction=\"in"
        "\" type=\"s\" name=\"destPathChart\"/>\n      <arg direction=\"in\""
        " type=\"d\" name=\"fovWidth\"/>\n      <arg direction=\"in\" type="
        "\"d\" name=\"fovHeight\"/>\n      <arg direction=\"in\" type=\"d\""
        " name=\"rotation\"/>\n      <arg direction=\"in\" type=\"d\" name="
        "\"scale\"/>\n      <arg direction=\"in\" type=\"b\" name=\"flip\"/"
        ">\n      <arg direction=\"in\" type=\"b\" name=\"invert\"/>\n     "
        " <arg direction=\"in\" type=\"s\" name=\"imagePath\"/>\n      <arg"
        " direction=\"in\" type=\"s\" name=\"destPathImage\"/>\n      <arg "
        "direction=\"in\" type=\"b\" name=\"overlay\"/>\n      <arg directi"
        "on=\"in\" type=\"b\" name=\"invertColors\"/>\n      <annotation va"
        "lue=\"true\" name=\"org.freedesktop.DBus.Method.NoReply\"/>\n    <"
        "/method>\n    <method name=\"setApproxFOV\">\n      <arg direction"
        "=\"in\" type=\"d\" name=\"FOV_Degrees\"/>\n      <annotation value"
        "=\"true\" name=\"org.freedesktop.DBus.Method.NoReply\"/>\n    </me"
        "thod>\n    <method name=\"getSkyMapDimensions\">\n      <arg direc"
        "tion=\"out\" type=\"s\"/>\n    </method>\n    <method name=\"getOb"
        "servingWishListObjectNames\">\n      <arg direction=\"out\" type=\""
        "s\"/>\n    </method>\n    <method name=\"getObservingSessionPlanOb"
        "jectNames\">\n      <arg direction=\"out\" type=\"s\"/>\n    </met"
        "hod>\n    <method name=\"printImage\">\n      <arg direction=\"in\""
        " type=\"b\" name=\"usePrintDialog\"/>\n      <arg direction=\"in\""
        " type=\"b\" name=\"useChartColors\"/>\n      <annotation value=\"t"
        "rue\" name=\"org.freedesktop.DBus.Method.NoReply\"/>\n    </method"
        ">\n    <method name=\"openFITS\">\n      <arg direction=\"in\" typ"
        "e=\"(i)\" name=\"imageURL\"/>\n      <annotation value=\"QUrl\" na"
        "me=\"org.qtproject.QtDBus.QtTypeName.In0\"/>\n      <annotation va"
        "lue=\"QUrl\" name=\"org.qtproject.QtDBus.QtTypeName.Out0\"/>\n    "
        "  <annotation value=\"true\" name=\"org.freedesktop.DBus.Method.No"
        "Reply\"/>\n    </method>\n    <method name=\"listSkyMapViews\">\n "
        "     <arg direction=\"out\" type=\"as\"/>\n    </method>\n    <met"
        "hod name=\"setSkyMapView\">\n      <arg direction=\"out\" type=\"b"
        "\"/>\n      <arg direction=\"in\" type=\"s\" name=\"viewName\"/>\n"
        "    </method>\n    <method name=\"setFOVIndicatorVisibility\">\n  "
        "    <arg direction=\"out\" type=\"b\"/>\n      <arg direction=\"in"
        "\" type=\"s\" name=\"fovName\"/>\n      <arg direction=\"in\" type"
        "=\"b\" name=\"visibility\"/>\n    </method>\n    <method name=\"ge"
        "tFOVIndicatorVisibility\">\n      <arg direction=\"out\" type=\"b\""
        "/>\n      <arg direction=\"in\" type=\"s\" name=\"fovName\"/>\n   "
        " </method>\n    <method name=\"getFOVIndicators\">\n      <arg dir"
        "ection=\"out\" type=\"as\"/>\n    </method>\n    <method name=\"se"
        "tSkyMapRotation\">\n      <arg direction=\"in\" type=\"d\" name=\""
        "viewAngle\"/>\n      <annotation value=\"true\" name=\"org.freedes"
        "ktop.DBus.Method.NoReply\"/>\n    </method>\n    <method name=\"ge"
        "tSkyMapRotation\">\n      <arg direction=\"out\" type=\"d\"/>\n   "
        " </method>\n    <method name=\"skyMapIsMirrored\">\n      <arg dir"
        "ection=\"out\" type=\"b\"/>\n    </method>\n    <method name=\"set"
        "SkyMapMirrored\">\n      <arg direction=\"in\" type=\"b\" name=\"m"
        "irrored\"/>\n      <annotation value=\"true\" name=\"org.freedeskt"
        "op.DBus.Method.NoReply\"/>\n    </method>\n    <signal name=\"colo"
        "rSchemeChanged\"/>\n    <method name=\"getToggleableActionStates\""
        ">\n      <arg direction=\"out\" type=\"s\"/>\n    </method>\n    <"
        "method name=\"activateAction\">\n      <arg direction=\"out\" type"
        "=\"b\"/>\n      <arg direction=\"in\" type=\"s\" name=\"actionName"
        "\"/>\n    </method>\n    <method name=\"getActions\">\n      <arg "
        "direction=\"out\" type=\"as\"/>\n    </method>\n    <method name=\""
        "setToggleableActionState\">\n      <arg direction=\"out\" type=\"b"
        "\"/>\n      <arg direction=\"in\" type=\"s\" name=\"actionName\"/>"
        "\n      <arg direction=\"in\" type=\"b\" name=\"state\"/>\n    </m"
        "ethod>\n    <method name=\"colorScheme\">\n      <arg direction=\""
        "out\" type=\"s\"/>\n    </method>\n  </interface>\n",
        "colorSchemeChanged",
        "",
        "activateAction",
        "actionName",
        "addLabel",
        "Q_NOREPLY",
        "name",
        "addTrail",
        "changeViewOption",
        "option",
        "value",
        "colorScheme",
        "defaultZoom",
        "drawLine",
        "x1",
        "y1",
        "x2",
        "y2",
        "speed",
        "exportImage",
        "filename",
        "width",
        "height",
        "includeLegend",
        "getActions",
        "getDSSURL",
        "RA_J2000",
        "Dec_J2000",
        "objectName",
        "getFOVIndicatorVisibility",
        "fovName",
        "getFOVIndicators",
        "getFocusInformationXML",
        "getObjectDataXML",
        "fallbackToInternet",
        "storeInternetResolved",
        "getObjectPositionInfo",
        "getObservingSessionPlanObjectNames",
        "getObservingWishListObjectNames",
        "getOption",
        "QDBusVariant",
        "getSkyMapDimensions",
        "getSkyMapRotation",
        "getToggleableActionStates",
        "listSkyMapViews",
        "loadColorScheme",
        "location",
        "lookTowards",
        "direction",
        "openFITS",
        "QUrl",
        "imageURL",
        "popupMessage",
        "x",
        "y",
        "message",
        "printImage",
        "usePrintDialog",
        "useChartColors",
        "readConfig",
        "removeLabel",
        "removeTrail",
        "renderEyepieceView",
        "destPathChart",
        "fovWidth",
        "fovHeight",
        "rotation",
        "scale",
        "flip",
        "invert",
        "imagePath",
        "destPathImage",
        "overlay",
        "invertColors",
        "setAltAz",
        "alt",
        "az",
        "altIsRefracted",
        "setApproxFOV",
        "FOV_Degrees",
        "setColor",
        "colorName",
        "setFOVIndicatorVisibility",
        "visibility",
        "setGPSLocation",
        "longitude",
        "latitude",
        "elevation",
        "tz0",
        "setGeoLocation",
        "city",
        "province",
        "country",
        "setLocalTime",
        "yr",
        "mth",
        "day",
        "hr",
        "min",
        "sec",
        "setOption",
        "setRaDec",
        "ra",
        "dec",
        "setRaDecJ2000",
        "ra0",
        "dec0",
        "setSkyMapMirrored",
        "mirrored",
        "setSkyMapRotation",
        "viewAngle",
        "setSkyMapView",
        "viewName",
        "setTimeToNow",
        "setToggleableActionState",
        "state",
        "setTracking",
        "track",
        "skyMapIsMirrored",
        "waitFor",
        "t",
        "waitForKey",
        "k",
        "writeConfig",
        "zoom",
        "z",
        "zoomIn",
        "zoomOut",
        "release",
        "version"
    };

    QtMocHelpers::UintData qt_methods {
        // Signal 'colorSchemeChanged'
        QtMocHelpers::SignalData<void()>(5, 6, QMC::AccessPublic, QMetaType::Void),
        // Slot 'activateAction'
        QtMocHelpers::SlotData<bool(const QString &)>(7, 6, QMC::AccessPublic, QMetaType::Bool, {{
            { QMetaType::QString, 8 },
        }}),
        // Slot 'addLabel'
        QtMocHelpers::SlotData<void(const QString &)>(9, 10, QMC::AccessPublic, QMetaType::Void, {{
            { QMetaType::QString, 11 },
        }}),
        // Slot 'addTrail'
        QtMocHelpers::SlotData<void(const QString &)>(12, 10, QMC::AccessPublic, QMetaType::Void, {{
            { QMetaType::QString, 11 },
        }}),
        // Slot 'changeViewOption'
        QtMocHelpers::SlotData<void(const QString &, const QString &)>(13, 10, QMC::AccessPublic, QMetaType::Void, {{
            { QMetaType::QString, 14 }, { QMetaType::QString, 15 },
        }}),
        // Slot 'colorScheme'
        QtMocHelpers::SlotData<QString()>(16, 6, QMC::AccessPublic, QMetaType::QString),
        // Slot 'defaultZoom'
        QtMocHelpers::SlotData<void()>(17, 10, QMC::AccessPublic, QMetaType::Void),
        // Slot 'drawLine'
        QtMocHelpers::SlotData<void(int, int, int, int, int)>(18, 10, QMC::AccessPublic, QMetaType::Void, {{
            { QMetaType::Int, 19 }, { QMetaType::Int, 20 }, { QMetaType::Int, 21 }, { QMetaType::Int, 22 },
            { QMetaType::Int, 23 },
        }}),
        // Slot 'exportImage'
        QtMocHelpers::SlotData<void(const QString &)>(24, 10, QMC::AccessPublic, QMetaType::Void, {{
            { QMetaType::QString, 25 },
        }}),
        // Slot 'exportImage'
        QtMocHelpers::SlotData<void(const QString &, int)>(24, 10, QMC::AccessPublic, QMetaType::Void, {{
            { QMetaType::QString, 25 }, { QMetaType::Int, 26 },
        }}),
        // Slot 'exportImage'
        QtMocHelpers::SlotData<void(const QString &, int, int)>(24, 10, QMC::AccessPublic, QMetaType::Void, {{
            { QMetaType::QString, 25 }, { QMetaType::Int, 26 }, { QMetaType::Int, 27 },
        }}),
        // Slot 'exportImage'
        QtMocHelpers::SlotData<void(const QString &, int, int, bool)>(24, 10, QMC::AccessPublic, QMetaType::Void, {{
            { QMetaType::QString, 25 }, { QMetaType::Int, 26 }, { QMetaType::Int, 27 }, { QMetaType::Bool, 28 },
        }}),
        // Slot 'getActions'
        QtMocHelpers::SlotData<QStringList()>(29, 6, QMC::AccessPublic, QMetaType::QStringList),
        // Slot 'getDSSURL'
        QtMocHelpers::SlotData<QString(double, double)>(30, 6, QMC::AccessPublic, QMetaType::QString, {{
            { QMetaType::Double, 31 }, { QMetaType::Double, 32 },
        }}),
        // Slot 'getDSSURL'
        QtMocHelpers::SlotData<QString(double, double, double, double)>(30, 6, QMC::AccessPublic, QMetaType::QString, {{
            { QMetaType::Double, 31 }, { QMetaType::Double, 32 }, { QMetaType::Double, 26 }, { QMetaType::Double, 27 },
        }}),
        // Slot 'getDSSURL'
        QtMocHelpers::SlotData<QString(const QString &)>(30, 6, QMC::AccessPublic, QMetaType::QString, {{
            { QMetaType::QString, 33 },
        }}),
        // Slot 'getFOVIndicatorVisibility'
        QtMocHelpers::SlotData<bool(const QString &)>(34, 6, QMC::AccessPublic, QMetaType::Bool, {{
            { QMetaType::QString, 35 },
        }}),
        // Slot 'getFOVIndicators'
        QtMocHelpers::SlotData<QStringList()>(36, 6, QMC::AccessPublic, QMetaType::QStringList),
        // Slot 'getFocusInformationXML'
        QtMocHelpers::SlotData<QString()>(37, 6, QMC::AccessPublic, QMetaType::QString),
        // Slot 'getObjectDataXML'
        QtMocHelpers::SlotData<QString(const QString &)>(38, 6, QMC::AccessPublic, QMetaType::QString, {{
            { QMetaType::QString, 33 },
        }}),
        // Slot 'getObjectDataXML'
        QtMocHelpers::SlotData<QString(const QString &, bool)>(38, 6, QMC::AccessPublic, QMetaType::QString, {{
            { QMetaType::QString, 33 }, { QMetaType::Bool, 39 },
        }}),
        // Slot 'getObjectDataXML'
        QtMocHelpers::SlotData<QString(const QString &, bool, bool)>(38, 6, QMC::AccessPublic, QMetaType::QString, {{
            { QMetaType::QString, 33 }, { QMetaType::Bool, 39 }, { QMetaType::Bool, 40 },
        }}),
        // Slot 'getObjectPositionInfo'
        QtMocHelpers::SlotData<QString(const QString &)>(41, 6, QMC::AccessPublic, QMetaType::QString, {{
            { QMetaType::QString, 33 },
        }}),
        // Slot 'getObservingSessionPlanObjectNames'
        QtMocHelpers::SlotData<QString()>(42, 6, QMC::AccessPublic, QMetaType::QString),
        // Slot 'getObservingWishListObjectNames'
        QtMocHelpers::SlotData<QString()>(43, 6, QMC::AccessPublic, QMetaType::QString),
        // Slot 'getOption'
        QtMocHelpers::SlotData<QDBusVariant(const QString &)>(44, 6, QMC::AccessPublic, 0x80000000 | 45, {{
            { QMetaType::QString, 11 },
        }}),
        // Slot 'getSkyMapDimensions'
        QtMocHelpers::SlotData<QString()>(46, 6, QMC::AccessPublic, QMetaType::QString),
        // Slot 'getSkyMapRotation'
        QtMocHelpers::SlotData<double()>(47, 6, QMC::AccessPublic, QMetaType::Double),
        // Slot 'getToggleableActionStates'
        QtMocHelpers::SlotData<QString()>(48, 6, QMC::AccessPublic, QMetaType::QString),
        // Slot 'listSkyMapViews'
        QtMocHelpers::SlotData<QStringList()>(49, 6, QMC::AccessPublic, QMetaType::QStringList),
        // Slot 'loadColorScheme'
        QtMocHelpers::SlotData<void(const QString &)>(50, 10, QMC::AccessPublic, QMetaType::Void, {{
            { QMetaType::QString, 11 },
        }}),
        // Slot 'location'
        QtMocHelpers::SlotData<QString()>(51, 6, QMC::AccessPublic, QMetaType::QString),
        // Slot 'lookTowards'
        QtMocHelpers::SlotData<void(const QString &)>(52, 10, QMC::AccessPublic, QMetaType::Void, {{
            { QMetaType::QString, 53 },
        }}),
        // Slot 'openFITS'
        QtMocHelpers::SlotData<void(const QUrl &)>(54, 10, QMC::AccessPublic, QMetaType::Void, {{
            { 0x80000000 | 55, 56 },
        }}),
        // Slot 'popupMessage'
        QtMocHelpers::SlotData<void(int, int, const QString &)>(57, 10, QMC::AccessPublic, QMetaType::Void, {{
            { QMetaType::Int, 58 }, { QMetaType::Int, 59 }, { QMetaType::QString, 60 },
        }}),
        // Slot 'printImage'
        QtMocHelpers::SlotData<void(bool, bool)>(61, 10, QMC::AccessPublic, QMetaType::Void, {{
            { QMetaType::Bool, 62 }, { QMetaType::Bool, 63 },
        }}),
        // Slot 'readConfig'
        QtMocHelpers::SlotData<void()>(64, 10, QMC::AccessPublic, QMetaType::Void),
        // Slot 'removeLabel'
        QtMocHelpers::SlotData<void(const QString &)>(65, 10, QMC::AccessPublic, QMetaType::Void, {{
            { QMetaType::QString, 11 },
        }}),
        // Slot 'removeTrail'
        QtMocHelpers::SlotData<void(const QString &)>(66, 10, QMC::AccessPublic, QMetaType::Void, {{
            { QMetaType::QString, 11 },
        }}),
        // Slot 'renderEyepieceView'
        QtMocHelpers::SlotData<void(const QString &, const QString &, double, double, double, double, bool, bool, const QString &, const QString &, bool, bool)>(67, 10, QMC::AccessPublic, QMetaType::Void, {{
            { QMetaType::QString, 33 }, { QMetaType::QString, 68 }, { QMetaType::Double, 69 }, { QMetaType::Double, 70 },
            { QMetaType::Double, 71 }, { QMetaType::Double, 72 }, { QMetaType::Bool, 73 }, { QMetaType::Bool, 74 },
            { QMetaType::QString, 75 }, { QMetaType::QString, 76 }, { QMetaType::Bool, 77 }, { QMetaType::Bool, 78 },
        }}),
        // Slot 'setAltAz'
        QtMocHelpers::SlotData<void(double, double)>(79, 10, QMC::AccessPublic, QMetaType::Void, {{
            { QMetaType::Double, 80 }, { QMetaType::Double, 81 },
        }}),
        // Slot 'setAltAz'
        QtMocHelpers::SlotData<void(double, double, bool)>(79, 10, QMC::AccessPublic, QMetaType::Void, {{
            { QMetaType::Double, 80 }, { QMetaType::Double, 81 }, { QMetaType::Bool, 82 },
        }}),
        // Slot 'setApproxFOV'
        QtMocHelpers::SlotData<void(double)>(83, 10, QMC::AccessPublic, QMetaType::Void, {{
            { QMetaType::Double, 84 },
        }}),
        // Slot 'setColor'
        QtMocHelpers::SlotData<void(const QString &, const QString &)>(85, 10, QMC::AccessPublic, QMetaType::Void, {{
            { QMetaType::QString, 86 }, { QMetaType::QString, 15 },
        }}),
        // Slot 'setFOVIndicatorVisibility'
        QtMocHelpers::SlotData<bool(const QString &, bool)>(87, 6, QMC::AccessPublic, QMetaType::Bool, {{
            { QMetaType::QString, 35 }, { QMetaType::Bool, 88 },
        }}),
        // Slot 'setGPSLocation'
        QtMocHelpers::SlotData<bool(double, double, double, double)>(89, 6, QMC::AccessPublic, QMetaType::Bool, {{
            { QMetaType::Double, 90 }, { QMetaType::Double, 91 }, { QMetaType::Double, 92 }, { QMetaType::Double, 93 },
        }}),
        // Slot 'setGeoLocation'
        QtMocHelpers::SlotData<bool(const QString &, const QString &, const QString &)>(94, 6, QMC::AccessPublic, QMetaType::Bool, {{
            { QMetaType::QString, 95 }, { QMetaType::QString, 96 }, { QMetaType::QString, 97 },
        }}),
        // Slot 'setLocalTime'
        QtMocHelpers::SlotData<void(int, int, int, int, int, int)>(98, 10, QMC::AccessPublic, QMetaType::Void, {{
            { QMetaType::Int, 99 }, { QMetaType::Int, 100 }, { QMetaType::Int, 101 }, { QMetaType::Int, 102 },
            { QMetaType::Int, 103 }, { QMetaType::Int, 104 },
        }}),
        // Slot 'setOption'
        QtMocHelpers::SlotData<void(const QString &, const QDBusVariant &)>(105, 10, QMC::AccessPublic, QMetaType::Void, {{
            { QMetaType::QString, 11 }, { 0x80000000 | 45, 15 },
        }}),
        // Slot 'setRaDec'
        QtMocHelpers::SlotData<void(double, double)>(106, 10, QMC::AccessPublic, QMetaType::Void, {{
            { QMetaType::Double, 107 }, { QMetaType::Double, 108 },
        }}),
        // Slot 'setRaDecJ2000'
        QtMocHelpers::SlotData<void(double, double)>(109, 10, QMC::AccessPublic, QMetaType::Void, {{
            { QMetaType::Double, 110 }, { QMetaType::Double, 111 },
        }}),
        // Slot 'setSkyMapMirrored'
        QtMocHelpers::SlotData<void(bool)>(112, 10, QMC::AccessPublic, QMetaType::Void, {{
            { QMetaType::Bool, 113 },
        }}),
        // Slot 'setSkyMapRotation'
        QtMocHelpers::SlotData<void(double)>(114, 10, QMC::AccessPublic, QMetaType::Void, {{
            { QMetaType::Double, 115 },
        }}),
        // Slot 'setSkyMapView'
        QtMocHelpers::SlotData<bool(const QString &)>(116, 6, QMC::AccessPublic, QMetaType::Bool, {{
            { QMetaType::QString, 117 },
        }}),
        // Slot 'setTimeToNow'
        QtMocHelpers::SlotData<void()>(118, 10, QMC::AccessPublic, QMetaType::Void),
        // Slot 'setToggleableActionState'
        QtMocHelpers::SlotData<bool(const QString &, bool)>(119, 6, QMC::AccessPublic, QMetaType::Bool, {{
            { QMetaType::QString, 8 }, { QMetaType::Bool, 120 },
        }}),
        // Slot 'setTracking'
        QtMocHelpers::SlotData<void(bool)>(121, 10, QMC::AccessPublic, QMetaType::Void, {{
            { QMetaType::Bool, 122 },
        }}),
        // Slot 'skyMapIsMirrored'
        QtMocHelpers::SlotData<bool()>(123, 6, QMC::AccessPublic, QMetaType::Bool),
        // Slot 'waitFor'
        QtMocHelpers::SlotData<void(double)>(124, 10, QMC::AccessPublic, QMetaType::Void, {{
            { QMetaType::Double, 125 },
        }}),
        // Slot 'waitForKey'
        QtMocHelpers::SlotData<void(const QString &)>(126, 10, QMC::AccessPublic, QMetaType::Void, {{
            { QMetaType::QString, 127 },
        }}),
        // Slot 'writeConfig'
        QtMocHelpers::SlotData<void()>(128, 10, QMC::AccessPublic, QMetaType::Void),
        // Slot 'zoom'
        QtMocHelpers::SlotData<void(double)>(129, 10, QMC::AccessPublic, QMetaType::Void, {{
            { QMetaType::Double, 130 },
        }}),
        // Slot 'zoomIn'
        QtMocHelpers::SlotData<void()>(131, 10, QMC::AccessPublic, QMetaType::Void),
        // Slot 'zoomOut'
        QtMocHelpers::SlotData<void()>(132, 10, QMC::AccessPublic, QMetaType::Void),
    };
    QtMocHelpers::UintData qt_properties {
        // property 'colorScheme'
        QtMocHelpers::PropertyData<QString>(16, QMetaType::QString, QMC::DefaultPropertyFlags | QMC::Writable | QMC::StdCppSet),
        // property 'release'
        QtMocHelpers::PropertyData<QString>(133, QMetaType::QString, QMC::DefaultPropertyFlags),
        // property 'version'
        QtMocHelpers::PropertyData<QString>(134, QMetaType::QString, QMC::DefaultPropertyFlags),
    };
    QtMocHelpers::UintData qt_enums {
    };
    QtMocHelpers::UintData qt_constructors {};
    QtMocHelpers::ClassInfos qt_classinfo({
            {    1,    2 },
            {    3,    4 },
    });
    return QtMocHelpers::metaObjectData<KstarsAdaptor, qt_meta_tag_ZN13KstarsAdaptorE_t>(QMC::MetaObjectFlag{}, qt_stringData,
            qt_methods, qt_properties, qt_enums, qt_constructors, qt_classinfo);
}
Q_CONSTINIT const QMetaObject KstarsAdaptor::staticMetaObject = { {
    QMetaObject::SuperData::link<QDBusAbstractAdaptor::staticMetaObject>(),
    qt_staticMetaObjectStaticContent<qt_meta_tag_ZN13KstarsAdaptorE_t>.stringdata,
    qt_staticMetaObjectStaticContent<qt_meta_tag_ZN13KstarsAdaptorE_t>.data,
    qt_static_metacall,
    nullptr,
    qt_staticMetaObjectRelocatingContent<qt_meta_tag_ZN13KstarsAdaptorE_t>.metaTypes,
    nullptr
} };

void KstarsAdaptor::qt_static_metacall(QObject *_o, QMetaObject::Call _c, int _id, void **_a)
{
    auto *_t = static_cast<KstarsAdaptor *>(_o);
    if (_c == QMetaObject::InvokeMetaMethod) {
        switch (_id) {
        case 0: _t->colorSchemeChanged(); break;
        case 1: { bool _r = _t->activateAction((*reinterpret_cast<std::add_pointer_t<QString>>(_a[1])));
            if (_a[0]) *reinterpret_cast<bool*>(_a[0]) = std::move(_r); }  break;
        case 2: _t->addLabel((*reinterpret_cast<std::add_pointer_t<QString>>(_a[1]))); break;
        case 3: _t->addTrail((*reinterpret_cast<std::add_pointer_t<QString>>(_a[1]))); break;
        case 4: _t->changeViewOption((*reinterpret_cast<std::add_pointer_t<QString>>(_a[1])),(*reinterpret_cast<std::add_pointer_t<QString>>(_a[2]))); break;
        case 5: { QString _r = _t->colorScheme();
            if (_a[0]) *reinterpret_cast<QString*>(_a[0]) = std::move(_r); }  break;
        case 6: _t->defaultZoom(); break;
        case 7: _t->drawLine((*reinterpret_cast<std::add_pointer_t<int>>(_a[1])),(*reinterpret_cast<std::add_pointer_t<int>>(_a[2])),(*reinterpret_cast<std::add_pointer_t<int>>(_a[3])),(*reinterpret_cast<std::add_pointer_t<int>>(_a[4])),(*reinterpret_cast<std::add_pointer_t<int>>(_a[5]))); break;
        case 8: _t->exportImage((*reinterpret_cast<std::add_pointer_t<QString>>(_a[1]))); break;
        case 9: _t->exportImage((*reinterpret_cast<std::add_pointer_t<QString>>(_a[1])),(*reinterpret_cast<std::add_pointer_t<int>>(_a[2]))); break;
        case 10: _t->exportImage((*reinterpret_cast<std::add_pointer_t<QString>>(_a[1])),(*reinterpret_cast<std::add_pointer_t<int>>(_a[2])),(*reinterpret_cast<std::add_pointer_t<int>>(_a[3]))); break;
        case 11: _t->exportImage((*reinterpret_cast<std::add_pointer_t<QString>>(_a[1])),(*reinterpret_cast<std::add_pointer_t<int>>(_a[2])),(*reinterpret_cast<std::add_pointer_t<int>>(_a[3])),(*reinterpret_cast<std::add_pointer_t<bool>>(_a[4]))); break;
        case 12: { QStringList _r = _t->getActions();
            if (_a[0]) *reinterpret_cast<QStringList*>(_a[0]) = std::move(_r); }  break;
        case 13: { QString _r = _t->getDSSURL((*reinterpret_cast<std::add_pointer_t<double>>(_a[1])),(*reinterpret_cast<std::add_pointer_t<double>>(_a[2])));
            if (_a[0]) *reinterpret_cast<QString*>(_a[0]) = std::move(_r); }  break;
        case 14: { QString _r = _t->getDSSURL((*reinterpret_cast<std::add_pointer_t<double>>(_a[1])),(*reinterpret_cast<std::add_pointer_t<double>>(_a[2])),(*reinterpret_cast<std::add_pointer_t<double>>(_a[3])),(*reinterpret_cast<std::add_pointer_t<double>>(_a[4])));
            if (_a[0]) *reinterpret_cast<QString*>(_a[0]) = std::move(_r); }  break;
        case 15: { QString _r = _t->getDSSURL((*reinterpret_cast<std::add_pointer_t<QString>>(_a[1])));
            if (_a[0]) *reinterpret_cast<QString*>(_a[0]) = std::move(_r); }  break;
        case 16: { bool _r = _t->getFOVIndicatorVisibility((*reinterpret_cast<std::add_pointer_t<QString>>(_a[1])));
            if (_a[0]) *reinterpret_cast<bool*>(_a[0]) = std::move(_r); }  break;
        case 17: { QStringList _r = _t->getFOVIndicators();
            if (_a[0]) *reinterpret_cast<QStringList*>(_a[0]) = std::move(_r); }  break;
        case 18: { QString _r = _t->getFocusInformationXML();
            if (_a[0]) *reinterpret_cast<QString*>(_a[0]) = std::move(_r); }  break;
        case 19: { QString _r = _t->getObjectDataXML((*reinterpret_cast<std::add_pointer_t<QString>>(_a[1])));
            if (_a[0]) *reinterpret_cast<QString*>(_a[0]) = std::move(_r); }  break;
        case 20: { QString _r = _t->getObjectDataXML((*reinterpret_cast<std::add_pointer_t<QString>>(_a[1])),(*reinterpret_cast<std::add_pointer_t<bool>>(_a[2])));
            if (_a[0]) *reinterpret_cast<QString*>(_a[0]) = std::move(_r); }  break;
        case 21: { QString _r = _t->getObjectDataXML((*reinterpret_cast<std::add_pointer_t<QString>>(_a[1])),(*reinterpret_cast<std::add_pointer_t<bool>>(_a[2])),(*reinterpret_cast<std::add_pointer_t<bool>>(_a[3])));
            if (_a[0]) *reinterpret_cast<QString*>(_a[0]) = std::move(_r); }  break;
        case 22: { QString _r = _t->getObjectPositionInfo((*reinterpret_cast<std::add_pointer_t<QString>>(_a[1])));
            if (_a[0]) *reinterpret_cast<QString*>(_a[0]) = std::move(_r); }  break;
        case 23: { QString _r = _t->getObservingSessionPlanObjectNames();
            if (_a[0]) *reinterpret_cast<QString*>(_a[0]) = std::move(_r); }  break;
        case 24: { QString _r = _t->getObservingWishListObjectNames();
            if (_a[0]) *reinterpret_cast<QString*>(_a[0]) = std::move(_r); }  break;
        case 25: { QDBusVariant _r = _t->getOption((*reinterpret_cast<std::add_pointer_t<QString>>(_a[1])));
            if (_a[0]) *reinterpret_cast<QDBusVariant*>(_a[0]) = std::move(_r); }  break;
        case 26: { QString _r = _t->getSkyMapDimensions();
            if (_a[0]) *reinterpret_cast<QString*>(_a[0]) = std::move(_r); }  break;
        case 27: { double _r = _t->getSkyMapRotation();
            if (_a[0]) *reinterpret_cast<double*>(_a[0]) = std::move(_r); }  break;
        case 28: { QString _r = _t->getToggleableActionStates();
            if (_a[0]) *reinterpret_cast<QString*>(_a[0]) = std::move(_r); }  break;
        case 29: { QStringList _r = _t->listSkyMapViews();
            if (_a[0]) *reinterpret_cast<QStringList*>(_a[0]) = std::move(_r); }  break;
        case 30: _t->loadColorScheme((*reinterpret_cast<std::add_pointer_t<QString>>(_a[1]))); break;
        case 31: { QString _r = _t->location();
            if (_a[0]) *reinterpret_cast<QString*>(_a[0]) = std::move(_r); }  break;
        case 32: _t->lookTowards((*reinterpret_cast<std::add_pointer_t<QString>>(_a[1]))); break;
        case 33: _t->openFITS((*reinterpret_cast<std::add_pointer_t<QUrl>>(_a[1]))); break;
        case 34: _t->popupMessage((*reinterpret_cast<std::add_pointer_t<int>>(_a[1])),(*reinterpret_cast<std::add_pointer_t<int>>(_a[2])),(*reinterpret_cast<std::add_pointer_t<QString>>(_a[3]))); break;
        case 35: _t->printImage((*reinterpret_cast<std::add_pointer_t<bool>>(_a[1])),(*reinterpret_cast<std::add_pointer_t<bool>>(_a[2]))); break;
        case 36: _t->readConfig(); break;
        case 37: _t->removeLabel((*reinterpret_cast<std::add_pointer_t<QString>>(_a[1]))); break;
        case 38: _t->removeTrail((*reinterpret_cast<std::add_pointer_t<QString>>(_a[1]))); break;
        case 39: _t->renderEyepieceView((*reinterpret_cast<std::add_pointer_t<QString>>(_a[1])),(*reinterpret_cast<std::add_pointer_t<QString>>(_a[2])),(*reinterpret_cast<std::add_pointer_t<double>>(_a[3])),(*reinterpret_cast<std::add_pointer_t<double>>(_a[4])),(*reinterpret_cast<std::add_pointer_t<double>>(_a[5])),(*reinterpret_cast<std::add_pointer_t<double>>(_a[6])),(*reinterpret_cast<std::add_pointer_t<bool>>(_a[7])),(*reinterpret_cast<std::add_pointer_t<bool>>(_a[8])),(*reinterpret_cast<std::add_pointer_t<QString>>(_a[9])),(*reinterpret_cast<std::add_pointer_t<QString>>(_a[10])),(*reinterpret_cast<std::add_pointer_t<bool>>(_a[11])),(*reinterpret_cast<std::add_pointer_t<bool>>(_a[12]))); break;
        case 40: _t->setAltAz((*reinterpret_cast<std::add_pointer_t<double>>(_a[1])),(*reinterpret_cast<std::add_pointer_t<double>>(_a[2]))); break;
        case 41: _t->setAltAz((*reinterpret_cast<std::add_pointer_t<double>>(_a[1])),(*reinterpret_cast<std::add_pointer_t<double>>(_a[2])),(*reinterpret_cast<std::add_pointer_t<bool>>(_a[3]))); break;
        case 42: _t->setApproxFOV((*reinterpret_cast<std::add_pointer_t<double>>(_a[1]))); break;
        case 43: _t->setColor((*reinterpret_cast<std::add_pointer_t<QString>>(_a[1])),(*reinterpret_cast<std::add_pointer_t<QString>>(_a[2]))); break;
        case 44: { bool _r = _t->setFOVIndicatorVisibility((*reinterpret_cast<std::add_pointer_t<QString>>(_a[1])),(*reinterpret_cast<std::add_pointer_t<bool>>(_a[2])));
            if (_a[0]) *reinterpret_cast<bool*>(_a[0]) = std::move(_r); }  break;
        case 45: { bool _r = _t->setGPSLocation((*reinterpret_cast<std::add_pointer_t<double>>(_a[1])),(*reinterpret_cast<std::add_pointer_t<double>>(_a[2])),(*reinterpret_cast<std::add_pointer_t<double>>(_a[3])),(*reinterpret_cast<std::add_pointer_t<double>>(_a[4])));
            if (_a[0]) *reinterpret_cast<bool*>(_a[0]) = std::move(_r); }  break;
        case 46: { bool _r = _t->setGeoLocation((*reinterpret_cast<std::add_pointer_t<QString>>(_a[1])),(*reinterpret_cast<std::add_pointer_t<QString>>(_a[2])),(*reinterpret_cast<std::add_pointer_t<QString>>(_a[3])));
            if (_a[0]) *reinterpret_cast<bool*>(_a[0]) = std::move(_r); }  break;
        case 47: _t->setLocalTime((*reinterpret_cast<std::add_pointer_t<int>>(_a[1])),(*reinterpret_cast<std::add_pointer_t<int>>(_a[2])),(*reinterpret_cast<std::add_pointer_t<int>>(_a[3])),(*reinterpret_cast<std::add_pointer_t<int>>(_a[4])),(*reinterpret_cast<std::add_pointer_t<int>>(_a[5])),(*reinterpret_cast<std::add_pointer_t<int>>(_a[6]))); break;
        case 48: _t->setOption((*reinterpret_cast<std::add_pointer_t<QString>>(_a[1])),(*reinterpret_cast<std::add_pointer_t<QDBusVariant>>(_a[2]))); break;
        case 49: _t->setRaDec((*reinterpret_cast<std::add_pointer_t<double>>(_a[1])),(*reinterpret_cast<std::add_pointer_t<double>>(_a[2]))); break;
        case 50: _t->setRaDecJ2000((*reinterpret_cast<std::add_pointer_t<double>>(_a[1])),(*reinterpret_cast<std::add_pointer_t<double>>(_a[2]))); break;
        case 51: _t->setSkyMapMirrored((*reinterpret_cast<std::add_pointer_t<bool>>(_a[1]))); break;
        case 52: _t->setSkyMapRotation((*reinterpret_cast<std::add_pointer_t<double>>(_a[1]))); break;
        case 53: { bool _r = _t->setSkyMapView((*reinterpret_cast<std::add_pointer_t<QString>>(_a[1])));
            if (_a[0]) *reinterpret_cast<bool*>(_a[0]) = std::move(_r); }  break;
        case 54: _t->setTimeToNow(); break;
        case 55: { bool _r = _t->setToggleableActionState((*reinterpret_cast<std::add_pointer_t<QString>>(_a[1])),(*reinterpret_cast<std::add_pointer_t<bool>>(_a[2])));
            if (_a[0]) *reinterpret_cast<bool*>(_a[0]) = std::move(_r); }  break;
        case 56: _t->setTracking((*reinterpret_cast<std::add_pointer_t<bool>>(_a[1]))); break;
        case 57: { bool _r = _t->skyMapIsMirrored();
            if (_a[0]) *reinterpret_cast<bool*>(_a[0]) = std::move(_r); }  break;
        case 58: _t->waitFor((*reinterpret_cast<std::add_pointer_t<double>>(_a[1]))); break;
        case 59: _t->waitForKey((*reinterpret_cast<std::add_pointer_t<QString>>(_a[1]))); break;
        case 60: _t->writeConfig(); break;
        case 61: _t->zoom((*reinterpret_cast<std::add_pointer_t<double>>(_a[1]))); break;
        case 62: _t->zoomIn(); break;
        case 63: _t->zoomOut(); break;
        default: ;
        }
    }
    if (_c == QMetaObject::IndexOfMethod) {
        if (QtMocHelpers::indexOfMethod<void (KstarsAdaptor::*)()>(_a, &KstarsAdaptor::colorSchemeChanged, 0))
            return;
    }
    if (_c == QMetaObject::ReadProperty) {
        void *_v = _a[0];
        switch (_id) {
        case 0: *reinterpret_cast<QString*>(_v) = _t->colorScheme(); break;
        case 1: *reinterpret_cast<QString*>(_v) = _t->release(); break;
        case 2: *reinterpret_cast<QString*>(_v) = _t->version(); break;
        default: break;
        }
    }
    if (_c == QMetaObject::WriteProperty) {
        void *_v = _a[0];
        switch (_id) {
        case 0: _t->setColorScheme(*reinterpret_cast<QString*>(_v)); break;
        default: break;
        }
    }
}

const QMetaObject *KstarsAdaptor::metaObject() const
{
    return QObject::d_ptr->metaObject ? QObject::d_ptr->dynamicMetaObject() : &staticMetaObject;
}

void *KstarsAdaptor::qt_metacast(const char *_clname)
{
    if (!_clname) return nullptr;
    if (!strcmp(_clname, qt_staticMetaObjectStaticContent<qt_meta_tag_ZN13KstarsAdaptorE_t>.strings))
        return static_cast<void*>(this);
    return QDBusAbstractAdaptor::qt_metacast(_clname);
}

int KstarsAdaptor::qt_metacall(QMetaObject::Call _c, int _id, void **_a)
{
    _id = QDBusAbstractAdaptor::qt_metacall(_c, _id, _a);
    if (_id < 0)
        return _id;
    if (_c == QMetaObject::InvokeMetaMethod) {
        if (_id < 64)
            qt_static_metacall(this, _c, _id, _a);
        _id -= 64;
    }
    if (_c == QMetaObject::RegisterMethodArgumentMetaType) {
        if (_id < 64)
            *reinterpret_cast<QMetaType *>(_a[0]) = QMetaType();
        _id -= 64;
    }
    if (_c == QMetaObject::ReadProperty || _c == QMetaObject::WriteProperty
            || _c == QMetaObject::ResetProperty || _c == QMetaObject::BindableProperty
            || _c == QMetaObject::RegisterPropertyMetaType) {
        qt_static_metacall(this, _c, _id, _a);
        _id -= 3;
    }
    return _id;
}

// SIGNAL 0
void KstarsAdaptor::colorSchemeChanged()
{
    QMetaObject::activate(this, &staticMetaObject, 0, nullptr);
}
QT_WARNING_POP
