/********************************************************************************
** Form generated from reading UI file 'opsmiscsettings.ui'
**
** Created by: Qt User Interface Compiler version 6.11.1
**
** WARNING! All changes made in this file will be lost when recompiling UI file!
********************************************************************************/

#ifndef UI_OPSMISCSETTINGS_H
#define UI_OPSMISCSETTINGS_H

#include <QtCore/QVariant>
#include <QtWidgets/QApplication>
#include <QtWidgets/QCheckBox>
#include <QtWidgets/QDoubleSpinBox>
#include <QtWidgets/QGridLayout>
#include <QtWidgets/QLabel>
#include <QtWidgets/QSpacerItem>
#include <QtWidgets/QSpinBox>
#include <QtWidgets/QVBoxLayout>
#include <QtWidgets/QWidget>
#include <klocalizedstring.h>

QT_BEGIN_NAMESPACE

class Ui_OpsMiscSettings
{
public:
    QVBoxLayout *verticalLayout;
    QGridLayout *gridLayout;
    QLabel *label_3;
    QLabel *label_14;
    QLabel *label_17;
    QSpinBox *kcfg_ManualCoverTimeout;
    QLabel *label_13;
    QDoubleSpinBox *kcfg_MaxTemperatureDiff;
    QLabel *label;
    QLabel *label_18;
    QLabel *label_15;
    QSpacerItem *horizontalSpacer_4;
    QSpinBox *kcfg_MinFlipDuration;
    QDoubleSpinBox *kcfg_GuidingSettle;
    QLabel *label_16;
    QLabel *label_2;
    QSpinBox *kcfg_CaptureOperationsTimeout;
    QLabel *label_4;
    QCheckBox *kcfg_AlwaysResetSequenceWhenStarting;
    QCheckBox *kcfg_ResetMountModelAfterMeridian;
    QCheckBox *kcfg_ForcedFlip;
    QCheckBox *kcfg_useSummaryPreview;
    QSpacerItem *verticalSpacer;

    void setupUi(QWidget *OpsMiscSettings)
    {
        if (OpsMiscSettings->objectName().isEmpty())
            OpsMiscSettings->setObjectName("OpsMiscSettings");
        OpsMiscSettings->resize(300, 257);
        OpsMiscSettings->setProperty("currentIndex", QVariant(3));
        verticalLayout = new QVBoxLayout(OpsMiscSettings);
        verticalLayout->setSpacing(3);
        verticalLayout->setObjectName("verticalLayout");
        verticalLayout->setContentsMargins(3, 3, 3, 3);
        gridLayout = new QGridLayout();
        gridLayout->setSpacing(3);
        gridLayout->setObjectName("gridLayout");
        label_3 = new QLabel(OpsMiscSettings);
        label_3->setObjectName("label_3");

        gridLayout->addWidget(label_3, 0, 2, 1, 1);

        label_14 = new QLabel(OpsMiscSettings);
        label_14->setObjectName("label_14");

        gridLayout->addWidget(label_14, 1, 2, 1, 1);

        label_17 = new QLabel(OpsMiscSettings);
        label_17->setObjectName("label_17");

        gridLayout->addWidget(label_17, 4, 0, 1, 1);

        kcfg_ManualCoverTimeout = new QSpinBox(OpsMiscSettings);
        kcfg_ManualCoverTimeout->setObjectName("kcfg_ManualCoverTimeout");
        kcfg_ManualCoverTimeout->setMaximum(600);
        kcfg_ManualCoverTimeout->setSingleStep(10);
        kcfg_ManualCoverTimeout->setValue(60);

        gridLayout->addWidget(kcfg_ManualCoverTimeout, 2, 1, 1, 1);

        label_13 = new QLabel(OpsMiscSettings);
        label_13->setObjectName("label_13");

        gridLayout->addWidget(label_13, 1, 0, 1, 1);

        kcfg_MaxTemperatureDiff = new QDoubleSpinBox(OpsMiscSettings);
        kcfg_MaxTemperatureDiff->setObjectName("kcfg_MaxTemperatureDiff");
        kcfg_MaxTemperatureDiff->setMinimum(0.100000000000000);
        kcfg_MaxTemperatureDiff->setMaximum(5.000000000000000);
        kcfg_MaxTemperatureDiff->setSingleStep(0.100000000000000);
        kcfg_MaxTemperatureDiff->setValue(0.100000000000000);

        gridLayout->addWidget(kcfg_MaxTemperatureDiff, 0, 1, 1, 1);

        label = new QLabel(OpsMiscSettings);
        label->setObjectName("label");

        gridLayout->addWidget(label, 0, 0, 1, 1);

        label_18 = new QLabel(OpsMiscSettings);
        label_18->setObjectName("label_18");

        gridLayout->addWidget(label_18, 4, 2, 1, 1);

        label_15 = new QLabel(OpsMiscSettings);
        label_15->setObjectName("label_15");

        gridLayout->addWidget(label_15, 2, 0, 1, 1);

        horizontalSpacer_4 = new QSpacerItem(163, 13, QSizePolicy::Policy::Expanding, QSizePolicy::Policy::Minimum);

        gridLayout->addItem(horizontalSpacer_4, 0, 3, 2, 1);

        kcfg_MinFlipDuration = new QSpinBox(OpsMiscSettings);
        kcfg_MinFlipDuration->setObjectName("kcfg_MinFlipDuration");
        kcfg_MinFlipDuration->setMaximum(360);
        kcfg_MinFlipDuration->setSingleStep(5);
        kcfg_MinFlipDuration->setValue(20);

        gridLayout->addWidget(kcfg_MinFlipDuration, 4, 1, 1, 1);

        kcfg_GuidingSettle = new QDoubleSpinBox(OpsMiscSettings);
        kcfg_GuidingSettle->setObjectName("kcfg_GuidingSettle");

        gridLayout->addWidget(kcfg_GuidingSettle, 1, 1, 1, 1);

        label_16 = new QLabel(OpsMiscSettings);
        label_16->setObjectName("label_16");

        gridLayout->addWidget(label_16, 2, 2, 1, 1);

        label_2 = new QLabel(OpsMiscSettings);
        label_2->setObjectName("label_2");

        gridLayout->addWidget(label_2, 3, 0, 1, 1);

        kcfg_CaptureOperationsTimeout = new QSpinBox(OpsMiscSettings);
        kcfg_CaptureOperationsTimeout->setObjectName("kcfg_CaptureOperationsTimeout");
        kcfg_CaptureOperationsTimeout->setMinimum(5);
        kcfg_CaptureOperationsTimeout->setMaximum(900);
        kcfg_CaptureOperationsTimeout->setValue(120);

        gridLayout->addWidget(kcfg_CaptureOperationsTimeout, 3, 1, 1, 1);

        label_4 = new QLabel(OpsMiscSettings);
        label_4->setObjectName("label_4");

        gridLayout->addWidget(label_4, 3, 2, 1, 1);


        verticalLayout->addLayout(gridLayout);

        kcfg_AlwaysResetSequenceWhenStarting = new QCheckBox(OpsMiscSettings);
        kcfg_AlwaysResetSequenceWhenStarting->setObjectName("kcfg_AlwaysResetSequenceWhenStarting");
        kcfg_AlwaysResetSequenceWhenStarting->setChecked(false);

        verticalLayout->addWidget(kcfg_AlwaysResetSequenceWhenStarting);

        kcfg_ResetMountModelAfterMeridian = new QCheckBox(OpsMiscSettings);
        kcfg_ResetMountModelAfterMeridian->setObjectName("kcfg_ResetMountModelAfterMeridian");

        verticalLayout->addWidget(kcfg_ResetMountModelAfterMeridian);

        kcfg_ForcedFlip = new QCheckBox(OpsMiscSettings);
        kcfg_ForcedFlip->setObjectName("kcfg_ForcedFlip");

        verticalLayout->addWidget(kcfg_ForcedFlip);

        kcfg_useSummaryPreview = new QCheckBox(OpsMiscSettings);
        kcfg_useSummaryPreview->setObjectName("kcfg_useSummaryPreview");

        verticalLayout->addWidget(kcfg_useSummaryPreview);

        verticalSpacer = new QSpacerItem(20, 40, QSizePolicy::Policy::Minimum, QSizePolicy::Policy::Expanding);

        verticalLayout->addItem(verticalSpacer);


        retranslateUi(OpsMiscSettings);

        QMetaObject::connectSlotsByName(OpsMiscSettings);
    } // setupUi

    void retranslateUi(QWidget *OpsMiscSettings)
    {
        OpsMiscSettings->setWindowTitle(tr2i18n("TabWidget", nullptr));
        label_3->setText(tr2i18n("\302\260 C", nullptr));
        label_14->setText(tr2i18n("seconds", nullptr));
#if QT_CONFIG(tooltip)
        label_17->setToolTip(tr2i18n("<html><head/><body><p>Minimal duration of a meridian flip in seconds. Increase this value if Ekos reports that a meridian flip has failed because the pier side did not change. A good estimation for this value is at least 50% of the typical duration of a meridian flip.</p></body></html>", nullptr));
#endif // QT_CONFIG(tooltip)
        label_17->setText(tr2i18n("Minimal meridian flip duration: ", nullptr));
#if QT_CONFIG(tooltip)
        label_13->setToolTip(tr2i18n("Wait this many seconds after guiding is resumed to stabilize the guiding performance before capture.", nullptr));
#endif // QT_CONFIG(tooltip)
        label_13->setText(tr2i18n("Guiding settle:", nullptr));
#if QT_CONFIG(tooltip)
        label->setToolTip(tr2i18n("Maximum acceptable difference between requested and measured temperature set point. When the temperature threshold is below this value, the temperature set point request is deemed successful.", nullptr));
#endif // QT_CONFIG(tooltip)
        label->setText(tr2i18n("Temperature threshold:", nullptr));
        label_18->setText(tr2i18n("seconds", nullptr));
#if QT_CONFIG(tooltip)
        label_15->setToolTip(tr2i18n("Cover or uncover telescope dialog timeout in seconds", nullptr));
#endif // QT_CONFIG(tooltip)
        label_15->setText(tr2i18n("Dialog timeout:", nullptr));
#if QT_CONFIG(tooltip)
        kcfg_GuidingSettle->setToolTip(tr2i18n("Wait this many seconds after guiding is resumed before starting capture", nullptr));
#endif // QT_CONFIG(tooltip)
        label_16->setText(tr2i18n("seconds", nullptr));
#if QT_CONFIG(tooltip)
        label_2->setToolTip(tr2i18n("Maximum number of seconds to wait before aborting the capture if operations like filter wheel changes or meridian flips take too long. Also bounds the time the scheduler spends establishing guiding (calibration and lock) before starting capture.", nullptr));
#endif // QT_CONFIG(tooltip)
        label_2->setText(tr2i18n("Capture Operations Timeout", nullptr));
        label_4->setText(tr2i18n("seconds", nullptr));
#if QT_CONFIG(tooltip)
        kcfg_AlwaysResetSequenceWhenStarting->setToolTip(tr2i18n("<html><head/><body><p>When starting to process a sequence list, reset all capture counts to zero. Scheduler overrides this option when Remember job progress is enabled.</p></body></html>", nullptr));
#endif // QT_CONFIG(tooltip)
        kcfg_AlwaysResetSequenceWhenStarting->setText(tr2i18n("Always reset sequence when starting", nullptr));
        kcfg_ResetMountModelAfterMeridian->setText(tr2i18n("Reset mount model after meridian flip", nullptr));
        kcfg_ForcedFlip->setText(tr2i18n("Use flip command if supported by mount", nullptr));
#if QT_CONFIG(tooltip)
        kcfg_useSummaryPreview->setToolTip(tr2i18n("Display received FITS in the Summary screen preview window.", nullptr));
#endif // QT_CONFIG(tooltip)
        kcfg_useSummaryPreview->setText(tr2i18n("Summary screen preview", nullptr));
    } // retranslateUi

};

namespace Ui {
    class OpsMiscSettings: public Ui_OpsMiscSettings {};
} // namespace Ui

QT_END_NAMESPACE

#endif // OPSMISCSETTINGS_H

