/****************************************************************************
** Meta object code from reading C++ file 'focusmodule.h'
**
** Created by: The Qt Meta Object Compiler version 69 (Qt 6.11.1)
**
** WARNING! All changes made in this file will be lost!
*****************************************************************************/

#include "../../../../kstars-3.8.4.1/kstars/ekos/focus/focusmodule.h"
#include <QtNetwork/QSslError>
#include <QtDataVisualization/qbar3dseries.h>
#include <QtDataVisualization/q3dscene.h>
#include <QtGui/qtextcursor.h>
#include <QtGui/qscreen.h>
#include <QtCore/qmetatype.h>

#include <QtCore/qtmochelpers.h>

#include <memory>


#include <QtCore/qxptype_traits.h>
#if !defined(Q_MOC_OUTPUT_REVISION)
#error "The header file 'focusmodule.h' doesn't include <QObject>."
#elif Q_MOC_OUTPUT_REVISION != 69
#error "This file was generated using the moc from 6.11.1. It"
#error "cannot be used with the include files from this version of Qt."
#error "(The moc has changed too much.)"
#endif

#ifndef Q_CONSTINIT
#define Q_CONSTINIT
#endif

QT_WARNING_PUSH
QT_WARNING_DISABLE_DEPRECATED
QT_WARNING_DISABLE_GCC("-Wuseless-cast")
namespace {
struct qt_meta_tag_ZN4Ekos11FocusModuleE_t {};
} // unnamed namespace

template <> constexpr inline auto Ekos::FocusModule::qt_create_metaobjectdata<qt_meta_tag_ZN4Ekos11FocusModuleE_t>()
{
    namespace QMC = QtMocConstants;
    QtMocHelpers::StringRefStorage qt_stringData {
        "Ekos::FocusModule",
        "D-Bus Interface",
        "org.kde.kstars.Ekos.Focus",
        "newLog",
        "",
        "text",
        "newStatus",
        "FocusState",
        "state",
        "trainname",
        "newHFR",
        "hfr",
        "position",
        "inAutofocus",
        "suspendGuiding",
        "resumeGuiding",
        "focusAdaptiveComplete",
        "success",
        "newFocusTemperatureDelta",
        "delta",
        "absTemperature",
        "inSequenceAF",
        "requested",
        "start",
        "capture",
        "settleTime",
        "focusIn",
        "ms",
        "focusOut",
        "checkFocus",
        "Q_NOREPLY",
        "requiredHFR",
        "status",
        "Ekos::FocusState",
        "camera",
        "focuser",
        "filterWheel",
        "setFilter",
        "filter",
        "getHFR",
        "setExposure",
        "value",
        "exposure",
        "canAutoFocus",
        "useFullField",
        "setBinning",
        "binX",
        "binY",
        "setAutoStarEnabled",
        "enable",
        "setAutoSubFrameEnabled",
        "setAutoFocusParameters",
        "boxSize",
        "stepSize",
        "maxTravel",
        "tolerance",
        "clearLog"
    };

    QtMocHelpers::UintData qt_methods {
        // Signal 'newLog'
        QtMocHelpers::SignalData<void(const QString &)>(3, 4, QMC::AccessPublic | QMC::MethodScriptable, QMetaType::Void, {{
            { QMetaType::QString, 5 },
        }}),
        // Signal 'newStatus'
        QtMocHelpers::SignalData<void(FocusState, const QString &)>(6, 4, QMC::AccessPublic | QMC::MethodScriptable, QMetaType::Void, {{
            { 0x80000000 | 7, 8 }, { QMetaType::QString, 9 },
        }}),
        // Signal 'newHFR'
        QtMocHelpers::SignalData<void(double, int, bool, const QString &)>(10, 4, QMC::AccessPublic | QMC::MethodScriptable, QMetaType::Void, {{
            { QMetaType::Double, 11 }, { QMetaType::Int, 12 }, { QMetaType::Bool, 13 }, { QMetaType::QString, 9 },
        }}),
        // Signal 'suspendGuiding'
        QtMocHelpers::SignalData<void()>(14, 4, QMC::AccessPublic, QMetaType::Void),
        // Signal 'resumeGuiding'
        QtMocHelpers::SignalData<void()>(15, 4, QMC::AccessPublic, QMetaType::Void),
        // Signal 'focusAdaptiveComplete'
        QtMocHelpers::SignalData<void(bool, const QString &)>(16, 4, QMC::AccessPublic, QMetaType::Void, {{
            { QMetaType::Bool, 17 }, { QMetaType::QString, 9 },
        }}),
        // Signal 'newFocusTemperatureDelta'
        QtMocHelpers::SignalData<void(double, double, const QString &)>(18, 4, QMC::AccessPublic, QMetaType::Void, {{
            { QMetaType::Double, 19 }, { QMetaType::Double, 20 }, { QMetaType::QString, 9 },
        }}),
        // Signal 'inSequenceAF'
        QtMocHelpers::SignalData<void(bool, const QString &)>(21, 4, QMC::AccessPublic, QMetaType::Void, {{
            { QMetaType::Bool, 22 }, { QMetaType::QString, 9 },
        }}),
        // Slot 'start'
        QtMocHelpers::SlotData<bool(const QString &)>(23, 4, QMC::AccessPublic | QMC::MethodScriptable, QMetaType::Bool, {{
            { QMetaType::QString, 9 },
        }}),
        // Slot 'capture'
        QtMocHelpers::SlotData<bool(const QString &, double)>(24, 4, QMC::AccessPublic | QMC::MethodScriptable, QMetaType::Bool, {{
            { QMetaType::QString, 9 }, { QMetaType::Double, 25 },
        }}),
        // Slot 'capture'
        QtMocHelpers::SlotData<bool(const QString &)>(24, 4, QMC::AccessPublic | QMC::MethodCloned | QMC::MethodScriptable, QMetaType::Bool, {{
            { QMetaType::QString, 9 },
        }}),
        // Slot 'focusIn'
        QtMocHelpers::SlotData<bool(const QString &, int)>(26, 4, QMC::AccessPublic | QMC::MethodScriptable, QMetaType::Bool, {{
            { QMetaType::QString, 9 }, { QMetaType::Int, 27 },
        }}),
        // Slot 'focusIn'
        QtMocHelpers::SlotData<bool(const QString &)>(26, 4, QMC::AccessPublic | QMC::MethodCloned | QMC::MethodScriptable, QMetaType::Bool, {{
            { QMetaType::QString, 9 },
        }}),
        // Slot 'focusOut'
        QtMocHelpers::SlotData<bool(const QString &, int)>(28, 4, QMC::AccessPublic | QMC::MethodScriptable, QMetaType::Bool, {{
            { QMetaType::QString, 9 }, { QMetaType::Int, 27 },
        }}),
        // Slot 'focusOut'
        QtMocHelpers::SlotData<bool(const QString &)>(28, 4, QMC::AccessPublic | QMC::MethodCloned | QMC::MethodScriptable, QMetaType::Bool, {{
            { QMetaType::QString, 9 },
        }}),
        // Slot 'checkFocus'
        QtMocHelpers::SlotData<void(double, const QString &)>(29, 30, QMC::AccessPublic | QMC::MethodScriptable, QMetaType::Void, {{
            { QMetaType::Double, 31 }, { QMetaType::QString, 9 },
        }}),
        // Method 'status'
        QtMocHelpers::MethodData<Ekos::FocusState(const QString &)>(32, 4, QMC::AccessPublic | QMC::MethodScriptable, 0x80000000 | 33, {{
            { QMetaType::QString, 9 },
        }}),
        // Method 'camera'
        QtMocHelpers::MethodData<QString(const QString &)>(34, 4, QMC::AccessPublic | QMC::MethodScriptable, QMetaType::QString, {{
            { QMetaType::QString, 9 },
        }}),
        // Method 'focuser'
        QtMocHelpers::MethodData<QString(const QString &)>(35, 4, QMC::AccessPublic | QMC::MethodScriptable, QMetaType::QString, {{
            { QMetaType::QString, 9 },
        }}),
        // Method 'filterWheel'
        QtMocHelpers::MethodData<QString(const QString &)>(36, 4, QMC::AccessPublic | QMC::MethodScriptable, QMetaType::QString, {{
            { QMetaType::QString, 9 },
        }}),
        // Method 'setFilter'
        QtMocHelpers::MethodData<bool(const QString &, const QString &)>(37, 4, QMC::AccessPublic | QMC::MethodScriptable, QMetaType::Bool, {{
            { QMetaType::QString, 38 }, { QMetaType::QString, 9 },
        }}),
        // Method 'filter'
        QtMocHelpers::MethodData<QString(const QString &)>(38, 4, QMC::AccessPublic | QMC::MethodScriptable, QMetaType::QString, {{
            { QMetaType::QString, 9 },
        }}),
        // Method 'getHFR'
        QtMocHelpers::MethodData<double(const QString &)>(39, 4, QMC::AccessPublic | QMC::MethodScriptable, QMetaType::Double, {{
            { QMetaType::QString, 9 },
        }}),
        // Method 'setExposure'
        QtMocHelpers::MethodData<bool(double, const QString &)>(40, 4, QMC::AccessPublic | QMC::MethodScriptable, QMetaType::Bool, {{
            { QMetaType::Double, 41 }, { QMetaType::QString, 9 },
        }}),
        // Method 'exposure'
        QtMocHelpers::MethodData<double(const QString &)>(42, 4, QMC::AccessPublic | QMC::MethodScriptable, QMetaType::Double, {{
            { QMetaType::QString, 9 },
        }}),
        // Method 'canAutoFocus'
        QtMocHelpers::MethodData<bool(const QString &)>(43, 4, QMC::AccessPublic | QMC::MethodScriptable, QMetaType::Bool, {{
            { QMetaType::QString, 9 },
        }}),
        // Method 'useFullField'
        QtMocHelpers::MethodData<bool(const QString &)>(44, 4, QMC::AccessPublic | QMC::MethodScriptable, QMetaType::Bool, {{
            { QMetaType::QString, 9 },
        }}),
        // Method 'setBinning'
        QtMocHelpers::MethodData<bool(int, int, const QString &)>(45, 4, QMC::AccessPublic | QMC::MethodScriptable, QMetaType::Bool, {{
            { QMetaType::Int, 46 }, { QMetaType::Int, 47 }, { QMetaType::QString, 9 },
        }}),
        // Method 'setAutoStarEnabled'
        QtMocHelpers::MethodData<bool(bool, const QString &)>(48, 4, QMC::AccessPublic | QMC::MethodScriptable, QMetaType::Bool, {{
            { QMetaType::Bool, 49 }, { QMetaType::QString, 9 },
        }}),
        // Method 'setAutoSubFrameEnabled'
        QtMocHelpers::MethodData<bool(bool, const QString &)>(50, 4, QMC::AccessPublic | QMC::MethodScriptable, QMetaType::Bool, {{
            { QMetaType::Bool, 49 }, { QMetaType::QString, 9 },
        }}),
        // Method 'setAutoFocusParameters'
        QtMocHelpers::MethodData<bool(const QString &, int, int, int, double)>(51, 4, QMC::AccessPublic | QMC::MethodScriptable, QMetaType::Bool, {{
            { QMetaType::QString, 9 }, { QMetaType::Int, 52 }, { QMetaType::Int, 53 }, { QMetaType::Int, 54 },
            { QMetaType::Double, 55 },
        }}),
        // Method 'clearLog'
        QtMocHelpers::MethodData<void()>(56, 4, QMC::AccessPublic, QMetaType::Void),
    };
    QtMocHelpers::UintData qt_properties {
    };
    QtMocHelpers::UintData qt_enums {
    };
    QtMocHelpers::UintData qt_constructors {};
    QtMocHelpers::ClassInfos qt_classinfo({
            {    1,    2 },
    });
    return QtMocHelpers::metaObjectData<FocusModule, qt_meta_tag_ZN4Ekos11FocusModuleE_t>(QMC::MetaObjectFlag{}, qt_stringData,
            qt_methods, qt_properties, qt_enums, qt_constructors, qt_classinfo);
}
Q_CONSTINIT const QMetaObject Ekos::FocusModule::staticMetaObject = { {
    QMetaObject::SuperData::link<QWidget::staticMetaObject>(),
    qt_staticMetaObjectStaticContent<qt_meta_tag_ZN4Ekos11FocusModuleE_t>.stringdata,
    qt_staticMetaObjectStaticContent<qt_meta_tag_ZN4Ekos11FocusModuleE_t>.data,
    qt_static_metacall,
    nullptr,
    qt_staticMetaObjectRelocatingContent<qt_meta_tag_ZN4Ekos11FocusModuleE_t>.metaTypes,
    nullptr
} };

void Ekos::FocusModule::qt_static_metacall(QObject *_o, QMetaObject::Call _c, int _id, void **_a)
{
    auto *_t = static_cast<FocusModule *>(_o);
    if (_c == QMetaObject::InvokeMetaMethod) {
        switch (_id) {
        case 0: _t->newLog((*reinterpret_cast<std::add_pointer_t<QString>>(_a[1]))); break;
        case 1: _t->newStatus((*reinterpret_cast<std::add_pointer_t<FocusState>>(_a[1])),(*reinterpret_cast<std::add_pointer_t<QString>>(_a[2]))); break;
        case 2: _t->newHFR((*reinterpret_cast<std::add_pointer_t<double>>(_a[1])),(*reinterpret_cast<std::add_pointer_t<int>>(_a[2])),(*reinterpret_cast<std::add_pointer_t<bool>>(_a[3])),(*reinterpret_cast<std::add_pointer_t<QString>>(_a[4]))); break;
        case 3: _t->suspendGuiding(); break;
        case 4: _t->resumeGuiding(); break;
        case 5: _t->focusAdaptiveComplete((*reinterpret_cast<std::add_pointer_t<bool>>(_a[1])),(*reinterpret_cast<std::add_pointer_t<QString>>(_a[2]))); break;
        case 6: _t->newFocusTemperatureDelta((*reinterpret_cast<std::add_pointer_t<double>>(_a[1])),(*reinterpret_cast<std::add_pointer_t<double>>(_a[2])),(*reinterpret_cast<std::add_pointer_t<QString>>(_a[3]))); break;
        case 7: _t->inSequenceAF((*reinterpret_cast<std::add_pointer_t<bool>>(_a[1])),(*reinterpret_cast<std::add_pointer_t<QString>>(_a[2]))); break;
        case 8: { bool _r = _t->start((*reinterpret_cast<std::add_pointer_t<QString>>(_a[1])));
            if (_a[0]) *reinterpret_cast<bool*>(_a[0]) = std::move(_r); }  break;
        case 9: { bool _r = _t->capture((*reinterpret_cast<std::add_pointer_t<QString>>(_a[1])),(*reinterpret_cast<std::add_pointer_t<double>>(_a[2])));
            if (_a[0]) *reinterpret_cast<bool*>(_a[0]) = std::move(_r); }  break;
        case 10: { bool _r = _t->capture((*reinterpret_cast<std::add_pointer_t<QString>>(_a[1])));
            if (_a[0]) *reinterpret_cast<bool*>(_a[0]) = std::move(_r); }  break;
        case 11: { bool _r = _t->focusIn((*reinterpret_cast<std::add_pointer_t<QString>>(_a[1])),(*reinterpret_cast<std::add_pointer_t<int>>(_a[2])));
            if (_a[0]) *reinterpret_cast<bool*>(_a[0]) = std::move(_r); }  break;
        case 12: { bool _r = _t->focusIn((*reinterpret_cast<std::add_pointer_t<QString>>(_a[1])));
            if (_a[0]) *reinterpret_cast<bool*>(_a[0]) = std::move(_r); }  break;
        case 13: { bool _r = _t->focusOut((*reinterpret_cast<std::add_pointer_t<QString>>(_a[1])),(*reinterpret_cast<std::add_pointer_t<int>>(_a[2])));
            if (_a[0]) *reinterpret_cast<bool*>(_a[0]) = std::move(_r); }  break;
        case 14: { bool _r = _t->focusOut((*reinterpret_cast<std::add_pointer_t<QString>>(_a[1])));
            if (_a[0]) *reinterpret_cast<bool*>(_a[0]) = std::move(_r); }  break;
        case 15: _t->checkFocus((*reinterpret_cast<std::add_pointer_t<double>>(_a[1])),(*reinterpret_cast<std::add_pointer_t<QString>>(_a[2]))); break;
        case 16: { Ekos::FocusState _r = _t->status((*reinterpret_cast<std::add_pointer_t<QString>>(_a[1])));
            if (_a[0]) *reinterpret_cast<Ekos::FocusState*>(_a[0]) = std::move(_r); }  break;
        case 17: { QString _r = _t->camera((*reinterpret_cast<std::add_pointer_t<QString>>(_a[1])));
            if (_a[0]) *reinterpret_cast<QString*>(_a[0]) = std::move(_r); }  break;
        case 18: { QString _r = _t->focuser((*reinterpret_cast<std::add_pointer_t<QString>>(_a[1])));
            if (_a[0]) *reinterpret_cast<QString*>(_a[0]) = std::move(_r); }  break;
        case 19: { QString _r = _t->filterWheel((*reinterpret_cast<std::add_pointer_t<QString>>(_a[1])));
            if (_a[0]) *reinterpret_cast<QString*>(_a[0]) = std::move(_r); }  break;
        case 20: { bool _r = _t->setFilter((*reinterpret_cast<std::add_pointer_t<QString>>(_a[1])),(*reinterpret_cast<std::add_pointer_t<QString>>(_a[2])));
            if (_a[0]) *reinterpret_cast<bool*>(_a[0]) = std::move(_r); }  break;
        case 21: { QString _r = _t->filter((*reinterpret_cast<std::add_pointer_t<QString>>(_a[1])));
            if (_a[0]) *reinterpret_cast<QString*>(_a[0]) = std::move(_r); }  break;
        case 22: { double _r = _t->getHFR((*reinterpret_cast<std::add_pointer_t<QString>>(_a[1])));
            if (_a[0]) *reinterpret_cast<double*>(_a[0]) = std::move(_r); }  break;
        case 23: { bool _r = _t->setExposure((*reinterpret_cast<std::add_pointer_t<double>>(_a[1])),(*reinterpret_cast<std::add_pointer_t<QString>>(_a[2])));
            if (_a[0]) *reinterpret_cast<bool*>(_a[0]) = std::move(_r); }  break;
        case 24: { double _r = _t->exposure((*reinterpret_cast<std::add_pointer_t<QString>>(_a[1])));
            if (_a[0]) *reinterpret_cast<double*>(_a[0]) = std::move(_r); }  break;
        case 25: { bool _r = _t->canAutoFocus((*reinterpret_cast<std::add_pointer_t<QString>>(_a[1])));
            if (_a[0]) *reinterpret_cast<bool*>(_a[0]) = std::move(_r); }  break;
        case 26: { bool _r = _t->useFullField((*reinterpret_cast<std::add_pointer_t<QString>>(_a[1])));
            if (_a[0]) *reinterpret_cast<bool*>(_a[0]) = std::move(_r); }  break;
        case 27: { bool _r = _t->setBinning((*reinterpret_cast<std::add_pointer_t<int>>(_a[1])),(*reinterpret_cast<std::add_pointer_t<int>>(_a[2])),(*reinterpret_cast<std::add_pointer_t<QString>>(_a[3])));
            if (_a[0]) *reinterpret_cast<bool*>(_a[0]) = std::move(_r); }  break;
        case 28: { bool _r = _t->setAutoStarEnabled((*reinterpret_cast<std::add_pointer_t<bool>>(_a[1])),(*reinterpret_cast<std::add_pointer_t<QString>>(_a[2])));
            if (_a[0]) *reinterpret_cast<bool*>(_a[0]) = std::move(_r); }  break;
        case 29: { bool _r = _t->setAutoSubFrameEnabled((*reinterpret_cast<std::add_pointer_t<bool>>(_a[1])),(*reinterpret_cast<std::add_pointer_t<QString>>(_a[2])));
            if (_a[0]) *reinterpret_cast<bool*>(_a[0]) = std::move(_r); }  break;
        case 30: { bool _r = _t->setAutoFocusParameters((*reinterpret_cast<std::add_pointer_t<QString>>(_a[1])),(*reinterpret_cast<std::add_pointer_t<int>>(_a[2])),(*reinterpret_cast<std::add_pointer_t<int>>(_a[3])),(*reinterpret_cast<std::add_pointer_t<int>>(_a[4])),(*reinterpret_cast<std::add_pointer_t<double>>(_a[5])));
            if (_a[0]) *reinterpret_cast<bool*>(_a[0]) = std::move(_r); }  break;
        case 31: _t->clearLog(); break;
        default: ;
        }
    }
    if (_c == QMetaObject::IndexOfMethod) {
        if (QtMocHelpers::indexOfMethod<void (FocusModule::*)(const QString & )>(_a, &FocusModule::newLog, 0))
            return;
        if (QtMocHelpers::indexOfMethod<void (FocusModule::*)(FocusState , const QString & )>(_a, &FocusModule::newStatus, 1))
            return;
        if (QtMocHelpers::indexOfMethod<void (FocusModule::*)(double , int , bool , const QString & )>(_a, &FocusModule::newHFR, 2))
            return;
        if (QtMocHelpers::indexOfMethod<void (FocusModule::*)()>(_a, &FocusModule::suspendGuiding, 3))
            return;
        if (QtMocHelpers::indexOfMethod<void (FocusModule::*)()>(_a, &FocusModule::resumeGuiding, 4))
            return;
        if (QtMocHelpers::indexOfMethod<void (FocusModule::*)(bool , const QString & )>(_a, &FocusModule::focusAdaptiveComplete, 5))
            return;
        if (QtMocHelpers::indexOfMethod<void (FocusModule::*)(double , double , const QString & )>(_a, &FocusModule::newFocusTemperatureDelta, 6))
            return;
        if (QtMocHelpers::indexOfMethod<void (FocusModule::*)(bool , const QString & )>(_a, &FocusModule::inSequenceAF, 7))
            return;
    }
}

const QMetaObject *Ekos::FocusModule::metaObject() const
{
    return QObject::d_ptr->metaObject ? QObject::d_ptr->dynamicMetaObject() : &staticMetaObject;
}

void *Ekos::FocusModule::qt_metacast(const char *_clname)
{
    if (!_clname) return nullptr;
    if (!strcmp(_clname, qt_staticMetaObjectStaticContent<qt_meta_tag_ZN4Ekos11FocusModuleE_t>.strings))
        return static_cast<void*>(this);
    if (!strcmp(_clname, "Ui::FocusManager"))
        return static_cast< Ui::FocusManager*>(this);
    return QWidget::qt_metacast(_clname);
}

int Ekos::FocusModule::qt_metacall(QMetaObject::Call _c, int _id, void **_a)
{
    _id = QWidget::qt_metacall(_c, _id, _a);
    if (_id < 0)
        return _id;
    if (_c == QMetaObject::InvokeMetaMethod) {
        if (_id < 32)
            qt_static_metacall(this, _c, _id, _a);
        _id -= 32;
    }
    if (_c == QMetaObject::RegisterMethodArgumentMetaType) {
        if (_id < 32)
            *reinterpret_cast<QMetaType *>(_a[0]) = QMetaType();
        _id -= 32;
    }
    return _id;
}

// SIGNAL 0
void Ekos::FocusModule::newLog(const QString & _t1)
{
    QMetaObject::activate<void>(this, &staticMetaObject, 0, nullptr, _t1);
}

// SIGNAL 1
void Ekos::FocusModule::newStatus(FocusState _t1, const QString & _t2)
{
    QMetaObject::activate<void>(this, &staticMetaObject, 1, nullptr, _t1, _t2);
}

// SIGNAL 2
void Ekos::FocusModule::newHFR(double _t1, int _t2, bool _t3, const QString & _t4)
{
    QMetaObject::activate<void>(this, &staticMetaObject, 2, nullptr, _t1, _t2, _t3, _t4);
}

// SIGNAL 3
void Ekos::FocusModule::suspendGuiding()
{
    QMetaObject::activate(this, &staticMetaObject, 3, nullptr);
}

// SIGNAL 4
void Ekos::FocusModule::resumeGuiding()
{
    QMetaObject::activate(this, &staticMetaObject, 4, nullptr);
}

// SIGNAL 5
void Ekos::FocusModule::focusAdaptiveComplete(bool _t1, const QString & _t2)
{
    QMetaObject::activate<void>(this, &staticMetaObject, 5, nullptr, _t1, _t2);
}

// SIGNAL 6
void Ekos::FocusModule::newFocusTemperatureDelta(double _t1, double _t2, const QString & _t3)
{
    QMetaObject::activate<void>(this, &staticMetaObject, 6, nullptr, _t1, _t2, _t3);
}

// SIGNAL 7
void Ekos::FocusModule::inSequenceAF(bool _t1, const QString & _t2)
{
    QMetaObject::activate<void>(this, &staticMetaObject, 7, nullptr, _t1, _t2);
}
QT_WARNING_POP
