/********************************************************************************
** Form generated from reading UI file 'unitspinboxwidget.ui'
**
** Created by: Qt User Interface Compiler version 6.11.1
**
** WARNING! All changes made in this file will be lost when recompiling UI file!
********************************************************************************/

#ifndef UI_UNITSPINBOXWIDGET_H
#define UI_UNITSPINBOXWIDGET_H

#include <QtCore/QVariant>
#include <QtWidgets/QApplication>
#include <QtWidgets/QComboBox>
#include <QtWidgets/QDoubleSpinBox>
#include <QtWidgets/QHBoxLayout>
#include <QtWidgets/QWidget>
#include <klocalizedstring.h>

QT_BEGIN_NAMESPACE

class Ui_UnitSpinBoxWidget
{
public:
    QHBoxLayout *horizontalLayout;
    QDoubleSpinBox *doubleSpinBox;
    QComboBox *comboBox;

    void setupUi(QWidget *UnitSpinBoxWidget)
    {
        if (UnitSpinBoxWidget->objectName().isEmpty())
            UnitSpinBoxWidget->setObjectName("UnitSpinBoxWidget");
        UnitSpinBoxWidget->resize(179, 32);
        horizontalLayout = new QHBoxLayout(UnitSpinBoxWidget);
        horizontalLayout->setSpacing(0);
        horizontalLayout->setContentsMargins(0, 0, 0, 0);
        horizontalLayout->setObjectName("horizontalLayout");
        horizontalLayout->setContentsMargins(0, 0, 0, 0);
        doubleSpinBox = new QDoubleSpinBox(UnitSpinBoxWidget);
        doubleSpinBox->setObjectName("doubleSpinBox");

        horizontalLayout->addWidget(doubleSpinBox);

        comboBox = new QComboBox(UnitSpinBoxWidget);
        comboBox->setObjectName("comboBox");

        horizontalLayout->addWidget(comboBox);


        retranslateUi(UnitSpinBoxWidget);

        QMetaObject::connectSlotsByName(UnitSpinBoxWidget);
    } // setupUi

    void retranslateUi(QWidget *UnitSpinBoxWidget)
    {
        (void)UnitSpinBoxWidget;
    } // retranslateUi

};

namespace Ui {
    class UnitSpinBoxWidget: public Ui_UnitSpinBoxWidget {};
} // namespace Ui

QT_END_NAMESPACE

#endif // UNITSPINBOXWIDGET_H

