/*
 * This file was generated by qdbusxml2cpp version 0.8
 * Source file was org.kde.kstars.INDI.GenericDevice.xml
 *
 * qdbusxml2cpp is Copyright (C) The Qt Company Ltd. and other contributors.
 *
 * This is an auto-generated file.
 * Do not edit! All changes made to it will be lost.
 */

#include "genericdeviceadaptor.h"
#include <QtCore/QMetaObject>
#include <QtCore/QByteArray>
#include <QtCore/QList>
#include <QtCore/QMap>
#include <QtCore/QString>
#include <QtCore/QStringList>
#include <QtCore/QVariant>

/*
 * Implementation of adaptor class GenericDeviceAdaptor
 */

GenericDeviceAdaptor::GenericDeviceAdaptor(ISD::GenericDevice *parent)
    : QDBusAbstractAdaptor(parent)
{
    // constructor
    setAutoRelaySignals(true);
}

GenericDeviceAdaptor::~GenericDeviceAdaptor()
{
    // destructor
}

bool GenericDeviceAdaptor::connected() const
{
    // get the value of property connected
    return qvariant_cast< bool >(parent()->property("connected"));
}

int GenericDeviceAdaptor::driverInterface() const
{
    // get the value of property driverInterface
    return qvariant_cast< int >(parent()->property("driverInterface"));
}

QString GenericDeviceAdaptor::driverVersion() const
{
    // get the value of property driverVersion
    return qvariant_cast< QString >(parent()->property("driverVersion"));
}

QString GenericDeviceAdaptor::name() const
{
    // get the value of property name
    return qvariant_cast< QString >(parent()->property("name"));
}

void GenericDeviceAdaptor::Connect()
{
    // handle method call org.kde.kstars.INDI.GenericDevice.Connect
    parent()->Connect();
}

void GenericDeviceAdaptor::Disconnect()
{
    // handle method call org.kde.kstars.INDI.GenericDevice.Disconnect
    parent()->Disconnect();
}


#include "moc_genericdeviceadaptor.cpp"
