/****************************************************************************
** Meta object code from reading C++ file 'skymap.h'
**
** Created by: The Qt Meta Object Compiler version 69 (Qt 6.11.1)
**
** WARNING! All changes made in this file will be lost!
*****************************************************************************/

#include "../../../../kstars-3.8.4.1/kstars/skymap.h"
#include <QtCore/qmetatype.h>

#include <QtCore/qtmochelpers.h>

#include <memory>


#include <QtCore/qxptype_traits.h>
#if !defined(Q_MOC_OUTPUT_REVISION)
#error "The header file 'skymap.h' doesn't include <QObject>."
#elif Q_MOC_OUTPUT_REVISION != 69
#error "This file was generated using the moc from 6.11.1. It"
#error "cannot be used with the include files from this version of Qt."
#error "(The moc has changed too much.)"
#endif

#ifndef Q_CONSTINIT
#define Q_CONSTINIT
#endif

QT_WARNING_PUSH
QT_WARNING_DISABLE_DEPRECATED
QT_WARNING_DISABLE_GCC("-Wuseless-cast")
namespace {
struct qt_meta_tag_ZN6SkyMapE_t {};
} // unnamed namespace

template <> constexpr inline auto SkyMap::qt_create_metaobjectdata<qt_meta_tag_ZN6SkyMapE_t>()
{
    namespace QMC = QtMocConstants;
    QtMocHelpers::StringRefStorage qt_stringData {
        "SkyMap",
        "destinationChanged",
        "",
        "zoomChanged",
        "objectChanged",
        "SkyObject*",
        "positionChanged",
        "SkyPoint*",
        "mousePointChanged",
        "positionClicked",
        "objectClicked",
        "removeSkyObject",
        "object",
        "mosaicCenterChanged",
        "dms",
        "dRA",
        "dDE",
        "updateQueued",
        "forceUpdate",
        "now",
        "forceUpdateNow",
        "slotUpdateSky",
        "slotToggleGeoBox",
        "slotToggleFocusBox",
        "slotToggleTimeBox",
        "slotToggleInfoboxes",
        "slotSetSkyRotation",
        "angle",
        "slewFocus",
        "slotCenter",
        "slotDSS",
        "slotSDSS",
        "slotCopyCoordinates",
        "slotCopyTLE",
        "slotInfo",
        "slotImage",
        "slotDetail",
        "slotAddObjectLabel",
        "slotRemoveObjectLabel",
        "slotRemoveCustomObject",
        "slotAddPlanetTrail",
        "slotRemovePlanetTrail",
        "slotDisplayFadingText",
        "text",
        "slotClockSlewing",
        "slotBeginAngularDistance",
        "slotBeginStarHop",
        "slotEndRulerMode",
        "slotCancelRulerMode",
        "slotAddFlag",
        "slotAddFlagRaw",
        "slotEditFlag",
        "flagIdx",
        "slotDeleteFlag",
        "slotStartXplanetViewer",
        "slotZoomIn",
        "slotZoomOut",
        "slotZoomDefault",
        "slotObjectSelected",
        "slotCancelLegendPreviewMode",
        "slotFinishFovCaptureMode",
        "slotCaptureFov",
        "slotTransientLabel",
        "setMouseMoveCursor",
        "setMouseDragCursor"
    };

    QtMocHelpers::UintData qt_methods {
        // Signal 'destinationChanged'
        QtMocHelpers::SignalData<void()>(1, 2, QMC::AccessPublic, QMetaType::Void),
        // Signal 'zoomChanged'
        QtMocHelpers::SignalData<void()>(3, 2, QMC::AccessPublic, QMetaType::Void),
        // Signal 'objectChanged'
        QtMocHelpers::SignalData<void(SkyObject *)>(4, 2, QMC::AccessPublic, QMetaType::Void, {{
            { 0x80000000 | 5, 2 },
        }}),
        // Signal 'positionChanged'
        QtMocHelpers::SignalData<void(SkyPoint *)>(6, 2, QMC::AccessPublic, QMetaType::Void, {{
            { 0x80000000 | 7, 2 },
        }}),
        // Signal 'mousePointChanged'
        QtMocHelpers::SignalData<void(SkyPoint *)>(8, 2, QMC::AccessPublic, QMetaType::Void, {{
            { 0x80000000 | 7, 2 },
        }}),
        // Signal 'positionClicked'
        QtMocHelpers::SignalData<void(SkyPoint *)>(9, 2, QMC::AccessPublic, QMetaType::Void, {{
            { 0x80000000 | 7, 2 },
        }}),
        // Signal 'objectClicked'
        QtMocHelpers::SignalData<void(SkyObject *)>(10, 2, QMC::AccessPublic, QMetaType::Void, {{
            { 0x80000000 | 5, 2 },
        }}),
        // Signal 'removeSkyObject'
        QtMocHelpers::SignalData<void(SkyObject *)>(11, 2, QMC::AccessPublic, QMetaType::Void, {{
            { 0x80000000 | 5, 12 },
        }}),
        // Signal 'mosaicCenterChanged'
        QtMocHelpers::SignalData<void(dms, dms)>(13, 2, QMC::AccessPublic, QMetaType::Void, {{
            { 0x80000000 | 14, 15 }, { 0x80000000 | 14, 16 },
        }}),
        // Signal 'updateQueued'
        QtMocHelpers::SignalData<void()>(17, 2, QMC::AccessPublic, QMetaType::Void),
        // Slot 'forceUpdate'
        QtMocHelpers::SlotData<void(bool)>(18, 2, QMC::AccessPublic, QMetaType::Void, {{
            { QMetaType::Bool, 19 },
        }}),
        // Slot 'forceUpdate'
        QtMocHelpers::SlotData<void()>(18, 2, QMC::AccessPublic | QMC::MethodCloned, QMetaType::Void),
        // Slot 'forceUpdateNow'
        QtMocHelpers::SlotData<void()>(20, 2, QMC::AccessPublic, QMetaType::Void),
        // Slot 'slotUpdateSky'
        QtMocHelpers::SlotData<void(bool)>(21, 2, QMC::AccessPublic, QMetaType::Void, {{
            { QMetaType::Bool, 19 },
        }}),
        // Slot 'slotToggleGeoBox'
        QtMocHelpers::SlotData<void(bool)>(22, 2, QMC::AccessPublic, QMetaType::Void, {{
            { QMetaType::Bool, 2 },
        }}),
        // Slot 'slotToggleFocusBox'
        QtMocHelpers::SlotData<void(bool)>(23, 2, QMC::AccessPublic, QMetaType::Void, {{
            { QMetaType::Bool, 2 },
        }}),
        // Slot 'slotToggleTimeBox'
        QtMocHelpers::SlotData<void(bool)>(24, 2, QMC::AccessPublic, QMetaType::Void, {{
            { QMetaType::Bool, 2 },
        }}),
        // Slot 'slotToggleInfoboxes'
        QtMocHelpers::SlotData<void(bool)>(25, 2, QMC::AccessPublic, QMetaType::Void, {{
            { QMetaType::Bool, 2 },
        }}),
        // Slot 'slotSetSkyRotation'
        QtMocHelpers::SlotData<void(double)>(26, 2, QMC::AccessPublic, QMetaType::Void, {{
            { QMetaType::Double, 27 },
        }}),
        // Slot 'slewFocus'
        QtMocHelpers::SlotData<void()>(28, 2, QMC::AccessPublic, QMetaType::Void),
        // Slot 'slotCenter'
        QtMocHelpers::SlotData<void()>(29, 2, QMC::AccessPublic, QMetaType::Void),
        // Slot 'slotDSS'
        QtMocHelpers::SlotData<void()>(30, 2, QMC::AccessPublic, QMetaType::Void),
        // Slot 'slotSDSS'
        QtMocHelpers::SlotData<void()>(31, 2, QMC::AccessPublic, QMetaType::Void),
        // Slot 'slotCopyCoordinates'
        QtMocHelpers::SlotData<void()>(32, 2, QMC::AccessPublic, QMetaType::Void),
        // Slot 'slotCopyTLE'
        QtMocHelpers::SlotData<void()>(33, 2, QMC::AccessPublic, QMetaType::Void),
        // Slot 'slotInfo'
        QtMocHelpers::SlotData<void()>(34, 2, QMC::AccessPublic, QMetaType::Void),
        // Slot 'slotImage'
        QtMocHelpers::SlotData<void()>(35, 2, QMC::AccessPublic, QMetaType::Void),
        // Slot 'slotDetail'
        QtMocHelpers::SlotData<void()>(36, 2, QMC::AccessPublic, QMetaType::Void),
        // Slot 'slotAddObjectLabel'
        QtMocHelpers::SlotData<void()>(37, 2, QMC::AccessPublic, QMetaType::Void),
        // Slot 'slotRemoveObjectLabel'
        QtMocHelpers::SlotData<void()>(38, 2, QMC::AccessPublic, QMetaType::Void),
        // Slot 'slotRemoveCustomObject'
        QtMocHelpers::SlotData<void()>(39, 2, QMC::AccessPublic, QMetaType::Void),
        // Slot 'slotAddPlanetTrail'
        QtMocHelpers::SlotData<void()>(40, 2, QMC::AccessPublic, QMetaType::Void),
        // Slot 'slotRemovePlanetTrail'
        QtMocHelpers::SlotData<void()>(41, 2, QMC::AccessPublic, QMetaType::Void),
        // Slot 'slotDisplayFadingText'
        QtMocHelpers::SlotData<void(const QString &)>(42, 2, QMC::AccessPublic, QMetaType::Void, {{
            { QMetaType::QString, 43 },
        }}),
        // Slot 'slotClockSlewing'
        QtMocHelpers::SlotData<void()>(44, 2, QMC::AccessPublic, QMetaType::Void),
        // Slot 'slotBeginAngularDistance'
        QtMocHelpers::SlotData<void()>(45, 2, QMC::AccessPublic, QMetaType::Void),
        // Slot 'slotBeginStarHop'
        QtMocHelpers::SlotData<void()>(46, 2, QMC::AccessPublic, QMetaType::Void),
        // Slot 'slotEndRulerMode'
        QtMocHelpers::SlotData<void()>(47, 2, QMC::AccessPublic, QMetaType::Void),
        // Slot 'slotCancelRulerMode'
        QtMocHelpers::SlotData<void()>(48, 2, QMC::AccessPublic, QMetaType::Void),
        // Slot 'slotAddFlag'
        QtMocHelpers::SlotData<void()>(49, 2, QMC::AccessPublic, QMetaType::Void),
        // Slot 'slotAddFlagRaw'
        QtMocHelpers::SlotData<void()>(50, 2, QMC::AccessPublic, QMetaType::Void),
        // Slot 'slotEditFlag'
        QtMocHelpers::SlotData<void(int)>(51, 2, QMC::AccessPublic, QMetaType::Void, {{
            { QMetaType::Int, 52 },
        }}),
        // Slot 'slotDeleteFlag'
        QtMocHelpers::SlotData<void(int)>(53, 2, QMC::AccessPublic, QMetaType::Void, {{
            { QMetaType::Int, 52 },
        }}),
        // Slot 'slotStartXplanetViewer'
        QtMocHelpers::SlotData<void()>(54, 2, QMC::AccessPublic, QMetaType::Void),
        // Slot 'slotZoomIn'
        QtMocHelpers::SlotData<void()>(55, 2, QMC::AccessPublic, QMetaType::Void),
        // Slot 'slotZoomOut'
        QtMocHelpers::SlotData<void()>(56, 2, QMC::AccessPublic, QMetaType::Void),
        // Slot 'slotZoomDefault'
        QtMocHelpers::SlotData<void()>(57, 2, QMC::AccessPublic, QMetaType::Void),
        // Slot 'slotObjectSelected'
        QtMocHelpers::SlotData<void()>(58, 2, QMC::AccessPublic, QMetaType::Void),
        // Slot 'slotCancelLegendPreviewMode'
        QtMocHelpers::SlotData<void()>(59, 2, QMC::AccessPublic, QMetaType::Void),
        // Slot 'slotFinishFovCaptureMode'
        QtMocHelpers::SlotData<void()>(60, 2, QMC::AccessPublic, QMetaType::Void),
        // Slot 'slotCaptureFov'
        QtMocHelpers::SlotData<void()>(61, 2, QMC::AccessPublic, QMetaType::Void),
        // Slot 'slotTransientLabel'
        QtMocHelpers::SlotData<void()>(62, 2, QMC::AccessPrivate, QMetaType::Void),
        // Slot 'setMouseMoveCursor'
        QtMocHelpers::SlotData<void()>(63, 2, QMC::AccessPrivate, QMetaType::Void),
        // Slot 'setMouseDragCursor'
        QtMocHelpers::SlotData<void()>(64, 2, QMC::AccessPrivate, QMetaType::Void),
    };
    QtMocHelpers::UintData qt_properties {
    };
    QtMocHelpers::UintData qt_enums {
    };
    return QtMocHelpers::metaObjectData<SkyMap, qt_meta_tag_ZN6SkyMapE_t>(QMC::MetaObjectFlag{}, qt_stringData,
            qt_methods, qt_properties, qt_enums);
}
Q_CONSTINIT const QMetaObject SkyMap::staticMetaObject = { {
    QMetaObject::SuperData::link<QGraphicsView::staticMetaObject>(),
    qt_staticMetaObjectStaticContent<qt_meta_tag_ZN6SkyMapE_t>.stringdata,
    qt_staticMetaObjectStaticContent<qt_meta_tag_ZN6SkyMapE_t>.data,
    qt_static_metacall,
    nullptr,
    qt_staticMetaObjectRelocatingContent<qt_meta_tag_ZN6SkyMapE_t>.metaTypes,
    nullptr
} };

void SkyMap::qt_static_metacall(QObject *_o, QMetaObject::Call _c, int _id, void **_a)
{
    auto *_t = static_cast<SkyMap *>(_o);
    if (_c == QMetaObject::InvokeMetaMethod) {
        switch (_id) {
        case 0: _t->destinationChanged(); break;
        case 1: _t->zoomChanged(); break;
        case 2: _t->objectChanged((*reinterpret_cast<std::add_pointer_t<SkyObject*>>(_a[1]))); break;
        case 3: _t->positionChanged((*reinterpret_cast<std::add_pointer_t<SkyPoint*>>(_a[1]))); break;
        case 4: _t->mousePointChanged((*reinterpret_cast<std::add_pointer_t<SkyPoint*>>(_a[1]))); break;
        case 5: _t->positionClicked((*reinterpret_cast<std::add_pointer_t<SkyPoint*>>(_a[1]))); break;
        case 6: _t->objectClicked((*reinterpret_cast<std::add_pointer_t<SkyObject*>>(_a[1]))); break;
        case 7: _t->removeSkyObject((*reinterpret_cast<std::add_pointer_t<SkyObject*>>(_a[1]))); break;
        case 8: _t->mosaicCenterChanged((*reinterpret_cast<std::add_pointer_t<dms>>(_a[1])),(*reinterpret_cast<std::add_pointer_t<dms>>(_a[2]))); break;
        case 9: _t->updateQueued(); break;
        case 10: _t->forceUpdate((*reinterpret_cast<std::add_pointer_t<bool>>(_a[1]))); break;
        case 11: _t->forceUpdate(); break;
        case 12: _t->forceUpdateNow(); break;
        case 13: _t->slotUpdateSky((*reinterpret_cast<std::add_pointer_t<bool>>(_a[1]))); break;
        case 14: _t->slotToggleGeoBox((*reinterpret_cast<std::add_pointer_t<bool>>(_a[1]))); break;
        case 15: _t->slotToggleFocusBox((*reinterpret_cast<std::add_pointer_t<bool>>(_a[1]))); break;
        case 16: _t->slotToggleTimeBox((*reinterpret_cast<std::add_pointer_t<bool>>(_a[1]))); break;
        case 17: _t->slotToggleInfoboxes((*reinterpret_cast<std::add_pointer_t<bool>>(_a[1]))); break;
        case 18: _t->slotSetSkyRotation((*reinterpret_cast<std::add_pointer_t<double>>(_a[1]))); break;
        case 19: _t->slewFocus(); break;
        case 20: _t->slotCenter(); break;
        case 21: _t->slotDSS(); break;
        case 22: _t->slotSDSS(); break;
        case 23: _t->slotCopyCoordinates(); break;
        case 24: _t->slotCopyTLE(); break;
        case 25: _t->slotInfo(); break;
        case 26: _t->slotImage(); break;
        case 27: _t->slotDetail(); break;
        case 28: _t->slotAddObjectLabel(); break;
        case 29: _t->slotRemoveObjectLabel(); break;
        case 30: _t->slotRemoveCustomObject(); break;
        case 31: _t->slotAddPlanetTrail(); break;
        case 32: _t->slotRemovePlanetTrail(); break;
        case 33: _t->slotDisplayFadingText((*reinterpret_cast<std::add_pointer_t<QString>>(_a[1]))); break;
        case 34: _t->slotClockSlewing(); break;
        case 35: _t->slotBeginAngularDistance(); break;
        case 36: _t->slotBeginStarHop(); break;
        case 37: _t->slotEndRulerMode(); break;
        case 38: _t->slotCancelRulerMode(); break;
        case 39: _t->slotAddFlag(); break;
        case 40: _t->slotAddFlagRaw(); break;
        case 41: _t->slotEditFlag((*reinterpret_cast<std::add_pointer_t<int>>(_a[1]))); break;
        case 42: _t->slotDeleteFlag((*reinterpret_cast<std::add_pointer_t<int>>(_a[1]))); break;
        case 43: _t->slotStartXplanetViewer(); break;
        case 44: _t->slotZoomIn(); break;
        case 45: _t->slotZoomOut(); break;
        case 46: _t->slotZoomDefault(); break;
        case 47: _t->slotObjectSelected(); break;
        case 48: _t->slotCancelLegendPreviewMode(); break;
        case 49: _t->slotFinishFovCaptureMode(); break;
        case 50: _t->slotCaptureFov(); break;
        case 51: _t->slotTransientLabel(); break;
        case 52: _t->setMouseMoveCursor(); break;
        case 53: _t->setMouseDragCursor(); break;
        default: ;
        }
    }
    if (_c == QMetaObject::IndexOfMethod) {
        if (QtMocHelpers::indexOfMethod<void (SkyMap::*)()>(_a, &SkyMap::destinationChanged, 0))
            return;
        if (QtMocHelpers::indexOfMethod<void (SkyMap::*)()>(_a, &SkyMap::zoomChanged, 1))
            return;
        if (QtMocHelpers::indexOfMethod<void (SkyMap::*)(SkyObject * )>(_a, &SkyMap::objectChanged, 2))
            return;
        if (QtMocHelpers::indexOfMethod<void (SkyMap::*)(SkyPoint * )>(_a, &SkyMap::positionChanged, 3))
            return;
        if (QtMocHelpers::indexOfMethod<void (SkyMap::*)(SkyPoint * )>(_a, &SkyMap::mousePointChanged, 4))
            return;
        if (QtMocHelpers::indexOfMethod<void (SkyMap::*)(SkyPoint * )>(_a, &SkyMap::positionClicked, 5))
            return;
        if (QtMocHelpers::indexOfMethod<void (SkyMap::*)(SkyObject * )>(_a, &SkyMap::objectClicked, 6))
            return;
        if (QtMocHelpers::indexOfMethod<void (SkyMap::*)(SkyObject * )>(_a, &SkyMap::removeSkyObject, 7))
            return;
        if (QtMocHelpers::indexOfMethod<void (SkyMap::*)(dms , dms )>(_a, &SkyMap::mosaicCenterChanged, 8))
            return;
        if (QtMocHelpers::indexOfMethod<void (SkyMap::*)()>(_a, &SkyMap::updateQueued, 9))
            return;
    }
}

const QMetaObject *SkyMap::metaObject() const
{
    return QObject::d_ptr->metaObject ? QObject::d_ptr->dynamicMetaObject() : &staticMetaObject;
}

void *SkyMap::qt_metacast(const char *_clname)
{
    if (!_clname) return nullptr;
    if (!strcmp(_clname, qt_staticMetaObjectStaticContent<qt_meta_tag_ZN6SkyMapE_t>.strings))
        return static_cast<void*>(this);
    return QGraphicsView::qt_metacast(_clname);
}

int SkyMap::qt_metacall(QMetaObject::Call _c, int _id, void **_a)
{
    _id = QGraphicsView::qt_metacall(_c, _id, _a);
    if (_id < 0)
        return _id;
    if (_c == QMetaObject::InvokeMetaMethod) {
        if (_id < 54)
            qt_static_metacall(this, _c, _id, _a);
        _id -= 54;
    }
    if (_c == QMetaObject::RegisterMethodArgumentMetaType) {
        if (_id < 54)
            *reinterpret_cast<QMetaType *>(_a[0]) = QMetaType();
        _id -= 54;
    }
    return _id;
}

// SIGNAL 0
void SkyMap::destinationChanged()
{
    QMetaObject::activate(this, &staticMetaObject, 0, nullptr);
}

// SIGNAL 1
void SkyMap::zoomChanged()
{
    QMetaObject::activate(this, &staticMetaObject, 1, nullptr);
}

// SIGNAL 2
void SkyMap::objectChanged(SkyObject * _t1)
{
    QMetaObject::activate<void>(this, &staticMetaObject, 2, nullptr, _t1);
}

// SIGNAL 3
void SkyMap::positionChanged(SkyPoint * _t1)
{
    QMetaObject::activate<void>(this, &staticMetaObject, 3, nullptr, _t1);
}

// SIGNAL 4
void SkyMap::mousePointChanged(SkyPoint * _t1)
{
    QMetaObject::activate<void>(this, &staticMetaObject, 4, nullptr, _t1);
}

// SIGNAL 5
void SkyMap::positionClicked(SkyPoint * _t1)
{
    QMetaObject::activate<void>(this, &staticMetaObject, 5, nullptr, _t1);
}

// SIGNAL 6
void SkyMap::objectClicked(SkyObject * _t1)
{
    QMetaObject::activate<void>(this, &staticMetaObject, 6, nullptr, _t1);
}

// SIGNAL 7
void SkyMap::removeSkyObject(SkyObject * _t1)
{
    QMetaObject::activate<void>(this, &staticMetaObject, 7, nullptr, _t1);
}

// SIGNAL 8
void SkyMap::mosaicCenterChanged(dms _t1, dms _t2)
{
    QMetaObject::activate<void>(this, &staticMetaObject, 8, nullptr, _t1, _t2);
}

// SIGNAL 9
void SkyMap::updateQueued()
{
    QMetaObject::activate(this, &staticMetaObject, 9, nullptr);
}
QT_WARNING_POP
