/********************************************************************************
** Form generated from reading UI file 'fitshistogramui.ui'
**
** Created by: Qt User Interface Compiler version 6.11.1
**
** WARNING! All changes made in this file will be lost when recompiling UI file!
********************************************************************************/

#ifndef UI_FITSHISTOGRAMUI_H
#define UI_FITSHISTOGRAMUI_H

#include <QtCore/QVariant>
#include <QtWidgets/QApplication>
#include <QtWidgets/QButtonGroup>
#include <QtWidgets/QDialog>
#include <QtWidgets/QDoubleSpinBox>
#include <QtWidgets/QGridLayout>
#include <QtWidgets/QHBoxLayout>
#include <QtWidgets/QLabel>
#include <QtWidgets/QLineEdit>
#include <QtWidgets/QPushButton>
#include <QtWidgets/QVBoxLayout>
#include <klocalizedstring.h>
#include "auxiliary/ctkrangeslider.h"
#include "fitsviewer/fitshistogramview.h"

QT_BEGIN_NAMESPACE

class Ui_FITSHistogramUI
{
public:
    QVBoxLayout *verticalLayout;
    FITSHistogramView *histogramPlot;
    QGridLayout *gridLayout;
    ctkRangeSlider *greenSlider;
    QDoubleSpinBox *minGEdit;
    QDoubleSpinBox *maxBEdit;
    QLabel *GLabel;
    QDoubleSpinBox *minREdit;
    QDoubleSpinBox *minBEdit;
    QLabel *RLabel;
    ctkRangeSlider *redSlider;
    QLabel *BLabel;
    ctkRangeSlider *blueSlider;
    QDoubleSpinBox *maxREdit;
    QDoubleSpinBox *maxGEdit;
    QGridLayout *gridLayout_2;
    QLabel *minLabel_2;
    QLabel *maxLabel_2;
    QLineEdit *meanEdit;
    QLineEdit *medianEdit;
    QHBoxLayout *horizontalLayout;
    QPushButton *applyB;
    QButtonGroup *FITSScaleButtonGroup;

    void setupUi(QDialog *FITSHistogramUI)
    {
        if (FITSHistogramUI->objectName().isEmpty())
            FITSHistogramUI->setObjectName("FITSHistogramUI");
        FITSHistogramUI->resize(220, 437);
        QSizePolicy sizePolicy(QSizePolicy::Policy::Preferred, QSizePolicy::Policy::Preferred);
        sizePolicy.setHorizontalStretch(0);
        sizePolicy.setVerticalStretch(0);
        sizePolicy.setHeightForWidth(FITSHistogramUI->sizePolicy().hasHeightForWidth());
        FITSHistogramUI->setSizePolicy(sizePolicy);
        FITSHistogramUI->setMinimumSize(QSize(0, 0));
        FITSHistogramUI->setMaximumSize(QSize(16777215, 16777215));
        FITSHistogramUI->setSizeGripEnabled(true);
        verticalLayout = new QVBoxLayout(FITSHistogramUI);
        verticalLayout->setSpacing(3);
        verticalLayout->setObjectName("verticalLayout");
        verticalLayout->setContentsMargins(3, 3, 3, 3);
        histogramPlot = new FITSHistogramView(FITSHistogramUI);
        histogramPlot->setObjectName("histogramPlot");
        QSizePolicy sizePolicy1(QSizePolicy::Policy::Expanding, QSizePolicy::Policy::MinimumExpanding);
        sizePolicy1.setHorizontalStretch(0);
        sizePolicy1.setVerticalStretch(0);
        sizePolicy1.setHeightForWidth(histogramPlot->sizePolicy().hasHeightForWidth());
        histogramPlot->setSizePolicy(sizePolicy1);
        histogramPlot->setMinimumSize(QSize(0, 200));
        histogramPlot->setMaximumSize(QSize(16777215, 16777215));

        verticalLayout->addWidget(histogramPlot);

        gridLayout = new QGridLayout();
        gridLayout->setSpacing(3);
        gridLayout->setObjectName("gridLayout");
        greenSlider = new ctkRangeSlider(FITSHistogramUI);
        greenSlider->setObjectName("greenSlider");
        greenSlider->setOrientation(Qt::Horizontal);

        gridLayout->addWidget(greenSlider, 1, 2, 1, 1);

        minGEdit = new QDoubleSpinBox(FITSHistogramUI);
        minGEdit->setObjectName("minGEdit");

        gridLayout->addWidget(minGEdit, 1, 1, 1, 1);

        maxBEdit = new QDoubleSpinBox(FITSHistogramUI);
        maxBEdit->setObjectName("maxBEdit");

        gridLayout->addWidget(maxBEdit, 2, 3, 1, 1);

        GLabel = new QLabel(FITSHistogramUI);
        GLabel->setObjectName("GLabel");

        gridLayout->addWidget(GLabel, 1, 0, 1, 1);

        minREdit = new QDoubleSpinBox(FITSHistogramUI);
        minREdit->setObjectName("minREdit");

        gridLayout->addWidget(minREdit, 0, 1, 1, 1);

        minBEdit = new QDoubleSpinBox(FITSHistogramUI);
        minBEdit->setObjectName("minBEdit");

        gridLayout->addWidget(minBEdit, 2, 1, 1, 1);

        RLabel = new QLabel(FITSHistogramUI);
        RLabel->setObjectName("RLabel");

        gridLayout->addWidget(RLabel, 0, 0, 1, 1);

        redSlider = new ctkRangeSlider(FITSHistogramUI);
        redSlider->setObjectName("redSlider");
        redSlider->setOrientation(Qt::Horizontal);

        gridLayout->addWidget(redSlider, 0, 2, 1, 1);

        BLabel = new QLabel(FITSHistogramUI);
        BLabel->setObjectName("BLabel");

        gridLayout->addWidget(BLabel, 2, 0, 1, 1);

        blueSlider = new ctkRangeSlider(FITSHistogramUI);
        blueSlider->setObjectName("blueSlider");
        blueSlider->setOrientation(Qt::Horizontal);

        gridLayout->addWidget(blueSlider, 2, 2, 1, 1);

        maxREdit = new QDoubleSpinBox(FITSHistogramUI);
        maxREdit->setObjectName("maxREdit");

        gridLayout->addWidget(maxREdit, 0, 3, 1, 1);

        maxGEdit = new QDoubleSpinBox(FITSHistogramUI);
        maxGEdit->setObjectName("maxGEdit");

        gridLayout->addWidget(maxGEdit, 1, 3, 1, 1);


        verticalLayout->addLayout(gridLayout);

        gridLayout_2 = new QGridLayout();
        gridLayout_2->setSpacing(3);
        gridLayout_2->setObjectName("gridLayout_2");
        minLabel_2 = new QLabel(FITSHistogramUI);
        minLabel_2->setObjectName("minLabel_2");

        gridLayout_2->addWidget(minLabel_2, 0, 0, 1, 1);

        maxLabel_2 = new QLabel(FITSHistogramUI);
        maxLabel_2->setObjectName("maxLabel_2");

        gridLayout_2->addWidget(maxLabel_2, 0, 1, 1, 1);

        meanEdit = new QLineEdit(FITSHistogramUI);
        meanEdit->setObjectName("meanEdit");
        QSizePolicy sizePolicy2(QSizePolicy::Policy::Preferred, QSizePolicy::Policy::Fixed);
        sizePolicy2.setHorizontalStretch(0);
        sizePolicy2.setVerticalStretch(0);
        sizePolicy2.setHeightForWidth(meanEdit->sizePolicy().hasHeightForWidth());
        meanEdit->setSizePolicy(sizePolicy2);
        meanEdit->setReadOnly(true);

        gridLayout_2->addWidget(meanEdit, 1, 0, 1, 1);

        medianEdit = new QLineEdit(FITSHistogramUI);
        medianEdit->setObjectName("medianEdit");
        sizePolicy2.setHeightForWidth(medianEdit->sizePolicy().hasHeightForWidth());
        medianEdit->setSizePolicy(sizePolicy2);
        medianEdit->setReadOnly(true);

        gridLayout_2->addWidget(medianEdit, 1, 1, 1, 1);


        verticalLayout->addLayout(gridLayout_2);

        horizontalLayout = new QHBoxLayout();
        horizontalLayout->setSpacing(3);
        horizontalLayout->setObjectName("horizontalLayout");
        applyB = new QPushButton(FITSHistogramUI);
        applyB->setObjectName("applyB");

        horizontalLayout->addWidget(applyB);


        verticalLayout->addLayout(horizontalLayout);


        retranslateUi(FITSHistogramUI);

        QMetaObject::connectSlotsByName(FITSHistogramUI);
    } // setupUi

    void retranslateUi(QDialog *FITSHistogramUI)
    {
        FITSHistogramUI->setWindowTitle(tr2i18n("Histogram", nullptr));
        GLabel->setText(tr2i18n("G", nullptr));
        RLabel->setText(tr2i18n("R", nullptr));
        BLabel->setText(tr2i18n("B", nullptr));
        minLabel_2->setText(tr2i18n("Mean:", nullptr));
        maxLabel_2->setText(tr2i18n("Median:", nullptr));
        applyB->setText(tr2i18n("Apply", nullptr));
    } // retranslateUi

};

namespace Ui {
    class FITSHistogramUI: public Ui_FITSHistogramUI {};
} // namespace Ui

QT_END_NAMESPACE

#endif // FITSHISTOGRAMUI_H

