/********************************************************************************
** Form generated from reading UI file 'opssolarsystem.ui'
**
** Created by: Qt User Interface Compiler version 6.11.1
**
** WARNING! All changes made in this file will be lost when recompiling UI file!
********************************************************************************/

#ifndef UI_OPSSOLARSYSTEM_H
#define UI_OPSSOLARSYSTEM_H

#include <QtCore/QVariant>
#include <QtWidgets/QApplication>
#include <QtWidgets/QButtonGroup>
#include <QtWidgets/QCheckBox>
#include <QtWidgets/QDoubleSpinBox>
#include <QtWidgets/QGridLayout>
#include <QtWidgets/QGroupBox>
#include <QtWidgets/QHBoxLayout>
#include <QtWidgets/QLabel>
#include <QtWidgets/QPushButton>
#include <QtWidgets/QSlider>
#include <QtWidgets/QSpacerItem>
#include <QtWidgets/QVBoxLayout>
#include <QtWidgets/QWidget>
#include <klocalizedstring.h>
#include "widgets/magnitudespinbox.h"

QT_BEGIN_NAMESPACE

class Ui_OpsSolarSystem
{
public:
    QVBoxLayout *vboxLayout;
    QCheckBox *kcfg_ShowSolarSystem;
    QGroupBox *MajorBodiesBox;
    QVBoxLayout *vboxLayout1;
    QGridLayout *gridLayout;
    QCheckBox *kcfg_ShowSaturn;
    QCheckBox *kcfg_ShowPlanetImages;
    QCheckBox *kcfg_ShowMars;
    QCheckBox *kcfg_ShowPlanetNames;
    QPushButton *showAllPlanets;
    QPushButton *showNonePlanets;
    QCheckBox *kcfg_ShowVenus;
    QHBoxLayout *hboxLayout;
    QCheckBox *kcfg_ShowSun;
    QLabel *sunLabel;
    QDoubleSpinBox *kcfg_SunScale;
    QCheckBox *kcfg_ShowJupiter;
    QHBoxLayout *hboxLayout1;
    QCheckBox *kcfg_ShowMoon;
    QLabel *moonLabel;
    QDoubleSpinBox *kcfg_MoonScale;
    QCheckBox *kcfg_ShowMercury;
    QCheckBox *kcfg_ShowNeptune;
    QSpacerItem *spacerItem;
    QCheckBox *kcfg_ShowUranus;
    QSpacerItem *spacerItem1;
    QGroupBox *MinorBodiesBox;
    QVBoxLayout *vboxLayout2;
    QGridLayout *gridLayout1;
    QLabel *label_3;
    QCheckBox *kcfg_ShowAsteroids;
    QCheckBox *kcfg_ShowComets;
    QSpacerItem *spacerItem2;
    QLabel *MagLimitAsteroidDownloadWarning;
    QLabel *textLabel3;
    QCheckBox *kcfg_ShowCometNames;
    QHBoxLayout *hboxLayout2;
    MagnitudeSpinBox *kcfg_MagLimitAsteroid;
    QLabel *textLabel6;
    QHBoxLayout *horizontalLayout;
    QDoubleSpinBox *kcfg_MagLimitAsteroidDownload;
    QLabel *label_2;
    QHBoxLayout *hboxLayout3;
    QDoubleSpinBox *kcfg_MaxRadCometName;
    QLabel *textLabel4;
    QSlider *kcfg_AsteroidLabelDensity;
    QHBoxLayout *hboxLayout4;
    QCheckBox *kcfg_ShowAsteroidNames;
    QSpacerItem *spacerItem3;
    QLabel *LabelDensity;
    QCheckBox *kcfg_ShowCometComas;
    QCheckBox *kcfg_OrbitalElementsAutoUpdate;
    QSpacerItem *spacerItem4;
    QGroupBox *TrailsBox;
    QVBoxLayout *vboxLayout3;
    QCheckBox *kcfg_UseAutoTrail;
    QHBoxLayout *hboxLayout5;
    QCheckBox *kcfg_FadePlanetTrails;
    QSpacerItem *spacerItem5;
    QPushButton *ClearAllTrails;
    QSpacerItem *spacerItem6;
    QCheckBox *checkBox;
    QSpacerItem *spacerItem7;
    QButtonGroup *solarButtonGroup;

    void setupUi(QWidget *OpsSolarSystem)
    {
        if (OpsSolarSystem->objectName().isEmpty())
            OpsSolarSystem->setObjectName("OpsSolarSystem");
        OpsSolarSystem->resize(465, 644);
        vboxLayout = new QVBoxLayout(OpsSolarSystem);
        vboxLayout->setSpacing(3);
        vboxLayout->setObjectName("vboxLayout");
        vboxLayout->setContentsMargins(3, 3, 3, 3);
        kcfg_ShowSolarSystem = new QCheckBox(OpsSolarSystem);
        solarButtonGroup = new QButtonGroup(OpsSolarSystem);
        solarButtonGroup->setObjectName("solarButtonGroup");
        solarButtonGroup->setExclusive(false);
        solarButtonGroup->addButton(kcfg_ShowSolarSystem);
        kcfg_ShowSolarSystem->setObjectName("kcfg_ShowSolarSystem");

        vboxLayout->addWidget(kcfg_ShowSolarSystem);

        MajorBodiesBox = new QGroupBox(OpsSolarSystem);
        MajorBodiesBox->setObjectName("MajorBodiesBox");
        vboxLayout1 = new QVBoxLayout(MajorBodiesBox);
        vboxLayout1->setObjectName("vboxLayout1");
        gridLayout = new QGridLayout();
        gridLayout->setObjectName("gridLayout");
        kcfg_ShowSaturn = new QCheckBox(MajorBodiesBox);
        solarButtonGroup->addButton(kcfg_ShowSaturn);
        kcfg_ShowSaturn->setObjectName("kcfg_ShowSaturn");

        gridLayout->addWidget(kcfg_ShowSaturn, 1, 1, 1, 1);

        kcfg_ShowPlanetImages = new QCheckBox(MajorBodiesBox);
        kcfg_ShowPlanetImages->setObjectName("kcfg_ShowPlanetImages");

        gridLayout->addWidget(kcfg_ShowPlanetImages, 3, 2, 1, 1);

        kcfg_ShowMars = new QCheckBox(MajorBodiesBox);
        solarButtonGroup->addButton(kcfg_ShowMars);
        kcfg_ShowMars->setObjectName("kcfg_ShowMars");

        gridLayout->addWidget(kcfg_ShowMars, 4, 0, 1, 1);

        kcfg_ShowPlanetNames = new QCheckBox(MajorBodiesBox);
        kcfg_ShowPlanetNames->setObjectName("kcfg_ShowPlanetNames");

        gridLayout->addWidget(kcfg_ShowPlanetNames, 2, 2, 1, 1);

        showAllPlanets = new QPushButton(MajorBodiesBox);
        showAllPlanets->setObjectName("showAllPlanets");

        gridLayout->addWidget(showAllPlanets, 0, 2, 1, 1);

        showNonePlanets = new QPushButton(MajorBodiesBox);
        showNonePlanets->setObjectName("showNonePlanets");

        gridLayout->addWidget(showNonePlanets, 1, 2, 1, 1);

        kcfg_ShowVenus = new QCheckBox(MajorBodiesBox);
        solarButtonGroup->addButton(kcfg_ShowVenus);
        kcfg_ShowVenus->setObjectName("kcfg_ShowVenus");

        gridLayout->addWidget(kcfg_ShowVenus, 3, 0, 1, 1);

        hboxLayout = new QHBoxLayout();
        hboxLayout->setObjectName("hboxLayout");
        kcfg_ShowSun = new QCheckBox(MajorBodiesBox);
        solarButtonGroup->addButton(kcfg_ShowSun);
        kcfg_ShowSun->setObjectName("kcfg_ShowSun");

        hboxLayout->addWidget(kcfg_ShowSun);

        sunLabel = new QLabel(MajorBodiesBox);
        sunLabel->setObjectName("sunLabel");

        hboxLayout->addWidget(sunLabel);

        kcfg_SunScale = new QDoubleSpinBox(MajorBodiesBox);
        kcfg_SunScale->setObjectName("kcfg_SunScale");
        kcfg_SunScale->setDecimals(1);
        kcfg_SunScale->setMaximum(20.000000000000000);
        kcfg_SunScale->setMinimum(1.000000000000000);

        hboxLayout->addWidget(kcfg_SunScale);


        gridLayout->addLayout(hboxLayout, 0, 0, 1, 1);

        kcfg_ShowJupiter = new QCheckBox(MajorBodiesBox);
        solarButtonGroup->addButton(kcfg_ShowJupiter);
        kcfg_ShowJupiter->setObjectName("kcfg_ShowJupiter");

        gridLayout->addWidget(kcfg_ShowJupiter, 0, 1, 1, 1);

        hboxLayout1 = new QHBoxLayout();
        hboxLayout1->setObjectName("hboxLayout1");
        kcfg_ShowMoon = new QCheckBox(MajorBodiesBox);
        solarButtonGroup->addButton(kcfg_ShowMoon);
        kcfg_ShowMoon->setObjectName("kcfg_ShowMoon");

        hboxLayout1->addWidget(kcfg_ShowMoon);

        moonLabel = new QLabel(MajorBodiesBox);
        moonLabel->setObjectName("moonLabel");

        hboxLayout1->addWidget(moonLabel);

        kcfg_MoonScale = new QDoubleSpinBox(MajorBodiesBox);
        kcfg_MoonScale->setObjectName("kcfg_MoonScale");
        kcfg_MoonScale->setDecimals(1);
        kcfg_MoonScale->setMaximum(20.000000000000000);
        kcfg_MoonScale->setMinimum(1.000000000000000);

        hboxLayout1->addWidget(kcfg_MoonScale);


        gridLayout->addLayout(hboxLayout1, 1, 0, 1, 1);

        kcfg_ShowMercury = new QCheckBox(MajorBodiesBox);
        solarButtonGroup->addButton(kcfg_ShowMercury);
        kcfg_ShowMercury->setObjectName("kcfg_ShowMercury");

        gridLayout->addWidget(kcfg_ShowMercury, 2, 0, 1, 1);

        kcfg_ShowNeptune = new QCheckBox(MajorBodiesBox);
        solarButtonGroup->addButton(kcfg_ShowNeptune);
        kcfg_ShowNeptune->setObjectName("kcfg_ShowNeptune");

        gridLayout->addWidget(kcfg_ShowNeptune, 3, 1, 1, 1);

        spacerItem = new QSpacerItem(100, 20, QSizePolicy::Policy::Fixed, QSizePolicy::Policy::Minimum);

        gridLayout->addItem(spacerItem, 4, 2, 1, 1);

        kcfg_ShowUranus = new QCheckBox(MajorBodiesBox);
        solarButtonGroup->addButton(kcfg_ShowUranus);
        kcfg_ShowUranus->setObjectName("kcfg_ShowUranus");

        gridLayout->addWidget(kcfg_ShowUranus, 2, 1, 1, 1);


        vboxLayout1->addLayout(gridLayout);

        spacerItem1 = new QSpacerItem(16, 16, QSizePolicy::Policy::Minimum, QSizePolicy::Policy::Expanding);

        vboxLayout1->addItem(spacerItem1);


        vboxLayout->addWidget(MajorBodiesBox);

        MinorBodiesBox = new QGroupBox(OpsSolarSystem);
        MinorBodiesBox->setObjectName("MinorBodiesBox");
        vboxLayout2 = new QVBoxLayout(MinorBodiesBox);
        vboxLayout2->setObjectName("vboxLayout2");
        gridLayout1 = new QGridLayout();
        gridLayout1->setObjectName("gridLayout1");
        label_3 = new QLabel(MinorBodiesBox);
        label_3->setObjectName("label_3");

        gridLayout1->addWidget(label_3, 1, 1, 1, 1);

        kcfg_ShowAsteroids = new QCheckBox(MinorBodiesBox);
        solarButtonGroup->addButton(kcfg_ShowAsteroids);
        kcfg_ShowAsteroids->setObjectName("kcfg_ShowAsteroids");

        gridLayout1->addWidget(kcfg_ShowAsteroids, 0, 0, 1, 1);

        kcfg_ShowComets = new QCheckBox(MinorBodiesBox);
        solarButtonGroup->addButton(kcfg_ShowComets);
        kcfg_ShowComets->setObjectName("kcfg_ShowComets");

        gridLayout1->addWidget(kcfg_ShowComets, 4, 0, 1, 1);

        spacerItem2 = new QSpacerItem(20, 16, QSizePolicy::Policy::Minimum, QSizePolicy::Policy::Fixed);

        gridLayout1->addItem(spacerItem2, 3, 0, 1, 1);

        MagLimitAsteroidDownloadWarning = new QLabel(MinorBodiesBox);
        MagLimitAsteroidDownloadWarning->setObjectName("MagLimitAsteroidDownloadWarning");
        MagLimitAsteroidDownloadWarning->setStyleSheet(QString::fromUtf8("color:red; font-weight:bold;"));
        MagLimitAsteroidDownloadWarning->setAlignment(Qt::AlignCenter);

        gridLayout1->addWidget(MagLimitAsteroidDownloadWarning, 2, 0, 1, 3);

        textLabel3 = new QLabel(MinorBodiesBox);
        textLabel3->setObjectName("textLabel3");

        gridLayout1->addWidget(textLabel3, 0, 1, 1, 1);

        kcfg_ShowCometNames = new QCheckBox(MinorBodiesBox);
        solarButtonGroup->addButton(kcfg_ShowCometNames);
        kcfg_ShowCometNames->setObjectName("kcfg_ShowCometNames");

        gridLayout1->addWidget(kcfg_ShowCometNames, 4, 1, 1, 1);

        hboxLayout2 = new QHBoxLayout();
        hboxLayout2->setObjectName("hboxLayout2");
        kcfg_MagLimitAsteroid = new MagnitudeSpinBox(MinorBodiesBox);
        kcfg_MagLimitAsteroid->setObjectName("kcfg_MagLimitAsteroid");
        kcfg_MagLimitAsteroid->setFocusPolicy(Qt::StrongFocus);
        kcfg_MagLimitAsteroid->setMinimum(-10.000000000000000);
        kcfg_MagLimitAsteroid->setMaximum(50.000000000000000);

        hboxLayout2->addWidget(kcfg_MagLimitAsteroid);

        textLabel6 = new QLabel(MinorBodiesBox);
        textLabel6->setObjectName("textLabel6");

        hboxLayout2->addWidget(textLabel6);


        gridLayout1->addLayout(hboxLayout2, 0, 2, 1, 1);

        horizontalLayout = new QHBoxLayout();
        horizontalLayout->setObjectName("horizontalLayout");
        kcfg_MagLimitAsteroidDownload = new QDoubleSpinBox(MinorBodiesBox);
        kcfg_MagLimitAsteroidDownload->setObjectName("kcfg_MagLimitAsteroidDownload");

        horizontalLayout->addWidget(kcfg_MagLimitAsteroidDownload);

        label_2 = new QLabel(MinorBodiesBox);
        label_2->setObjectName("label_2");

        horizontalLayout->addWidget(label_2);


        gridLayout1->addLayout(horizontalLayout, 1, 2, 1, 1);

        hboxLayout3 = new QHBoxLayout();
        hboxLayout3->setObjectName("hboxLayout3");
        kcfg_MaxRadCometName = new QDoubleSpinBox(MinorBodiesBox);
        kcfg_MaxRadCometName->setObjectName("kcfg_MaxRadCometName");
        kcfg_MaxRadCometName->setDecimals(2);
        kcfg_MaxRadCometName->setMaximum(9999.000000000000000);

        hboxLayout3->addWidget(kcfg_MaxRadCometName);

        textLabel4 = new QLabel(MinorBodiesBox);
        textLabel4->setObjectName("textLabel4");

        hboxLayout3->addWidget(textLabel4);


        gridLayout1->addLayout(hboxLayout3, 4, 2, 1, 1);

        kcfg_AsteroidLabelDensity = new QSlider(MinorBodiesBox);
        kcfg_AsteroidLabelDensity->setObjectName("kcfg_AsteroidLabelDensity");
        kcfg_AsteroidLabelDensity->setMaximum(20);
        kcfg_AsteroidLabelDensity->setOrientation(Qt::Horizontal);

        gridLayout1->addWidget(kcfg_AsteroidLabelDensity, 3, 2, 1, 1);

        hboxLayout4 = new QHBoxLayout();
        hboxLayout4->setObjectName("hboxLayout4");
        kcfg_ShowAsteroidNames = new QCheckBox(MinorBodiesBox);
        solarButtonGroup->addButton(kcfg_ShowAsteroidNames);
        kcfg_ShowAsteroidNames->setObjectName("kcfg_ShowAsteroidNames");

        hboxLayout4->addWidget(kcfg_ShowAsteroidNames);

        spacerItem3 = new QSpacerItem(20, 20, QSizePolicy::Policy::Preferred, QSizePolicy::Policy::Minimum);

        hboxLayout4->addItem(spacerItem3);

        LabelDensity = new QLabel(MinorBodiesBox);
        LabelDensity->setObjectName("LabelDensity");

        hboxLayout4->addWidget(LabelDensity);


        gridLayout1->addLayout(hboxLayout4, 3, 1, 1, 1);

        kcfg_ShowCometComas = new QCheckBox(MinorBodiesBox);
        kcfg_ShowCometComas->setObjectName("kcfg_ShowCometComas");

        gridLayout1->addWidget(kcfg_ShowCometComas, 5, 1, 1, 1);

        kcfg_OrbitalElementsAutoUpdate = new QCheckBox(MinorBodiesBox);
        kcfg_OrbitalElementsAutoUpdate->setObjectName("kcfg_OrbitalElementsAutoUpdate");

        gridLayout1->addWidget(kcfg_OrbitalElementsAutoUpdate, 5, 2, 1, 1);


        vboxLayout2->addLayout(gridLayout1);

        spacerItem4 = new QSpacerItem(21, 16, QSizePolicy::Policy::Minimum, QSizePolicy::Policy::Expanding);

        vboxLayout2->addItem(spacerItem4);


        vboxLayout->addWidget(MinorBodiesBox);

        TrailsBox = new QGroupBox(OpsSolarSystem);
        TrailsBox->setObjectName("TrailsBox");
        vboxLayout3 = new QVBoxLayout(TrailsBox);
        vboxLayout3->setObjectName("vboxLayout3");
        kcfg_UseAutoTrail = new QCheckBox(TrailsBox);
        solarButtonGroup->addButton(kcfg_UseAutoTrail);
        kcfg_UseAutoTrail->setObjectName("kcfg_UseAutoTrail");

        vboxLayout3->addWidget(kcfg_UseAutoTrail);

        hboxLayout5 = new QHBoxLayout();
        hboxLayout5->setObjectName("hboxLayout5");
        kcfg_FadePlanetTrails = new QCheckBox(TrailsBox);
        solarButtonGroup->addButton(kcfg_FadePlanetTrails);
        kcfg_FadePlanetTrails->setObjectName("kcfg_FadePlanetTrails");

        hboxLayout5->addWidget(kcfg_FadePlanetTrails);

        spacerItem5 = new QSpacerItem(40, 20, QSizePolicy::Policy::Expanding, QSizePolicy::Policy::Minimum);

        hboxLayout5->addItem(spacerItem5);

        ClearAllTrails = new QPushButton(TrailsBox);
        ClearAllTrails->setObjectName("ClearAllTrails");

        hboxLayout5->addWidget(ClearAllTrails);


        vboxLayout3->addLayout(hboxLayout5);

        spacerItem6 = new QSpacerItem(41, 21, QSizePolicy::Policy::Minimum, QSizePolicy::Policy::Fixed);

        vboxLayout3->addItem(spacerItem6);

        checkBox = new QCheckBox(TrailsBox);
        solarButtonGroup->addButton(checkBox);
        checkBox->setObjectName("checkBox");

        vboxLayout3->addWidget(checkBox);

        spacerItem7 = new QSpacerItem(20, 20, QSizePolicy::Policy::Minimum, QSizePolicy::Policy::Expanding);

        vboxLayout3->addItem(spacerItem7);


        vboxLayout->addWidget(TrailsBox);

        QWidget::setTabOrder(kcfg_ShowSolarSystem, kcfg_ShowSun);
        QWidget::setTabOrder(kcfg_ShowSun, kcfg_ShowJupiter);
        QWidget::setTabOrder(kcfg_ShowJupiter, showAllPlanets);
        QWidget::setTabOrder(showAllPlanets, kcfg_ShowMoon);
        QWidget::setTabOrder(kcfg_ShowMoon, kcfg_ShowSaturn);
        QWidget::setTabOrder(kcfg_ShowSaturn, showNonePlanets);
        QWidget::setTabOrder(showNonePlanets, kcfg_ShowMercury);
        QWidget::setTabOrder(kcfg_ShowMercury, kcfg_ShowUranus);
        QWidget::setTabOrder(kcfg_ShowUranus, kcfg_ShowPlanetNames);
        QWidget::setTabOrder(kcfg_ShowPlanetNames, kcfg_ShowVenus);
        QWidget::setTabOrder(kcfg_ShowVenus, kcfg_ShowNeptune);
        QWidget::setTabOrder(kcfg_ShowNeptune, kcfg_ShowPlanetImages);
        QWidget::setTabOrder(kcfg_ShowPlanetImages, kcfg_ShowMars);
        QWidget::setTabOrder(kcfg_ShowMars, kcfg_ShowAsteroids);
        QWidget::setTabOrder(kcfg_ShowAsteroids, kcfg_MagLimitAsteroid);
        QWidget::setTabOrder(kcfg_MagLimitAsteroid, kcfg_ShowAsteroidNames);
        QWidget::setTabOrder(kcfg_ShowAsteroidNames, kcfg_AsteroidLabelDensity);
        QWidget::setTabOrder(kcfg_AsteroidLabelDensity, kcfg_ShowComets);
        QWidget::setTabOrder(kcfg_ShowComets, kcfg_ShowCometNames);
        QWidget::setTabOrder(kcfg_ShowCometNames, kcfg_MaxRadCometName);
        QWidget::setTabOrder(kcfg_MaxRadCometName, kcfg_UseAutoTrail);
        QWidget::setTabOrder(kcfg_UseAutoTrail, kcfg_FadePlanetTrails);
        QWidget::setTabOrder(kcfg_FadePlanetTrails, ClearAllTrails);
        QWidget::setTabOrder(ClearAllTrails, checkBox);

        retranslateUi(OpsSolarSystem);

        QMetaObject::connectSlotsByName(OpsSolarSystem);
    } // setupUi

    void retranslateUi(QWidget *OpsSolarSystem)
    {
        kcfg_ShowSolarSystem->setText(tr2i18n("Show solar system objects", nullptr));
        MajorBodiesBox->setTitle(tr2i18n("Sun, Moon && Planets", nullptr));
#if QT_CONFIG(tooltip)
        kcfg_ShowSaturn->setToolTip(tr2i18n("Draw Saturn?", nullptr));
#endif // QT_CONFIG(tooltip)
#if QT_CONFIG(whatsthis)
        kcfg_ShowSaturn->setWhatsThis(tr2i18n("If checked, Saturn will be drawn on the map.", nullptr));
#endif // QT_CONFIG(whatsthis)
        kcfg_ShowSaturn->setText(tr2i18n("Saturn", nullptr));
#if QT_CONFIG(tooltip)
        kcfg_ShowPlanetImages->setToolTip(tr2i18n("Draw major bodies as images?", nullptr));
#endif // QT_CONFIG(tooltip)
#if QT_CONFIG(whatsthis)
        kcfg_ShowPlanetImages->setWhatsThis(tr2i18n("If checked, then the planets, the Sun and the Moon will be shown as bitmap images on the map", nullptr));
#endif // QT_CONFIG(whatsthis)
        kcfg_ShowPlanetImages->setText(tr2i18n("Use images", nullptr));
#if QT_CONFIG(tooltip)
        kcfg_ShowMars->setToolTip(tr2i18n("Draw Mars?", nullptr));
#endif // QT_CONFIG(tooltip)
#if QT_CONFIG(whatsthis)
        kcfg_ShowMars->setWhatsThis(tr2i18n("If checked, Mars will be drawn on the map.", nullptr));
#endif // QT_CONFIG(whatsthis)
        kcfg_ShowMars->setText(tr2i18n("Mars", nullptr));
#if QT_CONFIG(tooltip)
        kcfg_ShowPlanetNames->setToolTip(tr2i18n("Attach Name labels to the major solar system bodies?", nullptr));
#endif // QT_CONFIG(tooltip)
#if QT_CONFIG(whatsthis)
        kcfg_ShowPlanetNames->setWhatsThis(tr2i18n("If checked, name labels will be attached to the planets, the Sun and the Moon", nullptr));
#endif // QT_CONFIG(whatsthis)
        kcfg_ShowPlanetNames->setText(tr2i18n("Use name labels", nullptr));
#if QT_CONFIG(tooltip)
        showAllPlanets->setToolTip(tr2i18n("Select all major bodies", nullptr));
#endif // QT_CONFIG(tooltip)
#if QT_CONFIG(whatsthis)
        showAllPlanets->setWhatsThis(tr2i18n("Press this to select all planets, the Sun and the Moon to be drawn in the map", nullptr));
#endif // QT_CONFIG(whatsthis)
        showAllPlanets->setText(tr2i18n("Select All", nullptr));
#if QT_CONFIG(tooltip)
        showNonePlanets->setToolTip(tr2i18n("Unselect all major bodies", nullptr));
#endif // QT_CONFIG(tooltip)
#if QT_CONFIG(whatsthis)
        showNonePlanets->setWhatsThis(tr2i18n("Press this button to unselect all planets, the Sun and the Moon so that they will not be drawn on the map", nullptr));
#endif // QT_CONFIG(whatsthis)
        showNonePlanets->setText(tr2i18n("Select None", nullptr));
#if QT_CONFIG(tooltip)
        kcfg_ShowVenus->setToolTip(tr2i18n("Draw Venus?", nullptr));
#endif // QT_CONFIG(tooltip)
#if QT_CONFIG(whatsthis)
        kcfg_ShowVenus->setWhatsThis(tr2i18n("If checked, Venus will be drawn on the map.", nullptr));
#endif // QT_CONFIG(whatsthis)
        kcfg_ShowVenus->setText(tr2i18n("Venus", nullptr));
#if QT_CONFIG(tooltip)
        kcfg_ShowSun->setToolTip(tr2i18n("Draw the Sun?", nullptr));
#endif // QT_CONFIG(tooltip)
#if QT_CONFIG(whatsthis)
        kcfg_ShowSun->setWhatsThis(tr2i18n("If checked, the Sun will be drawn on the map.", nullptr));
#endif // QT_CONFIG(whatsthis)
        kcfg_ShowSun->setText(tr2i18n("Sun", nullptr));
        sunLabel->setText(tr2i18n("scale:", nullptr));
#if QT_CONFIG(tooltip)
        kcfg_SunScale->setToolTip(tr2i18n("Scale of sun rendering.", nullptr));
#endif // QT_CONFIG(tooltip)
#if QT_CONFIG(tooltip)
        kcfg_SunScale->setToolTip(tr2i18n("Increase the size of the sun by this factor.", nullptr));
#endif // QT_CONFIG(tooltip)
#if QT_CONFIG(tooltip)
        kcfg_ShowJupiter->setToolTip(tr2i18n("Draw Jupiter?", nullptr));
#endif // QT_CONFIG(tooltip)
#if QT_CONFIG(whatsthis)
        kcfg_ShowJupiter->setWhatsThis(tr2i18n("If checked, Jupiter will be drawn on the map.", nullptr));
#endif // QT_CONFIG(whatsthis)
        kcfg_ShowJupiter->setText(tr2i18n("Jupiter", nullptr));
#if QT_CONFIG(tooltip)
        kcfg_ShowMoon->setToolTip(tr2i18n("Draw the Moon?", nullptr));
#endif // QT_CONFIG(tooltip)
#if QT_CONFIG(whatsthis)
        kcfg_ShowMoon->setWhatsThis(tr2i18n("If checked, the Moon will be drawn on the map.", nullptr));
#endif // QT_CONFIG(whatsthis)
        kcfg_ShowMoon->setText(tr2i18n("Moon", nullptr));
        moonLabel->setText(tr2i18n("scale:", nullptr));
#if QT_CONFIG(tooltip)
        kcfg_MoonScale->setToolTip(tr2i18n("Scale of moon rendering.", nullptr));
#endif // QT_CONFIG(tooltip)
#if QT_CONFIG(tooltip)
        kcfg_MoonScale->setToolTip(tr2i18n("Increase the size of the moon by this factor.", nullptr));
#endif // QT_CONFIG(tooltip)
#if QT_CONFIG(tooltip)
        kcfg_ShowMercury->setToolTip(tr2i18n("Draw Mercury?", nullptr));
#endif // QT_CONFIG(tooltip)
#if QT_CONFIG(whatsthis)
        kcfg_ShowMercury->setWhatsThis(tr2i18n("If checked, Mercury will be drawn on the map.", nullptr));
#endif // QT_CONFIG(whatsthis)
        kcfg_ShowMercury->setText(tr2i18n("Mercury", nullptr));
#if QT_CONFIG(tooltip)
        kcfg_ShowNeptune->setToolTip(tr2i18n("Draw Neptune?", nullptr));
#endif // QT_CONFIG(tooltip)
#if QT_CONFIG(whatsthis)
        kcfg_ShowNeptune->setWhatsThis(tr2i18n("If checked, Neptune will be drawn on the map.", nullptr));
#endif // QT_CONFIG(whatsthis)
        kcfg_ShowNeptune->setText(tr2i18n("Neptune", nullptr));
#if QT_CONFIG(tooltip)
        kcfg_ShowUranus->setToolTip(tr2i18n("Draw Uranus?", nullptr));
#endif // QT_CONFIG(tooltip)
#if QT_CONFIG(whatsthis)
        kcfg_ShowUranus->setWhatsThis(tr2i18n("If checked, Uranus will be drawn on the map.", nullptr));
#endif // QT_CONFIG(whatsthis)
        kcfg_ShowUranus->setText(tr2i18n("Uranus", nullptr));
        MinorBodiesBox->setTitle(tr2i18n("Minor Planets", nullptr));
        label_3->setText(tr2i18n("Download asteroids brighter than:", nullptr));
#if QT_CONFIG(tooltip)
        kcfg_ShowAsteroids->setToolTip(tr2i18n("Draw asteroids?", nullptr));
#endif // QT_CONFIG(tooltip)
#if QT_CONFIG(whatsthis)
        kcfg_ShowAsteroids->setWhatsThis(tr2i18n("If checked, asteroids will be drawn on the map", nullptr));
#endif // QT_CONFIG(whatsthis)
        kcfg_ShowAsteroids->setText(tr2i18n("Asteroids", nullptr));
#if QT_CONFIG(tooltip)
        kcfg_ShowComets->setToolTip(tr2i18n("Draw comets?", nullptr));
#endif // QT_CONFIG(tooltip)
#if QT_CONFIG(whatsthis)
        kcfg_ShowComets->setWhatsThis(tr2i18n("If checked, comets will be drawn on the map", nullptr));
#endif // QT_CONFIG(whatsthis)
        kcfg_ShowComets->setText(tr2i18n("Comets", nullptr));
        MagLimitAsteroidDownloadWarning->setText(tr2i18n("This value might result in a big data file and reduced performance.", nullptr));
        textLabel3->setText(tr2i18n("Show asteroids brighter than:", nullptr));
#if QT_CONFIG(tooltip)
        kcfg_ShowCometNames->setToolTip(tr2i18n("Show names of comets near the Sun", nullptr));
#endif // QT_CONFIG(tooltip)
#if QT_CONFIG(whatsthis)
        kcfg_ShowCometNames->setWhatsThis(tr2i18n("If checked, the comets near the Sun will have name labels attached.  Comets vary in brightness in their orbits, so a faint magnitude is not effective in this case.", nullptr));
#endif // QT_CONFIG(whatsthis)
        kcfg_ShowCometNames->setText(tr2i18n("Show names of comets within:", nullptr));
#if QT_CONFIG(tooltip)
        kcfg_MagLimitAsteroid->setToolTip(tr2i18n("Faint limit for asteroids", nullptr));
#endif // QT_CONFIG(tooltip)
#if QT_CONFIG(whatsthis)
        kcfg_MagLimitAsteroid->setWhatsThis(tr2i18n("Set the faintest magnitude for drawing asteroids", nullptr));
#endif // QT_CONFIG(whatsthis)
        textLabel6->setText(tr2i18n("mag", nullptr));
        label_2->setText(tr2i18n("mag", nullptr));
#if QT_CONFIG(tooltip)
        kcfg_MaxRadCometName->setToolTip(tr2i18n("Maximum distance for comet names", nullptr));
#endif // QT_CONFIG(tooltip)
#if QT_CONFIG(whatsthis)
        kcfg_MaxRadCometName->setWhatsThis(tr2i18n("Set the maximum distance from the Sun for a comet to have a name label, in Astronomical Units (AU).  1 AU is the distance between the Earth and the Sun, approximately 150 million km", nullptr));
#endif // QT_CONFIG(whatsthis)
        textLabel4->setText(tr2i18n("AU", nullptr));
#if QT_CONFIG(tooltip)
        kcfg_ShowAsteroidNames->setToolTip(tr2i18n("Attach name labels to asteroids?", nullptr));
#endif // QT_CONFIG(tooltip)
#if QT_CONFIG(whatsthis)
        kcfg_ShowAsteroidNames->setWhatsThis(tr2i18n("If checked, then name labels will be attached to asteroids", nullptr));
#endif // QT_CONFIG(whatsthis)
        kcfg_ShowAsteroidNames->setText(tr2i18n("Show names", nullptr));
        LabelDensity->setText(tr2i18n("Label density:", nullptr));
        kcfg_ShowCometComas->setText(tr2i18n("Show comet comas", nullptr));
#if QT_CONFIG(tooltip)
        kcfg_OrbitalElementsAutoUpdate->setToolTip(tr2i18n("Update orbital element from online sources on startup.", nullptr));
#endif // QT_CONFIG(tooltip)
        kcfg_OrbitalElementsAutoUpdate->setText(tr2i18n("Auto online update", nullptr));
        TrailsBox->setTitle(tr2i18n("Orbit Trails", nullptr));
#if QT_CONFIG(tooltip)
        kcfg_UseAutoTrail->setToolTip(tr2i18n("Auto-trail tracked bodies", nullptr));
#endif // QT_CONFIG(tooltip)
#if QT_CONFIG(whatsthis)
        kcfg_UseAutoTrail->setWhatsThis(tr2i18n("If checked then any solar system body will have a temporary trail attached while it is centered in the display.", nullptr));
#endif // QT_CONFIG(whatsthis)
        kcfg_UseAutoTrail->setText(tr2i18n("Always show trail when tracking a solar system body", nullptr));
#if QT_CONFIG(tooltip)
        kcfg_FadePlanetTrails->setToolTip(tr2i18n("Fade trail color into the background?", nullptr));
#endif // QT_CONFIG(tooltip)
#if QT_CONFIG(whatsthis)
        kcfg_FadePlanetTrails->setWhatsThis(tr2i18n("If checked, the color of the planet trail will be blended into the background sky color.", nullptr));
#endif // QT_CONFIG(whatsthis)
        kcfg_FadePlanetTrails->setText(tr2i18n("Fade trails to background color", nullptr));
#if QT_CONFIG(tooltip)
        ClearAllTrails->setToolTip(tr2i18n("Clear all orbit trails", nullptr));
#endif // QT_CONFIG(tooltip)
#if QT_CONFIG(whatsthis)
        ClearAllTrails->setWhatsThis(tr2i18n("Press this to clear all orbit trails that you may have attached to solar system bodies using the right-click popup menu.", nullptr));
#endif // QT_CONFIG(whatsthis)
        ClearAllTrails->setText(tr2i18n("Remove All Trails", nullptr));
        checkBox->setText(tr2i18n("Earth satellite tracks", nullptr));
        (void)OpsSolarSystem;
    } // retranslateUi

};

namespace Ui {
    class OpsSolarSystem: public Ui_OpsSolarSystem {};
} // namespace Ui

QT_END_NAMESPACE

#endif // OPSSOLARSYSTEM_H

