// This file was generated by ecm_qt_declare_logging_category(): DO NOT EDIT!

#include "ekos_scheduler_debug.h"


Q_LOGGING_CATEGORY(KSTARS_EKOS_SCHEDULER, "org.kde.kstars.ekos.scheduler", QtInfoMsg)

