/*
 * This file was generated by qdbusxml2cpp version 0.8
 * Source file was org.kde.kstars.Ekos.Guide.xml
 *
 * qdbusxml2cpp is Copyright (C) The Qt Company Ltd. and other contributors.
 *
 * This is an auto-generated file.
 * Do not edit! All changes made to it will be lost.
 */

#include "guideadaptor.h"
#include <QtCore/QMetaObject>
#include <QtCore/QByteArray>
#include <QtCore/QList>
#include <QtCore/QMap>
#include <QtCore/QString>
#include <QtCore/QStringList>
#include <QtCore/QVariant>

/*
 * Implementation of adaptor class GuideAdaptor
 */

GuideAdaptor::GuideAdaptor(Ekos::Guide *parent)
    : QDBusAbstractAdaptor(parent)
{
    // constructor
    setAutoRelaySignals(true);
}

GuideAdaptor::~GuideAdaptor()
{
    // destructor
}

QList<double> GuideAdaptor::axisDelta() const
{
    // get the value of property axisDelta
    return qvariant_cast< QList<double> >(parent()->property("axisDelta"));
}

QList<double> GuideAdaptor::axisSigma() const
{
    // get the value of property axisSigma
    return qvariant_cast< QList<double> >(parent()->property("axisSigma"));
}

QString GuideAdaptor::camera() const
{
    // get the value of property camera
    return qvariant_cast< QString >(parent()->property("camera"));
}

double GuideAdaptor::exposure() const
{
    // get the value of property exposure
    return qvariant_cast< double >(parent()->property("exposure"));
}

void GuideAdaptor::setExposure(double value)
{
    // set the value of property exposure
    parent()->setProperty("exposure", QVariant::fromValue(value));
}

QString GuideAdaptor::guider() const
{
    // get the value of property guider
    return qvariant_cast< QString >(parent()->property("guider"));
}

QStringList GuideAdaptor::logText() const
{
    // get the value of property logText
    return qvariant_cast< QStringList >(parent()->property("logText"));
}

QString GuideAdaptor::opticalTrain() const
{
    // get the value of property opticalTrain
    return qvariant_cast< QString >(parent()->property("opticalTrain"));
}

void GuideAdaptor::setOpticalTrain(const QString &value)
{
    // set the value of property opticalTrain
    parent()->setProperty("opticalTrain", QVariant::fromValue(value));
}

int GuideAdaptor::status() const
{
    // get the value of property status
    return qvariant_cast< int >(parent()->property("status"));
}

bool GuideAdaptor::abort()
{
    // handle method call org.kde.kstars.Ekos.Guide.abort
    return parent()->abort();
}

bool GuideAdaptor::calibrate()
{
    // handle method call org.kde.kstars.Ekos.Guide.calibrate
    return parent()->calibrate();
}

bool GuideAdaptor::capture()
{
    // handle method call org.kde.kstars.Ekos.Guide.capture
    return parent()->capture();
}

void GuideAdaptor::clearCalibration()
{
    // handle method call org.kde.kstars.Ekos.Guide.clearCalibration
    parent()->clearCalibration();
}

bool GuideAdaptor::connectGuider()
{
    // handle method call org.kde.kstars.Ekos.Guide.connectGuider
    return parent()->connectGuider();
}

bool GuideAdaptor::disconnectGuider()
{
    // handle method call org.kde.kstars.Ekos.Guide.disconnectGuider
    return parent()->disconnectGuider();
}

bool GuideAdaptor::dither()
{
    // handle method call org.kde.kstars.Ekos.Guide.dither
    return parent()->dither();
}

bool GuideAdaptor::guide()
{
    // handle method call org.kde.kstars.Ekos.Guide.guide
    return parent()->guide();
}

void GuideAdaptor::loop()
{
    // handle method call org.kde.kstars.Ekos.Guide.loop
    parent()->loop();
}

void GuideAdaptor::reloadAIWeights()
{
    // handle method call org.kde.kstars.Ekos.Guide.reloadAIWeights
    parent()->reloadAIWeights();
}

bool GuideAdaptor::resume()
{
    // handle method call org.kde.kstars.Ekos.Guide.resume
    return parent()->resume();
}

void GuideAdaptor::setAutoStarEnabled(bool enable)
{
    // handle method call org.kde.kstars.Ekos.Guide.setAutoStarEnabled
    parent()->setAutoStarEnabled(enable);
}

void GuideAdaptor::setDarkFrameEnabled(bool enable)
{
    // handle method call org.kde.kstars.Ekos.Guide.setDarkFrameEnabled
    parent()->setDarkFrameEnabled(enable);
}

bool GuideAdaptor::setGuiderType(int guideType)
{
    // handle method call org.kde.kstars.Ekos.Guide.setGuiderType
    return parent()->setGuiderType(guideType);
}

void GuideAdaptor::setSubFrameEnabled(bool enable)
{
    // handle method call org.kde.kstars.Ekos.Guide.setSubFrameEnabled
    parent()->setSubFrameEnabled(enable);
}

bool GuideAdaptor::suspend()
{
    // handle method call org.kde.kstars.Ekos.Guide.suspend
    return parent()->suspend();
}


#include "moc_guideadaptor.cpp"
