/********************************************************************************
** Form generated from reading UI file 'pwizfovtypeselection.ui'
**
** Created by: Qt User Interface Compiler version 6.11.1
**
** WARNING! All changes made in this file will be lost when recompiling UI file!
********************************************************************************/

#ifndef UI_PWIZFOVTYPESELECTION_H
#define UI_PWIZFOVTYPESELECTION_H

#include <QtCore/QVariant>
#include <QtWidgets/QApplication>
#include <QtWidgets/QHBoxLayout>
#include <QtWidgets/QLabel>
#include <QtWidgets/QRadioButton>
#include <QtWidgets/QSpacerItem>
#include <QtWidgets/QVBoxLayout>
#include <QtWidgets/QWidget>
#include <klocalizedstring.h>

QT_BEGIN_NAMESPACE

class Ui_PWizFovTypeSelection
{
public:
    QHBoxLayout *horizontalLayout;
    QLabel *banner;
    QSpacerItem *horSpacer4;
    QVBoxLayout *fovTypeLayout;
    QLabel *stepTitle;
    QSpacerItem *vertSpacer1;
    QLabel *stepText;
    QSpacerItem *vertSpacer2;
    QLabel *typeLabel;
    QRadioButton *manualRadio;
    QRadioButton *hopperRadio;
    QSpacerItem *vertSpacer3;

    void setupUi(QWidget *PWizFovTypeSelection)
    {
        if (PWizFovTypeSelection->objectName().isEmpty())
            PWizFovTypeSelection->setObjectName("PWizFovTypeSelection");
        PWizFovTypeSelection->resize(586, 395);
        horizontalLayout = new QHBoxLayout(PWizFovTypeSelection);
        horizontalLayout->setObjectName("horizontalLayout");
        banner = new QLabel(PWizFovTypeSelection);
        banner->setObjectName("banner");
        QSizePolicy sizePolicy(QSizePolicy::Policy::Fixed, QSizePolicy::Policy::Fixed);
        sizePolicy.setHorizontalStretch(0);
        sizePolicy.setVerticalStretch(0);
        sizePolicy.setHeightForWidth(banner->sizePolicy().hasHeightForWidth());
        banner->setSizePolicy(sizePolicy);
        banner->setMinimumSize(QSize(120, 360));

        horizontalLayout->addWidget(banner);

        horSpacer4 = new QSpacerItem(5, 20, QSizePolicy::Policy::Fixed, QSizePolicy::Policy::Minimum);

        horizontalLayout->addItem(horSpacer4);

        fovTypeLayout = new QVBoxLayout();
#ifndef UI_Q_OS_MAC
        fovTypeLayout->setSpacing(6);
#endif
        fovTypeLayout->setContentsMargins(0, 0, 0, 0);
        fovTypeLayout->setObjectName("fovTypeLayout");
        stepTitle = new QLabel(PWizFovTypeSelection);
        stepTitle->setObjectName("stepTitle");
        QFont font;
        font.setFamilies({QString::fromUtf8("Sans Serif")});
        font.setPointSize(11);
        font.setBold(true);
        font.setItalic(false);
        font.setUnderline(false);
        font.setStrikeOut(false);
        stepTitle->setFont(font);

        fovTypeLayout->addWidget(stepTitle);

        vertSpacer1 = new QSpacerItem(20, 12, QSizePolicy::Policy::Minimum, QSizePolicy::Policy::Fixed);

        fovTypeLayout->addItem(vertSpacer1);

        stepText = new QLabel(PWizFovTypeSelection);
        stepText->setObjectName("stepText");
        stepText->setWordWrap(true);

        fovTypeLayout->addWidget(stepText);

        vertSpacer2 = new QSpacerItem(20, 12, QSizePolicy::Policy::Minimum, QSizePolicy::Policy::Maximum);

        fovTypeLayout->addItem(vertSpacer2);

        typeLabel = new QLabel(PWizFovTypeSelection);
        typeLabel->setObjectName("typeLabel");
        QFont font1;
        font1.setBold(true);
        typeLabel->setFont(font1);

        fovTypeLayout->addWidget(typeLabel);

        manualRadio = new QRadioButton(PWizFovTypeSelection);
        manualRadio->setObjectName("manualRadio");
        manualRadio->setChecked(true);

        fovTypeLayout->addWidget(manualRadio);

        hopperRadio = new QRadioButton(PWizFovTypeSelection);
        hopperRadio->setObjectName("hopperRadio");
        QSizePolicy sizePolicy1(QSizePolicy::Policy::Minimum, QSizePolicy::Policy::Preferred);
        sizePolicy1.setHorizontalStretch(0);
        sizePolicy1.setVerticalStretch(0);
        sizePolicy1.setHeightForWidth(hopperRadio->sizePolicy().hasHeightForWidth());
        hopperRadio->setSizePolicy(sizePolicy1);

        fovTypeLayout->addWidget(hopperRadio);

        vertSpacer3 = new QSpacerItem(20, 40, QSizePolicy::Policy::Minimum, QSizePolicy::Policy::Expanding);

        fovTypeLayout->addItem(vertSpacer3);


        horizontalLayout->addLayout(fovTypeLayout);


        retranslateUi(PWizFovTypeSelection);

        QMetaObject::connectSlotsByName(PWizFovTypeSelection);
    } // setupUi

    void retranslateUi(QWidget *PWizFovTypeSelection)
    {
        banner->setText(QString());
        stepTitle->setText(tr2i18n("Choose Field of View Capture Method", nullptr));
        stepText->setText(tr2i18n("<p>Select field of view capture method. There are two methods: manual and star hopping-based.</p>\n"
"<p>In <b>manual method</b> you navigate the sky map to find the objects of interest, then capture multiple fields of view representations.</p>\n"
"<p><b>Star hopping-based method</b> automatically captures FOV snapshots using star hopping. This is experimental feature.</p>\n"
"<p>Once you have selected field of view capture method, press <b>Next</b>.</p>", nullptr));
        typeLabel->setText(tr2i18n("Field of view definition method:", nullptr));
        manualRadio->setText(tr2i18n("Manually capture field of view snapshots", nullptr));
        hopperRadio->setText(tr2i18n("Star hopper-based fields of view capture (experimental)", nullptr));
        (void)PWizFovTypeSelection;
    } // retranslateUi

};

namespace Ui {
    class PWizFovTypeSelection: public Ui_PWizFovTypeSelection {};
} // namespace Ui

QT_END_NAMESPACE

#endif // PWIZFOVTYPESELECTION_H

