/********************************************************************************
** Form generated from reading UI file 'livestackwebcast.ui'
**
** Created by: Qt User Interface Compiler version 6.11.1
**
** WARNING! All changes made in this file will be lost when recompiling UI file!
********************************************************************************/

#ifndef UI_LIVESTACKWEBCAST_H
#define UI_LIVESTACKWEBCAST_H

#include <QtCore/QVariant>
#include <QtGui/QIcon>
#include <QtWidgets/QAbstractButton>
#include <QtWidgets/QApplication>
#include <QtWidgets/QDialogButtonBox>
#include <QtWidgets/QGridLayout>
#include <QtWidgets/QHBoxLayout>
#include <QtWidgets/QHeaderView>
#include <QtWidgets/QLabel>
#include <QtWidgets/QLineEdit>
#include <QtWidgets/QPushButton>
#include <QtWidgets/QSpinBox>
#include <QtWidgets/QTableWidget>
#include <QtWidgets/QToolButton>
#include <QtWidgets/QWidget>
#include <klocalizedstring.h>

QT_BEGIN_NAMESPACE

class Ui_FitsStackWebcast
{
public:
    QGridLayout *gridLayout;
    QToolButton *logoRBtn;
    QLabel *qrLabel;
    QToolButton *logoLBtn;
    QSpinBox *throttle;
    QLabel *portLabel;
    QLabel *logoLLabel;
    QSpinBox *port;
    QHBoxLayout *horizontalLayout;
    QPushButton *startBtn;
    QPushButton *stopBtn;
    QPushButton *resetBtn;
    QPushButton *subscribersBtn;
    QDialogButtonBox *buttonBox;
    QLineEdit *logoRPathDisplay;
    QLabel *titleLabel;
    QLabel *urlLabel;
    QLineEdit *logoLPathDisplay;
    QLineEdit *titleEntry;
    QLabel *throttleLabel;
    QLabel *logoRLabel;
    QTableWidget *subscribersTable;

    void setupUi(QWidget *FitsStackWebcast)
    {
        if (FitsStackWebcast->objectName().isEmpty())
            FitsStackWebcast->setObjectName("FitsStackWebcast");
        FitsStackWebcast->resize(600, 583);
        gridLayout = new QGridLayout(FitsStackWebcast);
        gridLayout->setObjectName("gridLayout");
        logoRBtn = new QToolButton(FitsStackWebcast);
        logoRBtn->setObjectName("logoRBtn");
        QIcon icon(QIcon::fromTheme(QString::fromUtf8("document-open")));
        logoRBtn->setIcon(icon);

        gridLayout->addWidget(logoRBtn, 2, 7, 1, 1);

        qrLabel = new QLabel(FitsStackWebcast);
        qrLabel->setObjectName("qrLabel");
        qrLabel->setMinimumSize(QSize(260, 260));
        qrLabel->setFrameShape(QFrame::Box);
        qrLabel->setAlignment(Qt::AlignCenter);

        gridLayout->addWidget(qrLabel, 4, 1, 1, 7);

        logoLBtn = new QToolButton(FitsStackWebcast);
        logoLBtn->setObjectName("logoLBtn");
        logoLBtn->setIcon(icon);

        gridLayout->addWidget(logoLBtn, 1, 7, 1, 1);

        throttle = new QSpinBox(FitsStackWebcast);
        throttle->setObjectName("throttle");
        throttle->setMaximum(300);
        throttle->setValue(5);

        gridLayout->addWidget(throttle, 3, 6, 1, 2);

        portLabel = new QLabel(FitsStackWebcast);
        portLabel->setObjectName("portLabel");
        QSizePolicy sizePolicy(QSizePolicy::Policy::Fixed, QSizePolicy::Policy::Fixed);
        sizePolicy.setHorizontalStretch(0);
        sizePolicy.setVerticalStretch(0);
        sizePolicy.setHeightForWidth(portLabel->sizePolicy().hasHeightForWidth());
        portLabel->setSizePolicy(sizePolicy);

        gridLayout->addWidget(portLabel, 3, 1, 1, 1);

        logoLLabel = new QLabel(FitsStackWebcast);
        logoLLabel->setObjectName("logoLLabel");
        sizePolicy.setHeightForWidth(logoLLabel->sizePolicy().hasHeightForWidth());
        logoLLabel->setSizePolicy(sizePolicy);

        gridLayout->addWidget(logoLLabel, 1, 1, 1, 1);

        port = new QSpinBox(FitsStackWebcast);
        port->setObjectName("port");
        sizePolicy.setHeightForWidth(port->sizePolicy().hasHeightForWidth());
        port->setSizePolicy(sizePolicy);
        port->setMinimum(1024);
        port->setMaximum(65535);
        port->setValue(8080);

        gridLayout->addWidget(port, 3, 2, 1, 2);

        horizontalLayout = new QHBoxLayout();
        horizontalLayout->setObjectName("horizontalLayout");
        horizontalLayout->setSizeConstraint(QLayout::SetDefaultConstraint);
        startBtn = new QPushButton(FitsStackWebcast);
        startBtn->setObjectName("startBtn");
        sizePolicy.setHeightForWidth(startBtn->sizePolicy().hasHeightForWidth());
        startBtn->setSizePolicy(sizePolicy);

        horizontalLayout->addWidget(startBtn);

        stopBtn = new QPushButton(FitsStackWebcast);
        stopBtn->setObjectName("stopBtn");
        sizePolicy.setHeightForWidth(stopBtn->sizePolicy().hasHeightForWidth());
        stopBtn->setSizePolicy(sizePolicy);

        horizontalLayout->addWidget(stopBtn);

        resetBtn = new QPushButton(FitsStackWebcast);
        resetBtn->setObjectName("resetBtn");
        sizePolicy.setHeightForWidth(resetBtn->sizePolicy().hasHeightForWidth());
        resetBtn->setSizePolicy(sizePolicy);

        horizontalLayout->addWidget(resetBtn);

        subscribersBtn = new QPushButton(FitsStackWebcast);
        subscribersBtn->setObjectName("subscribersBtn");
        sizePolicy.setHeightForWidth(subscribersBtn->sizePolicy().hasHeightForWidth());
        subscribersBtn->setSizePolicy(sizePolicy);

        horizontalLayout->addWidget(subscribersBtn);

        buttonBox = new QDialogButtonBox(FitsStackWebcast);
        buttonBox->setObjectName("buttonBox");
        buttonBox->setStandardButtons(QDialogButtonBox::Close);

        horizontalLayout->addWidget(buttonBox);


        gridLayout->addLayout(horizontalLayout, 7, 1, 1, 7);

        logoRPathDisplay = new QLineEdit(FitsStackWebcast);
        logoRPathDisplay->setObjectName("logoRPathDisplay");

        gridLayout->addWidget(logoRPathDisplay, 2, 2, 1, 5);

        titleLabel = new QLabel(FitsStackWebcast);
        titleLabel->setObjectName("titleLabel");
        sizePolicy.setHeightForWidth(titleLabel->sizePolicy().hasHeightForWidth());
        titleLabel->setSizePolicy(sizePolicy);

        gridLayout->addWidget(titleLabel, 0, 1, 1, 1);

        urlLabel = new QLabel(FitsStackWebcast);
        urlLabel->setObjectName("urlLabel");
        QSizePolicy sizePolicy1(QSizePolicy::Policy::Preferred, QSizePolicy::Policy::Fixed);
        sizePolicy1.setHorizontalStretch(0);
        sizePolicy1.setVerticalStretch(0);
        sizePolicy1.setHeightForWidth(urlLabel->sizePolicy().hasHeightForWidth());
        urlLabel->setSizePolicy(sizePolicy1);
        urlLabel->setFrameShape(QFrame::Box);
        urlLabel->setAlignment(Qt::AlignCenter);
        urlLabel->setOpenExternalLinks(true);

        gridLayout->addWidget(urlLabel, 5, 1, 1, 7);

        logoLPathDisplay = new QLineEdit(FitsStackWebcast);
        logoLPathDisplay->setObjectName("logoLPathDisplay");

        gridLayout->addWidget(logoLPathDisplay, 1, 2, 1, 5);

        titleEntry = new QLineEdit(FitsStackWebcast);
        titleEntry->setObjectName("titleEntry");

        gridLayout->addWidget(titleEntry, 0, 2, 1, 6);

        throttleLabel = new QLabel(FitsStackWebcast);
        throttleLabel->setObjectName("throttleLabel");

        gridLayout->addWidget(throttleLabel, 3, 4, 1, 2);

        logoRLabel = new QLabel(FitsStackWebcast);
        logoRLabel->setObjectName("logoRLabel");

        gridLayout->addWidget(logoRLabel, 2, 1, 1, 1);

        subscribersTable = new QTableWidget(FitsStackWebcast);
        if (subscribersTable->columnCount() < 4)
            subscribersTable->setColumnCount(4);
        QTableWidgetItem *__qtablewidgetitem = new QTableWidgetItem();
        subscribersTable->setHorizontalHeaderItem(0, __qtablewidgetitem);
        QTableWidgetItem *__qtablewidgetitem1 = new QTableWidgetItem();
        subscribersTable->setHorizontalHeaderItem(1, __qtablewidgetitem1);
        QTableWidgetItem *__qtablewidgetitem2 = new QTableWidgetItem();
        subscribersTable->setHorizontalHeaderItem(2, __qtablewidgetitem2);
        QTableWidgetItem *__qtablewidgetitem3 = new QTableWidgetItem();
        subscribersTable->setHorizontalHeaderItem(3, __qtablewidgetitem3);
        subscribersTable->setObjectName("subscribersTable");
        QSizePolicy sizePolicy2(QSizePolicy::Policy::Preferred, QSizePolicy::Policy::Preferred);
        sizePolicy2.setHorizontalStretch(0);
        sizePolicy2.setVerticalStretch(0);
        sizePolicy2.setHeightForWidth(subscribersTable->sizePolicy().hasHeightForWidth());
        subscribersTable->setSizePolicy(sizePolicy2);
        subscribersTable->setSizeAdjustPolicy(QAbstractScrollArea::AdjustToContents);
        subscribersTable->setEditTriggers(QAbstractItemView::NoEditTriggers);
        subscribersTable->setTabKeyNavigation(false);
        subscribersTable->setProperty("showDropIndicator", QVariant(false));
        subscribersTable->setDragDropOverwriteMode(false);
        subscribersTable->setAlternatingRowColors(true);
        subscribersTable->setSelectionMode(QAbstractItemView::NoSelection);
        subscribersTable->setColumnCount(4);
        subscribersTable->horizontalHeader()->setVisible(true);
        subscribersTable->horizontalHeader()->setProperty("showSortIndicator", QVariant(true));
        subscribersTable->horizontalHeader()->setStretchLastSection(true);
        subscribersTable->verticalHeader()->setHighlightSections(false);
        subscribersTable->verticalHeader()->setStretchLastSection(false);

        gridLayout->addWidget(subscribersTable, 6, 1, 1, 7);

#if QT_CONFIG(shortcut)
        portLabel->setBuddy(port);
        logoLLabel->setBuddy(logoLPathDisplay);
        titleLabel->setBuddy(titleEntry);
        throttleLabel->setBuddy(throttle);
        logoRLabel->setBuddy(logoRPathDisplay);
#endif // QT_CONFIG(shortcut)
        QWidget::setTabOrder(titleEntry, logoLPathDisplay);
        QWidget::setTabOrder(logoLPathDisplay, logoLBtn);
        QWidget::setTabOrder(logoLBtn, logoRPathDisplay);
        QWidget::setTabOrder(logoRPathDisplay, logoRBtn);
        QWidget::setTabOrder(logoRBtn, port);
        QWidget::setTabOrder(port, throttle);
        QWidget::setTabOrder(throttle, subscribersTable);
        QWidget::setTabOrder(subscribersTable, startBtn);
        QWidget::setTabOrder(startBtn, stopBtn);
        QWidget::setTabOrder(stopBtn, resetBtn);
        QWidget::setTabOrder(resetBtn, subscribersBtn);

        retranslateUi(FitsStackWebcast);

        QMetaObject::connectSlotsByName(FitsStackWebcast);
    } // setupUi

    void retranslateUi(QWidget *FitsStackWebcast)
    {
        FitsStackWebcast->setWindowTitle(tr2i18n("KStars Live Stacker Webcast", nullptr));
#if QT_CONFIG(tooltip)
        logoRBtn->setToolTip(tr2i18n("<html><head/><body><p>Logo (Right) file chooser.</p></body></html>", nullptr));
#endif // QT_CONFIG(tooltip)
        logoRBtn->setText(QString());
#if QT_CONFIG(tooltip)
        qrLabel->setToolTip(tr2i18n("<html><head/><body><p>Start the webcast to view the QR code here</p></body></html>", nullptr));
#endif // QT_CONFIG(tooltip)
        qrLabel->setText(QString());
#if QT_CONFIG(tooltip)
        logoLBtn->setToolTip(tr2i18n("<html><head/><body><p>Logo (Left) file chooser.</p></body></html>", nullptr));
#endif // QT_CONFIG(tooltip)
        logoLBtn->setText(QString());
#if QT_CONFIG(tooltip)
        throttle->setToolTip(tr2i18n("<html><head/><body><p>Throttle updates to conserve CPU and network bandwidth. Set the number of seconds per update. More frequent updates are discarded. Set 0 for no throttle.</p></body></html>", nullptr));
#endif // QT_CONFIG(tooltip)
        throttle->setSuffix(tr2i18n(" s", nullptr));
#if QT_CONFIG(tooltip)
        portLabel->setToolTip(tr2i18n("<html><head/><body><p>Port to use for the webcast. Usually 8080 will be fine unless you have something else using this port in which case pick 8081, etc.</p></body></html>", nullptr));
#endif // QT_CONFIG(tooltip)
        portLabel->setText(tr2i18n("Port:", nullptr));
#if QT_CONFIG(tooltip)
        logoLLabel->setToolTip(tr2i18n("<html><head/><body><p>Logo (Left) for the webcast event.</p></body></html>", nullptr));
#endif // QT_CONFIG(tooltip)
        logoLLabel->setText(tr2i18n("Logo L:", nullptr));
#if QT_CONFIG(tooltip)
        port->setToolTip(tr2i18n("<html><head/><body><p>Port to use for the webcast. Usually 8080 will be fine unless you have something else using this port in which case pick 8081, etc.</p></body></html>", nullptr));
#endif // QT_CONFIG(tooltip)
#if QT_CONFIG(tooltip)
        startBtn->setToolTip(tr2i18n("<html><head/><body><p>Start the webcast</p></body></html>", nullptr));
#endif // QT_CONFIG(tooltip)
        startBtn->setText(tr2i18n("Start Webcast", nullptr));
#if QT_CONFIG(tooltip)
        stopBtn->setToolTip(tr2i18n("<html><head/><body><p>Stop the webcast</p></body></html>", nullptr));
#endif // QT_CONFIG(tooltip)
        stopBtn->setText(tr2i18n("Stop Webcast", nullptr));
#if QT_CONFIG(tooltip)
        resetBtn->setToolTip(tr2i18n("<html><head/><body><p>Reset the webcast</p></body></html>", nullptr));
#endif // QT_CONFIG(tooltip)
        resetBtn->setText(tr2i18n("Reset", nullptr));
#if QT_CONFIG(tooltip)
        subscribersBtn->setToolTip(tr2i18n("<html><head/><body><p>Toggle display of webcast subcribers</p></body></html>", nullptr));
#endif // QT_CONFIG(tooltip)
        subscribersBtn->setText(tr2i18n("Subscribers", nullptr));
#if QT_CONFIG(tooltip)
        logoRPathDisplay->setToolTip(tr2i18n("Logo (Right) for the webcast event.", nullptr));
#endif // QT_CONFIG(tooltip)
#if QT_CONFIG(tooltip)
        titleLabel->setToolTip(tr2i18n("<html><head/><body><p>Title for the webcast event.</p></body></html>", nullptr));
#endif // QT_CONFIG(tooltip)
        titleLabel->setText(tr2i18n("Title:", nullptr));
#if QT_CONFIG(tooltip)
        urlLabel->setToolTip(tr2i18n("<html><head/><body><p>Start the webcast to view the URL and port here</p></body></html>", nullptr));
#endif // QT_CONFIG(tooltip)
        urlLabel->setText(QString());
#if QT_CONFIG(tooltip)
        logoLPathDisplay->setToolTip(tr2i18n("Logo (Left) for the webcast event.", nullptr));
#endif // QT_CONFIG(tooltip)
#if QT_CONFIG(tooltip)
        titleEntry->setToolTip(tr2i18n("Title for the webcast event.", nullptr));
#endif // QT_CONFIG(tooltip)
        titleEntry->setPlaceholderText(tr2i18n("My LiveStacker Webcast", nullptr));
#if QT_CONFIG(tooltip)
        throttleLabel->setToolTip(tr2i18n("<html><head/><body><p>Throttle updates to conserve CPU and network bandwidth. Set the number of seconds per update. More frequent updates are discarded. Set 0 for no throttle.</p></body></html>", nullptr));
#endif // QT_CONFIG(tooltip)
        throttleLabel->setText(tr2i18n("Throttle Updates:", nullptr));
#if QT_CONFIG(tooltip)
        logoRLabel->setToolTip(tr2i18n("<html><head/><body><p>Logo (Right) for the webcast event.</p></body></html>", nullptr));
#endif // QT_CONFIG(tooltip)
        logoRLabel->setText(tr2i18n("Logo R:", nullptr));
        QTableWidgetItem *___qtablewidgetitem = subscribersTable->horizontalHeaderItem(0);
        ___qtablewidgetitem->setText(tr2i18n("IP", nullptr));
        QTableWidgetItem *___qtablewidgetitem1 = subscribersTable->horizontalHeaderItem(1);
        ___qtablewidgetitem1->setText(tr2i18n("Name", nullptr));
        QTableWidgetItem *___qtablewidgetitem2 = subscribersTable->horizontalHeaderItem(2);
        ___qtablewidgetitem2->setText(tr2i18n("Device", nullptr));
        QTableWidgetItem *___qtablewidgetitem3 = subscribersTable->horizontalHeaderItem(3);
        ___qtablewidgetitem3->setText(tr2i18n("Activity", nullptr));
    } // retranslateUi

};

namespace Ui {
    class FitsStackWebcast: public Ui_FitsStackWebcast {};
} // namespace Ui

QT_END_NAMESPACE

#endif // LIVESTACKWEBCAST_H

