/****************************************************************************
** Meta object code from reading C++ file 'execute.h'
**
** Created by: The Qt Meta Object Compiler version 69 (Qt 6.11.1)
**
** WARNING! All changes made in this file will be lost!
*****************************************************************************/

#include "../../../../kstars-3.8.4.1/kstars/oal/execute.h"
#include <QtCore/qmetatype.h>

#include <QtCore/qtmochelpers.h>

#include <memory>


#include <QtCore/qxptype_traits.h>
#if !defined(Q_MOC_OUTPUT_REVISION)
#error "The header file 'execute.h' doesn't include <QObject>."
#elif Q_MOC_OUTPUT_REVISION != 69
#error "This file was generated using the moc from 6.11.1. It"
#error "cannot be used with the include files from this version of Qt."
#error "(The moc has changed too much.)"
#endif

#ifndef Q_CONSTINIT
#define Q_CONSTINIT
#endif

QT_WARNING_PUSH
QT_WARNING_DISABLE_DEPRECATED
QT_WARNING_DISABLE_GCC("-Wuseless-cast")
namespace {
struct qt_meta_tag_ZN7ExecuteE_t {};
} // unnamed namespace

template <> constexpr inline auto Execute::qt_create_metaobjectdata<qt_meta_tag_ZN7ExecuteE_t>()
{
    namespace QMC = QtMocConstants;
    QtMocHelpers::StringRefStorage qt_stringData {
        "Execute",
        "slotNext",
        "",
        "saveSession",
        "addTargetNotes",
        "slotObserverAdd",
        "addObservation",
        "slotEndSession",
        "slotLocation",
        "loadTargets",
        "sortTargetList",
        "slotSetTarget",
        "name",
        "loadEquipment",
        "loadObservers",
        "loadObservationTab",
        "getObjectName",
        "const SkyObject*",
        "o",
        "translated",
        "selectNextTarget",
        "loadCurrentItems",
        "slotSetCurrentObjects",
        "slotSlew",
        "slotShowSession",
        "slotShowTargets",
        "findIndexOfTarget",
        "slotAddObject",
        "slotRemoveObject"
    };

    QtMocHelpers::UintData qt_methods {
        // Slot 'slotNext'
        QtMocHelpers::SlotData<void()>(1, 2, QMC::AccessPublic, QMetaType::Void),
        // Slot 'saveSession'
        QtMocHelpers::SlotData<bool()>(3, 2, QMC::AccessPublic, QMetaType::Bool),
        // Slot 'addTargetNotes'
        QtMocHelpers::SlotData<void()>(4, 2, QMC::AccessPublic, QMetaType::Void),
        // Slot 'slotObserverAdd'
        QtMocHelpers::SlotData<void()>(5, 2, QMC::AccessPublic, QMetaType::Void),
        // Slot 'addObservation'
        QtMocHelpers::SlotData<bool()>(6, 2, QMC::AccessPublic, QMetaType::Bool),
        // Slot 'slotEndSession'
        QtMocHelpers::SlotData<void()>(7, 2, QMC::AccessPublic, QMetaType::Void),
        // Slot 'slotLocation'
        QtMocHelpers::SlotData<void()>(8, 2, QMC::AccessPublic, QMetaType::Void),
        // Slot 'loadTargets'
        QtMocHelpers::SlotData<void()>(9, 2, QMC::AccessPublic, QMetaType::Void),
        // Slot 'sortTargetList'
        QtMocHelpers::SlotData<void()>(10, 2, QMC::AccessPublic, QMetaType::Void),
        // Slot 'slotSetTarget'
        QtMocHelpers::SlotData<void(const QString &)>(11, 2, QMC::AccessPublic, QMetaType::Void, {{
            { QMetaType::QString, 12 },
        }}),
        // Slot 'loadEquipment'
        QtMocHelpers::SlotData<void()>(13, 2, QMC::AccessPublic, QMetaType::Void),
        // Slot 'loadObservers'
        QtMocHelpers::SlotData<void()>(14, 2, QMC::AccessPublic, QMetaType::Void),
        // Slot 'loadObservationTab'
        QtMocHelpers::SlotData<void()>(15, 2, QMC::AccessPublic, QMetaType::Void),
        // Slot 'getObjectName'
        QtMocHelpers::SlotData<QString(const SkyObject *, bool)>(16, 2, QMC::AccessPublic, QMetaType::QString, {{
            { 0x80000000 | 17, 18 }, { QMetaType::Bool, 19 },
        }}),
        // Slot 'getObjectName'
        QtMocHelpers::SlotData<QString(const SkyObject *)>(16, 2, QMC::AccessPublic | QMC::MethodCloned, QMetaType::QString, {{
            { 0x80000000 | 17, 18 },
        }}),
        // Slot 'selectNextTarget'
        QtMocHelpers::SlotData<void()>(20, 2, QMC::AccessPublic, QMetaType::Void),
        // Slot 'loadCurrentItems'
        QtMocHelpers::SlotData<void()>(21, 2, QMC::AccessPublic, QMetaType::Void),
        // Slot 'slotSetCurrentObjects'
        QtMocHelpers::SlotData<void()>(22, 2, QMC::AccessPublic, QMetaType::Void),
        // Slot 'slotSlew'
        QtMocHelpers::SlotData<void()>(23, 2, QMC::AccessPublic, QMetaType::Void),
        // Slot 'slotShowSession'
        QtMocHelpers::SlotData<void()>(24, 2, QMC::AccessPublic, QMetaType::Void),
        // Slot 'slotShowTargets'
        QtMocHelpers::SlotData<void()>(25, 2, QMC::AccessPublic, QMetaType::Void),
        // Slot 'findIndexOfTarget'
        QtMocHelpers::SlotData<int(QString)>(26, 2, QMC::AccessPublic, QMetaType::Int, {{
            { QMetaType::QString, 2 },
        }}),
        // Slot 'slotAddObject'
        QtMocHelpers::SlotData<void()>(27, 2, QMC::AccessPublic, QMetaType::Void),
        // Slot 'slotRemoveObject'
        QtMocHelpers::SlotData<void()>(28, 2, QMC::AccessPublic, QMetaType::Void),
    };
    QtMocHelpers::UintData qt_properties {
    };
    QtMocHelpers::UintData qt_enums {
    };
    return QtMocHelpers::metaObjectData<Execute, qt_meta_tag_ZN7ExecuteE_t>(QMC::MetaObjectFlag{}, qt_stringData,
            qt_methods, qt_properties, qt_enums);
}
Q_CONSTINIT const QMetaObject Execute::staticMetaObject = { {
    QMetaObject::SuperData::link<QDialog::staticMetaObject>(),
    qt_staticMetaObjectStaticContent<qt_meta_tag_ZN7ExecuteE_t>.stringdata,
    qt_staticMetaObjectStaticContent<qt_meta_tag_ZN7ExecuteE_t>.data,
    qt_static_metacall,
    nullptr,
    qt_staticMetaObjectRelocatingContent<qt_meta_tag_ZN7ExecuteE_t>.metaTypes,
    nullptr
} };

void Execute::qt_static_metacall(QObject *_o, QMetaObject::Call _c, int _id, void **_a)
{
    auto *_t = static_cast<Execute *>(_o);
    if (_c == QMetaObject::InvokeMetaMethod) {
        switch (_id) {
        case 0: _t->slotNext(); break;
        case 1: { bool _r = _t->saveSession();
            if (_a[0]) *reinterpret_cast<bool*>(_a[0]) = std::move(_r); }  break;
        case 2: _t->addTargetNotes(); break;
        case 3: _t->slotObserverAdd(); break;
        case 4: { bool _r = _t->addObservation();
            if (_a[0]) *reinterpret_cast<bool*>(_a[0]) = std::move(_r); }  break;
        case 5: _t->slotEndSession(); break;
        case 6: _t->slotLocation(); break;
        case 7: _t->loadTargets(); break;
        case 8: _t->sortTargetList(); break;
        case 9: _t->slotSetTarget((*reinterpret_cast<std::add_pointer_t<QString>>(_a[1]))); break;
        case 10: _t->loadEquipment(); break;
        case 11: _t->loadObservers(); break;
        case 12: _t->loadObservationTab(); break;
        case 13: { QString _r = _t->getObjectName((*reinterpret_cast<std::add_pointer_t<const SkyObject*>>(_a[1])),(*reinterpret_cast<std::add_pointer_t<bool>>(_a[2])));
            if (_a[0]) *reinterpret_cast<QString*>(_a[0]) = std::move(_r); }  break;
        case 14: { QString _r = _t->getObjectName((*reinterpret_cast<std::add_pointer_t<const SkyObject*>>(_a[1])));
            if (_a[0]) *reinterpret_cast<QString*>(_a[0]) = std::move(_r); }  break;
        case 15: _t->selectNextTarget(); break;
        case 16: _t->loadCurrentItems(); break;
        case 17: _t->slotSetCurrentObjects(); break;
        case 18: _t->slotSlew(); break;
        case 19: _t->slotShowSession(); break;
        case 20: _t->slotShowTargets(); break;
        case 21: { int _r = _t->findIndexOfTarget((*reinterpret_cast<std::add_pointer_t<QString>>(_a[1])));
            if (_a[0]) *reinterpret_cast<int*>(_a[0]) = std::move(_r); }  break;
        case 22: _t->slotAddObject(); break;
        case 23: _t->slotRemoveObject(); break;
        default: ;
        }
    }
}

const QMetaObject *Execute::metaObject() const
{
    return QObject::d_ptr->metaObject ? QObject::d_ptr->dynamicMetaObject() : &staticMetaObject;
}

void *Execute::qt_metacast(const char *_clname)
{
    if (!_clname) return nullptr;
    if (!strcmp(_clname, qt_staticMetaObjectStaticContent<qt_meta_tag_ZN7ExecuteE_t>.strings))
        return static_cast<void*>(this);
    return QDialog::qt_metacast(_clname);
}

int Execute::qt_metacall(QMetaObject::Call _c, int _id, void **_a)
{
    _id = QDialog::qt_metacall(_c, _id, _a);
    if (_id < 0)
        return _id;
    if (_c == QMetaObject::InvokeMetaMethod) {
        if (_id < 24)
            qt_static_metacall(this, _c, _id, _a);
        _id -= 24;
    }
    if (_c == QMetaObject::RegisterMethodArgumentMetaType) {
        if (_id < 24)
            *reinterpret_cast<QMetaType *>(_a[0]) = QMetaType();
        _id -= 24;
    }
    return _id;
}
QT_WARNING_POP
