/****************************************************************************
** Meta object code from reading C++ file 'manager.h'
**
** Created by: The Qt Meta Object Compiler version 69 (Qt 6.11.1)
**
** WARNING! All changes made in this file will be lost!
*****************************************************************************/

#include "../../../../kstars-3.8.4.1/kstars/ekos/manager.h"
#include <QtNetwork/QSslError>
#include <QtDataVisualization/qbar3dseries.h>
#include <QtDataVisualization/q3dscene.h>
#include <QtGui/qtextcursor.h>
#include <QtCore/qmetatype.h>
#include <QtCore/QSharedPointer>

#include <QtCore/qtmochelpers.h>

#include <memory>


#include <QtCore/qxptype_traits.h>
#if !defined(Q_MOC_OUTPUT_REVISION)
#error "The header file 'manager.h' doesn't include <QObject>."
#elif Q_MOC_OUTPUT_REVISION != 69
#error "This file was generated using the moc from 6.11.1. It"
#error "cannot be used with the include files from this version of Qt."
#error "(The moc has changed too much.)"
#endif

#ifndef Q_CONSTINIT
#define Q_CONSTINIT
#endif

QT_WARNING_PUSH
QT_WARNING_DISABLE_DEPRECATED
QT_WARNING_DISABLE_GCC("-Wuseless-cast")
namespace {
struct qt_meta_tag_ZN4Ekos7ManagerE_t {};
} // unnamed namespace

template <> constexpr inline auto Ekos::Manager::qt_create_metaobjectdata<qt_meta_tag_ZN4Ekos7ManagerE_t>()
{
    namespace QMC = QtMocConstants;
    QtMocHelpers::StringRefStorage qt_stringData {
        "Ekos::Manager",
        "D-Bus Interface",
        "org.kde.kstars.Ekos",
        "ekosStatusChanged",
        "",
        "Ekos::CommunicationStatus",
        "status",
        "indiStatusChanged",
        "settleStatusChanged",
        "ekosLiveStatusChanged",
        "extensionStatusChanged",
        "newLog",
        "text",
        "newModule",
        "name",
        "newDevice",
        "interface",
        "connectDevices",
        "Q_NOREPLY",
        "disconnectDevices",
        "setFITSfromFile",
        "previewFromFile",
        "previewFile",
        "filePath",
        "processINDI",
        "cleanDevices",
        "stopDrivers",
        "processNewDevice",
        "QSharedPointer<ISD::GenericDevice>",
        "device",
        "processNewProperty",
        "INDI::Property",
        "processUpdateProperty",
        "processDeleteProperty",
        "processMessage",
        "message",
        "setDeviceReady",
        "restartDriver",
        "deviceName",
        "changeAlwaysOnTop",
        "Qt::ApplicationState",
        "state",
        "showEkosOptions",
        "updateLog",
        "clearLog",
        "processTabChange",
        "setServerStarted",
        "host",
        "port",
        "setServerFailed",
        "setClientStarted",
        "setClientFailed",
        "setClientTerminated",
        "removeDevice",
        "deviceConnected",
        "deviceDisconnected",
        "checkINDITimeout",
        "updateDebugInterfaces",
        "watchDebugProperty",
        "prop",
        "addMount",
        "ISD::Mount*",
        "addCamera",
        "ISD::Camera*",
        "addFilterWheel",
        "ISD::FilterWheel*",
        "addFocuser",
        "ISD::Focuser*",
        "addRotator",
        "ISD::Rotator*",
        "addDome",
        "ISD::Dome*",
        "addWeather",
        "ISD::Weather*",
        "addDustCap",
        "ISD::DustCap*",
        "addLightBox",
        "ISD::LightBox*",
        "addGuider",
        "ISD::Guider*",
        "addGPS",
        "ISD::GPS*",
        "addPAC",
        "ISD::PAC*",
        "createModulesForDevice",
        "bindDeviceToModules",
        "addProfile",
        "editProfile",
        "deleteProfile",
        "wizardProfile",
        "updateMountCoords",
        "SkyPoint",
        "position",
        "ISD::Mount::PierSide",
        "pierSide",
        "dms",
        "ha",
        "updateMountStatus",
        "ISD::Mount::Status",
        "setTarget",
        "updateCaptureStatus",
        "CaptureState",
        "trainname",
        "updateCaptureProgress",
        "QSharedPointer<SequenceJob>",
        "job",
        "QSharedPointer<FITSData>",
        "data",
        "devicename",
        "updateExposureProgress",
        "updateCaptureCountDown",
        "updateFocusStatus",
        "FocusState",
        "updateCurrentHFR",
        "newHFR",
        "inAutofocus",
        "updateGuideStatus",
        "GuideState",
        "updateSigmas",
        "ra",
        "de",
        "help",
        "setProfile",
        "profileName",
        "getProfiles",
        "profileJSON",
        "getProfile",
        "getINDIConnectionStatus",
        "indiStatus",
        "getEkosStartingStatus",
        "ekosStatus",
        "settleStatus",
        "setEkosLoggingEnabled",
        "enabled",
        "start",
        "stop",
        "logText",
        "ekosLiveStatus",
        "extensionStatus",
        "Ekos::ExtensionState",
        "setEkosLiveConnected",
        "setEkosLiveConfig",
        "rememberCredentials",
        "autoConnect",
        "setEkosLiveUser",
        "username",
        "password",
        "acceptPortSelection"
    };

    QtMocHelpers::UintData qt_methods {
        // Signal 'ekosStatusChanged'
        QtMocHelpers::SignalData<void(Ekos::CommunicationStatus)>(3, 4, QMC::AccessPublic, QMetaType::Void, {{
            { 0x80000000 | 5, 6 },
        }}),
        // Signal 'indiStatusChanged'
        QtMocHelpers::SignalData<void(Ekos::CommunicationStatus)>(7, 4, QMC::AccessPublic, QMetaType::Void, {{
            { 0x80000000 | 5, 6 },
        }}),
        // Signal 'settleStatusChanged'
        QtMocHelpers::SignalData<void(Ekos::CommunicationStatus)>(8, 4, QMC::AccessPublic, QMetaType::Void, {{
            { 0x80000000 | 5, 6 },
        }}),
        // Signal 'ekosLiveStatusChanged'
        QtMocHelpers::SignalData<void(bool)>(9, 4, QMC::AccessPublic, QMetaType::Void, {{
            { QMetaType::Bool, 6 },
        }}),
        // Signal 'extensionStatusChanged'
        QtMocHelpers::SignalData<void(bool)>(10, 4, QMC::AccessPublic, QMetaType::Void, {{
            { QMetaType::Bool, 4 },
        }}),
        // Signal 'extensionStatusChanged'
        QtMocHelpers::SignalData<void()>(10, 4, QMC::AccessPublic | QMC::MethodCloned, QMetaType::Void),
        // Signal 'newLog'
        QtMocHelpers::SignalData<void(const QString &)>(11, 4, QMC::AccessPublic, QMetaType::Void, {{
            { QMetaType::QString, 12 },
        }}),
        // Signal 'newModule'
        QtMocHelpers::SignalData<void(const QString &)>(13, 4, QMC::AccessPublic, QMetaType::Void, {{
            { QMetaType::QString, 14 },
        }}),
        // Signal 'newDevice'
        QtMocHelpers::SignalData<void(const QString &, int)>(15, 4, QMC::AccessPublic, QMetaType::Void, {{
            { QMetaType::QString, 14 }, { QMetaType::Int, 16 },
        }}),
        // Slot 'connectDevices'
        QtMocHelpers::SlotData<void()>(17, 18, QMC::AccessPublic | QMC::MethodScriptable, QMetaType::Void),
        // Slot 'disconnectDevices'
        QtMocHelpers::SlotData<void()>(19, 18, QMC::AccessPublic | QMC::MethodScriptable, QMetaType::Void),
        // Slot 'setFITSfromFile'
        QtMocHelpers::SlotData<void(bool)>(20, 18, QMC::AccessPublic | QMC::MethodScriptable, QMetaType::Void, {{
            { QMetaType::Bool, 21 },
        }}),
        // Slot 'previewFile'
        QtMocHelpers::SlotData<void(QString)>(22, 18, QMC::AccessPublic | QMC::MethodScriptable, QMetaType::Void, {{
            { QMetaType::QString, 23 },
        }}),
        // Slot 'processINDI'
        QtMocHelpers::SlotData<void()>(24, 4, QMC::AccessPublic, QMetaType::Void),
        // Slot 'cleanDevices'
        QtMocHelpers::SlotData<void(bool)>(25, 4, QMC::AccessPublic, QMetaType::Void, {{
            { QMetaType::Bool, 26 },
        }}),
        // Slot 'cleanDevices'
        QtMocHelpers::SlotData<void()>(25, 4, QMC::AccessPublic | QMC::MethodCloned, QMetaType::Void),
        // Slot 'processNewDevice'
        QtMocHelpers::SlotData<void(const QSharedPointer<ISD::GenericDevice> &)>(27, 4, QMC::AccessPublic, QMetaType::Void, {{
            { 0x80000000 | 28, 29 },
        }}),
        // Slot 'processNewProperty'
        QtMocHelpers::SlotData<void(INDI::Property)>(30, 4, QMC::AccessPublic, QMetaType::Void, {{
            { 0x80000000 | 31, 4 },
        }}),
        // Slot 'processUpdateProperty'
        QtMocHelpers::SlotData<void(INDI::Property)>(32, 4, QMC::AccessPublic, QMetaType::Void, {{
            { 0x80000000 | 31, 4 },
        }}),
        // Slot 'processDeleteProperty'
        QtMocHelpers::SlotData<void(INDI::Property)>(33, 4, QMC::AccessPublic, QMetaType::Void, {{
            { 0x80000000 | 31, 4 },
        }}),
        // Slot 'processMessage'
        QtMocHelpers::SlotData<void(const QString &)>(34, 4, QMC::AccessPublic, QMetaType::Void, {{
            { QMetaType::QString, 35 },
        }}),
        // Slot 'setDeviceReady'
        QtMocHelpers::SlotData<void()>(36, 4, QMC::AccessPublic, QMetaType::Void),
        // Slot 'restartDriver'
        QtMocHelpers::SlotData<void(const QString &)>(37, 4, QMC::AccessPublic, QMetaType::Void, {{
            { QMetaType::QString, 38 },
        }}),
        // Slot 'changeAlwaysOnTop'
        QtMocHelpers::SlotData<void(Qt::ApplicationState)>(39, 4, QMC::AccessPrivate, QMetaType::Void, {{
            { 0x80000000 | 40, 41 },
        }}),
        // Slot 'showEkosOptions'
        QtMocHelpers::SlotData<void()>(42, 4, QMC::AccessPrivate, QMetaType::Void),
        // Slot 'updateLog'
        QtMocHelpers::SlotData<void()>(43, 4, QMC::AccessPrivate, QMetaType::Void),
        // Slot 'clearLog'
        QtMocHelpers::SlotData<void()>(44, 4, QMC::AccessPrivate, QMetaType::Void),
        // Slot 'processTabChange'
        QtMocHelpers::SlotData<void()>(45, 4, QMC::AccessPrivate, QMetaType::Void),
        // Slot 'setServerStarted'
        QtMocHelpers::SlotData<void(const QString &, int)>(46, 4, QMC::AccessPrivate, QMetaType::Void, {{
            { QMetaType::QString, 47 }, { QMetaType::Int, 48 },
        }}),
        // Slot 'setServerFailed'
        QtMocHelpers::SlotData<void(const QString &, int, const QString &)>(49, 4, QMC::AccessPrivate, QMetaType::Void, {{
            { QMetaType::QString, 47 }, { QMetaType::Int, 48 }, { QMetaType::QString, 35 },
        }}),
        // Slot 'setClientStarted'
        QtMocHelpers::SlotData<void(const QString &, int)>(50, 4, QMC::AccessPrivate, QMetaType::Void, {{
            { QMetaType::QString, 47 }, { QMetaType::Int, 48 },
        }}),
        // Slot 'setClientFailed'
        QtMocHelpers::SlotData<void(const QString &, int, const QString &)>(51, 4, QMC::AccessPrivate, QMetaType::Void, {{
            { QMetaType::QString, 47 }, { QMetaType::Int, 48 }, { QMetaType::QString, 35 },
        }}),
        // Slot 'setClientTerminated'
        QtMocHelpers::SlotData<void(const QString &, int, const QString &)>(52, 4, QMC::AccessPrivate, QMetaType::Void, {{
            { QMetaType::QString, 47 }, { QMetaType::Int, 48 }, { QMetaType::QString, 35 },
        }}),
        // Slot 'removeDevice'
        QtMocHelpers::SlotData<void(const QSharedPointer<ISD::GenericDevice> &)>(53, 4, QMC::AccessPrivate, QMetaType::Void, {{
            { 0x80000000 | 28, 29 },
        }}),
        // Slot 'deviceConnected'
        QtMocHelpers::SlotData<void()>(54, 4, QMC::AccessPrivate, QMetaType::Void),
        // Slot 'deviceDisconnected'
        QtMocHelpers::SlotData<void()>(55, 4, QMC::AccessPrivate, QMetaType::Void),
        // Slot 'checkINDITimeout'
        QtMocHelpers::SlotData<void()>(56, 4, QMC::AccessPrivate, QMetaType::Void),
        // Slot 'updateDebugInterfaces'
        QtMocHelpers::SlotData<void()>(57, 4, QMC::AccessPrivate, QMetaType::Void),
        // Slot 'watchDebugProperty'
        QtMocHelpers::SlotData<void(INDI::Property)>(58, 4, QMC::AccessPrivate, QMetaType::Void, {{
            { 0x80000000 | 31, 59 },
        }}),
        // Slot 'addMount'
        QtMocHelpers::SlotData<void(ISD::Mount *)>(60, 4, QMC::AccessPrivate, QMetaType::Void, {{
            { 0x80000000 | 61, 29 },
        }}),
        // Slot 'addCamera'
        QtMocHelpers::SlotData<void(ISD::Camera *)>(62, 4, QMC::AccessPrivate, QMetaType::Void, {{
            { 0x80000000 | 63, 29 },
        }}),
        // Slot 'addFilterWheel'
        QtMocHelpers::SlotData<void(ISD::FilterWheel *)>(64, 4, QMC::AccessPrivate, QMetaType::Void, {{
            { 0x80000000 | 65, 29 },
        }}),
        // Slot 'addFocuser'
        QtMocHelpers::SlotData<void(ISD::Focuser *)>(66, 4, QMC::AccessPrivate, QMetaType::Void, {{
            { 0x80000000 | 67, 29 },
        }}),
        // Slot 'addRotator'
        QtMocHelpers::SlotData<void(ISD::Rotator *)>(68, 4, QMC::AccessPrivate, QMetaType::Void, {{
            { 0x80000000 | 69, 29 },
        }}),
        // Slot 'addDome'
        QtMocHelpers::SlotData<void(ISD::Dome *)>(70, 4, QMC::AccessPrivate, QMetaType::Void, {{
            { 0x80000000 | 71, 29 },
        }}),
        // Slot 'addWeather'
        QtMocHelpers::SlotData<void(ISD::Weather *)>(72, 4, QMC::AccessPrivate, QMetaType::Void, {{
            { 0x80000000 | 73, 29 },
        }}),
        // Slot 'addDustCap'
        QtMocHelpers::SlotData<void(ISD::DustCap *)>(74, 4, QMC::AccessPrivate, QMetaType::Void, {{
            { 0x80000000 | 75, 29 },
        }}),
        // Slot 'addLightBox'
        QtMocHelpers::SlotData<void(ISD::LightBox *)>(76, 4, QMC::AccessPrivate, QMetaType::Void, {{
            { 0x80000000 | 77, 29 },
        }}),
        // Slot 'addGuider'
        QtMocHelpers::SlotData<void(ISD::Guider *)>(78, 4, QMC::AccessPrivate, QMetaType::Void, {{
            { 0x80000000 | 79, 29 },
        }}),
        // Slot 'addGPS'
        QtMocHelpers::SlotData<void(ISD::GPS *)>(80, 4, QMC::AccessPrivate, QMetaType::Void, {{
            { 0x80000000 | 81, 29 },
        }}),
        // Slot 'addPAC'
        QtMocHelpers::SlotData<void(ISD::PAC *)>(82, 4, QMC::AccessPrivate, QMetaType::Void, {{
            { 0x80000000 | 83, 29 },
        }}),
        // Slot 'createModulesForDevice'
        QtMocHelpers::SlotData<void(const QSharedPointer<ISD::GenericDevice> &)>(84, 4, QMC::AccessPrivate, QMetaType::Void, {{
            { 0x80000000 | 28, 29 },
        }}),
        // Slot 'bindDeviceToModules'
        QtMocHelpers::SlotData<void(const QSharedPointer<ISD::GenericDevice> &)>(85, 4, QMC::AccessPrivate, QMetaType::Void, {{
            { 0x80000000 | 28, 29 },
        }}),
        // Slot 'addProfile'
        QtMocHelpers::SlotData<void()>(86, 4, QMC::AccessPrivate, QMetaType::Void),
        // Slot 'editProfile'
        QtMocHelpers::SlotData<void()>(87, 4, QMC::AccessPrivate, QMetaType::Void),
        // Slot 'deleteProfile'
        QtMocHelpers::SlotData<void()>(88, 4, QMC::AccessPrivate, QMetaType::Void),
        // Slot 'wizardProfile'
        QtMocHelpers::SlotData<void()>(89, 4, QMC::AccessPrivate, QMetaType::Void),
        // Slot 'updateMountCoords'
        QtMocHelpers::SlotData<void(const SkyPoint, ISD::Mount::PierSide, const dms &)>(90, 4, QMC::AccessPrivate, QMetaType::Void, {{
            { 0x80000000 | 91, 92 }, { 0x80000000 | 93, 94 }, { 0x80000000 | 95, 96 },
        }}),
        // Slot 'updateMountStatus'
        QtMocHelpers::SlotData<void(ISD::Mount::Status)>(97, 4, QMC::AccessPrivate, QMetaType::Void, {{
            { 0x80000000 | 98, 6 },
        }}),
        // Slot 'setTarget'
        QtMocHelpers::SlotData<void(const QString &)>(99, 4, QMC::AccessPrivate, QMetaType::Void, {{
            { QMetaType::QString, 14 },
        }}),
        // Slot 'updateCaptureStatus'
        QtMocHelpers::SlotData<void(CaptureState, const QString &)>(100, 4, QMC::AccessPrivate, QMetaType::Void, {{
            { 0x80000000 | 101, 6 }, { QMetaType::QString, 102 },
        }}),
        // Slot 'updateCaptureProgress'
        QtMocHelpers::SlotData<void(const QSharedPointer<SequenceJob> &, const QSharedPointer<FITSData> &, const QString &)>(103, 4, QMC::AccessPrivate, QMetaType::Void, {{
            { 0x80000000 | 104, 105 }, { 0x80000000 | 106, 107 }, { QMetaType::QString, 108 },
        }}),
        // Slot 'updateCaptureProgress'
        QtMocHelpers::SlotData<void(const QSharedPointer<SequenceJob> &, const QSharedPointer<FITSData> &)>(103, 4, QMC::AccessPrivate | QMC::MethodCloned, QMetaType::Void, {{
            { 0x80000000 | 104, 105 }, { 0x80000000 | 106, 107 },
        }}),
        // Slot 'updateExposureProgress'
        QtMocHelpers::SlotData<void(const QSharedPointer<SequenceJob> &, const QString &)>(109, 4, QMC::AccessPrivate, QMetaType::Void, {{
            { 0x80000000 | 104, 105 }, { QMetaType::QString, 102 },
        }}),
        // Slot 'updateCaptureCountDown'
        QtMocHelpers::SlotData<void()>(110, 4, QMC::AccessPrivate, QMetaType::Void),
        // Slot 'updateFocusStatus'
        QtMocHelpers::SlotData<void(FocusState)>(111, 4, QMC::AccessPrivate, QMetaType::Void, {{
            { 0x80000000 | 112, 6 },
        }}),
        // Slot 'updateCurrentHFR'
        QtMocHelpers::SlotData<void(double, int, bool)>(113, 4, QMC::AccessPrivate, QMetaType::Void, {{
            { QMetaType::Double, 114 }, { QMetaType::Int, 92 }, { QMetaType::Bool, 115 },
        }}),
        // Slot 'updateGuideStatus'
        QtMocHelpers::SlotData<void(GuideState)>(116, 4, QMC::AccessPrivate, QMetaType::Void, {{
            { 0x80000000 | 117, 6 },
        }}),
        // Slot 'updateSigmas'
        QtMocHelpers::SlotData<void(double, double)>(118, 4, QMC::AccessPrivate, QMetaType::Void, {{
            { QMetaType::Double, 119 }, { QMetaType::Double, 120 },
        }}),
        // Slot 'help'
        QtMocHelpers::SlotData<void()>(121, 4, QMC::AccessPrivate, QMetaType::Void),
        // Method 'setProfile'
        QtMocHelpers::MethodData<bool(const QString &)>(122, 4, QMC::AccessPublic | QMC::MethodScriptable, QMetaType::Bool, {{
            { QMetaType::QString, 123 },
        }}),
        // Method 'getProfiles'
        QtMocHelpers::MethodData<QStringList()>(124, 4, QMC::AccessPublic | QMC::MethodScriptable, QMetaType::QStringList),
        // Method 'addProfile'
        QtMocHelpers::MethodData<void(const QString &)>(86, 18, QMC::AccessPublic | QMC::MethodScriptable, QMetaType::Void, {{
            { QMetaType::QString, 125 },
        }}),
        // Method 'editProfile'
        QtMocHelpers::MethodData<void(const QString &)>(87, 18, QMC::AccessPublic | QMC::MethodScriptable, QMetaType::Void, {{
            { QMetaType::QString, 125 },
        }}),
        // Method 'deleteProfile'
        QtMocHelpers::MethodData<void(const QString &)>(88, 18, QMC::AccessPublic | QMC::MethodScriptable, QMetaType::Void, {{
            { QMetaType::QString, 14 },
        }}),
        // Method 'getProfile'
        QtMocHelpers::MethodData<QString(const QString &)>(126, 4, QMC::AccessPublic | QMC::MethodScriptable, QMetaType::QString, {{
            { QMetaType::QString, 14 },
        }}),
        // Method 'getINDIConnectionStatus'
        QtMocHelpers::MethodData<unsigned int()>(127, 4, QMC::AccessPublic | QMC::MethodScriptable, QMetaType::UInt),
        // Method 'indiStatus'
        QtMocHelpers::MethodData<Ekos::CommunicationStatus()>(128, 4, QMC::AccessPublic | QMC::MethodScriptable, 0x80000000 | 5),
        // Method 'getEkosStartingStatus'
        QtMocHelpers::MethodData<unsigned int()>(129, 4, QMC::AccessPublic | QMC::MethodScriptable, QMetaType::UInt),
        // Method 'ekosStatus'
        QtMocHelpers::MethodData<Ekos::CommunicationStatus()>(130, 4, QMC::AccessPublic | QMC::MethodScriptable, 0x80000000 | 5),
        // Method 'settleStatus'
        QtMocHelpers::MethodData<Ekos::CommunicationStatus()>(131, 4, QMC::AccessPublic | QMC::MethodScriptable, 0x80000000 | 5),
        // Method 'setEkosLoggingEnabled'
        QtMocHelpers::MethodData<void(const QString &, bool)>(132, 18, QMC::AccessPublic | QMC::MethodScriptable, QMetaType::Void, {{
            { QMetaType::QString, 14 }, { QMetaType::Bool, 133 },
        }}),
        // Method 'start'
        QtMocHelpers::MethodData<void()>(134, 4, QMC::AccessPublic | QMC::MethodScriptable, QMetaType::Void),
        // Method 'stop'
        QtMocHelpers::MethodData<void()>(135, 4, QMC::AccessPublic | QMC::MethodScriptable, QMetaType::Void),
        // Method 'logText'
        QtMocHelpers::MethodData<QStringList()>(136, 4, QMC::AccessPublic | QMC::MethodScriptable, QMetaType::QStringList),
        // Method 'ekosLiveStatus'
        QtMocHelpers::MethodData<bool()>(137, 4, QMC::AccessPublic | QMC::MethodScriptable, QMetaType::Bool),
        // Method 'extensionStatus'
        QtMocHelpers::MethodData<Ekos::ExtensionState()>(138, 4, QMC::AccessPublic | QMC::MethodScriptable, 0x80000000 | 139),
        // Method 'setEkosLiveConnected'
        QtMocHelpers::MethodData<void(bool)>(140, 4, QMC::AccessPublic | QMC::MethodScriptable, QMetaType::Void, {{
            { QMetaType::Bool, 133 },
        }}),
        // Method 'setEkosLiveConfig'
        QtMocHelpers::MethodData<void(bool, bool)>(141, 4, QMC::AccessPublic | QMC::MethodScriptable, QMetaType::Void, {{
            { QMetaType::Bool, 142 }, { QMetaType::Bool, 143 },
        }}),
        // Method 'setEkosLiveUser'
        QtMocHelpers::MethodData<void(const QString &, const QString &)>(144, 4, QMC::AccessPublic | QMC::MethodScriptable, QMetaType::Void, {{
            { QMetaType::QString, 145 }, { QMetaType::QString, 146 },
        }}),
        // Method 'acceptPortSelection'
        QtMocHelpers::MethodData<void()>(147, 4, QMC::AccessPublic | QMC::MethodScriptable, QMetaType::Void),
    };
    QtMocHelpers::UintData qt_properties {
        // property 'indiStatus'
        QtMocHelpers::PropertyData<Ekos::CommunicationStatus>(128, 0x80000000 | 5, QMC::DefaultPropertyFlags | QMC::EnumOrFlag, 1),
        // property 'ekosStatus'
        QtMocHelpers::PropertyData<Ekos::CommunicationStatus>(130, 0x80000000 | 5, QMC::DefaultPropertyFlags | QMC::EnumOrFlag, 0),
        // property 'settleStatus'
        QtMocHelpers::PropertyData<Ekos::CommunicationStatus>(131, 0x80000000 | 5, QMC::DefaultPropertyFlags | QMC::EnumOrFlag, 2),
        // property 'ekosLiveStatus'
        QtMocHelpers::PropertyData<bool>(137, QMetaType::Bool, QMC::DefaultPropertyFlags, 3),
        // property 'extensionStatus'
        QtMocHelpers::PropertyData<Ekos::ExtensionState>(138, 0x80000000 | 139, QMC::DefaultPropertyFlags | QMC::EnumOrFlag, 4),
        // property 'logText'
        QtMocHelpers::PropertyData<QStringList>(136, QMetaType::QStringList, QMC::DefaultPropertyFlags, 6),
    };
    QtMocHelpers::UintData qt_enums {
    };
    QtMocHelpers::UintData qt_constructors {};
    QtMocHelpers::ClassInfos qt_classinfo({
            {    1,    2 },
    });
    return QtMocHelpers::metaObjectData<Manager, qt_meta_tag_ZN4Ekos7ManagerE_t>(QMC::MetaObjectFlag{}, qt_stringData,
            qt_methods, qt_properties, qt_enums, qt_constructors, qt_classinfo);
}
Q_CONSTINIT const QMetaObject Ekos::Manager::staticMetaObject = { {
    QMetaObject::SuperData::link<QDialog::staticMetaObject>(),
    qt_staticMetaObjectStaticContent<qt_meta_tag_ZN4Ekos7ManagerE_t>.stringdata,
    qt_staticMetaObjectStaticContent<qt_meta_tag_ZN4Ekos7ManagerE_t>.data,
    qt_static_metacall,
    nullptr,
    qt_staticMetaObjectRelocatingContent<qt_meta_tag_ZN4Ekos7ManagerE_t>.metaTypes,
    nullptr
} };

void Ekos::Manager::qt_static_metacall(QObject *_o, QMetaObject::Call _c, int _id, void **_a)
{
    auto *_t = static_cast<Manager *>(_o);
    if (_c == QMetaObject::InvokeMetaMethod) {
        switch (_id) {
        case 0: _t->ekosStatusChanged((*reinterpret_cast<std::add_pointer_t<Ekos::CommunicationStatus>>(_a[1]))); break;
        case 1: _t->indiStatusChanged((*reinterpret_cast<std::add_pointer_t<Ekos::CommunicationStatus>>(_a[1]))); break;
        case 2: _t->settleStatusChanged((*reinterpret_cast<std::add_pointer_t<Ekos::CommunicationStatus>>(_a[1]))); break;
        case 3: _t->ekosLiveStatusChanged((*reinterpret_cast<std::add_pointer_t<bool>>(_a[1]))); break;
        case 4: _t->extensionStatusChanged((*reinterpret_cast<std::add_pointer_t<bool>>(_a[1]))); break;
        case 5: _t->extensionStatusChanged(); break;
        case 6: _t->newLog((*reinterpret_cast<std::add_pointer_t<QString>>(_a[1]))); break;
        case 7: _t->newModule((*reinterpret_cast<std::add_pointer_t<QString>>(_a[1]))); break;
        case 8: _t->newDevice((*reinterpret_cast<std::add_pointer_t<QString>>(_a[1])),(*reinterpret_cast<std::add_pointer_t<int>>(_a[2]))); break;
        case 9: _t->connectDevices(); break;
        case 10: _t->disconnectDevices(); break;
        case 11: _t->setFITSfromFile((*reinterpret_cast<std::add_pointer_t<bool>>(_a[1]))); break;
        case 12: _t->previewFile((*reinterpret_cast<std::add_pointer_t<QString>>(_a[1]))); break;
        case 13: _t->processINDI(); break;
        case 14: _t->cleanDevices((*reinterpret_cast<std::add_pointer_t<bool>>(_a[1]))); break;
        case 15: _t->cleanDevices(); break;
        case 16: _t->processNewDevice((*reinterpret_cast<std::add_pointer_t<QSharedPointer<ISD::GenericDevice>>>(_a[1]))); break;
        case 17: _t->processNewProperty((*reinterpret_cast<std::add_pointer_t<INDI::Property>>(_a[1]))); break;
        case 18: _t->processUpdateProperty((*reinterpret_cast<std::add_pointer_t<INDI::Property>>(_a[1]))); break;
        case 19: _t->processDeleteProperty((*reinterpret_cast<std::add_pointer_t<INDI::Property>>(_a[1]))); break;
        case 20: _t->processMessage((*reinterpret_cast<std::add_pointer_t<QString>>(_a[1]))); break;
        case 21: _t->setDeviceReady(); break;
        case 22: _t->restartDriver((*reinterpret_cast<std::add_pointer_t<QString>>(_a[1]))); break;
        case 23: _t->changeAlwaysOnTop((*reinterpret_cast<std::add_pointer_t<Qt::ApplicationState>>(_a[1]))); break;
        case 24: _t->showEkosOptions(); break;
        case 25: _t->updateLog(); break;
        case 26: _t->clearLog(); break;
        case 27: _t->processTabChange(); break;
        case 28: _t->setServerStarted((*reinterpret_cast<std::add_pointer_t<QString>>(_a[1])),(*reinterpret_cast<std::add_pointer_t<int>>(_a[2]))); break;
        case 29: _t->setServerFailed((*reinterpret_cast<std::add_pointer_t<QString>>(_a[1])),(*reinterpret_cast<std::add_pointer_t<int>>(_a[2])),(*reinterpret_cast<std::add_pointer_t<QString>>(_a[3]))); break;
        case 30: _t->setClientStarted((*reinterpret_cast<std::add_pointer_t<QString>>(_a[1])),(*reinterpret_cast<std::add_pointer_t<int>>(_a[2]))); break;
        case 31: _t->setClientFailed((*reinterpret_cast<std::add_pointer_t<QString>>(_a[1])),(*reinterpret_cast<std::add_pointer_t<int>>(_a[2])),(*reinterpret_cast<std::add_pointer_t<QString>>(_a[3]))); break;
        case 32: _t->setClientTerminated((*reinterpret_cast<std::add_pointer_t<QString>>(_a[1])),(*reinterpret_cast<std::add_pointer_t<int>>(_a[2])),(*reinterpret_cast<std::add_pointer_t<QString>>(_a[3]))); break;
        case 33: _t->removeDevice((*reinterpret_cast<std::add_pointer_t<QSharedPointer<ISD::GenericDevice>>>(_a[1]))); break;
        case 34: _t->deviceConnected(); break;
        case 35: _t->deviceDisconnected(); break;
        case 36: _t->checkINDITimeout(); break;
        case 37: _t->updateDebugInterfaces(); break;
        case 38: _t->watchDebugProperty((*reinterpret_cast<std::add_pointer_t<INDI::Property>>(_a[1]))); break;
        case 39: _t->addMount((*reinterpret_cast<std::add_pointer_t<ISD::Mount*>>(_a[1]))); break;
        case 40: _t->addCamera((*reinterpret_cast<std::add_pointer_t<ISD::Camera*>>(_a[1]))); break;
        case 41: _t->addFilterWheel((*reinterpret_cast<std::add_pointer_t<ISD::FilterWheel*>>(_a[1]))); break;
        case 42: _t->addFocuser((*reinterpret_cast<std::add_pointer_t<ISD::Focuser*>>(_a[1]))); break;
        case 43: _t->addRotator((*reinterpret_cast<std::add_pointer_t<ISD::Rotator*>>(_a[1]))); break;
        case 44: _t->addDome((*reinterpret_cast<std::add_pointer_t<ISD::Dome*>>(_a[1]))); break;
        case 45: _t->addWeather((*reinterpret_cast<std::add_pointer_t<ISD::Weather*>>(_a[1]))); break;
        case 46: _t->addDustCap((*reinterpret_cast<std::add_pointer_t<ISD::DustCap*>>(_a[1]))); break;
        case 47: _t->addLightBox((*reinterpret_cast<std::add_pointer_t<ISD::LightBox*>>(_a[1]))); break;
        case 48: _t->addGuider((*reinterpret_cast<std::add_pointer_t<ISD::Guider*>>(_a[1]))); break;
        case 49: _t->addGPS((*reinterpret_cast<std::add_pointer_t<ISD::GPS*>>(_a[1]))); break;
        case 50: _t->addPAC((*reinterpret_cast<std::add_pointer_t<ISD::PAC*>>(_a[1]))); break;
        case 51: _t->createModulesForDevice((*reinterpret_cast<std::add_pointer_t<QSharedPointer<ISD::GenericDevice>>>(_a[1]))); break;
        case 52: _t->bindDeviceToModules((*reinterpret_cast<std::add_pointer_t<QSharedPointer<ISD::GenericDevice>>>(_a[1]))); break;
        case 53: _t->addProfile(); break;
        case 54: _t->editProfile(); break;
        case 55: _t->deleteProfile(); break;
        case 56: _t->wizardProfile(); break;
        case 57: _t->updateMountCoords((*reinterpret_cast<std::add_pointer_t<SkyPoint>>(_a[1])),(*reinterpret_cast<std::add_pointer_t<ISD::Mount::PierSide>>(_a[2])),(*reinterpret_cast<std::add_pointer_t<dms>>(_a[3]))); break;
        case 58: _t->updateMountStatus((*reinterpret_cast<std::add_pointer_t<ISD::Mount::Status>>(_a[1]))); break;
        case 59: _t->setTarget((*reinterpret_cast<std::add_pointer_t<QString>>(_a[1]))); break;
        case 60: _t->updateCaptureStatus((*reinterpret_cast<std::add_pointer_t<CaptureState>>(_a[1])),(*reinterpret_cast<std::add_pointer_t<QString>>(_a[2]))); break;
        case 61: _t->updateCaptureProgress((*reinterpret_cast<std::add_pointer_t<QSharedPointer<SequenceJob>>>(_a[1])),(*reinterpret_cast<std::add_pointer_t<QSharedPointer<FITSData>>>(_a[2])),(*reinterpret_cast<std::add_pointer_t<QString>>(_a[3]))); break;
        case 62: _t->updateCaptureProgress((*reinterpret_cast<std::add_pointer_t<QSharedPointer<SequenceJob>>>(_a[1])),(*reinterpret_cast<std::add_pointer_t<QSharedPointer<FITSData>>>(_a[2]))); break;
        case 63: _t->updateExposureProgress((*reinterpret_cast<std::add_pointer_t<QSharedPointer<SequenceJob>>>(_a[1])),(*reinterpret_cast<std::add_pointer_t<QString>>(_a[2]))); break;
        case 64: _t->updateCaptureCountDown(); break;
        case 65: _t->updateFocusStatus((*reinterpret_cast<std::add_pointer_t<FocusState>>(_a[1]))); break;
        case 66: _t->updateCurrentHFR((*reinterpret_cast<std::add_pointer_t<double>>(_a[1])),(*reinterpret_cast<std::add_pointer_t<int>>(_a[2])),(*reinterpret_cast<std::add_pointer_t<bool>>(_a[3]))); break;
        case 67: _t->updateGuideStatus((*reinterpret_cast<std::add_pointer_t<GuideState>>(_a[1]))); break;
        case 68: _t->updateSigmas((*reinterpret_cast<std::add_pointer_t<double>>(_a[1])),(*reinterpret_cast<std::add_pointer_t<double>>(_a[2]))); break;
        case 69: _t->help(); break;
        case 70: { bool _r = _t->setProfile((*reinterpret_cast<std::add_pointer_t<QString>>(_a[1])));
            if (_a[0]) *reinterpret_cast<bool*>(_a[0]) = std::move(_r); }  break;
        case 71: { QStringList _r = _t->getProfiles();
            if (_a[0]) *reinterpret_cast<QStringList*>(_a[0]) = std::move(_r); }  break;
        case 72: _t->addProfile((*reinterpret_cast<std::add_pointer_t<QString>>(_a[1]))); break;
        case 73: _t->editProfile((*reinterpret_cast<std::add_pointer_t<QString>>(_a[1]))); break;
        case 74: _t->deleteProfile((*reinterpret_cast<std::add_pointer_t<QString>>(_a[1]))); break;
        case 75: { QString _r = _t->getProfile((*reinterpret_cast<std::add_pointer_t<QString>>(_a[1])));
            if (_a[0]) *reinterpret_cast<QString*>(_a[0]) = std::move(_r); }  break;
        case 76: { uint _r = _t->getINDIConnectionStatus();
            if (_a[0]) *reinterpret_cast<uint*>(_a[0]) = std::move(_r); }  break;
        case 77: { Ekos::CommunicationStatus _r = _t->indiStatus();
            if (_a[0]) *reinterpret_cast<Ekos::CommunicationStatus*>(_a[0]) = std::move(_r); }  break;
        case 78: { uint _r = _t->getEkosStartingStatus();
            if (_a[0]) *reinterpret_cast<uint*>(_a[0]) = std::move(_r); }  break;
        case 79: { Ekos::CommunicationStatus _r = _t->ekosStatus();
            if (_a[0]) *reinterpret_cast<Ekos::CommunicationStatus*>(_a[0]) = std::move(_r); }  break;
        case 80: { Ekos::CommunicationStatus _r = _t->settleStatus();
            if (_a[0]) *reinterpret_cast<Ekos::CommunicationStatus*>(_a[0]) = std::move(_r); }  break;
        case 81: _t->setEkosLoggingEnabled((*reinterpret_cast<std::add_pointer_t<QString>>(_a[1])),(*reinterpret_cast<std::add_pointer_t<bool>>(_a[2]))); break;
        case 82: _t->start(); break;
        case 83: _t->stop(); break;
        case 84: { QStringList _r = _t->logText();
            if (_a[0]) *reinterpret_cast<QStringList*>(_a[0]) = std::move(_r); }  break;
        case 85: { bool _r = _t->ekosLiveStatus();
            if (_a[0]) *reinterpret_cast<bool*>(_a[0]) = std::move(_r); }  break;
        case 86: { Ekos::ExtensionState _r = _t->extensionStatus();
            if (_a[0]) *reinterpret_cast<Ekos::ExtensionState*>(_a[0]) = std::move(_r); }  break;
        case 87: _t->setEkosLiveConnected((*reinterpret_cast<std::add_pointer_t<bool>>(_a[1]))); break;
        case 88: _t->setEkosLiveConfig((*reinterpret_cast<std::add_pointer_t<bool>>(_a[1])),(*reinterpret_cast<std::add_pointer_t<bool>>(_a[2]))); break;
        case 89: _t->setEkosLiveUser((*reinterpret_cast<std::add_pointer_t<QString>>(_a[1])),(*reinterpret_cast<std::add_pointer_t<QString>>(_a[2]))); break;
        case 90: _t->acceptPortSelection(); break;
        default: ;
        }
    }
    if (_c == QMetaObject::RegisterMethodArgumentMetaType) {
        switch (_id) {
        default: *reinterpret_cast<QMetaType *>(_a[0]) = QMetaType(); break;
        case 0:
            switch (*reinterpret_cast<int*>(_a[1])) {
            default: *reinterpret_cast<QMetaType *>(_a[0]) = QMetaType(); break;
            case 0:
                *reinterpret_cast<QMetaType *>(_a[0]) = QMetaType::fromType< Ekos::CommunicationStatus >(); break;
            }
            break;
        case 1:
            switch (*reinterpret_cast<int*>(_a[1])) {
            default: *reinterpret_cast<QMetaType *>(_a[0]) = QMetaType(); break;
            case 0:
                *reinterpret_cast<QMetaType *>(_a[0]) = QMetaType::fromType< Ekos::CommunicationStatus >(); break;
            }
            break;
        case 2:
            switch (*reinterpret_cast<int*>(_a[1])) {
            default: *reinterpret_cast<QMetaType *>(_a[0]) = QMetaType(); break;
            case 0:
                *reinterpret_cast<QMetaType *>(_a[0]) = QMetaType::fromType< Ekos::CommunicationStatus >(); break;
            }
            break;
        case 16:
            switch (*reinterpret_cast<int*>(_a[1])) {
            default: *reinterpret_cast<QMetaType *>(_a[0]) = QMetaType(); break;
            case 0:
                *reinterpret_cast<QMetaType *>(_a[0]) = QMetaType::fromType< QSharedPointer<ISD::GenericDevice> >(); break;
            }
            break;
        case 17:
            switch (*reinterpret_cast<int*>(_a[1])) {
            default: *reinterpret_cast<QMetaType *>(_a[0]) = QMetaType(); break;
            case 0:
                *reinterpret_cast<QMetaType *>(_a[0]) = QMetaType::fromType< INDI::Property >(); break;
            }
            break;
        case 18:
            switch (*reinterpret_cast<int*>(_a[1])) {
            default: *reinterpret_cast<QMetaType *>(_a[0]) = QMetaType(); break;
            case 0:
                *reinterpret_cast<QMetaType *>(_a[0]) = QMetaType::fromType< INDI::Property >(); break;
            }
            break;
        case 19:
            switch (*reinterpret_cast<int*>(_a[1])) {
            default: *reinterpret_cast<QMetaType *>(_a[0]) = QMetaType(); break;
            case 0:
                *reinterpret_cast<QMetaType *>(_a[0]) = QMetaType::fromType< INDI::Property >(); break;
            }
            break;
        case 33:
            switch (*reinterpret_cast<int*>(_a[1])) {
            default: *reinterpret_cast<QMetaType *>(_a[0]) = QMetaType(); break;
            case 0:
                *reinterpret_cast<QMetaType *>(_a[0]) = QMetaType::fromType< QSharedPointer<ISD::GenericDevice> >(); break;
            }
            break;
        case 38:
            switch (*reinterpret_cast<int*>(_a[1])) {
            default: *reinterpret_cast<QMetaType *>(_a[0]) = QMetaType(); break;
            case 0:
                *reinterpret_cast<QMetaType *>(_a[0]) = QMetaType::fromType< INDI::Property >(); break;
            }
            break;
        case 39:
            switch (*reinterpret_cast<int*>(_a[1])) {
            default: *reinterpret_cast<QMetaType *>(_a[0]) = QMetaType(); break;
            case 0:
                *reinterpret_cast<QMetaType *>(_a[0]) = QMetaType::fromType< ISD::Mount* >(); break;
            }
            break;
        case 51:
            switch (*reinterpret_cast<int*>(_a[1])) {
            default: *reinterpret_cast<QMetaType *>(_a[0]) = QMetaType(); break;
            case 0:
                *reinterpret_cast<QMetaType *>(_a[0]) = QMetaType::fromType< QSharedPointer<ISD::GenericDevice> >(); break;
            }
            break;
        case 52:
            switch (*reinterpret_cast<int*>(_a[1])) {
            default: *reinterpret_cast<QMetaType *>(_a[0]) = QMetaType(); break;
            case 0:
                *reinterpret_cast<QMetaType *>(_a[0]) = QMetaType::fromType< QSharedPointer<ISD::GenericDevice> >(); break;
            }
            break;
        case 57:
            switch (*reinterpret_cast<int*>(_a[1])) {
            default: *reinterpret_cast<QMetaType *>(_a[0]) = QMetaType(); break;
            case 1:
                *reinterpret_cast<QMetaType *>(_a[0]) = QMetaType::fromType< ISD::Mount::PierSide >(); break;
            case 0:
                *reinterpret_cast<QMetaType *>(_a[0]) = QMetaType::fromType< SkyPoint >(); break;
            }
            break;
        case 58:
            switch (*reinterpret_cast<int*>(_a[1])) {
            default: *reinterpret_cast<QMetaType *>(_a[0]) = QMetaType(); break;
            case 0:
                *reinterpret_cast<QMetaType *>(_a[0]) = QMetaType::fromType< ISD::Mount::Status >(); break;
            }
            break;
        case 61:
            switch (*reinterpret_cast<int*>(_a[1])) {
            default: *reinterpret_cast<QMetaType *>(_a[0]) = QMetaType(); break;
            case 1:
                *reinterpret_cast<QMetaType *>(_a[0]) = QMetaType::fromType< QSharedPointer<FITSData> >(); break;
            }
            break;
        case 62:
            switch (*reinterpret_cast<int*>(_a[1])) {
            default: *reinterpret_cast<QMetaType *>(_a[0]) = QMetaType(); break;
            case 1:
                *reinterpret_cast<QMetaType *>(_a[0]) = QMetaType::fromType< QSharedPointer<FITSData> >(); break;
            }
            break;
        }
    }
    if (_c == QMetaObject::IndexOfMethod) {
        if (QtMocHelpers::indexOfMethod<void (Manager::*)(Ekos::CommunicationStatus )>(_a, &Manager::ekosStatusChanged, 0))
            return;
        if (QtMocHelpers::indexOfMethod<void (Manager::*)(Ekos::CommunicationStatus )>(_a, &Manager::indiStatusChanged, 1))
            return;
        if (QtMocHelpers::indexOfMethod<void (Manager::*)(Ekos::CommunicationStatus )>(_a, &Manager::settleStatusChanged, 2))
            return;
        if (QtMocHelpers::indexOfMethod<void (Manager::*)(bool )>(_a, &Manager::ekosLiveStatusChanged, 3))
            return;
        if (QtMocHelpers::indexOfMethod<void (Manager::*)(bool )>(_a, &Manager::extensionStatusChanged, 4))
            return;
        if (QtMocHelpers::indexOfMethod<void (Manager::*)(const QString & )>(_a, &Manager::newLog, 6))
            return;
        if (QtMocHelpers::indexOfMethod<void (Manager::*)(const QString & )>(_a, &Manager::newModule, 7))
            return;
        if (QtMocHelpers::indexOfMethod<void (Manager::*)(const QString & , int )>(_a, &Manager::newDevice, 8))
            return;
    }
    if (_c == QMetaObject::RegisterPropertyMetaType) {
        switch (_id) {
        default: *reinterpret_cast<int*>(_a[0]) = -1; break;
        case 2:
        case 1:
        case 0:
            *reinterpret_cast<int*>(_a[0]) = qRegisterMetaType< Ekos::CommunicationStatus >(); break;
        case 4:
            *reinterpret_cast<int*>(_a[0]) = qRegisterMetaType< Ekos::ExtensionState >(); break;
        }
    }
    if (_c == QMetaObject::ReadProperty) {
        void *_v = _a[0];
        switch (_id) {
        case 0: *reinterpret_cast<Ekos::CommunicationStatus*>(_v) = _t->indiStatus(); break;
        case 1: *reinterpret_cast<Ekos::CommunicationStatus*>(_v) = _t->ekosStatus(); break;
        case 2: *reinterpret_cast<Ekos::CommunicationStatus*>(_v) = _t->settleStatus(); break;
        case 3: *reinterpret_cast<bool*>(_v) = _t->ekosLiveStatus(); break;
        case 4: *reinterpret_cast<Ekos::ExtensionState*>(_v) = _t->extensionStatus(); break;
        case 5: *reinterpret_cast<QStringList*>(_v) = _t->logText(); break;
        default: break;
        }
    }
}

const QMetaObject *Ekos::Manager::metaObject() const
{
    return QObject::d_ptr->metaObject ? QObject::d_ptr->dynamicMetaObject() : &staticMetaObject;
}

void *Ekos::Manager::qt_metacast(const char *_clname)
{
    if (!_clname) return nullptr;
    if (!strcmp(_clname, qt_staticMetaObjectStaticContent<qt_meta_tag_ZN4Ekos7ManagerE_t>.strings))
        return static_cast<void*>(this);
    if (!strcmp(_clname, "Ui::Manager"))
        return static_cast< Ui::Manager*>(this);
    return QDialog::qt_metacast(_clname);
}

int Ekos::Manager::qt_metacall(QMetaObject::Call _c, int _id, void **_a)
{
    _id = QDialog::qt_metacall(_c, _id, _a);
    if (_id < 0)
        return _id;
    if (_c == QMetaObject::InvokeMetaMethod) {
        if (_id < 91)
            qt_static_metacall(this, _c, _id, _a);
        _id -= 91;
    }
    if (_c == QMetaObject::RegisterMethodArgumentMetaType) {
        if (_id < 91)
            qt_static_metacall(this, _c, _id, _a);
        _id -= 91;
    }
    if (_c == QMetaObject::ReadProperty || _c == QMetaObject::WriteProperty
            || _c == QMetaObject::ResetProperty || _c == QMetaObject::BindableProperty
            || _c == QMetaObject::RegisterPropertyMetaType) {
        qt_static_metacall(this, _c, _id, _a);
        _id -= 6;
    }
    return _id;
}

// SIGNAL 0
void Ekos::Manager::ekosStatusChanged(Ekos::CommunicationStatus _t1)
{
    QMetaObject::activate<void>(this, &staticMetaObject, 0, nullptr, _t1);
}

// SIGNAL 1
void Ekos::Manager::indiStatusChanged(Ekos::CommunicationStatus _t1)
{
    QMetaObject::activate<void>(this, &staticMetaObject, 1, nullptr, _t1);
}

// SIGNAL 2
void Ekos::Manager::settleStatusChanged(Ekos::CommunicationStatus _t1)
{
    QMetaObject::activate<void>(this, &staticMetaObject, 2, nullptr, _t1);
}

// SIGNAL 3
void Ekos::Manager::ekosLiveStatusChanged(bool _t1)
{
    QMetaObject::activate<void>(this, &staticMetaObject, 3, nullptr, _t1);
}

// SIGNAL 4
void Ekos::Manager::extensionStatusChanged(bool _t1)
{
    QMetaObject::activate<void>(this, &staticMetaObject, 4, nullptr, _t1);
}

// SIGNAL 6
void Ekos::Manager::newLog(const QString & _t1)
{
    QMetaObject::activate<void>(this, &staticMetaObject, 6, nullptr, _t1);
}

// SIGNAL 7
void Ekos::Manager::newModule(const QString & _t1)
{
    QMetaObject::activate<void>(this, &staticMetaObject, 7, nullptr, _t1);
}

// SIGNAL 8
void Ekos::Manager::newDevice(const QString & _t1, int _t2)
{
    QMetaObject::activate<void>(this, &staticMetaObject, 8, nullptr, _t1, _t2);
}
QT_WARNING_POP
