/********************************************************************************
** Form generated from reading UI file 'argsetgeolocation.ui'
**
** Created by: Qt User Interface Compiler version 6.11.1
**
** WARNING! All changes made in this file will be lost when recompiling UI file!
********************************************************************************/

#ifndef UI_ARGSETGEOLOCATION_H
#define UI_ARGSETGEOLOCATION_H

#include <QtCore/QVariant>
#include <QtWidgets/QApplication>
#include <QtWidgets/QGridLayout>
#include <QtWidgets/QHBoxLayout>
#include <QtWidgets/QLabel>
#include <QtWidgets/QLineEdit>
#include <QtWidgets/QPushButton>
#include <QtWidgets/QSpacerItem>
#include <QtWidgets/QVBoxLayout>
#include <QtWidgets/QWidget>
#include <klocalizedstring.h>

QT_BEGIN_NAMESPACE

class Ui_ArgSetGeoLocation
{
public:
    QVBoxLayout *vboxLayout;
    QHBoxLayout *hboxLayout;
    QVBoxLayout *vboxLayout1;
    QGridLayout *gridLayout;
    QLabel *textLabel1_2;
    QLineEdit *CountryName;
    QLabel *textLabel1;
    QLabel *textLabel1_2_3;
    QLineEdit *CityName;
    QLineEdit *ProvinceName;
    QHBoxLayout *hboxLayout1;
    QSpacerItem *spacerItem;
    QPushButton *FindCityButton;
    QSpacerItem *spacerItem1;
    QSpacerItem *spacerItem2;

    void setupUi(QWidget *ArgSetGeoLocation)
    {
        if (ArgSetGeoLocation->objectName().isEmpty())
            ArgSetGeoLocation->setObjectName("ArgSetGeoLocation");
        ArgSetGeoLocation->resize(316, 208);
        vboxLayout = new QVBoxLayout(ArgSetGeoLocation);
#ifndef UI_Q_OS_MAC
        vboxLayout->setSpacing(6);
#endif
        vboxLayout->setContentsMargins(10, 10, 10, 10);
        vboxLayout->setObjectName("vboxLayout");
        hboxLayout = new QHBoxLayout();
#ifndef UI_Q_OS_MAC
        hboxLayout->setSpacing(6);
#endif
#ifndef UI_Q_OS_MAC
        hboxLayout->setContentsMargins(0, 0, 0, 0);
#endif
        hboxLayout->setObjectName("hboxLayout");
        vboxLayout1 = new QVBoxLayout();
#ifndef UI_Q_OS_MAC
        vboxLayout1->setSpacing(6);
#endif
#ifndef UI_Q_OS_MAC
        vboxLayout1->setContentsMargins(0, 0, 0, 0);
#endif
        vboxLayout1->setObjectName("vboxLayout1");
        gridLayout = new QGridLayout();
#ifndef UI_Q_OS_MAC
        gridLayout->setSpacing(6);
#endif
#ifndef UI_Q_OS_MAC
        gridLayout->setContentsMargins(0, 0, 0, 0);
#endif
        gridLayout->setObjectName("gridLayout");
        textLabel1_2 = new QLabel(ArgSetGeoLocation);
        textLabel1_2->setObjectName("textLabel1_2");

        gridLayout->addWidget(textLabel1_2, 1, 0, 1, 1);

        CountryName = new QLineEdit(ArgSetGeoLocation);
        CountryName->setObjectName("CountryName");

        gridLayout->addWidget(CountryName, 2, 1, 1, 1);

        textLabel1 = new QLabel(ArgSetGeoLocation);
        textLabel1->setObjectName("textLabel1");

        gridLayout->addWidget(textLabel1, 0, 0, 1, 1);

        textLabel1_2_3 = new QLabel(ArgSetGeoLocation);
        textLabel1_2_3->setObjectName("textLabel1_2_3");

        gridLayout->addWidget(textLabel1_2_3, 2, 0, 1, 1);

        CityName = new QLineEdit(ArgSetGeoLocation);
        CityName->setObjectName("CityName");

        gridLayout->addWidget(CityName, 0, 1, 1, 1);

        ProvinceName = new QLineEdit(ArgSetGeoLocation);
        ProvinceName->setObjectName("ProvinceName");

        gridLayout->addWidget(ProvinceName, 1, 1, 1, 1);


        vboxLayout1->addLayout(gridLayout);

        hboxLayout1 = new QHBoxLayout();
#ifndef UI_Q_OS_MAC
        hboxLayout1->setSpacing(6);
#endif
        hboxLayout1->setContentsMargins(0, 0, 0, 0);
        hboxLayout1->setObjectName("hboxLayout1");
        spacerItem = new QSpacerItem(49, 20, QSizePolicy::Policy::Expanding, QSizePolicy::Policy::Minimum);

        hboxLayout1->addItem(spacerItem);

        FindCityButton = new QPushButton(ArgSetGeoLocation);
        FindCityButton->setObjectName("FindCityButton");

        hboxLayout1->addWidget(FindCityButton);


        vboxLayout1->addLayout(hboxLayout1);


        hboxLayout->addLayout(vboxLayout1);

        spacerItem1 = new QSpacerItem(49, 20, QSizePolicy::Policy::Expanding, QSizePolicy::Policy::Minimum);

        hboxLayout->addItem(spacerItem1);


        vboxLayout->addLayout(hboxLayout);

        spacerItem2 = new QSpacerItem(20, 40, QSizePolicy::Policy::Minimum, QSizePolicy::Policy::Expanding);

        vboxLayout->addItem(spacerItem2);

        QWidget::setTabOrder(CityName, ProvinceName);
        QWidget::setTabOrder(ProvinceName, CountryName);
        QWidget::setTabOrder(CountryName, FindCityButton);

        retranslateUi(ArgSetGeoLocation);

        QMetaObject::connectSlotsByName(ArgSetGeoLocation);
    } // setupUi

    void retranslateUi(QWidget *ArgSetGeoLocation)
    {
        textLabel1_2->setText(tr2i18n("Province:", nullptr));
#if QT_CONFIG(tooltip)
        CountryName->setToolTip(tr2i18n("Country name", nullptr));
#endif // QT_CONFIG(tooltip)
#if QT_CONFIG(whatsthis)
        CountryName->setWhatsThis(tr2i18n("Enter the Country name for the desired location.  It might be easier to use the \"Find City...\" button to choose your location from the list of predefined cities.", nullptr));
#endif // QT_CONFIG(whatsthis)
        textLabel1->setText(tr2i18n("City:", nullptr));
        textLabel1_2_3->setText(tr2i18n("Country:", nullptr));
#if QT_CONFIG(tooltip)
        CityName->setToolTip(tr2i18n("City name", nullptr));
#endif // QT_CONFIG(tooltip)
#if QT_CONFIG(whatsthis)
        CityName->setWhatsThis(tr2i18n("Enter the City name for the desired location.  It might be easier to use the \"Find City...\" button to choose your location from the list of predefined cities.", nullptr));
#endif // QT_CONFIG(whatsthis)
#if QT_CONFIG(tooltip)
        ProvinceName->setToolTip(tr2i18n("Province name", nullptr));
#endif // QT_CONFIG(tooltip)
#if QT_CONFIG(whatsthis)
        ProvinceName->setWhatsThis(tr2i18n("Enter the Province name for the desired location.  It might be easier to use the \"Find City...\" button to choose your location from the list of predefined cities.", nullptr));
#endif // QT_CONFIG(whatsthis)
#if QT_CONFIG(tooltip)
        FindCityButton->setToolTip(tr2i18n("Open the Set Location tool", nullptr));
#endif // QT_CONFIG(tooltip)
#if QT_CONFIG(whatsthis)
        FindCityButton->setWhatsThis(tr2i18n("Press this button to open the Set Location dialog, which will allow you to choose a location from our list of over 2500 cities around the word.  Once a location has been selected, the City, Province and Country fields will be filled in.", nullptr));
#endif // QT_CONFIG(whatsthis)
        FindCityButton->setText(tr2i18n("Find City...", nullptr));
        (void)ArgSetGeoLocation;
    } // retranslateUi

};

namespace Ui {
    class ArgSetGeoLocation: public Ui_ArgSetGeoLocation {};
} // namespace Ui

QT_END_NAMESPACE

#endif // ARGSETGEOLOCATION_H

