/********************************************************************************
** Form generated from reading UI file 'analyze.ui'
**
** Created by: Qt User Interface Compiler version 6.11.1
**
** WARNING! All changes made in this file will be lost when recompiling UI file!
********************************************************************************/

#ifndef UI_ANALYZE_H
#define UI_ANALYZE_H

#include <QtCore/QVariant>
#include <QtWidgets/QApplication>
#include <QtWidgets/QCheckBox>
#include <QtWidgets/QComboBox>
#include <QtWidgets/QFrame>
#include <QtWidgets/QGridLayout>
#include <QtWidgets/QHBoxLayout>
#include <QtWidgets/QHeaderView>
#include <QtWidgets/QLabel>
#include <QtWidgets/QLineEdit>
#include <QtWidgets/QPushButton>
#include <QtWidgets/QScrollBar>
#include <QtWidgets/QSpacerItem>
#include <QtWidgets/QTableWidget>
#include <QtWidgets/QVBoxLayout>
#include <QtWidgets/QWidget>
#include <klocalizedstring.h>
#include "auxiliary/qcustomplot.h"

QT_BEGIN_NAMESPACE

class Ui_Analyze
{
public:
    QVBoxLayout *AnalyzeLayout;
    QHBoxLayout *horizontalLayout_4;
    QCheckBox *timelineCB;
    QLabel *timelineLabel;
    QSpacerItem *horizontalSpacer_2;
    QLabel *inputLabel;
    QSpacerItem *horizontalSpacer_4;
    QPushButton *prevFileB;
    QPushButton *nextFileB;
    QComboBox *inputCombo;
    QLabel *inputValue;
    QCheckBox *fullWidthCB;
    QCheckBox *keepCurrentCB;
    QCustomPlot *timelinePlot;
    QHBoxLayout *horizontalLayout_5;
    QCheckBox *graphsCB;
    QCheckBox *statsCB;
    QLabel *statsLabel;
    QSpacerItem *horizontalSpacer_3;
    QPushButton *prevSessionB;
    QPushButton *zoomInB;
    QLineEdit *cursorTimeOut;
    QLineEdit *cursorClockTimeOut;
    QPushButton *zoomOutB;
    QPushButton *nextSessionB;
    QSpacerItem *horizontalSpacer;
    QCustomPlot *statsPlot;
    QScrollBar *analyzeSB;
    QFrame *statsGridWidget;
    QGridLayout *statsGridLayout;
    QLabel *label2;
    QLabel *label3;
    QLabel *label;
    QCheckBox *raCB;
    QLineEdit *raOut;
    QCheckBox *decCB;
    QLineEdit *decOut;
    QCheckBox *raPulseCB;
    QLineEdit *raPulseOut;
    QCheckBox *decPulseCB;
    QLineEdit *decPulseOut;
    QCheckBox *driftCB;
    QLineEdit *driftOut;
    QCheckBox *rmsCB;
    QLineEdit *rmsOut;
    QCheckBox *skyBgCB;
    QLineEdit *skyBgOut;
    QCheckBox *numStarsCB;
    QLineEdit *numStarsOut;
    QCheckBox *snrCB;
    QLineEdit *snrOut;
    QCheckBox *mountRaCB;
    QLineEdit *mountRaOut;
    QCheckBox *mountDecCB;
    QLineEdit *mountDecOut;
    QCheckBox *azCB;
    QLineEdit *azOut;
    QCheckBox *altCB;
    QLineEdit *altOut;
    QCheckBox *pierSideCB;
    QLineEdit *pierSideOut;
    QCheckBox *mountHaCB;
    QLineEdit *mountHaOut;
    QCheckBox *hfrCB;
    QLineEdit *hfrOut;
    QCheckBox *numCaptureStarsCB;
    QLineEdit *numCaptureStarsOut;
    QCheckBox *medianCB;
    QLineEdit *medianOut;
    QCheckBox *eccentricityCB;
    QLineEdit *eccentricityOut;
    QCheckBox *temperatureCB;
    QLineEdit *temperatureOut;
    QCheckBox *rmsCCB;
    QLineEdit *rmsCOut;
    QCheckBox *targetDistanceCB;
    QLineEdit *targetDistanceOut;
    QCheckBox *focusPositionCB;
    QLineEdit *focusPositionOut;
    QCheckBox *detailsCB;
    QFrame *detailsWidget;
    QHBoxLayout *detailsLayout;
    QTableWidget *detailsTable;
    QCustomPlot *graphicsPlot;

    void setupUi(QWidget *Analyze)
    {
        if (Analyze->objectName().isEmpty())
            Analyze->setObjectName("Analyze");
        Analyze->resize(980, 824);
        AnalyzeLayout = new QVBoxLayout(Analyze);
        AnalyzeLayout->setSpacing(1);
        AnalyzeLayout->setObjectName("AnalyzeLayout");
        horizontalLayout_4 = new QHBoxLayout();
        horizontalLayout_4->setObjectName("horizontalLayout_4");
        timelineCB = new QCheckBox(Analyze);
        timelineCB->setObjectName("timelineCB");
        timelineCB->setMaximumSize(QSize(20, 16777215));
        timelineCB->setChecked(true);

        horizontalLayout_4->addWidget(timelineCB);

        timelineLabel = new QLabel(Analyze);
        timelineLabel->setObjectName("timelineLabel");
        QSizePolicy sizePolicy(QSizePolicy::Policy::Fixed, QSizePolicy::Policy::Preferred);
        sizePolicy.setHorizontalStretch(0);
        sizePolicy.setVerticalStretch(0);
        sizePolicy.setHeightForWidth(timelineLabel->sizePolicy().hasHeightForWidth());
        timelineLabel->setSizePolicy(sizePolicy);
        timelineLabel->setMaximumSize(QSize(70, 16777215));

        horizontalLayout_4->addWidget(timelineLabel);

        horizontalSpacer_2 = new QSpacerItem(10, 20, QSizePolicy::Policy::Fixed, QSizePolicy::Policy::Minimum);

        horizontalLayout_4->addItem(horizontalSpacer_2);

        inputLabel = new QLabel(Analyze);
        inputLabel->setObjectName("inputLabel");
        sizePolicy.setHeightForWidth(inputLabel->sizePolicy().hasHeightForWidth());
        inputLabel->setSizePolicy(sizePolicy);
        inputLabel->setMaximumSize(QSize(40, 16777215));
        inputLabel->setAlignment(Qt::AlignRight|Qt::AlignTrailing|Qt::AlignVCenter);

        horizontalLayout_4->addWidget(inputLabel);

        horizontalSpacer_4 = new QSpacerItem(8, 20, QSizePolicy::Policy::Fixed, QSizePolicy::Policy::Minimum);

        horizontalLayout_4->addItem(horizontalSpacer_4);

        prevFileB = new QPushButton(Analyze);
        prevFileB->setObjectName("prevFileB");
        QSizePolicy sizePolicy1(QSizePolicy::Policy::Fixed, QSizePolicy::Policy::Fixed);
        sizePolicy1.setHorizontalStretch(0);
        sizePolicy1.setVerticalStretch(0);
        sizePolicy1.setHeightForWidth(prevFileB->sizePolicy().hasHeightForWidth());
        prevFileB->setSizePolicy(sizePolicy1);
        prevFileB->setMaximumSize(QSize(25, 16777215));

        horizontalLayout_4->addWidget(prevFileB);

        nextFileB = new QPushButton(Analyze);
        nextFileB->setObjectName("nextFileB");
        sizePolicy1.setHeightForWidth(nextFileB->sizePolicy().hasHeightForWidth());
        nextFileB->setSizePolicy(sizePolicy1);
        nextFileB->setMaximumSize(QSize(25, 16777215));

        horizontalLayout_4->addWidget(nextFileB);

        inputCombo = new QComboBox(Analyze);
        inputCombo->setObjectName("inputCombo");
        sizePolicy1.setHeightForWidth(inputCombo->sizePolicy().hasHeightForWidth());
        inputCombo->setSizePolicy(sizePolicy1);

        horizontalLayout_4->addWidget(inputCombo);

        inputValue = new QLabel(Analyze);
        inputValue->setObjectName("inputValue");
        QSizePolicy sizePolicy2(QSizePolicy::Policy::Preferred, QSizePolicy::Policy::Fixed);
        sizePolicy2.setHorizontalStretch(0);
        sizePolicy2.setVerticalStretch(0);
        sizePolicy2.setHeightForWidth(inputValue->sizePolicy().hasHeightForWidth());
        inputValue->setSizePolicy(sizePolicy2);
        inputValue->setMinimumSize(QSize(100, 0));
        inputValue->setMaximumSize(QSize(16777215, 16777215));
        inputValue->setAlignment(Qt::AlignCenter);

        horizontalLayout_4->addWidget(inputValue);

        fullWidthCB = new QCheckBox(Analyze);
        fullWidthCB->setObjectName("fullWidthCB");
        sizePolicy1.setHeightForWidth(fullWidthCB->sizePolicy().hasHeightForWidth());
        fullWidthCB->setSizePolicy(sizePolicy1);

        horizontalLayout_4->addWidget(fullWidthCB);

        keepCurrentCB = new QCheckBox(Analyze);
        keepCurrentCB->setObjectName("keepCurrentCB");
        sizePolicy1.setHeightForWidth(keepCurrentCB->sizePolicy().hasHeightForWidth());
        keepCurrentCB->setSizePolicy(sizePolicy1);

        horizontalLayout_4->addWidget(keepCurrentCB);


        AnalyzeLayout->addLayout(horizontalLayout_4);

        timelinePlot = new QCustomPlot(Analyze);
        timelinePlot->setObjectName("timelinePlot");
        QSizePolicy sizePolicy3(QSizePolicy::Policy::Preferred, QSizePolicy::Policy::MinimumExpanding);
        sizePolicy3.setHorizontalStretch(0);
        sizePolicy3.setVerticalStretch(0);
        sizePolicy3.setHeightForWidth(timelinePlot->sizePolicy().hasHeightForWidth());
        timelinePlot->setSizePolicy(sizePolicy3);
        timelinePlot->setMinimumSize(QSize(200, 150));
        timelinePlot->setMaximumSize(QSize(16777215, 16777215));

        AnalyzeLayout->addWidget(timelinePlot);

        horizontalLayout_5 = new QHBoxLayout();
        horizontalLayout_5->setObjectName("horizontalLayout_5");
        graphsCB = new QCheckBox(Analyze);
        graphsCB->setObjectName("graphsCB");
        graphsCB->setMaximumSize(QSize(20, 16777215));
        graphsCB->setChecked(true);

        horizontalLayout_5->addWidget(graphsCB);

        statsCB = new QCheckBox(Analyze);
        statsCB->setObjectName("statsCB");
        statsCB->setMaximumSize(QSize(20, 16777215));
        statsCB->setChecked(true);

        horizontalLayout_5->addWidget(statsCB);

        statsLabel = new QLabel(Analyze);
        statsLabel->setObjectName("statsLabel");

        horizontalLayout_5->addWidget(statsLabel);

        horizontalSpacer_3 = new QSpacerItem(40, 20, QSizePolicy::Policy::Expanding, QSizePolicy::Policy::Minimum);

        horizontalLayout_5->addItem(horizontalSpacer_3);

        prevSessionB = new QPushButton(Analyze);
        prevSessionB->setObjectName("prevSessionB");
        prevSessionB->setMaximumSize(QSize(30, 16777215));

        horizontalLayout_5->addWidget(prevSessionB);

        zoomInB = new QPushButton(Analyze);
        zoomInB->setObjectName("zoomInB");

        horizontalLayout_5->addWidget(zoomInB);

        cursorTimeOut = new QLineEdit(Analyze);
        cursorTimeOut->setObjectName("cursorTimeOut");
        cursorTimeOut->setMaximumSize(QSize(80, 16777215));
        cursorTimeOut->setAlignment(Qt::AlignCenter);
        cursorTimeOut->setReadOnly(true);

        horizontalLayout_5->addWidget(cursorTimeOut);

        cursorClockTimeOut = new QLineEdit(Analyze);
        cursorClockTimeOut->setObjectName("cursorClockTimeOut");
        cursorClockTimeOut->setMaximumSize(QSize(80, 16777215));
        cursorClockTimeOut->setAlignment(Qt::AlignCenter);
        cursorClockTimeOut->setReadOnly(true);

        horizontalLayout_5->addWidget(cursorClockTimeOut);

        zoomOutB = new QPushButton(Analyze);
        zoomOutB->setObjectName("zoomOutB");

        horizontalLayout_5->addWidget(zoomOutB);

        nextSessionB = new QPushButton(Analyze);
        nextSessionB->setObjectName("nextSessionB");
        nextSessionB->setMaximumSize(QSize(30, 16777215));

        horizontalLayout_5->addWidget(nextSessionB);

        horizontalSpacer = new QSpacerItem(40, 20, QSizePolicy::Policy::Expanding, QSizePolicy::Policy::Minimum);

        horizontalLayout_5->addItem(horizontalSpacer);


        AnalyzeLayout->addLayout(horizontalLayout_5);

        statsPlot = new QCustomPlot(Analyze);
        statsPlot->setObjectName("statsPlot");
        sizePolicy3.setHeightForWidth(statsPlot->sizePolicy().hasHeightForWidth());
        statsPlot->setSizePolicy(sizePolicy3);
        statsPlot->setMinimumSize(QSize(200, 125));
        statsPlot->setMaximumSize(QSize(16777215, 16777215));
        QFont font;
        font.setPointSize(10);
        statsPlot->setFont(font);

        AnalyzeLayout->addWidget(statsPlot);

        analyzeSB = new QScrollBar(Analyze);
        analyzeSB->setObjectName("analyzeSB");
        analyzeSB->setOrientation(Qt::Horizontal);

        AnalyzeLayout->addWidget(analyzeSB);

        statsGridWidget = new QFrame(Analyze);
        statsGridWidget->setObjectName("statsGridWidget");
        statsGridWidget->setFrameShape(QFrame::NoFrame);
        statsGridWidget->setLineWidth(0);
        statsGridLayout = new QGridLayout(statsGridWidget);
        statsGridLayout->setObjectName("statsGridLayout");
        statsGridLayout->setSizeConstraint(QLayout::SetDefaultConstraint);
        statsGridLayout->setVerticalSpacing(2);
        statsGridLayout->setContentsMargins(-1, 2, -1, 2);
        label2 = new QLabel(statsGridWidget);
        label2->setObjectName("label2");
        label2->setMaximumSize(QSize(40, 16777215));
        label2->setFont(font);

        statsGridLayout->addWidget(label2, 0, 0, 1, 1);

        label3 = new QLabel(statsGridWidget);
        label3->setObjectName("label3");
        label3->setMaximumSize(QSize(40, 16777215));
        label3->setFont(font);

        statsGridLayout->addWidget(label3, 1, 0, 1, 1);

        label = new QLabel(statsGridWidget);
        label->setObjectName("label");
        label->setMaximumSize(QSize(50, 16777215));
        label->setFont(font);

        statsGridLayout->addWidget(label, 2, 0, 1, 1);

        raCB = new QCheckBox(statsGridWidget);
        raCB->setObjectName("raCB");
        raCB->setMaximumSize(QSize(40, 16777215));
        raCB->setStyleSheet(QString::fromUtf8("font-size: 9pt"));

        statsGridLayout->addWidget(raCB, 0, 1, 1, 1);

        raOut = new QLineEdit(statsGridWidget);
        raOut->setObjectName("raOut");
        raOut->setMaximumSize(QSize(40, 16777215));
        raOut->setStyleSheet(QString::fromUtf8("font-size: 9pt"));
        raOut->setAlignment(Qt::AlignRight|Qt::AlignTrailing|Qt::AlignVCenter);
        raOut->setReadOnly(true);

        statsGridLayout->addWidget(raOut, 0, 2, 1, 1);

        decCB = new QCheckBox(statsGridWidget);
        decCB->setObjectName("decCB");
        decCB->setMaximumSize(QSize(40, 16777215));
        decCB->setStyleSheet(QString::fromUtf8("font-size: 9pt"));

        statsGridLayout->addWidget(decCB, 0, 3, 1, 1);

        decOut = new QLineEdit(statsGridWidget);
        decOut->setObjectName("decOut");
        decOut->setMaximumSize(QSize(40, 16777215));
        decOut->setStyleSheet(QString::fromUtf8("font-size: 9pt"));
        decOut->setAlignment(Qt::AlignRight|Qt::AlignTrailing|Qt::AlignVCenter);
        decOut->setReadOnly(true);

        statsGridLayout->addWidget(decOut, 0, 4, 1, 1);

        raPulseCB = new QCheckBox(statsGridWidget);
        raPulseCB->setObjectName("raPulseCB");
        raPulseCB->setMaximumSize(QSize(65, 16777215));
        raPulseCB->setStyleSheet(QString::fromUtf8("font-size: 9pt"));

        statsGridLayout->addWidget(raPulseCB, 0, 5, 1, 1);

        raPulseOut = new QLineEdit(statsGridWidget);
        raPulseOut->setObjectName("raPulseOut");
        raPulseOut->setMaximumSize(QSize(40, 16777215));
        raPulseOut->setStyleSheet(QString::fromUtf8("font-size: 9pt"));
        raPulseOut->setAlignment(Qt::AlignRight|Qt::AlignTrailing|Qt::AlignVCenter);
        raPulseOut->setReadOnly(true);

        statsGridLayout->addWidget(raPulseOut, 0, 6, 1, 1);

        decPulseCB = new QCheckBox(statsGridWidget);
        decPulseCB->setObjectName("decPulseCB");
        decPulseCB->setMinimumSize(QSize(0, 0));
        decPulseCB->setMaximumSize(QSize(40, 16777215));
        decPulseCB->setStyleSheet(QString::fromUtf8("font-size: 9pt"));

        statsGridLayout->addWidget(decPulseCB, 0, 7, 1, 1);

        decPulseOut = new QLineEdit(statsGridWidget);
        decPulseOut->setObjectName("decPulseOut");
        decPulseOut->setMaximumSize(QSize(40, 16777209));
        decPulseOut->setStyleSheet(QString::fromUtf8("font-size: 9pt"));
        decPulseOut->setAlignment(Qt::AlignRight|Qt::AlignTrailing|Qt::AlignVCenter);
        decPulseOut->setReadOnly(true);

        statsGridLayout->addWidget(decPulseOut, 0, 8, 1, 1);

        driftCB = new QCheckBox(statsGridWidget);
        driftCB->setObjectName("driftCB");
        driftCB->setMinimumSize(QSize(40, 0));
        driftCB->setMaximumSize(QSize(50, 16777215));
        driftCB->setStyleSheet(QString::fromUtf8("font-size: 9pt"));

        statsGridLayout->addWidget(driftCB, 0, 9, 1, 1);

        driftOut = new QLineEdit(statsGridWidget);
        driftOut->setObjectName("driftOut");
        driftOut->setMaximumSize(QSize(45, 16777215));
        driftOut->setStyleSheet(QString::fromUtf8("font-size: 9pt"));
        driftOut->setAlignment(Qt::AlignRight|Qt::AlignTrailing|Qt::AlignVCenter);
        driftOut->setReadOnly(true);

        statsGridLayout->addWidget(driftOut, 0, 10, 1, 1);

        rmsCB = new QCheckBox(statsGridWidget);
        rmsCB->setObjectName("rmsCB");
        rmsCB->setMinimumSize(QSize(40, 0));
        rmsCB->setMaximumSize(QSize(40, 16777215));
        rmsCB->setStyleSheet(QString::fromUtf8("font-size: 9pt"));

        statsGridLayout->addWidget(rmsCB, 0, 11, 1, 1);

        rmsOut = new QLineEdit(statsGridWidget);
        rmsOut->setObjectName("rmsOut");
        rmsOut->setMaximumSize(QSize(40, 16777215));
        rmsOut->setStyleSheet(QString::fromUtf8("font-size: 9pt"));
        rmsOut->setAlignment(Qt::AlignRight|Qt::AlignTrailing|Qt::AlignVCenter);
        rmsOut->setReadOnly(true);

        statsGridLayout->addWidget(rmsOut, 0, 12, 1, 1);

        skyBgCB = new QCheckBox(statsGridWidget);
        skyBgCB->setObjectName("skyBgCB");
        skyBgCB->setMinimumSize(QSize(40, 0));
        skyBgCB->setMaximumSize(QSize(55, 16777215));
        skyBgCB->setStyleSheet(QString::fromUtf8("font-size: 9pt"));

        statsGridLayout->addWidget(skyBgCB, 0, 13, 1, 1);

        skyBgOut = new QLineEdit(statsGridWidget);
        skyBgOut->setObjectName("skyBgOut");
        skyBgOut->setMaximumSize(QSize(40, 16777215));
        skyBgOut->setStyleSheet(QString::fromUtf8("font-size: 9pt"));
        skyBgOut->setAlignment(Qt::AlignRight|Qt::AlignTrailing|Qt::AlignVCenter);
        skyBgOut->setReadOnly(true);

        statsGridLayout->addWidget(skyBgOut, 0, 14, 1, 1);

        numStarsCB = new QCheckBox(statsGridWidget);
        numStarsCB->setObjectName("numStarsCB");
        numStarsCB->setMaximumSize(QSize(50, 16777215));
        numStarsCB->setStyleSheet(QString::fromUtf8("font-size: 9pt"));

        statsGridLayout->addWidget(numStarsCB, 0, 15, 1, 1);

        numStarsOut = new QLineEdit(statsGridWidget);
        numStarsOut->setObjectName("numStarsOut");
        numStarsOut->setMaximumSize(QSize(40, 16777215));
        numStarsOut->setStyleSheet(QString::fromUtf8("font-size: 9pt"));
        numStarsOut->setAlignment(Qt::AlignRight|Qt::AlignTrailing|Qt::AlignVCenter);
        numStarsOut->setReadOnly(true);

        statsGridLayout->addWidget(numStarsOut, 0, 16, 1, 1);

        snrCB = new QCheckBox(statsGridWidget);
        snrCB->setObjectName("snrCB");
        snrCB->setMinimumSize(QSize(0, 0));
        snrCB->setMaximumSize(QSize(40, 16777215));
        snrCB->setStyleSheet(QString::fromUtf8("font-size: 9pt"));

        statsGridLayout->addWidget(snrCB, 0, 17, 1, 1);

        snrOut = new QLineEdit(statsGridWidget);
        snrOut->setObjectName("snrOut");
        snrOut->setMaximumSize(QSize(40, 16777215));
        snrOut->setStyleSheet(QString::fromUtf8("font-size: 9pt"));
        snrOut->setAlignment(Qt::AlignRight|Qt::AlignTrailing|Qt::AlignVCenter);
        snrOut->setReadOnly(true);

        statsGridLayout->addWidget(snrOut, 0, 18, 1, 1);

        mountRaCB = new QCheckBox(statsGridWidget);
        mountRaCB->setObjectName("mountRaCB");
        mountRaCB->setMinimumSize(QSize(0, 0));
        mountRaCB->setMaximumSize(QSize(40, 16777215));
        mountRaCB->setStyleSheet(QString::fromUtf8("font-size: 9pt"));

        statsGridLayout->addWidget(mountRaCB, 1, 1, 1, 1);

        mountRaOut = new QLineEdit(statsGridWidget);
        mountRaOut->setObjectName("mountRaOut");
        mountRaOut->setMinimumSize(QSize(50, 0));
        mountRaOut->setMaximumSize(QSize(40, 16777215));
        mountRaOut->setStyleSheet(QString::fromUtf8("font-size: 8pt"));
        mountRaOut->setAlignment(Qt::AlignLeading|Qt::AlignLeft|Qt::AlignVCenter);
        mountRaOut->setReadOnly(true);

        statsGridLayout->addWidget(mountRaOut, 1, 2, 1, 1);

        mountDecCB = new QCheckBox(statsGridWidget);
        mountDecCB->setObjectName("mountDecCB");
        mountDecCB->setMaximumSize(QSize(40, 16777215));
        mountDecCB->setStyleSheet(QString::fromUtf8("font-size: 9pt"));

        statsGridLayout->addWidget(mountDecCB, 1, 3, 1, 1);

        mountDecOut = new QLineEdit(statsGridWidget);
        mountDecOut->setObjectName("mountDecOut");
        mountDecOut->setMinimumSize(QSize(60, 0));
        mountDecOut->setMaximumSize(QSize(40, 16777215));
        mountDecOut->setStyleSheet(QString::fromUtf8("font-size: 8pt"));
        mountDecOut->setAlignment(Qt::AlignLeading|Qt::AlignLeft|Qt::AlignVCenter);
        mountDecOut->setReadOnly(true);

        statsGridLayout->addWidget(mountDecOut, 1, 4, 1, 1);

        azCB = new QCheckBox(statsGridWidget);
        azCB->setObjectName("azCB");
        azCB->setMaximumSize(QSize(50, 16777215));
        azCB->setStyleSheet(QString::fromUtf8("font-size: 9pt"));

        statsGridLayout->addWidget(azCB, 1, 5, 1, 1);

        azOut = new QLineEdit(statsGridWidget);
        azOut->setObjectName("azOut");
        azOut->setMaximumSize(QSize(40, 16777215));
        azOut->setStyleSheet(QString::fromUtf8("font-size: 9pt"));
        azOut->setAlignment(Qt::AlignRight|Qt::AlignTrailing|Qt::AlignVCenter);
        azOut->setReadOnly(true);

        statsGridLayout->addWidget(azOut, 1, 6, 1, 1);

        altCB = new QCheckBox(statsGridWidget);
        altCB->setObjectName("altCB");
        altCB->setMinimumSize(QSize(30, 0));
        altCB->setMaximumSize(QSize(40, 16777215));
        altCB->setStyleSheet(QString::fromUtf8("font-size: 9pt"));

        statsGridLayout->addWidget(altCB, 1, 7, 1, 1);

        altOut = new QLineEdit(statsGridWidget);
        altOut->setObjectName("altOut");
        altOut->setMaximumSize(QSize(40, 16777215));
        altOut->setStyleSheet(QString::fromUtf8("font-size: 9pt"));
        altOut->setAlignment(Qt::AlignRight|Qt::AlignTrailing|Qt::AlignVCenter);
        altOut->setReadOnly(true);

        statsGridLayout->addWidget(altOut, 1, 8, 1, 1);

        pierSideCB = new QCheckBox(statsGridWidget);
        pierSideCB->setObjectName("pierSideCB");
        pierSideCB->setMinimumSize(QSize(40, 0));
        pierSideCB->setMaximumSize(QSize(50, 16777215));
        pierSideCB->setStyleSheet(QString::fromUtf8("font-size: 9pt"));

        statsGridLayout->addWidget(pierSideCB, 1, 9, 1, 1);

        pierSideOut = new QLineEdit(statsGridWidget);
        pierSideOut->setObjectName("pierSideOut");
        pierSideOut->setMaximumSize(QSize(40, 16777215));
        pierSideOut->setStyleSheet(QString::fromUtf8("font-size: 9pt"));
        pierSideOut->setAlignment(Qt::AlignRight|Qt::AlignTrailing|Qt::AlignVCenter);
        pierSideOut->setReadOnly(true);

        statsGridLayout->addWidget(pierSideOut, 1, 10, 1, 1);

        mountHaCB = new QCheckBox(statsGridWidget);
        mountHaCB->setObjectName("mountHaCB");
        mountHaCB->setMinimumSize(QSize(45, 0));
        mountHaCB->setMaximumSize(QSize(40, 16777215));
        mountHaCB->setStyleSheet(QString::fromUtf8("font-size: 9pt"));

        statsGridLayout->addWidget(mountHaCB, 1, 11, 1, 1);

        mountHaOut = new QLineEdit(statsGridWidget);
        mountHaOut->setObjectName("mountHaOut");
        mountHaOut->setMinimumSize(QSize(40, 0));
        mountHaOut->setMaximumSize(QSize(40, 16777215));
        mountHaOut->setStyleSheet(QString::fromUtf8("font-size: 8pt"));
        mountHaOut->setAlignment(Qt::AlignLeading|Qt::AlignLeft|Qt::AlignVCenter);
        mountHaOut->setReadOnly(true);

        statsGridLayout->addWidget(mountHaOut, 1, 12, 1, 1);

        hfrCB = new QCheckBox(statsGridWidget);
        hfrCB->setObjectName("hfrCB");
        hfrCB->setMaximumSize(QSize(40, 16777215));
        hfrCB->setStyleSheet(QString::fromUtf8("font-size: 9pt"));

        statsGridLayout->addWidget(hfrCB, 2, 1, 1, 1);

        hfrOut = new QLineEdit(statsGridWidget);
        hfrOut->setObjectName("hfrOut");
        hfrOut->setMaximumSize(QSize(40, 16777215));
        hfrOut->setStyleSheet(QString::fromUtf8("font-size: 9pt"));
        hfrOut->setAlignment(Qt::AlignRight|Qt::AlignTrailing|Qt::AlignVCenter);
        hfrOut->setReadOnly(true);

        statsGridLayout->addWidget(hfrOut, 2, 2, 1, 1);

        numCaptureStarsCB = new QCheckBox(statsGridWidget);
        numCaptureStarsCB->setObjectName("numCaptureStarsCB");
        numCaptureStarsCB->setMaximumSize(QSize(50, 16777215));
        numCaptureStarsCB->setStyleSheet(QString::fromUtf8("font-size: 9pt"));

        statsGridLayout->addWidget(numCaptureStarsCB, 2, 3, 1, 1);

        numCaptureStarsOut = new QLineEdit(statsGridWidget);
        numCaptureStarsOut->setObjectName("numCaptureStarsOut");
        numCaptureStarsOut->setMaximumSize(QSize(40, 16777215));
        numCaptureStarsOut->setStyleSheet(QString::fromUtf8("font-size: 9pt"));
        numCaptureStarsOut->setAlignment(Qt::AlignRight|Qt::AlignTrailing|Qt::AlignVCenter);
        numCaptureStarsOut->setReadOnly(true);

        statsGridLayout->addWidget(numCaptureStarsOut, 2, 4, 1, 1);

        medianCB = new QCheckBox(statsGridWidget);
        medianCB->setObjectName("medianCB");
        medianCB->setMaximumSize(QSize(65, 16777215));
        medianCB->setStyleSheet(QString::fromUtf8("font-size: 9pt"));

        statsGridLayout->addWidget(medianCB, 2, 5, 1, 1);

        medianOut = new QLineEdit(statsGridWidget);
        medianOut->setObjectName("medianOut");
        medianOut->setMaximumSize(QSize(40, 16777215));
        medianOut->setStyleSheet(QString::fromUtf8("font-size: 9pt"));
        medianOut->setAlignment(Qt::AlignRight|Qt::AlignTrailing|Qt::AlignVCenter);
        medianOut->setReadOnly(false);

        statsGridLayout->addWidget(medianOut, 2, 6, 1, 1);

        eccentricityCB = new QCheckBox(statsGridWidget);
        eccentricityCB->setObjectName("eccentricityCB");
        eccentricityCB->setMaximumSize(QSize(40, 16777215));
        eccentricityCB->setStyleSheet(QString::fromUtf8("font-size: 9pt"));

        statsGridLayout->addWidget(eccentricityCB, 2, 7, 1, 1);

        eccentricityOut = new QLineEdit(statsGridWidget);
        eccentricityOut->setObjectName("eccentricityOut");
        eccentricityOut->setMaximumSize(QSize(40, 16777215));
        eccentricityOut->setStyleSheet(QString::fromUtf8("font-size: 9pt"));
        eccentricityOut->setAlignment(Qt::AlignRight|Qt::AlignTrailing|Qt::AlignVCenter);
        eccentricityOut->setReadOnly(false);

        statsGridLayout->addWidget(eccentricityOut, 2, 8, 1, 1);

        temperatureCB = new QCheckBox(statsGridWidget);
        temperatureCB->setObjectName("temperatureCB");
        temperatureCB->setMaximumSize(QSize(50, 16777215));
        temperatureCB->setStyleSheet(QString::fromUtf8("font-size: 9pt"));

        statsGridLayout->addWidget(temperatureCB, 2, 9, 1, 1);

        temperatureOut = new QLineEdit(statsGridWidget);
        temperatureOut->setObjectName("temperatureOut");
        temperatureOut->setMaximumSize(QSize(45, 16777215));
        temperatureOut->setStyleSheet(QString::fromUtf8("font-size: 9pt"));
        temperatureOut->setAlignment(Qt::AlignRight|Qt::AlignTrailing|Qt::AlignVCenter);
        temperatureOut->setReadOnly(false);

        statsGridLayout->addWidget(temperatureOut, 2, 10, 1, 1);

        rmsCCB = new QCheckBox(statsGridWidget);
        rmsCCB->setObjectName("rmsCCB");
        rmsCCB->setMinimumSize(QSize(40, 0));
        rmsCCB->setMaximumSize(QSize(40, 16777215));
        rmsCCB->setStyleSheet(QString::fromUtf8("font-size: 9pt"));

        statsGridLayout->addWidget(rmsCCB, 2, 11, 1, 1);

        rmsCOut = new QLineEdit(statsGridWidget);
        rmsCOut->setObjectName("rmsCOut");
        rmsCOut->setMaximumSize(QSize(40, 16777215));
        rmsCOut->setStyleSheet(QString::fromUtf8("font-size: 9pt"));
        rmsCOut->setAlignment(Qt::AlignRight|Qt::AlignTrailing|Qt::AlignVCenter);
        rmsCOut->setReadOnly(true);

        statsGridLayout->addWidget(rmsCOut, 2, 12, 1, 1);

        targetDistanceCB = new QCheckBox(statsGridWidget);
        targetDistanceCB->setObjectName("targetDistanceCB");
        targetDistanceCB->setMinimumSize(QSize(40, 0));
        targetDistanceCB->setMaximumSize(QSize(40, 16777215));
        targetDistanceCB->setStyleSheet(QString::fromUtf8("font-size: 9pt"));

        statsGridLayout->addWidget(targetDistanceCB, 2, 13, 1, 1);

        targetDistanceOut = new QLineEdit(statsGridWidget);
        targetDistanceOut->setObjectName("targetDistanceOut");
        targetDistanceOut->setMaximumSize(QSize(40, 16777215));
        targetDistanceOut->setStyleSheet(QString::fromUtf8("font-size: 9pt"));
        targetDistanceOut->setAlignment(Qt::AlignRight|Qt::AlignTrailing|Qt::AlignVCenter);
        targetDistanceOut->setReadOnly(true);

        statsGridLayout->addWidget(targetDistanceOut, 2, 14, 1, 1);

        focusPositionCB = new QCheckBox(statsGridWidget);
        focusPositionCB->setObjectName("focusPositionCB");
        focusPositionCB->setMinimumSize(QSize(50, 0));
        focusPositionCB->setMaximumSize(QSize(50, 16777215));
        focusPositionCB->setStyleSheet(QString::fromUtf8("font-size: 9pt"));

        statsGridLayout->addWidget(focusPositionCB, 2, 15, 1, 1);

        focusPositionOut = new QLineEdit(statsGridWidget);
        focusPositionOut->setObjectName("focusPositionOut");
        focusPositionOut->setMaximumSize(QSize(50, 16777215));
        focusPositionOut->setStyleSheet(QString::fromUtf8("font-size: 9pt"));
        focusPositionOut->setAlignment(Qt::AlignRight|Qt::AlignTrailing|Qt::AlignVCenter);
        focusPositionOut->setReadOnly(true);

        statsGridLayout->addWidget(focusPositionOut, 2, 16, 1, 1);


        AnalyzeLayout->addWidget(statsGridWidget);

        detailsCB = new QCheckBox(Analyze);
        detailsCB->setObjectName("detailsCB");
        detailsCB->setIconSize(QSize(16, 16));
        detailsCB->setChecked(true);

        AnalyzeLayout->addWidget(detailsCB);

        detailsWidget = new QFrame(Analyze);
        detailsWidget->setObjectName("detailsWidget");
        detailsWidget->setLineWidth(0);
        detailsLayout = new QHBoxLayout(detailsWidget);
        detailsLayout->setObjectName("detailsLayout");
        detailsLayout->setContentsMargins(-1, 0, -1, 0);
        detailsTable = new QTableWidget(detailsWidget);
        detailsTable->setObjectName("detailsTable");
        QSizePolicy sizePolicy4(QSizePolicy::Policy::MinimumExpanding, QSizePolicy::Policy::MinimumExpanding);
        sizePolicy4.setHorizontalStretch(0);
        sizePolicy4.setVerticalStretch(0);
        sizePolicy4.setHeightForWidth(detailsTable->sizePolicy().hasHeightForWidth());
        detailsTable->setSizePolicy(sizePolicy4);
        detailsTable->setVerticalScrollBarPolicy(Qt::ScrollBarAsNeeded);
        detailsTable->setHorizontalScrollBarPolicy(Qt::ScrollBarAsNeeded);

        detailsLayout->addWidget(detailsTable);

        graphicsPlot = new QCustomPlot(detailsWidget);
        graphicsPlot->setObjectName("graphicsPlot");
        graphicsPlot->setEnabled(true);
        graphicsPlot->setMinimumSize(QSize(400, 125));
        graphicsPlot->setMaximumSize(QSize(16777215, 175));
        graphicsPlot->setFont(font);

        detailsLayout->addWidget(graphicsPlot);


        AnalyzeLayout->addWidget(detailsWidget);


        retranslateUi(Analyze);

        QMetaObject::connectSlotsByName(Analyze);
    } // setupUi

    void retranslateUi(QWidget *Analyze)
    {
        timelineCB->setText(QString());
        timelineLabel->setText(tr2i18n("Timeline", nullptr));
        inputLabel->setText(tr2i18n("Input:", nullptr));
#if QT_CONFIG(tooltip)
        prevFileB->setToolTip(tr2i18n("<html><head/><body><p>Display the previous .analyze file.</p></body></html>", nullptr));
#endif // QT_CONFIG(tooltip)
        prevFileB->setText(tr2i18n("<<", nullptr));
#if QT_CONFIG(tooltip)
        nextFileB->setToolTip(tr2i18n("<html><head/><body><p>Display the next .analyze file.</p></body></html>", nullptr));
#endif // QT_CONFIG(tooltip)
        nextFileB->setText(tr2i18n(">>", nullptr));
#if QT_CONFIG(tooltip)
        inputCombo->setToolTip(tr2i18n("<html><head/><body><p>Select the input for the plots. This can be the current Ekos session, or it can be read from a file.</p></body></html>", nullptr));
#endif // QT_CONFIG(tooltip)
        inputCombo->setProperty("text", QVariant(tr2i18n("--", nullptr)));
        inputValue->setText(QString());
#if QT_CONFIG(tooltip)
        fullWidthCB->setToolTip(tr2i18n("<html><head/><body><p>Keep the plot at the full input width.</p></body></html>", nullptr));
#endif // QT_CONFIG(tooltip)
        fullWidthCB->setText(tr2i18n("Full Width", nullptr));
#if QT_CONFIG(tooltip)
        keepCurrentCB->setToolTip(tr2i18n("<html><head/><body><p>While recording live, Keep the plot recent. That is, the most recent actions performed by Ekos are shown on the right side of the plot.</p></body></html>", nullptr));
#endif // QT_CONFIG(tooltip)
        keepCurrentCB->setText(tr2i18n("Latest", nullptr));
        graphsCB->setText(QString());
        statsCB->setText(QString());
        statsLabel->setText(tr2i18n("Statistics", nullptr));
#if QT_CONFIG(tooltip)
        prevSessionB->setToolTip(tr2i18n("<html><head/><body><p>Move from the selected session to its previous session (on its left). Keyboard: control-left.</p></body></html>", nullptr));
#endif // QT_CONFIG(tooltip)
        prevSessionB->setText(tr2i18n("<", nullptr));
#if QT_CONFIG(tooltip)
        zoomInB->setToolTip(tr2i18n("<html><head/><body><p>Zoom in to the x-axis on the Timeline and Statistics plots. That is, show a shorter time period.</p></body></html>", nullptr));
#endif // QT_CONFIG(tooltip)
        zoomInB->setText(tr2i18n("+", nullptr));
#if QT_CONFIG(tooltip)
        cursorTimeOut->setToolTip(tr2i18n("<html><head/><body><p>The number of seconds from the start of the log to the statistics cursor. If there is no cursor and latest is checked, then it is the time at the right-side of the plot.</p></body></html>", nullptr));
#endif // QT_CONFIG(tooltip)
#if QT_CONFIG(tooltip)
        cursorClockTimeOut->setToolTip(tr2i18n("<html><head/><body><p>The clock-time for the statistics plot cursor. If there is no cursor and latest is checked, then it is the clock time at the right-side of the plot.</p></body></html>", nullptr));
#endif // QT_CONFIG(tooltip)
#if QT_CONFIG(tooltip)
        zoomOutB->setToolTip(tr2i18n("<html><head/><body><p>Zoom out on the x-axis on the Timeline and Statistics plots. That is, show a longer time period.</p></body></html>", nullptr));
#endif // QT_CONFIG(tooltip)
        zoomOutB->setText(tr2i18n("-", nullptr));
#if QT_CONFIG(tooltip)
        nextSessionB->setToolTip(tr2i18n("<html><head/><body><p>Move from the selected session to its next session (on its right). Keyboard: control-right.</p></body></html>", nullptr));
#endif // QT_CONFIG(tooltip)
        nextSessionB->setText(tr2i18n(">", nullptr));
#if QT_CONFIG(tooltip)
        analyzeSB->setToolTip(tr2i18n("<html><head/><body><p>If possible display previous (scroll to left) or future (scroll to right) sections of the Timeline and Statistics plot.</p></body></html>", nullptr));
#endif // QT_CONFIG(tooltip)
        label2->setText(tr2i18n("Guide:", nullptr));
        label3->setText(tr2i18n("Mount:", nullptr));
        label->setText(tr2i18n("Capture:", nullptr));
#if QT_CONFIG(tooltip)
        raCB->setToolTip(tr2i18n("<html><head/><body><p>Plot the right ascension (RA) drift error in arc-seconds.</p></body></html>", nullptr));
#endif // QT_CONFIG(tooltip)
        raCB->setText(tr2i18n("ra", nullptr));
#if QT_CONFIG(tooltip)
        raOut->setToolTip(tr2i18n("<html><head/><body><p>The right ascension (RA) drift error in arc-seconds. Click here to view this axis on left-axis values. Shares axis with RA/DEC error, drift, and RMS values. Double click to update axis.</p></body></html>", nullptr));
#endif // QT_CONFIG(tooltip)
#if QT_CONFIG(tooltip)
        decCB->setToolTip(tr2i18n("<html><head/><body><p>Plot the declination (DEC) drift error in arc-seconds.</p></body></html>", nullptr));
#endif // QT_CONFIG(tooltip)
        decCB->setText(tr2i18n("dec", nullptr));
#if QT_CONFIG(tooltip)
        decOut->setToolTip(tr2i18n("<html><head/><body><p>Plot the declination (DEC) drift error in arc-seconds. Click here to view this axis on left-axis values. Shares axis with RA/DEC error, drift, and RMS values. Double click to update axis.</p></body></html>", nullptr));
#endif // QT_CONFIG(tooltip)
#if QT_CONFIG(tooltip)
        raPulseCB->setToolTip(tr2i18n("<html><head/><body><p>Plot the right ascension (RA) guide pulses in milliseconds.</p></body></html>", nullptr));
#endif // QT_CONFIG(tooltip)
        raPulseCB->setText(tr2i18n("ra pulse", nullptr));
#if QT_CONFIG(tooltip)
        raPulseOut->setToolTip(tr2i18n("<html><head/><body><p>The right ascension (RA) guide pulses in milliseconds. Click here to view this axis on left-axis values. Double click to update axis.</p></body></html>", nullptr));
#endif // QT_CONFIG(tooltip)
#if QT_CONFIG(tooltip)
        decPulseCB->setToolTip(tr2i18n("<html><head/><body><p>Plot the declination (DEC) guide pulses in milliseconds.</p></body></html>", nullptr));
#endif // QT_CONFIG(tooltip)
        decPulseCB->setText(tr2i18n("dec", nullptr));
#if QT_CONFIG(tooltip)
        decPulseOut->setToolTip(tr2i18n("<html><head/><body><p>The declination (DEC) guide pulses in milliseconds. Click here to view this axis on left-axis values. Double click to update axis.</p></body></html>", nullptr));
#endif // QT_CONFIG(tooltip)
#if QT_CONFIG(tooltip)
        driftCB->setToolTip(tr2i18n("<html><head/><body><p>Plot the combined RA and DEC drift error in arc-seconds.</p></body></html>", nullptr));
#endif // QT_CONFIG(tooltip)
        driftCB->setText(tr2i18n("drift", nullptr));
#if QT_CONFIG(tooltip)
        driftOut->setToolTip(tr2i18n("<html><head/><body><p>The combined RA and DEC drift error in arc-seconds. Click here to view this axis on left-axis values. Shares axis with RA/DEC error, drift, and RMS values. Double click to update axis.</p></body></html>", nullptr));
#endif // QT_CONFIG(tooltip)
#if QT_CONFIG(tooltip)
        rmsCB->setToolTip(tr2i18n("<html><head/><body><p>Plot the root-mean-squared (RMS) value of the combined RA and DEC drift in arc-seconds, averaged on approximately the past 40 samples.</p></body></html>", nullptr));
#endif // QT_CONFIG(tooltip)
        rmsCB->setText(tr2i18n("rms", nullptr));
#if QT_CONFIG(tooltip)
        rmsOut->setToolTip(tr2i18n("<html><head/><body><p>The root-mean-squared (RMS) value of the combined RA and DEC drift in arc-seconds, averaged on approximately the past 40 samples. Click here to view this axis on left-axis values. Shares axis with RA/DEC error, drift, and RMS values. Double click to update axis.</p></body></html>", nullptr));
#endif // QT_CONFIG(tooltip)
#if QT_CONFIG(tooltip)
        skyBgCB->setToolTip(tr2i18n("<html><head/><body><p>Plot the sky background light (computed by SEP from the guide images).</p></body></html>", nullptr));
#endif // QT_CONFIG(tooltip)
        skyBgCB->setText(tr2i18n("sky", nullptr));
#if QT_CONFIG(tooltip)
        skyBgOut->setToolTip(tr2i18n("<html><head/><body><p>The sky background light level (computed by SEP from the guide images). Click here to view this axis on left-axis values. Double click to update axis.</p></body></html>", nullptr));
#endif // QT_CONFIG(tooltip)
#if QT_CONFIG(tooltip)
        numStarsCB->setToolTip(tr2i18n("<html><head/><body><p>Plot the number of stars detected in the guide images.</p></body></html>", nullptr));
#endif // QT_CONFIG(tooltip)
        numStarsCB->setText(tr2i18n("stars", nullptr));
#if QT_CONFIG(tooltip)
        numStarsOut->setToolTip(tr2i18n("<html><head/><body><p>The number of stars detected in the guide images. Click here to view this axis on left-axis values. Double click to update axis.</p></body></html>", nullptr));
#endif // QT_CONFIG(tooltip)
#if QT_CONFIG(tooltip)
        snrCB->setToolTip(tr2i18n("<html><head/><body><p>Plot the signal-to-noise ratio (SNR) of the guide star.</p></body></html>", nullptr));
#endif // QT_CONFIG(tooltip)
        snrCB->setText(tr2i18n("snr", nullptr));
#if QT_CONFIG(tooltip)
        snrOut->setToolTip(tr2i18n("<html><head/><body><p>The signal-to-noise ratio (SNR) of the guide star. Click here to view this axis on left-axis values. Double click to update axis.</p></body></html>", nullptr));
#endif // QT_CONFIG(tooltip)
#if QT_CONFIG(tooltip)
        mountRaCB->setToolTip(tr2i18n("<html><head/><body><p>Plot the Right Ascension (RA) where the telescope is pointing.</p></body></html>", nullptr));
#endif // QT_CONFIG(tooltip)
        mountRaCB->setText(tr2i18n("ra", nullptr));
#if QT_CONFIG(tooltip)
        mountRaOut->setToolTip(tr2i18n("<html><head/><body><p>The Right Ascension (RA) in HMS where the telescope is pointing. Click here to view this axis on left-axis values. Double click to update axis.</p></body></html>", nullptr));
#endif // QT_CONFIG(tooltip)
#if QT_CONFIG(tooltip)
        mountDecCB->setToolTip(tr2i18n("<html><head/><body><p>Plot the Declination (DEC) in where the telescope is pointing.</p></body></html>", nullptr));
#endif // QT_CONFIG(tooltip)
        mountDecCB->setText(tr2i18n("dec", nullptr));
#if QT_CONFIG(tooltip)
        mountDecOut->setToolTip(tr2i18n("<html><head/><body><p>The Declination (DEC) in degrees:arc-minutes:arc-seconds where the telescope is pointing. Click here to view this axis on left-axis values. Double click to update axis.</p></body></html>", nullptr));
#endif // QT_CONFIG(tooltip)
#if QT_CONFIG(tooltip)
        azCB->setToolTip(tr2i18n("<html><head/><body><p>Plot the telescope's azimuth (degrees).</p></body></html>", nullptr));
#endif // QT_CONFIG(tooltip)
        azCB->setText(tr2i18n("az", nullptr));
#if QT_CONFIG(tooltip)
        azOut->setToolTip(tr2i18n("<html><head/><body><p>The telescope's azimuth (degrees). Click here to view this axis on left-axis values. Double click to update axis.</p></body></html>", nullptr));
#endif // QT_CONFIG(tooltip)
#if QT_CONFIG(tooltip)
        altCB->setToolTip(tr2i18n("<html><head/><body><p>Plot the telescope's altitude (degrees).</p></body></html>", nullptr));
#endif // QT_CONFIG(tooltip)
        altCB->setText(tr2i18n("alt", nullptr));
#if QT_CONFIG(tooltip)
        altOut->setToolTip(tr2i18n("<html><head/><body><p>The telescope's altitude (degrees). Click here to view this axis on left-axis values. Double click to update axis.</p></body></html>", nullptr));
#endif // QT_CONFIG(tooltip)
#if QT_CONFIG(tooltip)
        pierSideCB->setToolTip(tr2i18n("<html><head/><body><p>Plot the mount's pier side (left) -> where the mount is pointing.</p></body></html>", nullptr));
#endif // QT_CONFIG(tooltip)
        pierSideCB->setText(tr2i18n("side", nullptr));
#if QT_CONFIG(tooltip)
        pierSideOut->setToolTip(tr2i18n("<html><head/><body><p>The mount's pier side (left) -> where the mount is pointing. Click here to view this axis on left-axis values. Double click to update axis.</p></body></html>", nullptr));
#endif // QT_CONFIG(tooltip)
#if QT_CONFIG(tooltip)
        mountHaCB->setToolTip(tr2i18n("<html><head/><body><p>Plot the mount's hour angle value.</p></body></html>", nullptr));
#endif // QT_CONFIG(tooltip)
        mountHaCB->setText(tr2i18n("ha", nullptr));
#if QT_CONFIG(tooltip)
        mountHaOut->setToolTip(tr2i18n("<html><head/><body><p>The mount's hour angle value. Click here to view this axis on left-axis values. Double click to update axis.</p></body></html>", nullptr));
#endif // QT_CONFIG(tooltip)
#if QT_CONFIG(tooltip)
        hfrCB->setToolTip(tr2i18n("<html><head/><body><p>Plot the Half-Flux Radius (in pixels) of the captured images.</p></body></html>", nullptr));
#endif // QT_CONFIG(tooltip)
        hfrCB->setText(tr2i18n("hfr", nullptr));
#if QT_CONFIG(tooltip)
        hfrOut->setToolTip(tr2i18n("<html><head/><body><p>The Half-Flux Radius (in pixels) of the captured images. Click here to view this axis on left-axis values. Double click to update axis.</p></body></html>", nullptr));
#endif // QT_CONFIG(tooltip)
#if QT_CONFIG(tooltip)
        numCaptureStarsCB->setToolTip(tr2i18n("<html><head/><body><p>Plot the number of stars detected in the captured images.</p></body></html>", nullptr));
#endif // QT_CONFIG(tooltip)
        numCaptureStarsCB->setText(tr2i18n("stars", nullptr));
#if QT_CONFIG(tooltip)
        numCaptureStarsOut->setToolTip(tr2i18n("<html><head/><body><p>Plot the number of stars detected in the captured images. Click here to view this axis on left-axis values. Double click to update axis.</p></body></html>", nullptr));
#endif // QT_CONFIG(tooltip)
#if QT_CONFIG(tooltip)
        medianCB->setToolTip(tr2i18n("<html><head/><body><p>Plot the median sample value in the captured images.</p></body></html>", nullptr));
#endif // QT_CONFIG(tooltip)
        medianCB->setText(tr2i18n("median", nullptr));
#if QT_CONFIG(tooltip)
        medianOut->setToolTip(tr2i18n("<html><head/><body><p>Plot the median sample value in the captured images. Click here to view this axis on left-axis values. Double click to update axis.</p></body></html>", nullptr));
#endif // QT_CONFIG(tooltip)
#if QT_CONFIG(tooltip)
        eccentricityCB->setToolTip(tr2i18n("<html><head/><body><p>Plot the median star eccentricity in the captured images.</p></body></html>", nullptr));
#endif // QT_CONFIG(tooltip)
        eccentricityCB->setText(tr2i18n("ecc", nullptr));
#if QT_CONFIG(tooltip)
        eccentricityOut->setToolTip(tr2i18n("<html><head/><body><p>Plot the median star eccentricity in the captured images. Click here to view this axis on left-axis values. Double click to update axis.</p></body></html>", nullptr));
#endif // QT_CONFIG(tooltip)
#if QT_CONFIG(tooltip)
        temperatureCB->setToolTip(tr2i18n("<html><head/><body><p>Plot the ambient temperature.</p></body></html>", nullptr));
#endif // QT_CONFIG(tooltip)
        temperatureCB->setText(tr2i18n("temp", nullptr));
#if QT_CONFIG(tooltip)
        temperatureOut->setToolTip(tr2i18n("<html><head/><body><p>Plot the ambient temperature. Click here to view this axis on left-axis values. Double click to update axis.</p></body></html>", nullptr));
#endif // QT_CONFIG(tooltip)
#if QT_CONFIG(tooltip)
        rmsCCB->setToolTip(tr2i18n("<html><head/><body><p>Plot the root-mean-squared (RMS) value of the combined RA and DEC drift in arc-seconds, averaged on approximately the past 40 samples, but only in during capture.</p></body></html>", nullptr));
#endif // QT_CONFIG(tooltip)
        rmsCCB->setText(tr2i18n("rms", nullptr));
#if QT_CONFIG(tooltip)
        rmsCOut->setToolTip(tr2i18n("<html><head/><body><p>The root-mean-squared (RMS) value of the combined RA and DEC drift in arc-seconds, averaged on approximately the past 40 samples, but only in during capture. Click here to view this axis on left-axis values. Shares axis with RA/DEC error, drift, and RMS values. Double click to update axis.</p></body></html>", nullptr));
#endif // QT_CONFIG(tooltip)
#if QT_CONFIG(tooltip)
        targetDistanceCB->setToolTip(tr2i18n("<html><head/><body><p>Plot the distance between the plate-solved captured image and the target position in arc-seconds. Must be enabled in scheduler options.</p></body></html>", nullptr));
#endif // QT_CONFIG(tooltip)
        targetDistanceCB->setText(tr2i18n("dist a-s", nullptr));
#if QT_CONFIG(tooltip)
        targetDistanceOut->setToolTip(tr2i18n("<html><head/><body><p>Plot the distance between the plate-solved captured image and the target position in arc-seconds. Must be enabled in scheduler options. Click here to view this axis on left-axis values. Double click to update axis.</p></body></html>", nullptr));
#endif // QT_CONFIG(tooltip)
#if QT_CONFIG(tooltip)
        focusPositionCB->setToolTip(tr2i18n("<html><head/><body><p>Plot the autofocus solution position.</p></body></html>", nullptr));
#endif // QT_CONFIG(tooltip)
        focusPositionCB->setText(tr2i18n("focus", nullptr));
#if QT_CONFIG(tooltip)
        focusPositionOut->setToolTip(tr2i18n("<html><head/><body><p>Plot the autofocus solution position. Click here to view this axis on left-axis values. Double click to update axis.</p></body></html>", nullptr));
#endif // QT_CONFIG(tooltip)
        detailsCB->setText(tr2i18n("Details", nullptr));
        (void)Analyze;
    } // retranslateUi

};

namespace Ui {
    class Analyze: public Ui_Analyze {};
} // namespace Ui

QT_END_NAMESPACE

#endif // ANALYZE_H

