/********************************************************************************
** Form generated from reading UI file 'optionstreeview.ui'
**
** Created by: Qt User Interface Compiler version 6.11.1
**
** WARNING! All changes made in this file will be lost when recompiling UI file!
********************************************************************************/

#ifndef UI_OPTIONSTREEVIEW_H
#define UI_OPTIONSTREEVIEW_H

#include <QtCore/QVariant>
#include <QtWidgets/QApplication>
#include <QtWidgets/QHeaderView>
#include <QtWidgets/QTreeWidget>
#include <QtWidgets/QVBoxLayout>
#include <QtWidgets/QWidget>
#include <klocalizedstring.h>

QT_BEGIN_NAMESPACE

class Ui_OptionsTreeView
{
public:
    QVBoxLayout *vboxLayout;
    QTreeWidget *OptionsList;

    void setupUi(QWidget *OptionsTreeView)
    {
        if (OptionsTreeView->objectName().isEmpty())
            OptionsTreeView->setObjectName("OptionsTreeView");
        OptionsTreeView->resize(499, 417);
        vboxLayout = new QVBoxLayout(OptionsTreeView);
#ifndef UI_Q_OS_MAC
        vboxLayout->setSpacing(6);
#endif
#ifndef UI_Q_OS_MAC
        vboxLayout->setContentsMargins(9, 9, 9, 9);
#endif
        vboxLayout->setObjectName("vboxLayout");
        OptionsList = new QTreeWidget(OptionsTreeView);
        OptionsList->setObjectName("OptionsList");

        vboxLayout->addWidget(OptionsList);


        retranslateUi(OptionsTreeView);

        QMetaObject::connectSlotsByName(OptionsTreeView);
    } // setupUi

    void retranslateUi(QWidget *OptionsTreeView)
    {
        QTreeWidgetItem *___qtreewidgetitem = OptionsList->headerItem();
        ___qtreewidgetitem->setText(2, tr2i18n("Type", nullptr));
        ___qtreewidgetitem->setText(1, tr2i18n("Description", nullptr));
        ___qtreewidgetitem->setText(0, tr2i18n("Option Name", nullptr));
        (void)OptionsTreeView;
    } // retranslateUi

};

namespace Ui {
    class OptionsTreeView: public Ui_OptionsTreeView {};
} // namespace Ui

QT_END_NAMESPACE

#endif // OPTIONSTREEVIEW_H

