/********************************************************************************
** Form generated from reading UI file 'manualrotator.ui'
**
** Created by: Qt User Interface Compiler version 6.11.1
**
** WARNING! All changes made in this file will be lost when recompiling UI file!
********************************************************************************/

#ifndef UI_MANUALROTATOR_H
#define UI_MANUALROTATOR_H

#include <QtCore/QVariant>
#include <QtWidgets/QApplication>
#include <QtWidgets/QDialog>
#include <QtWidgets/QGridLayout>
#include <QtWidgets/QHBoxLayout>
#include <QtWidgets/QLabel>
#include <QtWidgets/QLineEdit>
#include <QtWidgets/QPushButton>
#include <QtWidgets/QVBoxLayout>
#include <klocalizedstring.h>

QT_BEGIN_NAMESPACE

class Ui_ManualRotator
{
public:
    QVBoxLayout *verticalLayout_1;
    QLabel *helpLabel;
    QHBoxLayout *horizontalLayout_2;
    QGridLayout *gridLayout;
    QLabel *currentRotationL;
    QLineEdit *currentRotation;
    QLabel *targetRotationL;
    QLineEdit *targetRotation;
    QLabel *icon;
    QLabel *diffLabel;
    QHBoxLayout *horizontalLayout_1;
    QPushButton *takeImageB;
    QPushButton *cancelB;

    void setupUi(QDialog *ManualRotator)
    {
        if (ManualRotator->objectName().isEmpty())
            ManualRotator->setObjectName("ManualRotator");
        ManualRotator->resize(400, 600);
        verticalLayout_1 = new QVBoxLayout(ManualRotator);
        verticalLayout_1->setSpacing(3);
        verticalLayout_1->setObjectName("verticalLayout_1");
        verticalLayout_1->setContentsMargins(5, 5, 5, 5);
        helpLabel = new QLabel(ManualRotator);
        helpLabel->setObjectName("helpLabel");
        helpLabel->setAlignment(Qt::AlignJustify|Qt::AlignVCenter);
        helpLabel->setWordWrap(true);

        verticalLayout_1->addWidget(helpLabel);

        horizontalLayout_2 = new QHBoxLayout();
        horizontalLayout_2->setSpacing(3);
        horizontalLayout_2->setObjectName("horizontalLayout_2");
        horizontalLayout_2->setContentsMargins(-1, 10, -1, -1);
        gridLayout = new QGridLayout();
        gridLayout->setObjectName("gridLayout");
        currentRotationL = new QLabel(ManualRotator);
        currentRotationL->setObjectName("currentRotationL");
        currentRotationL->setAlignment(Qt::AlignCenter);

        gridLayout->addWidget(currentRotationL, 0, 0, 1, 1);

        currentRotation = new QLineEdit(ManualRotator);
        currentRotation->setObjectName("currentRotation");
        currentRotation->setAlignment(Qt::AlignCenter);
        currentRotation->setReadOnly(true);

        gridLayout->addWidget(currentRotation, 1, 0, 1, 1);

        targetRotationL = new QLabel(ManualRotator);
        targetRotationL->setObjectName("targetRotationL");
        targetRotationL->setAlignment(Qt::AlignCenter);

        gridLayout->addWidget(targetRotationL, 0, 1, 1, 1);

        targetRotation = new QLineEdit(ManualRotator);
        targetRotation->setObjectName("targetRotation");
        targetRotation->setAlignment(Qt::AlignCenter);
        targetRotation->setReadOnly(true);

        gridLayout->addWidget(targetRotation, 1, 1, 1, 1);


        horizontalLayout_2->addLayout(gridLayout);


        verticalLayout_1->addLayout(horizontalLayout_2);

        icon = new QLabel(ManualRotator);
        icon->setObjectName("icon");
        icon->setAlignment(Qt::AlignCenter);

        verticalLayout_1->addWidget(icon);

        diffLabel = new QLabel(ManualRotator);
        diffLabel->setObjectName("diffLabel");
        QFont font;
        font.setPointSize(64);
        font.setBold(true);
        diffLabel->setFont(font);
        diffLabel->setAlignment(Qt::AlignCenter);

        verticalLayout_1->addWidget(diffLabel);

        horizontalLayout_1 = new QHBoxLayout();
        horizontalLayout_1->setSpacing(3);
        horizontalLayout_1->setObjectName("horizontalLayout_1");
        takeImageB = new QPushButton(ManualRotator);
        takeImageB->setObjectName("takeImageB");

        horizontalLayout_1->addWidget(takeImageB);

        cancelB = new QPushButton(ManualRotator);
        cancelB->setObjectName("cancelB");

        horizontalLayout_1->addWidget(cancelB);


        verticalLayout_1->addLayout(horizontalLayout_1);


        retranslateUi(ManualRotator);

        QMetaObject::connectSlotsByName(ManualRotator);
    } // setupUi

    void retranslateUi(QDialog *ManualRotator)
    {
        ManualRotator->setWindowTitle(tr2i18n("Manual Rotator", nullptr));
        helpLabel->setText(tr2i18n("<html><head/><body><p>To disable rotation validation, uncheck the &quot;Automatic and Manual Rotator Control&quot; in &quot;StellarSolver Options&quot;.</p></body></html>", nullptr));
        currentRotationL->setText(tr2i18n("Current PA", nullptr));
        targetRotationL->setText(tr2i18n("Target PA", nullptr));
        takeImageB->setText(tr2i18n("Take Another Image", nullptr));
        cancelB->setText(tr2i18n("Cancel", nullptr));
    } // retranslateUi

};

namespace Ui {
    class ManualRotator: public Ui_ManualRotator {};
} // namespace Ui

QT_END_NAMESPACE

#endif // MANUALROTATOR_H

