/*
 * This file was generated by qdbusxml2cpp version 0.8
 * Source file was org.kde.kstars.FOV.xml
 *
 * qdbusxml2cpp is Copyright (C) The Qt Company Ltd. and other contributors.
 *
 * This is an auto-generated file.
 * Do not edit! All changes made to it will be lost.
 */

#include "fovadaptor.h"
#include <QtCore/QMetaObject>
#include <QtCore/QByteArray>
#include <QtCore/QList>
#include <QtCore/QMap>
#include <QtCore/QString>
#include <QtCore/QStringList>
#include <QtCore/QVariant>

/*
 * Implementation of adaptor class FovAdaptor
 */

FovAdaptor::FovAdaptor(FOV *parent)
    : QDBusAbstractAdaptor(parent)
{
    // constructor
    setAutoRelaySignals(true);
}

FovAdaptor::~FovAdaptor()
{
    // destructor
}

double FovAdaptor::pA() const
{
    // get the value of property PA
    return qvariant_cast< double >(parent()->property("PA"));
}

void FovAdaptor::setPA(double value)
{
    // set the value of property PA
    parent()->setProperty("PA", QVariant::fromValue(value));
}

QString FovAdaptor::color() const
{
    // get the value of property color
    return qvariant_cast< QString >(parent()->property("color"));
}

void FovAdaptor::setColor(const QString &value)
{
    // set the value of property color
    parent()->setProperty("color", QVariant::fromValue(value));
}

bool FovAdaptor::cpLock() const
{
    // get the value of property cpLock
    return qvariant_cast< bool >(parent()->property("cpLock"));
}

void FovAdaptor::setCpLock(bool value)
{
    // set the value of property cpLock
    parent()->setProperty("cpLock", QVariant::fromValue(value));
}

QString FovAdaptor::name() const
{
    // get the value of property name
    return qvariant_cast< QString >(parent()->property("name"));
}

void FovAdaptor::setName(const QString &value)
{
    // set the value of property name
    parent()->setProperty("name", QVariant::fromValue(value));
}

double FovAdaptor::offsetX() const
{
    // get the value of property offsetX
    return qvariant_cast< double >(parent()->property("offsetX"));
}

void FovAdaptor::setOffsetX(double value)
{
    // set the value of property offsetX
    parent()->setProperty("offsetX", QVariant::fromValue(value));
}

double FovAdaptor::offsetY() const
{
    // get the value of property offsetY
    return qvariant_cast< double >(parent()->property("offsetY"));
}

void FovAdaptor::setOffsetY(double value)
{
    // set the value of property offsetY
    parent()->setProperty("offsetY", QVariant::fromValue(value));
}

FOV::Shape FovAdaptor::shape() const
{
    // get the value of property shape
    return qvariant_cast< FOV::Shape >(parent()->property("shape"));
}

void FovAdaptor::setShape(FOV::Shape value)
{
    // set the value of property shape
    parent()->setProperty("shape", QVariant::fromValue(value));
}

double FovAdaptor::sizeX() const
{
    // get the value of property sizeX
    return qvariant_cast< double >(parent()->property("sizeX"));
}

void FovAdaptor::setSizeX(double value)
{
    // set the value of property sizeX
    parent()->setProperty("sizeX", QVariant::fromValue(value));
}

double FovAdaptor::sizeY() const
{
    // get the value of property sizeY
    return qvariant_cast< double >(parent()->property("sizeY"));
}

void FovAdaptor::setSizeY(double value)
{
    // set the value of property sizeY
    parent()->setProperty("sizeY", QVariant::fromValue(value));
}


#include "moc_fovadaptor.cpp"
