/********************************************************************************
** Form generated from reading UI file 'obslistwizard.ui'
**
** Created by: Qt User Interface Compiler version 6.11.1
**
** WARNING! All changes made in this file will be lost when recompiling UI file!
********************************************************************************/

#ifndef UI_OBSLISTWIZARD_H
#define UI_OBSLISTWIZARD_H

#include <QtCore/QVariant>
#include <QtWidgets/QApplication>
#include <QtWidgets/QCheckBox>
#include <QtWidgets/QDateEdit>
#include <QtWidgets/QDoubleSpinBox>
#include <QtWidgets/QGridLayout>
#include <QtWidgets/QHBoxLayout>
#include <QtWidgets/QLabel>
#include <QtWidgets/QListWidget>
#include <QtWidgets/QPushButton>
#include <QtWidgets/QSpacerItem>
#include <QtWidgets/QStackedWidget>
#include <QtWidgets/QTimeEdit>
#include <QtWidgets/QVBoxLayout>
#include <QtWidgets/QWidget>
#include <klocalizedstring.h>
#include "widgets/dmsbox.h"
#include "widgets/magnitudespinbox.h"

QT_BEGIN_NAMESPACE

class Ui_ObsListWizard
{
public:
    QVBoxLayout *verticalLayout_2;
    QStackedWidget *olwStack;
    QWidget *WelcomePage;
    QVBoxLayout *vboxLayout;
    QLabel *WelcomeText;
    QWidget *ObjectTypePage;
    QVBoxLayout *vboxLayout1;
    QLabel *ObjTypeLabel;
    QHBoxLayout *hboxLayout;
    QListWidget *TypeList;
    QVBoxLayout *vboxLayout2;
    QPushButton *AllButton;
    QPushButton *NoneButton;
    QPushButton *DeepSkyButton;
    QPushButton *SolarSystemButton;
    QSpacerItem *spacerItem;
    QSpacerItem *spacerItem1;
    QWidget *RegionSelectPage;
    QVBoxLayout *vboxLayout3;
    QLabel *RegionSelectText;
    QHBoxLayout *hboxLayout1;
    QVBoxLayout *vboxLayout4;
    QLabel *RegionSelectLabel;
    QSpacerItem *spacerItem2;
    QListWidget *RegionList;
    QSpacerItem *spacerItem3;
    QWidget *ConstellationPage;
    QVBoxLayout *vboxLayout5;
    QLabel *ConstellationText;
    QListWidget *ConstellationList;
    QWidget *RectangularRegionPage;
    QVBoxLayout *vboxLayout6;
    QLabel *RectangularRegionText;
    QGridLayout *gridLayout;
    QLabel *label_2;
    dmsBox *RAMax;
    QLabel *label;
    dmsBox *RAMin;
    dmsBox *DecMax;
    QLabel *DecLabel;
    QLabel *RALabel;
    dmsBox *DecMin;
    QSpacerItem *spacerItem4;
    QWidget *CircularRegionPage;
    QVBoxLayout *vboxLayout7;
    QLabel *CircularRegionText;
    QHBoxLayout *hboxLayout2;
    QSpacerItem *spacerItem5;
    QVBoxLayout *vboxLayout8;
    QGridLayout *gridLayout1;
    QLabel *CenterRALabel;
    dmsBox *RA;
    dmsBox *Dec;
    QLabel *CenterDecLabel;
    QHBoxLayout *hboxLayout3;
    QLabel *RadiusLabel;
    dmsBox *Radius;
    QSpacerItem *spacerItem6;
    QSpacerItem *spacerItem7;
    QWidget *ObserveOnDatePage;
    QVBoxLayout *verticalLayout;
    QLabel *ObserveOnDateText;
    QSpacerItem *spacerItem8;
    QHBoxLayout *horizontalLayout_2;
    QGridLayout *conditionsGrid;
    QDoubleSpinBox *minAlt;
    QLabel *label_4;
    QLabel *LocationText;
    QLabel *label_6;
    QTimeEdit *timeFrom;
    QLabel *label_8;
    QDoubleSpinBox *coverage;
    QLabel *label_5;
    QLabel *label_7;
    QTimeEdit *timeTo;
    QDoubleSpinBox *maxAlt;
    QCheckBox *SelectByDate;
    QDateEdit *Date;
    QPushButton *LocationButton;
    QSpacerItem *horizontalSpacer;
    QSpacerItem *spacerItem9;
    QWidget *MagnitudePage;
    QVBoxLayout *vboxLayout9;
    QLabel *MagnitudeText;
    QHBoxLayout *hboxLayout4;
    QCheckBox *SelectByMagnitude;
    MagnitudeSpinBox *Mag;
    QLabel *label_3;
    QSpacerItem *spacerItem10;
    QHBoxLayout *hboxLayout5;
    QSpacerItem *spacerItem11;
    QCheckBox *IncludeNoMag;
    QSpacerItem *spacerItem12;
    QSpacerItem *spacerItem13;
    QHBoxLayout *horizontalLayout;
    QLabel *CountLabel;
    QPushButton *updateButton;

    void setupUi(QWidget *ObsListWizard)
    {
        if (ObsListWizard->objectName().isEmpty())
            ObsListWizard->setObjectName("ObsListWizard");
        ObsListWizard->resize(489, 372);
        verticalLayout_2 = new QVBoxLayout(ObsListWizard);
        verticalLayout_2->setObjectName("verticalLayout_2");
        olwStack = new QStackedWidget(ObsListWizard);
        olwStack->setObjectName("olwStack");
        WelcomePage = new QWidget();
        WelcomePage->setObjectName("WelcomePage");
        vboxLayout = new QVBoxLayout(WelcomePage);
        vboxLayout->setSpacing(6);
        vboxLayout->setObjectName("vboxLayout");
        vboxLayout->setContentsMargins(9, 9, 9, 9);
        WelcomeText = new QLabel(WelcomePage);
        WelcomeText->setObjectName("WelcomeText");
        WelcomeText->setAlignment(Qt::AlignLeading|Qt::AlignLeft|Qt::AlignTop);
        WelcomeText->setWordWrap(true);

        vboxLayout->addWidget(WelcomeText);

        olwStack->addWidget(WelcomePage);
        ObjectTypePage = new QWidget();
        ObjectTypePage->setObjectName("ObjectTypePage");
        vboxLayout1 = new QVBoxLayout(ObjectTypePage);
        vboxLayout1->setSpacing(6);
        vboxLayout1->setObjectName("vboxLayout1");
        vboxLayout1->setContentsMargins(9, 9, 9, 9);
        ObjTypeLabel = new QLabel(ObjectTypePage);
        ObjTypeLabel->setObjectName("ObjTypeLabel");
        ObjTypeLabel->setWordWrap(true);

        vboxLayout1->addWidget(ObjTypeLabel);

        hboxLayout = new QHBoxLayout();
        hboxLayout->setSpacing(6);
        hboxLayout->setObjectName("hboxLayout");
        hboxLayout->setContentsMargins(0, 0, 0, 0);
        TypeList = new QListWidget(ObjectTypePage);
        new QListWidgetItem(TypeList);
        new QListWidgetItem(TypeList);
        new QListWidgetItem(TypeList);
        new QListWidgetItem(TypeList);
        new QListWidgetItem(TypeList);
        new QListWidgetItem(TypeList);
        new QListWidgetItem(TypeList);
        new QListWidgetItem(TypeList);
        new QListWidgetItem(TypeList);
        TypeList->setObjectName("TypeList");
        TypeList->setSelectionMode(QAbstractItemView::ExtendedSelection);

        hboxLayout->addWidget(TypeList);

        vboxLayout2 = new QVBoxLayout();
        vboxLayout2->setSpacing(6);
        vboxLayout2->setObjectName("vboxLayout2");
        vboxLayout2->setContentsMargins(0, 0, 0, 0);
        AllButton = new QPushButton(ObjectTypePage);
        AllButton->setObjectName("AllButton");

        vboxLayout2->addWidget(AllButton);

        NoneButton = new QPushButton(ObjectTypePage);
        NoneButton->setObjectName("NoneButton");

        vboxLayout2->addWidget(NoneButton);

        DeepSkyButton = new QPushButton(ObjectTypePage);
        DeepSkyButton->setObjectName("DeepSkyButton");

        vboxLayout2->addWidget(DeepSkyButton);

        SolarSystemButton = new QPushButton(ObjectTypePage);
        SolarSystemButton->setObjectName("SolarSystemButton");

        vboxLayout2->addWidget(SolarSystemButton);

        spacerItem = new QSpacerItem(20, 21, QSizePolicy::Policy::Minimum, QSizePolicy::Policy::Expanding);

        vboxLayout2->addItem(spacerItem);


        hboxLayout->addLayout(vboxLayout2);


        vboxLayout1->addLayout(hboxLayout);

        spacerItem1 = new QSpacerItem(20, 40, QSizePolicy::Policy::Minimum, QSizePolicy::Policy::Expanding);

        vboxLayout1->addItem(spacerItem1);

        olwStack->addWidget(ObjectTypePage);
        RegionSelectPage = new QWidget();
        RegionSelectPage->setObjectName("RegionSelectPage");
        vboxLayout3 = new QVBoxLayout(RegionSelectPage);
        vboxLayout3->setSpacing(6);
        vboxLayout3->setObjectName("vboxLayout3");
        vboxLayout3->setContentsMargins(9, 9, 9, 9);
        RegionSelectText = new QLabel(RegionSelectPage);
        RegionSelectText->setObjectName("RegionSelectText");
        RegionSelectText->setWordWrap(true);

        vboxLayout3->addWidget(RegionSelectText);

        hboxLayout1 = new QHBoxLayout();
        hboxLayout1->setSpacing(6);
        hboxLayout1->setObjectName("hboxLayout1");
        hboxLayout1->setContentsMargins(0, 0, 0, 0);
        vboxLayout4 = new QVBoxLayout();
        vboxLayout4->setSpacing(6);
        vboxLayout4->setObjectName("vboxLayout4");
        vboxLayout4->setContentsMargins(0, 0, 0, 0);
        RegionSelectLabel = new QLabel(RegionSelectPage);
        RegionSelectLabel->setObjectName("RegionSelectLabel");

        vboxLayout4->addWidget(RegionSelectLabel);

        spacerItem2 = new QSpacerItem(20, 21, QSizePolicy::Policy::Minimum, QSizePolicy::Policy::Expanding);

        vboxLayout4->addItem(spacerItem2);


        hboxLayout1->addLayout(vboxLayout4);

        RegionList = new QListWidget(RegionSelectPage);
        new QListWidgetItem(RegionList);
        new QListWidgetItem(RegionList);
        new QListWidgetItem(RegionList);
        new QListWidgetItem(RegionList);
        RegionList->setObjectName("RegionList");
        QSizePolicy sizePolicy(QSizePolicy::Policy::Expanding, QSizePolicy::Policy::Preferred);
        sizePolicy.setHorizontalStretch(0);
        sizePolicy.setVerticalStretch(0);
        sizePolicy.setHeightForWidth(RegionList->sizePolicy().hasHeightForWidth());
        RegionList->setSizePolicy(sizePolicy);

        hboxLayout1->addWidget(RegionList);


        vboxLayout3->addLayout(hboxLayout1);

        spacerItem3 = new QSpacerItem(20, 40, QSizePolicy::Policy::Minimum, QSizePolicy::Policy::Expanding);

        vboxLayout3->addItem(spacerItem3);

        olwStack->addWidget(RegionSelectPage);
        ConstellationPage = new QWidget();
        ConstellationPage->setObjectName("ConstellationPage");
        vboxLayout5 = new QVBoxLayout(ConstellationPage);
        vboxLayout5->setSpacing(6);
        vboxLayout5->setObjectName("vboxLayout5");
        vboxLayout5->setContentsMargins(9, 9, 9, 9);
        ConstellationText = new QLabel(ConstellationPage);
        ConstellationText->setObjectName("ConstellationText");
        ConstellationText->setWordWrap(true);

        vboxLayout5->addWidget(ConstellationText);

        ConstellationList = new QListWidget(ConstellationPage);
        ConstellationList->setObjectName("ConstellationList");
        ConstellationList->setSelectionMode(QAbstractItemView::ExtendedSelection);

        vboxLayout5->addWidget(ConstellationList);

        olwStack->addWidget(ConstellationPage);
        RectangularRegionPage = new QWidget();
        RectangularRegionPage->setObjectName("RectangularRegionPage");
        vboxLayout6 = new QVBoxLayout(RectangularRegionPage);
        vboxLayout6->setSpacing(6);
        vboxLayout6->setObjectName("vboxLayout6");
        vboxLayout6->setContentsMargins(9, 9, 9, 9);
        RectangularRegionText = new QLabel(RectangularRegionPage);
        RectangularRegionText->setObjectName("RectangularRegionText");
        RectangularRegionText->setWordWrap(true);

        vboxLayout6->addWidget(RectangularRegionText);

        gridLayout = new QGridLayout();
        gridLayout->setSpacing(6);
        gridLayout->setObjectName("gridLayout");
        gridLayout->setContentsMargins(0, 0, 0, 0);
        label_2 = new QLabel(RectangularRegionPage);
        label_2->setObjectName("label_2");

        gridLayout->addWidget(label_2, 1, 2, 1, 1);

        RAMax = new dmsBox(RectangularRegionPage);
        RAMax->setObjectName("RAMax");

        gridLayout->addWidget(RAMax, 0, 3, 1, 1);

        label = new QLabel(RectangularRegionPage);
        label->setObjectName("label");

        gridLayout->addWidget(label, 0, 2, 1, 1);

        RAMin = new dmsBox(RectangularRegionPage);
        RAMin->setObjectName("RAMin");

        gridLayout->addWidget(RAMin, 0, 1, 1, 1);

        DecMax = new dmsBox(RectangularRegionPage);
        DecMax->setObjectName("DecMax");

        gridLayout->addWidget(DecMax, 1, 3, 1, 1);

        DecLabel = new QLabel(RectangularRegionPage);
        DecLabel->setObjectName("DecLabel");

        gridLayout->addWidget(DecLabel, 1, 0, 1, 1);

        RALabel = new QLabel(RectangularRegionPage);
        RALabel->setObjectName("RALabel");

        gridLayout->addWidget(RALabel, 0, 0, 1, 1);

        DecMin = new dmsBox(RectangularRegionPage);
        DecMin->setObjectName("DecMin");

        gridLayout->addWidget(DecMin, 1, 1, 1, 1);


        vboxLayout6->addLayout(gridLayout);

        spacerItem4 = new QSpacerItem(20, 40, QSizePolicy::Policy::Minimum, QSizePolicy::Policy::Expanding);

        vboxLayout6->addItem(spacerItem4);

        olwStack->addWidget(RectangularRegionPage);
        CircularRegionPage = new QWidget();
        CircularRegionPage->setObjectName("CircularRegionPage");
        vboxLayout7 = new QVBoxLayout(CircularRegionPage);
        vboxLayout7->setSpacing(6);
        vboxLayout7->setObjectName("vboxLayout7");
        vboxLayout7->setContentsMargins(9, 9, 9, 9);
        CircularRegionText = new QLabel(CircularRegionPage);
        CircularRegionText->setObjectName("CircularRegionText");
        CircularRegionText->setWordWrap(true);

        vboxLayout7->addWidget(CircularRegionText);

        hboxLayout2 = new QHBoxLayout();
        hboxLayout2->setSpacing(6);
        hboxLayout2->setObjectName("hboxLayout2");
        hboxLayout2->setContentsMargins(0, 0, 0, 0);
        spacerItem5 = new QSpacerItem(40, 20, QSizePolicy::Policy::Expanding, QSizePolicy::Policy::Minimum);

        hboxLayout2->addItem(spacerItem5);

        vboxLayout8 = new QVBoxLayout();
        vboxLayout8->setSpacing(6);
        vboxLayout8->setObjectName("vboxLayout8");
        vboxLayout8->setContentsMargins(0, 0, 0, 0);
        gridLayout1 = new QGridLayout();
        gridLayout1->setSpacing(6);
        gridLayout1->setObjectName("gridLayout1");
        gridLayout1->setContentsMargins(0, 0, 0, 0);
        CenterRALabel = new QLabel(CircularRegionPage);
        CenterRALabel->setObjectName("CenterRALabel");

        gridLayout1->addWidget(CenterRALabel, 0, 0, 1, 1);

        RA = new dmsBox(CircularRegionPage);
        RA->setObjectName("RA");

        gridLayout1->addWidget(RA, 0, 1, 1, 1);

        Dec = new dmsBox(CircularRegionPage);
        Dec->setObjectName("Dec");

        gridLayout1->addWidget(Dec, 1, 1, 1, 1);

        CenterDecLabel = new QLabel(CircularRegionPage);
        CenterDecLabel->setObjectName("CenterDecLabel");

        gridLayout1->addWidget(CenterDecLabel, 1, 0, 1, 1);


        vboxLayout8->addLayout(gridLayout1);

        hboxLayout3 = new QHBoxLayout();
        hboxLayout3->setSpacing(6);
        hboxLayout3->setObjectName("hboxLayout3");
        hboxLayout3->setContentsMargins(0, 0, 0, 0);
        RadiusLabel = new QLabel(CircularRegionPage);
        RadiusLabel->setObjectName("RadiusLabel");

        hboxLayout3->addWidget(RadiusLabel);

        Radius = new dmsBox(CircularRegionPage);
        Radius->setObjectName("Radius");

        hboxLayout3->addWidget(Radius);


        vboxLayout8->addLayout(hboxLayout3);


        hboxLayout2->addLayout(vboxLayout8);

        spacerItem6 = new QSpacerItem(40, 20, QSizePolicy::Policy::Expanding, QSizePolicy::Policy::Minimum);

        hboxLayout2->addItem(spacerItem6);


        vboxLayout7->addLayout(hboxLayout2);

        spacerItem7 = new QSpacerItem(20, 40, QSizePolicy::Policy::Minimum, QSizePolicy::Policy::Expanding);

        vboxLayout7->addItem(spacerItem7);

        olwStack->addWidget(CircularRegionPage);
        ObserveOnDatePage = new QWidget();
        ObserveOnDatePage->setObjectName("ObserveOnDatePage");
        verticalLayout = new QVBoxLayout(ObserveOnDatePage);
        verticalLayout->setObjectName("verticalLayout");
        ObserveOnDateText = new QLabel(ObserveOnDatePage);
        ObserveOnDateText->setObjectName("ObserveOnDateText");
        ObserveOnDateText->setWordWrap(true);

        verticalLayout->addWidget(ObserveOnDateText);

        spacerItem8 = new QSpacerItem(539, 20, QSizePolicy::Policy::Expanding, QSizePolicy::Policy::Minimum);

        verticalLayout->addItem(spacerItem8);

        horizontalLayout_2 = new QHBoxLayout();
        horizontalLayout_2->setObjectName("horizontalLayout_2");
        conditionsGrid = new QGridLayout();
        conditionsGrid->setObjectName("conditionsGrid");
        minAlt = new QDoubleSpinBox(ObserveOnDatePage);
        minAlt->setObjectName("minAlt");
        minAlt->setEnabled(false);
        minAlt->setMaximum(90.000000000000000);
        minAlt->setValue(15.000000000000000);

        conditionsGrid->addWidget(minAlt, 3, 1, 1, 1);

        label_4 = new QLabel(ObserveOnDatePage);
        label_4->setObjectName("label_4");

        conditionsGrid->addWidget(label_4, 1, 0, 1, 1);

        LocationText = new QLabel(ObserveOnDatePage);
        LocationText->setObjectName("LocationText");

        conditionsGrid->addWidget(LocationText, 5, 0, 1, 1);

        label_6 = new QLabel(ObserveOnDatePage);
        label_6->setObjectName("label_6");

        conditionsGrid->addWidget(label_6, 3, 0, 1, 1);

        timeFrom = new QTimeEdit(ObserveOnDatePage);
        timeFrom->setObjectName("timeFrom");
        timeFrom->setEnabled(false);

        conditionsGrid->addWidget(timeFrom, 1, 1, 1, 1);

        label_8 = new QLabel(ObserveOnDatePage);
        label_8->setObjectName("label_8");

        conditionsGrid->addWidget(label_8, 4, 0, 1, 1);

        coverage = new QDoubleSpinBox(ObserveOnDatePage);
        coverage->setObjectName("coverage");
        coverage->setMaximum(100.000000000000000);
        coverage->setValue(40.000000000000000);

        conditionsGrid->addWidget(coverage, 4, 1, 1, 1);

        label_5 = new QLabel(ObserveOnDatePage);
        label_5->setObjectName("label_5");

        conditionsGrid->addWidget(label_5, 1, 2, 1, 1);

        label_7 = new QLabel(ObserveOnDatePage);
        label_7->setObjectName("label_7");

        conditionsGrid->addWidget(label_7, 3, 2, 1, 1);

        timeTo = new QTimeEdit(ObserveOnDatePage);
        timeTo->setObjectName("timeTo");
        timeTo->setEnabled(false);

        conditionsGrid->addWidget(timeTo, 1, 3, 1, 1);

        maxAlt = new QDoubleSpinBox(ObserveOnDatePage);
        maxAlt->setObjectName("maxAlt");
        maxAlt->setEnabled(false);
        maxAlt->setMaximum(90.000000000000000);
        maxAlt->setValue(90.000000000000000);

        conditionsGrid->addWidget(maxAlt, 3, 3, 1, 1);

        SelectByDate = new QCheckBox(ObserveOnDatePage);
        SelectByDate->setObjectName("SelectByDate");

        conditionsGrid->addWidget(SelectByDate, 0, 0, 1, 2);

        Date = new QDateEdit(ObserveOnDatePage);
        Date->setObjectName("Date");
        Date->setEnabled(false);

        conditionsGrid->addWidget(Date, 0, 2, 1, 2);

        LocationButton = new QPushButton(ObserveOnDatePage);
        LocationButton->setObjectName("LocationButton");
        LocationButton->setEnabled(false);
        QSizePolicy sizePolicy1(QSizePolicy::Policy::Minimum, QSizePolicy::Policy::Fixed);
        sizePolicy1.setHorizontalStretch(0);
        sizePolicy1.setVerticalStretch(0);
        sizePolicy1.setHeightForWidth(LocationButton->sizePolicy().hasHeightForWidth());
        LocationButton->setSizePolicy(sizePolicy1);

        conditionsGrid->addWidget(LocationButton, 5, 1, 1, 3);


        horizontalLayout_2->addLayout(conditionsGrid);

        horizontalSpacer = new QSpacerItem(40, 20, QSizePolicy::Policy::Expanding, QSizePolicy::Policy::Minimum);

        horizontalLayout_2->addItem(horizontalSpacer);


        verticalLayout->addLayout(horizontalLayout_2);

        spacerItem9 = new QSpacerItem(20, 111, QSizePolicy::Policy::Minimum, QSizePolicy::Policy::Expanding);

        verticalLayout->addItem(spacerItem9);

        olwStack->addWidget(ObserveOnDatePage);
        MagnitudePage = new QWidget();
        MagnitudePage->setObjectName("MagnitudePage");
        vboxLayout9 = new QVBoxLayout(MagnitudePage);
        vboxLayout9->setSpacing(6);
        vboxLayout9->setObjectName("vboxLayout9");
        vboxLayout9->setContentsMargins(9, 9, 9, 9);
        MagnitudeText = new QLabel(MagnitudePage);
        MagnitudeText->setObjectName("MagnitudeText");
        MagnitudeText->setWordWrap(true);

        vboxLayout9->addWidget(MagnitudeText);

        hboxLayout4 = new QHBoxLayout();
        hboxLayout4->setSpacing(6);
        hboxLayout4->setObjectName("hboxLayout4");
        hboxLayout4->setContentsMargins(0, 0, 0, 0);
        SelectByMagnitude = new QCheckBox(MagnitudePage);
        SelectByMagnitude->setObjectName("SelectByMagnitude");

        hboxLayout4->addWidget(SelectByMagnitude);

        Mag = new MagnitudeSpinBox(MagnitudePage);
        Mag->setObjectName("Mag");
        Mag->setEnabled(false);

        hboxLayout4->addWidget(Mag);

        label_3 = new QLabel(MagnitudePage);
        label_3->setObjectName("label_3");

        hboxLayout4->addWidget(label_3);

        spacerItem10 = new QSpacerItem(40, 20, QSizePolicy::Policy::Expanding, QSizePolicy::Policy::Minimum);

        hboxLayout4->addItem(spacerItem10);


        vboxLayout9->addLayout(hboxLayout4);

        hboxLayout5 = new QHBoxLayout();
        hboxLayout5->setSpacing(6);
        hboxLayout5->setObjectName("hboxLayout5");
        hboxLayout5->setContentsMargins(0, 0, 0, 0);
        spacerItem11 = new QSpacerItem(16, 20, QSizePolicy::Policy::Fixed, QSizePolicy::Policy::Minimum);

        hboxLayout5->addItem(spacerItem11);

        IncludeNoMag = new QCheckBox(MagnitudePage);
        IncludeNoMag->setObjectName("IncludeNoMag");
        IncludeNoMag->setEnabled(false);

        hboxLayout5->addWidget(IncludeNoMag);

        spacerItem12 = new QSpacerItem(40, 20, QSizePolicy::Policy::Expanding, QSizePolicy::Policy::Minimum);

        hboxLayout5->addItem(spacerItem12);


        vboxLayout9->addLayout(hboxLayout5);

        spacerItem13 = new QSpacerItem(20, 40, QSizePolicy::Policy::Minimum, QSizePolicy::Policy::Expanding);

        vboxLayout9->addItem(spacerItem13);

        olwStack->addWidget(MagnitudePage);

        verticalLayout_2->addWidget(olwStack);

        horizontalLayout = new QHBoxLayout();
        horizontalLayout->setObjectName("horizontalLayout");
        CountLabel = new QLabel(ObsListWizard);
        CountLabel->setObjectName("CountLabel");
        CountLabel->setFrameShape(QFrame::StyledPanel);

        horizontalLayout->addWidget(CountLabel);

        updateButton = new QPushButton(ObsListWizard);
        updateButton->setObjectName("updateButton");

        horizontalLayout->addWidget(updateButton);


        verticalLayout_2->addLayout(horizontalLayout);

        QWidget::setTabOrder(TypeList, AllButton);
        QWidget::setTabOrder(AllButton, NoneButton);
        QWidget::setTabOrder(NoneButton, DeepSkyButton);
        QWidget::setTabOrder(DeepSkyButton, SolarSystemButton);
        QWidget::setTabOrder(SolarSystemButton, RegionList);
        QWidget::setTabOrder(RegionList, ConstellationList);
        QWidget::setTabOrder(ConstellationList, RAMin);
        QWidget::setTabOrder(RAMin, RAMax);
        QWidget::setTabOrder(RAMax, DecMin);
        QWidget::setTabOrder(DecMin, DecMax);
        QWidget::setTabOrder(DecMax, RA);
        QWidget::setTabOrder(RA, Dec);
        QWidget::setTabOrder(Dec, Radius);
        QWidget::setTabOrder(Radius, SelectByDate);
        QWidget::setTabOrder(SelectByDate, SelectByMagnitude);
        QWidget::setTabOrder(SelectByMagnitude, IncludeNoMag);

        retranslateUi(ObsListWizard);

        olwStack->setCurrentIndex(0);
        RegionList->setCurrentRow(0);


        QMetaObject::connectSlotsByName(ObsListWizard);
    } // setupUi

    void retranslateUi(QWidget *ObsListWizard)
    {
        ObsListWizard->setWindowTitle(tr2i18n("Observing List Wizard", nullptr));
        WelcomeText->setText(tr2i18n("<html><head></head><body><p>Welcome to the Observing List Wizard</p><p></p><p>With this tool, you can construct an observing list by filtering the list of all objects in various ways.  First, you will select objects by <span style=\" font-weight:600;\">type</span>.  Next, you can select only those objects which occupy a specific <span style=\" font-weight:600;\">region on the sky</span>.  You can further trim the observing list by selecting objects in a specified <span style=\" font-weight:600;\">magnitude range</span>.  Finally, you can choose to keep only those objects which are <span style=\" font-weight:600;\">observable on a particular date</span>.</p><p></p><p>Press the <span style=\" font-weight:600;\">Next</span> button to get started by selecting which object types you would like to be present in your observing list.</p></body></html>", nullptr));
        ObjTypeLabel->setText(tr2i18n("<html><head></head><body><p>Select objects by type</p><p></p><p>Highlight the object types you want to include in your observing list in the box below.  You can highlight more than one item in the list.  The buttons along the right can be used to quickly choose some common selections.</p><p></p><p>When you are finished, press the <span style=\" font-weight:600;\">Next</span> button.</p></body></html>", nullptr));

        const bool __sortingEnabled = TypeList->isSortingEnabled();
        TypeList->setSortingEnabled(false);
        QListWidgetItem *___qlistwidgetitem = TypeList->item(0);
        ___qlistwidgetitem->setText(tr2i18n("Stars", nullptr));
        QListWidgetItem *___qlistwidgetitem1 = TypeList->item(1);
        ___qlistwidgetitem1->setText(tr2i18n("Sun, moon, planets", nullptr));
        QListWidgetItem *___qlistwidgetitem2 = TypeList->item(2);
        ___qlistwidgetitem2->setText(tr2i18n("Comets", nullptr));
        QListWidgetItem *___qlistwidgetitem3 = TypeList->item(3);
        ___qlistwidgetitem3->setText(tr2i18n("Asteroids", nullptr));
        QListWidgetItem *___qlistwidgetitem4 = TypeList->item(4);
        ___qlistwidgetitem4->setText(tr2i18n("Open clusters", nullptr));
        QListWidgetItem *___qlistwidgetitem5 = TypeList->item(5);
        ___qlistwidgetitem5->setText(tr2i18n("Globular clusters", nullptr));
        QListWidgetItem *___qlistwidgetitem6 = TypeList->item(6);
        ___qlistwidgetitem6->setText(tr2i18n("Gaseous nebulae", nullptr));
        QListWidgetItem *___qlistwidgetitem7 = TypeList->item(7);
        ___qlistwidgetitem7->setText(tr2i18n("Planetary nebulae", nullptr));
        QListWidgetItem *___qlistwidgetitem8 = TypeList->item(8);
        ___qlistwidgetitem8->setText(tr2i18n("Galaxies", nullptr));
        TypeList->setSortingEnabled(__sortingEnabled);

#if QT_CONFIG(tooltip)
        AllButton->setToolTip(tr2i18n("Select all items in the list", nullptr));
#endif // QT_CONFIG(tooltip)
        AllButton->setText(tr2i18n("All", nullptr));
#if QT_CONFIG(tooltip)
        NoneButton->setToolTip(tr2i18n("Clear all selected items in the list", nullptr));
#endif // QT_CONFIG(tooltip)
        NoneButton->setText(tr2i18n("None", nullptr));
#if QT_CONFIG(tooltip)
        DeepSkyButton->setToolTip(tr2i18n("Select all \"deep-sky\" object types in the list", nullptr));
#endif // QT_CONFIG(tooltip)
        DeepSkyButton->setText(tr2i18n("Deep sky", nullptr));
#if QT_CONFIG(tooltip)
        SolarSystemButton->setToolTip(tr2i18n("Select all solar system object types in the list", nullptr));
#endif // QT_CONFIG(tooltip)
        SolarSystemButton->setText(tr2i18n("Solar system", nullptr));
        RegionSelectText->setText(tr2i18n("<html><head></head><body><p>Select by region</p><p></p><p>Next, you can limit your object list to only those objects which occupy a specific region on the sky.  There are three ways to specify the region for your list:  by <span style=\" font-weight:600;\">constellation</span>, by specifying a <span style=\" font-weight:600;\">rectangular region</span>, or by specifying a <span style=\" font-weight:600;\">circular region</span>.  You may also skip selecting by a region, which will include objects from <span style=\" font-weight:600;\">all over the sky</span>.</p><p></p><p>Make your selection below, and press <span style=\" font-weight:600;\">Next</span>.</p></body></html>", nullptr));
        RegionSelectLabel->setText(tr2i18n("I wish to select objects:", nullptr));

        const bool __sortingEnabled1 = RegionList->isSortingEnabled();
        RegionList->setSortingEnabled(false);
        QListWidgetItem *___qlistwidgetitem9 = RegionList->item(0);
        ___qlistwidgetitem9->setText(tr2i18n("all over the sky", nullptr));
        QListWidgetItem *___qlistwidgetitem10 = RegionList->item(1);
        ___qlistwidgetitem10->setText(tr2i18n("by constellation", nullptr));
        QListWidgetItem *___qlistwidgetitem11 = RegionList->item(2);
        ___qlistwidgetitem11->setText(tr2i18n("in a rectangular region", nullptr));
        QListWidgetItem *___qlistwidgetitem12 = RegionList->item(3);
        ___qlistwidgetitem12->setText(tr2i18n("in a circular region", nullptr));
        RegionList->setSortingEnabled(__sortingEnabled1);

        ConstellationText->setText(tr2i18n("<html><head></head><body><p>Select objects in one or more constellations</p><p></p><p>In the list below, highlight the constellations you want to use for your observing list.  Only objects that occupy the selected constellations will be included in the list.</p><p></p><p>When you are finished, press <span style=\" font-weight:600;\">Next</span> to continue.</p></body></html>", nullptr));
        RectangularRegionText->setText(tr2i18n("<html><head></head><body><p>Select objects in a rectangular region</p><p></p><p>On this page, you can limit your observing list to those objects which occupy a particular rectangular region on the sky.  Specify the rectangular region by selecting the right ascension (RA) and declination (Dec) limits that define the region.</p><p></p><p>When you are finished, press <span style=\" font-weight:600;\">Next</span> to continue.</p></body></html>", nullptr));
        label_2->setText(tr2i18n("to", nullptr));
        label->setText(tr2i18n("to", nullptr));
        DecLabel->setText(tr2i18n("Dec limits:", nullptr));
        RALabel->setText(tr2i18n("RA limits:", nullptr));
        CircularRegionText->setText(tr2i18n("<html><head></head><body><p>Select objects in a circular region</p><p></p><p>On this page, you can limit your observing list to those objects which occupy a particular circular region on the sky.  Specify the circular region by selecting the right ascension (RA) and declination (Dec) coordinates for the center of the circle, and the size of the circle's radius, in Degrees.</p><p></p><p>When you are finished, press <span style=\" font-weight:600;\">Next</span> to continue.</p></body></html>", nullptr));
        CenterRALabel->setText(tr2i18n("Center RA (in Hours):", nullptr));
        CenterDecLabel->setText(tr2i18n("Center Dec (in Degrees):", nullptr));
        RadiusLabel->setText(tr2i18n("Radius (in Degrees):", nullptr));
        ObserveOnDateText->setText(tr2i18n("<html><head></head><body><p>Select objects observable on a date:</p><p></p><p>On this page, you can limit your observing list to only those objects which can be observed on a particular date (and from a particular location on Earth).  To filter your list in this way, check the checkbox below, and then select the desired date.  If you leave this box unchecked, then your list will include objects regardless of when they are observable (this is the default).  You may also change the geographic location used to determine whether objects are observable.</p><p></p><p>When you are finished, press <span style=\" font-weight:600;\">Next</span> to continue.</p><p></p></body></html>", nullptr));
        label_4->setText(tr2i18n("From:", nullptr));
        LocationText->setText(tr2i18n("From: ", nullptr));
        label_6->setText(tr2i18n("Min. Altitude:", nullptr));
#if QT_CONFIG(tooltip)
        label_8->setToolTip(tr2i18n("The object must obey the minimum and maximum altitudes at least this much percentage of the indicated time range.", nullptr));
#endif // QT_CONFIG(tooltip)
        label_8->setText(tr2i18n("Coverage:", nullptr));
#if QT_CONFIG(tooltip)
        coverage->setToolTip(tr2i18n("The object must obey the minimum and maximum altitudes at least this much percentage of the indicated time range.", nullptr));
#endif // QT_CONFIG(tooltip)
        label_5->setText(tr2i18n("To:", nullptr));
        label_7->setText(tr2i18n("Max. Altitude:", nullptr));
        SelectByDate->setText(tr2i18n("Select objects which are observable on:", nullptr));
        LocationButton->setText(tr2i18n("Greenwich, United Kingdom", nullptr));
        MagnitudeText->setText(tr2i18n("<html><head/><body><p>Select bright objects</p><p>On this page, you can limit your observing list to only those objects brighter than a given magnitude. Be careful with this selection, because KStars does not have a magnitude for every object in its database. You need to indicate whether you want to include objects with an undefined magnitude.</p><p>If you do not wish to exclude faint objects with this selection, simply leave the checkbox below unchecked.</p><p>This is the final page of the Observing List Wizard. You can go back and modify previous pages with the <span style=\" font-weight:600;\">Back</span> button. When you are satisfied, press the <span style=\" font-weight:600;\">Ok</span> button to exit the wizard, and the Observing List tool will be populated with the objects you have specified here.</p><p><br/></p></body></html>", nullptr));
        SelectByMagnitude->setText(tr2i18n("Select objects brighter than:", nullptr));
        label_3->setText(tr2i18n("mag", nullptr));
        IncludeNoMag->setText(tr2i18n("Include objects which have no defined magnitude", nullptr));
        CountLabel->setText(tr2i18n("Your observing list currently has 0 objects.", nullptr));
        updateButton->setText(tr2i18n("Update Count", nullptr));
    } // retranslateUi

};

namespace Ui {
    class ObsListWizard: public Ui_ObsListWizard {};
} // namespace Ui

QT_END_NAMESPACE

#endif // OBSLISTWIZARD_H

