/********************************************************************************
** Form generated from reading UI file 'ledstatuswidget.ui'
**
** Created by: Qt User Interface Compiler version 6.11.1
**
** WARNING! All changes made in this file will be lost when recompiling UI file!
********************************************************************************/

#ifndef UI_LEDSTATUSWIDGET_H
#define UI_LEDSTATUSWIDGET_H

#include <QtCore/QVariant>
#include <QtWidgets/QApplication>
#include <QtWidgets/QHBoxLayout>
#include <QtWidgets/QLabel>
#include <QtWidgets/QWidget>
#include <klocalizedstring.h>

QT_BEGIN_NAMESPACE

class Ui_LedStatusWidget
{
public:
    QHBoxLayout *statusLayout;
    QLabel *statusText;

    void setupUi(QWidget *LedStatusWidget)
    {
        if (LedStatusWidget->objectName().isEmpty())
            LedStatusWidget->setObjectName("LedStatusWidget");
        LedStatusWidget->resize(397, 25);
        statusLayout = new QHBoxLayout(LedStatusWidget);
        statusLayout->setObjectName("statusLayout");
        statusLayout->setContentsMargins(0, 0, 0, 0);
        statusText = new QLabel(LedStatusWidget);
        statusText->setObjectName("statusText");
        QSizePolicy sizePolicy(QSizePolicy::Policy::Preferred, QSizePolicy::Policy::MinimumExpanding);
        sizePolicy.setHorizontalStretch(0);
        sizePolicy.setVerticalStretch(1);
        sizePolicy.setHeightForWidth(statusText->sizePolicy().hasHeightForWidth());
        statusText->setSizePolicy(sizePolicy);
        statusText->setMinimumSize(QSize(24, 24));
        statusText->setAlignment(Qt::AlignRight|Qt::AlignTrailing|Qt::AlignVCenter);

        statusLayout->addWidget(statusText, 0, Qt::AlignVCenter);

        statusLayout->setStretch(0, 1);

        retranslateUi(LedStatusWidget);

        QMetaObject::connectSlotsByName(LedStatusWidget);
    } // setupUi

    void retranslateUi(QWidget *LedStatusWidget)
    {
        LedStatusWidget->setWindowTitle(tr2i18n("Form", nullptr));
        statusText->setText(tr2i18n("<unknown>", nullptr));
    } // retranslateUi

};

namespace Ui {
    class LedStatusWidget: public Ui_LedStatusWidget {};
} // namespace Ui

QT_END_NAMESPACE

#endif // LEDSTATUSWIDGET_H

