/********************************************************************************
** Form generated from reading UI file 'opsfocusmechanics.ui'
**
** Created by: Qt User Interface Compiler version 6.11.1
**
** WARNING! All changes made in this file will be lost when recompiling UI file!
********************************************************************************/

#ifndef UI_OPSFOCUSMECHANICS_H
#define UI_OPSFOCUSMECHANICS_H

#include <QtCore/QVariant>
#include <QtWidgets/QApplication>
#include <QtWidgets/QComboBox>
#include <QtWidgets/QDoubleSpinBox>
#include <QtWidgets/QGridLayout>
#include <QtWidgets/QLabel>
#include <QtWidgets/QSpacerItem>
#include <QtWidgets/QSpinBox>
#include <QtWidgets/QVBoxLayout>
#include <QtWidgets/QWidget>
#include <klocalizedstring.h>

QT_BEGIN_NAMESPACE

class Ui_OpsFocusMechanics
{
public:
    QVBoxLayout *verticalLayout;
    QGridLayout *gridLayoutMechanics;
    QLabel *label_8;
    QDoubleSpinBox *focusOutSteps;
    QLabel *focusOutStepsLabel;
    QComboBox *focusWalk;
    QLabel *label_27;
    QSpinBox *focusTicks;
    QSpinBox *focusMotionTimeout;
    QDoubleSpinBox *focusOverscanDelay;
    QSpinBox *focusMaxSingleStep;
    QSpinBox *focusAFOverscan;
    QLabel *label_26;
    QLabel *label;
    QLabel *focusWalkLabel;
    QLabel *label_9;
    QLabel *label_11;
    QSpinBox *focusCaptureTimeout;
    QDoubleSpinBox *focusMaxTravel;
    QLabel *label_17;
    QLabel *label_12;
    QDoubleSpinBox *focusSettleTime;
    QLabel *focusNumStepsLabel;
    QLabel *label_2;
    QSpinBox *focusNumSteps;
    QSpinBox *focusBacklash;
    QLabel *speedupShiftLabel;
    QLabel *speedupCtrlLabel;
    QSpinBox *speedupShift;
    QSpinBox *speedupCtrl;
    QSpacerItem *verticalSpacer;

    void setupUi(QWidget *OpsFocusMechanics)
    {
        if (OpsFocusMechanics->objectName().isEmpty())
            OpsFocusMechanics->setObjectName("OpsFocusMechanics");
        OpsFocusMechanics->resize(439, 212);
        verticalLayout = new QVBoxLayout(OpsFocusMechanics);
        verticalLayout->setObjectName("verticalLayout");
        gridLayoutMechanics = new QGridLayout();
        gridLayoutMechanics->setSpacing(3);
        gridLayoutMechanics->setObjectName("gridLayoutMechanics");
        gridLayoutMechanics->setContentsMargins(0, 0, -1, -1);
        label_8 = new QLabel(OpsFocusMechanics);
        label_8->setObjectName("label_8");
        QSizePolicy sizePolicy(QSizePolicy::Policy::Preferred, QSizePolicy::Policy::Fixed);
        sizePolicy.setHorizontalStretch(0);
        sizePolicy.setVerticalStretch(0);
        sizePolicy.setHeightForWidth(label_8->sizePolicy().hasHeightForWidth());
        label_8->setSizePolicy(sizePolicy);
        label_8->setAlignment(Qt::AlignLeading|Qt::AlignLeft|Qt::AlignVCenter);

        gridLayoutMechanics->addWidget(label_8, 4, 2, 1, 1);

        focusOutSteps = new QDoubleSpinBox(OpsFocusMechanics);
        focusOutSteps->setObjectName("focusOutSteps");
        sizePolicy.setHeightForWidth(focusOutSteps->sizePolicy().hasHeightForWidth());
        focusOutSteps->setSizePolicy(sizePolicy);
        focusOutSteps->setMinimum(3.000000000000000);
        focusOutSteps->setMaximum(10.000000000000000);
        focusOutSteps->setSingleStep(1.000000000000000);
        focusOutSteps->setValue(5.000000000000000);

        gridLayoutMechanics->addWidget(focusOutSteps, 1, 3, 1, 1);

        focusOutStepsLabel = new QLabel(OpsFocusMechanics);
        focusOutStepsLabel->setObjectName("focusOutStepsLabel");
        sizePolicy.setHeightForWidth(focusOutStepsLabel->sizePolicy().hasHeightForWidth());
        focusOutStepsLabel->setSizePolicy(sizePolicy);

        gridLayoutMechanics->addWidget(focusOutStepsLabel, 1, 2, 1, 1);

        focusWalk = new QComboBox(OpsFocusMechanics);
        focusWalk->addItem(QString());
        focusWalk->addItem(QString());
        focusWalk->addItem(QString());
        focusWalk->setObjectName("focusWalk");
        sizePolicy.setHeightForWidth(focusWalk->sizePolicy().hasHeightForWidth());
        focusWalk->setSizePolicy(sizePolicy);

        gridLayoutMechanics->addWidget(focusWalk, 0, 1, 1, 1);

        label_27 = new QLabel(OpsFocusMechanics);
        label_27->setObjectName("label_27");
        sizePolicy.setHeightForWidth(label_27->sizePolicy().hasHeightForWidth());
        label_27->setSizePolicy(sizePolicy);

        gridLayoutMechanics->addWidget(label_27, 6, 0, 1, 1);

        focusTicks = new QSpinBox(OpsFocusMechanics);
        focusTicks->setObjectName("focusTicks");
        sizePolicy.setHeightForWidth(focusTicks->sizePolicy().hasHeightForWidth());
        focusTicks->setSizePolicy(sizePolicy);
        focusTicks->setMinimum(1);
        focusTicks->setMaximum(50000);
        focusTicks->setSingleStep(10);
        focusTicks->setValue(250);

        gridLayoutMechanics->addWidget(focusTicks, 1, 1, 1, 1);

        focusMotionTimeout = new QSpinBox(OpsFocusMechanics);
        focusMotionTimeout->setObjectName("focusMotionTimeout");
        sizePolicy.setHeightForWidth(focusMotionTimeout->sizePolicy().hasHeightForWidth());
        focusMotionTimeout->setSizePolicy(sizePolicy);
        focusMotionTimeout->setMinimum(5);
        focusMotionTimeout->setMaximum(120);
        focusMotionTimeout->setValue(30);

        gridLayoutMechanics->addWidget(focusMotionTimeout, 6, 1, 1, 1);

        focusOverscanDelay = new QDoubleSpinBox(OpsFocusMechanics);
        focusOverscanDelay->setObjectName("focusOverscanDelay");
        sizePolicy.setHeightForWidth(focusOverscanDelay->sizePolicy().hasHeightForWidth());
        focusOverscanDelay->setSizePolicy(sizePolicy);
        focusOverscanDelay->setMaximum(10.000000000000000);

        gridLayoutMechanics->addWidget(focusOverscanDelay, 5, 3, 1, 1);

        focusMaxSingleStep = new QSpinBox(OpsFocusMechanics);
        focusMaxSingleStep->setObjectName("focusMaxSingleStep");
        sizePolicy.setHeightForWidth(focusMaxSingleStep->sizePolicy().hasHeightForWidth());
        focusMaxSingleStep->setSizePolicy(sizePolicy);
        focusMaxSingleStep->setMinimum(10);
        focusMaxSingleStep->setMaximum(100000);
        focusMaxSingleStep->setValue(100000);

        gridLayoutMechanics->addWidget(focusMaxSingleStep, 3, 3, 1, 1);

        focusAFOverscan = new QSpinBox(OpsFocusMechanics);
        focusAFOverscan->setObjectName("focusAFOverscan");
        sizePolicy.setHeightForWidth(focusAFOverscan->sizePolicy().hasHeightForWidth());
        focusAFOverscan->setSizePolicy(sizePolicy);
        focusAFOverscan->setMaximum(10000);
        focusAFOverscan->setValue(100);

        gridLayoutMechanics->addWidget(focusAFOverscan, 4, 3, 1, 1);

        label_26 = new QLabel(OpsFocusMechanics);
        label_26->setObjectName("label_26");
        sizePolicy.setHeightForWidth(label_26->sizePolicy().hasHeightForWidth());
        label_26->setSizePolicy(sizePolicy);

        gridLayoutMechanics->addWidget(label_26, 5, 0, 1, 1);

        label = new QLabel(OpsFocusMechanics);
        label->setObjectName("label");
        sizePolicy.setHeightForWidth(label->sizePolicy().hasHeightForWidth());
        label->setSizePolicy(sizePolicy);

        gridLayoutMechanics->addWidget(label, 1, 0, 1, 1);

        focusWalkLabel = new QLabel(OpsFocusMechanics);
        focusWalkLabel->setObjectName("focusWalkLabel");
        sizePolicy.setHeightForWidth(focusWalkLabel->sizePolicy().hasHeightForWidth());
        focusWalkLabel->setSizePolicy(sizePolicy);

        gridLayoutMechanics->addWidget(focusWalkLabel, 0, 0, 1, 1);

        label_9 = new QLabel(OpsFocusMechanics);
        label_9->setObjectName("label_9");
        sizePolicy.setHeightForWidth(label_9->sizePolicy().hasHeightForWidth());
        label_9->setSizePolicy(sizePolicy);

        gridLayoutMechanics->addWidget(label_9, 0, 2, 1, 1);

        label_11 = new QLabel(OpsFocusMechanics);
        label_11->setObjectName("label_11");
        sizePolicy.setHeightForWidth(label_11->sizePolicy().hasHeightForWidth());
        label_11->setSizePolicy(sizePolicy);

        gridLayoutMechanics->addWidget(label_11, 4, 0, 1, 1);

        focusCaptureTimeout = new QSpinBox(OpsFocusMechanics);
        focusCaptureTimeout->setObjectName("focusCaptureTimeout");
        sizePolicy.setHeightForWidth(focusCaptureTimeout->sizePolicy().hasHeightForWidth());
        focusCaptureTimeout->setSizePolicy(sizePolicy);
        focusCaptureTimeout->setMinimum(5);
        focusCaptureTimeout->setMaximum(300);
        focusCaptureTimeout->setValue(30);

        gridLayoutMechanics->addWidget(focusCaptureTimeout, 5, 1, 1, 1);

        focusMaxTravel = new QDoubleSpinBox(OpsFocusMechanics);
        focusMaxTravel->setObjectName("focusMaxTravel");
        sizePolicy.setHeightForWidth(focusMaxTravel->sizePolicy().hasHeightForWidth());
        focusMaxTravel->setSizePolicy(sizePolicy);
        focusMaxTravel->setDecimals(0);
        focusMaxTravel->setMinimum(10.000000000000000);
        focusMaxTravel->setMaximum(100000.000000000000000);
        focusMaxTravel->setSingleStep(1000.000000000000000);
        focusMaxTravel->setValue(10000.000000000000000);

        gridLayoutMechanics->addWidget(focusMaxTravel, 3, 1, 1, 1);

        label_17 = new QLabel(OpsFocusMechanics);
        label_17->setObjectName("label_17");
        sizePolicy.setHeightForWidth(label_17->sizePolicy().hasHeightForWidth());
        label_17->setSizePolicy(sizePolicy);
        label_17->setMouseTracking(false);

        gridLayoutMechanics->addWidget(label_17, 3, 2, 1, 1);

        label_12 = new QLabel(OpsFocusMechanics);
        label_12->setObjectName("label_12");
        sizePolicy.setHeightForWidth(label_12->sizePolicy().hasHeightForWidth());
        label_12->setSizePolicy(sizePolicy);

        gridLayoutMechanics->addWidget(label_12, 3, 0, 1, 1);

        focusSettleTime = new QDoubleSpinBox(OpsFocusMechanics);
        focusSettleTime->setObjectName("focusSettleTime");
        sizePolicy.setHeightForWidth(focusSettleTime->sizePolicy().hasHeightForWidth());
        focusSettleTime->setSizePolicy(sizePolicy);
        focusSettleTime->setDecimals(2);
        focusSettleTime->setMaximum(30.000000000000000);
        focusSettleTime->setValue(1.000000000000000);

        gridLayoutMechanics->addWidget(focusSettleTime, 0, 3, 1, 1);

        focusNumStepsLabel = new QLabel(OpsFocusMechanics);
        focusNumStepsLabel->setObjectName("focusNumStepsLabel");
        sizePolicy.setHeightForWidth(focusNumStepsLabel->sizePolicy().hasHeightForWidth());
        focusNumStepsLabel->setSizePolicy(sizePolicy);

        gridLayoutMechanics->addWidget(focusNumStepsLabel, 6, 2, 1, 1);

        label_2 = new QLabel(OpsFocusMechanics);
        label_2->setObjectName("label_2");
        sizePolicy.setHeightForWidth(label_2->sizePolicy().hasHeightForWidth());
        label_2->setSizePolicy(sizePolicy);

        gridLayoutMechanics->addWidget(label_2, 5, 2, 1, 1);

        focusNumSteps = new QSpinBox(OpsFocusMechanics);
        focusNumSteps->setObjectName("focusNumSteps");
        sizePolicy.setHeightForWidth(focusNumSteps->sizePolicy().hasHeightForWidth());
        focusNumSteps->setSizePolicy(sizePolicy);
        focusNumSteps->setMinimum(5);
        focusNumSteps->setMaximum(50);
        focusNumSteps->setValue(11);

        gridLayoutMechanics->addWidget(focusNumSteps, 6, 3, 1, 1);

        focusBacklash = new QSpinBox(OpsFocusMechanics);
        focusBacklash->setObjectName("focusBacklash");
        sizePolicy.setHeightForWidth(focusBacklash->sizePolicy().hasHeightForWidth());
        focusBacklash->setSizePolicy(sizePolicy);

        gridLayoutMechanics->addWidget(focusBacklash, 4, 1, 1, 1);

        speedupShiftLabel = new QLabel(OpsFocusMechanics);
        speedupShiftLabel->setObjectName("speedupShiftLabel");

        gridLayoutMechanics->addWidget(speedupShiftLabel, 2, 0, 1, 1);

        speedupCtrlLabel = new QLabel(OpsFocusMechanics);
        speedupCtrlLabel->setObjectName("speedupCtrlLabel");

        gridLayoutMechanics->addWidget(speedupCtrlLabel, 2, 2, 1, 1);

        speedupShift = new QSpinBox(OpsFocusMechanics);
        speedupShift->setObjectName("speedupShift");
        speedupShift->setMinimum(1);
        speedupShift->setMaximum(9999);
        speedupShift->setValue(5);

        gridLayoutMechanics->addWidget(speedupShift, 2, 1, 1, 1);

        speedupCtrl = new QSpinBox(OpsFocusMechanics);
        speedupCtrl->setObjectName("speedupCtrl");
        speedupCtrl->setMinimum(1);
        speedupCtrl->setMaximum(9999);
        speedupCtrl->setValue(5);

        gridLayoutMechanics->addWidget(speedupCtrl, 2, 3, 1, 1);


        verticalLayout->addLayout(gridLayoutMechanics);

        verticalSpacer = new QSpacerItem(20, 40, QSizePolicy::Policy::Minimum, QSizePolicy::Policy::Expanding);

        verticalLayout->addItem(verticalSpacer);

#if QT_CONFIG(shortcut)
        label_8->setBuddy(focusAFOverscan);
        focusOutStepsLabel->setBuddy(focusOutSteps);
        label_27->setBuddy(focusMotionTimeout);
        label_26->setBuddy(focusCaptureTimeout);
        label->setBuddy(focusTicks);
        focusWalkLabel->setBuddy(focusWalk);
        label_9->setBuddy(focusSettleTime);
        label_11->setBuddy(focusBacklash);
        label_17->setBuddy(focusMaxSingleStep);
        label_12->setBuddy(focusMaxTravel);
        focusNumStepsLabel->setBuddy(focusNumSteps);
        label_2->setBuddy(focusOverscanDelay);
#endif // QT_CONFIG(shortcut)
        QWidget::setTabOrder(focusWalk, focusSettleTime);
        QWidget::setTabOrder(focusSettleTime, focusTicks);
        QWidget::setTabOrder(focusTicks, focusOutSteps);
        QWidget::setTabOrder(focusOutSteps, focusMaxTravel);
        QWidget::setTabOrder(focusMaxTravel, focusMaxSingleStep);
        QWidget::setTabOrder(focusMaxSingleStep, focusBacklash);
        QWidget::setTabOrder(focusBacklash, focusAFOverscan);
        QWidget::setTabOrder(focusAFOverscan, focusCaptureTimeout);
        QWidget::setTabOrder(focusCaptureTimeout, focusOverscanDelay);
        QWidget::setTabOrder(focusOverscanDelay, focusMotionTimeout);

        retranslateUi(OpsFocusMechanics);

        QMetaObject::connectSlotsByName(OpsFocusMechanics);
    } // setupUi

    void retranslateUi(QWidget *OpsFocusMechanics)
    {
        OpsFocusMechanics->setWindowTitle(tr2i18n("Focus Mechanics", nullptr));
        label_8->setText(tr2i18n("AF Overscan:", nullptr));
#if QT_CONFIG(tooltip)
        focusOutSteps->setToolTip(tr2i18n("<html><body><p>This number multiplied by initial-step-size is number of outward steps the Linear Focus algorithm moves away from the initial position at the start of focusing.</p></body></html>", nullptr));
#endif // QT_CONFIG(tooltip)
        focusOutStepsLabel->setText(tr2i18n("Out Step Multiple:", nullptr));
        focusWalk->setItemText(0, tr2i18n("Classic", nullptr));
        focusWalk->setItemText(1, tr2i18n("Fixed Steps", nullptr));
        focusWalk->setItemText(2, tr2i18n("CFZ Shuffle", nullptr));

#if QT_CONFIG(tooltip)
        focusWalk->setToolTip(tr2i18n("<html><head/><body><p>Select the type of walk for the focuser to take when using <span style=\" font-weight:600;\">Linear 1 Pass</span>.  For <span style=\" font-weight:600;\">Linear</span> only <span style=\" font-weight:600;\">Classic</span> is available.</p><p><span style=\" font-weight:600;\">Classic</span>: Focuser steps out &quot;Out Step Multiple&quot; steps, takes a frame and then steps in through focus at a constant step size taking and analysing frames at each step. The exact point at which the pass stops is dependent on the data so this walk is tolerant of starting further away from focus, but at the expense of extra steps.</p><p><span style=\" font-weight:600;\">Fixed Steps</span>: Focuser steps out half of &quot;Number Steps&quot;, takes a frame and then steps in exactly &quot;Number Steps&quot;. This walk must be started close to focus to be effective but is predictable in the number of steps taken.</p><p><span style=\" font-weight:600;\">CFZ Shuffle</span>: Similar to <span style=\" font-weight:"
                        "600;\">Fixed Steps</span> except this walk takes half steps near the focus point to try to give more weight to points nearer to focus in the curve fitting. As with <span style=\" font-weight:600;\">Fixed Steps</span> this walk must be started close to focus to be effective but is predictable in the number of steps taken.</p><p><br/></p></body></html>", nullptr));
#endif // QT_CONFIG(tooltip)
        label_27->setText(tr2i18n("Motion Timeout:", nullptr));
#if QT_CONFIG(tooltip)
        focusTicks->setToolTip(tr2i18n("<html><head/><body><p><span style=\" font-weight:600;\">Initial Step Size</span> in ticks to cause a noticeable change in HFR value. For timer based focuser, it is the initial time in milliseconds to move the focuser inward or outward</p></body></html>", nullptr));
#endif // QT_CONFIG(tooltip)
#if QT_CONFIG(tooltip)
        focusMotionTimeout->setToolTip(tr2i18n("<html><head/><body><p>Maximum time in seconds to wait for the focuser to move to the desired position before declaring a timeout.</p></body></html>", nullptr));
#endif // QT_CONFIG(tooltip)
        focusMotionTimeout->setSuffix(tr2i18n(" s", nullptr));
#if QT_CONFIG(tooltip)
        focusOverscanDelay->setToolTip(tr2i18n("<html><head/><body><p>Delay between completing the outward motion of an Overscan and starting the inward motion. For most focusers 0 s is fine.</p></body></html>", nullptr));
#endif // QT_CONFIG(tooltip)
        focusOverscanDelay->setSuffix(tr2i18n(" s", nullptr));
#if QT_CONFIG(tooltip)
        focusMaxSingleStep->setToolTip(tr2i18n("<html><head/><body><p>The maximum single step size the algorithm is allowed to command as it searches for the critical focus zone. The calculated step size would be limited to this maximum value.</p></body></html>", nullptr));
#endif // QT_CONFIG(tooltip)
#if QT_CONFIG(tooltip)
        focusAFOverscan->setToolTip(tr2i18n("<html><head/><body><p>Provides backlash overscan in ticks for outward focuser movements during an Autofocus run. This is in addition to any Driver Backlash provided by the device driver and set in the Driver Backlash field. Set to 0 to disable. </p><p>If set, AF Overscan is applied to all focuser movements initiated by the Focus module.</p><p>Typically either Focuser Backlash or AF Overscan is set.</p></body></html>", nullptr));
#endif // QT_CONFIG(tooltip)
        label_26->setText(tr2i18n("Capture Timeout:", nullptr));
#if QT_CONFIG(tooltip)
        label->setToolTip(QString());
#endif // QT_CONFIG(tooltip)
#if QT_CONFIG(whatsthis)
        label->setWhatsThis(QString());
#endif // QT_CONFIG(whatsthis)
        label->setText(tr2i18n("Initial Step Size:", nullptr));
        focusWalkLabel->setText(tr2i18n("Walk:", nullptr));
        label_9->setText(tr2i18n("Focuser Settle:", nullptr));
        label_11->setText(tr2i18n("Driver Backlash:", nullptr));
#if QT_CONFIG(tooltip)
        focusCaptureTimeout->setToolTip(tr2i18n("Maximum time in seconds to wait for a captured image to be received before declaring a timeout.", nullptr));
#endif // QT_CONFIG(tooltip)
        focusCaptureTimeout->setSuffix(tr2i18n(" s", nullptr));
#if QT_CONFIG(tooltip)
        focusMaxTravel->setToolTip(tr2i18n("<html><head/><body><p>Maximum travel in steps before the autofocus process aborts</p></body></html>", nullptr));
#endif // QT_CONFIG(tooltip)
        label_17->setText(tr2i18n("Max Step Size:", nullptr));
#if QT_CONFIG(tooltip)
        label_12->setToolTip(QString());
#endif // QT_CONFIG(tooltip)
        label_12->setText(tr2i18n("Max Travel:", nullptr));
#if QT_CONFIG(tooltip)
        focusSettleTime->setToolTip(tr2i18n("<html><head/><body><p>Settle time (in seconds) after moving the focuser before capturing the next image during Auto Focus and after an Adaptive Focus movement.</p></body></html>", nullptr));
#endif // QT_CONFIG(tooltip)
        focusSettleTime->setSuffix(tr2i18n(" s", nullptr));
        focusNumStepsLabel->setText(tr2i18n("Number Steps:", nullptr));
        label_2->setText(tr2i18n("AF Overscan Delay:", nullptr));
#if QT_CONFIG(tooltip)
        focusNumSteps->setToolTip(tr2i18n("<html><head/><body><p>The total number of steps to use when Walk is set to one of the fixed number of steps walks and Algorithm is Linear 1 Pass.</p></body></html>", nullptr));
#endif // QT_CONFIG(tooltip)
#if QT_CONFIG(tooltip)
        focusBacklash->setToolTip(tr2i18n("<html><head/><body><p>For backlash-aware focusers, the amount of backlash to apply when reversing movement direction. Set to 0 to disable.</p><p>Typically either Focuser Backlash or AF Overscan is set.</p><p>This field sets the Indi Focuser Backlash field and can be set either here or on the Indi Control Panel.</p></body></html>", nullptr));
#endif // QT_CONFIG(tooltip)
        speedupShiftLabel->setText(tr2i18n("Speedup (Shift)", nullptr));
        speedupCtrlLabel->setText(tr2i18n("Speedup (Ctrl)", nullptr));
#if QT_CONFIG(tooltip)
        speedupShift->setToolTip(tr2i18n("<html><head/><body><p>Multiplier for manual focus motions when the shift key is pressed.</p></body></html>", nullptr));
#endif // QT_CONFIG(tooltip)
        speedupShift->setSuffix(tr2i18n(" x", nullptr));
#if QT_CONFIG(tooltip)
        speedupCtrl->setToolTip(tr2i18n("<html><head/><body><p>Multiplier for manual focus motions when the control key is pressed.</p></body></html>", nullptr));
#endif // QT_CONFIG(tooltip)
        speedupCtrl->setSuffix(tr2i18n(" x", nullptr));
    } // retranslateUi

};

namespace Ui {
    class OpsFocusMechanics: public Ui_OpsFocusMechanics {};
} // namespace Ui

QT_END_NAMESPACE

#endif // OPSFOCUSMECHANICS_H

