/********************************************************************************
** Form generated from reading UI file 'meridianflipstatuswidget.ui'
**
** Created by: Qt User Interface Compiler version 6.11.1
**
** WARNING! All changes made in this file will be lost when recompiling UI file!
********************************************************************************/

#ifndef UI_MERIDIANFLIPSTATUSWIDGET_H
#define UI_MERIDIANFLIPSTATUSWIDGET_H

#include <QtCore/QVariant>
#include <QtWidgets/QApplication>
#include <QtWidgets/QHBoxLayout>
#include <QtWidgets/QLabel>
#include <QtWidgets/QWidget>
#include <klocalizedstring.h>

QT_BEGIN_NAMESPACE

class Ui_MeridianFlipStatusWidget
{
public:
    QHBoxLayout *statusLayout;
    QLabel *statusText;

    void setupUi(QWidget *MeridianFlipStatusWidget)
    {
        if (MeridianFlipStatusWidget->objectName().isEmpty())
            MeridianFlipStatusWidget->setObjectName("MeridianFlipStatusWidget");
        MeridianFlipStatusWidget->resize(397, 25);
        statusLayout = new QHBoxLayout(MeridianFlipStatusWidget);
        statusLayout->setObjectName("statusLayout");
        statusLayout->setContentsMargins(0, 0, 0, 0);
        statusText = new QLabel(MeridianFlipStatusWidget);
        statusText->setObjectName("statusText");
        statusText->setAlignment(Qt::AlignLeading|Qt::AlignLeft|Qt::AlignVCenter);

        statusLayout->addWidget(statusText, 0, Qt::AlignVCenter);

        statusLayout->setStretch(0, 1);

        retranslateUi(MeridianFlipStatusWidget);

        QMetaObject::connectSlotsByName(MeridianFlipStatusWidget);
    } // setupUi

    void retranslateUi(QWidget *MeridianFlipStatusWidget)
    {
        MeridianFlipStatusWidget->setWindowTitle(tr2i18n("Form", nullptr));
#if QT_CONFIG(tooltip)
        statusText->setToolTip(tr2i18n("Meridian Flip Status", nullptr));
#endif // QT_CONFIG(tooltip)
        statusText->setText(tr2i18n("<unknown>", nullptr));
    } // retranslateUi

};

namespace Ui {
    class MeridianFlipStatusWidget: public Ui_MeridianFlipStatusWidget {};
} // namespace Ui

QT_END_NAMESPACE

#endif // MERIDIANFLIPSTATUSWIDGET_H

