/********************************************************************************
** Form generated from reading UI file 'argexportimage.ui'
**
** Created by: Qt User Interface Compiler version 6.11.1
**
** WARNING! All changes made in this file will be lost when recompiling UI file!
********************************************************************************/

#ifndef UI_ARGEXPORTIMAGE_H
#define UI_ARGEXPORTIMAGE_H

#include <QtCore/QVariant>
#include <QtWidgets/QApplication>
#include <QtWidgets/QGridLayout>
#include <QtWidgets/QHBoxLayout>
#include <QtWidgets/QLabel>
#include <QtWidgets/QSpacerItem>
#include <QtWidgets/QSpinBox>
#include <QtWidgets/QVBoxLayout>
#include <QtWidgets/QWidget>
#include <klocalizedstring.h>
#include "kurlrequester.h"

QT_BEGIN_NAMESPACE

class Ui_ArgExportImage
{
public:
    QVBoxLayout *vboxLayout;
    QHBoxLayout *hboxLayout;
    QLabel *textLabel1;
    KUrlRequester *ExportFileName;
    QHBoxLayout *hboxLayout1;
    QSpacerItem *spacerItem;
    QGridLayout *gridLayout;
    QSpinBox *ExportHeight;
    QSpinBox *ExportWidth;
    QLabel *textLabel2;
    QLabel *textLabel2_2;
    QSpacerItem *spacerItem1;

    void setupUi(QWidget *ArgExportImage)
    {
        if (ArgExportImage->objectName().isEmpty())
            ArgExportImage->setObjectName("ArgExportImage");
        ArgExportImage->resize(302, 131);
        vboxLayout = new QVBoxLayout(ArgExportImage);
#ifndef UI_Q_OS_MAC
        vboxLayout->setSpacing(6);
#endif
        vboxLayout->setContentsMargins(10, 10, 10, 10);
        vboxLayout->setObjectName("vboxLayout");
        hboxLayout = new QHBoxLayout();
#ifndef UI_Q_OS_MAC
        hboxLayout->setSpacing(6);
#endif
#ifndef UI_Q_OS_MAC
        hboxLayout->setContentsMargins(0, 0, 0, 0);
#endif
        hboxLayout->setObjectName("hboxLayout");
        textLabel1 = new QLabel(ArgExportImage);
        textLabel1->setObjectName("textLabel1");

        hboxLayout->addWidget(textLabel1);

        ExportFileName = new KUrlRequester(ArgExportImage);
        ExportFileName->setObjectName("ExportFileName");
        ExportFileName->setMinimumSize(QSize(160, 0));

        hboxLayout->addWidget(ExportFileName);


        vboxLayout->addLayout(hboxLayout);

        hboxLayout1 = new QHBoxLayout();
#ifndef UI_Q_OS_MAC
        hboxLayout1->setSpacing(6);
#endif
        hboxLayout1->setContentsMargins(0, 0, 0, 0);
        hboxLayout1->setObjectName("hboxLayout1");
        spacerItem = new QSpacerItem(40, 20, QSizePolicy::Policy::Expanding, QSizePolicy::Policy::Minimum);

        hboxLayout1->addItem(spacerItem);

        gridLayout = new QGridLayout();
#ifndef UI_Q_OS_MAC
        gridLayout->setSpacing(6);
#endif
#ifndef UI_Q_OS_MAC
        gridLayout->setContentsMargins(0, 0, 0, 0);
#endif
        gridLayout->setObjectName("gridLayout");
        ExportHeight = new QSpinBox(ArgExportImage);
        ExportHeight->setObjectName("ExportHeight");
        ExportHeight->setValue(600);
        ExportHeight->setMinimum(0);
        ExportHeight->setMaximum(5000);

        gridLayout->addWidget(ExportHeight, 1, 1, 1, 1);

        ExportWidth = new QSpinBox(ArgExportImage);
        ExportWidth->setObjectName("ExportWidth");
        ExportWidth->setValue(800);
        ExportWidth->setMinimum(0);
        ExportWidth->setMaximum(5000);

        gridLayout->addWidget(ExportWidth, 0, 1, 1, 1);

        textLabel2 = new QLabel(ArgExportImage);
        textLabel2->setObjectName("textLabel2");

        gridLayout->addWidget(textLabel2, 0, 0, 1, 1);

        textLabel2_2 = new QLabel(ArgExportImage);
        textLabel2_2->setObjectName("textLabel2_2");

        gridLayout->addWidget(textLabel2_2, 1, 0, 1, 1);


        hboxLayout1->addLayout(gridLayout);


        vboxLayout->addLayout(hboxLayout1);

        spacerItem1 = new QSpacerItem(20, 40, QSizePolicy::Policy::Minimum, QSizePolicy::Policy::Expanding);

        vboxLayout->addItem(spacerItem1);


        retranslateUi(ArgExportImage);

        QMetaObject::connectSlotsByName(ArgExportImage);
    } // setupUi

    void retranslateUi(QWidget *ArgExportImage)
    {
        textLabel1->setText(tr2i18n("File name:", nullptr));
        textLabel2->setText(tr2i18n("Image width:", nullptr));
        textLabel2_2->setText(tr2i18n("Image height:", nullptr));
        (void)ArgExportImage;
    } // retranslateUi

};

namespace Ui {
    class ArgExportImage: public Ui_ArgExportImage {};
} // namespace Ui

QT_END_NAMESPACE

#endif // ARGEXPORTIMAGE_H

