/********************************************************************************
** Form generated from reading UI file 'pwizwelcome.ui'
**
** Created by: Qt User Interface Compiler version 6.11.1
**
** WARNING! All changes made in this file will be lost when recompiling UI file!
********************************************************************************/

#ifndef UI_PWIZWELCOME_H
#define UI_PWIZWELCOME_H

#include <QtCore/QVariant>
#include <QtWidgets/QApplication>
#include <QtWidgets/QHBoxLayout>
#include <QtWidgets/QLabel>
#include <QtWidgets/QSpacerItem>
#include <QtWidgets/QVBoxLayout>
#include <QtWidgets/QWidget>
#include <klocalizedstring.h>

QT_BEGIN_NAMESPACE

class Ui_PWizWelcome
{
public:
    QHBoxLayout *horizontalLayout;
    QLabel *banner;
    QSpacerItem *horSpacer1;
    QVBoxLayout *welcomeLayout;
    QLabel *stepTitle;
    QSpacerItem *vertSpacer1;
    QLabel *stepText;
    QSpacerItem *vertSpacer2;

    void setupUi(QWidget *PWizWelcome)
    {
        if (PWizWelcome->objectName().isEmpty())
            PWizWelcome->setObjectName("PWizWelcome");
        PWizWelcome->resize(586, 395);
        PWizWelcome->setMinimumSize(QSize(586, 395));
        PWizWelcome->setMaximumSize(QSize(16777215, 16777215));
        horizontalLayout = new QHBoxLayout(PWizWelcome);
        horizontalLayout->setObjectName("horizontalLayout");
        banner = new QLabel(PWizWelcome);
        banner->setObjectName("banner");
        QSizePolicy sizePolicy(QSizePolicy::Policy::Fixed, QSizePolicy::Policy::Fixed);
        sizePolicy.setHorizontalStretch(0);
        sizePolicy.setVerticalStretch(0);
        sizePolicy.setHeightForWidth(banner->sizePolicy().hasHeightForWidth());
        banner->setSizePolicy(sizePolicy);
        banner->setMinimumSize(QSize(120, 360));

        horizontalLayout->addWidget(banner);

        horSpacer1 = new QSpacerItem(5, 20, QSizePolicy::Policy::Fixed, QSizePolicy::Policy::Minimum);

        horizontalLayout->addItem(horSpacer1);

        welcomeLayout = new QVBoxLayout();
#ifndef UI_Q_OS_MAC
        welcomeLayout->setSpacing(6);
#endif
        welcomeLayout->setContentsMargins(0, 0, 0, 0);
        welcomeLayout->setObjectName("welcomeLayout");
        stepTitle = new QLabel(PWizWelcome);
        stepTitle->setObjectName("stepTitle");
        QFont font;
        font.setFamilies({QString::fromUtf8("Sans Serif")});
        font.setPointSize(11);
        font.setBold(true);
        font.setItalic(false);
        font.setUnderline(false);
        font.setStrikeOut(false);
        stepTitle->setFont(font);

        welcomeLayout->addWidget(stepTitle);

        vertSpacer1 = new QSpacerItem(20, 12, QSizePolicy::Policy::Minimum, QSizePolicy::Policy::Fixed);

        welcomeLayout->addItem(vertSpacer1);

        stepText = new QLabel(PWizWelcome);
        stepText->setObjectName("stepText");
        stepText->setWordWrap(true);

        welcomeLayout->addWidget(stepText);

        vertSpacer2 = new QSpacerItem(20, 191, QSizePolicy::Policy::Minimum, QSizePolicy::Policy::Expanding);

        welcomeLayout->addItem(vertSpacer2);


        horizontalLayout->addLayout(welcomeLayout);


        retranslateUi(PWizWelcome);

        QMetaObject::connectSlotsByName(PWizWelcome);
    } // setupUi

    void retranslateUi(QWidget *PWizWelcome)
    {
        banner->setText(QString());
        stepTitle->setText(tr2i18n("Welcome to the KStars Printing Wizard", nullptr));
        stepText->setText(tr2i18n("<p>This wizard will help you set up all the parameters for printing finder charts with logging forms.</p>\n"
"<p>To get started, press the <b>Next</b> button.</p>", nullptr));
        (void)PWizWelcome;
    } // retranslateUi

};

namespace Ui {
    class PWizWelcome: public Ui_PWizWelcome {};
} // namespace Ui

QT_END_NAMESPACE

#endif // PWIZWELCOME_H

