/********************************************************************************
** Form generated from reading UI file 'manualpulse.ui'
**
** Created by: Qt User Interface Compiler version 6.11.1
**
** WARNING! All changes made in this file will be lost when recompiling UI file!
********************************************************************************/

#ifndef UI_MANUALPULSE_H
#define UI_MANUALPULSE_H

#include <QtCore/QVariant>
#include <QtGui/QIcon>
#include <QtWidgets/QApplication>
#include <QtWidgets/QDialog>
#include <QtWidgets/QFormLayout>
#include <QtWidgets/QHBoxLayout>
#include <QtWidgets/QLabel>
#include <QtWidgets/QLineEdit>
#include <QtWidgets/QPushButton>
#include <QtWidgets/QSpacerItem>
#include <QtWidgets/QSpinBox>
#include <QtWidgets/QVBoxLayout>
#include <klocalizedstring.h>

QT_BEGIN_NAMESPACE

class Ui_ManualPulse
{
public:
    QVBoxLayout *verticalLayout_2;
    QVBoxLayout *verticalLayout;
    QPushButton *northPulseB;
    QHBoxLayout *horizontalLayout;
    QPushButton *eastPulseB;
    QSpacerItem *horizontalSpacer;
    QPushButton *westPulseB;
    QPushButton *southPulseB;
    QFormLayout *formLayout;
    QLabel *label_3;
    QSpinBox *pulseDuration;
    QLabel *label;
    QLineEdit *raOffset;
    QLabel *label_2;
    QLineEdit *deOffset;
    QPushButton *resetB;

    void setupUi(QDialog *ManualPulse)
    {
        if (ManualPulse->objectName().isEmpty())
            ManualPulse->setObjectName("ManualPulse");
        ManualPulse->resize(286, 235);
        verticalLayout_2 = new QVBoxLayout(ManualPulse);
        verticalLayout_2->setSpacing(3);
        verticalLayout_2->setObjectName("verticalLayout_2");
        verticalLayout_2->setContentsMargins(3, 3, 3, 3);
        verticalLayout = new QVBoxLayout();
        verticalLayout->setObjectName("verticalLayout");
        northPulseB = new QPushButton(ManualPulse);
        northPulseB->setObjectName("northPulseB");

        verticalLayout->addWidget(northPulseB);

        horizontalLayout = new QHBoxLayout();
        horizontalLayout->setObjectName("horizontalLayout");
        eastPulseB = new QPushButton(ManualPulse);
        eastPulseB->setObjectName("eastPulseB");

        horizontalLayout->addWidget(eastPulseB);

        horizontalSpacer = new QSpacerItem(40, 20, QSizePolicy::Policy::Expanding, QSizePolicy::Policy::Minimum);

        horizontalLayout->addItem(horizontalSpacer);

        westPulseB = new QPushButton(ManualPulse);
        westPulseB->setObjectName("westPulseB");

        horizontalLayout->addWidget(westPulseB);


        verticalLayout->addLayout(horizontalLayout);

        southPulseB = new QPushButton(ManualPulse);
        southPulseB->setObjectName("southPulseB");

        verticalLayout->addWidget(southPulseB);


        verticalLayout_2->addLayout(verticalLayout);

        formLayout = new QFormLayout();
        formLayout->setObjectName("formLayout");
        label_3 = new QLabel(ManualPulse);
        label_3->setObjectName("label_3");

        formLayout->setWidget(0, QFormLayout::ItemRole::LabelRole, label_3);

        pulseDuration = new QSpinBox(ManualPulse);
        pulseDuration->setObjectName("pulseDuration");
        pulseDuration->setMinimum(100);
        pulseDuration->setMaximum(5000);
        pulseDuration->setSingleStep(100);
        pulseDuration->setValue(1000);

        formLayout->setWidget(0, QFormLayout::ItemRole::FieldRole, pulseDuration);

        label = new QLabel(ManualPulse);
        label->setObjectName("label");

        formLayout->setWidget(1, QFormLayout::ItemRole::LabelRole, label);

        raOffset = new QLineEdit(ManualPulse);
        raOffset->setObjectName("raOffset");

        formLayout->setWidget(1, QFormLayout::ItemRole::FieldRole, raOffset);

        label_2 = new QLabel(ManualPulse);
        label_2->setObjectName("label_2");

        formLayout->setWidget(2, QFormLayout::ItemRole::LabelRole, label_2);

        deOffset = new QLineEdit(ManualPulse);
        deOffset->setObjectName("deOffset");

        formLayout->setWidget(2, QFormLayout::ItemRole::FieldRole, deOffset);

        resetB = new QPushButton(ManualPulse);
        resetB->setObjectName("resetB");
        QIcon icon;
        QString iconThemeName = QString::fromUtf8("edit-clear");
        if (QIcon::hasThemeIcon(iconThemeName)) {
            icon = QIcon::fromTheme(iconThemeName);
        } else {
            icon.addFile(QString::fromUtf8("."), QSize(), QIcon::Mode::Normal, QIcon::State::Off);
        }
        resetB->setIcon(icon);

        formLayout->setWidget(3, QFormLayout::ItemRole::LabelRole, resetB);


        verticalLayout_2->addLayout(formLayout);


        retranslateUi(ManualPulse);

        QMetaObject::connectSlotsByName(ManualPulse);
    } // setupUi

    void retranslateUi(QDialog *ManualPulse)
    {
        ManualPulse->setWindowTitle(tr2i18n("Manual Pulse", nullptr));
        northPulseB->setText(tr2i18n("North / DE+", nullptr));
        eastPulseB->setText(tr2i18n("East / RA+", nullptr));
        westPulseB->setText(tr2i18n("West / RA-", nullptr));
        southPulseB->setText(tr2i18n("South / DE-", nullptr));
        label_3->setText(tr2i18n("Pulse:", nullptr));
        pulseDuration->setSuffix(tr2i18n(" ms", nullptr));
        label->setText(tr2i18n("RA Offset\":", nullptr));
        raOffset->setText(tr2i18n("0", nullptr));
        label_2->setText(tr2i18n("DE Offset\":", nullptr));
        deOffset->setText(tr2i18n("0", nullptr));
        resetB->setText(tr2i18n("Reset", nullptr));
    } // retranslateUi

};

namespace Ui {
    class ManualPulse: public Ui_ManualPulse {};
} // namespace Ui

QT_END_NAMESPACE

#endif // MANUALPULSE_H

