/********************************************************************************
** Form generated from reading UI file 'stellarsolverprofileeditor.ui'
**
** Created by: Qt User Interface Compiler version 6.11.1
**
** WARNING! All changes made in this file will be lost when recompiling UI file!
********************************************************************************/

#ifndef UI_STELLARSOLVERPROFILEEDITOR_H
#define UI_STELLARSOLVERPROFILEEDITOR_H

#include <QtCore/QVariant>
#include <QtWidgets/QApplication>
#include <QtWidgets/QCheckBox>
#include <QtWidgets/QComboBox>
#include <QtWidgets/QGridLayout>
#include <QtWidgets/QGroupBox>
#include <QtWidgets/QHBoxLayout>
#include <QtWidgets/QLabel>
#include <QtWidgets/QLineEdit>
#include <QtWidgets/QPushButton>
#include <QtWidgets/QSpacerItem>
#include <QtWidgets/QSpinBox>
#include <QtWidgets/QTextEdit>
#include <QtWidgets/QVBoxLayout>
#include <QtWidgets/QWidget>
#include <klocalizedstring.h>

QT_BEGIN_NAMESPACE

class Ui_StellarSolverProfileEditor
{
public:
    QVBoxLayout *verticalLayout_5;
    QGroupBox *groupBox_4;
    QVBoxLayout *verticalLayout;
    QHBoxLayout *horizontalLayout_4;
    QComboBox *optionsProfileGroup;
    QPushButton *reloadProfiles;
    QPushButton *loadBackups;
    QPushButton *saveBackups;
    QPushButton *loadDefaults;
    QComboBox *optionsProfile;
    QPushButton *addOptionProfile;
    QPushButton *removeOptionProfile;
    QPushButton *saveProfile;
    QPushButton *openProfile;
    QPushButton *copyProfile;
    QTextEdit *description;
    QGroupBox *sextractorOptions;
    QGridLayout *gridLayout;
    QLineEdit *r_min;
    QSpinBox *fwhm;
    QLineEdit *magzero;
    QLineEdit *deblend_contrast;
    QLabel *label_19;
    QLineEdit *kron_fact;
    QLabel *label_25;
    QLabel *label_23;
    QLabel *label_15;
    QComboBox *convFilter;
    QLineEdit *deblend_thresh;
    QLabel *label_38;
    QLabel *label_13;
    QComboBox *apertureShape;
    QLabel *label_20;
    QLabel *label_18;
    QLabel *label_14;
    QLabel *label_26;
    QLabel *label_12;
    QCheckBox *cleanCheckBox;
    QLineEdit *clean_param;
    QLabel *label_24;
    QLineEdit *subpix;
    QLabel *label_21;
    QLineEdit *minarea;
    QLabel *label_22;
    QLineEdit *threshOffset;
    QLabel *label_30;
    QLineEdit *threshMultiple;
    QGroupBox *starFilterOptions;
    QGridLayout *gridLayout_2;
    QLineEdit *maxEllipse;
    QLineEdit *brightestPercent;
    QLabel *label_41;
    QLineEdit *dimmestPercent;
    QLabel *label_52;
    QLineEdit *saturationLimit;
    QLabel *label_46;
    QLineEdit *minSize;
    QLabel *label_39;
    QLabel *label_56;
    QLabel *label_43;
    QLineEdit *maxSize;
    QLabel *label_57;
    QLabel *label_51;
    QLabel *label_40;
    QLabel *label_55;
    QLabel *label_44;
    QLabel *label_49;
    QLabel *label_53;
    QLabel *label_54;
    QLineEdit *keepNum;
    QLineEdit *initialKeep;
    QLabel *label;
    QLabel *label_2;
    QGroupBox *astrometryOptions;
    QGridLayout *gridLayout_3;
    QLabel *label_29;
    QSpinBox *downsample;
    QLabel *label_9;
    QLabel *label_16;
    QComboBox *multiAlgo;
    QLineEdit *maxWidth;
    QLineEdit *radius;
    QCheckBox *resort;
    QLineEdit *minWidth;
    QLabel *label_27;
    QLabel *label_33;
    QLabel *label_28;
    QLineEdit *solverTimeLimit;
    QCheckBox *autoDownsample;
    QCheckBox *inParallel;
    QSpacerItem *verticalSpacer;

    void setupUi(QWidget *StellarSolverProfileEditor)
    {
        if (StellarSolverProfileEditor->objectName().isEmpty())
            StellarSolverProfileEditor->setObjectName("StellarSolverProfileEditor");
        StellarSolverProfileEditor->resize(488, 671);
        verticalLayout_5 = new QVBoxLayout(StellarSolverProfileEditor);
        verticalLayout_5->setSpacing(3);
        verticalLayout_5->setObjectName("verticalLayout_5");
        verticalLayout_5->setContentsMargins(3, 3, 3, 3);
        groupBox_4 = new QGroupBox(StellarSolverProfileEditor);
        groupBox_4->setObjectName("groupBox_4");
        verticalLayout = new QVBoxLayout(groupBox_4);
        verticalLayout->setSpacing(3);
        verticalLayout->setObjectName("verticalLayout");
        verticalLayout->setContentsMargins(3, 3, 3, 3);
        horizontalLayout_4 = new QHBoxLayout();
        horizontalLayout_4->setSpacing(3);
        horizontalLayout_4->setObjectName("horizontalLayout_4");
        optionsProfileGroup = new QComboBox(groupBox_4);
        optionsProfileGroup->addItem(QString());
        optionsProfileGroup->addItem(QString());
        optionsProfileGroup->addItem(QString());
        optionsProfileGroup->addItem(QString());
        optionsProfileGroup->setObjectName("optionsProfileGroup");
        QSizePolicy sizePolicy(QSizePolicy::Policy::Preferred, QSizePolicy::Policy::Fixed);
        sizePolicy.setHorizontalStretch(0);
        sizePolicy.setVerticalStretch(0);
        sizePolicy.setHeightForWidth(optionsProfileGroup->sizePolicy().hasHeightForWidth());
        optionsProfileGroup->setSizePolicy(sizePolicy);

        horizontalLayout_4->addWidget(optionsProfileGroup);

        reloadProfiles = new QPushButton(groupBox_4);
        reloadProfiles->setObjectName("reloadProfiles");
        reloadProfiles->setMinimumSize(QSize(22, 22));
        reloadProfiles->setMaximumSize(QSize(22, 22));

        horizontalLayout_4->addWidget(reloadProfiles);

        loadBackups = new QPushButton(groupBox_4);
        loadBackups->setObjectName("loadBackups");
        loadBackups->setMinimumSize(QSize(22, 22));
        loadBackups->setMaximumSize(QSize(22, 22));

        horizontalLayout_4->addWidget(loadBackups);

        saveBackups = new QPushButton(groupBox_4);
        saveBackups->setObjectName("saveBackups");
        saveBackups->setMinimumSize(QSize(22, 22));
        saveBackups->setMaximumSize(QSize(22, 22));

        horizontalLayout_4->addWidget(saveBackups);

        loadDefaults = new QPushButton(groupBox_4);
        loadDefaults->setObjectName("loadDefaults");
        loadDefaults->setMinimumSize(QSize(22, 22));
        loadDefaults->setMaximumSize(QSize(22, 22));

        horizontalLayout_4->addWidget(loadDefaults);

        optionsProfile = new QComboBox(groupBox_4);
        optionsProfile->setObjectName("optionsProfile");
        sizePolicy.setHeightForWidth(optionsProfile->sizePolicy().hasHeightForWidth());
        optionsProfile->setSizePolicy(sizePolicy);

        horizontalLayout_4->addWidget(optionsProfile);

        addOptionProfile = new QPushButton(groupBox_4);
        addOptionProfile->setObjectName("addOptionProfile");
        addOptionProfile->setMinimumSize(QSize(0, 0));
        addOptionProfile->setMaximumSize(QSize(30, 30));
        addOptionProfile->setIconSize(QSize(24, 24));

        horizontalLayout_4->addWidget(addOptionProfile);

        removeOptionProfile = new QPushButton(groupBox_4);
        removeOptionProfile->setObjectName("removeOptionProfile");
        removeOptionProfile->setMaximumSize(QSize(30, 30));
        removeOptionProfile->setIconSize(QSize(24, 24));

        horizontalLayout_4->addWidget(removeOptionProfile);

        saveProfile = new QPushButton(groupBox_4);
        saveProfile->setObjectName("saveProfile");
        saveProfile->setMinimumSize(QSize(22, 22));
        saveProfile->setMaximumSize(QSize(22, 22));

        horizontalLayout_4->addWidget(saveProfile);

        openProfile = new QPushButton(groupBox_4);
        openProfile->setObjectName("openProfile");
        openProfile->setMinimumSize(QSize(22, 22));
        openProfile->setMaximumSize(QSize(22, 22));

        horizontalLayout_4->addWidget(openProfile);

        copyProfile = new QPushButton(groupBox_4);
        copyProfile->setObjectName("copyProfile");
        copyProfile->setMinimumSize(QSize(22, 22));
        copyProfile->setMaximumSize(QSize(22, 22));

        horizontalLayout_4->addWidget(copyProfile);


        verticalLayout->addLayout(horizontalLayout_4);

        description = new QTextEdit(groupBox_4);
        description->setObjectName("description");
        description->setMaximumSize(QSize(16777215, 50));

        verticalLayout->addWidget(description);


        verticalLayout_5->addWidget(groupBox_4);

        sextractorOptions = new QGroupBox(StellarSolverProfileEditor);
        sextractorOptions->setObjectName("sextractorOptions");
        gridLayout = new QGridLayout(sextractorOptions);
        gridLayout->setSpacing(3);
        gridLayout->setObjectName("gridLayout");
        gridLayout->setContentsMargins(3, 3, 3, 3);
        r_min = new QLineEdit(sextractorOptions);
        r_min->setObjectName("r_min");

        gridLayout->addWidget(r_min, 4, 6, 1, 1);

        fwhm = new QSpinBox(sextractorOptions);
        fwhm->setObjectName("fwhm");
        fwhm->setMinimum(1);
        fwhm->setMaximum(100);

        gridLayout->addWidget(fwhm, 5, 3, 1, 1);

        magzero = new QLineEdit(sextractorOptions);
        magzero->setObjectName("magzero");

        gridLayout->addWidget(magzero, 5, 6, 1, 1);

        deblend_contrast = new QLineEdit(sextractorOptions);
        deblend_contrast->setObjectName("deblend_contrast");

        gridLayout->addWidget(deblend_contrast, 3, 3, 1, 1);

        label_19 = new QLabel(sextractorOptions);
        label_19->setObjectName("label_19");

        gridLayout->addWidget(label_19, 3, 2, 1, 1);

        kron_fact = new QLineEdit(sextractorOptions);
        kron_fact->setObjectName("kron_fact");

        gridLayout->addWidget(kron_fact, 2, 6, 1, 1);

        label_25 = new QLabel(sextractorOptions);
        label_25->setObjectName("label_25");

        gridLayout->addWidget(label_25, 2, 5, 1, 1);

        label_23 = new QLabel(sextractorOptions);
        label_23->setObjectName("label_23");

        gridLayout->addWidget(label_23, 5, 2, 1, 1);

        label_15 = new QLabel(sextractorOptions);
        label_15->setObjectName("label_15");

        gridLayout->addWidget(label_15, 5, 5, 1, 1);

        convFilter = new QComboBox(sextractorOptions);
        convFilter->addItem(QString());
        convFilter->addItem(QString());
        convFilter->addItem(QString());
        convFilter->addItem(QString());
        convFilter->addItem(QString());
        convFilter->setObjectName("convFilter");

        gridLayout->addWidget(convFilter, 4, 3, 1, 1);

        deblend_thresh = new QLineEdit(sextractorOptions);
        deblend_thresh->setObjectName("deblend_thresh");

        gridLayout->addWidget(deblend_thresh, 2, 3, 1, 1);

        label_38 = new QLabel(sextractorOptions);
        label_38->setObjectName("label_38");
        QSizePolicy sizePolicy1(QSizePolicy::Policy::Preferred, QSizePolicy::Policy::Preferred);
        sizePolicy1.setHorizontalStretch(0);
        sizePolicy1.setVerticalStretch(0);
        sizePolicy1.setHeightForWidth(label_38->sizePolicy().hasHeightForWidth());
        label_38->setSizePolicy(sizePolicy1);
        label_38->setOpenExternalLinks(true);

        gridLayout->addWidget(label_38, 0, 0, 1, 2);

        label_13 = new QLabel(sextractorOptions);
        label_13->setObjectName("label_13");

        gridLayout->addWidget(label_13, 4, 5, 1, 1);

        apertureShape = new QComboBox(sextractorOptions);
        apertureShape->addItem(QString());
        apertureShape->addItem(QString());
        apertureShape->addItem(QString());
        apertureShape->setObjectName("apertureShape");

        gridLayout->addWidget(apertureShape, 3, 6, 1, 1);

        label_20 = new QLabel(sextractorOptions);
        label_20->setObjectName("label_20");
        label_20->setOpenExternalLinks(true);

        gridLayout->addWidget(label_20, 0, 2, 1, 2);

        label_18 = new QLabel(sextractorOptions);
        label_18->setObjectName("label_18");

        gridLayout->addWidget(label_18, 2, 2, 1, 1);

        label_14 = new QLabel(sextractorOptions);
        label_14->setObjectName("label_14");
        sizePolicy1.setHeightForWidth(label_14->sizePolicy().hasHeightForWidth());
        label_14->setSizePolicy(sizePolicy1);
        label_14->setOpenExternalLinks(true);

        gridLayout->addWidget(label_14, 0, 5, 1, 2);

        label_26 = new QLabel(sextractorOptions);
        label_26->setObjectName("label_26");

        gridLayout->addWidget(label_26, 4, 2, 1, 1);

        label_12 = new QLabel(sextractorOptions);
        label_12->setObjectName("label_12");

        gridLayout->addWidget(label_12, 3, 5, 1, 1);

        cleanCheckBox = new QCheckBox(sextractorOptions);
        cleanCheckBox->setObjectName("cleanCheckBox");
        cleanCheckBox->setChecked(true);

        gridLayout->addWidget(cleanCheckBox, 6, 0, 1, 1);

        clean_param = new QLineEdit(sextractorOptions);
        clean_param->setObjectName("clean_param");

        gridLayout->addWidget(clean_param, 6, 1, 1, 1);

        label_24 = new QLabel(sextractorOptions);
        label_24->setObjectName("label_24");

        gridLayout->addWidget(label_24, 5, 0, 1, 1);

        subpix = new QLineEdit(sextractorOptions);
        subpix->setObjectName("subpix");

        gridLayout->addWidget(subpix, 5, 1, 1, 1);

        label_21 = new QLabel(sextractorOptions);
        label_21->setObjectName("label_21");

        gridLayout->addWidget(label_21, 4, 0, 1, 1);

        minarea = new QLineEdit(sextractorOptions);
        minarea->setObjectName("minarea");

        gridLayout->addWidget(minarea, 4, 1, 1, 1);

        label_22 = new QLabel(sextractorOptions);
        label_22->setObjectName("label_22");

        gridLayout->addWidget(label_22, 3, 0, 1, 1);

        threshOffset = new QLineEdit(sextractorOptions);
        threshOffset->setObjectName("threshOffset");

        gridLayout->addWidget(threshOffset, 3, 1, 1, 1);

        label_30 = new QLabel(sextractorOptions);
        label_30->setObjectName("label_30");

        gridLayout->addWidget(label_30, 2, 0, 1, 1);

        threshMultiple = new QLineEdit(sextractorOptions);
        threshMultiple->setObjectName("threshMultiple");

        gridLayout->addWidget(threshMultiple, 2, 1, 1, 1);


        verticalLayout_5->addWidget(sextractorOptions);

        starFilterOptions = new QGroupBox(StellarSolverProfileEditor);
        starFilterOptions->setObjectName("starFilterOptions");
        gridLayout_2 = new QGridLayout(starFilterOptions);
        gridLayout_2->setSpacing(3);
        gridLayout_2->setObjectName("gridLayout_2");
        gridLayout_2->setContentsMargins(3, 3, 3, 3);
        maxEllipse = new QLineEdit(starFilterOptions);
        maxEllipse->setObjectName("maxEllipse");

        gridLayout_2->addWidget(maxEllipse, 4, 1, 1, 1);

        brightestPercent = new QLineEdit(starFilterOptions);
        brightestPercent->setObjectName("brightestPercent");

        gridLayout_2->addWidget(brightestPercent, 2, 4, 1, 1);

        label_41 = new QLabel(starFilterOptions);
        label_41->setObjectName("label_41");

        gridLayout_2->addWidget(label_41, 3, 3, 1, 1);

        dimmestPercent = new QLineEdit(starFilterOptions);
        dimmestPercent->setObjectName("dimmestPercent");

        gridLayout_2->addWidget(dimmestPercent, 3, 4, 1, 1);

        label_52 = new QLabel(starFilterOptions);
        label_52->setObjectName("label_52");

        gridLayout_2->addWidget(label_52, 4, 5, 1, 1);

        saturationLimit = new QLineEdit(starFilterOptions);
        saturationLimit->setObjectName("saturationLimit");

        gridLayout_2->addWidget(saturationLimit, 4, 4, 1, 1);

        label_46 = new QLabel(starFilterOptions);
        label_46->setObjectName("label_46");

        gridLayout_2->addWidget(label_46, 4, 3, 1, 1);

        minSize = new QLineEdit(starFilterOptions);
        minSize->setObjectName("minSize");

        gridLayout_2->addWidget(minSize, 3, 1, 1, 1);

        label_39 = new QLabel(starFilterOptions);
        label_39->setObjectName("label_39");

        gridLayout_2->addWidget(label_39, 4, 0, 1, 1);

        label_56 = new QLabel(starFilterOptions);
        label_56->setObjectName("label_56");

        gridLayout_2->addWidget(label_56, 3, 0, 1, 1);

        label_43 = new QLabel(starFilterOptions);
        label_43->setObjectName("label_43");

        gridLayout_2->addWidget(label_43, 2, 0, 1, 1);

        maxSize = new QLineEdit(starFilterOptions);
        maxSize->setObjectName("maxSize");

        gridLayout_2->addWidget(maxSize, 2, 1, 1, 1);

        label_57 = new QLabel(starFilterOptions);
        label_57->setObjectName("label_57");

        gridLayout_2->addWidget(label_57, 3, 2, 1, 1);

        label_51 = new QLabel(starFilterOptions);
        label_51->setObjectName("label_51");

        gridLayout_2->addWidget(label_51, 3, 5, 1, 1);

        label_40 = new QLabel(starFilterOptions);
        label_40->setObjectName("label_40");

        gridLayout_2->addWidget(label_40, 2, 3, 1, 1);

        label_55 = new QLabel(starFilterOptions);
        label_55->setObjectName("label_55");

        gridLayout_2->addWidget(label_55, 0, 5, 1, 1);

        label_44 = new QLabel(starFilterOptions);
        label_44->setObjectName("label_44");

        gridLayout_2->addWidget(label_44, 2, 5, 1, 1);

        label_49 = new QLabel(starFilterOptions);
        label_49->setObjectName("label_49");

        gridLayout_2->addWidget(label_49, 2, 2, 1, 1);

        label_53 = new QLabel(starFilterOptions);
        label_53->setObjectName("label_53");

        gridLayout_2->addWidget(label_53, 4, 2, 1, 1);

        label_54 = new QLabel(starFilterOptions);
        label_54->setObjectName("label_54");

        gridLayout_2->addWidget(label_54, 0, 3, 1, 1);

        keepNum = new QLineEdit(starFilterOptions);
        keepNum->setObjectName("keepNum");

        gridLayout_2->addWidget(keepNum, 0, 4, 1, 1);

        initialKeep = new QLineEdit(starFilterOptions);
        initialKeep->setObjectName("initialKeep");

        gridLayout_2->addWidget(initialKeep, 0, 1, 1, 1);

        label = new QLabel(starFilterOptions);
        label->setObjectName("label");

        gridLayout_2->addWidget(label, 0, 0, 1, 1);

        label_2 = new QLabel(starFilterOptions);
        label_2->setObjectName("label_2");

        gridLayout_2->addWidget(label_2, 0, 2, 1, 1);


        verticalLayout_5->addWidget(starFilterOptions);

        astrometryOptions = new QGroupBox(StellarSolverProfileEditor);
        astrometryOptions->setObjectName("astrometryOptions");
        gridLayout_3 = new QGridLayout(astrometryOptions);
        gridLayout_3->setSpacing(3);
        gridLayout_3->setObjectName("gridLayout_3");
        gridLayout_3->setContentsMargins(3, 3, 3, 3);
        label_29 = new QLabel(astrometryOptions);
        label_29->setObjectName("label_29");

        gridLayout_3->addWidget(label_29, 5, 0, 1, 1);

        downsample = new QSpinBox(astrometryOptions);
        downsample->setObjectName("downsample");
        downsample->setMinimum(1);
        downsample->setMaximum(5);

        gridLayout_3->addWidget(downsample, 4, 2, 1, 1);

        label_9 = new QLabel(astrometryOptions);
        label_9->setObjectName("label_9");

        gridLayout_3->addWidget(label_9, 5, 3, 1, 1);

        label_16 = new QLabel(astrometryOptions);
        label_16->setObjectName("label_16");

        gridLayout_3->addWidget(label_16, 4, 0, 1, 1);

        multiAlgo = new QComboBox(astrometryOptions);
        multiAlgo->addItem(QString());
        multiAlgo->addItem(QString());
        multiAlgo->addItem(QString());
        multiAlgo->addItem(QString());
        multiAlgo->setObjectName("multiAlgo");

        gridLayout_3->addWidget(multiAlgo, 3, 2, 1, 1);

        maxWidth = new QLineEdit(astrometryOptions);
        maxWidth->setObjectName("maxWidth");

        gridLayout_3->addWidget(maxWidth, 4, 4, 1, 1);

        radius = new QLineEdit(astrometryOptions);
        radius->setObjectName("radius");

        gridLayout_3->addWidget(radius, 5, 4, 1, 1);

        resort = new QCheckBox(astrometryOptions);
        resort->setObjectName("resort");

        gridLayout_3->addWidget(resort, 0, 0, 1, 1);

        minWidth = new QLineEdit(astrometryOptions);
        minWidth->setObjectName("minWidth");

        gridLayout_3->addWidget(minWidth, 3, 4, 1, 1);

        label_27 = new QLabel(astrometryOptions);
        label_27->setObjectName("label_27");

        gridLayout_3->addWidget(label_27, 3, 3, 1, 1);

        label_33 = new QLabel(astrometryOptions);
        label_33->setObjectName("label_33");

        gridLayout_3->addWidget(label_33, 3, 0, 1, 1);

        label_28 = new QLabel(astrometryOptions);
        label_28->setObjectName("label_28");

        gridLayout_3->addWidget(label_28, 4, 3, 1, 1);

        solverTimeLimit = new QLineEdit(astrometryOptions);
        solverTimeLimit->setObjectName("solverTimeLimit");

        gridLayout_3->addWidget(solverTimeLimit, 5, 2, 1, 1);

        autoDownsample = new QCheckBox(astrometryOptions);
        autoDownsample->setObjectName("autoDownsample");
        autoDownsample->setChecked(true);

        gridLayout_3->addWidget(autoDownsample, 0, 2, 1, 1);

        inParallel = new QCheckBox(astrometryOptions);
        inParallel->setObjectName("inParallel");
        inParallel->setChecked(true);

        gridLayout_3->addWidget(inParallel, 0, 3, 1, 2);


        verticalLayout_5->addWidget(astrometryOptions);

        verticalSpacer = new QSpacerItem(20, 1, QSizePolicy::Policy::Minimum, QSizePolicy::Policy::Expanding);

        verticalLayout_5->addItem(verticalSpacer);


        retranslateUi(StellarSolverProfileEditor);

        optionsProfileGroup->setCurrentIndex(0);
        optionsProfile->setCurrentIndex(-1);
        convFilter->setCurrentIndex(0);
        apertureShape->setCurrentIndex(1);
        multiAlgo->setCurrentIndex(0);


        QMetaObject::connectSlotsByName(StellarSolverProfileEditor);
    } // setupUi

    void retranslateUi(QWidget *StellarSolverProfileEditor)
    {
        groupBox_4->setTitle(tr2i18n("Options Profiles", nullptr));
        optionsProfileGroup->setItemText(0, tr2i18n("Alignment Profiles", nullptr));
        optionsProfileGroup->setItemText(1, tr2i18n("Focus SEP Profiles", nullptr));
        optionsProfileGroup->setItemText(2, tr2i18n("Guide SEP Profiles", nullptr));
        optionsProfileGroup->setItemText(3, tr2i18n("HFR SEP Profiles", nullptr));

#if QT_CONFIG(tooltip)
        optionsProfileGroup->setToolTip(tr2i18n("Selects the profile group that the editor is working with", nullptr));
#endif // QT_CONFIG(tooltip)
#if QT_CONFIG(tooltip)
        reloadProfiles->setToolTip(tr2i18n("Reloads the options profiles from the saved file", nullptr));
#endif // QT_CONFIG(tooltip)
        reloadProfiles->setText(QString());
#if QT_CONFIG(tooltip)
        loadBackups->setToolTip(tr2i18n("Loads an alternate or backup file of profiles you saved somewhere else on your computer into and replaces all profiles in this group", nullptr));
#endif // QT_CONFIG(tooltip)
        loadBackups->setText(QString());
#if QT_CONFIG(tooltip)
        saveBackups->setToolTip(tr2i18n("Saves your current set of profiles in this group somewhere else on your computer", nullptr));
#endif // QT_CONFIG(tooltip)
        saveBackups->setText(QString());
#if QT_CONFIG(tooltip)
        loadDefaults->setToolTip(tr2i18n("Loads the default set of profiles, clearing any modifications or custom profiles.", nullptr));
#endif // QT_CONFIG(tooltip)
        loadDefaults->setText(QString());
#if QT_CONFIG(tooltip)
        optionsProfile->setToolTip(tr2i18n("This lets you select which options profile you want to load and edit.", nullptr));
#endif // QT_CONFIG(tooltip)
#if QT_CONFIG(tooltip)
        addOptionProfile->setToolTip(tr2i18n("This allows you to add a new Options Profile and give it a name", nullptr));
#endif // QT_CONFIG(tooltip)
        addOptionProfile->setText(tr2i18n("+", nullptr));
#if QT_CONFIG(tooltip)
        removeOptionProfile->setToolTip(tr2i18n("This allows you to remove the currently selected options profile", nullptr));
#endif // QT_CONFIG(tooltip)
        removeOptionProfile->setText(tr2i18n("-", nullptr));
#if QT_CONFIG(tooltip)
        saveProfile->setToolTip(tr2i18n("Saves this single profile to a separate file on your computer so that you can back it up or sent it to someone else.", nullptr));
#endif // QT_CONFIG(tooltip)
        saveProfile->setText(QString());
#if QT_CONFIG(tooltip)
        openProfile->setToolTip(tr2i18n("Opens a profile from a file on your computer and loads it into this profile group", nullptr));
#endif // QT_CONFIG(tooltip)
        openProfile->setText(QString());
#if QT_CONFIG(tooltip)
        copyProfile->setToolTip(tr2i18n("Copies the current options profile so that you can either make a duplicate in this profile group or copy it into another profile group", nullptr));
#endif // QT_CONFIG(tooltip)
        copyProfile->setText(QString());
#if QT_CONFIG(tooltip)
        description->setToolTip(tr2i18n("Description of the selected profile", nullptr));
#endif // QT_CONFIG(tooltip)
        sextractorOptions->setTitle(tr2i18n("Sextractor Parameters", nullptr));
#if QT_CONFIG(tooltip)
        r_min->setToolTip(tr2i18n("The minimum radius for stars for flux calculations.", nullptr));
#endif // QT_CONFIG(tooltip)
        r_min->setText(tr2i18n("3.5", nullptr));
#if QT_CONFIG(tooltip)
        fwhm->setToolTip(tr2i18n("A variable to store the fwhm in pixels used to generate the convolution filter for star detection.", nullptr));
#endif // QT_CONFIG(tooltip)
#if QT_CONFIG(tooltip)
        magzero->setToolTip(tr2i18n("This is the 'zero' magnitude used for setting the magnitude scale for the stars in the image during sextraction.", nullptr));
#endif // QT_CONFIG(tooltip)
        magzero->setText(tr2i18n("20", nullptr));
#if QT_CONFIG(tooltip)
        deblend_contrast->setToolTip(tr2i18n("The percentage of flux a separate peak must have to be considered a separate object.", nullptr));
#endif // QT_CONFIG(tooltip)
        deblend_contrast->setText(tr2i18n("1", nullptr));
        label_19->setText(tr2i18n("Min Cont.", nullptr));
#if QT_CONFIG(tooltip)
        kron_fact->setToolTip(tr2i18n("This sets the Kron Factor for use with the kron radius for flux calculations.", nullptr));
#endif // QT_CONFIG(tooltip)
        kron_fact->setText(tr2i18n("3.5", nullptr));
        label_25->setText(tr2i18n("Kron Factor", nullptr));
        label_23->setText(tr2i18n("Conv FWHM", nullptr));
        label_15->setText(tr2i18n("magzero", nullptr));
        convFilter->setItemText(0, tr2i18n("Default", nullptr));
        convFilter->setItemText(1, tr2i18n("Custom", nullptr));
        convFilter->setItemText(2, tr2i18n("Gaussian", nullptr));
        convFilter->setItemText(3, tr2i18n("Mexican Hat", nullptr));
        convFilter->setItemText(4, tr2i18n("Top Hat", nullptr));

#if QT_CONFIG(tooltip)
        convFilter->setToolTip(tr2i18n("The type of Convolution Filter that SEP will apply to the image prior to star extraction.  These filters are comparable to the included filters in a SExtractor installation, but here you have the flexibility to change the FWHM.  The Default filter is the fastest filter, but does NOT change with the FWHM setting, and so is best for small stars.  The Gaussian Filter is best for faint object detection.  The Mexican Hat filter is good in crowded star fields or in the vicinity of nebulae.  The Top Hat filter is good for extended, low brightness objects.  Note: The \"Custom\" filter selection is meant for testing purposes and should only be used by developers", nullptr));
#endif // QT_CONFIG(tooltip)
#if QT_CONFIG(tooltip)
        deblend_thresh->setToolTip(tr2i18n("The number of thresholds the intensity range is divided up into.", nullptr));
#endif // QT_CONFIG(tooltip)
        deblend_thresh->setText(tr2i18n("32", nullptr));
        label_38->setText(tr2i18n("<a href = \"https://sep.readthedocs.io/en/v1.0.x/api/sep.extract.html\" >Extraction Params</a>", nullptr));
        label_13->setText(tr2i18n("r_min", nullptr));
        apertureShape->setItemText(0, tr2i18n("Auto", "Aperture Shape"));
        apertureShape->setItemText(1, tr2i18n("Circle", nullptr));
        apertureShape->setItemText(2, tr2i18n("Ellipse", nullptr));

#if QT_CONFIG(tooltip)
        apertureShape->setToolTip(tr2i18n("Whether to use the SEP_SUM_ELLIPSE method or the SEP_SUM_CIRCLE method or automatically choose.  NOTE: Circle is usually better at the moment", nullptr));
#endif // QT_CONFIG(tooltip)
        label_20->setText(tr2i18n("<a href=\"https://sep.readthedocs.io/en/v1.0.x/api/sep.extract.html\">Deblending Params</a>", nullptr));
        label_18->setText(tr2i18n("Thresh", nullptr));
        label_14->setText(tr2i18n("<a href = \"https://sep.readthedocs.io/en/v1.0.x/api/sep.sum_ellipse.html\">Photometry Params</a>", nullptr));
        label_26->setText(tr2i18n("Conv Filter", nullptr));
        label_12->setText(tr2i18n("Shape", nullptr));
#if QT_CONFIG(tooltip)
        cleanCheckBox->setToolTip(tr2i18n("Attempts to 'clean' the image to remove artifacts caused by bright objects", nullptr));
#endif // QT_CONFIG(tooltip)
        cleanCheckBox->setText(tr2i18n("Clean?", nullptr));
#if QT_CONFIG(tooltip)
        clean_param->setToolTip(tr2i18n(" The cleaning parameter", nullptr));
#endif // QT_CONFIG(tooltip)
        clean_param->setText(tr2i18n("1", nullptr));
        label_24->setText(tr2i18n("Sub Pix", nullptr));
#if QT_CONFIG(tooltip)
        subpix->setToolTip(tr2i18n("The subpixel sampling factor for star extraction", nullptr));
#endif // QT_CONFIG(tooltip)
        subpix->setText(tr2i18n("5", nullptr));
        label_21->setText(tr2i18n("Min Area", nullptr));
#if QT_CONFIG(tooltip)
        minarea->setToolTip(tr2i18n("This is the minimum area in pixels for a star detection, smaller stars are ignored.", nullptr));
#endif // QT_CONFIG(tooltip)
        minarea->setText(tr2i18n("5", nullptr));
        label_22->setText(tr2i18n("Thresh Offset", nullptr));
#if QT_CONFIG(tooltip)
        threshOffset->setToolTip(tr2i18n("Add this offset to the detection threshold", nullptr));
#endif // QT_CONFIG(tooltip)
        threshOffset->setText(tr2i18n("0", nullptr));
        label_30->setText(tr2i18n("Thresh Multiple", nullptr));
#if QT_CONFIG(tooltip)
        threshMultiple->setToolTip(tr2i18n("Add the multiple times the rms background level to the detection threshold.", nullptr));
#endif // QT_CONFIG(tooltip)
        threshMultiple->setText(tr2i18n("2.0", nullptr));
        starFilterOptions->setTitle(tr2i18n("Star Filtering Parameters (Make these settings 0 to disable them)", nullptr));
#if QT_CONFIG(tooltip)
        maxEllipse->setToolTip(tr2i18n("The maximum ratio between the semi-major and semi-minor axes for stars to include (a/b), this will allow you to exclude elliptical sources like galaxies or badly distorted stars.", nullptr));
#endif // QT_CONFIG(tooltip)
        maxEllipse->setText(tr2i18n("0", nullptr));
#if QT_CONFIG(tooltip)
        brightestPercent->setToolTip(tr2i18n("The percentage of brightest stars to remove from the list", nullptr));
#endif // QT_CONFIG(tooltip)
        brightestPercent->setText(tr2i18n("0", nullptr));
        label_41->setText(tr2i18n("Cut Dimmest", nullptr));
#if QT_CONFIG(tooltip)
        dimmestPercent->setToolTip(tr2i18n("The percentage of dimmest stars to remove from the list", nullptr));
#endif // QT_CONFIG(tooltip)
        dimmestPercent->setText(tr2i18n("0", nullptr));
        label_52->setText(tr2i18n("%", nullptr));
#if QT_CONFIG(tooltip)
        saturationLimit->setToolTip(tr2i18n("Remove all stars above a certain threshold percentage of saturation", nullptr));
#endif // QT_CONFIG(tooltip)
        saturationLimit->setText(tr2i18n("0", nullptr));
        label_46->setText(tr2i18n("Sat. Limit", nullptr));
#if QT_CONFIG(tooltip)
        minSize->setToolTip(tr2i18n("The minimum size of stars to include in the final list in pixels based on semi-major and semi-minor axes", nullptr));
#endif // QT_CONFIG(tooltip)
        minSize->setText(tr2i18n("0", nullptr));
        label_39->setText(tr2i18n("Max Ellipse", nullptr));
        label_56->setText(tr2i18n("Min Size", nullptr));
        label_43->setText(tr2i18n("Max Size", nullptr));
#if QT_CONFIG(tooltip)
        maxSize->setToolTip(tr2i18n("The maximum size of stars to include in the final list in pixels based on semi-major and semi-minor axes", nullptr));
#endif // QT_CONFIG(tooltip)
        maxSize->setText(tr2i18n("0", nullptr));
        label_57->setText(tr2i18n("px", nullptr));
        label_51->setText(tr2i18n("%", nullptr));
        label_40->setText(tr2i18n("Cut Brightest", nullptr));
        label_55->setText(tr2i18n("stars", nullptr));
        label_44->setText(tr2i18n("%", nullptr));
        label_49->setText(tr2i18n("px", nullptr));
        label_53->setText(tr2i18n("a/b", nullptr));
        label_54->setText(tr2i18n("Keep #", nullptr));
#if QT_CONFIG(tooltip)
        keepNum->setToolTip(tr2i18n("The number of stars to keep in the list after star extraction. This parameter is based on magnitude and is most useful to speed up plate solving, such as in the Align Module.", nullptr));
#endif // QT_CONFIG(tooltip)
        keepNum->setText(tr2i18n("0", nullptr));
#if QT_CONFIG(tooltip)
        initialKeep->setToolTip(tr2i18n("The number of stars to keep in the list initially. This filter is based on the size of the stars.  It is primarily useful for speeding up star extraction with HFR such as in Focus, Guide, and HFR monitoring.", nullptr));
#endif // QT_CONFIG(tooltip)
        initialKeep->setText(tr2i18n("500", nullptr));
        label->setText(tr2i18n("InitialKeep", nullptr));
        label_2->setText(tr2i18n("stars", nullptr));
        astrometryOptions->setTitle(tr2i18n("Astrometry Parameters", nullptr));
        label_29->setText(tr2i18n("Maximum time", nullptr));
#if QT_CONFIG(tooltip)
        downsample->setToolTip(tr2i18n("Factor to use for downsampling the image before SEP for plate solving.  Can speed it up.", nullptr));
#endif // QT_CONFIG(tooltip)
        label_9->setText(tr2i18n("Search Radius", nullptr));
        label_16->setText(tr2i18n("DownSample", nullptr));
        multiAlgo->setItemText(0, tr2i18n("None", nullptr));
        multiAlgo->setItemText(1, tr2i18n("MultiScales", nullptr));
        multiAlgo->setItemText(2, tr2i18n("MultiDepths", nullptr));
        multiAlgo->setItemText(3, tr2i18n("Auto", nullptr));

#if QT_CONFIG(tooltip)
        multiAlgo->setToolTip(tr2i18n("Algorithm for running multiple threads on possibly multiple cores to solve faster", nullptr));
#endif // QT_CONFIG(tooltip)
#if QT_CONFIG(tooltip)
        maxWidth->setToolTip(tr2i18n("If no scale estimate is given, this is the limit on the maximum field width in degrees.", nullptr));
#endif // QT_CONFIG(tooltip)
        maxWidth->setText(tr2i18n("180", nullptr));
#if QT_CONFIG(tooltip)
        radius->setToolTip(tr2i18n("Only search in indexes within 'radius' of the field center given by RA and DEC", nullptr));
#endif // QT_CONFIG(tooltip)
        radius->setText(tr2i18n("15", nullptr));
#if QT_CONFIG(tooltip)
        resort->setToolTip(tr2i18n("Whether to resort the stars based on magnitude. NOTE: This is REQUIRED to be true for the filters above", nullptr));
#endif // QT_CONFIG(tooltip)
        resort->setText(tr2i18n("Resort", nullptr));
#if QT_CONFIG(tooltip)
        minWidth->setToolTip(tr2i18n("If no scale estimate is given, this is the limit on the minimum field width in degrees.", nullptr));
#endif // QT_CONFIG(tooltip)
        minWidth->setText(tr2i18n("0.1", nullptr));
        label_27->setText(tr2i18n("Min Degree Width", nullptr));
        label_33->setText(tr2i18n("Parallel Algorithm", nullptr));
        label_28->setText(tr2i18n("Max Degree Width", nullptr));
#if QT_CONFIG(tooltip)
        solverTimeLimit->setToolTip(tr2i18n("Give up solving after the specified number of seconds of CPU time", nullptr));
#endif // QT_CONFIG(tooltip)
        solverTimeLimit->setText(tr2i18n("600", nullptr));
#if QT_CONFIG(tooltip)
        autoDownsample->setToolTip(tr2i18n("Automatically Downsamples the image based on the image size", nullptr));
#endif // QT_CONFIG(tooltip)
        autoDownsample->setText(tr2i18n("Auto DownSample", nullptr));
#if QT_CONFIG(tooltip)
        inParallel->setToolTip(tr2i18n("Check the indices in parallel by loading them simultaneously into memory? If the indices you are using take less than 2 GB of space, and you have at least as much physical memory as indices, you want this enabled.", nullptr));
#endif // QT_CONFIG(tooltip)
        inParallel->setText(tr2i18n("Load all Indexes in Memory", nullptr));
        (void)StellarSolverProfileEditor;
    } // retranslateUi

};

namespace Ui {
    class StellarSolverProfileEditor: public Ui_StellarSolverProfileEditor {};
} // namespace Ui

QT_END_NAMESPACE

#endif // STELLARSOLVERPROFILEEDITOR_H

