/*
 * This file was generated by qdbusxml2cpp version 0.8
 * Source file was org.kde.kstars.Ekos.Capture.xml
 *
 * qdbusxml2cpp is Copyright (C) The Qt Company Ltd. and other contributors.
 *
 * This is an auto-generated file.
 * This file may have been hand-edited. Look for HAND-EDIT comments
 * before re-generating it.
 */

#ifndef CAPTUREADAPTOR_H
#define CAPTUREADAPTOR_H

#include <QtCore/QObject>
#include <QtDBus/QtDBus>
#include "ekos/capture/capture.h"
#include <QtCore/qcontainerfwd.h>

/*
 * Adaptor class for interface org.kde.kstars.Ekos.Capture
 */
class CaptureAdaptor: public QDBusAbstractAdaptor
{
    Q_OBJECT
    Q_CLASSINFO("D-Bus Interface", "org.kde.kstars.Ekos.Capture")
    Q_CLASSINFO("D-Bus Introspection", ""
"  <interface name=\"org.kde.kstars.Ekos.Capture\">\n"
"    <property access=\"readwrite\" type=\"s\" name=\"targetName\"/>\n"
"    <property access=\"readwrite\" type=\"s\" name=\"observerName\"/>\n"
"    <property access=\"readwrite\" type=\"s\" name=\"opticalTrain\"/>\n"
"    <property access=\"read\" type=\"s\" name=\"camera\"/>\n"
"    <property access=\"read\" type=\"s\" name=\"filterWheel\"/>\n"
"    <property access=\"readwrite\" type=\"s\" name=\"filter\"/>\n"
"    <property access=\"readwrite\" type=\"b\" name=\"coolerControl\"/>\n"
"    <property access=\"read\" type=\"as\" name=\"logText\"/>\n"
"    <property access=\"read\" type=\"i\" name=\"status\">\n"
"      <annotation value=\"Ekos::CaptureState\" name=\"org.qtproject.QtDBus.QtTypeName\"/>\n"
"    </property>\n"
"    <method name=\"start\">\n"
"      <arg direction=\"in\" type=\"s\" name=\"train\"/>\n"
"      <arg direction=\"out\" type=\"s\"/>\n"
"    </method>\n"
"    <method name=\"abort\">\n"
"      <arg direction=\"in\" type=\"s\" name=\"train\"/>\n"
"      <annotation value=\"true\" name=\"org.freedesktop.DBus.Method.NoReply\"/>\n"
"    </method>\n"
"    <method name=\"suspend\">\n"
"      <annotation value=\"true\" name=\"org.freedesktop.DBus.Method.NoReply\"/>\n"
"    </method>\n"
"    <method name=\"stop\">\n"
"      <annotation value=\"true\" name=\"org.freedesktop.DBus.Method.NoReply\"/>\n"
"    </method>\n"
"    <method name=\"pause\">\n"
"      <annotation value=\"true\" name=\"org.freedesktop.DBus.Method.NoReply\"/>\n"
"    </method>\n"
"    <method name=\"toggleSequence\">\n"
"      <annotation value=\"true\" name=\"org.freedesktop.DBus.Method.NoReply\"/>\n"
"    </method>\n"
"    <method name=\"restartCamera\">\n"
"      <arg direction=\"in\" type=\"s\" name=\"name\"/>\n"
"      <annotation value=\"true\" name=\"org.freedesktop.DBus.Method.NoReply\"/>\n"
"    </method>\n"
"    <method name=\"toggleVideo\">\n"
"      <arg direction=\"in\" type=\"b\" name=\"enabled\"/>\n"
"      <annotation value=\"true\" name=\"org.freedesktop.DBus.Method.NoReply\"/>\n"
"    </method>\n"
"    <method name=\"findCameraPosition\">\n"
"      <arg direction=\"out\" type=\"i\"/>\n"
"      <arg direction=\"in\" type=\"s\" name=\"train\"/>\n"
"      <arg direction=\"in\" type=\"b\" name=\"addIfNecessary\"/>\n"
"    </method>\n"
"    <method name=\"loadSequenceQueue\">\n"
"      <arg direction=\"out\" type=\"b\"/>\n"
"      <arg direction=\"in\" type=\"s\" name=\"fileURL\"/>\n"
"      <arg direction=\"in\" type=\"s\" name=\"train\"/>\n"
"      <arg direction=\"in\" type=\"b\" name=\"isMaster\"/>\n"
"      <arg direction=\"in\" type=\"s\" name=\"targetName\"/>\n"
"    </method>\n"
"    <method name=\"saveSequenceQueue\">\n"
"      <arg direction=\"out\" type=\"b\"/>\n"
"      <arg direction=\"in\" type=\"s\" name=\"path\"/>\n"
"    </method>\n"
"    <method name=\"clearSequenceQueue\">\n"
"      <annotation value=\"true\" name=\"org.freedesktop.DBus.Method.NoReply\"/>\n"
"    </method>\n"
"    <method name=\"getSequenceQueueStatus\">\n"
"      <arg direction=\"out\" type=\"s\"/>\n"
"    </method>\n"
"    <method name=\"setMaximumGuidingDeviation\">\n"
"      <arg direction=\"in\" type=\"b\" name=\"enable\"/>\n"
"      <arg direction=\"in\" type=\"d\" name=\"value\"/>\n"
"      <annotation value=\"true\" name=\"org.freedesktop.DBus.Method.NoReply\"/>\n"
"    </method>\n"
"    <method name=\"setInSequenceFocus\">\n"
"      <arg direction=\"in\" type=\"b\" name=\"enable\"/>\n"
"      <arg direction=\"in\" type=\"d\" name=\"HFR\"/>\n"
"      <annotation value=\"true\" name=\"org.freedesktop.DBus.Method.NoReply\"/>\n"
"    </method>\n"
"    <method name=\"getJobCount\">\n"
"      <arg direction=\"out\" type=\"i\"/>\n"
"    </method>\n"
"    <method name=\"getPendingJobCount\">\n"
"      <arg direction=\"out\" type=\"i\"/>\n"
"    </method>\n"
"    <method name=\"getJobState\">\n"
"      <arg direction=\"out\" type=\"s\"/>\n"
"      <arg direction=\"in\" type=\"i\" name=\"id\"/>\n"
"    </method>\n"
"    <method name=\"getJobFilterName\">\n"
"      <arg direction=\"out\" type=\"s\"/>\n"
"      <arg direction=\"in\" type=\"i\" name=\"id\"/>\n"
"    </method>\n"
"    <method name=\"getJobImageProgress\">\n"
"      <arg direction=\"out\" type=\"i\"/>\n"
"      <arg direction=\"in\" type=\"i\" name=\"id\"/>\n"
"    </method>\n"
"    <method name=\"getJobImageCount\">\n"
"      <arg direction=\"out\" type=\"i\"/>\n"
"      <arg direction=\"in\" type=\"i\" name=\"id\"/>\n"
"    </method>\n"
"    <method name=\"getJobExposureProgress\">\n"
"      <arg direction=\"out\" type=\"d\"/>\n"
"      <arg direction=\"in\" type=\"i\" name=\"id\"/>\n"
"    </method>\n"
"    <method name=\"getJobExposureDuration\">\n"
"      <arg direction=\"out\" type=\"d\"/>\n"
"      <arg direction=\"in\" type=\"i\" name=\"id\"/>\n"
"    </method>\n"
"    <method name=\"getJobFrameType\">\n"
"      <arg direction=\"out\" type=\"i\"/>\n"
"      <arg direction=\"in\" type=\"i\" name=\"id\"/>\n"
"    </method>\n"
"    <method name=\"getJobPlaceholderFormat\">\n"
"      <arg direction=\"out\" type=\"s\"/>\n"
"    </method>\n"
"    <method name=\"getJobPreviewFileName\">\n"
"      <arg direction=\"out\" type=\"s\"/>\n"
"    </method>\n"
"    <method name=\"getProgressPercentage\">\n"
"      <arg direction=\"out\" type=\"d\"/>\n"
"    </method>\n"
"    <method name=\"getActiveJobID\">\n"
"      <arg direction=\"out\" type=\"i\"/>\n"
"    </method>\n"
"    <method name=\"getActiveJobRemainingTime\">\n"
"      <arg direction=\"out\" type=\"i\"/>\n"
"    </method>\n"
"    <method name=\"getOverallRemainingTime\">\n"
"      <arg direction=\"out\" type=\"i\"/>\n"
"    </method>\n"
"    <method name=\"clearAutoFocusHFR\">\n"
"      <arg direction=\"in\" type=\"s\" name=\"trainname\"/>\n"
"      <annotation value=\"true\" name=\"org.freedesktop.DBus.Method.NoReply\"/>\n"
"    </method>\n"
"    <method name=\"ignoreSequenceHistory\">\n"
"      <annotation value=\"true\" name=\"org.freedesktop.DBus.Method.NoReply\"/>\n"
"    </method>\n"
"    <method name=\"setCapturedFramesMap\">\n"
"      <arg direction=\"in\" type=\"s\" name=\"signature\"/>\n"
"      <arg direction=\"in\" type=\"i\" name=\"count\"/>\n"
"      <arg direction=\"in\" type=\"s\" name=\"train\"/>\n"
"      <annotation value=\"true\" name=\"org.freedesktop.DBus.Method.NoReply\"/>\n"
"    </method>\n"
"    <method name=\"setPicturesDirectory\">\n"
"      <arg direction=\"in\" type=\"s\" name=\"path\"/>\n"
"      <arg direction=\"out\" type=\"b\"/>\n"
"    </method>\n"
"    <method name=\"getPicturesDirectory\">\n"
"      <arg direction=\"out\" type=\"s\"/>\n"
"    </method>\n"
"    <method name=\"mainCameraDeviceName\">\n"
"      <arg direction=\"out\" type=\"s\"/>\n"
"    </method>\n"
"    <signal name=\"newLog\">\n"
"      <arg direction=\"out\" type=\"s\" name=\"text\"/>\n"
"    </signal>\n"
"    <signal name=\"meridianFlipStarted\"/>\n"
"    <signal name=\"newStatus\">\n"
"      <arg direction=\"out\" type=\"(i)\" name=\"status\"/>\n"
"      <arg direction=\"out\" type=\"s\" name=\"trainname\"/>\n"
"      <arg direction=\"out\" type=\"i\" name=\"cameraID\"/>\n"
"      <annotation value=\"Ekos::CaptureState\" name=\"org.qtproject.QtDBus.QtTypeName.Out0\"/>\n"
"    </signal>\n"
"    <signal name=\"captureComplete\">\n"
"      <arg direction=\"out\" type=\"a{sv}\" name=\"metadata\"/>\n"
"      <arg direction=\"out\" type=\"s\" name=\"train\"/>\n"
"      <annotation value=\"QVariantMap\" name=\"org.qtproject.QtDBus.QtTypeName.In0\"/>\n"
"      <annotation value=\"QVariantMap\" name=\"org.qtproject.QtDBus.QtTypeName.Out0\"/>\n"
"    </signal>\n"
"    <signal name=\"ready\"/>\n"
"  </interface>\n"
        "")
public:
    CaptureAdaptor(Ekos::Capture *parent);
    ~CaptureAdaptor() override;

    inline Ekos::Capture *parent() const
    { return static_cast<Ekos::Capture *>(QObject::parent()); }

public: // PROPERTIES
    Q_PROPERTY(QString camera READ camera)
    QString camera() const;

    Q_PROPERTY(bool coolerControl READ coolerControl WRITE setCoolerControl)
    bool coolerControl() const;
    void setCoolerControl(bool value);

    Q_PROPERTY(QString filter READ filter WRITE setFilter)
    QString filter() const;
    void setFilter(const QString &value);

    Q_PROPERTY(QString filterWheel READ filterWheel)
    QString filterWheel() const;

    Q_PROPERTY(QStringList logText READ logText)
    QStringList logText() const;

    Q_PROPERTY(QString observerName READ observerName WRITE setObserverName)
    QString observerName() const;
    void setObserverName(const QString &value);

    Q_PROPERTY(QString opticalTrain READ opticalTrain WRITE setOpticalTrain)
    QString opticalTrain() const;
    void setOpticalTrain(const QString &value);

    Q_PROPERTY(int status READ status)
    int status() const;

    Q_PROPERTY(QString targetName READ targetName WRITE setTargetName)
    QString targetName() const;
    void setTargetName(const QString &value);

public Q_SLOTS: // METHODS
    Q_NOREPLY void abort(const QString &train);
    Q_NOREPLY void clearAutoFocusHFR(const QString &trainname);
    Q_NOREPLY void clearSequenceQueue();
    int findCameraPosition(const QString &train, bool addIfNecessary);
    int getActiveJobID();
    int getActiveJobRemainingTime();
    int getJobCount();
    double getJobExposureDuration(int id);
    double getJobExposureProgress(int id);
    QString getJobFilterName(int id);
    int getJobFrameType(int id);
    int getJobImageCount(int id);
    int getJobImageProgress(int id);
    QString getJobPlaceholderFormat();
    QString getJobPreviewFileName();
    QString getJobState(int id);
    int getOverallRemainingTime();
    int getPendingJobCount();
    QString getPicturesDirectory();
    double getProgressPercentage();
    QString getSequenceQueueStatus();
    Q_NOREPLY void ignoreSequenceHistory();
    bool loadSequenceQueue(const QString &fileURL, const QString &train, bool isMaster, const QString &targetName);
    QString mainCameraDeviceName();
    Q_NOREPLY void pause();
    Q_NOREPLY void restartCamera(const QString &name);
    bool saveSequenceQueue(const QString &path);
    Q_NOREPLY void setCapturedFramesMap(const QString &signature, int count, const QString &train);
    Q_NOREPLY void setInSequenceFocus(bool enable, double HFR);
    Q_NOREPLY void setMaximumGuidingDeviation(bool enable, double value);
    bool setPicturesDirectory(const QString &path);
    QString start(const QString &train);
    Q_NOREPLY void stop();
    Q_NOREPLY void suspend();
    Q_NOREPLY void toggleSequence();
    Q_NOREPLY void toggleVideo(bool enabled);
Q_SIGNALS: // SIGNALS
    void captureComplete(const QVariantMap &metadata, const QString &train);
    void meridianFlipStarted();
    void newLog(const QString &text);
    void newStatus(Ekos::CaptureState status, const QString &trainname, int cameraID);
    void ready();
};

#endif
