/********************************************************************************
** Form generated from reading UI file 'fitsdebayer.ui'
**
** Created by: Qt User Interface Compiler version 6.11.1
**
** WARNING! All changes made in this file will be lost when recompiling UI file!
********************************************************************************/

#ifndef UI_FITSDEBAYER_H
#define UI_FITSDEBAYER_H

#include <QtCore/QVariant>
#include <QtWidgets/QAbstractButton>
#include <QtWidgets/QApplication>
#include <QtWidgets/QComboBox>
#include <QtWidgets/QDialog>
#include <QtWidgets/QDialogButtonBox>
#include <QtWidgets/QFormLayout>
#include <QtWidgets/QLabel>
#include <QtWidgets/QLineEdit>
#include <QtWidgets/QSpinBox>
#include <QtWidgets/QVBoxLayout>
#include <klocalizedstring.h>

QT_BEGIN_NAMESPACE

class Ui_FITSDebayerDialog
{
public:
    QVBoxLayout *verticalLayout;
    QFormLayout *formLayout;
    QLabel *xOffsetLabel;
    QSpinBox *XOffsetSpin;
    QLabel *yOffsetLabel;
    QSpinBox *YOffsetSpin;
    QLabel *statusLabel;
    QLineEdit *statusEdit;
    QLabel *engineLabel;
    QComboBox *engineCombo;
    QLabel *filterLabel;
    QLabel *methodLabel;
    QComboBox *filterCombo;
    QComboBox *methodCombo;
    QDialogButtonBox *buttonBox;

    void setupUi(QDialog *FITSDebayerDialog)
    {
        if (FITSDebayerDialog->objectName().isEmpty())
            FITSDebayerDialog->setObjectName("FITSDebayerDialog");
        FITSDebayerDialog->resize(215, 274);
        verticalLayout = new QVBoxLayout(FITSDebayerDialog);
        verticalLayout->setObjectName("verticalLayout");
        formLayout = new QFormLayout();
        formLayout->setObjectName("formLayout");
        xOffsetLabel = new QLabel(FITSDebayerDialog);
        xOffsetLabel->setObjectName("xOffsetLabel");

        formLayout->setWidget(4, QFormLayout::ItemRole::LabelRole, xOffsetLabel);

        XOffsetSpin = new QSpinBox(FITSDebayerDialog);
        XOffsetSpin->setObjectName("XOffsetSpin");
        XOffsetSpin->setMinimum(0);
        XOffsetSpin->setMaximum(1);

        formLayout->setWidget(4, QFormLayout::ItemRole::FieldRole, XOffsetSpin);

        yOffsetLabel = new QLabel(FITSDebayerDialog);
        yOffsetLabel->setObjectName("yOffsetLabel");

        formLayout->setWidget(5, QFormLayout::ItemRole::LabelRole, yOffsetLabel);

        YOffsetSpin = new QSpinBox(FITSDebayerDialog);
        YOffsetSpin->setObjectName("YOffsetSpin");
        YOffsetSpin->setMinimum(0);
        YOffsetSpin->setMaximum(1);

        formLayout->setWidget(5, QFormLayout::ItemRole::FieldRole, YOffsetSpin);

        statusLabel = new QLabel(FITSDebayerDialog);
        statusLabel->setObjectName("statusLabel");

        formLayout->setWidget(6, QFormLayout::ItemRole::LabelRole, statusLabel);

        statusEdit = new QLineEdit(FITSDebayerDialog);
        statusEdit->setObjectName("statusEdit");
        statusEdit->setReadOnly(true);

        formLayout->setWidget(6, QFormLayout::ItemRole::FieldRole, statusEdit);

        engineLabel = new QLabel(FITSDebayerDialog);
        engineLabel->setObjectName("engineLabel");

        formLayout->setWidget(0, QFormLayout::ItemRole::LabelRole, engineLabel);

        engineCombo = new QComboBox(FITSDebayerDialog);
        engineCombo->addItem(QString());
        engineCombo->addItem(QString());
        engineCombo->setObjectName("engineCombo");

        formLayout->setWidget(0, QFormLayout::ItemRole::FieldRole, engineCombo);

        filterLabel = new QLabel(FITSDebayerDialog);
        filterLabel->setObjectName("filterLabel");

        formLayout->setWidget(2, QFormLayout::ItemRole::LabelRole, filterLabel);

        methodLabel = new QLabel(FITSDebayerDialog);
        methodLabel->setObjectName("methodLabel");

        formLayout->setWidget(1, QFormLayout::ItemRole::LabelRole, methodLabel);

        filterCombo = new QComboBox(FITSDebayerDialog);
        filterCombo->addItem(QString());
        filterCombo->addItem(QString());
        filterCombo->addItem(QString());
        filterCombo->addItem(QString());
        filterCombo->setObjectName("filterCombo");

        formLayout->setWidget(2, QFormLayout::ItemRole::FieldRole, filterCombo);

        methodCombo = new QComboBox(FITSDebayerDialog);
        methodCombo->addItem(QString());
        methodCombo->addItem(QString());
        methodCombo->addItem(QString());
        methodCombo->addItem(QString());
        methodCombo->addItem(QString());
        methodCombo->setObjectName("methodCombo");

        formLayout->setWidget(1, QFormLayout::ItemRole::FieldRole, methodCombo);


        verticalLayout->addLayout(formLayout);

        buttonBox = new QDialogButtonBox(FITSDebayerDialog);
        buttonBox->setObjectName("buttonBox");
        buttonBox->setOrientation(Qt::Horizontal);
        buttonBox->setStandardButtons(QDialogButtonBox::Apply);

        verticalLayout->addWidget(buttonBox);


        retranslateUi(FITSDebayerDialog);
        QObject::connect(buttonBox, &QDialogButtonBox::accepted, FITSDebayerDialog, qOverload<>(&QDialog::accept));
        QObject::connect(buttonBox, &QDialogButtonBox::rejected, FITSDebayerDialog, qOverload<>(&QDialog::reject));

        QMetaObject::connectSlotsByName(FITSDebayerDialog);
    } // setupUi

    void retranslateUi(QDialog *FITSDebayerDialog)
    {
        FITSDebayerDialog->setWindowTitle(tr2i18n("Image Debayering", nullptr));
        xOffsetLabel->setText(tr2i18n("X Offset:", nullptr));
        yOffsetLabel->setText(tr2i18n("Y Offset:", nullptr));
        statusLabel->setText(tr2i18n("Status:", nullptr));
        statusEdit->setText(tr2i18n("Ready.", nullptr));
        engineLabel->setText(tr2i18n("Engine:", nullptr));
        engineCombo->setItemText(0, tr2i18n("dc1394", nullptr));
        engineCombo->setItemText(1, tr2i18n("openCV", nullptr));

#if QT_CONFIG(tooltip)
        engineCombo->setToolTip(tr2i18n("<html><head/><body><p><br/></p></body></html>", nullptr));
#endif // QT_CONFIG(tooltip)
        filterLabel->setText(tr2i18n("Filter:", nullptr));
        methodLabel->setText(tr2i18n("Method:", nullptr));
        filterCombo->setItemText(0, tr2i18n("RGGB", nullptr));
        filterCombo->setItemText(1, tr2i18n("GBRG", nullptr));
        filterCombo->setItemText(2, tr2i18n("GRBG", nullptr));
        filterCombo->setItemText(3, tr2i18n("BGGR", nullptr));

        methodCombo->setItemText(0, tr2i18n("Nearest", nullptr));
        methodCombo->setItemText(1, tr2i18n("Simple", nullptr));
        methodCombo->setItemText(2, tr2i18n("BILinear", nullptr));
        methodCombo->setItemText(3, tr2i18n("HQLinear", nullptr));
        methodCombo->setItemText(4, tr2i18n("VNG", nullptr));

    } // retranslateUi

};

namespace Ui {
    class FITSDebayerDialog: public Ui_FITSDebayerDialog {};
} // namespace Ui

QT_END_NAMESPACE

#endif // FITSDEBAYER_H

