/********************************************************************************
** Form generated from reading UI file 'opsalignmentsettings.ui'
**
** Created by: Qt User Interface Compiler version 6.11.1
**
** WARNING! All changes made in this file will be lost when recompiling UI file!
********************************************************************************/

#ifndef UI_OPSALIGNMENTSETTINGS_H
#define UI_OPSALIGNMENTSETTINGS_H

#include <QtCore/QVariant>
#include <QtWidgets/QApplication>
#include <QtWidgets/QCheckBox>
#include <QtWidgets/QDoubleSpinBox>
#include <QtWidgets/QGridLayout>
#include <QtWidgets/QLabel>
#include <QtWidgets/QSpacerItem>
#include <QtWidgets/QSpinBox>
#include <QtWidgets/QWidget>
#include <klocalizedstring.h>

QT_BEGIN_NAMESPACE

class Ui_OpsAlignmentSettings
{
public:
    QGridLayout *gridLayout;
    QDoubleSpinBox *kcfg_AlignCheckThreshold;
    QLabel *label_8;
    QLabel *label_6;
    QSpinBox *kcfg_AlignCheckFrequency;
    QLabel *label_10;
    QLabel *label_7;
    QCheckBox *kcfg_ResetMountModelOnAlignFail;
    QCheckBox *kcfg_RealignAfterCalibrationFailure;
    QCheckBox *kcfg_ResetMountModelBeforeJob;
    QCheckBox *kcfg_ForceAlignmentBeforeJob;
    QSpacerItem *verticalSpacer;

    void setupUi(QWidget *OpsAlignmentSettings)
    {
        if (OpsAlignmentSettings->objectName().isEmpty())
            OpsAlignmentSettings->setObjectName("OpsAlignmentSettings");
        OpsAlignmentSettings->resize(408, 168);
        OpsAlignmentSettings->setProperty("currentIndex", QVariant(1));
        gridLayout = new QGridLayout(OpsAlignmentSettings);
        gridLayout->setSpacing(3);
        gridLayout->setObjectName("gridLayout");
        gridLayout->setContentsMargins(3, 3, 3, 3);
        kcfg_AlignCheckThreshold = new QDoubleSpinBox(OpsAlignmentSettings);
        kcfg_AlignCheckThreshold->setObjectName("kcfg_AlignCheckThreshold");
        kcfg_AlignCheckThreshold->setMaximum(3600.000000000000000);
        kcfg_AlignCheckThreshold->setSingleStep(60.000000000000000);

        gridLayout->addWidget(kcfg_AlignCheckThreshold, 1, 1, 1, 1);

        label_8 = new QLabel(OpsAlignmentSettings);
        label_8->setObjectName("label_8");

        gridLayout->addWidget(label_8, 1, 0, 1, 1);

        label_6 = new QLabel(OpsAlignmentSettings);
        label_6->setObjectName("label_6");

        gridLayout->addWidget(label_6, 0, 0, 1, 1);

        kcfg_AlignCheckFrequency = new QSpinBox(OpsAlignmentSettings);
        kcfg_AlignCheckFrequency->setObjectName("kcfg_AlignCheckFrequency");
        kcfg_AlignCheckFrequency->setMaximum(100);

        gridLayout->addWidget(kcfg_AlignCheckFrequency, 0, 1, 1, 1);

        label_10 = new QLabel(OpsAlignmentSettings);
        label_10->setObjectName("label_10");

        gridLayout->addWidget(label_10, 1, 2, 1, 1);

        label_7 = new QLabel(OpsAlignmentSettings);
        label_7->setObjectName("label_7");

        gridLayout->addWidget(label_7, 0, 2, 1, 1);

        kcfg_ResetMountModelOnAlignFail = new QCheckBox(OpsAlignmentSettings);
        kcfg_ResetMountModelOnAlignFail->setObjectName("kcfg_ResetMountModelOnAlignFail");

        gridLayout->addWidget(kcfg_ResetMountModelOnAlignFail, 2, 0, 1, 1);

        kcfg_RealignAfterCalibrationFailure = new QCheckBox(OpsAlignmentSettings);
        kcfg_RealignAfterCalibrationFailure->setObjectName("kcfg_RealignAfterCalibrationFailure");

        gridLayout->addWidget(kcfg_RealignAfterCalibrationFailure, 5, 0, 1, 2);

        kcfg_ResetMountModelBeforeJob = new QCheckBox(OpsAlignmentSettings);
        kcfg_ResetMountModelBeforeJob->setObjectName("kcfg_ResetMountModelBeforeJob");

        gridLayout->addWidget(kcfg_ResetMountModelBeforeJob, 3, 0, 1, 2);

        kcfg_ForceAlignmentBeforeJob = new QCheckBox(OpsAlignmentSettings);
        kcfg_ForceAlignmentBeforeJob->setObjectName("kcfg_ForceAlignmentBeforeJob");

        gridLayout->addWidget(kcfg_ForceAlignmentBeforeJob, 4, 0, 1, 1);

        verticalSpacer = new QSpacerItem(20, 40, QSizePolicy::Policy::Minimum, QSizePolicy::Policy::Expanding);

        gridLayout->addItem(verticalSpacer, 6, 0, 1, 1);


        retranslateUi(OpsAlignmentSettings);

        QMetaObject::connectSlotsByName(OpsAlignmentSettings);
    } // setupUi

    void retranslateUi(QWidget *OpsAlignmentSettings)
    {
        OpsAlignmentSettings->setWindowTitle(tr2i18n("TabWidget", nullptr));
#if QT_CONFIG(tooltip)
        label_8->setToolTip(tr2i18n("If captured position exceeds target position by more this many arcminutes, abort capture and reschedule the pipeline.", nullptr));
#endif // QT_CONFIG(tooltip)
        label_8->setText(tr2i18n("Reset pipeline if verified image delta exceeds:", nullptr));
#if QT_CONFIG(tooltip)
        label_6->setToolTip(tr2i18n("When calculating position after captures, compute it every Nth capture. Set to 0 to disable.", nullptr));
#endif // QT_CONFIG(tooltip)
        label_6->setText(tr2i18n("Verify captured image position every:", nullptr));
        label_10->setText(tr2i18n("arcminutes", nullptr));
        label_7->setText(tr2i18n("frames", nullptr));
        kcfg_ResetMountModelOnAlignFail->setText(tr2i18n("Reset mount model on alignment failure", nullptr));
#if QT_CONFIG(tooltip)
        kcfg_RealignAfterCalibrationFailure->setToolTip(tr2i18n("<html><head/><body><p>If guiding calibration fails then restart alignment process before proceeding to guiding recalibration process again. This can help recenter the target object in the field of view if the calibration process strayed too far off.</p></body></html>", nullptr));
#endif // QT_CONFIG(tooltip)
        kcfg_RealignAfterCalibrationFailure->setText(tr2i18n("Restart alignment on guiding calibration failure", nullptr));
        kcfg_ResetMountModelBeforeJob->setText(tr2i18n("Reset mount model before starting each job:", nullptr));
#if QT_CONFIG(tooltip)
        kcfg_ForceAlignmentBeforeJob->setToolTip(tr2i18n("If Align is enabled, scheduler would initiate a realignment procedure before restarting any jobs even if guiding is active.", nullptr));
#endif // QT_CONFIG(tooltip)
        kcfg_ForceAlignmentBeforeJob->setText(tr2i18n("Force re-alignment before re-starting jobs", nullptr));
    } // retranslateUi

};

namespace Ui {
    class OpsAlignmentSettings: public Ui_OpsAlignmentSettings {};
} // namespace Ui

QT_END_NAMESPACE

#endif // OPSALIGNMENTSETTINGS_H

