/********************************************************************************
** Form generated from reading UI file 'catalogobject.ui'
**
** Created by: Qt User Interface Compiler version 6.11.1
**
** WARNING! All changes made in this file will be lost when recompiling UI file!
********************************************************************************/

#ifndef UI_CATALOGOBJECT_H
#define UI_CATALOGOBJECT_H

#include <QtCore/QVariant>
#include <QtWidgets/QApplication>
#include <QtWidgets/QCheckBox>
#include <QtWidgets/QDialog>
#include <QtWidgets/QHBoxLayout>
#include <QtWidgets/QHeaderView>
#include <QtWidgets/QLabel>
#include <QtWidgets/QPushButton>
#include <QtWidgets/QTableView>
#include <QtWidgets/QVBoxLayout>
#include <klocalizedstring.h>

QT_BEGIN_NAMESPACE

class Ui_CatalogObjectUI
{
public:
    QVBoxLayout *verticalLayout;
    QHBoxLayout *horizontalLayout;
    QLabel *status;
    QCheckBox *kcfg_FitsCatObjShowNames;
    QPushButton *filterPB;
    QTableView *tableView;

    void setupUi(QDialog *CatalogObjectUI)
    {
        if (CatalogObjectUI->objectName().isEmpty())
            CatalogObjectUI->setObjectName("CatalogObjectUI");
        CatalogObjectUI->resize(511, 247);
        CatalogObjectUI->setSizeGripEnabled(true);
        verticalLayout = new QVBoxLayout(CatalogObjectUI);
        verticalLayout->setObjectName("verticalLayout");
        horizontalLayout = new QHBoxLayout();
        horizontalLayout->setObjectName("horizontalLayout");
        status = new QLabel(CatalogObjectUI);
        status->setObjectName("status");
        QSizePolicy sizePolicy(QSizePolicy::Policy::Preferred, QSizePolicy::Policy::Fixed);
        sizePolicy.setHorizontalStretch(0);
        sizePolicy.setVerticalStretch(0);
        sizePolicy.setHeightForWidth(status->sizePolicy().hasHeightForWidth());
        status->setSizePolicy(sizePolicy);

        horizontalLayout->addWidget(status);

        kcfg_FitsCatObjShowNames = new QCheckBox(CatalogObjectUI);
        kcfg_FitsCatObjShowNames->setObjectName("kcfg_FitsCatObjShowNames");
        QSizePolicy sizePolicy1(QSizePolicy::Policy::Fixed, QSizePolicy::Policy::Fixed);
        sizePolicy1.setHorizontalStretch(0);
        sizePolicy1.setVerticalStretch(0);
        sizePolicy1.setHeightForWidth(kcfg_FitsCatObjShowNames->sizePolicy().hasHeightForWidth());
        kcfg_FitsCatObjShowNames->setSizePolicy(sizePolicy1);
        kcfg_FitsCatObjShowNames->setChecked(true);

        horizontalLayout->addWidget(kcfg_FitsCatObjShowNames);

        filterPB = new QPushButton(CatalogObjectUI);
        filterPB->setObjectName("filterPB");
        sizePolicy1.setHeightForWidth(filterPB->sizePolicy().hasHeightForWidth());
        filterPB->setSizePolicy(sizePolicy1);

        horizontalLayout->addWidget(filterPB);


        verticalLayout->addLayout(horizontalLayout);

        tableView = new QTableView(CatalogObjectUI);
        tableView->setObjectName("tableView");
        tableView->setSizeAdjustPolicy(QAbstractScrollArea::AdjustToContents);
        tableView->setAutoScroll(true);
        tableView->setEditTriggers(QAbstractItemView::NoEditTriggers);
        tableView->setAlternatingRowColors(true);
        tableView->setSelectionMode(QAbstractItemView::SingleSelection);
        tableView->setSelectionBehavior(QAbstractItemView::SelectRows);
        tableView->setShowGrid(true);
        tableView->setSortingEnabled(true);
        tableView->verticalHeader()->setVisible(false);
        tableView->verticalHeader()->setDefaultSectionSize(24);
        tableView->verticalHeader()->setHighlightSections(false);

        verticalLayout->addWidget(tableView);


        retranslateUi(CatalogObjectUI);

        QMetaObject::connectSlotsByName(CatalogObjectUI);
    } // setupUi

    void retranslateUi(QDialog *CatalogObjectUI)
    {
        CatalogObjectUI->setWindowTitle(tr2i18n("FITS Header", nullptr));
        status->setText(QString());
        kcfg_FitsCatObjShowNames->setText(tr2i18n("Show Names", nullptr));
#if QT_CONFIG(tooltip)
        filterPB->setToolTip(tr2i18n("Launches the Catalog Object Filter dialog", nullptr));
#endif // QT_CONFIG(tooltip)
        filterPB->setText(tr2i18n("Filter", nullptr));
    } // retranslateUi

};

namespace Ui {
    class CatalogObjectUI: public Ui_CatalogObjectUI {};
} // namespace Ui

QT_END_NAMESPACE

#endif // CATALOGOBJECT_H

