/****************************************************************************
** Meta object code from reading C++ file 'catalogsdbui.h'
**
** Created by: The Qt Meta Object Compiler version 69 (Qt 6.11.1)
**
** WARNING! All changes made in this file will be lost!
*****************************************************************************/

#include "../../../../kstars-3.8.4.1/kstars/dialogs/catalogsdbui.h"
#include <QtCore/qmetatype.h>

#include <QtCore/qtmochelpers.h>

#include <memory>


#include <QtCore/qxptype_traits.h>
#if !defined(Q_MOC_OUTPUT_REVISION)
#error "The header file 'catalogsdbui.h' doesn't include <QObject>."
#elif Q_MOC_OUTPUT_REVISION != 69
#error "This file was generated using the moc from 6.11.1. It"
#error "cannot be used with the include files from this version of Qt."
#error "(The moc has changed too much.)"
#endif

#ifndef Q_CONSTINIT
#define Q_CONSTINIT
#endif

QT_WARNING_PUSH
QT_WARNING_DISABLE_DEPRECATED
QT_WARNING_DISABLE_GCC("-Wuseless-cast")
namespace {
struct qt_meta_tag_ZN12CatalogsDBUIE_t {};
} // unnamed namespace

template <> constexpr inline auto CatalogsDBUI::qt_create_metaobjectdata<qt_meta_tag_ZN12CatalogsDBUIE_t>()
{
    namespace QMC = QtMocConstants;
    QtMocHelpers::StringRefStorage qt_stringData {
        "CatalogsDBUI",
        "row_selected",
        "",
        "row",
        "disable_buttons",
        "enable_disable_catalog",
        "export_catalog",
        "import_catalog",
        "force",
        "remove_catalog",
        "create_new_catalog",
        "std::pair<bool,int>",
        "CatalogsDB::Catalog",
        "catalog",
        "show_more_dialog",
        "show_color_editor",
        "dublicate_catalog",
        "refresh_db_table"
    };

    QtMocHelpers::UintData qt_methods {
        // Slot 'row_selected'
        QtMocHelpers::SlotData<void(int, int)>(1, 2, QMC::AccessPrivate, QMetaType::Void, {{
            { QMetaType::Int, 3 }, { QMetaType::Int, 2 },
        }}),
        // Slot 'disable_buttons'
        QtMocHelpers::SlotData<void()>(4, 2, QMC::AccessPrivate, QMetaType::Void),
        // Slot 'enable_disable_catalog'
        QtMocHelpers::SlotData<void()>(5, 2, QMC::AccessPrivate, QMetaType::Void),
        // Slot 'export_catalog'
        QtMocHelpers::SlotData<void()>(6, 2, QMC::AccessPrivate, QMetaType::Void),
        // Slot 'import_catalog'
        QtMocHelpers::SlotData<void(bool)>(7, 2, QMC::AccessPrivate, QMetaType::Void, {{
            { QMetaType::Bool, 8 },
        }}),
        // Slot 'import_catalog'
        QtMocHelpers::SlotData<void()>(7, 2, QMC::AccessPrivate | QMC::MethodCloned, QMetaType::Void),
        // Slot 'remove_catalog'
        QtMocHelpers::SlotData<void()>(9, 2, QMC::AccessPrivate, QMetaType::Void),
        // Slot 'create_new_catalog'
        QtMocHelpers::SlotData<void()>(10, 2, QMC::AccessPrivate, QMetaType::Void),
        // Slot 'create_new_catalog'
        QtMocHelpers::SlotData<std::pair<bool,int>(const CatalogsDB::Catalog &)>(10, 2, QMC::AccessPrivate, 0x80000000 | 11, {{
            { 0x80000000 | 12, 13 },
        }}),
        // Slot 'show_more_dialog'
        QtMocHelpers::SlotData<void()>(14, 2, QMC::AccessPrivate, QMetaType::Void),
        // Slot 'show_color_editor'
        QtMocHelpers::SlotData<void()>(15, 2, QMC::AccessPrivate, QMetaType::Void),
        // Slot 'dublicate_catalog'
        QtMocHelpers::SlotData<void()>(16, 2, QMC::AccessPrivate, QMetaType::Void),
        // Slot 'refresh_db_table'
        QtMocHelpers::SlotData<void()>(17, 2, QMC::AccessPrivate, QMetaType::Void),
    };
    QtMocHelpers::UintData qt_properties {
    };
    QtMocHelpers::UintData qt_enums {
    };
    return QtMocHelpers::metaObjectData<CatalogsDBUI, qt_meta_tag_ZN12CatalogsDBUIE_t>(QMC::MetaObjectFlag{}, qt_stringData,
            qt_methods, qt_properties, qt_enums);
}
Q_CONSTINIT const QMetaObject CatalogsDBUI::staticMetaObject = { {
    QMetaObject::SuperData::link<QDialog::staticMetaObject>(),
    qt_staticMetaObjectStaticContent<qt_meta_tag_ZN12CatalogsDBUIE_t>.stringdata,
    qt_staticMetaObjectStaticContent<qt_meta_tag_ZN12CatalogsDBUIE_t>.data,
    qt_static_metacall,
    nullptr,
    qt_staticMetaObjectRelocatingContent<qt_meta_tag_ZN12CatalogsDBUIE_t>.metaTypes,
    nullptr
} };

void CatalogsDBUI::qt_static_metacall(QObject *_o, QMetaObject::Call _c, int _id, void **_a)
{
    auto *_t = static_cast<CatalogsDBUI *>(_o);
    if (_c == QMetaObject::InvokeMetaMethod) {
        switch (_id) {
        case 0: _t->row_selected((*reinterpret_cast<std::add_pointer_t<int>>(_a[1])),(*reinterpret_cast<std::add_pointer_t<int>>(_a[2]))); break;
        case 1: _t->disable_buttons(); break;
        case 2: _t->enable_disable_catalog(); break;
        case 3: _t->export_catalog(); break;
        case 4: _t->import_catalog((*reinterpret_cast<std::add_pointer_t<bool>>(_a[1]))); break;
        case 5: _t->import_catalog(); break;
        case 6: _t->remove_catalog(); break;
        case 7: _t->create_new_catalog(); break;
        case 8: { std::pair<bool,int> _r = _t->create_new_catalog((*reinterpret_cast<std::add_pointer_t<CatalogsDB::Catalog>>(_a[1])));
            if (_a[0]) *reinterpret_cast<std::pair<bool,int>*>(_a[0]) = std::move(_r); }  break;
        case 9: _t->show_more_dialog(); break;
        case 10: _t->show_color_editor(); break;
        case 11: _t->dublicate_catalog(); break;
        case 12: _t->refresh_db_table(); break;
        default: ;
        }
    }
}

const QMetaObject *CatalogsDBUI::metaObject() const
{
    return QObject::d_ptr->metaObject ? QObject::d_ptr->dynamicMetaObject() : &staticMetaObject;
}

void *CatalogsDBUI::qt_metacast(const char *_clname)
{
    if (!_clname) return nullptr;
    if (!strcmp(_clname, qt_staticMetaObjectStaticContent<qt_meta_tag_ZN12CatalogsDBUIE_t>.strings))
        return static_cast<void*>(this);
    return QDialog::qt_metacast(_clname);
}

int CatalogsDBUI::qt_metacall(QMetaObject::Call _c, int _id, void **_a)
{
    _id = QDialog::qt_metacall(_c, _id, _a);
    if (_id < 0)
        return _id;
    if (_c == QMetaObject::InvokeMetaMethod) {
        if (_id < 13)
            qt_static_metacall(this, _c, _id, _a);
        _id -= 13;
    }
    if (_c == QMetaObject::RegisterMethodArgumentMetaType) {
        if (_id < 13)
            *reinterpret_cast<QMetaType *>(_a[0]) = QMetaType();
        _id -= 13;
    }
    return _id;
}
QT_WARNING_POP
