/********************************************************************************
** Form generated from reading UI file 'argloadcolorscheme.ui'
**
** Created by: Qt User Interface Compiler version 6.11.1
**
** WARNING! All changes made in this file will be lost when recompiling UI file!
********************************************************************************/

#ifndef UI_ARGLOADCOLORSCHEME_H
#define UI_ARGLOADCOLORSCHEME_H

#include <QtCore/QVariant>
#include <QtWidgets/QApplication>
#include <QtWidgets/QListWidget>
#include <QtWidgets/QVBoxLayout>
#include <QtWidgets/QWidget>
#include <klocalizedstring.h>

QT_BEGIN_NAMESPACE

class Ui_ArgLoadColorScheme
{
public:
    QVBoxLayout *vboxLayout;
    QListWidget *SchemeList;

    void setupUi(QWidget *ArgLoadColorScheme)
    {
        if (ArgLoadColorScheme->objectName().isEmpty())
            ArgLoadColorScheme->setObjectName("ArgLoadColorScheme");
        ArgLoadColorScheme->resize(329, 180);
        vboxLayout = new QVBoxLayout(ArgLoadColorScheme);
#ifndef UI_Q_OS_MAC
        vboxLayout->setSpacing(6);
#endif
        vboxLayout->setContentsMargins(10, 10, 10, 10);
        vboxLayout->setObjectName("vboxLayout");
        SchemeList = new QListWidget(ArgLoadColorScheme);
        SchemeList->setObjectName("SchemeList");

        vboxLayout->addWidget(SchemeList);


        retranslateUi(ArgLoadColorScheme);

        QMetaObject::connectSlotsByName(ArgLoadColorScheme);
    } // setupUi

    void retranslateUi(QWidget *ArgLoadColorScheme)
    {
        (void)ArgLoadColorScheme;
    } // retranslateUi

};

namespace Ui {
    class ArgLoadColorScheme: public Ui_ArgLoadColorScheme {};
} // namespace Ui

QT_END_NAMESPACE

#endif // ARGLOADCOLORSCHEME_H

