/********************************************************************************
** Form generated from reading UI file 'scriptbuilder.ui'
**
** Created by: Qt User Interface Compiler version 6.11.1
**
** WARNING! All changes made in this file will be lost when recompiling UI file!
********************************************************************************/

#ifndef UI_SCRIPTBUILDER_H
#define UI_SCRIPTBUILDER_H

#include <QtCore/QVariant>
#include <QtWidgets/QApplication>
#include <QtWidgets/QGroupBox>
#include <QtWidgets/QHBoxLayout>
#include <QtWidgets/QHeaderView>
#include <QtWidgets/QListWidget>
#include <QtWidgets/QPushButton>
#include <QtWidgets/QSpacerItem>
#include <QtWidgets/QSplitter>
#include <QtWidgets/QStackedWidget>
#include <QtWidgets/QTextEdit>
#include <QtWidgets/QTreeWidget>
#include <QtWidgets/QVBoxLayout>
#include <QtWidgets/QWidget>
#include <klocalizedstring.h>

QT_BEGIN_NAMESPACE

class Ui_ScriptBuilder
{
public:
    QVBoxLayout *vboxLayout;
    QHBoxLayout *hboxLayout;
    QPushButton *NewButton;
    QPushButton *OpenButton;
    QPushButton *SaveButton;
    QPushButton *SaveAsButton;
    QPushButton *RunButton;
    QSpacerItem *spacerItem;
    QSplitter *splitter;
    QGroupBox *groupBox;
    QVBoxLayout *vboxLayout1;
    QHBoxLayout *hboxLayout1;
    QListWidget *ScriptListBox;
    QVBoxLayout *vboxLayout2;
    QPushButton *AddButton;
    QPushButton *RemoveButton;
    QPushButton *CopyButton;
    QPushButton *UpButton;
    QPushButton *DownButton;
    QSpacerItem *spacerItem1;
    QGroupBox *groupBox_2;
    QVBoxLayout *vboxLayout3;
    QStackedWidget *ArgStack;
    QWidget *page;
    QWidget *page_2;
    QGroupBox *groupBox_3;
    QVBoxLayout *vboxLayout4;
    QSplitter *splitter7;
    QTreeWidget *FunctionTree;
    QTextEdit *FuncDoc;

    void setupUi(QWidget *ScriptBuilder)
    {
        if (ScriptBuilder->objectName().isEmpty())
            ScriptBuilder->setObjectName("ScriptBuilder");
        ScriptBuilder->resize(753, 520);
        vboxLayout = new QVBoxLayout(ScriptBuilder);
        vboxLayout->setSpacing(6);
        vboxLayout->setObjectName("vboxLayout");
        vboxLayout->setContentsMargins(9, 9, 9, 9);
        hboxLayout = new QHBoxLayout();
        hboxLayout->setSpacing(6);
        hboxLayout->setObjectName("hboxLayout");
        hboxLayout->setContentsMargins(0, 0, 0, 0);
        NewButton = new QPushButton(ScriptBuilder);
        NewButton->setObjectName("NewButton");
        QSizePolicy sizePolicy(QSizePolicy::Policy::Minimum, QSizePolicy::Policy::Fixed);
        sizePolicy.setHorizontalStretch(0);
        sizePolicy.setVerticalStretch(0);
        sizePolicy.setHeightForWidth(NewButton->sizePolicy().hasHeightForWidth());
        NewButton->setSizePolicy(sizePolicy);
        NewButton->setMinimumSize(QSize(32, 32));
        NewButton->setMaximumSize(QSize(32, 32));
        NewButton->setIconSize(QSize(28, 28));

        hboxLayout->addWidget(NewButton);

        OpenButton = new QPushButton(ScriptBuilder);
        OpenButton->setObjectName("OpenButton");
        sizePolicy.setHeightForWidth(OpenButton->sizePolicy().hasHeightForWidth());
        OpenButton->setSizePolicy(sizePolicy);
        OpenButton->setMinimumSize(QSize(32, 32));
        OpenButton->setMaximumSize(QSize(32, 32));
        OpenButton->setIconSize(QSize(28, 28));

        hboxLayout->addWidget(OpenButton);

        SaveButton = new QPushButton(ScriptBuilder);
        SaveButton->setObjectName("SaveButton");
        sizePolicy.setHeightForWidth(SaveButton->sizePolicy().hasHeightForWidth());
        SaveButton->setSizePolicy(sizePolicy);
        SaveButton->setMinimumSize(QSize(32, 32));
        SaveButton->setMaximumSize(QSize(32, 32));
        SaveButton->setIconSize(QSize(28, 28));

        hboxLayout->addWidget(SaveButton);

        SaveAsButton = new QPushButton(ScriptBuilder);
        SaveAsButton->setObjectName("SaveAsButton");
        sizePolicy.setHeightForWidth(SaveAsButton->sizePolicy().hasHeightForWidth());
        SaveAsButton->setSizePolicy(sizePolicy);
        SaveAsButton->setMinimumSize(QSize(32, 32));
        SaveAsButton->setMaximumSize(QSize(32, 32));
        SaveAsButton->setIconSize(QSize(28, 28));

        hboxLayout->addWidget(SaveAsButton);

        RunButton = new QPushButton(ScriptBuilder);
        RunButton->setObjectName("RunButton");
        RunButton->setMinimumSize(QSize(32, 32));
        RunButton->setMaximumSize(QSize(32, 32));
        RunButton->setIconSize(QSize(28, 28));

        hboxLayout->addWidget(RunButton);

        spacerItem = new QSpacerItem(490, 20, QSizePolicy::Policy::Expanding, QSizePolicy::Policy::Minimum);

        hboxLayout->addItem(spacerItem);


        vboxLayout->addLayout(hboxLayout);

        splitter = new QSplitter(ScriptBuilder);
        splitter->setObjectName("splitter");
        splitter->setOrientation(Qt::Horizontal);
        groupBox = new QGroupBox(splitter);
        groupBox->setObjectName("groupBox");
        vboxLayout1 = new QVBoxLayout(groupBox);
        vboxLayout1->setSpacing(6);
        vboxLayout1->setObjectName("vboxLayout1");
        vboxLayout1->setContentsMargins(9, 9, 9, 9);
        hboxLayout1 = new QHBoxLayout();
        hboxLayout1->setSpacing(6);
        hboxLayout1->setObjectName("hboxLayout1");
        hboxLayout1->setContentsMargins(0, 0, 0, 0);
        ScriptListBox = new QListWidget(groupBox);
        ScriptListBox->setObjectName("ScriptListBox");
        QSizePolicy sizePolicy1(QSizePolicy::Policy::Expanding, QSizePolicy::Policy::Expanding);
        sizePolicy1.setHorizontalStretch(0);
        sizePolicy1.setVerticalStretch(1);
        sizePolicy1.setHeightForWidth(ScriptListBox->sizePolicy().hasHeightForWidth());
        ScriptListBox->setSizePolicy(sizePolicy1);

        hboxLayout1->addWidget(ScriptListBox);

        vboxLayout2 = new QVBoxLayout();
        vboxLayout2->setSpacing(6);
        vboxLayout2->setObjectName("vboxLayout2");
        vboxLayout2->setContentsMargins(0, 0, 0, 0);
        AddButton = new QPushButton(groupBox);
        AddButton->setObjectName("AddButton");
        AddButton->setMinimumSize(QSize(32, 32));
        AddButton->setMaximumSize(QSize(32, 32));

        vboxLayout2->addWidget(AddButton);

        RemoveButton = new QPushButton(groupBox);
        RemoveButton->setObjectName("RemoveButton");
        RemoveButton->setMinimumSize(QSize(32, 32));
        RemoveButton->setMaximumSize(QSize(32, 32));

        vboxLayout2->addWidget(RemoveButton);

        CopyButton = new QPushButton(groupBox);
        CopyButton->setObjectName("CopyButton");
        CopyButton->setMinimumSize(QSize(32, 32));
        CopyButton->setMaximumSize(QSize(32, 32));

        vboxLayout2->addWidget(CopyButton);

        UpButton = new QPushButton(groupBox);
        UpButton->setObjectName("UpButton");
        UpButton->setMinimumSize(QSize(32, 32));
        UpButton->setMaximumSize(QSize(32, 32));

        vboxLayout2->addWidget(UpButton);

        DownButton = new QPushButton(groupBox);
        DownButton->setObjectName("DownButton");
        DownButton->setMinimumSize(QSize(32, 32));
        DownButton->setMaximumSize(QSize(32, 32));

        vboxLayout2->addWidget(DownButton);

        spacerItem1 = new QSpacerItem(20, 118, QSizePolicy::Policy::Minimum, QSizePolicy::Policy::Expanding);

        vboxLayout2->addItem(spacerItem1);


        hboxLayout1->addLayout(vboxLayout2);


        vboxLayout1->addLayout(hboxLayout1);

        groupBox_2 = new QGroupBox(groupBox);
        groupBox_2->setObjectName("groupBox_2");
        vboxLayout3 = new QVBoxLayout(groupBox_2);
        vboxLayout3->setSpacing(6);
        vboxLayout3->setObjectName("vboxLayout3");
        vboxLayout3->setContentsMargins(9, 9, 9, 9);
        ArgStack = new QStackedWidget(groupBox_2);
        ArgStack->setObjectName("ArgStack");
        page = new QWidget();
        page->setObjectName("page");
        ArgStack->addWidget(page);
        page_2 = new QWidget();
        page_2->setObjectName("page_2");
        ArgStack->addWidget(page_2);

        vboxLayout3->addWidget(ArgStack);


        vboxLayout1->addWidget(groupBox_2);

        splitter->addWidget(groupBox);
        groupBox_3 = new QGroupBox(splitter);
        groupBox_3->setObjectName("groupBox_3");
        vboxLayout4 = new QVBoxLayout(groupBox_3);
        vboxLayout4->setSpacing(6);
        vboxLayout4->setObjectName("vboxLayout4");
        vboxLayout4->setContentsMargins(9, 9, 9, 9);
        splitter7 = new QSplitter(groupBox_3);
        splitter7->setObjectName("splitter7");
        splitter7->setOrientation(Qt::Vertical);
        FunctionTree = new QTreeWidget(splitter7);
        FunctionTree->setObjectName("FunctionTree");
        QSizePolicy sizePolicy2(QSizePolicy::Policy::Expanding, QSizePolicy::Policy::Expanding);
        sizePolicy2.setHorizontalStretch(0);
        sizePolicy2.setVerticalStretch(5);
        sizePolicy2.setHeightForWidth(FunctionTree->sizePolicy().hasHeightForWidth());
        FunctionTree->setSizePolicy(sizePolicy2);
        FunctionTree->setRootIsDecorated(true);
        splitter7->addWidget(FunctionTree);
        FuncDoc = new QTextEdit(splitter7);
        FuncDoc->setObjectName("FuncDoc");
        QSizePolicy sizePolicy3(QSizePolicy::Policy::Expanding, QSizePolicy::Policy::Expanding);
        sizePolicy3.setHorizontalStretch(0);
        sizePolicy3.setVerticalStretch(0);
        sizePolicy3.setHeightForWidth(FuncDoc->sizePolicy().hasHeightForWidth());
        FuncDoc->setSizePolicy(sizePolicy3);
        splitter7->addWidget(FuncDoc);

        vboxLayout4->addWidget(splitter7);

        splitter->addWidget(groupBox_3);

        vboxLayout->addWidget(splitter);


        retranslateUi(ScriptBuilder);

        QMetaObject::connectSlotsByName(ScriptBuilder);
    } // setupUi

    void retranslateUi(QWidget *ScriptBuilder)
    {
#if QT_CONFIG(tooltip)
        NewButton->setToolTip(tr2i18n("New Script", nullptr));
#endif // QT_CONFIG(tooltip)
#if QT_CONFIG(whatsthis)
        NewButton->setWhatsThis(tr2i18n("Discards current script and starts a new one.  Will prompt to save any unsaved changes in the current script.", nullptr));
#endif // QT_CONFIG(whatsthis)
#if QT_CONFIG(tooltip)
        OpenButton->setToolTip(tr2i18n("Open Script...", nullptr));
#endif // QT_CONFIG(tooltip)
#if QT_CONFIG(whatsthis)
        OpenButton->setWhatsThis(tr2i18n("Opens an existing script.  Will prompt to save any unsaved changes in the current script.", nullptr));
#endif // QT_CONFIG(whatsthis)
#if QT_CONFIG(tooltip)
        SaveButton->setToolTip(tr2i18n("Save Script", nullptr));
#endif // QT_CONFIG(tooltip)
#if QT_CONFIG(whatsthis)
        SaveButton->setWhatsThis(tr2i18n("Save the current script.  If the script has not been saved before, this is equivalent to \"Save As...\"", nullptr));
#endif // QT_CONFIG(whatsthis)
#if QT_CONFIG(tooltip)
        SaveAsButton->setToolTip(tr2i18n("Save Script As...", nullptr));
#endif // QT_CONFIG(tooltip)
#if QT_CONFIG(whatsthis)
        SaveAsButton->setWhatsThis(tr2i18n("Saves the script to a file, allowing you to first specify the filename and a name for the script.", nullptr));
#endif // QT_CONFIG(whatsthis)
#if QT_CONFIG(tooltip)
        RunButton->setToolTip(tr2i18n("Test Script", nullptr));
#endif // QT_CONFIG(tooltip)
#if QT_CONFIG(whatsthis)
        RunButton->setWhatsThis(tr2i18n("Executes the script in the KStars main window. You may want to reposition the Script Builder tool so that the Sky map is visible.", nullptr));
#endif // QT_CONFIG(whatsthis)
        groupBox->setTitle(tr2i18n("Current Script", nullptr));
#if QT_CONFIG(whatsthis)
        ScriptListBox->setWhatsThis(tr2i18n("This shows the list of commands present in the current working script. Highlighting any command will present a widget where you can specify its arguments below. Use the action buttons at right to copy, remove, or change the position of the selected command.", nullptr));
#endif // QT_CONFIG(whatsthis)
#if QT_CONFIG(tooltip)
        AddButton->setToolTip(tr2i18n("Add Function", nullptr));
#endif // QT_CONFIG(tooltip)
#if QT_CONFIG(whatsthis)
        AddButton->setWhatsThis(tr2i18n("If a function is highlighted in the \"Function Browser\" box, this button will add it to the current working script.  The new function is inserted directly after the highlighted function in the \"Current Script\" box.\n"
"", nullptr));
#endif // QT_CONFIG(whatsthis)
#if QT_CONFIG(tooltip)
        RemoveButton->setToolTip(tr2i18n("Remove Function", nullptr));
#endif // QT_CONFIG(tooltip)
#if QT_CONFIG(whatsthis)
        RemoveButton->setWhatsThis(tr2i18n("If a function is highlighted in the \"Current Script\" box, this button will remove it from the script.", nullptr));
#endif // QT_CONFIG(whatsthis)
#if QT_CONFIG(tooltip)
        CopyButton->setToolTip(tr2i18n("Copy Function", nullptr));
#endif // QT_CONFIG(tooltip)
#if QT_CONFIG(whatsthis)
        CopyButton->setWhatsThis(tr2i18n("If a function is highlighted in the \"Current Script\" box, this button will add a duplicate of the function.", nullptr));
#endif // QT_CONFIG(whatsthis)
#if QT_CONFIG(tooltip)
        UpButton->setToolTip(tr2i18n("Move Up", nullptr));
#endif // QT_CONFIG(tooltip)
#if QT_CONFIG(whatsthis)
        UpButton->setWhatsThis(tr2i18n("If a function is highlighted in the \"Current Script\" box, this button will move it up one position in the script.", nullptr));
#endif // QT_CONFIG(whatsthis)
#if QT_CONFIG(tooltip)
        DownButton->setToolTip(tr2i18n("Move Down", nullptr));
#endif // QT_CONFIG(tooltip)
#if QT_CONFIG(whatsthis)
        DownButton->setWhatsThis(tr2i18n("If a function is highlighted in the \"Current Script\" box, this button will move it down one position in the script.", nullptr));
#endif // QT_CONFIG(whatsthis)
        groupBox_2->setTitle(tr2i18n("Function Arguments", nullptr));
        groupBox_3->setTitle(tr2i18n("Function Browser", nullptr));
        QTreeWidgetItem *___qtreewidgetitem = FunctionTree->headerItem();
        ___qtreewidgetitem->setText(0, tr2i18n("1", nullptr));
#if QT_CONFIG(tooltip)
        FuncDoc->setToolTip(tr2i18n("Function Help", nullptr));
#endif // QT_CONFIG(tooltip)
#if QT_CONFIG(whatsthis)
        FuncDoc->setWhatsThis(tr2i18n("If a function is highlighted in the Function Browser, this area will show some brief documentation about the function.", nullptr));
#endif // QT_CONFIG(whatsthis)
        (void)ScriptBuilder;
    } // retranslateUi

};

namespace Ui {
    class ScriptBuilder: public Ui_ScriptBuilder {};
} // namespace Ui

QT_END_NAMESPACE

#endif // SCRIPTBUILDER_H

