/********************************************************************************
** Form generated from reading UI file 'modcalcsidtime.ui'
**
** Created by: Qt User Interface Compiler version 6.11.1
**
** WARNING! All changes made in this file will be lost when recompiling UI file!
********************************************************************************/

#ifndef UI_MODCALCSIDTIME_H
#define UI_MODCALCSIDTIME_H

#include <QtCore/QVariant>
#include <QtWidgets/QApplication>
#include <QtWidgets/QCheckBox>
#include <QtWidgets/QComboBox>
#include <QtWidgets/QDateEdit>
#include <QtWidgets/QGridLayout>
#include <QtWidgets/QGroupBox>
#include <QtWidgets/QHBoxLayout>
#include <QtWidgets/QLabel>
#include <QtWidgets/QPushButton>
#include <QtWidgets/QSpacerItem>
#include <QtWidgets/QTabWidget>
#include <QtWidgets/QTimeEdit>
#include <QtWidgets/QVBoxLayout>
#include <QtWidgets/QWidget>
#include <klocalizedstring.h>
#include "kurlrequester.h"

QT_BEGIN_NAMESPACE

class Ui_modCalcSidTimeDlg
{
public:
    QVBoxLayout *vboxLayout;
    QTabWidget *tabWidget;
    QWidget *interact;
    QVBoxLayout *vboxLayout1;
    QGridLayout *gridLayout;
    QSpacerItem *spacerItem;
    QSpacerItem *spacerItem1;
    QPushButton *LocationButton;
    QLabel *DateLabel;
    QTimeEdit *ST;
    QTimeEdit *LT;
    QLabel *SiderealTimeLabel;
    QLabel *LocalTimeLabel;
    QHBoxLayout *hboxLayout;
    QDateEdit *Date;
    QSpacerItem *spacerItem2;
    QLabel *LocationLabel;
    QSpacerItem *spacerItem3;
    QWidget *batch;
    QVBoxLayout *vboxLayout2;
    QHBoxLayout *hboxLayout1;
    QComboBox *ComputeComboBatch;
    QSpacerItem *spacerItem4;
    QGroupBox *groupBox;
    QGridLayout *gridLayout1;
    QLabel *DateLabelBatch;
    QCheckBox *DateCheckBatch;
    QLabel *LocationLabelBatch;
    QPushButton *LocationButtonBatch;
    QCheckBox *LocationCheckBatch;
    QDateEdit *DateBatch;
    QSpacerItem *spacerItem5;
    QLabel *HelpLabel;
    QGridLayout *gridLayout2;
    QLabel *label_3;
    KUrlRequester *InputFileBatch;
    QLabel *label_4;
    KUrlRequester *OutputFileBatch;
    QHBoxLayout *hboxLayout2;
    QSpacerItem *spacerItem6;
    QVBoxLayout *vboxLayout3;
    QPushButton *RunButtonBatch;
    QPushButton *ViewButtonBatch;
    QSpacerItem *spacerItem7;
    QSpacerItem *spacerItem8;

    void setupUi(QWidget *modCalcSidTimeDlg)
    {
        if (modCalcSidTimeDlg->objectName().isEmpty())
            modCalcSidTimeDlg->setObjectName("modCalcSidTimeDlg");
        modCalcSidTimeDlg->resize(517, 463);
        vboxLayout = new QVBoxLayout(modCalcSidTimeDlg);
        vboxLayout->setObjectName("vboxLayout");
        tabWidget = new QTabWidget(modCalcSidTimeDlg);
        tabWidget->setObjectName("tabWidget");
        interact = new QWidget();
        interact->setObjectName("interact");
        vboxLayout1 = new QVBoxLayout(interact);
#ifndef UI_Q_OS_MAC
        vboxLayout1->setSpacing(6);
#endif
#ifndef UI_Q_OS_MAC
        vboxLayout1->setContentsMargins(9, 9, 9, 9);
#endif
        vboxLayout1->setObjectName("vboxLayout1");
        gridLayout = new QGridLayout();
#ifndef UI_Q_OS_MAC
        gridLayout->setSpacing(6);
#endif
#ifndef UI_Q_OS_MAC
        gridLayout->setContentsMargins(0, 0, 0, 0);
#endif
        gridLayout->setObjectName("gridLayout");
        spacerItem = new QSpacerItem(391, 20, QSizePolicy::Policy::Expanding, QSizePolicy::Policy::Minimum);

        gridLayout->addItem(spacerItem, 2, 0, 1, 3);

        spacerItem1 = new QSpacerItem(40, 20, QSizePolicy::Policy::Expanding, QSizePolicy::Policy::Minimum);

        gridLayout->addItem(spacerItem1, 3, 2, 2, 1);

        LocationButton = new QPushButton(interact);
        LocationButton->setObjectName("LocationButton");

        gridLayout->addWidget(LocationButton, 1, 1, 1, 2);

        DateLabel = new QLabel(interact);
        DateLabel->setObjectName("DateLabel");

        gridLayout->addWidget(DateLabel, 0, 0, 1, 1);

        ST = new QTimeEdit(interact);
        ST->setObjectName("ST");

        gridLayout->addWidget(ST, 4, 1, 1, 1);

        LT = new QTimeEdit(interact);
        LT->setObjectName("LT");

        gridLayout->addWidget(LT, 3, 1, 1, 1);

        SiderealTimeLabel = new QLabel(interact);
        SiderealTimeLabel->setObjectName("SiderealTimeLabel");

        gridLayout->addWidget(SiderealTimeLabel, 4, 0, 1, 1);

        LocalTimeLabel = new QLabel(interact);
        LocalTimeLabel->setObjectName("LocalTimeLabel");

        gridLayout->addWidget(LocalTimeLabel, 3, 0, 1, 1);

        hboxLayout = new QHBoxLayout();
#ifndef UI_Q_OS_MAC
        hboxLayout->setSpacing(6);
#endif
        hboxLayout->setContentsMargins(0, 0, 0, 0);
        hboxLayout->setObjectName("hboxLayout");
        Date = new QDateEdit(interact);
        Date->setObjectName("Date");

        hboxLayout->addWidget(Date);

        spacerItem2 = new QSpacerItem(40, 20, QSizePolicy::Policy::Expanding, QSizePolicy::Policy::Minimum);

        hboxLayout->addItem(spacerItem2);


        gridLayout->addLayout(hboxLayout, 0, 1, 1, 2);

        LocationLabel = new QLabel(interact);
        LocationLabel->setObjectName("LocationLabel");

        gridLayout->addWidget(LocationLabel, 1, 0, 1, 1);


        vboxLayout1->addLayout(gridLayout);

        spacerItem3 = new QSpacerItem(20, 40, QSizePolicy::Policy::Minimum, QSizePolicy::Policy::Expanding);

        vboxLayout1->addItem(spacerItem3);

        tabWidget->addTab(interact, QString());
        batch = new QWidget();
        batch->setObjectName("batch");
        vboxLayout2 = new QVBoxLayout(batch);
        vboxLayout2->setObjectName("vboxLayout2");
        hboxLayout1 = new QHBoxLayout();
        hboxLayout1->setObjectName("hboxLayout1");
        ComputeComboBatch = new QComboBox(batch);
        ComputeComboBatch->addItem(QString());
        ComputeComboBatch->addItem(QString());
        ComputeComboBatch->setObjectName("ComputeComboBatch");

        hboxLayout1->addWidget(ComputeComboBatch);

        spacerItem4 = new QSpacerItem(40, 20, QSizePolicy::Policy::Expanding, QSizePolicy::Policy::Minimum);

        hboxLayout1->addItem(spacerItem4);


        vboxLayout2->addLayout(hboxLayout1);

        groupBox = new QGroupBox(batch);
        groupBox->setObjectName("groupBox");
        gridLayout1 = new QGridLayout(groupBox);
        gridLayout1->setObjectName("gridLayout1");
        DateLabelBatch = new QLabel(groupBox);
        DateLabelBatch->setObjectName("DateLabelBatch");
        QSizePolicy sizePolicy(QSizePolicy::Policy::Minimum, QSizePolicy::Policy::Preferred);
        sizePolicy.setHorizontalStretch(0);
        sizePolicy.setVerticalStretch(0);
        sizePolicy.setHeightForWidth(DateLabelBatch->sizePolicy().hasHeightForWidth());
        DateLabelBatch->setSizePolicy(sizePolicy);

        gridLayout1->addWidget(DateLabelBatch, 0, 0, 1, 1);

        DateCheckBatch = new QCheckBox(groupBox);
        DateCheckBatch->setObjectName("DateCheckBatch");

        gridLayout1->addWidget(DateCheckBatch, 0, 2, 1, 1);

        LocationLabelBatch = new QLabel(groupBox);
        LocationLabelBatch->setObjectName("LocationLabelBatch");
        sizePolicy.setHeightForWidth(LocationLabelBatch->sizePolicy().hasHeightForWidth());
        LocationLabelBatch->setSizePolicy(sizePolicy);

        gridLayout1->addWidget(LocationLabelBatch, 1, 0, 1, 1);

        LocationButtonBatch = new QPushButton(groupBox);
        LocationButtonBatch->setObjectName("LocationButtonBatch");
        QSizePolicy sizePolicy1(QSizePolicy::Policy::Preferred, QSizePolicy::Policy::Minimum);
        sizePolicy1.setHorizontalStretch(0);
        sizePolicy1.setVerticalStretch(0);
        sizePolicy1.setHeightForWidth(LocationButtonBatch->sizePolicy().hasHeightForWidth());
        LocationButtonBatch->setSizePolicy(sizePolicy1);

        gridLayout1->addWidget(LocationButtonBatch, 1, 1, 1, 1);

        LocationCheckBatch = new QCheckBox(groupBox);
        LocationCheckBatch->setObjectName("LocationCheckBatch");

        gridLayout1->addWidget(LocationCheckBatch, 1, 2, 1, 1);

        DateBatch = new QDateEdit(groupBox);
        DateBatch->setObjectName("DateBatch");

        gridLayout1->addWidget(DateBatch, 0, 1, 1, 1);


        vboxLayout2->addWidget(groupBox);

        spacerItem5 = new QSpacerItem(20, 16, QSizePolicy::Policy::Minimum, QSizePolicy::Policy::Minimum);

        vboxLayout2->addItem(spacerItem5);

        HelpLabel = new QLabel(batch);
        HelpLabel->setObjectName("HelpLabel");

        vboxLayout2->addWidget(HelpLabel);

        gridLayout2 = new QGridLayout();
        gridLayout2->setObjectName("gridLayout2");
        label_3 = new QLabel(batch);
        label_3->setObjectName("label_3");

        gridLayout2->addWidget(label_3, 0, 0, 1, 1);

        InputFileBatch = new KUrlRequester(batch);
        InputFileBatch->setObjectName("InputFileBatch");

        gridLayout2->addWidget(InputFileBatch, 0, 1, 1, 1);

        label_4 = new QLabel(batch);
        label_4->setObjectName("label_4");

        gridLayout2->addWidget(label_4, 1, 0, 1, 1);

        OutputFileBatch = new KUrlRequester(batch);
        OutputFileBatch->setObjectName("OutputFileBatch");

        gridLayout2->addWidget(OutputFileBatch, 1, 1, 1, 1);


        vboxLayout2->addLayout(gridLayout2);

        hboxLayout2 = new QHBoxLayout();
        hboxLayout2->setObjectName("hboxLayout2");
        spacerItem6 = new QSpacerItem(40, 20, QSizePolicy::Policy::Expanding, QSizePolicy::Policy::Minimum);

        hboxLayout2->addItem(spacerItem6);

        vboxLayout3 = new QVBoxLayout();
        vboxLayout3->setObjectName("vboxLayout3");
        RunButtonBatch = new QPushButton(batch);
        RunButtonBatch->setObjectName("RunButtonBatch");

        vboxLayout3->addWidget(RunButtonBatch);

        ViewButtonBatch = new QPushButton(batch);
        ViewButtonBatch->setObjectName("ViewButtonBatch");

        vboxLayout3->addWidget(ViewButtonBatch);


        hboxLayout2->addLayout(vboxLayout3);

        spacerItem7 = new QSpacerItem(40, 20, QSizePolicy::Policy::Expanding, QSizePolicy::Policy::Minimum);

        hboxLayout2->addItem(spacerItem7);


        vboxLayout2->addLayout(hboxLayout2);

        spacerItem8 = new QSpacerItem(465, 16, QSizePolicy::Policy::Minimum, QSizePolicy::Policy::Expanding);

        vboxLayout2->addItem(spacerItem8);

        tabWidget->addTab(batch, QString());

        vboxLayout->addWidget(tabWidget);

        QWidget::setTabOrder(tabWidget, Date);
        QWidget::setTabOrder(Date, LocationButton);
        QWidget::setTabOrder(LocationButton, LT);
        QWidget::setTabOrder(LT, ST);
        QWidget::setTabOrder(ST, ComputeComboBatch);
        QWidget::setTabOrder(ComputeComboBatch, DateBatch);
        QWidget::setTabOrder(DateBatch, DateCheckBatch);
        QWidget::setTabOrder(DateCheckBatch, LocationButtonBatch);
        QWidget::setTabOrder(LocationButtonBatch, LocationCheckBatch);
        QWidget::setTabOrder(LocationCheckBatch, InputFileBatch);
        QWidget::setTabOrder(InputFileBatch, OutputFileBatch);
        QWidget::setTabOrder(OutputFileBatch, RunButtonBatch);
        QWidget::setTabOrder(RunButtonBatch, ViewButtonBatch);

        retranslateUi(modCalcSidTimeDlg);

        tabWidget->setCurrentIndex(0);


        QMetaObject::connectSlotsByName(modCalcSidTimeDlg);
    } // setupUi

    void retranslateUi(QWidget *modCalcSidTimeDlg)
    {
        modCalcSidTimeDlg->setWindowTitle(tr2i18n("Sidereal Time", nullptr));
        LocationButton->setText(tr2i18n("Greenwich, United Kingdom", nullptr));
        DateLabel->setText(tr2i18n("Date:", nullptr));
        SiderealTimeLabel->setText(tr2i18n("Sidereal time:", nullptr));
        LocalTimeLabel->setText(tr2i18n("Local time:", nullptr));
        LocationLabel->setText(tr2i18n("Location:", nullptr));
        tabWidget->setTabText(tabWidget->indexOf(interact), tr2i18n("Interactive Mode", nullptr));
        ComputeComboBatch->setItemText(0, tr2i18n("Compute sidereal time", nullptr));
        ComputeComboBatch->setItemText(1, tr2i18n("Compute standard time", nullptr));

        groupBox->setTitle(tr2i18n("Input Parameters", nullptr));
        DateLabelBatch->setText(tr2i18n("Date:", nullptr));
        DateCheckBatch->setText(tr2i18n("Read from input file", nullptr));
        LocationLabelBatch->setText(tr2i18n("Location:", nullptr));
        LocationButtonBatch->setText(tr2i18n("Greenwich, United Kingdom", nullptr));
        LocationCheckBatch->setText(tr2i18n("Read from input file", nullptr));
        HelpLabel->setText(tr2i18n("Specify Local Time in the Input File", nullptr));
        label_3->setText(tr2i18n("Input file:", nullptr));
        label_4->setText(tr2i18n("Output file:", nullptr));
        RunButtonBatch->setText(tr2i18n("Compute", nullptr));
        ViewButtonBatch->setText(tr2i18n("View Output...", nullptr));
        tabWidget->setTabText(tabWidget->indexOf(batch), tr2i18n("Batch Mode", nullptr));
    } // retranslateUi

};

namespace Ui {
    class modCalcSidTimeDlg: public Ui_modCalcSidTimeDlg {};
} // namespace Ui

QT_END_NAMESPACE

#endif // MODCALCSIDTIME_H

