/********************************************************************************
** Form generated from reading UI file 'dslrinfo.ui'
**
** Created by: Qt User Interface Compiler version 6.11.1
**
** WARNING! All changes made in this file will be lost when recompiling UI file!
********************************************************************************/

#ifndef UI_DSLRINFO_H
#define UI_DSLRINFO_H

#include <QtCore/QVariant>
#include <QtWidgets/QAbstractButton>
#include <QtWidgets/QApplication>
#include <QtWidgets/QDialog>
#include <QtWidgets/QDialogButtonBox>
#include <QtWidgets/QDoubleSpinBox>
#include <QtWidgets/QFormLayout>
#include <QtWidgets/QHBoxLayout>
#include <QtWidgets/QLabel>
#include <QtWidgets/QSpacerItem>
#include <QtWidgets/QSpinBox>
#include <QtWidgets/QVBoxLayout>
#include <klocalizedstring.h>

QT_BEGIN_NAMESPACE

class Ui_DSLRInfo
{
public:
    QVBoxLayout *verticalLayout;
    QHBoxLayout *horizontalLayout;
    QLabel *DSLRIcon;
    QLabel *label;
    QFormLayout *formLayout;
    QLabel *label_3;
    QHBoxLayout *horizontalLayout_2;
    QSpinBox *maxWidth;
    QLabel *label_4;
    QSpinBox *maxHeight;
    QSpacerItem *horizontalSpacer;
    QLabel *label_5;
    QHBoxLayout *horizontalLayout_3;
    QDoubleSpinBox *pixelX;
    QLabel *label_7;
    QDoubleSpinBox *pixelY;
    QSpacerItem *horizontalSpacer_2;
    QDialogButtonBox *buttonBox;

    void setupUi(QDialog *DSLRInfo)
    {
        if (DSLRInfo->objectName().isEmpty())
            DSLRInfo->setObjectName("DSLRInfo");
        DSLRInfo->resize(391, 162);
        verticalLayout = new QVBoxLayout(DSLRInfo);
        verticalLayout->setObjectName("verticalLayout");
        horizontalLayout = new QHBoxLayout();
        horizontalLayout->setObjectName("horizontalLayout");
        DSLRIcon = new QLabel(DSLRInfo);
        DSLRIcon->setObjectName("DSLRIcon");
        QSizePolicy sizePolicy(QSizePolicy::Policy::Fixed, QSizePolicy::Policy::Fixed);
        sizePolicy.setHorizontalStretch(0);
        sizePolicy.setVerticalStretch(0);
        sizePolicy.setHeightForWidth(DSLRIcon->sizePolicy().hasHeightForWidth());
        DSLRIcon->setSizePolicy(sizePolicy);
        DSLRIcon->setMinimumSize(QSize(48, 48));
        DSLRIcon->setAlignment(Qt::AlignCenter);

        horizontalLayout->addWidget(DSLRIcon);

        label = new QLabel(DSLRInfo);
        label->setObjectName("label");
        label->setWordWrap(true);

        horizontalLayout->addWidget(label);


        verticalLayout->addLayout(horizontalLayout);

        formLayout = new QFormLayout();
        formLayout->setObjectName("formLayout");
        label_3 = new QLabel(DSLRInfo);
        label_3->setObjectName("label_3");

        formLayout->setWidget(0, QFormLayout::ItemRole::LabelRole, label_3);

        horizontalLayout_2 = new QHBoxLayout();
        horizontalLayout_2->setObjectName("horizontalLayout_2");
        maxWidth = new QSpinBox(DSLRInfo);
        maxWidth->setObjectName("maxWidth");
        maxWidth->setMaximum(12000);
        maxWidth->setSingleStep(100);

        horizontalLayout_2->addWidget(maxWidth);

        label_4 = new QLabel(DSLRInfo);
        label_4->setObjectName("label_4");
        label_4->setAlignment(Qt::AlignCenter);

        horizontalLayout_2->addWidget(label_4);

        maxHeight = new QSpinBox(DSLRInfo);
        maxHeight->setObjectName("maxHeight");
        maxHeight->setMaximum(12000);
        maxHeight->setSingleStep(100);

        horizontalLayout_2->addWidget(maxHeight);

        horizontalSpacer = new QSpacerItem(40, 20, QSizePolicy::Policy::Expanding, QSizePolicy::Policy::Minimum);

        horizontalLayout_2->addItem(horizontalSpacer);


        formLayout->setLayout(0, QFormLayout::ItemRole::FieldRole, horizontalLayout_2);

        label_5 = new QLabel(DSLRInfo);
        label_5->setObjectName("label_5");
        label_5->setWordWrap(true);

        formLayout->setWidget(1, QFormLayout::ItemRole::LabelRole, label_5);

        horizontalLayout_3 = new QHBoxLayout();
        horizontalLayout_3->setObjectName("horizontalLayout_3");
        pixelX = new QDoubleSpinBox(DSLRInfo);
        pixelX->setObjectName("pixelX");
        pixelX->setMaximum(60.000000000000000);

        horizontalLayout_3->addWidget(pixelX);

        label_7 = new QLabel(DSLRInfo);
        label_7->setObjectName("label_7");
        label_7->setAlignment(Qt::AlignCenter);

        horizontalLayout_3->addWidget(label_7);

        pixelY = new QDoubleSpinBox(DSLRInfo);
        pixelY->setObjectName("pixelY");
        pixelY->setMaximum(60.000000000000000);

        horizontalLayout_3->addWidget(pixelY);

        horizontalSpacer_2 = new QSpacerItem(40, 20, QSizePolicy::Policy::Expanding, QSizePolicy::Policy::Minimum);

        horizontalLayout_3->addItem(horizontalSpacer_2);


        formLayout->setLayout(1, QFormLayout::ItemRole::FieldRole, horizontalLayout_3);


        verticalLayout->addLayout(formLayout);

        buttonBox = new QDialogButtonBox(DSLRInfo);
        buttonBox->setObjectName("buttonBox");
        buttonBox->setOrientation(Qt::Horizontal);
        buttonBox->setStandardButtons(QDialogButtonBox::Cancel|QDialogButtonBox::Save);

        verticalLayout->addWidget(buttonBox);


        retranslateUi(DSLRInfo);
        QObject::connect(buttonBox, &QDialogButtonBox::accepted, DSLRInfo, qOverload<>(&QDialog::accept));
        QObject::connect(buttonBox, &QDialogButtonBox::rejected, DSLRInfo, qOverload<>(&QDialog::reject));

        QMetaObject::connectSlotsByName(DSLRInfo);
    } // setupUi

    void retranslateUi(QDialog *DSLRInfo)
    {
        DSLRInfo->setWindowTitle(tr2i18n("DSLR Camera Settings", nullptr));
        DSLRIcon->setText(QString());
        label->setText(tr2i18n("<html><head/><body><p>Please fill the required information below. This is a one-time setup. You can obtain these values from your camera manual or from online sources such as <a href=\"https://www.digicamdb.com/\"><span style=\" text-decoration: underline; color:#007af4;\">Digital Camera Database</span></a>.</p></body></html>", nullptr));
#if QT_CONFIG(tooltip)
        label_3->setToolTip(tr2i18n("<html><head/><body><p>Sensor resolution in pixels (W x H)</p></body></html>", nullptr));
#endif // QT_CONFIG(tooltip)
        label_3->setText(tr2i18n("Sensor Resolution:", nullptr));
        label_4->setText(tr2i18n("x", nullptr));
#if QT_CONFIG(tooltip)
        label_5->setToolTip(tr2i18n("<html><head/><body><p>Pixel pitch in micrometers. For squared-pixel cameras, put the same value in the horizontal and vertical pixel pitches.</p></body></html>", nullptr));
#endif // QT_CONFIG(tooltip)
        label_5->setText(tr2i18n("Pixel Pitch:", nullptr));
        label_7->setText(tr2i18n("x", nullptr));
    } // retranslateUi

};

namespace Ui {
    class DSLRInfo: public Ui_DSLRInfo {};
} // namespace Ui

QT_END_NAMESPACE

#endif // DSLRINFO_H

