/********************************************************************************
** Form generated from reading UI file 'opssupernovae.ui'
**
** Created by: Qt User Interface Compiler version 6.11.1
**
** WARNING! All changes made in this file will be lost when recompiling UI file!
********************************************************************************/

#ifndef UI_OPSSUPERNOVAE_H
#define UI_OPSSUPERNOVAE_H

#include <QtCore/QVariant>
#include <QtWidgets/QApplication>
#include <QtWidgets/QCheckBox>
#include <QtWidgets/QDoubleSpinBox>
#include <QtWidgets/QGridLayout>
#include <QtWidgets/QGroupBox>
#include <QtWidgets/QLabel>
#include <QtWidgets/QLineEdit>
#include <QtWidgets/QSpacerItem>
#include <QtWidgets/QSpinBox>
#include <QtWidgets/QVBoxLayout>
#include <QtWidgets/QWidget>
#include <klocalizedstring.h>

QT_BEGIN_NAMESPACE

class Ui_OpsSupernovae
{
public:
    QGridLayout *gridLayout;
    QVBoxLayout *verticalLayout;
    QGroupBox *groupBox_2;
    QVBoxLayout *verticalLayout_3;
    QGridLayout *gridLayout_2;
    QLineEdit *kcfg_SupernovaDownloadUrl;
    QSpacerItem *verticalSpacer;
    QLabel *label;
    QCheckBox *kcfg_LimitSupernovaeByZoom;
    QDoubleSpinBox *kcfg_MagnitudeLimitAlertSupernovae;
    QCheckBox *kcfg_ShowSupernovae;
    QDoubleSpinBox *kcfg_MagnitudeLimitShowSupernovae;
    QLabel *label_2;
    QLabel *label_4;
    QLabel *label_3;
    QSpinBox *kcfg_SupernovaDetectionAge;
    QCheckBox *kcfg_SupernovaeHostOnly;
    QCheckBox *kcfg_SupernovaeClassifiedOnly;

    void setupUi(QWidget *OpsSupernovae)
    {
        if (OpsSupernovae->objectName().isEmpty())
            OpsSupernovae->setObjectName("OpsSupernovae");
        OpsSupernovae->resize(694, 270);
        gridLayout = new QGridLayout(OpsSupernovae);
        gridLayout->setObjectName("gridLayout");
        verticalLayout = new QVBoxLayout();
        verticalLayout->setObjectName("verticalLayout");
        groupBox_2 = new QGroupBox(OpsSupernovae);
        groupBox_2->setObjectName("groupBox_2");
        verticalLayout_3 = new QVBoxLayout(groupBox_2);
        verticalLayout_3->setObjectName("verticalLayout_3");
        gridLayout_2 = new QGridLayout();
        gridLayout_2->setObjectName("gridLayout_2");
        kcfg_SupernovaDownloadUrl = new QLineEdit(groupBox_2);
        kcfg_SupernovaDownloadUrl->setObjectName("kcfg_SupernovaDownloadUrl");

        gridLayout_2->addWidget(kcfg_SupernovaDownloadUrl, 7, 1, 1, 1);

        verticalSpacer = new QSpacerItem(20, 40, QSizePolicy::Policy::Minimum, QSizePolicy::Policy::Expanding);

        gridLayout_2->addItem(verticalSpacer, 9, 0, 1, 1);

        label = new QLabel(groupBox_2);
        label->setObjectName("label");

        gridLayout_2->addWidget(label, 1, 0, 1, 1);

        kcfg_LimitSupernovaeByZoom = new QCheckBox(groupBox_2);
        kcfg_LimitSupernovaeByZoom->setObjectName("kcfg_LimitSupernovaeByZoom");
        kcfg_LimitSupernovaeByZoom->setEnabled(true);
        kcfg_LimitSupernovaeByZoom->setTristate(false);

        gridLayout_2->addWidget(kcfg_LimitSupernovaeByZoom, 3, 0, 1, 1);

        kcfg_MagnitudeLimitAlertSupernovae = new QDoubleSpinBox(groupBox_2);
        kcfg_MagnitudeLimitAlertSupernovae->setObjectName("kcfg_MagnitudeLimitAlertSupernovae");
        kcfg_MagnitudeLimitAlertSupernovae->setDecimals(0);
        kcfg_MagnitudeLimitAlertSupernovae->setMaximum(30.000000000000000);
        kcfg_MagnitudeLimitAlertSupernovae->setValue(16.000000000000000);

        gridLayout_2->addWidget(kcfg_MagnitudeLimitAlertSupernovae, 2, 1, 1, 1);

        kcfg_ShowSupernovae = new QCheckBox(groupBox_2);
        kcfg_ShowSupernovae->setObjectName("kcfg_ShowSupernovae");
        kcfg_ShowSupernovae->setEnabled(true);
        kcfg_ShowSupernovae->setTristate(false);

        gridLayout_2->addWidget(kcfg_ShowSupernovae, 0, 0, 1, 1);

        kcfg_MagnitudeLimitShowSupernovae = new QDoubleSpinBox(groupBox_2);
        kcfg_MagnitudeLimitShowSupernovae->setObjectName("kcfg_MagnitudeLimitShowSupernovae");
        kcfg_MagnitudeLimitShowSupernovae->setDecimals(0);
        kcfg_MagnitudeLimitShowSupernovae->setMaximum(30.000000000000000);
        kcfg_MagnitudeLimitShowSupernovae->setValue(16.000000000000000);

        gridLayout_2->addWidget(kcfg_MagnitudeLimitShowSupernovae, 1, 1, 1, 1);

        label_2 = new QLabel(groupBox_2);
        label_2->setObjectName("label_2");

        gridLayout_2->addWidget(label_2, 2, 0, 1, 1);

        label_4 = new QLabel(groupBox_2);
        label_4->setObjectName("label_4");

        gridLayout_2->addWidget(label_4, 7, 0, 1, 1);

        label_3 = new QLabel(groupBox_2);
        label_3->setObjectName("label_3");

        gridLayout_2->addWidget(label_3, 6, 0, 1, 1);

        kcfg_SupernovaDetectionAge = new QSpinBox(groupBox_2);
        kcfg_SupernovaDetectionAge->setObjectName("kcfg_SupernovaDetectionAge");
        kcfg_SupernovaDetectionAge->setMaximum(30000);
        kcfg_SupernovaDetectionAge->setValue(60);

        gridLayout_2->addWidget(kcfg_SupernovaDetectionAge, 6, 1, 1, 1);

        kcfg_SupernovaeHostOnly = new QCheckBox(groupBox_2);
        kcfg_SupernovaeHostOnly->setObjectName("kcfg_SupernovaeHostOnly");

        gridLayout_2->addWidget(kcfg_SupernovaeHostOnly, 4, 0, 1, 1);

        kcfg_SupernovaeClassifiedOnly = new QCheckBox(groupBox_2);
        kcfg_SupernovaeClassifiedOnly->setObjectName("kcfg_SupernovaeClassifiedOnly");

        gridLayout_2->addWidget(kcfg_SupernovaeClassifiedOnly, 5, 0, 1, 1);


        verticalLayout_3->addLayout(gridLayout_2);


        verticalLayout->addWidget(groupBox_2);


        gridLayout->addLayout(verticalLayout, 1, 0, 1, 1);

        QWidget::setTabOrder(kcfg_ShowSupernovae, kcfg_MagnitudeLimitShowSupernovae);
        QWidget::setTabOrder(kcfg_MagnitudeLimitShowSupernovae, kcfg_MagnitudeLimitAlertSupernovae);

        retranslateUi(OpsSupernovae);

        QMetaObject::connectSlotsByName(OpsSupernovae);
    } // setupUi

    void retranslateUi(QWidget *OpsSupernovae)
    {
        groupBox_2->setTitle(tr2i18n("Supernovae Options", nullptr));
        kcfg_SupernovaDownloadUrl->setText(tr2i18n("https://indilib.org/jdownloads/kstars/tns-daily.csv", nullptr));
        label->setText(tr2i18n("Set the magnitude limit for supernova to show:", nullptr));
        kcfg_LimitSupernovaeByZoom->setText(tr2i18n("Limit supernovae by zoom limit", nullptr));
        kcfg_ShowSupernovae->setText(tr2i18n("Show supernovae", nullptr));
        label_2->setText(tr2i18n("Set the magnitude limit for supernova alerts:", nullptr));
        label_4->setText(tr2i18n("Download URL:", nullptr));
        label_3->setText(tr2i18n("Age (days):", nullptr));
        kcfg_SupernovaeHostOnly->setText(tr2i18n("Show only SN with host galaxy given", nullptr));
        kcfg_SupernovaeClassifiedOnly->setText(tr2i18n("Show only classified Supernovae", nullptr));
        (void)OpsSupernovae;
    } // retranslateUi

};

namespace Ui {
    class OpsSupernovae: public Ui_OpsSupernovae {};
} // namespace Ui

QT_END_NAMESPACE

#endif // OPSSUPERNOVAE_H

