/*
 * This file was generated by qdbusxml2cpp version 0.8
 * Source file was org.kde.kstars.xml
 *
 * qdbusxml2cpp is Copyright (C) The Qt Company Ltd. and other contributors.
 *
 * This is an auto-generated file.
 * Do not edit! All changes made to it will be lost.
 */

#include "kstarsadaptor.h"
#include <QtCore/QMetaObject>
#include <QtCore/QByteArray>
#include <QtCore/QList>
#include <QtCore/QMap>
#include <QtCore/QString>
#include <QtCore/QStringList>
#include <QtCore/QVariant>

/*
 * Implementation of adaptor class KstarsAdaptor
 */

KstarsAdaptor::KstarsAdaptor(KStars *parent)
    : QDBusAbstractAdaptor(parent)
{
    // constructor
    setAutoRelaySignals(true);
}

KstarsAdaptor::~KstarsAdaptor()
{
    // destructor
}

QString KstarsAdaptor::colorScheme() const
{
    // get the value of property colorScheme
    return qvariant_cast< QString >(parent()->property("colorScheme"));
}

void KstarsAdaptor::setColorScheme(const QString &value)
{
    // set the value of property colorScheme
    parent()->setProperty("colorScheme", QVariant::fromValue(value));
}

QString KstarsAdaptor::release() const
{
    // get the value of property release
    return qvariant_cast< QString >(parent()->property("release"));
}

QString KstarsAdaptor::version() const
{
    // get the value of property version
    return qvariant_cast< QString >(parent()->property("version"));
}

bool KstarsAdaptor::activateAction(const QString &actionName)
{
    // handle method call org.kde.kstars.activateAction
    return parent()->activateAction(actionName);
}

void KstarsAdaptor::addLabel(const QString &name)
{
    // handle method call org.kde.kstars.addLabel
    parent()->addLabel(name);
}

void KstarsAdaptor::addTrail(const QString &name)
{
    // handle method call org.kde.kstars.addTrail
    parent()->addTrail(name);
}

void KstarsAdaptor::changeViewOption(const QString &option, const QString &value)
{
    // handle method call org.kde.kstars.changeViewOption
    parent()->changeViewOption(option, value);
}

QString KstarsAdaptor::colorScheme()
{
    // handle method call org.kde.kstars.colorScheme
    return parent()->colorScheme();
}

void KstarsAdaptor::defaultZoom()
{
    // handle method call org.kde.kstars.defaultZoom
    parent()->defaultZoom();
}

void KstarsAdaptor::drawLine(int x1, int y1, int x2, int y2, int speed)
{
    // handle method call org.kde.kstars.drawLine
    parent()->drawLine(x1, y1, x2, y2, speed);
}

void KstarsAdaptor::exportImage(const QString &filename)
{
    // handle method call org.kde.kstars.exportImage
    parent()->exportImage(filename);
}

void KstarsAdaptor::exportImage(const QString &filename, int width)
{
    // handle method call org.kde.kstars.exportImage
    parent()->exportImage(filename, width);
}

void KstarsAdaptor::exportImage(const QString &filename, int width, int height)
{
    // handle method call org.kde.kstars.exportImage
    parent()->exportImage(filename, width, height);
}

void KstarsAdaptor::exportImage(const QString &filename, int width, int height, bool includeLegend)
{
    // handle method call org.kde.kstars.exportImage
    parent()->exportImage(filename, width, height, includeLegend);
}

QStringList KstarsAdaptor::getActions()
{
    // handle method call org.kde.kstars.getActions
    return parent()->getActions();
}

QString KstarsAdaptor::getDSSURL(double RA_J2000, double Dec_J2000)
{
    // handle method call org.kde.kstars.getDSSURL
    return parent()->getDSSURL(RA_J2000, Dec_J2000);
}

QString KstarsAdaptor::getDSSURL(double RA_J2000, double Dec_J2000, double width, double height)
{
    // handle method call org.kde.kstars.getDSSURL
    return parent()->getDSSURL(RA_J2000, Dec_J2000, width, height);
}

QString KstarsAdaptor::getDSSURL(const QString &objectName)
{
    // handle method call org.kde.kstars.getDSSURL
    return parent()->getDSSURL(objectName);
}

bool KstarsAdaptor::getFOVIndicatorVisibility(const QString &fovName)
{
    // handle method call org.kde.kstars.getFOVIndicatorVisibility
    return parent()->getFOVIndicatorVisibility(fovName);
}

QStringList KstarsAdaptor::getFOVIndicators()
{
    // handle method call org.kde.kstars.getFOVIndicators
    return parent()->getFOVIndicators();
}

QString KstarsAdaptor::getFocusInformationXML()
{
    // handle method call org.kde.kstars.getFocusInformationXML
    return parent()->getFocusInformationXML();
}

QString KstarsAdaptor::getObjectDataXML(const QString &objectName)
{
    // handle method call org.kde.kstars.getObjectDataXML
    return parent()->getObjectDataXML(objectName);
}

QString KstarsAdaptor::getObjectDataXML(const QString &objectName, bool fallbackToInternet)
{
    // handle method call org.kde.kstars.getObjectDataXML
    return parent()->getObjectDataXML(objectName, fallbackToInternet);
}

QString KstarsAdaptor::getObjectDataXML(const QString &objectName, bool fallbackToInternet, bool storeInternetResolved)
{
    // handle method call org.kde.kstars.getObjectDataXML
    return parent()->getObjectDataXML(objectName, fallbackToInternet, storeInternetResolved);
}

QString KstarsAdaptor::getObjectPositionInfo(const QString &objectName)
{
    // handle method call org.kde.kstars.getObjectPositionInfo
    return parent()->getObjectPositionInfo(objectName);
}

QString KstarsAdaptor::getObservingSessionPlanObjectNames()
{
    // handle method call org.kde.kstars.getObservingSessionPlanObjectNames
    return parent()->getObservingSessionPlanObjectNames();
}

QString KstarsAdaptor::getObservingWishListObjectNames()
{
    // handle method call org.kde.kstars.getObservingWishListObjectNames
    return parent()->getObservingWishListObjectNames();
}

QDBusVariant KstarsAdaptor::getOption(const QString &name)
{
    // handle method call org.kde.kstars.getOption
    return parent()->getOption(name);
}

QString KstarsAdaptor::getSkyMapDimensions()
{
    // handle method call org.kde.kstars.getSkyMapDimensions
    return parent()->getSkyMapDimensions();
}

double KstarsAdaptor::getSkyMapRotation()
{
    // handle method call org.kde.kstars.getSkyMapRotation
    return parent()->getSkyMapRotation();
}

QString KstarsAdaptor::getToggleableActionStates()
{
    // handle method call org.kde.kstars.getToggleableActionStates
    return parent()->getToggleableActionStates();
}

QStringList KstarsAdaptor::listSkyMapViews()
{
    // handle method call org.kde.kstars.listSkyMapViews
    return parent()->listSkyMapViews();
}

void KstarsAdaptor::loadColorScheme(const QString &name)
{
    // handle method call org.kde.kstars.loadColorScheme
    parent()->loadColorScheme(name);
}

QString KstarsAdaptor::location()
{
    // handle method call org.kde.kstars.location
    return parent()->location();
}

void KstarsAdaptor::lookTowards(const QString &direction)
{
    // handle method call org.kde.kstars.lookTowards
    parent()->lookTowards(direction);
}

void KstarsAdaptor::openFITS(const QUrl &imageURL)
{
    // handle method call org.kde.kstars.openFITS
    parent()->openFITS(imageURL);
}

void KstarsAdaptor::popupMessage(int x, int y, const QString &message)
{
    // handle method call org.kde.kstars.popupMessage
    parent()->popupMessage(x, y, message);
}

void KstarsAdaptor::printImage(bool usePrintDialog, bool useChartColors)
{
    // handle method call org.kde.kstars.printImage
    parent()->printImage(usePrintDialog, useChartColors);
}

void KstarsAdaptor::readConfig()
{
    // handle method call org.kde.kstars.readConfig
    parent()->readConfig();
}

void KstarsAdaptor::removeLabel(const QString &name)
{
    // handle method call org.kde.kstars.removeLabel
    parent()->removeLabel(name);
}

void KstarsAdaptor::removeTrail(const QString &name)
{
    // handle method call org.kde.kstars.removeTrail
    parent()->removeTrail(name);
}

void KstarsAdaptor::renderEyepieceView(const QString &objectName, const QString &destPathChart, double fovWidth, double fovHeight, double rotation, double scale, bool flip, bool invert, const QString &imagePath, const QString &destPathImage, bool overlay, bool invertColors)
{
    // handle method call org.kde.kstars.renderEyepieceView
    parent()->renderEyepieceView(objectName, destPathChart, fovWidth, fovHeight, rotation, scale, flip, invert, imagePath, destPathImage, overlay, invertColors);
}

void KstarsAdaptor::setAltAz(double alt, double az)
{
    // handle method call org.kde.kstars.setAltAz
    parent()->setAltAz(alt, az);
}

void KstarsAdaptor::setAltAz(double alt, double az, bool altIsRefracted)
{
    // handle method call org.kde.kstars.setAltAz
    parent()->setAltAz(alt, az, altIsRefracted);
}

void KstarsAdaptor::setApproxFOV(double FOV_Degrees)
{
    // handle method call org.kde.kstars.setApproxFOV
    parent()->setApproxFOV(FOV_Degrees);
}

void KstarsAdaptor::setColor(const QString &colorName, const QString &value)
{
    // handle method call org.kde.kstars.setColor
    parent()->setColor(colorName, value);
}

bool KstarsAdaptor::setFOVIndicatorVisibility(const QString &fovName, bool visibility)
{
    // handle method call org.kde.kstars.setFOVIndicatorVisibility
    return parent()->setFOVIndicatorVisibility(fovName, visibility);
}

bool KstarsAdaptor::setGPSLocation(double longitude, double latitude, double elevation, double tz0)
{
    // handle method call org.kde.kstars.setGPSLocation
    return parent()->setGPSLocation(longitude, latitude, elevation, tz0);
}

bool KstarsAdaptor::setGeoLocation(const QString &city, const QString &province, const QString &country)
{
    // handle method call org.kde.kstars.setGeoLocation
    return parent()->setGeoLocation(city, province, country);
}

void KstarsAdaptor::setLocalTime(int yr, int mth, int day, int hr, int min, int sec)
{
    // handle method call org.kde.kstars.setLocalTime
    parent()->setLocalTime(yr, mth, day, hr, min, sec);
}

void KstarsAdaptor::setOption(const QString &name, const QDBusVariant &value)
{
    // handle method call org.kde.kstars.setOption
    parent()->setOption(name, value);
}

void KstarsAdaptor::setRaDec(double ra, double dec)
{
    // handle method call org.kde.kstars.setRaDec
    parent()->setRaDec(ra, dec);
}

void KstarsAdaptor::setRaDecJ2000(double ra0, double dec0)
{
    // handle method call org.kde.kstars.setRaDecJ2000
    parent()->setRaDecJ2000(ra0, dec0);
}

void KstarsAdaptor::setSkyMapMirrored(bool mirrored)
{
    // handle method call org.kde.kstars.setSkyMapMirrored
    parent()->setSkyMapMirrored(mirrored);
}

void KstarsAdaptor::setSkyMapRotation(double viewAngle)
{
    // handle method call org.kde.kstars.setSkyMapRotation
    parent()->setSkyMapRotation(viewAngle);
}

bool KstarsAdaptor::setSkyMapView(const QString &viewName)
{
    // handle method call org.kde.kstars.setSkyMapView
    return parent()->setSkyMapView(viewName);
}

void KstarsAdaptor::setTimeToNow()
{
    // handle method call org.kde.kstars.setTimeToNow
    parent()->setTimeToNow();
}

bool KstarsAdaptor::setToggleableActionState(const QString &actionName, bool state)
{
    // handle method call org.kde.kstars.setToggleableActionState
    return parent()->setToggleableActionState(actionName, state);
}

void KstarsAdaptor::setTracking(bool track)
{
    // handle method call org.kde.kstars.setTracking
    parent()->setTracking(track);
}

bool KstarsAdaptor::skyMapIsMirrored()
{
    // handle method call org.kde.kstars.skyMapIsMirrored
    return parent()->skyMapIsMirrored();
}

void KstarsAdaptor::waitFor(double t)
{
    // handle method call org.kde.kstars.waitFor
    parent()->waitFor(t);
}

void KstarsAdaptor::waitForKey(const QString &k)
{
    // handle method call org.kde.kstars.waitForKey
    parent()->waitForKey(k);
}

void KstarsAdaptor::writeConfig()
{
    // handle method call org.kde.kstars.writeConfig
    parent()->writeConfig();
}

void KstarsAdaptor::zoom(double z)
{
    // handle method call org.kde.kstars.zoom
    parent()->zoom(z);
}

void KstarsAdaptor::zoomIn()
{
    // handle method call org.kde.kstars.zoomIn
    parent()->zoomIn();
}

void KstarsAdaptor::zoomOut()
{
    // handle method call org.kde.kstars.zoomOut
    parent()->zoomOut();
}


#include "moc_kstarsadaptor.cpp"
