/*
 * This file was generated by qdbusxml2cpp version 0.8
 * Source file was org.kde.kstars.INDI.DustCap.xml
 *
 * qdbusxml2cpp is Copyright (C) The Qt Company Ltd. and other contributors.
 *
 * This is an auto-generated file.
 * Do not edit! All changes made to it will be lost.
 */

#include "dustcapadaptor.h"
#include <QtCore/QMetaObject>
#include <QtCore/QByteArray>
#include <QtCore/QList>
#include <QtCore/QMap>
#include <QtCore/QString>
#include <QtCore/QStringList>
#include <QtCore/QVariant>

/*
 * Implementation of adaptor class DustCapAdaptor
 */

DustCapAdaptor::DustCapAdaptor(ISD::DustCap *parent)
    : QDBusAbstractAdaptor(parent)
{
    // constructor
    setAutoRelaySignals(true);
}

DustCapAdaptor::~DustCapAdaptor()
{
    // destructor
}

bool DustCapAdaptor::canPark() const
{
    // get the value of property canPark
    return qvariant_cast< bool >(parent()->property("canPark"));
}

bool DustCapAdaptor::connected() const
{
    // get the value of property connected
    return qvariant_cast< bool >(parent()->property("connected"));
}

QString DustCapAdaptor::name() const
{
    // get the value of property name
    return qvariant_cast< QString >(parent()->property("name"));
}

int DustCapAdaptor::parkStatus() const
{
    // get the value of property parkStatus
    return qvariant_cast< int >(parent()->property("parkStatus"));
}

int DustCapAdaptor::status() const
{
    // get the value of property status
    return qvariant_cast< int >(parent()->property("status"));
}

bool DustCapAdaptor::isParked()
{
    // handle method call org.kde.kstars.INDI.DustCap.isParked
    return parent()->isParked();
}

bool DustCapAdaptor::isUnParked()
{
    // handle method call org.kde.kstars.INDI.DustCap.isUnParked
    return parent()->isUnParked();
}

bool DustCapAdaptor::park()
{
    // handle method call org.kde.kstars.INDI.DustCap.park
    return parent()->park();
}

bool DustCapAdaptor::unpark()
{
    // handle method call org.kde.kstars.INDI.DustCap.unpark
    return parent()->unpark();
}


#include "moc_dustcapadaptor.cpp"
