/********************************************************************************
** Form generated from reading UI file 'capturepreviewwidget.ui'
**
** Created by: Qt User Interface Compiler version 6.11.1
**
** WARNING! All changes made in this file will be lost when recompiling UI file!
********************************************************************************/

#ifndef UI_CAPTUREPREVIEWWIDGET_H
#define UI_CAPTUREPREVIEWWIDGET_H

#include <QtCore/QVariant>
#include <QtWidgets/QApplication>
#include <QtWidgets/QComboBox>
#include <QtWidgets/QHBoxLayout>
#include <QtWidgets/QLabel>
#include <QtWidgets/QSpacerItem>
#include <QtWidgets/QVBoxLayout>
#include <QtWidgets/QWidget>
#include <klocalizedstring.h>
#include "ekos/auxiliary/ledstatuswidget.h"
#include "ekos/capture/capturecountswidget.h"

QT_BEGIN_NAMESPACE

class Ui_CapturePreviewWidget
{
public:
    QVBoxLayout *verticalLayout;
    QHBoxLayout *captureStatusLayout;
    QLabel *captureLabel;
    QComboBox *trainSelectionCB;
    QSpacerItem *horizontalSpacer_2;
    QLabel *targetLabel;
    QLabel *mountTarget;
    QSpacerItem *horizontalSpacer;
    Ekos::LedStatusWidget *captureStatusWidget;
    QWidget *previewWidget;
    CaptureCountsWidget *captureCountsWidget;

    void setupUi(QWidget *CapturePreviewWidget)
    {
        if (CapturePreviewWidget->objectName().isEmpty())
            CapturePreviewWidget->setObjectName("CapturePreviewWidget");
        CapturePreviewWidget->resize(300, 400);
        QSizePolicy sizePolicy(QSizePolicy::Policy::MinimumExpanding, QSizePolicy::Policy::MinimumExpanding);
        sizePolicy.setHorizontalStretch(0);
        sizePolicy.setVerticalStretch(0);
        sizePolicy.setHeightForWidth(CapturePreviewWidget->sizePolicy().hasHeightForWidth());
        CapturePreviewWidget->setSizePolicy(sizePolicy);
        CapturePreviewWidget->setMinimumSize(QSize(300, 400));
        CapturePreviewWidget->setMaximumSize(QSize(16777215, 16777215));
        CapturePreviewWidget->setBaseSize(QSize(0, 0));
        verticalLayout = new QVBoxLayout(CapturePreviewWidget);
        verticalLayout->setSpacing(0);
        verticalLayout->setObjectName("verticalLayout");
        verticalLayout->setContentsMargins(4, 4, 4, 4);
        captureStatusLayout = new QHBoxLayout();
        captureStatusLayout->setSpacing(2);
        captureStatusLayout->setObjectName("captureStatusLayout");
        captureStatusLayout->setContentsMargins(-1, -1, -1, 4);
        captureLabel = new QLabel(CapturePreviewWidget);
        captureLabel->setObjectName("captureLabel");

        captureStatusLayout->addWidget(captureLabel);

        trainSelectionCB = new QComboBox(CapturePreviewWidget);
        trainSelectionCB->setObjectName("trainSelectionCB");

        captureStatusLayout->addWidget(trainSelectionCB);

        horizontalSpacer_2 = new QSpacerItem(40, 20, QSizePolicy::Policy::Expanding, QSizePolicy::Policy::Minimum);

        captureStatusLayout->addItem(horizontalSpacer_2);

        targetLabel = new QLabel(CapturePreviewWidget);
        targetLabel->setObjectName("targetLabel");
        QSizePolicy sizePolicy1(QSizePolicy::Policy::Preferred, QSizePolicy::Policy::Preferred);
        sizePolicy1.setHorizontalStretch(0);
        sizePolicy1.setVerticalStretch(0);
        sizePolicy1.setHeightForWidth(targetLabel->sizePolicy().hasHeightForWidth());
        targetLabel->setSizePolicy(sizePolicy1);
        QFont font;
        font.setBold(true);
        targetLabel->setFont(font);

        captureStatusLayout->addWidget(targetLabel);

        mountTarget = new QLabel(CapturePreviewWidget);
        mountTarget->setObjectName("mountTarget");
        mountTarget->setMinimumSize(QSize(10, 0));

        captureStatusLayout->addWidget(mountTarget);

        horizontalSpacer = new QSpacerItem(1, 20, QSizePolicy::Policy::Expanding, QSizePolicy::Policy::Minimum);

        captureStatusLayout->addItem(horizontalSpacer);

        captureStatusWidget = new Ekos::LedStatusWidget(CapturePreviewWidget);
        captureStatusWidget->setObjectName("captureStatusWidget");
        captureStatusWidget->setMinimumSize(QSize(20, 24));

        captureStatusLayout->addWidget(captureStatusWidget);

        captureStatusLayout->setStretch(0, 1);
        captureStatusLayout->setStretch(1, 1);
        captureStatusLayout->setStretch(2, 1);
        captureStatusLayout->setStretch(5, 1);

        verticalLayout->addLayout(captureStatusLayout);

        previewWidget = new QWidget(CapturePreviewWidget);
        previewWidget->setObjectName("previewWidget");
        QSizePolicy sizePolicy2(QSizePolicy::Policy::Expanding, QSizePolicy::Policy::Expanding);
        sizePolicy2.setHorizontalStretch(0);
        sizePolicy2.setVerticalStretch(0);
        sizePolicy2.setHeightForWidth(previewWidget->sizePolicy().hasHeightForWidth());
        previewWidget->setSizePolicy(sizePolicy2);
        previewWidget->setMinimumSize(QSize(250, 250));
        previewWidget->setToolTipDuration(1);
        previewWidget->setAutoFillBackground(false);
        previewWidget->setStyleSheet(QString::fromUtf8(""));

        verticalLayout->addWidget(previewWidget);

        captureCountsWidget = new CaptureCountsWidget(CapturePreviewWidget);
        captureCountsWidget->setObjectName("captureCountsWidget");
        captureCountsWidget->setMinimumSize(QSize(250, 20));

        verticalLayout->addWidget(captureCountsWidget);

        verticalLayout->setStretch(1, 1);

        retranslateUi(CapturePreviewWidget);

        QMetaObject::connectSlotsByName(CapturePreviewWidget);
    } // setupUi

    void retranslateUi(QWidget *CapturePreviewWidget)
    {
        CapturePreviewWidget->setWindowTitle(tr2i18n("Ekos", nullptr));
        captureLabel->setText(tr2i18n("Capture", nullptr));
        targetLabel->setText(tr2i18n("Target: ", nullptr));
        mountTarget->setText(QString());
    } // retranslateUi

};

namespace Ui {
    class CapturePreviewWidget: public Ui_CapturePreviewWidget {};
} // namespace Ui

QT_END_NAMESPACE

#endif // CAPTUREPREVIEWWIDGET_H

