/****************************************************************************
** Meta object code from reading C++ file 'mountadaptor.h'
**
** Created by: The Qt Meta Object Compiler version 69 (Qt 6.11.1)
**
** WARNING! All changes made in this file will be lost!
*****************************************************************************/

#include "mountadaptor.h"
#include <QtCore/qmetatype.h>
#include <QtCore/QList>

#include <QtCore/qtmochelpers.h>

#include <memory>


#include <QtCore/qxptype_traits.h>
#if !defined(Q_MOC_OUTPUT_REVISION)
#error "The header file 'mountadaptor.h' doesn't include <QObject>."
#elif Q_MOC_OUTPUT_REVISION != 69
#error "This file was generated using the moc from 6.11.1. It"
#error "cannot be used with the include files from this version of Qt."
#error "(The moc has changed too much.)"
#endif

#ifndef Q_CONSTINIT
#define Q_CONSTINIT
#endif

QT_WARNING_PUSH
QT_WARNING_DISABLE_DEPRECATED
QT_WARNING_DISABLE_GCC("-Wuseless-cast")
namespace {
struct qt_meta_tag_ZN12MountAdaptorE_t {};
} // unnamed namespace

template <> constexpr inline auto MountAdaptor::qt_create_metaobjectdata<qt_meta_tag_ZN12MountAdaptorE_t>()
{
    namespace QMC = QtMocConstants;
    QtMocHelpers::StringRefStorage qt_stringData {
        "MountAdaptor",
        "D-Bus Interface",
        "org.kde.kstars.Ekos.Mount",
        "D-Bus Introspection",
        "  <interface name=\"org.kde.kstars.Ekos.Mount\">\n    <property ac"
        "cess=\"readwrite\" type=\"s\" name=\"opticalTrain\"/>\n    <proper"
        "ty access=\"read\" type=\"as\" name=\"logText\"/>\n    <property a"
        "ccess=\"read\" type=\"b\" name=\"canPark\"/>\n    <property access"
        "=\"read\" type=\"i\" name=\"slewStatus\"/>\n    <property access=\""
        "readwrite\" type=\"ad\" name=\"altitudeLimits\">\n      <annotatio"
        "n value=\"QList&lt;double&gt;\" name=\"org.qtproject.QtDBus.QtType"
        "Name\"/>\n    </property>\n    <property access=\"readwrite\" type"
        "=\"b\" name=\"altitudeLimitsEnabled\"/>\n    <property access=\"re"
        "adwrite\" type=\"d\" name=\"hourAngleLimit\"/>\n    <property acce"
        "ss=\"readwrite\" type=\"b\" name=\"hourAngleLimitEnabled\"/>\n    "
        "<property access=\"read\" type=\"ad\" name=\"equatorialCoords\">\n"
        "      <annotation value=\"QList&lt;double&gt;\" name=\"org.qtproje"
        "ct.QtDBus.QtTypeName\"/>\n    </property>\n    <property access=\""
        "read\" type=\"ad\" name=\"horizontalCoords\">\n      <annotation v"
        "alue=\"QList&lt;double&gt;\" name=\"org.qtproject.QtDBus.QtTypeNam"
        "e\"/>\n    </property>\n    <property access=\"readwrite\" type=\""
        "i\" name=\"slewRate\"/>\n    <property access=\"read\" type=\"d\" "
        "name=\"hourAngle\"/>\n    <property access=\"read\" type=\"i\" nam"
        "e=\"status\">\n      <annotation value=\"ISD::Mount::Status\" name"
        "=\"org.qtproject.QtDBus.QtTypeName\"/>\n    </property>\n    <prop"
        "erty access=\"read\" type=\"i\" name=\"parkStatus\">\n      <annot"
        "ation value=\"ISD::ParkStatus\" name=\"org.qtproject.QtDBus.QtType"
        "Name\"/>\n    </property>\n    <property access=\"read\" type=\"i\""
        " name=\"pierSide\">\n      <annotation value=\"ISD::Mount::PierSid"
        "e\" name=\"org.qtproject.QtDBus.QtTypeName\"/>\n    </property>\n "
        "   <method name=\"slew\">\n      <arg direction=\"out\" type=\"b\""
        "/>\n      <arg direction=\"in\" type=\"d\" name=\"RA\"/>\n      <a"
        "rg direction=\"in\" type=\"d\" name=\"DEC\"/>\n    </method>\n    "
        "<method name=\"sync\">\n      <arg direction=\"out\" type=\"b\"/>\n"
        "      <arg direction=\"in\" type=\"d\" name=\"RA\"/>\n      <arg d"
        "irection=\"in\" type=\"d\" name=\"DEC\"/>\n    </method>\n    <met"
        "hod name=\"gotoTarget\">\n      <arg direction=\"out\" type=\"b\"/"
        ">\n      <arg direction=\"in\" type=\"s\" name=\"target\"/>\n    <"
        "/method>\n    <method name=\"syncTarget\">\n      <arg direction=\""
        "out\" type=\"b\"/>\n      <arg direction=\"in\" type=\"s\" name=\""
        "target\"/>\n    </method>\n    <method name=\"abort\">\n      <arg"
        " direction=\"out\" type=\"b\"/>\n    </method>\n    <method name=\""
        "park\">\n      <arg direction=\"out\" type=\"b\"/>\n    </method>\n"
        "    <method name=\"unpark\">\n      <arg direction=\"out\" type=\""
        "b\"/>\n    </method>\n    <method name=\"resetModel\">\n      <arg"
        " direction=\"out\" type=\"b\"/>\n    </method>\n    <method name=\""
        "setMeridianFlipValues\">\n      <arg direction=\"in\" type=\"b\" n"
        "ame=\"activate\"/>\n      <arg direction=\"in\" type=\"d\" name=\""
        "hours\"/>\n      <annotation value=\"true\" name=\"org.freedesktop"
        ".DBus.Method.NoReply\"/>\n    </method>\n    <signal name=\"newSta"
        "tus\">\n      <arg direction=\"out\" type=\"(i)\" name=\"status\"/"
        ">\n      <annotation value=\"ISD::Mount::Status\" name=\"org.qtpro"
        "ject.QtDBus.QtTypeName.In0\"/>\n      <annotation value=\"ISD::Mou"
        "nt::Status\" name=\"org.qtproject.QtDBus.QtTypeName.Out0\"/>\n    "
        "</signal>\n    <signal name=\"newParkStatus\">\n      <arg directi"
        "on=\"out\" type=\"(i)\" name=\"status\"/>\n      <annotation value"
        "=\"ISD::ParkStatus\" name=\"org.qtproject.QtDBus.QtTypeName.In0\"/"
        ">\n      <annotation value=\"ISD::ParkStatus\" name=\"org.qtprojec"
        "t.QtDBus.QtTypeName.Out0\"/>\n    </signal>\n    <signal name=\"pi"
        "erSideChanged\">\n      <arg direction=\"out\" type=\"(i)\" name=\""
        "side\"/>\n      <annotation value=\"ISD::Mount::PierSide\" name=\""
        "org.qtproject.QtDBus.QtTypeName.In0\"/>\n      <annotation value=\""
        "ISD::Mount::PierSide\" name=\"org.qtproject.QtDBus.QtTypeName.Out0"
        "\"/>\n    </signal>\n    <signal name=\"newMeridianFlipSetup\">\n "
        "   </signal>\n    <signal name=\"ready\"/>\n  </interface>\n",
        "newMeridianFlipSetup",
        "",
        "newParkStatus",
        "ISD::ParkStatus",
        "status",
        "newStatus",
        "ISD::Mount::Status",
        "pierSideChanged",
        "ISD::Mount::PierSide",
        "side",
        "ready",
        "abort",
        "gotoTarget",
        "target",
        "park",
        "resetModel",
        "setMeridianFlipValues",
        "Q_NOREPLY",
        "activate",
        "hours",
        "slew",
        "RA",
        "DEC",
        "sync",
        "syncTarget",
        "unpark",
        "altitudeLimits",
        "QList<double>",
        "altitudeLimitsEnabled",
        "canPark",
        "equatorialCoords",
        "horizontalCoords",
        "hourAngle",
        "hourAngleLimit",
        "hourAngleLimitEnabled",
        "logText",
        "opticalTrain",
        "parkStatus",
        "pierSide",
        "slewRate",
        "slewStatus"
    };

    QtMocHelpers::UintData qt_methods {
        // Signal 'newMeridianFlipSetup'
        QtMocHelpers::SignalData<void()>(5, 6, QMC::AccessPublic, QMetaType::Void),
        // Signal 'newParkStatus'
        QtMocHelpers::SignalData<void(ISD::ParkStatus)>(7, 6, QMC::AccessPublic, QMetaType::Void, {{
            { 0x80000000 | 8, 9 },
        }}),
        // Signal 'newStatus'
        QtMocHelpers::SignalData<void(ISD::Mount::Status)>(10, 6, QMC::AccessPublic, QMetaType::Void, {{
            { 0x80000000 | 11, 9 },
        }}),
        // Signal 'pierSideChanged'
        QtMocHelpers::SignalData<void(ISD::Mount::PierSide)>(12, 6, QMC::AccessPublic, QMetaType::Void, {{
            { 0x80000000 | 13, 14 },
        }}),
        // Signal 'ready'
        QtMocHelpers::SignalData<void()>(15, 6, QMC::AccessPublic, QMetaType::Void),
        // Slot 'abort'
        QtMocHelpers::SlotData<bool()>(16, 6, QMC::AccessPublic, QMetaType::Bool),
        // Slot 'gotoTarget'
        QtMocHelpers::SlotData<bool(const QString &)>(17, 6, QMC::AccessPublic, QMetaType::Bool, {{
            { QMetaType::QString, 18 },
        }}),
        // Slot 'park'
        QtMocHelpers::SlotData<bool()>(19, 6, QMC::AccessPublic, QMetaType::Bool),
        // Slot 'resetModel'
        QtMocHelpers::SlotData<bool()>(20, 6, QMC::AccessPublic, QMetaType::Bool),
        // Slot 'setMeridianFlipValues'
        QtMocHelpers::SlotData<void(bool, double)>(21, 22, QMC::AccessPublic, QMetaType::Void, {{
            { QMetaType::Bool, 23 }, { QMetaType::Double, 24 },
        }}),
        // Slot 'slew'
        QtMocHelpers::SlotData<bool(double, double)>(25, 6, QMC::AccessPublic, QMetaType::Bool, {{
            { QMetaType::Double, 26 }, { QMetaType::Double, 27 },
        }}),
        // Slot 'sync'
        QtMocHelpers::SlotData<bool(double, double)>(28, 6, QMC::AccessPublic, QMetaType::Bool, {{
            { QMetaType::Double, 26 }, { QMetaType::Double, 27 },
        }}),
        // Slot 'syncTarget'
        QtMocHelpers::SlotData<bool(const QString &)>(29, 6, QMC::AccessPublic, QMetaType::Bool, {{
            { QMetaType::QString, 18 },
        }}),
        // Slot 'unpark'
        QtMocHelpers::SlotData<bool()>(30, 6, QMC::AccessPublic, QMetaType::Bool),
    };
    QtMocHelpers::UintData qt_properties {
        // property 'altitudeLimits'
        QtMocHelpers::PropertyData<QList<double>>(31, 0x80000000 | 32, QMC::DefaultPropertyFlags | QMC::Writable | QMC::EnumOrFlag | QMC::StdCppSet),
        // property 'altitudeLimitsEnabled'
        QtMocHelpers::PropertyData<bool>(33, QMetaType::Bool, QMC::DefaultPropertyFlags | QMC::Writable | QMC::StdCppSet),
        // property 'canPark'
        QtMocHelpers::PropertyData<bool>(34, QMetaType::Bool, QMC::DefaultPropertyFlags),
        // property 'equatorialCoords'
        QtMocHelpers::PropertyData<QList<double>>(35, 0x80000000 | 32, QMC::DefaultPropertyFlags | QMC::EnumOrFlag),
        // property 'horizontalCoords'
        QtMocHelpers::PropertyData<QList<double>>(36, 0x80000000 | 32, QMC::DefaultPropertyFlags | QMC::EnumOrFlag),
        // property 'hourAngle'
        QtMocHelpers::PropertyData<double>(37, QMetaType::Double, QMC::DefaultPropertyFlags),
        // property 'hourAngleLimit'
        QtMocHelpers::PropertyData<double>(38, QMetaType::Double, QMC::DefaultPropertyFlags | QMC::Writable | QMC::StdCppSet),
        // property 'hourAngleLimitEnabled'
        QtMocHelpers::PropertyData<bool>(39, QMetaType::Bool, QMC::DefaultPropertyFlags | QMC::Writable | QMC::StdCppSet),
        // property 'logText'
        QtMocHelpers::PropertyData<QStringList>(40, QMetaType::QStringList, QMC::DefaultPropertyFlags),
        // property 'opticalTrain'
        QtMocHelpers::PropertyData<QString>(41, QMetaType::QString, QMC::DefaultPropertyFlags | QMC::Writable | QMC::StdCppSet),
        // property 'parkStatus'
        QtMocHelpers::PropertyData<int>(42, QMetaType::Int, QMC::DefaultPropertyFlags),
        // property 'pierSide'
        QtMocHelpers::PropertyData<int>(43, QMetaType::Int, QMC::DefaultPropertyFlags),
        // property 'slewRate'
        QtMocHelpers::PropertyData<int>(44, QMetaType::Int, QMC::DefaultPropertyFlags | QMC::Writable | QMC::StdCppSet),
        // property 'slewStatus'
        QtMocHelpers::PropertyData<int>(45, QMetaType::Int, QMC::DefaultPropertyFlags),
        // property 'status'
        QtMocHelpers::PropertyData<int>(9, QMetaType::Int, QMC::DefaultPropertyFlags),
    };
    QtMocHelpers::UintData qt_enums {
    };
    QtMocHelpers::UintData qt_constructors {};
    QtMocHelpers::ClassInfos qt_classinfo({
            {    1,    2 },
            {    3,    4 },
    });
    return QtMocHelpers::metaObjectData<MountAdaptor, qt_meta_tag_ZN12MountAdaptorE_t>(QMC::MetaObjectFlag{}, qt_stringData,
            qt_methods, qt_properties, qt_enums, qt_constructors, qt_classinfo);
}
Q_CONSTINIT const QMetaObject MountAdaptor::staticMetaObject = { {
    QMetaObject::SuperData::link<QDBusAbstractAdaptor::staticMetaObject>(),
    qt_staticMetaObjectStaticContent<qt_meta_tag_ZN12MountAdaptorE_t>.stringdata,
    qt_staticMetaObjectStaticContent<qt_meta_tag_ZN12MountAdaptorE_t>.data,
    qt_static_metacall,
    nullptr,
    qt_staticMetaObjectRelocatingContent<qt_meta_tag_ZN12MountAdaptorE_t>.metaTypes,
    nullptr
} };

void MountAdaptor::qt_static_metacall(QObject *_o, QMetaObject::Call _c, int _id, void **_a)
{
    auto *_t = static_cast<MountAdaptor *>(_o);
    if (_c == QMetaObject::InvokeMetaMethod) {
        switch (_id) {
        case 0: _t->newMeridianFlipSetup(); break;
        case 1: _t->newParkStatus((*reinterpret_cast<std::add_pointer_t<ISD::ParkStatus>>(_a[1]))); break;
        case 2: _t->newStatus((*reinterpret_cast<std::add_pointer_t<ISD::Mount::Status>>(_a[1]))); break;
        case 3: _t->pierSideChanged((*reinterpret_cast<std::add_pointer_t<ISD::Mount::PierSide>>(_a[1]))); break;
        case 4: _t->ready(); break;
        case 5: { bool _r = _t->abort();
            if (_a[0]) *reinterpret_cast<bool*>(_a[0]) = std::move(_r); }  break;
        case 6: { bool _r = _t->gotoTarget((*reinterpret_cast<std::add_pointer_t<QString>>(_a[1])));
            if (_a[0]) *reinterpret_cast<bool*>(_a[0]) = std::move(_r); }  break;
        case 7: { bool _r = _t->park();
            if (_a[0]) *reinterpret_cast<bool*>(_a[0]) = std::move(_r); }  break;
        case 8: { bool _r = _t->resetModel();
            if (_a[0]) *reinterpret_cast<bool*>(_a[0]) = std::move(_r); }  break;
        case 9: _t->setMeridianFlipValues((*reinterpret_cast<std::add_pointer_t<bool>>(_a[1])),(*reinterpret_cast<std::add_pointer_t<double>>(_a[2]))); break;
        case 10: { bool _r = _t->slew((*reinterpret_cast<std::add_pointer_t<double>>(_a[1])),(*reinterpret_cast<std::add_pointer_t<double>>(_a[2])));
            if (_a[0]) *reinterpret_cast<bool*>(_a[0]) = std::move(_r); }  break;
        case 11: { bool _r = _t->sync((*reinterpret_cast<std::add_pointer_t<double>>(_a[1])),(*reinterpret_cast<std::add_pointer_t<double>>(_a[2])));
            if (_a[0]) *reinterpret_cast<bool*>(_a[0]) = std::move(_r); }  break;
        case 12: { bool _r = _t->syncTarget((*reinterpret_cast<std::add_pointer_t<QString>>(_a[1])));
            if (_a[0]) *reinterpret_cast<bool*>(_a[0]) = std::move(_r); }  break;
        case 13: { bool _r = _t->unpark();
            if (_a[0]) *reinterpret_cast<bool*>(_a[0]) = std::move(_r); }  break;
        default: ;
        }
    }
    if (_c == QMetaObject::RegisterMethodArgumentMetaType) {
        switch (_id) {
        default: *reinterpret_cast<QMetaType *>(_a[0]) = QMetaType(); break;
        case 1:
            switch (*reinterpret_cast<int*>(_a[1])) {
            default: *reinterpret_cast<QMetaType *>(_a[0]) = QMetaType(); break;
            case 0:
                *reinterpret_cast<QMetaType *>(_a[0]) = QMetaType::fromType< ISD::ParkStatus >(); break;
            }
            break;
        case 2:
            switch (*reinterpret_cast<int*>(_a[1])) {
            default: *reinterpret_cast<QMetaType *>(_a[0]) = QMetaType(); break;
            case 0:
                *reinterpret_cast<QMetaType *>(_a[0]) = QMetaType::fromType< ISD::Mount::Status >(); break;
            }
            break;
        case 3:
            switch (*reinterpret_cast<int*>(_a[1])) {
            default: *reinterpret_cast<QMetaType *>(_a[0]) = QMetaType(); break;
            case 0:
                *reinterpret_cast<QMetaType *>(_a[0]) = QMetaType::fromType< ISD::Mount::PierSide >(); break;
            }
            break;
        }
    }
    if (_c == QMetaObject::IndexOfMethod) {
        if (QtMocHelpers::indexOfMethod<void (MountAdaptor::*)()>(_a, &MountAdaptor::newMeridianFlipSetup, 0))
            return;
        if (QtMocHelpers::indexOfMethod<void (MountAdaptor::*)(ISD::ParkStatus )>(_a, &MountAdaptor::newParkStatus, 1))
            return;
        if (QtMocHelpers::indexOfMethod<void (MountAdaptor::*)(ISD::Mount::Status )>(_a, &MountAdaptor::newStatus, 2))
            return;
        if (QtMocHelpers::indexOfMethod<void (MountAdaptor::*)(ISD::Mount::PierSide )>(_a, &MountAdaptor::pierSideChanged, 3))
            return;
        if (QtMocHelpers::indexOfMethod<void (MountAdaptor::*)()>(_a, &MountAdaptor::ready, 4))
            return;
    }
    if (_c == QMetaObject::RegisterPropertyMetaType) {
        switch (_id) {
        default: *reinterpret_cast<int*>(_a[0]) = -1; break;
        case 4:
        case 3:
        case 0:
            *reinterpret_cast<int*>(_a[0]) = qRegisterMetaType< QList<double> >(); break;
        }
    }
    if (_c == QMetaObject::ReadProperty) {
        void *_v = _a[0];
        switch (_id) {
        case 0: *reinterpret_cast<QList<double>*>(_v) = _t->altitudeLimits(); break;
        case 1: *reinterpret_cast<bool*>(_v) = _t->altitudeLimitsEnabled(); break;
        case 2: *reinterpret_cast<bool*>(_v) = _t->canPark(); break;
        case 3: *reinterpret_cast<QList<double>*>(_v) = _t->equatorialCoords(); break;
        case 4: *reinterpret_cast<QList<double>*>(_v) = _t->horizontalCoords(); break;
        case 5: *reinterpret_cast<double*>(_v) = _t->hourAngle(); break;
        case 6: *reinterpret_cast<double*>(_v) = _t->hourAngleLimit(); break;
        case 7: *reinterpret_cast<bool*>(_v) = _t->hourAngleLimitEnabled(); break;
        case 8: *reinterpret_cast<QStringList*>(_v) = _t->logText(); break;
        case 9: *reinterpret_cast<QString*>(_v) = _t->opticalTrain(); break;
        case 10: *reinterpret_cast<int*>(_v) = _t->parkStatus(); break;
        case 11: *reinterpret_cast<int*>(_v) = _t->pierSide(); break;
        case 12: *reinterpret_cast<int*>(_v) = _t->slewRate(); break;
        case 13: *reinterpret_cast<int*>(_v) = _t->slewStatus(); break;
        case 14: *reinterpret_cast<int*>(_v) = _t->status(); break;
        default: break;
        }
    }
    if (_c == QMetaObject::WriteProperty) {
        void *_v = _a[0];
        switch (_id) {
        case 0: _t->setAltitudeLimits(*reinterpret_cast<QList<double>*>(_v)); break;
        case 1: _t->setAltitudeLimitsEnabled(*reinterpret_cast<bool*>(_v)); break;
        case 6: _t->setHourAngleLimit(*reinterpret_cast<double*>(_v)); break;
        case 7: _t->setHourAngleLimitEnabled(*reinterpret_cast<bool*>(_v)); break;
        case 9: _t->setOpticalTrain(*reinterpret_cast<QString*>(_v)); break;
        case 12: _t->setSlewRate(*reinterpret_cast<int*>(_v)); break;
        default: break;
        }
    }
}

const QMetaObject *MountAdaptor::metaObject() const
{
    return QObject::d_ptr->metaObject ? QObject::d_ptr->dynamicMetaObject() : &staticMetaObject;
}

void *MountAdaptor::qt_metacast(const char *_clname)
{
    if (!_clname) return nullptr;
    if (!strcmp(_clname, qt_staticMetaObjectStaticContent<qt_meta_tag_ZN12MountAdaptorE_t>.strings))
        return static_cast<void*>(this);
    return QDBusAbstractAdaptor::qt_metacast(_clname);
}

int MountAdaptor::qt_metacall(QMetaObject::Call _c, int _id, void **_a)
{
    _id = QDBusAbstractAdaptor::qt_metacall(_c, _id, _a);
    if (_id < 0)
        return _id;
    if (_c == QMetaObject::InvokeMetaMethod) {
        if (_id < 14)
            qt_static_metacall(this, _c, _id, _a);
        _id -= 14;
    }
    if (_c == QMetaObject::RegisterMethodArgumentMetaType) {
        if (_id < 14)
            qt_static_metacall(this, _c, _id, _a);
        _id -= 14;
    }
    if (_c == QMetaObject::ReadProperty || _c == QMetaObject::WriteProperty
            || _c == QMetaObject::ResetProperty || _c == QMetaObject::BindableProperty
            || _c == QMetaObject::RegisterPropertyMetaType) {
        qt_static_metacall(this, _c, _id, _a);
        _id -= 15;
    }
    return _id;
}

// SIGNAL 0
void MountAdaptor::newMeridianFlipSetup()
{
    QMetaObject::activate(this, &staticMetaObject, 0, nullptr);
}

// SIGNAL 1
void MountAdaptor::newParkStatus(ISD::ParkStatus _t1)
{
    QMetaObject::activate<void>(this, &staticMetaObject, 1, nullptr, _t1);
}

// SIGNAL 2
void MountAdaptor::newStatus(ISD::Mount::Status _t1)
{
    QMetaObject::activate<void>(this, &staticMetaObject, 2, nullptr, _t1);
}

// SIGNAL 3
void MountAdaptor::pierSideChanged(ISD::Mount::PierSide _t1)
{
    QMetaObject::activate<void>(this, &staticMetaObject, 3, nullptr, _t1);
}

// SIGNAL 4
void MountAdaptor::ready()
{
    QMetaObject::activate(this, &staticMetaObject, 4, nullptr);
}
QT_WARNING_POP
