/********************************************************************************
** Form generated from reading UI file 'collimationOptions.ui'
**
** Created by: Qt User Interface Compiler version 6.11.1
**
** WARNING! All changes made in this file will be lost when recompiling UI file!
********************************************************************************/

#ifndef UI_COLLIMATIONOPTIONS_H
#define UI_COLLIMATIONOPTIONS_H

#include <QtCore/QVariant>
#include <QtGui/QIcon>
#include <QtWidgets/QAbstractButton>
#include <QtWidgets/QApplication>
#include <QtWidgets/QCheckBox>
#include <QtWidgets/QComboBox>
#include <QtWidgets/QDialog>
#include <QtWidgets/QDialogButtonBox>
#include <QtWidgets/QDoubleSpinBox>
#include <QtWidgets/QGridLayout>
#include <QtWidgets/QGroupBox>
#include <QtWidgets/QHBoxLayout>
#include <QtWidgets/QLabel>
#include <QtWidgets/QLineEdit>
#include <QtWidgets/QListWidget>
#include <QtWidgets/QPushButton>
#include <QtWidgets/QSpacerItem>
#include <QtWidgets/QSpinBox>
#include <QtWidgets/QSplitter>
#include <QtWidgets/QVBoxLayout>
#include <klocalizedstring.h>
#include "kcolorbutton.h"

QT_BEGIN_NAMESPACE

class Ui_collimationOptions
{
public:
    QVBoxLayout *verticalLayout;
    QHBoxLayout *horizontalLayout;
    QPushButton *addB;
    QPushButton *removeB;
    QSpacerItem *horizontalSpacer;
    QSplitter *splitter;
    QListWidget *elementNamesList;
    QGroupBox *elementConfigBox;
    QGridLayout *gridLayout;
    QLabel *enableLabel;
    QHBoxLayout *horizontalLayout_4;
    QCheckBox *EnableCheckBox;
    QPushButton *renameB;
    QSpinBox *countSpinBox;
    QLabel *nameLabel;
    QComboBox *typeComboBox;
    QLabel *colourLabel;
    QHBoxLayout *horizontalLayout_5;
    QLabel *offsetXLabel;
    QSpinBox *offsetXSpinBox;
    QLabel *offsetYLabel;
    QSpinBox *offsetYSpinBox;
    QHBoxLayout *horizontalLayout_7;
    KColorButton *colourButton;
    QLabel *thicknessLabel;
    QSpinBox *thicknessSpinBox;
    QLabel *offsetLabel;
    QLabel *sizeLabel;
    QHBoxLayout *horizontalLayout_2;
    QLabel *sizeXLabel;
    QSpinBox *sizeXSpinBox;
    QPushButton *linkXYB;
    QLabel *sizeYLabel;
    QSpinBox *sizeYSpinBox;
    QLabel *typeLabel;
    QLabel *countLabel;
    QHBoxLayout *horizontalLayout_9;
    QSpinBox *pcdSpinBox;
    QLabel *rotationLabel;
    QDoubleSpinBox *rotationDoubleSpinBox;
    QLabel *pcdLabel;
    QLineEdit *nameLineEdit;
    QHBoxLayout *horizontalLayout_3;
    QSpacerItem *horizontalSpacer_2;
    QDialogButtonBox *buttonBox;

    void setupUi(QDialog *collimationOptions)
    {
        if (collimationOptions->objectName().isEmpty())
            collimationOptions->setObjectName("collimationOptions");
        collimationOptions->resize(435, 356);
        collimationOptions->setMaximumSize(QSize(16777215, 16777215));
        collimationOptions->setInputMethodHints(Qt::ImhNoPredictiveText);
        verticalLayout = new QVBoxLayout(collimationOptions);
        verticalLayout->setSpacing(3);
        verticalLayout->setObjectName("verticalLayout");
        verticalLayout->setContentsMargins(3, 3, 3, 3);
        horizontalLayout = new QHBoxLayout();
        horizontalLayout->setSpacing(3);
        horizontalLayout->setObjectName("horizontalLayout");
        addB = new QPushButton(collimationOptions);
        addB->setObjectName("addB");
        addB->setMaximumSize(QSize(32, 32));
        QIcon icon;
        QString iconThemeName = QString::fromUtf8("list-add");
        if (QIcon::hasThemeIcon(iconThemeName)) {
            icon = QIcon::fromTheme(iconThemeName);
        } else {
            icon.addFile(QString::fromUtf8("../ekos/auxiliary"), QSize(), QIcon::Mode::Normal, QIcon::State::Off);
        }
        addB->setIcon(icon);

        horizontalLayout->addWidget(addB);

        removeB = new QPushButton(collimationOptions);
        removeB->setObjectName("removeB");
        removeB->setEnabled(false);
        removeB->setMaximumSize(QSize(32, 32));
        QIcon icon1;
        iconThemeName = QString::fromUtf8("list-remove");
        if (QIcon::hasThemeIcon(iconThemeName)) {
            icon1 = QIcon::fromTheme(iconThemeName);
        } else {
            icon1.addFile(QString::fromUtf8("../ekos/auxiliary"), QSize(), QIcon::Mode::Normal, QIcon::State::Off);
        }
        removeB->setIcon(icon1);

        horizontalLayout->addWidget(removeB);

        horizontalSpacer = new QSpacerItem(40, 20, QSizePolicy::Policy::Expanding, QSizePolicy::Policy::Minimum);

        horizontalLayout->addItem(horizontalSpacer);


        verticalLayout->addLayout(horizontalLayout);

        splitter = new QSplitter(collimationOptions);
        splitter->setObjectName("splitter");
        QSizePolicy sizePolicy(QSizePolicy::Policy::Expanding, QSizePolicy::Policy::Preferred);
        sizePolicy.setHorizontalStretch(0);
        sizePolicy.setVerticalStretch(0);
        sizePolicy.setHeightForWidth(splitter->sizePolicy().hasHeightForWidth());
        splitter->setSizePolicy(sizePolicy);
        splitter->setOrientation(Qt::Horizontal);
        elementNamesList = new QListWidget(splitter);
        elementNamesList->setObjectName("elementNamesList");
        elementNamesList->setMinimumSize(QSize(175, 0));
        elementNamesList->setSizeAdjustPolicy(QAbstractScrollArea::AdjustToContentsOnFirstShow);
        elementNamesList->setEditTriggers(QAbstractItemView::NoEditTriggers);
        elementNamesList->setProperty("showDropIndicator", QVariant(false));
        splitter->addWidget(elementNamesList);
        elementConfigBox = new QGroupBox(splitter);
        elementConfigBox->setObjectName("elementConfigBox");
        QSizePolicy sizePolicy1(QSizePolicy::Policy::Preferred, QSizePolicy::Policy::Preferred);
        sizePolicy1.setHorizontalStretch(0);
        sizePolicy1.setVerticalStretch(0);
        sizePolicy1.setHeightForWidth(elementConfigBox->sizePolicy().hasHeightForWidth());
        elementConfigBox->setSizePolicy(sizePolicy1);
        gridLayout = new QGridLayout(elementConfigBox);
        gridLayout->setSpacing(3);
        gridLayout->setObjectName("gridLayout");
        gridLayout->setContentsMargins(3, 3, 3, 3);
        enableLabel = new QLabel(elementConfigBox);
        enableLabel->setObjectName("enableLabel");
        enableLabel->setAlignment(Qt::AlignLeading|Qt::AlignLeft|Qt::AlignVCenter);

        gridLayout->addWidget(enableLabel, 1, 0, 1, 1);

        horizontalLayout_4 = new QHBoxLayout();
        horizontalLayout_4->setObjectName("horizontalLayout_4");
        EnableCheckBox = new QCheckBox(elementConfigBox);
        EnableCheckBox->setObjectName("EnableCheckBox");
        EnableCheckBox->setChecked(true);

        horizontalLayout_4->addWidget(EnableCheckBox);

        renameB = new QPushButton(elementConfigBox);
        renameB->setObjectName("renameB");
        renameB->setEnabled(false);

        horizontalLayout_4->addWidget(renameB);


        gridLayout->addLayout(horizontalLayout_4, 1, 2, 1, 1);

        countSpinBox = new QSpinBox(elementConfigBox);
        countSpinBox->setObjectName("countSpinBox");
        countSpinBox->setMinimum(1);
        countSpinBox->setMaximum(12);

        gridLayout->addWidget(countSpinBox, 7, 2, 1, 1);

        nameLabel = new QLabel(elementConfigBox);
        nameLabel->setObjectName("nameLabel");

        gridLayout->addWidget(nameLabel, 0, 0, 1, 1);

        typeComboBox = new QComboBox(elementConfigBox);
        typeComboBox->setObjectName("typeComboBox");
        QSizePolicy sizePolicy2(QSizePolicy::Policy::MinimumExpanding, QSizePolicy::Policy::Fixed);
        sizePolicy2.setHorizontalStretch(0);
        sizePolicy2.setVerticalStretch(0);
        sizePolicy2.setHeightForWidth(typeComboBox->sizePolicy().hasHeightForWidth());
        typeComboBox->setSizePolicy(sizePolicy2);

        gridLayout->addWidget(typeComboBox, 4, 2, 1, 1);

        colourLabel = new QLabel(elementConfigBox);
        colourLabel->setObjectName("colourLabel");

        gridLayout->addWidget(colourLabel, 11, 0, 1, 1);

        horizontalLayout_5 = new QHBoxLayout();
        horizontalLayout_5->setObjectName("horizontalLayout_5");
        offsetXLabel = new QLabel(elementConfigBox);
        offsetXLabel->setObjectName("offsetXLabel");
        offsetXLabel->setAlignment(Qt::AlignRight|Qt::AlignTrailing|Qt::AlignVCenter);

        horizontalLayout_5->addWidget(offsetXLabel);

        offsetXSpinBox = new QSpinBox(elementConfigBox);
        offsetXSpinBox->setObjectName("offsetXSpinBox");
        offsetXSpinBox->setMinimum(-9999);
        offsetXSpinBox->setMaximum(9999);

        horizontalLayout_5->addWidget(offsetXSpinBox);

        offsetYLabel = new QLabel(elementConfigBox);
        offsetYLabel->setObjectName("offsetYLabel");
        offsetYLabel->setAlignment(Qt::AlignRight|Qt::AlignTrailing|Qt::AlignVCenter);

        horizontalLayout_5->addWidget(offsetYLabel);

        offsetYSpinBox = new QSpinBox(elementConfigBox);
        offsetYSpinBox->setObjectName("offsetYSpinBox");
        offsetYSpinBox->setMinimum(-9999);
        offsetYSpinBox->setMaximum(9999);
        offsetYSpinBox->setSingleStep(1);

        horizontalLayout_5->addWidget(offsetYSpinBox);


        gridLayout->addLayout(horizontalLayout_5, 6, 2, 1, 1);

        horizontalLayout_7 = new QHBoxLayout();
        horizontalLayout_7->setObjectName("horizontalLayout_7");
        colourButton = new KColorButton(elementConfigBox);
        colourButton->setObjectName("colourButton");
        colourButton->setProperty("color", QVariant(QColor(255, 255, 255)));

        horizontalLayout_7->addWidget(colourButton);

        thicknessLabel = new QLabel(elementConfigBox);
        thicknessLabel->setObjectName("thicknessLabel");

        horizontalLayout_7->addWidget(thicknessLabel);

        thicknessSpinBox = new QSpinBox(elementConfigBox);
        thicknessSpinBox->setObjectName("thicknessSpinBox");
        thicknessSpinBox->setMinimum(1);

        horizontalLayout_7->addWidget(thicknessSpinBox);


        gridLayout->addLayout(horizontalLayout_7, 11, 2, 1, 1);

        offsetLabel = new QLabel(elementConfigBox);
        offsetLabel->setObjectName("offsetLabel");

        gridLayout->addWidget(offsetLabel, 6, 0, 1, 1);

        sizeLabel = new QLabel(elementConfigBox);
        sizeLabel->setObjectName("sizeLabel");
        sizeLabel->setAlignment(Qt::AlignLeading|Qt::AlignLeft|Qt::AlignVCenter);

        gridLayout->addWidget(sizeLabel, 5, 0, 1, 1);

        horizontalLayout_2 = new QHBoxLayout();
        horizontalLayout_2->setObjectName("horizontalLayout_2");
        sizeXLabel = new QLabel(elementConfigBox);
        sizeXLabel->setObjectName("sizeXLabel");
        sizeXLabel->setAlignment(Qt::AlignRight|Qt::AlignTrailing|Qt::AlignVCenter);

        horizontalLayout_2->addWidget(sizeXLabel);

        sizeXSpinBox = new QSpinBox(elementConfigBox);
        sizeXSpinBox->setObjectName("sizeXSpinBox");
        sizeXSpinBox->setMinimum(1);
        sizeXSpinBox->setMaximum(10000);
        sizeXSpinBox->setValue(1000);

        horizontalLayout_2->addWidget(sizeXSpinBox);

        linkXYB = new QPushButton(elementConfigBox);
        linkXYB->setObjectName("linkXYB");
        QSizePolicy sizePolicy3(QSizePolicy::Policy::Fixed, QSizePolicy::Policy::Fixed);
        sizePolicy3.setHorizontalStretch(0);
        sizePolicy3.setVerticalStretch(0);
        sizePolicy3.setHeightForWidth(linkXYB->sizePolicy().hasHeightForWidth());
        linkXYB->setSizePolicy(sizePolicy3);
        linkXYB->setMaximumSize(QSize(20, 16777215));

        horizontalLayout_2->addWidget(linkXYB);

        sizeYLabel = new QLabel(elementConfigBox);
        sizeYLabel->setObjectName("sizeYLabel");
        sizeYLabel->setAlignment(Qt::AlignRight|Qt::AlignTrailing|Qt::AlignVCenter);

        horizontalLayout_2->addWidget(sizeYLabel);

        sizeYSpinBox = new QSpinBox(elementConfigBox);
        sizeYSpinBox->setObjectName("sizeYSpinBox");
        sizeYSpinBox->setMinimum(1);
        sizeYSpinBox->setMaximum(10000);
        sizeYSpinBox->setValue(1000);

        horizontalLayout_2->addWidget(sizeYSpinBox);


        gridLayout->addLayout(horizontalLayout_2, 5, 2, 1, 1);

        typeLabel = new QLabel(elementConfigBox);
        typeLabel->setObjectName("typeLabel");
        typeLabel->setAlignment(Qt::AlignLeading|Qt::AlignLeft|Qt::AlignVCenter);

        gridLayout->addWidget(typeLabel, 4, 0, 1, 1);

        countLabel = new QLabel(elementConfigBox);
        countLabel->setObjectName("countLabel");
        countLabel->setAlignment(Qt::AlignLeading|Qt::AlignLeft|Qt::AlignVCenter);

        gridLayout->addWidget(countLabel, 7, 0, 1, 1);

        horizontalLayout_9 = new QHBoxLayout();
        horizontalLayout_9->setObjectName("horizontalLayout_9");
        pcdSpinBox = new QSpinBox(elementConfigBox);
        pcdSpinBox->setObjectName("pcdSpinBox");
        pcdSpinBox->setMaximum(9999);

        horizontalLayout_9->addWidget(pcdSpinBox);

        rotationLabel = new QLabel(elementConfigBox);
        rotationLabel->setObjectName("rotationLabel");
        rotationLabel->setAlignment(Qt::AlignLeading|Qt::AlignLeft|Qt::AlignVCenter);

        horizontalLayout_9->addWidget(rotationLabel);

        rotationDoubleSpinBox = new QDoubleSpinBox(elementConfigBox);
        rotationDoubleSpinBox->setObjectName("rotationDoubleSpinBox");
        rotationDoubleSpinBox->setDecimals(1);
        rotationDoubleSpinBox->setMaximum(359.899999999999977);
        rotationDoubleSpinBox->setSingleStep(0.100000000000000);

        horizontalLayout_9->addWidget(rotationDoubleSpinBox);


        gridLayout->addLayout(horizontalLayout_9, 8, 2, 1, 1);

        pcdLabel = new QLabel(elementConfigBox);
        pcdLabel->setObjectName("pcdLabel");

        gridLayout->addWidget(pcdLabel, 8, 0, 1, 1);

        nameLineEdit = new QLineEdit(elementConfigBox);
        nameLineEdit->setObjectName("nameLineEdit");

        gridLayout->addWidget(nameLineEdit, 0, 2, 1, 1);

        splitter->addWidget(elementConfigBox);

        verticalLayout->addWidget(splitter);

        horizontalLayout_3 = new QHBoxLayout();
        horizontalLayout_3->setSpacing(3);
        horizontalLayout_3->setObjectName("horizontalLayout_3");
        horizontalSpacer_2 = new QSpacerItem(40, 20, QSizePolicy::Policy::Expanding, QSizePolicy::Policy::Minimum);

        horizontalLayout_3->addItem(horizontalSpacer_2);

        buttonBox = new QDialogButtonBox(collimationOptions);
        buttonBox->setObjectName("buttonBox");
        buttonBox->setOrientation(Qt::Horizontal);
        buttonBox->setStandardButtons(QDialogButtonBox::Close);

        horizontalLayout_3->addWidget(buttonBox);


        verticalLayout->addLayout(horizontalLayout_3);

        QWidget::setTabOrder(addB, removeB);
        QWidget::setTabOrder(removeB, elementNamesList);
        QWidget::setTabOrder(elementNamesList, nameLineEdit);
        QWidget::setTabOrder(nameLineEdit, renameB);
        QWidget::setTabOrder(renameB, EnableCheckBox);
        QWidget::setTabOrder(EnableCheckBox, typeComboBox);
        QWidget::setTabOrder(typeComboBox, sizeXSpinBox);
        QWidget::setTabOrder(sizeXSpinBox, linkXYB);
        QWidget::setTabOrder(linkXYB, sizeYSpinBox);
        QWidget::setTabOrder(sizeYSpinBox, offsetXSpinBox);
        QWidget::setTabOrder(offsetXSpinBox, offsetYSpinBox);
        QWidget::setTabOrder(offsetYSpinBox, countSpinBox);
        QWidget::setTabOrder(countSpinBox, pcdSpinBox);
        QWidget::setTabOrder(pcdSpinBox, rotationDoubleSpinBox);
        QWidget::setTabOrder(rotationDoubleSpinBox, colourButton);
        QWidget::setTabOrder(colourButton, thicknessSpinBox);

        retranslateUi(collimationOptions);
        QObject::connect(buttonBox, &QDialogButtonBox::accepted, collimationOptions, qOverload<>(&QDialog::accept));
        QObject::connect(buttonBox, &QDialogButtonBox::rejected, collimationOptions, qOverload<>(&QDialog::reject));

        QMetaObject::connectSlotsByName(collimationOptions);
    } // setupUi

    void retranslateUi(QDialog *collimationOptions)
    {
        collimationOptions->setWindowTitle(tr2i18n("Collimation Overlay Options", nullptr));
#if QT_CONFIG(tooltip)
        addB->setToolTip(tr2i18n("Create a new Collimation Overlay Element", nullptr));
#endif // QT_CONFIG(tooltip)
        addB->setText(QString());
#if QT_CONFIG(tooltip)
        removeB->setToolTip(tr2i18n("Delete the selected Collimation Overlay Element", nullptr));
#endif // QT_CONFIG(tooltip)
        removeB->setText(QString());
#if QT_CONFIG(tooltip)
        elementNamesList->setToolTip(tr2i18n("Collimation Overlay Element name (double click to edit)", nullptr));
#endif // QT_CONFIG(tooltip)
        elementConfigBox->setTitle(tr2i18n("Collimation Overlay Element", nullptr));
#if QT_CONFIG(tooltip)
        enableLabel->setToolTip(tr2i18n("Select whether this Element is enabled or not", nullptr));
#endif // QT_CONFIG(tooltip)
        enableLabel->setText(tr2i18n("Enable:", nullptr));
        EnableCheckBox->setText(QString());
        renameB->setText(tr2i18n("Rename", nullptr));
#if QT_CONFIG(tooltip)
        nameLabel->setToolTip(tr2i18n("Enter a name for this Collimation Overlay Element. If left empty a name will be generated based on the Type selected.", nullptr));
#endif // QT_CONFIG(tooltip)
        nameLabel->setText(tr2i18n("Name:", nullptr));
#if QT_CONFIG(tooltip)
        colourLabel->setToolTip(tr2i18n("Select color for the Element", nullptr));
#endif // QT_CONFIG(tooltip)
        colourLabel->setText(tr2i18n("Color:", nullptr));
        offsetXLabel->setText(tr2i18n("X", nullptr));
        offsetYLabel->setText(tr2i18n("Y", nullptr));
#if QT_CONFIG(tooltip)
        colourButton->setToolTip(QString());
#endif // QT_CONFIG(tooltip)
#if QT_CONFIG(whatsthis)
        colourButton->setWhatsThis(tr2i18n("Select a color for the Collimation Overlay Element.", nullptr));
#endif // QT_CONFIG(whatsthis)
        colourButton->setText(QString());
#if QT_CONFIG(tooltip)
        thicknessLabel->setToolTip(tr2i18n("Set the line thickness used to draw the element.", nullptr));
#endif // QT_CONFIG(tooltip)
        thicknessLabel->setText(tr2i18n("Thickness:", nullptr));
#if QT_CONFIG(tooltip)
        offsetLabel->setToolTip(tr2i18n("Set the Element's offset from its Anchor. For an Anchor Element this is from the center of the image.", nullptr));
#endif // QT_CONFIG(tooltip)
        offsetLabel->setText(tr2i18n("Offset:", nullptr));
#if QT_CONFIG(tooltip)
        sizeLabel->setToolTip(tr2i18n("Set the size of the Element", nullptr));
#endif // QT_CONFIG(tooltip)
        sizeLabel->setText(tr2i18n("Size:", nullptr));
        sizeXLabel->setText(tr2i18n("X", nullptr));
#if QT_CONFIG(tooltip)
        linkXYB->setToolTip(tr2i18n("Link X & Y sizes", nullptr));
#endif // QT_CONFIG(tooltip)
        linkXYB->setText(QString());
        sizeYLabel->setText(tr2i18n("Y", nullptr));
#if QT_CONFIG(tooltip)
        typeLabel->setToolTip(tr2i18n("Select the type of Collimation Overlay Element", nullptr));
#endif // QT_CONFIG(tooltip)
        typeLabel->setText(tr2i18n("Type:", nullptr));
#if QT_CONFIG(tooltip)
        countLabel->setToolTip(tr2i18n("Select number of occurrences of the object type within this element", nullptr));
#endif // QT_CONFIG(tooltip)
        countLabel->setText(tr2i18n("Count:", nullptr));
#if QT_CONFIG(tooltip)
        rotationLabel->setToolTip(tr2i18n("If there is more than one occurrence set the base rotation angle.", nullptr));
#endif // QT_CONFIG(tooltip)
        rotationLabel->setText(tr2i18n("Rotation:", nullptr));
#if QT_CONFIG(tooltip)
        pcdLabel->setToolTip(tr2i18n("Set the Pitch Circle Diameter where there are multiple occurrences (Count >1)", nullptr));
#endif // QT_CONFIG(tooltip)
        pcdLabel->setText(tr2i18n("PCD:", nullptr));
    } // retranslateUi

};

namespace Ui {
    class collimationOptions: public Ui_collimationOptions {};
} // namespace Ui

QT_END_NAMESPACE

#endif // COLLIMATIONOPTIONS_H

