/********************************************************************************
** Form generated from reading UI file 'sequenceeditorui.ui'
**
** Created by: Qt User Interface Compiler version 6.11.1
**
** WARNING! All changes made in this file will be lost when recompiling UI file!
********************************************************************************/

#ifndef UI_SEQUENCEEDITORUI_H
#define UI_SEQUENCEEDITORUI_H

#include <QtCore/QVariant>
#include <QtWidgets/QApplication>
#include <QtWidgets/QDialog>
#include <QtWidgets/QLabel>
#include <QtWidgets/QVBoxLayout>
#include <klocalizedstring.h>

QT_BEGIN_NAMESPACE

class Ui_SequenceEditorUI
{
public:
    QVBoxLayout *sequenceEditorLayout;
    QLabel *sequenceEditorComment;

    void setupUi(QDialog *SequenceEditorUI)
    {
        if (SequenceEditorUI->objectName().isEmpty())
            SequenceEditorUI->setObjectName("SequenceEditorUI");
        SequenceEditorUI->resize(436, 380);
        QSizePolicy sizePolicy(QSizePolicy::Policy::MinimumExpanding, QSizePolicy::Policy::MinimumExpanding);
        sizePolicy.setHorizontalStretch(0);
        sizePolicy.setVerticalStretch(0);
        sizePolicy.setHeightForWidth(SequenceEditorUI->sizePolicy().hasHeightForWidth());
        SequenceEditorUI->setSizePolicy(sizePolicy);
        sequenceEditorLayout = new QVBoxLayout(SequenceEditorUI);
        sequenceEditorLayout->setObjectName("sequenceEditorLayout");
        sequenceEditorComment = new QLabel(SequenceEditorUI);
        sequenceEditorComment->setObjectName("sequenceEditorComment");

        sequenceEditorLayout->addWidget(sequenceEditorComment);


        retranslateUi(SequenceEditorUI);

        QMetaObject::connectSlotsByName(SequenceEditorUI);
    } // setupUi

    void retranslateUi(QDialog *SequenceEditorUI)
    {
        SequenceEditorUI->setWindowTitle(tr2i18n("Capture Sequence Editor", nullptr));
        sequenceEditorComment->setText(tr2i18n("<comment>", nullptr));
    } // retranslateUi

};

namespace Ui {
    class SequenceEditorUI: public Ui_SequenceEditorUI {};
} // namespace Ui

QT_END_NAMESPACE

#endif // SEQUENCEEDITORUI_H

