/****************************************************************************
** Meta object code from reading C++ file 'Options.h'
**
** Created by: The Qt Meta Object Compiler version 69 (Qt 6.11.1)
**
** WARNING! All changes made in this file will be lost!
*****************************************************************************/

#include "../../Options.h"
#include <QtCore/qmetatype.h>
#include <QtCore/QList>

#include <QtCore/qtmochelpers.h>

#include <memory>


#include <QtCore/qxptype_traits.h>
#if !defined(Q_MOC_OUTPUT_REVISION)
#error "The header file 'Options.h' doesn't include <QObject>."
#elif Q_MOC_OUTPUT_REVISION != 69
#error "This file was generated using the moc from 6.11.1. It"
#error "cannot be used with the include files from this version of Qt."
#error "(The moc has changed too much.)"
#endif

#ifndef Q_CONSTINIT
#define Q_CONSTINIT
#endif

QT_WARNING_PUSH
QT_WARNING_DISABLE_DEPRECATED
QT_WARNING_DISABLE_GCC("-Wuseless-cast")
namespace {
struct qt_meta_tag_ZN7OptionsE_t {};
} // unnamed namespace

template <> constexpr inline auto Options::qt_create_metaobjectdata<qt_meta_tag_ZN7OptionsE_t>()
{
    namespace QMC = QtMocConstants;
    QtMocHelpers::StringRefStorage qt_stringData {
        "Options",
        "PositionTimeBoxChanged",
        "",
        "PositionFocusBoxChanged",
        "PositionGeoBoxChanged",
        "ShadeTimeBoxChanged",
        "ShadeFocusBoxChanged",
        "ShadeGeoBoxChanged",
        "ShowInfoBoxesChanged",
        "ShowTimeBoxChanged",
        "ShowFocusBoxChanged",
        "ShowGeoBoxChanged",
        "StickyTimeBoxChanged",
        "StickyFocusBoxChanged",
        "StickyGeoBoxChanged",
        "ShowStatusBarChanged",
        "ShowAltAzFieldChanged",
        "ShowRADecFieldChanged",
        "ShowJ2000RADecFieldChanged",
        "ShowSensorFOVChanged",
        "WindowWidthChanged",
        "WindowHeightChanged",
        "KStarsGeometryChanged",
        "RunStartupWizardChanged",
        "CurrentThemeChanged",
        "CatalogFileChanged",
        "ShowCatalogChanged",
        "ShowCatalogNamesChanged",
        "ResolveNamesOnlineChanged",
        "DSOCachePercentageChanged",
        "DSOMinZoomFactorChanged",
        "DSOCatalogFilenameChanged",
        "DSODefaultCatalogFilenameChanged",
        "INDIWindowWidthChanged",
        "INDIWindowHeightChanged",
        "INDIWindowGeometryChanged",
        "useGeographicUpdateChanged",
        "useTimeUpdateChanged",
        "independentWindowINDIChanged",
        "showTargetCrosshairChanged",
        "showINDIMessagesChanged",
        "showINDIwindowInitiallyChanged",
        "maxFocusFrameFilesChanged",
        "messageNotificationINDIChanged",
        "timeSourceChanged",
        "locationSourceChanged",
        "useExternalSkyMapChanged",
        "fitsDirChanged",
        "serverTransferBufferSizeChanged",
        "serverPortStartChanged",
        "serverPortEndChanged",
        "indiServerChanged",
        "indiServerIsInternalChanged",
        "indiDriversDirChanged",
        "indiDriversAreInternalChanged",
        "streamWindowWidthChanged",
        "streamWindowHeightChanged",
        "INDIMountLoggingChanged",
        "INDIFocuserLoggingChanged",
        "INDICCDLoggingChanged",
        "INDIFilterWheelLoggingChanged",
        "INDIDomeLoggingChanged",
        "INDIDetectorLoggingChanged",
        "INDIWeatherLoggingChanged",
        "INDIAuxiliaryLoggingChanged",
        "INDIRotatorLoggingChanged",
        "INDIGPSLoggingChanged",
        "INDIAOLoggingChanged",
        "CityNameChanged",
        "ProvinceNameChanged",
        "CountryNameChanged",
        "LongitudeChanged",
        "LatitudeChanged",
        "ElevationChanged",
        "TimeZoneChanged",
        "DSTChanged",
        "UseAnimatedSlewingChanged",
        "LeftClickSelectsObjectChanged",
        "DefaultCursorChanged",
        "FOVNamesChanged",
        "FadePlanetTrailsChanged",
        "FocusRAChanged",
        "FocusDecChanged",
        "FocusObjectChanged",
        "IsTrackingChanged",
        "HideOnSlewChanged",
        "HideCBoundsChanged",
        "HideCLinesChanged",
        "SkyCultureChanged",
        "HideCNamesChanged",
        "HideGridsChanged",
        "HideMilkyWayChanged",
        "HideOtherChanged",
        "HidePlanetsChanged",
        "HideStarsChanged",
        "HideLabelsChanged",
        "ShowAsteroidsChanged",
        "ShowAsteroidNamesChanged",
        "OrbitalElementsAutoUpdateChanged",
        "ShowCometsChanged",
        "ShowCometComasChanged",
        "ShowCometNamesChanged",
        "ShowSupernovaeChanged",
        "ShowSupernovaNamesChanged",
        "MagnitudeLimitShowSupernovaeChanged",
        "SupernovaDetectionAgeChanged",
        "SupernovaDownloadUrlChanged",
        "LimitSupernovaeByZoomChanged",
        "SupernovaeHostOnlyChanged",
        "SupernovaeClassifiedOnlyChanged",
        "ShowSupernovaAlertsChanged",
        "MagnitudeLimitAlertSupernovaeChanged",
        "ShowCBoundsChanged",
        "ShowHighlightedCBoundChanged",
        "ShowCLinesChanged",
        "ShowConstellationArtChanged",
        "ShowCNamesChanged",
        "ShowDeepSkyChanged",
        "ShowEclipticChanged",
        "ShowEquatorChanged",
        "AutoSelectGridChanged",
        "ShowEquatorialGridChanged",
        "ShowHorizontalGridChanged",
        "ShowLocalMeridianChanged",
        "ShowGroundChanged",
        "ShowHorizonChanged",
        "ShowFlagsChanged",
        "SimulateDaytimeChanged",
        "ShowOtherChanged",
        "ShowMilkyWayChanged",
        "FillMilkyWayChanged",
        "ShowSolarSystemChanged",
        "ShowPlanetImagesChanged",
        "ShowPlanetNamesChanged",
        "ShowSunChanged",
        "SunScaleChanged",
        "ShowMoonChanged",
        "MoonScaleChanged",
        "ShowMercuryChanged",
        "ShowVenusChanged",
        "ShowMarsChanged",
        "ShowJupiterChanged",
        "ShowSaturnChanged",
        "ShowUranusChanged",
        "ShowNeptuneChanged",
        "ShowPlutoChanged",
        "ShowStarsChanged",
        "ShowStarMagnitudesChanged",
        "ShowStarsOverHIPSChanged",
        "ShowStarNamesChanged",
        "ShowDeepSkyMagnitudesChanged",
        "ShowDeepSkyNamesChanged",
        "ShowMosaicPanelChanged",
        "SlewTimeScaleChanged",
        "BoxBGModeChanged",
        "ProjectionChanged",
        "UseAbbrevConstellNamesChanged",
        "UseLatinConstellNamesChanged",
        "UseLocalConstellNamesChanged",
        "UseAltAzChanged",
        "UseAutoLabelChanged",
        "UseAutoTrailChanged",
        "UseHoverLabelChanged",
        "UseRefractionChanged",
        "UseRelativisticChanged",
        "UseAntialiasChanged",
        "ZoomFactorChanged",
        "SkyRotationChanged",
        "MirrorSkyMapChanged",
        "ErectObserverCorrectionChanged",
        "ZoomScrollFactorChanged",
        "MagLimitAsteroidChanged",
        "MagLimitAsteroidDownloadChanged",
        "AsteroidLabelDensityChanged",
        "MagLimitDrawDeepSkyChanged",
        "MagLimitDrawDeepSkyZoomOutChanged",
        "ShowUnknownMagObjectsChanged",
        "ShowInlineImagesChanged",
        "StarDensityChanged",
        "MagLimitHideStarChanged",
        "StarLabelDensityChanged",
        "DeepSkyLabelDensityChanged",
        "DeepSkyLongLabelsChanged",
        "LabelFontScalingChanged",
        "MaxRadCometNameChanged",
        "UseGLChanged",
        "RunClockChanged",
        "ImagingPlannerAcceptOpenClusterChanged",
        "ImagingPlannerAcceptNebulaChanged",
        "ImagingPlannerAcceptGlobularClusterChanged",
        "ImagingPlannerAcceptPlanetaryChanged",
        "ImagingPlannerAcceptSupernovaRemnantChanged",
        "ImagingPlannerAcceptGalaxyChanged",
        "ImagingPlannerAcceptGalaxyClusterChanged",
        "ImagingPlannerAcceptDarkNebulaChanged",
        "ImagingPlannerAcceptOtherChanged",
        "AstrobinAwardChanged",
        "AstrobinMinRadiusChanged",
        "AstrobinMaxRadiusChanged",
        "ImagingPlannerUseArtificialHorizonChanged",
        "ImagingPlannerMinHoursChanged",
        "ImagingPlannerMinAltitudeChanged",
        "ImagingPlannerMinMoonSeparationChanged",
        "ImagingPlannerMaxMoonAltitudeChanged",
        "ImagingPlannerShowPickedChanged",
        "ImagingPlannerShowNotPickedChanged",
        "ImagingPlannerDontCarePickedChanged",
        "ImagingPlannerShowKeywordChanged",
        "ImagingPlannerShowNotKeywordChanged",
        "ImagingPlannerDontCareKeywordChanged",
        "ImagingPlannerKeywordChanged",
        "ImagingPlannerShowImagedChanged",
        "ImagingPlannerShowNotImagedChanged",
        "ImagingPlannerDontCareImagedChanged",
        "ImagingPlannerShowAddedChanged",
        "ImagingPlannerShowNotAddedChanged",
        "ImagingPlannerDontCareAddedChanged",
        "ImagingPlannerShowIgnoredChanged",
        "ImagingPlannerShowNotIgnoredChanged",
        "ImagingPlannerDontCareIgnoredChanged",
        "ImagingPlannerHideAstrobinDetailsChanged",
        "ImagingPlannerHideFiltersChanged",
        "ImagingPlannerHideImageChanged",
        "ImagingPlannerHideAltitudeGraphChanged",
        "ImagingPlannerCatalogPathChanged",
        "ImagingPlannerCenterOnSkyMapChanged",
        "ImagingPlannerIndependentWindowChanged",
        "ImagingPlannerStartSolvingImmediatelyChanged",
        "ObsListSymbolChanged",
        "ObsListTextChanged",
        "ObsListPreferDSSChanged",
        "ObsListPreferSDSSChanged",
        "ObsListDemoteHoleChanged",
        "ObsListHoleSizeChanged",
        "ObsListCoverageChanged",
        "ColorSchemeFileChanged",
        "StarColorModeChanged",
        "StarColorIntensityChanged",
        "DomeSlitInvertedChanged",
        "AngularRulerColorChanged",
        "BoxBGColorChanged",
        "BoxGrabColorChanged",
        "BoxTextColorChanged",
        "CBoundColorChanged",
        "CBoundHighColorChanged",
        "CLineColorChanged",
        "CNameColorChanged",
        "CompassColorChanged",
        "EclipticColorChanged",
        "EquatorColorChanged",
        "EquatorialGridColorChanged",
        "HorizontalGridColorChanged",
        "SpecialObjectColorChanged",
        "HorizonColorChanged",
        "LocalMeridianColorChanged",
        "MilkyWayWColorChanged",
        "StarNameColorChanged",
        "DeepSkyNameColorChanged",
        "PlanetNameColorChanged",
        "PlanetTrailColorChanged",
        "SkyColorChanged",
        "SkyColorDaytimeChanged",
        "ArtificialHorizonColorChanged",
        "TelescopeTargetColorChanged",
        "VisibleSatColorChanged",
        "SatColorChanged",
        "SatLabelColorChanged",
        "SupernovaColorChanged",
        "AsteroidColorChanged",
        "UserLabelColorChanged",
        "RAGuideColorChanged",
        "DEGuideColorChanged",
        "SolverFOVColorChanged",
        "xplanetIsInternalChanged",
        "XplanetPathChanged",
        "XplanetUseFIFOChanged",
        "XplanetTimeoutChanged",
        "XplanetAnimationDelayChanged",
        "XplanetWidthChanged",
        "XplanetHeightChanged",
        "XplanetLabelChanged",
        "XplanetLabelLocalTimeChanged",
        "XplanetLabelGMTChanged",
        "XplanetLabelStringChanged",
        "XplanetFontSizeChanged",
        "XplanetColorChanged",
        "XplanetDateFormatChanged",
        "XplanetLabelTLChanged",
        "XplanetLabelTRChanged",
        "XplanetLabelBRChanged",
        "XplanetLabelBLChanged",
        "XplanetGlareChanged",
        "XplanetRandomChanged",
        "XplanetLatLongChanged",
        "XplanetLatitudeChanged",
        "XplanetLongitudeChanged",
        "XplanetProjectionChanged",
        "XplanetBackgroundChanged",
        "XplanetBackgroundImageChanged",
        "XplanetBackgroundImagePathChanged",
        "XplanetBackgroundColorChanged",
        "XplanetBackgroundColorValueChanged",
        "XplanetMagnitudeChanged",
        "XplanetArcFileChanged",
        "XplanetArcFilePathChanged",
        "XplanetConfigFileChanged",
        "XplanetConfigFilePathChanged",
        "XplanetFOVChanged",
        "XplanetMarkerFileChanged",
        "XplanetMarkerFilePathChanged",
        "XplanetMarkerBoundsChanged",
        "XplanetMarkerBoundsPathChanged",
        "XplanetStarmapChanged",
        "XplanetStarmapPathChanged",
        "XplanetQualityChanged",
        "ShowSatellitesChanged",
        "ShowVisibleSatellitesChanged",
        "DrawSatellitesLikeStarsChanged",
        "ShowSatellitesLabelsChanged",
        "SelectedSatellitesChanged",
        "KStarsFirstRunChanged",
        "AlwaysRecomputeCoordinatesChanged",
        "DefaultDSSImageSizeChanged",
        "DSSPaddingChanged",
        "VerboseLoggingChanged",
        "RegularLoggingChanged",
        "DisableLoggingChanged",
        "LogToDefaultChanged",
        "LogToFileChanged",
        "FITSLoggingChanged",
        "INDILoggingChanged",
        "CaptureLoggingChanged",
        "FocusLoggingChanged",
        "SaveGuideImagesChanged",
        "SaveAlignImagesChanged",
        "SaveFailedAlignImagesChanged",
        "DontSyncToRealTimeChanged",
        "GuideLoggingChanged",
        "AlignmentLoggingChanged",
        "MountLoggingChanged",
        "ObservatoryLoggingChanged",
        "ImageDebayerEngineChanged",
        "ImageDebayerAlgoChanged",
        "StackDebayerEngineChanged",
        "StackDebayerAlgoChanged",
        "FITSWindowGeometryChanged",
        "useFITSViewerChanged",
        "singlePreviewFITSChanged",
        "singleWindowCapturedFITSChanged",
        "singleWindowOpenedFITSChanged",
        "focusFITSOnNewImageChanged",
        "independentWindowFITSChanged",
        "liveStackerOwnProcessChanged",
        "AutoDebayerChanged",
        "Auto3DCubeChanged",
        "AutoHFRChanged",
        "QuickHFRChanged",
        "StellarSolverPartitionChanged",
        "AutoWCSChanged",
        "LimitedResourcesModeChanged",
        "NonLinearHistogramChanged",
        "HIPSOpacityChanged",
        "HIPSOffsetXChanged",
        "HIPSOffsetYChanged",
        "FitsSolverProfileChanged",
        "FitsSolverModuleChanged",
        "FitsSolverProfileIndecesChanged",
        "FitsCatalogChanged",
        "FitsCatObjShowNamesChanged",
        "FitsSolverUseScaleChanged",
        "FitsSolverUsePositionChanged",
        "FitsSolverScaleChanged",
        "FitsSolverImageScaleUnitsChanged",
        "FitsSolverRadiusChanged",
        "fitsLSHideGeneralChanged",
        "fitsLSHideCalibrationChanged",
        "fitsLSHideAlignmentChanged",
        "fitsLSHideStackingChanged",
        "fitsLSHidePostProcChanged",
        "fitsLSCalcSNRChanged",
        "fitsLSMasterDarkChanged",
        "fitsLSMasterFlatChanged",
        "fitsLSHotPixelsChanged",
        "fitsLSColdPixelsChanged",
        "fitsLSAlignMethodChanged",
        "fitsLSNumInMemChanged",
        "fitsLSDownscaleChanged",
        "fitsLSWeightingChanged",
        "fitsLSNormalizationChanged",
        "fitsLSStackingMethodChanged",
        "fitsLSLowSigmaChanged",
        "fitsLSHighSigmaChanged",
        "fitsLSWinsorCutoffChanged",
        "fitsLSIterationsChanged",
        "fitsLSKappaChanged",
        "fitsLSAlphaChanged",
        "fitsLSSigmaChanged",
        "fitsPSFUpdateChanged",
        "fitsLSPostProcChanged",
        "fitsLSGradientAmtChanged",
        "fitsLSDeconvAmtChanged",
        "fitsLSPSFSigmaChanged",
        "fitsLSDenoiseAmtChanged",
        "fitsLSSharpenAmtChanged",
        "fitsLSSharpenKernalChanged",
        "fitsLSSharpenSigmaChanged",
        "fitsLSMWindowGeometryChanged",
        "fitsLSMVisibleColumnsChanged",
        "fitsLSMColumnWidthsChanged",
        "fitsLSMSortColumnChanged",
        "fitsLSMSortOrderChanged",
        "fitsLSMHighlightingChanged",
        "fitsLSWebcastTitleChanged",
        "fitsLSWebcastLogoLChanged",
        "fitsLSWebcastLogoRChanged",
        "fitsLSWebcastPortChanged",
        "fitsLSWebcastThrottleChanged",
        "BortleClassChanged",
        "TelescopeCheckChanged",
        "BinocularsCheckChanged",
        "BinocularsApertureChanged",
        "ScopeListIndexChanged",
        "EkosWindowWidthChanged",
        "EkosWindowHeightChanged",
        "EkosGeometryChanged",
        "EkosTopIconsChanged",
        "EkosLeftIconsChanged",
        "independentWindowEkosChanged",
        "profileChanged",
        "neverLoadConfigChanged",
        "loadConfigOnConnectionChanged",
        "loadDefaultConfigChanged",
        "autoLoadSerialAssistantChanged",
        "RememberCredentialsChanged",
        "AutoStartEkosLiveChanged",
        "EkosLiveUsernameChanged",
        "EkosLiveObservatoryChanged",
        "EkosLiveOfflineServerChanged",
        "EkosLiveOnlineServerChanged",
        "EkosLiveSoundChanged",
        "EkosLiveNotificationsChanged",
        "EkosLiveCloudChanged",
        "MaxDarkTemperatureDiffChanged",
        "shutterfulCCDsChanged",
        "shutterlessCCDsChanged",
        "DarkLibraryDurationChanged",
        "UseGraphicalCountsDisplayChanged",
        "MinimumAltLimitChanged",
        "MaximumAltLimitChanged",
        "EnableAltitudeLimitsChanged",
        "EnableAltitudeLimitsTrackingOnlyChanged",
        "ConfirmBelowHorizonChanged",
        "MeridianFlipOffsetDegreesChanged",
        "MaximumHaLimitChanged",
        "EnableHaLimitChanged",
        "ExecuteMeridianFlipChanged",
        "LeftRightReversedChanged",
        "UpDownReversedChanged",
        "ParkEveryDayChanged",
        "ParkTimeChanged",
        "DefaultObserverChanged",
        "SyncFOVPAChanged",
        "PAMultiplierChanged",
        "PAOffsetChanged",
        "PAPierSideChanged",
        "GuideDeviationChanged",
        "GuideDeviationRepsChanged",
        "StartGuideDeviationChanged",
        "GuideDitherPerJobFrequencyChanged",
        "HFRDeviationChanged",
        "MaxFocusTemperatureDeltaChanged",
        "AutoDarkChanged",
        "EnforceGuideDeviationChanged",
        "EnforceAutofocusHFRChanged",
        "EnforceAutofocusOnTemperatureChanged",
        "EnforceRefocusEveryNChanged",
        "RefocusEveryNChanged",
        "RefocusAfterMeridianFlipChanged",
        "ResetMountModelAfterMeridianChanged",
        "ForcedFlipChanged",
        "CalibrationADUValueChanged",
        "CalibrationADUValueToleranceChanged",
        "CalibrationPreActionIndexChanged",
        "CalibrationFlatDurationIndexChanged",
        "CalibrationWallAzChanged",
        "CalibrationWallAltChanged",
        "MaxTemperatureDiffChanged",
        "MaxStartGuiderDriftChanged",
        "EnforceStartGuiderDriftChanged",
        "GuidingSettleChanged",
        "AlwaysResetSequenceWhenStartingChanged",
        "FlatSyncFocusChanged",
        "HFRThresholdPercentageChanged",
        "HFRCheckAlgorithmChanged",
        "InSequenceCheckFramesChanged",
        "AutoStretchChanged",
        "StretchPreviewSamplingChanged",
        "Clipping64KValueChanged",
        "Clipping256ValueChanged",
        "AdaptiveSamplingChanged",
        "useSummaryPreviewChanged",
        "useDSLRImageViewerChanged",
        "ForceDSLRPresetsChanged",
        "CaptureDirectoryChanged",
        "PlaceholderFormatChanged",
        "RemoteCaptureDirectoryChanged",
        "ManualCoverTimeoutChanged",
        "CaptureOperationsTimeoutChanged",
        "MinFlipDurationChanged",
        "CapturePositionChanged",
        "CaptureTrainIDChanged",
        "CaptureCalibrationWallChanged",
        "CaptureCalibrationParkMountChanged",
        "CaptureCalibrationParkDomeChanged",
        "CaptureCalibrationUseManualChanged",
        "CaptureCalibrationUseADUChanged",
        "CaptureCalibrationADUValueChanged",
        "CaptureCalibrationADUToleranceChanged",
        "CaptureCalibrationSkyFlatsChanged",
        "AbsTicksSpinChanged",
        "FocusExposureChanged",
        "FocusBinningChanged",
        "FocusGainChanged",
        "FocusISOChanged",
        "DefaultFocusTemperatureSourceChanged",
        "FocusFilterChanged",
        "UseFocusDarkFrameChanged",
        "FocusSubFrameChanged",
        "FocusBoxSizeChanged",
        "FocusUseFullFieldChanged",
        "FocusNoMaskRBChanged",
        "focusRingMaskRBChanged",
        "focusMosaicMaskRBChanged",
        "FocusFullFieldInnerRadiusChanged",
        "FocusFullFieldOuterRadiusChanged",
        "FocusMosaicTileWidthChanged",
        "focusMosaicSpaceChanged",
        "FocusAutoStarEnabledChanged",
        "FocusSuspendGuidingChanged",
        "FocusGuideSettleTimeChanged",
        "FocusUnitsChanged",
        "FocusAdaptiveChanged",
        "focusAdaptiveMinMoveChanged",
        "FocusAdaptStartChanged",
        "focusAdaptiveMaxMoveChanged",
        "FocusDetectionChanged",
        "FocusSEPProfileChanged",
        "FocusAlgorithmChanged",
        "FocusCurveFitChanged",
        "FocusStarMeasureChanged",
        "FocusStarPSFChanged",
        "FocusUseWeightsChanged",
        "FocusR2LimitChanged",
        "FocusRefineCurveFitChanged",
        "focusFramesCountChanged",
        "focusHFRFramesCountChanged",
        "FocusMultiRowAverageChanged",
        "FocusGaussianSigmaChanged",
        "FocusThresholdChanged",
        "FocusDenoiseChanged",
        "FocusDonutChanged",
        "FocusTimeDilationChanged",
        "focusOutlierRejectionChanged",
        "focusScanStartPosChanged",
        "focusScanAlwaysOnChanged",
        "focusScanDatapointsChanged",
        "focusScanStepSizeFactorChanged",
        "FocusGaussianKernelSizeChanged",
        "FocusToleranceChanged",
        "FocusWalkChanged",
        "FocusSettleTimeChanged",
        "FocusTicksChanged",
        "FocusOutStepsChanged",
        "focusNumStepsChanged",
        "FocusMaxTravelChanged",
        "FocusMaxSingleStepChanged",
        "FocusBacklashChanged",
        "FocusAFOverscanChanged",
        "FocusOverscanDelayChanged",
        "FocusCaptureTimeoutChanged",
        "FocusMotionTimeoutChanged",
        "focusCFZAlgorithmChanged",
        "focusCFZToleranceChanged",
        "focusCFZTauChanged",
        "focusCFZDisplayVCurveChanged",
        "focusCFZWavelengthChanged",
        "focusCFZApertureChanged",
        "focusCFZFNumberChanged",
        "focusCFZSeeingChanged",
        "focusCFZStepSizeChanged",
        "focusAdvHelpOnlyChangesChanged",
        "focusAdvUpdateParamsChanged",
        "focusAdvFindStarsChanged",
        "focusAdvCourseAdjChanged",
        "focusAdvFineAdjChanged",
        "FocusSplitterChanged",
        "rightLayoutChanged",
        "adaptFocusBFOChanged",
        "abInsTileSelectionChanged",
        "abInsShowLabelsChanged",
        "abInsShowCFZChanged",
        "abInsOptCentresChanged",
        "abInsHSplitterChanged",
        "abInsVSplitterChanged",
        "abInsSelectionChanged",
        "abInsThemeChanged",
        "abInsLabelsChanged",
        "abInsSensorChanged",
        "abInsPetzvalWireChanged",
        "abInsPetzvalSurfaceChanged",
        "tiltPlateTypeChanged",
        "tiltRadiusChanged",
        "tiltThreadIndexChanged",
        "tiltScrewPitchChanged",
        "tiltRotationChanged",
        "tiltModeChanged",
        "tiltPlatePresentChanged",
        "FocusSextractorTypeChanged",
        "FocusOptionsProfileChanged",
        "HFRSextractorTypeChanged",
        "HFROptionsProfileChanged",
        "GuideSextractorTypeChanged",
        "GuideOptionsProfileChanged",
        "SolveSextractorTypeChanged",
        "SolverModeChanged",
        "SolverTypeChanged",
        "SolveOptionsProfileChanged",
        "LoggerLevelChanged",
        "AstrometryLogToFileChanged",
        "AstrometryLogFilepathChanged",
        "AstrometryIndexFolderListChanged",
        "AlignExposureChanged",
        "AlignBinningChanged",
        "AlignGainChanged",
        "AlignISOChanged",
        "AlignDarkFrameChanged",
        "AlignFilterChanged",
        "AlignUseCurrentFilterChanged",
        "AstrometryUseRotatorChanged",
        "AstrometryRotatorThresholdChanged",
        "AstrometryFlipRotationAllowedChanged",
        "RotatorParityReversedChanged",
        "AstrometrySolverWCSChanged",
        "AstrometrySolverOverlayChanged",
        "AstrometryDifferentialSlewingChanged",
        "AlignAccuracyThresholdChanged",
        "AlignSettlingTimeChanged",
        "AstrometryUseNoFITS2FITSChanged",
        "AstrometryUseResortChanged",
        "AstrometryUseNoVerifyChanged",
        "AstrometryUseImageScaleChanged",
        "AstrometryImageScaleLowChanged",
        "AstrometryImageScaleHighChanged",
        "AstrometryAutoUpdateImageScaleChanged",
        "AstrometryImageScaleUnitsChanged",
        "AstrometryUseDownsampleChanged",
        "AstrometryDownsampleChanged",
        "AstrometryAutoDownsampleChanged",
        "AstrometryDynamicThresholdChanged",
        "AstrometryUsePositionChanged",
        "AstrometryPositionRAChanged",
        "AstrometryPositionDEChanged",
        "AstrometryAutoUpdatePositionChanged",
        "AstrometryRadiusChanged",
        "AstrometryDetectParityChanged",
        "AstrometryCustomOptionsChanged",
        "AstrometrySolverBinaryChanged",
        "AstrometryWCSInfoChanged",
        "AstrometryConfFileChanged",
        "SextractorBinaryChanged",
        "WatneyBinaryChanged",
        "AstrometryAPIKeyChanged",
        "AstrometryAPIURLChanged",
        "AstrometryUseJPEGChanged",
        "AstrometryTimeoutChanged",
        "PAHMountSpeedChanged",
        "PAHRotaionChanged",
        "PAHRefreshAlgorithmChanged",
        "PAHDirectionChanged",
        "PAHAutoParkChanged",
        "PAHManualSlewChanged",
        "PAHExposureChanged",
        "PAHAutoPACCorrectionChanged",
        "PAHAutoChangeDirectionChanged",
        "PAHSuccessThresholdChanged",
        "PAHCorrectionTimeoutChanged",
        "GuideExposureChanged",
        "GuideDelayChanged",
        "GuiderTypeChanged",
        "GuideAlgorithmChanged",
        "RAGuidePulseAlgorithmChanged",
        "DECGuidePulseAlgorithmChanged",
        "AIGuiderWeightsFileChanged",
        "AIPredictionGainChanged",
        "AIProportionalBackoffChanged",
        "AIPIDAutoTuneChanged",
        "AIShadowModeChanged",
        "PHD2HostChanged",
        "PHD2PortChanged",
        "LinGuiderHostChanged",
        "LinGuiderPortChanged",
        "CalibrationPulseDurationChanged",
        "CalibrationMaxMoveChanged",
        "GuideSquareSizeChanged",
        "GuideBinningChanged",
        "GuideAutoStarChanged",
        "guideShowFrameChanged",
        "GuideAutoSquareSizeEnabledChanged",
        "AutoModeIterationsChanged",
        "GuideLostStarTimeoutChanged",
        "GuideCalibrationTimeoutChanged",
        "GuideMaxDeltaRMSChanged",
        "GuideMaxHFRChanged",
        "MinDetectionsSEPMultistarChanged",
        "MaxMultistarReferenceStarsChanged",
        "AlwaysInventGuideStarChanged",
        "TwoAxisEnabledChanged",
        "UseGuideHeadChanged",
        "SaveGuideLogChanged",
        "GuideDarkFrameChanged",
        "GuideSubframeChanged",
        "DitherPixelsChanged",
        "DitherFramesChanged",
        "DitherSettleChanged",
        "DitherThresholdChanged",
        "DitherTimeoutChanged",
        "DitherMaxIterationsChanged",
        "DitherNoGuidingPulseChanged",
        "DitherFailAbortsAutoGuideChanged",
        "DitherWithOnePulseChanged",
        "DitherEnabledChanged",
        "DitherNoGuidingChanged",
        "RAGuideEnabledChanged",
        "DECGuideEnabledChanged",
        "NorthDECGuideEnabledChanged",
        "SouthDECGuideEnabledChanged",
        "EastRAGuideEnabledChanged",
        "WestRAGuideEnabledChanged",
        "RAProportionalGainChanged",
        "DECProportionalGainChanged",
        "RAIntegralGainChanged",
        "DECIntegralGainChanged",
        "RAMinimumPulseArcSecChanged",
        "DECMinimumPulseArcSecChanged",
        "RAMaximumPulseArcSecChanged",
        "DECMaximumPulseArcSecChanged",
        "GPGEnabledChanged",
        "GPGDarkGuidingChanged",
        "GPGDarkGuidingIntervalChanged",
        "AIDarkGuidingChanged",
        "AIDarkGuidingIntervalChanged",
        "GPGcWeightChanged",
        "GPGMinPeriodsForInferenceChanged",
        "GPGMinMoveChanged",
        "GPGSE0KLengthScaleChanged",
        "GPGSE0KSignalVarianceChanged",
        "GPGPKLengthScaleChanged",
        "GPGPeriodChanged",
        "GPGPKSignalVarianceChanged",
        "GPGSE1KLengthScaleChanged",
        "GPGSE1KSignalVarianceChanged",
        "GPGMinPeriodsForPeriodEstimateChanged",
        "GPGPointsForApproximationChanged",
        "GPGpWeightChanged",
        "GPGEstimatePeriodChanged",
        "GuiderAccuracyThresholdChanged",
        "RADisplayedOnGuideGraphChanged",
        "DEDisplayedOnGuideGraphChanged",
        "RACorrDisplayedOnGuideGraphChanged",
        "DECorrDisplayedOnGuideGraphChanged",
        "SNRDisplayedOnGuideGraphChanged",
        "RMSDisplayedOnGuideGraphChanged",
        "RAHysteresisChanged",
        "DECHysteresisChanged",
        "SchedulerAlgorithmChanged",
        "SchedulerLoggingChanged",
        "StopEkosAfterShutdownChanged",
        "ShutdownScriptTerminatesINDIChanged",
        "CameraWarmupEnabledChanged",
        "CameraWarmupRampChanged",
        "PreemptiveShutdownChanged",
        "ResetMountModelOnAlignFailChanged",
        "ResetMountModelBeforeJobChanged",
        "ResetGuideCalibrationChanged",
        "ForceAlignmentBeforeJobChanged",
        "ReuseGuideCalibrationChanged",
        "ReverseDecOnPierSideChangeChanged",
        "GuideCalibrationBacklashChanged",
        "AssumeDecOrthogonalChanged",
        "SerializedCalibrationChanged",
        "RealignAfterCalibrationFailureChanged",
        "PreemptiveShutdownTimeChanged",
        "RememberJobProgressChanged",
        "GreedySchedulingChanged",
        "LeadTimeChanged",
        "PreDawnTimeChanged",
        "DawnOffsetChanged",
        "DuskOffsetChanged",
        "TelescopeFocalLengthChanged",
        "TelescopeFocalReducerChanged",
        "CameraPixelWidthChanged",
        "CameraPixelHeightChanged",
        "CameraWidthChanged",
        "CameraHeightChanged",
        "CameraRotationChanged",
        "ErrorHandlingStrategyChanged",
        "ErrorHandlingStrategyDelayChanged",
        "RescheduleErrorsChanged",
        "AlignCheckFrequencyChanged",
        "AlignCheckThresholdChanged",
        "SchedulerTrackStepChanged",
        "SchedulerStartupEnabledChanged",
        "SchedulerPreStartupScriptChanged",
        "SchedulerPostStartupScriptChanged",
        "SchedulerShutdownEnabledChanged",
        "SchedulerPreShutdownScriptChanged",
        "SchedulerPostShutdownScriptChanged",
        "SchedulerFocusStepChanged",
        "SchedulerGuideStepChanged",
        "SchedulerAlignStepChanged",
        "SchedulerAltitudeChanged",
        "SchedulerAltitudeValueChanged",
        "SchedulerHorizonChanged",
        "SchedulerMoonSeparationChanged",
        "SchedulerMoonSeparationValueChanged",
        "SchedulerMoonAltitudeChanged",
        "SchedulerMoonAltitudeMaxValueChanged",
        "SchedulerWeatherChanged",
        "SchedulerWeatherGracePeriodChanged",
        "SchedulerWeatherShutdownDelayChanged",
        "SchedulerSafetyMonitorConnectionStringChanged",
        "SchedulerTwilightChanged",
        "SchedulerCompleteSequencesChanged",
        "SchedulerRepeatEverythingChanged",
        "SchedulerRepeatSequencesChanged",
        "SchedulerUntilTerminatedChanged",
        "SchedulerUntilChanged",
        "SchedulerUntilValueChanged",
        "SchedulerExecutionSequencesLimitChanged",
        "AnalyzeRestartWithEkosChanged",
        "AnalyzeAlternativeDirectoryNameChanged",
        "AnalyzeHFRChanged",
        "AnalyzeNumCaptureStarsChanged",
        "AnalyzeMedianChanged",
        "AnalyzeEccentricityChanged",
        "AnalyzeTemperatureChanged",
        "FocusPositionChanged",
        "AnalyzeNumStarsChanged",
        "AnalyzeSkyBgChanged",
        "AnalyzeSNRChanged",
        "AnalyzeRAChanged",
        "AnalyzeDECChanged",
        "AnalyzeRApChanged",
        "AnalyzeDECpChanged",
        "AnalyzeDriftChanged",
        "AnalyzeRMSChanged",
        "AnalyzeTargetDistanceChanged",
        "AnalyzeRMSCChanged",
        "AnalyzeMountRAChanged",
        "AnalyzeMountDECChanged",
        "AnalyzeMountHAChanged",
        "AnalyzeAzChanged",
        "AnalyzeAltChanged",
        "AnalyzePierSideChanged",
        "AnalyzeStatsYAxisChanged",
        "LastServerChanged",
        "LastServerPortChanged",
        "LastWebManagerPortChanged",
        "HIPSMemoryCacheChanged",
        "HIPSNetCacheChanged",
        "HIPSSourceChanged",
        "HIPSBiLinearInterpolationChanged",
        "HIPSShowGridChanged",
        "HIPSPanningChanged",
        "ShowHIPSChanged",
        "HIPSUseOfflineSourceChanged",
        "HIPSOfflinePathChanged",
        "TerrainSourceChanged",
        "TerrainSourceCorrectAzChanged",
        "TerrainSourceCorrectAltChanged",
        "TerrainDownsamplingChanged",
        "TerrainPanningChanged",
        "ShowTerrainChanged",
        "TerrainSkipSpeedupChanged",
        "TerrainTransparencySpeedupChanged",
        "TerrainSmoothPixelsChanged",
        "ShowImageOverlaysChanged",
        "ShowImageOverlaysBelowCatalogsChanged",
        "ShowSelectedImageOverlayChanged",
        "ImageOverlayMaxDimensionChanged",
        "ImageOverlayTimeoutChanged",
        "ImageOverlayDefaultScaleChanged",
        "DefaultObservatoryWeatherSourceChanged",
        "warningActionsActiveChanged",
        "alertActionsActiveChanged",
        "weatherWarningCloseDomeChanged",
        "weatherWarningCloseShutterChanged",
        "weatherWarningStopSchedulerChanged",
        "weatherWarningDelayChanged",
        "weatherAlertCloseDomeChanged",
        "weatherAlertCloseShutterChanged",
        "weatherAlertStopSchedulerChanged",
        "weatherAlertDelayChanged",
        "observatoryStatusUseDomeChanged",
        "observatoryStatusUseShutterChanged",
        "observatoryStatusUseWeatherChanged",
        "weatherAutoScaleValuesChanged",
        "ASTAPExecutableChanged",
        "ASTAPDownSampleChanged",
        "ASTAPDownSampleValueChanged",
        "ASTAPSearchRadiusChanged",
        "ASTAPSearchRadiusValueChanged",
        "ASTAPUpdateFITSChanged",
        "ASTAPLargeSearchWindowChanged",
        "MosaicTransparencyAutoChanged",
        "MosaicTransparencyLevelChanged",
        "MCPEnabledChanged",
        "MCPPortChanged",
        "MCPReadOnlyModeChanged",
        "MCPDisabledToolsChanged",
        "positionTimeBox",
        "QPoint",
        "isPositionTimeBoxImmutable",
        "positionFocusBox",
        "isPositionFocusBoxImmutable",
        "positionGeoBox",
        "isPositionGeoBoxImmutable",
        "shadeTimeBox",
        "isShadeTimeBoxImmutable",
        "shadeFocusBox",
        "isShadeFocusBoxImmutable",
        "shadeGeoBox",
        "isShadeGeoBoxImmutable",
        "showInfoBoxes",
        "isShowInfoBoxesImmutable",
        "showTimeBox",
        "isShowTimeBoxImmutable",
        "showFocusBox",
        "isShowFocusBoxImmutable",
        "showGeoBox",
        "isShowGeoBoxImmutable",
        "stickyTimeBox",
        "isStickyTimeBoxImmutable",
        "stickyFocusBox",
        "isStickyFocusBoxImmutable",
        "stickyGeoBox",
        "isStickyGeoBoxImmutable",
        "showStatusBar",
        "isShowStatusBarImmutable",
        "showAltAzField",
        "isShowAltAzFieldImmutable",
        "showRADecField",
        "isShowRADecFieldImmutable",
        "showJ2000RADecField",
        "isShowJ2000RADecFieldImmutable",
        "showSensorFOV",
        "isShowSensorFOVImmutable",
        "windowWidth",
        "isWindowWidthImmutable",
        "windowHeight",
        "isWindowHeightImmutable",
        "kStarsGeometry",
        "isKStarsGeometryImmutable",
        "runStartupWizard",
        "isRunStartupWizardImmutable",
        "currentTheme",
        "isCurrentThemeImmutable",
        "catalogFile",
        "isCatalogFileImmutable",
        "showCatalog",
        "QList<int>",
        "isShowCatalogImmutable",
        "showCatalogNames",
        "isShowCatalogNamesImmutable",
        "resolveNamesOnline",
        "isResolveNamesOnlineImmutable",
        "dSOCachePercentage",
        "isDSOCachePercentageImmutable",
        "dSOMinZoomFactor",
        "isDSOMinZoomFactorImmutable",
        "dSOCatalogFilename",
        "isDSOCatalogFilenameImmutable",
        "dSODefaultCatalogFilename",
        "isDSODefaultCatalogFilenameImmutable",
        "iNDIWindowWidth",
        "isINDIWindowWidthImmutable",
        "iNDIWindowHeight",
        "isINDIWindowHeightImmutable",
        "iNDIWindowGeometry",
        "isINDIWindowGeometryImmutable",
        "useGeographicUpdate",
        "isUseGeographicUpdateImmutable",
        "useTimeUpdate",
        "isUseTimeUpdateImmutable",
        "independentWindowINDI",
        "isIndependentWindowINDIImmutable",
        "showTargetCrosshair",
        "isShowTargetCrosshairImmutable",
        "showINDIMessages",
        "isShowINDIMessagesImmutable",
        "showINDIwindowInitially",
        "isShowINDIwindowInitiallyImmutable",
        "maxFocusFrameFiles",
        "isMaxFocusFrameFilesImmutable",
        "messageNotificationINDI",
        "isMessageNotificationINDIImmutable",
        "timeSource",
        "isTimeSourceImmutable",
        "locationSource",
        "isLocationSourceImmutable",
        "useExternalSkyMap",
        "isUseExternalSkyMapImmutable",
        "fitsDir",
        "isFitsDirImmutable",
        "serverTransferBufferSize",
        "isServerTransferBufferSizeImmutable",
        "serverPortStart",
        "isServerPortStartImmutable",
        "serverPortEnd",
        "isServerPortEndImmutable",
        "indiServer",
        "isIndiServerImmutable",
        "indiServerIsInternal",
        "isIndiServerIsInternalImmutable",
        "indiDriversDir",
        "isIndiDriversDirImmutable",
        "indiDriversAreInternal",
        "isIndiDriversAreInternalImmutable",
        "streamWindowWidth",
        "isStreamWindowWidthImmutable",
        "streamWindowHeight",
        "isStreamWindowHeightImmutable",
        "iNDIMountLogging",
        "isINDIMountLoggingImmutable",
        "iNDIFocuserLogging",
        "isINDIFocuserLoggingImmutable",
        "iNDICCDLogging",
        "isINDICCDLoggingImmutable",
        "iNDIFilterWheelLogging",
        "isINDIFilterWheelLoggingImmutable",
        "iNDIDomeLogging",
        "isINDIDomeLoggingImmutable",
        "iNDIDetectorLogging",
        "isINDIDetectorLoggingImmutable",
        "iNDIWeatherLogging",
        "isINDIWeatherLoggingImmutable",
        "iNDIAuxiliaryLogging",
        "isINDIAuxiliaryLoggingImmutable",
        "iNDIRotatorLogging",
        "isINDIRotatorLoggingImmutable",
        "iNDIGPSLogging",
        "isINDIGPSLoggingImmutable",
        "iNDIAOLogging",
        "isINDIAOLoggingImmutable",
        "cityName",
        "isCityNameImmutable",
        "provinceName",
        "isProvinceNameImmutable",
        "countryName",
        "isCountryNameImmutable",
        "longitude",
        "isLongitudeImmutable",
        "latitude",
        "isLatitudeImmutable",
        "elevation",
        "isElevationImmutable",
        "timeZone",
        "isTimeZoneImmutable",
        "dST",
        "isDSTImmutable",
        "useAnimatedSlewing",
        "isUseAnimatedSlewingImmutable",
        "leftClickSelectsObject",
        "isLeftClickSelectsObjectImmutable",
        "defaultCursor",
        "isDefaultCursorImmutable",
        "fOVNames",
        "isFOVNamesImmutable",
        "fadePlanetTrails",
        "isFadePlanetTrailsImmutable",
        "focusRA",
        "isFocusRAImmutable",
        "focusDec",
        "isFocusDecImmutable",
        "focusObject",
        "isFocusObjectImmutable",
        "isTracking",
        "isIsTrackingImmutable",
        "hideOnSlew",
        "isHideOnSlewImmutable",
        "hideCBounds",
        "isHideCBoundsImmutable",
        "hideCLines",
        "isHideCLinesImmutable",
        "skyCulture",
        "isSkyCultureImmutable",
        "hideCNames",
        "isHideCNamesImmutable",
        "hideGrids",
        "isHideGridsImmutable",
        "hideMilkyWay",
        "isHideMilkyWayImmutable",
        "hideOther",
        "isHideOtherImmutable",
        "hidePlanets",
        "isHidePlanetsImmutable",
        "hideStars",
        "isHideStarsImmutable",
        "hideLabels",
        "isHideLabelsImmutable",
        "showAsteroids",
        "isShowAsteroidsImmutable",
        "showAsteroidNames",
        "isShowAsteroidNamesImmutable",
        "orbitalElementsAutoUpdate",
        "isOrbitalElementsAutoUpdateImmutable",
        "showComets",
        "isShowCometsImmutable",
        "showCometComas",
        "isShowCometComasImmutable",
        "showCometNames",
        "isShowCometNamesImmutable",
        "showSupernovae",
        "isShowSupernovaeImmutable",
        "showSupernovaNames",
        "isShowSupernovaNamesImmutable",
        "magnitudeLimitShowSupernovae",
        "isMagnitudeLimitShowSupernovaeImmutable",
        "supernovaDetectionAge",
        "isSupernovaDetectionAgeImmutable",
        "supernovaDownloadUrl",
        "isSupernovaDownloadUrlImmutable",
        "limitSupernovaeByZoom",
        "isLimitSupernovaeByZoomImmutable",
        "supernovaeHostOnly",
        "isSupernovaeHostOnlyImmutable",
        "supernovaeClassifiedOnly",
        "isSupernovaeClassifiedOnlyImmutable",
        "showSupernovaAlerts",
        "isShowSupernovaAlertsImmutable",
        "magnitudeLimitAlertSupernovae",
        "isMagnitudeLimitAlertSupernovaeImmutable",
        "showCBounds",
        "isShowCBoundsImmutable",
        "showHighlightedCBound",
        "isShowHighlightedCBoundImmutable",
        "showCLines",
        "isShowCLinesImmutable",
        "showConstellationArt",
        "isShowConstellationArtImmutable",
        "showCNames",
        "isShowCNamesImmutable",
        "showDeepSky",
        "isShowDeepSkyImmutable",
        "showEcliptic",
        "isShowEclipticImmutable",
        "showEquator",
        "isShowEquatorImmutable",
        "autoSelectGrid",
        "isAutoSelectGridImmutable",
        "showEquatorialGrid",
        "isShowEquatorialGridImmutable",
        "showHorizontalGrid",
        "isShowHorizontalGridImmutable",
        "showLocalMeridian",
        "isShowLocalMeridianImmutable",
        "showGround",
        "isShowGroundImmutable",
        "showHorizon",
        "isShowHorizonImmutable",
        "showFlags",
        "isShowFlagsImmutable",
        "simulateDaytime",
        "isSimulateDaytimeImmutable",
        "showOther",
        "isShowOtherImmutable",
        "showMilkyWay",
        "isShowMilkyWayImmutable",
        "fillMilkyWay",
        "isFillMilkyWayImmutable",
        "showSolarSystem",
        "isShowSolarSystemImmutable",
        "showPlanetImages",
        "isShowPlanetImagesImmutable",
        "showPlanetNames",
        "isShowPlanetNamesImmutable",
        "showSun",
        "isShowSunImmutable",
        "sunScale",
        "isSunScaleImmutable",
        "showMoon",
        "isShowMoonImmutable",
        "moonScale",
        "isMoonScaleImmutable",
        "showMercury",
        "isShowMercuryImmutable",
        "showVenus",
        "isShowVenusImmutable",
        "showMars",
        "isShowMarsImmutable",
        "showJupiter",
        "isShowJupiterImmutable",
        "showSaturn",
        "isShowSaturnImmutable",
        "showUranus",
        "isShowUranusImmutable",
        "showNeptune",
        "isShowNeptuneImmutable",
        "showPluto",
        "isShowPlutoImmutable",
        "showStars",
        "isShowStarsImmutable",
        "showStarMagnitudes",
        "isShowStarMagnitudesImmutable",
        "showStarsOverHIPS",
        "isShowStarsOverHIPSImmutable",
        "showStarNames",
        "isShowStarNamesImmutable",
        "showDeepSkyMagnitudes",
        "isShowDeepSkyMagnitudesImmutable",
        "showDeepSkyNames",
        "isShowDeepSkyNamesImmutable",
        "showMosaicPanel",
        "isShowMosaicPanelImmutable",
        "slewTimeScale",
        "isSlewTimeScaleImmutable",
        "boxBGMode",
        "isBoxBGModeImmutable",
        "projection",
        "isProjectionImmutable",
        "useAbbrevConstellNames",
        "isUseAbbrevConstellNamesImmutable",
        "useLatinConstellNames",
        "isUseLatinConstellNamesImmutable",
        "useLocalConstellNames",
        "isUseLocalConstellNamesImmutable",
        "useAltAz",
        "isUseAltAzImmutable",
        "useAutoLabel",
        "isUseAutoLabelImmutable",
        "useAutoTrail",
        "isUseAutoTrailImmutable",
        "useHoverLabel",
        "isUseHoverLabelImmutable",
        "useRefraction",
        "isUseRefractionImmutable",
        "useRelativistic",
        "isUseRelativisticImmutable",
        "useAntialias",
        "isUseAntialiasImmutable",
        "zoomFactor",
        "isZoomFactorImmutable",
        "skyRotation",
        "isSkyRotationImmutable",
        "mirrorSkyMap",
        "isMirrorSkyMapImmutable",
        "erectObserverCorrection",
        "isErectObserverCorrectionImmutable",
        "zoomScrollFactor",
        "isZoomScrollFactorImmutable",
        "magLimitAsteroid",
        "isMagLimitAsteroidImmutable",
        "magLimitAsteroidDownload",
        "isMagLimitAsteroidDownloadImmutable",
        "asteroidLabelDensity",
        "isAsteroidLabelDensityImmutable",
        "magLimitDrawDeepSky",
        "isMagLimitDrawDeepSkyImmutable",
        "magLimitDrawDeepSkyZoomOut",
        "isMagLimitDrawDeepSkyZoomOutImmutable",
        "showUnknownMagObjects",
        "isShowUnknownMagObjectsImmutable",
        "showInlineImages",
        "isShowInlineImagesImmutable",
        "starDensity",
        "isStarDensityImmutable",
        "magLimitHideStar",
        "isMagLimitHideStarImmutable",
        "starLabelDensity",
        "isStarLabelDensityImmutable",
        "deepSkyLabelDensity",
        "isDeepSkyLabelDensityImmutable",
        "deepSkyLongLabels",
        "isDeepSkyLongLabelsImmutable",
        "labelFontScaling",
        "isLabelFontScalingImmutable",
        "maxRadCometName",
        "isMaxRadCometNameImmutable",
        "useGL",
        "isUseGLImmutable",
        "runClock",
        "isRunClockImmutable",
        "imagingPlannerAcceptOpenCluster",
        "isImagingPlannerAcceptOpenClusterImmutable",
        "imagingPlannerAcceptNebula",
        "isImagingPlannerAcceptNebulaImmutable",
        "imagingPlannerAcceptGlobularCluster",
        "isImagingPlannerAcceptGlobularClusterImmutable",
        "imagingPlannerAcceptPlanetary",
        "isImagingPlannerAcceptPlanetaryImmutable",
        "imagingPlannerAcceptSupernovaRemnant",
        "isImagingPlannerAcceptSupernovaRemnantImmutable",
        "imagingPlannerAcceptGalaxy",
        "isImagingPlannerAcceptGalaxyImmutable",
        "imagingPlannerAcceptGalaxyCluster",
        "isImagingPlannerAcceptGalaxyClusterImmutable",
        "imagingPlannerAcceptDarkNebula",
        "isImagingPlannerAcceptDarkNebulaImmutable",
        "imagingPlannerAcceptOther",
        "isImagingPlannerAcceptOtherImmutable",
        "astrobinAward",
        "isAstrobinAwardImmutable",
        "astrobinMinRadius",
        "isAstrobinMinRadiusImmutable",
        "astrobinMaxRadius",
        "isAstrobinMaxRadiusImmutable",
        "imagingPlannerUseArtificialHorizon",
        "isImagingPlannerUseArtificialHorizonImmutable",
        "imagingPlannerMinHours",
        "isImagingPlannerMinHoursImmutable",
        "imagingPlannerMinAltitude",
        "isImagingPlannerMinAltitudeImmutable",
        "imagingPlannerMinMoonSeparation",
        "isImagingPlannerMinMoonSeparationImmutable",
        "imagingPlannerMaxMoonAltitude",
        "isImagingPlannerMaxMoonAltitudeImmutable",
        "imagingPlannerShowPicked",
        "isImagingPlannerShowPickedImmutable",
        "imagingPlannerShowNotPicked",
        "isImagingPlannerShowNotPickedImmutable",
        "imagingPlannerDontCarePicked",
        "isImagingPlannerDontCarePickedImmutable",
        "imagingPlannerShowKeyword",
        "isImagingPlannerShowKeywordImmutable",
        "imagingPlannerShowNotKeyword",
        "isImagingPlannerShowNotKeywordImmutable",
        "imagingPlannerDontCareKeyword",
        "isImagingPlannerDontCareKeywordImmutable",
        "imagingPlannerKeyword",
        "isImagingPlannerKeywordImmutable",
        "imagingPlannerShowImaged",
        "isImagingPlannerShowImagedImmutable",
        "imagingPlannerShowNotImaged",
        "isImagingPlannerShowNotImagedImmutable",
        "imagingPlannerDontCareImaged",
        "isImagingPlannerDontCareImagedImmutable",
        "imagingPlannerShowAdded",
        "isImagingPlannerShowAddedImmutable",
        "imagingPlannerShowNotAdded",
        "isImagingPlannerShowNotAddedImmutable",
        "imagingPlannerDontCareAdded",
        "isImagingPlannerDontCareAddedImmutable",
        "imagingPlannerShowIgnored",
        "isImagingPlannerShowIgnoredImmutable",
        "imagingPlannerShowNotIgnored",
        "isImagingPlannerShowNotIgnoredImmutable",
        "imagingPlannerDontCareIgnored",
        "isImagingPlannerDontCareIgnoredImmutable",
        "imagingPlannerHideAstrobinDetails",
        "isImagingPlannerHideAstrobinDetailsImmutable",
        "imagingPlannerHideFilters",
        "isImagingPlannerHideFiltersImmutable",
        "imagingPlannerHideImage",
        "isImagingPlannerHideImageImmutable",
        "imagingPlannerHideAltitudeGraph",
        "isImagingPlannerHideAltitudeGraphImmutable",
        "imagingPlannerCatalogPath",
        "isImagingPlannerCatalogPathImmutable",
        "imagingPlannerCenterOnSkyMap",
        "isImagingPlannerCenterOnSkyMapImmutable",
        "imagingPlannerIndependentWindow",
        "isImagingPlannerIndependentWindowImmutable",
        "imagingPlannerStartSolvingImmediately",
        "isImagingPlannerStartSolvingImmediatelyImmutable",
        "obsListSymbol",
        "isObsListSymbolImmutable",
        "obsListText",
        "isObsListTextImmutable",
        "obsListPreferDSS",
        "isObsListPreferDSSImmutable",
        "obsListPreferSDSS",
        "isObsListPreferSDSSImmutable",
        "obsListDemoteHole",
        "isObsListDemoteHoleImmutable",
        "obsListHoleSize",
        "isObsListHoleSizeImmutable",
        "obsListCoverage",
        "isObsListCoverageImmutable",
        "colorSchemeFile",
        "isColorSchemeFileImmutable",
        "starColorMode",
        "isStarColorModeImmutable",
        "starColorIntensity",
        "isStarColorIntensityImmutable",
        "domeSlitInverted",
        "isDomeSlitInvertedImmutable",
        "angularRulerColor",
        "isAngularRulerColorImmutable",
        "boxBGColor",
        "isBoxBGColorImmutable",
        "boxGrabColor",
        "isBoxGrabColorImmutable",
        "boxTextColor",
        "isBoxTextColorImmutable",
        "cBoundColor",
        "isCBoundColorImmutable",
        "cBoundHighColor",
        "isCBoundHighColorImmutable",
        "cLineColor",
        "isCLineColorImmutable",
        "cNameColor",
        "isCNameColorImmutable",
        "compassColor",
        "isCompassColorImmutable",
        "eclipticColor",
        "isEclipticColorImmutable",
        "equatorColor",
        "isEquatorColorImmutable",
        "equatorialGridColor",
        "isEquatorialGridColorImmutable",
        "horizontalGridColor",
        "isHorizontalGridColorImmutable",
        "specialObjectColor",
        "isSpecialObjectColorImmutable",
        "horizonColor",
        "isHorizonColorImmutable",
        "localMeridianColor",
        "isLocalMeridianColorImmutable",
        "milkyWayWColor",
        "isMilkyWayWColorImmutable",
        "starNameColor",
        "isStarNameColorImmutable",
        "deepSkyNameColor",
        "isDeepSkyNameColorImmutable",
        "planetNameColor",
        "isPlanetNameColorImmutable",
        "planetTrailColor",
        "isPlanetTrailColorImmutable",
        "skyColor",
        "isSkyColorImmutable",
        "skyColorDaytime",
        "isSkyColorDaytimeImmutable",
        "artificialHorizonColor",
        "isArtificialHorizonColorImmutable",
        "telescopeTargetColor",
        "isTelescopeTargetColorImmutable",
        "visibleSatColor",
        "isVisibleSatColorImmutable",
        "satColor",
        "isSatColorImmutable",
        "satLabelColor",
        "isSatLabelColorImmutable",
        "supernovaColor",
        "isSupernovaColorImmutable",
        "asteroidColor",
        "isAsteroidColorImmutable",
        "userLabelColor",
        "isUserLabelColorImmutable",
        "rAGuideColor",
        "isRAGuideColorImmutable",
        "dEGuideColor",
        "isDEGuideColorImmutable",
        "solverFOVColor",
        "isSolverFOVColorImmutable",
        "xplanetIsInternal",
        "isXplanetIsInternalImmutable",
        "xplanetPath",
        "isXplanetPathImmutable",
        "xplanetUseFIFO",
        "isXplanetUseFIFOImmutable",
        "xplanetTimeout",
        "isXplanetTimeoutImmutable",
        "xplanetAnimationDelay",
        "isXplanetAnimationDelayImmutable",
        "xplanetWidth",
        "isXplanetWidthImmutable",
        "xplanetHeight",
        "isXplanetHeightImmutable",
        "xplanetLabel",
        "isXplanetLabelImmutable",
        "xplanetLabelLocalTime",
        "isXplanetLabelLocalTimeImmutable",
        "xplanetLabelGMT",
        "isXplanetLabelGMTImmutable",
        "xplanetLabelString",
        "isXplanetLabelStringImmutable",
        "xplanetFontSize",
        "isXplanetFontSizeImmutable",
        "xplanetColor",
        "isXplanetColorImmutable",
        "xplanetDateFormat",
        "isXplanetDateFormatImmutable",
        "xplanetLabelTL",
        "isXplanetLabelTLImmutable",
        "xplanetLabelTR",
        "isXplanetLabelTRImmutable",
        "xplanetLabelBR",
        "isXplanetLabelBRImmutable",
        "xplanetLabelBL",
        "isXplanetLabelBLImmutable",
        "xplanetGlare",
        "isXplanetGlareImmutable",
        "xplanetRandom",
        "isXplanetRandomImmutable",
        "xplanetLatLong",
        "isXplanetLatLongImmutable",
        "xplanetLatitude",
        "isXplanetLatitudeImmutable",
        "xplanetLongitude",
        "isXplanetLongitudeImmutable",
        "xplanetProjection",
        "isXplanetProjectionImmutable",
        "xplanetBackground",
        "isXplanetBackgroundImmutable",
        "xplanetBackgroundImage",
        "isXplanetBackgroundImageImmutable",
        "xplanetBackgroundImagePath",
        "isXplanetBackgroundImagePathImmutable",
        "xplanetBackgroundColor",
        "isXplanetBackgroundColorImmutable",
        "xplanetBackgroundColorValue",
        "isXplanetBackgroundColorValueImmutable",
        "xplanetMagnitude",
        "isXplanetMagnitudeImmutable",
        "xplanetArcFile",
        "isXplanetArcFileImmutable",
        "xplanetArcFilePath",
        "isXplanetArcFilePathImmutable",
        "xplanetConfigFile",
        "isXplanetConfigFileImmutable",
        "xplanetConfigFilePath",
        "isXplanetConfigFilePathImmutable",
        "xplanetFOV",
        "isXplanetFOVImmutable",
        "xplanetMarkerFile",
        "isXplanetMarkerFileImmutable",
        "xplanetMarkerFilePath",
        "isXplanetMarkerFilePathImmutable",
        "xplanetMarkerBounds",
        "isXplanetMarkerBoundsImmutable",
        "xplanetMarkerBoundsPath",
        "isXplanetMarkerBoundsPathImmutable",
        "xplanetStarmap",
        "isXplanetStarmapImmutable",
        "xplanetStarmapPath",
        "isXplanetStarmapPathImmutable",
        "xplanetQuality",
        "isXplanetQualityImmutable",
        "showSatellites",
        "isShowSatellitesImmutable",
        "showVisibleSatellites",
        "isShowVisibleSatellitesImmutable",
        "drawSatellitesLikeStars",
        "isDrawSatellitesLikeStarsImmutable",
        "showSatellitesLabels",
        "isShowSatellitesLabelsImmutable",
        "selectedSatellites",
        "isSelectedSatellitesImmutable",
        "kStarsFirstRun",
        "isKStarsFirstRunImmutable",
        "alwaysRecomputeCoordinates",
        "isAlwaysRecomputeCoordinatesImmutable",
        "defaultDSSImageSize",
        "isDefaultDSSImageSizeImmutable",
        "dSSPadding",
        "isDSSPaddingImmutable",
        "verboseLogging",
        "isVerboseLoggingImmutable",
        "regularLogging",
        "isRegularLoggingImmutable",
        "disableLogging",
        "isDisableLoggingImmutable",
        "logToDefault",
        "isLogToDefaultImmutable",
        "logToFile",
        "isLogToFileImmutable",
        "fITSLogging",
        "isFITSLoggingImmutable",
        "iNDILogging",
        "isINDILoggingImmutable",
        "captureLogging",
        "isCaptureLoggingImmutable",
        "focusLogging",
        "isFocusLoggingImmutable",
        "saveGuideImages",
        "isSaveGuideImagesImmutable",
        "saveAlignImages",
        "isSaveAlignImagesImmutable",
        "saveFailedAlignImages",
        "isSaveFailedAlignImagesImmutable",
        "dontSyncToRealTime",
        "isDontSyncToRealTimeImmutable",
        "guideLogging",
        "isGuideLoggingImmutable",
        "alignmentLogging",
        "isAlignmentLoggingImmutable",
        "mountLogging",
        "isMountLoggingImmutable",
        "observatoryLogging",
        "isObservatoryLoggingImmutable",
        "imageDebayerEngine",
        "isImageDebayerEngineImmutable",
        "imageDebayerAlgo",
        "isImageDebayerAlgoImmutable",
        "stackDebayerEngine",
        "isStackDebayerEngineImmutable",
        "stackDebayerAlgo",
        "isStackDebayerAlgoImmutable",
        "fITSWindowGeometry",
        "isFITSWindowGeometryImmutable",
        "useFITSViewer",
        "isUseFITSViewerImmutable",
        "singlePreviewFITS",
        "isSinglePreviewFITSImmutable",
        "singleWindowCapturedFITS",
        "isSingleWindowCapturedFITSImmutable",
        "singleWindowOpenedFITS",
        "isSingleWindowOpenedFITSImmutable",
        "focusFITSOnNewImage",
        "isFocusFITSOnNewImageImmutable",
        "independentWindowFITS",
        "isIndependentWindowFITSImmutable",
        "liveStackerOwnProcess",
        "isLiveStackerOwnProcessImmutable",
        "autoDebayer",
        "isAutoDebayerImmutable",
        "auto3DCube",
        "isAuto3DCubeImmutable",
        "autoHFR",
        "isAutoHFRImmutable",
        "quickHFR",
        "isQuickHFRImmutable",
        "stellarSolverPartition",
        "isStellarSolverPartitionImmutable",
        "autoWCS",
        "isAutoWCSImmutable",
        "limitedResourcesMode",
        "isLimitedResourcesModeImmutable",
        "nonLinearHistogram",
        "isNonLinearHistogramImmutable",
        "hIPSOpacity",
        "isHIPSOpacityImmutable",
        "hIPSOffsetX",
        "isHIPSOffsetXImmutable",
        "hIPSOffsetY",
        "isHIPSOffsetYImmutable",
        "fitsSolverProfile",
        "isFitsSolverProfileImmutable",
        "fitsSolverModule",
        "isFitsSolverModuleImmutable",
        "fitsSolverProfileIndeces",
        "isFitsSolverProfileIndecesImmutable",
        "fitsCatalog",
        "isFitsCatalogImmutable",
        "fitsCatObjShowNames",
        "isFitsCatObjShowNamesImmutable",
        "fitsSolverUseScale",
        "isFitsSolverUseScaleImmutable",
        "fitsSolverUsePosition",
        "isFitsSolverUsePositionImmutable",
        "fitsSolverScale",
        "isFitsSolverScaleImmutable",
        "fitsSolverImageScaleUnits",
        "isFitsSolverImageScaleUnitsImmutable",
        "fitsSolverRadius",
        "isFitsSolverRadiusImmutable",
        "fitsLSHideGeneral",
        "isFitsLSHideGeneralImmutable",
        "fitsLSHideCalibration",
        "isFitsLSHideCalibrationImmutable",
        "fitsLSHideAlignment",
        "isFitsLSHideAlignmentImmutable",
        "fitsLSHideStacking",
        "isFitsLSHideStackingImmutable",
        "fitsLSHidePostProc",
        "isFitsLSHidePostProcImmutable",
        "fitsLSCalcSNR",
        "isFitsLSCalcSNRImmutable",
        "fitsLSMasterDark",
        "isFitsLSMasterDarkImmutable",
        "fitsLSMasterFlat",
        "isFitsLSMasterFlatImmutable",
        "fitsLSHotPixels",
        "isFitsLSHotPixelsImmutable",
        "fitsLSColdPixels",
        "isFitsLSColdPixelsImmutable",
        "fitsLSAlignMethod",
        "isFitsLSAlignMethodImmutable",
        "fitsLSNumInMem",
        "isFitsLSNumInMemImmutable",
        "fitsLSDownscale",
        "isFitsLSDownscaleImmutable",
        "fitsLSWeighting",
        "isFitsLSWeightingImmutable",
        "fitsLSNormalization",
        "isFitsLSNormalizationImmutable",
        "fitsLSStackingMethod",
        "isFitsLSStackingMethodImmutable",
        "fitsLSLowSigma",
        "isFitsLSLowSigmaImmutable",
        "fitsLSHighSigma",
        "isFitsLSHighSigmaImmutable",
        "fitsLSWinsorCutoff",
        "isFitsLSWinsorCutoffImmutable",
        "fitsLSIterations",
        "isFitsLSIterationsImmutable",
        "fitsLSKappa",
        "isFitsLSKappaImmutable",
        "fitsLSAlpha",
        "isFitsLSAlphaImmutable",
        "fitsLSSigma",
        "isFitsLSSigmaImmutable",
        "fitsPSFUpdate",
        "isFitsPSFUpdateImmutable",
        "fitsLSPostProc",
        "isFitsLSPostProcImmutable",
        "fitsLSGradientAmt",
        "isFitsLSGradientAmtImmutable",
        "fitsLSDeconvAmt",
        "isFitsLSDeconvAmtImmutable",
        "fitsLSPSFSigma",
        "isFitsLSPSFSigmaImmutable",
        "fitsLSDenoiseAmt",
        "isFitsLSDenoiseAmtImmutable",
        "fitsLSSharpenAmt",
        "isFitsLSSharpenAmtImmutable",
        "fitsLSSharpenKernal",
        "isFitsLSSharpenKernalImmutable",
        "fitsLSSharpenSigma",
        "isFitsLSSharpenSigmaImmutable",
        "fitsLSMWindowGeometry",
        "isFitsLSMWindowGeometryImmutable",
        "fitsLSMVisibleColumns",
        "isFitsLSMVisibleColumnsImmutable",
        "fitsLSMColumnWidths",
        "isFitsLSMColumnWidthsImmutable",
        "fitsLSMSortColumn",
        "isFitsLSMSortColumnImmutable",
        "fitsLSMSortOrder",
        "isFitsLSMSortOrderImmutable",
        "fitsLSMHighlighting",
        "isFitsLSMHighlightingImmutable",
        "fitsLSWebcastTitle",
        "isFitsLSWebcastTitleImmutable",
        "fitsLSWebcastLogoL",
        "isFitsLSWebcastLogoLImmutable",
        "fitsLSWebcastLogoR",
        "isFitsLSWebcastLogoRImmutable",
        "fitsLSWebcastPort",
        "isFitsLSWebcastPortImmutable",
        "fitsLSWebcastThrottle",
        "isFitsLSWebcastThrottleImmutable",
        "bortleClass",
        "isBortleClassImmutable",
        "telescopeCheck",
        "isTelescopeCheckImmutable",
        "binocularsCheck",
        "isBinocularsCheckImmutable",
        "binocularsAperture",
        "isBinocularsApertureImmutable",
        "scopeListIndex",
        "isScopeListIndexImmutable",
        "ekosWindowWidth",
        "isEkosWindowWidthImmutable",
        "ekosWindowHeight",
        "isEkosWindowHeightImmutable",
        "ekosGeometry",
        "isEkosGeometryImmutable",
        "ekosTopIcons",
        "isEkosTopIconsImmutable",
        "ekosLeftIcons",
        "isEkosLeftIconsImmutable",
        "independentWindowEkos",
        "isIndependentWindowEkosImmutable",
        "profile",
        "isProfileImmutable",
        "neverLoadConfig",
        "isNeverLoadConfigImmutable",
        "loadConfigOnConnection",
        "isLoadConfigOnConnectionImmutable",
        "loadDefaultConfig",
        "isLoadDefaultConfigImmutable",
        "autoLoadSerialAssistant",
        "isAutoLoadSerialAssistantImmutable",
        "rememberCredentials",
        "isRememberCredentialsImmutable",
        "autoStartEkosLive",
        "isAutoStartEkosLiveImmutable",
        "ekosLiveUsername",
        "isEkosLiveUsernameImmutable",
        "ekosLiveObservatory",
        "isEkosLiveObservatoryImmutable",
        "ekosLiveOfflineServer",
        "isEkosLiveOfflineServerImmutable",
        "ekosLiveOnlineServer",
        "isEkosLiveOnlineServerImmutable",
        "ekosLiveSound",
        "isEkosLiveSoundImmutable",
        "ekosLiveNotifications",
        "isEkosLiveNotificationsImmutable",
        "ekosLiveCloud",
        "isEkosLiveCloudImmutable",
        "maxDarkTemperatureDiff",
        "isMaxDarkTemperatureDiffImmutable",
        "shutterfulCCDs",
        "isShutterfulCCDsImmutable",
        "shutterlessCCDs",
        "isShutterlessCCDsImmutable",
        "darkLibraryDuration",
        "isDarkLibraryDurationImmutable",
        "useGraphicalCountsDisplay",
        "isUseGraphicalCountsDisplayImmutable",
        "minimumAltLimit",
        "isMinimumAltLimitImmutable",
        "maximumAltLimit",
        "isMaximumAltLimitImmutable",
        "enableAltitudeLimits",
        "isEnableAltitudeLimitsImmutable",
        "enableAltitudeLimitsTrackingOnly",
        "isEnableAltitudeLimitsTrackingOnlyImmutable",
        "confirmBelowHorizon",
        "isConfirmBelowHorizonImmutable",
        "meridianFlipOffsetDegrees",
        "isMeridianFlipOffsetDegreesImmutable",
        "maximumHaLimit",
        "isMaximumHaLimitImmutable",
        "enableHaLimit",
        "isEnableHaLimitImmutable",
        "executeMeridianFlip",
        "isExecuteMeridianFlipImmutable",
        "leftRightReversed",
        "isLeftRightReversedImmutable",
        "upDownReversed",
        "isUpDownReversedImmutable",
        "parkEveryDay",
        "isParkEveryDayImmutable",
        "parkTime",
        "isParkTimeImmutable",
        "defaultObserver",
        "isDefaultObserverImmutable",
        "syncFOVPA",
        "isSyncFOVPAImmutable",
        "pAMultiplier",
        "isPAMultiplierImmutable",
        "pAOffset",
        "isPAOffsetImmutable",
        "pAPierSide",
        "isPAPierSideImmutable",
        "guideDeviation",
        "isGuideDeviationImmutable",
        "guideDeviationReps",
        "isGuideDeviationRepsImmutable",
        "startGuideDeviation",
        "isStartGuideDeviationImmutable",
        "guideDitherPerJobFrequency",
        "isGuideDitherPerJobFrequencyImmutable",
        "hFRDeviation",
        "isHFRDeviationImmutable",
        "maxFocusTemperatureDelta",
        "isMaxFocusTemperatureDeltaImmutable",
        "autoDark",
        "isAutoDarkImmutable",
        "enforceGuideDeviation",
        "isEnforceGuideDeviationImmutable",
        "enforceAutofocusHFR",
        "isEnforceAutofocusHFRImmutable",
        "enforceAutofocusOnTemperature",
        "isEnforceAutofocusOnTemperatureImmutable",
        "enforceRefocusEveryN",
        "isEnforceRefocusEveryNImmutable",
        "refocusEveryN",
        "isRefocusEveryNImmutable",
        "refocusAfterMeridianFlip",
        "isRefocusAfterMeridianFlipImmutable",
        "resetMountModelAfterMeridian",
        "isResetMountModelAfterMeridianImmutable",
        "forcedFlip",
        "isForcedFlipImmutable",
        "calibrationADUValue",
        "isCalibrationADUValueImmutable",
        "calibrationADUValueTolerance",
        "isCalibrationADUValueToleranceImmutable",
        "calibrationPreActionIndex",
        "isCalibrationPreActionIndexImmutable",
        "calibrationFlatDurationIndex",
        "isCalibrationFlatDurationIndexImmutable",
        "calibrationWallAz",
        "isCalibrationWallAzImmutable",
        "calibrationWallAlt",
        "isCalibrationWallAltImmutable",
        "maxTemperatureDiff",
        "isMaxTemperatureDiffImmutable",
        "maxStartGuiderDrift",
        "isMaxStartGuiderDriftImmutable",
        "enforceStartGuiderDrift",
        "isEnforceStartGuiderDriftImmutable",
        "guidingSettle",
        "isGuidingSettleImmutable",
        "alwaysResetSequenceWhenStarting",
        "isAlwaysResetSequenceWhenStartingImmutable",
        "flatSyncFocus",
        "isFlatSyncFocusImmutable",
        "hFRThresholdPercentage",
        "isHFRThresholdPercentageImmutable",
        "hFRCheckAlgorithm",
        "isHFRCheckAlgorithmImmutable",
        "inSequenceCheckFrames",
        "isInSequenceCheckFramesImmutable",
        "autoStretch",
        "isAutoStretchImmutable",
        "stretchPreviewSampling",
        "isStretchPreviewSamplingImmutable",
        "clipping64KValue",
        "isClipping64KValueImmutable",
        "clipping256Value",
        "isClipping256ValueImmutable",
        "adaptiveSampling",
        "isAdaptiveSamplingImmutable",
        "useSummaryPreview",
        "isUseSummaryPreviewImmutable",
        "useDSLRImageViewer",
        "isUseDSLRImageViewerImmutable",
        "forceDSLRPresets",
        "isForceDSLRPresetsImmutable",
        "captureDirectory",
        "isCaptureDirectoryImmutable",
        "placeholderFormat",
        "isPlaceholderFormatImmutable",
        "remoteCaptureDirectory",
        "isRemoteCaptureDirectoryImmutable",
        "manualCoverTimeout",
        "isManualCoverTimeoutImmutable",
        "captureOperationsTimeout",
        "isCaptureOperationsTimeoutImmutable",
        "minFlipDuration",
        "isMinFlipDurationImmutable",
        "capturePosition",
        "isCapturePositionImmutable",
        "captureTrainID",
        "isCaptureTrainIDImmutable",
        "captureCalibrationWall",
        "isCaptureCalibrationWallImmutable",
        "captureCalibrationParkMount",
        "isCaptureCalibrationParkMountImmutable",
        "captureCalibrationParkDome",
        "isCaptureCalibrationParkDomeImmutable",
        "captureCalibrationUseManual",
        "isCaptureCalibrationUseManualImmutable",
        "captureCalibrationUseADU",
        "isCaptureCalibrationUseADUImmutable",
        "captureCalibrationADUValue",
        "isCaptureCalibrationADUValueImmutable",
        "captureCalibrationADUTolerance",
        "isCaptureCalibrationADUToleranceImmutable",
        "captureCalibrationSkyFlats",
        "isCaptureCalibrationSkyFlatsImmutable",
        "absTicksSpin",
        "isAbsTicksSpinImmutable",
        "focusExposure",
        "isFocusExposureImmutable",
        "focusBinning",
        "isFocusBinningImmutable",
        "focusGain",
        "isFocusGainImmutable",
        "focusISO",
        "isFocusISOImmutable",
        "defaultFocusTemperatureSource",
        "isDefaultFocusTemperatureSourceImmutable",
        "focusFilter",
        "isFocusFilterImmutable",
        "useFocusDarkFrame",
        "isUseFocusDarkFrameImmutable",
        "focusSubFrame",
        "isFocusSubFrameImmutable",
        "focusBoxSize",
        "isFocusBoxSizeImmutable",
        "focusUseFullField",
        "isFocusUseFullFieldImmutable",
        "focusNoMaskRB",
        "isFocusNoMaskRBImmutable",
        "focusRingMaskRB",
        "isFocusRingMaskRBImmutable",
        "focusMosaicMaskRB",
        "isFocusMosaicMaskRBImmutable",
        "focusFullFieldInnerRadius",
        "isFocusFullFieldInnerRadiusImmutable",
        "focusFullFieldOuterRadius",
        "isFocusFullFieldOuterRadiusImmutable",
        "focusMosaicTileWidth",
        "isFocusMosaicTileWidthImmutable",
        "focusMosaicSpace",
        "isFocusMosaicSpaceImmutable",
        "focusAutoStarEnabled",
        "isFocusAutoStarEnabledImmutable",
        "focusSuspendGuiding",
        "isFocusSuspendGuidingImmutable",
        "focusGuideSettleTime",
        "isFocusGuideSettleTimeImmutable",
        "focusUnits",
        "isFocusUnitsImmutable",
        "focusAdaptive",
        "isFocusAdaptiveImmutable",
        "focusAdaptiveMinMove",
        "isFocusAdaptiveMinMoveImmutable",
        "focusAdaptStart",
        "isFocusAdaptStartImmutable",
        "focusAdaptiveMaxMove",
        "isFocusAdaptiveMaxMoveImmutable",
        "focusDetection",
        "isFocusDetectionImmutable",
        "focusSEPProfile",
        "isFocusSEPProfileImmutable",
        "focusAlgorithm",
        "isFocusAlgorithmImmutable",
        "focusCurveFit",
        "isFocusCurveFitImmutable",
        "focusStarMeasure",
        "isFocusStarMeasureImmutable",
        "focusStarPSF",
        "isFocusStarPSFImmutable",
        "focusUseWeights",
        "isFocusUseWeightsImmutable",
        "focusR2Limit",
        "isFocusR2LimitImmutable",
        "focusRefineCurveFit",
        "isFocusRefineCurveFitImmutable",
        "focusFramesCount",
        "isFocusFramesCountImmutable",
        "focusHFRFramesCount",
        "isFocusHFRFramesCountImmutable",
        "focusMultiRowAverage",
        "isFocusMultiRowAverageImmutable",
        "focusGaussianSigma",
        "isFocusGaussianSigmaImmutable",
        "focusThreshold",
        "isFocusThresholdImmutable",
        "focusDenoise",
        "isFocusDenoiseImmutable",
        "focusDonut",
        "isFocusDonutImmutable",
        "focusTimeDilation",
        "isFocusTimeDilationImmutable",
        "focusOutlierRejection",
        "isFocusOutlierRejectionImmutable",
        "focusScanStartPos",
        "isFocusScanStartPosImmutable",
        "focusScanAlwaysOn",
        "isFocusScanAlwaysOnImmutable",
        "focusScanDatapoints",
        "isFocusScanDatapointsImmutable",
        "focusScanStepSizeFactor",
        "isFocusScanStepSizeFactorImmutable",
        "focusGaussianKernelSize",
        "isFocusGaussianKernelSizeImmutable",
        "focusTolerance",
        "isFocusToleranceImmutable",
        "focusWalk",
        "isFocusWalkImmutable",
        "focusSettleTime",
        "isFocusSettleTimeImmutable",
        "focusTicks",
        "isFocusTicksImmutable",
        "focusOutSteps",
        "isFocusOutStepsImmutable",
        "focusNumSteps",
        "isFocusNumStepsImmutable",
        "focusMaxTravel",
        "isFocusMaxTravelImmutable",
        "focusMaxSingleStep",
        "isFocusMaxSingleStepImmutable",
        "focusBacklash",
        "isFocusBacklashImmutable",
        "focusAFOverscan",
        "isFocusAFOverscanImmutable",
        "focusOverscanDelay",
        "isFocusOverscanDelayImmutable",
        "focusCaptureTimeout",
        "isFocusCaptureTimeoutImmutable",
        "focusMotionTimeout",
        "isFocusMotionTimeoutImmutable",
        "focusCFZAlgorithm",
        "isFocusCFZAlgorithmImmutable",
        "focusCFZTolerance",
        "isFocusCFZToleranceImmutable",
        "focusCFZTau",
        "isFocusCFZTauImmutable",
        "focusCFZDisplayVCurve",
        "isFocusCFZDisplayVCurveImmutable",
        "focusCFZWavelength",
        "isFocusCFZWavelengthImmutable",
        "focusCFZAperture",
        "isFocusCFZApertureImmutable",
        "focusCFZFNumber",
        "isFocusCFZFNumberImmutable",
        "focusCFZSeeing",
        "isFocusCFZSeeingImmutable",
        "focusCFZStepSize",
        "isFocusCFZStepSizeImmutable",
        "focusAdvHelpOnlyChanges",
        "isFocusAdvHelpOnlyChangesImmutable",
        "focusAdvUpdateParams",
        "isFocusAdvUpdateParamsImmutable",
        "focusAdvFindStars",
        "isFocusAdvFindStarsImmutable",
        "focusAdvCourseAdj",
        "isFocusAdvCourseAdjImmutable",
        "focusAdvFineAdj",
        "isFocusAdvFineAdjImmutable",
        "focusSplitter",
        "isFocusSplitterImmutable",
        "rightLayout",
        "isRightLayoutImmutable",
        "adaptFocusBFO",
        "isAdaptFocusBFOImmutable",
        "abInsTileSelection",
        "isAbInsTileSelectionImmutable",
        "abInsShowLabels",
        "isAbInsShowLabelsImmutable",
        "abInsShowCFZ",
        "isAbInsShowCFZImmutable",
        "abInsOptCentres",
        "isAbInsOptCentresImmutable",
        "abInsHSplitter",
        "isAbInsHSplitterImmutable",
        "abInsVSplitter",
        "isAbInsVSplitterImmutable",
        "abInsSelection",
        "isAbInsSelectionImmutable",
        "abInsTheme",
        "isAbInsThemeImmutable",
        "abInsLabels",
        "isAbInsLabelsImmutable",
        "abInsSensor",
        "isAbInsSensorImmutable",
        "abInsPetzvalWire",
        "isAbInsPetzvalWireImmutable",
        "abInsPetzvalSurface",
        "isAbInsPetzvalSurfaceImmutable",
        "tiltPlateType",
        "isTiltPlateTypeImmutable",
        "tiltRadius",
        "isTiltRadiusImmutable",
        "tiltThreadIndex",
        "isTiltThreadIndexImmutable",
        "tiltScrewPitch",
        "isTiltScrewPitchImmutable",
        "tiltRotation",
        "isTiltRotationImmutable",
        "tiltMode",
        "isTiltModeImmutable",
        "tiltPlatePresent",
        "isTiltPlatePresentImmutable",
        "focusSextractorType",
        "isFocusSextractorTypeImmutable",
        "focusOptionsProfile",
        "isFocusOptionsProfileImmutable",
        "hFRSextractorType",
        "isHFRSextractorTypeImmutable",
        "hFROptionsProfile",
        "isHFROptionsProfileImmutable",
        "guideSextractorType",
        "isGuideSextractorTypeImmutable",
        "guideOptionsProfile",
        "isGuideOptionsProfileImmutable",
        "solveSextractorType",
        "isSolveSextractorTypeImmutable",
        "solverMode",
        "isSolverModeImmutable",
        "solverType",
        "isSolverTypeImmutable",
        "solveOptionsProfile",
        "isSolveOptionsProfileImmutable",
        "loggerLevel",
        "isLoggerLevelImmutable",
        "astrometryLogToFile",
        "isAstrometryLogToFileImmutable",
        "astrometryLogFilepath",
        "isAstrometryLogFilepathImmutable",
        "astrometryIndexFolderList",
        "isAstrometryIndexFolderListImmutable",
        "alignExposure",
        "isAlignExposureImmutable",
        "alignBinning",
        "isAlignBinningImmutable",
        "alignGain",
        "isAlignGainImmutable",
        "alignISO",
        "isAlignISOImmutable",
        "alignDarkFrame",
        "isAlignDarkFrameImmutable",
        "alignFilter",
        "isAlignFilterImmutable",
        "alignUseCurrentFilter",
        "isAlignUseCurrentFilterImmutable",
        "astrometryUseRotator",
        "isAstrometryUseRotatorImmutable",
        "astrometryRotatorThreshold",
        "isAstrometryRotatorThresholdImmutable",
        "astrometryFlipRotationAllowed",
        "isAstrometryFlipRotationAllowedImmutable",
        "rotatorParityReversed",
        "isRotatorParityReversedImmutable",
        "astrometrySolverWCS",
        "isAstrometrySolverWCSImmutable",
        "astrometrySolverOverlay",
        "isAstrometrySolverOverlayImmutable",
        "astrometryDifferentialSlewing",
        "isAstrometryDifferentialSlewingImmutable",
        "alignAccuracyThreshold",
        "isAlignAccuracyThresholdImmutable",
        "alignSettlingTime",
        "isAlignSettlingTimeImmutable",
        "astrometryUseNoFITS2FITS",
        "isAstrometryUseNoFITS2FITSImmutable",
        "astrometryUseResort",
        "isAstrometryUseResortImmutable",
        "astrometryUseNoVerify",
        "isAstrometryUseNoVerifyImmutable",
        "astrometryUseImageScale",
        "isAstrometryUseImageScaleImmutable",
        "astrometryImageScaleLow",
        "isAstrometryImageScaleLowImmutable",
        "astrometryImageScaleHigh",
        "isAstrometryImageScaleHighImmutable",
        "astrometryAutoUpdateImageScale",
        "isAstrometryAutoUpdateImageScaleImmutable",
        "astrometryImageScaleUnits",
        "isAstrometryImageScaleUnitsImmutable",
        "astrometryUseDownsample",
        "isAstrometryUseDownsampleImmutable",
        "astrometryDownsample",
        "isAstrometryDownsampleImmutable",
        "astrometryAutoDownsample",
        "isAstrometryAutoDownsampleImmutable",
        "astrometryDynamicThreshold",
        "isAstrometryDynamicThresholdImmutable",
        "astrometryUsePosition",
        "isAstrometryUsePositionImmutable",
        "astrometryPositionRA",
        "isAstrometryPositionRAImmutable",
        "astrometryPositionDE",
        "isAstrometryPositionDEImmutable",
        "astrometryAutoUpdatePosition",
        "isAstrometryAutoUpdatePositionImmutable",
        "astrometryRadius",
        "isAstrometryRadiusImmutable",
        "astrometryDetectParity",
        "isAstrometryDetectParityImmutable",
        "astrometryCustomOptions",
        "isAstrometryCustomOptionsImmutable",
        "astrometrySolverBinary",
        "isAstrometrySolverBinaryImmutable",
        "astrometryWCSInfo",
        "isAstrometryWCSInfoImmutable",
        "astrometryConfFile",
        "isAstrometryConfFileImmutable",
        "sextractorBinary",
        "isSextractorBinaryImmutable",
        "watneyBinary",
        "isWatneyBinaryImmutable",
        "astrometryAPIKey",
        "isAstrometryAPIKeyImmutable",
        "astrometryAPIURL",
        "isAstrometryAPIURLImmutable",
        "astrometryUseJPEG",
        "isAstrometryUseJPEGImmutable",
        "astrometryTimeout",
        "isAstrometryTimeoutImmutable",
        "pAHMountSpeed",
        "isPAHMountSpeedImmutable",
        "pAHRotaion",
        "isPAHRotaionImmutable",
        "pAHRefreshAlgorithm",
        "isPAHRefreshAlgorithmImmutable",
        "pAHDirection",
        "isPAHDirectionImmutable",
        "pAHAutoPark",
        "isPAHAutoParkImmutable",
        "pAHManualSlew",
        "isPAHManualSlewImmutable",
        "pAHExposure",
        "isPAHExposureImmutable",
        "pAHAutoPACCorrection",
        "isPAHAutoPACCorrectionImmutable",
        "pAHAutoChangeDirection",
        "isPAHAutoChangeDirectionImmutable",
        "pAHSuccessThreshold",
        "isPAHSuccessThresholdImmutable",
        "pAHCorrectionTimeout",
        "isPAHCorrectionTimeoutImmutable",
        "guideExposure",
        "isGuideExposureImmutable",
        "guideDelay",
        "isGuideDelayImmutable",
        "guiderType",
        "isGuiderTypeImmutable",
        "guideAlgorithm",
        "isGuideAlgorithmImmutable",
        "rAGuidePulseAlgorithm",
        "isRAGuidePulseAlgorithmImmutable",
        "dECGuidePulseAlgorithm",
        "isDECGuidePulseAlgorithmImmutable",
        "aIGuiderWeightsFile",
        "QUrl",
        "isAIGuiderWeightsFileImmutable",
        "aIPredictionGain",
        "isAIPredictionGainImmutable",
        "aIProportionalBackoff",
        "isAIProportionalBackoffImmutable",
        "aIPIDAutoTune",
        "isAIPIDAutoTuneImmutable",
        "aIShadowMode",
        "isAIShadowModeImmutable",
        "pHD2Host",
        "isPHD2HostImmutable",
        "pHD2Port",
        "isPHD2PortImmutable",
        "linGuiderHost",
        "isLinGuiderHostImmutable",
        "linGuiderPort",
        "isLinGuiderPortImmutable",
        "calibrationPulseDuration",
        "isCalibrationPulseDurationImmutable",
        "calibrationMaxMove",
        "isCalibrationMaxMoveImmutable",
        "guideSquareSize",
        "isGuideSquareSizeImmutable",
        "guideBinning",
        "isGuideBinningImmutable",
        "guideAutoStar",
        "isGuideAutoStarImmutable",
        "guideShowFrame",
        "isGuideShowFrameImmutable",
        "guideAutoSquareSizeEnabled",
        "isGuideAutoSquareSizeEnabledImmutable",
        "autoModeIterations",
        "isAutoModeIterationsImmutable",
        "guideLostStarTimeout",
        "isGuideLostStarTimeoutImmutable",
        "guideCalibrationTimeout",
        "isGuideCalibrationTimeoutImmutable",
        "guideMaxDeltaRMS",
        "isGuideMaxDeltaRMSImmutable",
        "guideMaxHFR",
        "isGuideMaxHFRImmutable",
        "minDetectionsSEPMultistar",
        "isMinDetectionsSEPMultistarImmutable",
        "maxMultistarReferenceStars",
        "isMaxMultistarReferenceStarsImmutable",
        "alwaysInventGuideStar",
        "isAlwaysInventGuideStarImmutable",
        "twoAxisEnabled",
        "isTwoAxisEnabledImmutable",
        "useGuideHead",
        "isUseGuideHeadImmutable",
        "saveGuideLog",
        "isSaveGuideLogImmutable",
        "guideDarkFrame",
        "isGuideDarkFrameImmutable",
        "guideSubframe",
        "isGuideSubframeImmutable",
        "ditherPixels",
        "isDitherPixelsImmutable",
        "ditherFrames",
        "isDitherFramesImmutable",
        "ditherSettle",
        "isDitherSettleImmutable",
        "ditherThreshold",
        "isDitherThresholdImmutable",
        "ditherTimeout",
        "isDitherTimeoutImmutable",
        "ditherMaxIterations",
        "isDitherMaxIterationsImmutable",
        "ditherNoGuidingPulse",
        "isDitherNoGuidingPulseImmutable",
        "ditherFailAbortsAutoGuide",
        "isDitherFailAbortsAutoGuideImmutable",
        "ditherWithOnePulse",
        "isDitherWithOnePulseImmutable",
        "ditherEnabled",
        "isDitherEnabledImmutable",
        "ditherNoGuiding",
        "isDitherNoGuidingImmutable",
        "rAGuideEnabled",
        "isRAGuideEnabledImmutable",
        "dECGuideEnabled",
        "isDECGuideEnabledImmutable",
        "northDECGuideEnabled",
        "isNorthDECGuideEnabledImmutable",
        "southDECGuideEnabled",
        "isSouthDECGuideEnabledImmutable",
        "eastRAGuideEnabled",
        "isEastRAGuideEnabledImmutable",
        "westRAGuideEnabled",
        "isWestRAGuideEnabledImmutable",
        "rAProportionalGain",
        "isRAProportionalGainImmutable",
        "dECProportionalGain",
        "isDECProportionalGainImmutable",
        "rAIntegralGain",
        "isRAIntegralGainImmutable",
        "dECIntegralGain",
        "isDECIntegralGainImmutable",
        "rAMinimumPulseArcSec",
        "isRAMinimumPulseArcSecImmutable",
        "dECMinimumPulseArcSec",
        "isDECMinimumPulseArcSecImmutable",
        "rAMaximumPulseArcSec",
        "isRAMaximumPulseArcSecImmutable",
        "dECMaximumPulseArcSec",
        "isDECMaximumPulseArcSecImmutable",
        "gPGEnabled",
        "isGPGEnabledImmutable",
        "gPGDarkGuiding",
        "isGPGDarkGuidingImmutable",
        "gPGDarkGuidingInterval",
        "isGPGDarkGuidingIntervalImmutable",
        "aIDarkGuiding",
        "isAIDarkGuidingImmutable",
        "aIDarkGuidingInterval",
        "isAIDarkGuidingIntervalImmutable",
        "gPGcWeight",
        "isGPGcWeightImmutable",
        "gPGMinPeriodsForInference",
        "isGPGMinPeriodsForInferenceImmutable",
        "gPGMinMove",
        "isGPGMinMoveImmutable",
        "gPGSE0KLengthScale",
        "isGPGSE0KLengthScaleImmutable",
        "gPGSE0KSignalVariance",
        "isGPGSE0KSignalVarianceImmutable",
        "gPGPKLengthScale",
        "isGPGPKLengthScaleImmutable",
        "gPGPeriod",
        "isGPGPeriodImmutable",
        "gPGPKSignalVariance",
        "isGPGPKSignalVarianceImmutable",
        "gPGSE1KLengthScale",
        "isGPGSE1KLengthScaleImmutable",
        "gPGSE1KSignalVariance",
        "isGPGSE1KSignalVarianceImmutable",
        "gPGMinPeriodsForPeriodEstimate",
        "isGPGMinPeriodsForPeriodEstimateImmutable",
        "gPGPointsForApproximation",
        "isGPGPointsForApproximationImmutable",
        "gPGpWeight",
        "isGPGpWeightImmutable",
        "gPGEstimatePeriod",
        "isGPGEstimatePeriodImmutable",
        "guiderAccuracyThreshold",
        "isGuiderAccuracyThresholdImmutable",
        "rADisplayedOnGuideGraph",
        "isRADisplayedOnGuideGraphImmutable",
        "dEDisplayedOnGuideGraph",
        "isDEDisplayedOnGuideGraphImmutable",
        "rACorrDisplayedOnGuideGraph",
        "isRACorrDisplayedOnGuideGraphImmutable",
        "dECorrDisplayedOnGuideGraph",
        "isDECorrDisplayedOnGuideGraphImmutable",
        "sNRDisplayedOnGuideGraph",
        "isSNRDisplayedOnGuideGraphImmutable",
        "rMSDisplayedOnGuideGraph",
        "isRMSDisplayedOnGuideGraphImmutable",
        "rAHysteresis",
        "isRAHysteresisImmutable",
        "dECHysteresis",
        "isDECHysteresisImmutable",
        "schedulerAlgorithm",
        "isSchedulerAlgorithmImmutable",
        "schedulerLogging",
        "isSchedulerLoggingImmutable",
        "stopEkosAfterShutdown",
        "isStopEkosAfterShutdownImmutable",
        "shutdownScriptTerminatesINDI",
        "isShutdownScriptTerminatesINDIImmutable",
        "cameraWarmupEnabled",
        "isCameraWarmupEnabledImmutable",
        "cameraWarmupRamp",
        "isCameraWarmupRampImmutable",
        "preemptiveShutdown",
        "isPreemptiveShutdownImmutable",
        "resetMountModelOnAlignFail",
        "isResetMountModelOnAlignFailImmutable",
        "resetMountModelBeforeJob",
        "isResetMountModelBeforeJobImmutable",
        "resetGuideCalibration",
        "isResetGuideCalibrationImmutable",
        "forceAlignmentBeforeJob",
        "isForceAlignmentBeforeJobImmutable",
        "reuseGuideCalibration",
        "isReuseGuideCalibrationImmutable",
        "reverseDecOnPierSideChange",
        "isReverseDecOnPierSideChangeImmutable",
        "guideCalibrationBacklash",
        "isGuideCalibrationBacklashImmutable",
        "assumeDecOrthogonal",
        "isAssumeDecOrthogonalImmutable",
        "serializedCalibration",
        "isSerializedCalibrationImmutable",
        "realignAfterCalibrationFailure",
        "isRealignAfterCalibrationFailureImmutable",
        "preemptiveShutdownTime",
        "isPreemptiveShutdownTimeImmutable",
        "rememberJobProgress",
        "isRememberJobProgressImmutable",
        "greedyScheduling",
        "isGreedySchedulingImmutable",
        "leadTime",
        "isLeadTimeImmutable",
        "preDawnTime",
        "isPreDawnTimeImmutable",
        "dawnOffset",
        "isDawnOffsetImmutable",
        "duskOffset",
        "isDuskOffsetImmutable",
        "telescopeFocalLength",
        "isTelescopeFocalLengthImmutable",
        "telescopeFocalReducer",
        "isTelescopeFocalReducerImmutable",
        "cameraPixelWidth",
        "isCameraPixelWidthImmutable",
        "cameraPixelHeight",
        "isCameraPixelHeightImmutable",
        "cameraWidth",
        "isCameraWidthImmutable",
        "cameraHeight",
        "isCameraHeightImmutable",
        "cameraRotation",
        "isCameraRotationImmutable",
        "errorHandlingStrategy",
        "isErrorHandlingStrategyImmutable",
        "errorHandlingStrategyDelay",
        "isErrorHandlingStrategyDelayImmutable",
        "rescheduleErrors",
        "isRescheduleErrorsImmutable",
        "alignCheckFrequency",
        "isAlignCheckFrequencyImmutable",
        "alignCheckThreshold",
        "isAlignCheckThresholdImmutable",
        "schedulerTrackStep",
        "isSchedulerTrackStepImmutable",
        "schedulerStartupEnabled",
        "isSchedulerStartupEnabledImmutable",
        "schedulerPreStartupScript",
        "isSchedulerPreStartupScriptImmutable",
        "schedulerPostStartupScript",
        "isSchedulerPostStartupScriptImmutable",
        "schedulerShutdownEnabled",
        "isSchedulerShutdownEnabledImmutable",
        "schedulerPreShutdownScript",
        "isSchedulerPreShutdownScriptImmutable",
        "schedulerPostShutdownScript",
        "isSchedulerPostShutdownScriptImmutable",
        "schedulerFocusStep",
        "isSchedulerFocusStepImmutable",
        "schedulerGuideStep",
        "isSchedulerGuideStepImmutable",
        "schedulerAlignStep",
        "isSchedulerAlignStepImmutable",
        "schedulerAltitude",
        "isSchedulerAltitudeImmutable",
        "schedulerAltitudeValue",
        "isSchedulerAltitudeValueImmutable",
        "schedulerHorizon",
        "isSchedulerHorizonImmutable",
        "schedulerMoonSeparation",
        "isSchedulerMoonSeparationImmutable",
        "schedulerMoonSeparationValue",
        "isSchedulerMoonSeparationValueImmutable",
        "schedulerMoonAltitude",
        "isSchedulerMoonAltitudeImmutable",
        "schedulerMoonAltitudeMaxValue",
        "isSchedulerMoonAltitudeMaxValueImmutable",
        "schedulerWeather",
        "isSchedulerWeatherImmutable",
        "schedulerWeatherGracePeriod",
        "isSchedulerWeatherGracePeriodImmutable",
        "schedulerWeatherShutdownDelay",
        "isSchedulerWeatherShutdownDelayImmutable",
        "schedulerSafetyMonitorConnectionString",
        "isSchedulerSafetyMonitorConnectionStringImmutable",
        "schedulerTwilight",
        "isSchedulerTwilightImmutable",
        "schedulerCompleteSequences",
        "isSchedulerCompleteSequencesImmutable",
        "schedulerRepeatEverything",
        "isSchedulerRepeatEverythingImmutable",
        "schedulerRepeatSequences",
        "isSchedulerRepeatSequencesImmutable",
        "schedulerUntilTerminated",
        "isSchedulerUntilTerminatedImmutable",
        "schedulerUntil",
        "isSchedulerUntilImmutable",
        "schedulerUntilValue",
        "isSchedulerUntilValueImmutable",
        "schedulerExecutionSequencesLimit",
        "isSchedulerExecutionSequencesLimitImmutable",
        "analyzeRestartWithEkos",
        "isAnalyzeRestartWithEkosImmutable",
        "analyzeAlternativeDirectoryName",
        "isAnalyzeAlternativeDirectoryNameImmutable",
        "analyzeHFR",
        "isAnalyzeHFRImmutable",
        "analyzeNumCaptureStars",
        "isAnalyzeNumCaptureStarsImmutable",
        "analyzeMedian",
        "isAnalyzeMedianImmutable",
        "analyzeEccentricity",
        "isAnalyzeEccentricityImmutable",
        "analyzeTemperature",
        "isAnalyzeTemperatureImmutable",
        "focusPosition",
        "isFocusPositionImmutable",
        "analyzeNumStars",
        "isAnalyzeNumStarsImmutable",
        "analyzeSkyBg",
        "isAnalyzeSkyBgImmutable",
        "analyzeSNR",
        "isAnalyzeSNRImmutable",
        "analyzeRA",
        "isAnalyzeRAImmutable",
        "analyzeDEC",
        "isAnalyzeDECImmutable",
        "analyzeRAp",
        "isAnalyzeRApImmutable",
        "analyzeDECp",
        "isAnalyzeDECpImmutable",
        "analyzeDrift",
        "isAnalyzeDriftImmutable",
        "analyzeRMS",
        "isAnalyzeRMSImmutable",
        "analyzeTargetDistance",
        "isAnalyzeTargetDistanceImmutable",
        "analyzeRMSC",
        "isAnalyzeRMSCImmutable",
        "analyzeMountRA",
        "isAnalyzeMountRAImmutable",
        "analyzeMountDEC",
        "isAnalyzeMountDECImmutable",
        "analyzeMountHA",
        "isAnalyzeMountHAImmutable",
        "analyzeAz",
        "isAnalyzeAzImmutable",
        "analyzeAlt",
        "isAnalyzeAltImmutable",
        "analyzePierSide",
        "isAnalyzePierSideImmutable",
        "analyzeStatsYAxis",
        "isAnalyzeStatsYAxisImmutable",
        "lastServer",
        "isLastServerImmutable",
        "lastServerPort",
        "isLastServerPortImmutable",
        "lastWebManagerPort",
        "isLastWebManagerPortImmutable",
        "hIPSMemoryCache",
        "isHIPSMemoryCacheImmutable",
        "hIPSNetCache",
        "isHIPSNetCacheImmutable",
        "hIPSSource",
        "isHIPSSourceImmutable",
        "hIPSBiLinearInterpolation",
        "isHIPSBiLinearInterpolationImmutable",
        "hIPSShowGrid",
        "isHIPSShowGridImmutable",
        "hIPSPanning",
        "isHIPSPanningImmutable",
        "showHIPS",
        "isShowHIPSImmutable",
        "hIPSUseOfflineSource",
        "isHIPSUseOfflineSourceImmutable",
        "hIPSOfflinePath",
        "isHIPSOfflinePathImmutable",
        "terrainSource",
        "isTerrainSourceImmutable",
        "terrainSourceCorrectAz",
        "isTerrainSourceCorrectAzImmutable",
        "terrainSourceCorrectAlt",
        "isTerrainSourceCorrectAltImmutable",
        "terrainDownsampling",
        "isTerrainDownsamplingImmutable",
        "terrainPanning",
        "isTerrainPanningImmutable",
        "showTerrain",
        "isShowTerrainImmutable",
        "terrainSkipSpeedup",
        "isTerrainSkipSpeedupImmutable",
        "terrainTransparencySpeedup",
        "isTerrainTransparencySpeedupImmutable",
        "terrainSmoothPixels",
        "isTerrainSmoothPixelsImmutable",
        "showImageOverlays",
        "isShowImageOverlaysImmutable",
        "showImageOverlaysBelowCatalogs",
        "isShowImageOverlaysBelowCatalogsImmutable",
        "showSelectedImageOverlay",
        "isShowSelectedImageOverlayImmutable",
        "imageOverlayMaxDimension",
        "isImageOverlayMaxDimensionImmutable",
        "imageOverlayTimeout",
        "isImageOverlayTimeoutImmutable",
        "imageOverlayDefaultScale",
        "isImageOverlayDefaultScaleImmutable",
        "defaultObservatoryWeatherSource",
        "isDefaultObservatoryWeatherSourceImmutable",
        "warningActionsActive",
        "isWarningActionsActiveImmutable",
        "alertActionsActive",
        "isAlertActionsActiveImmutable",
        "weatherWarningCloseDome",
        "isWeatherWarningCloseDomeImmutable",
        "weatherWarningCloseShutter",
        "isWeatherWarningCloseShutterImmutable",
        "weatherWarningStopScheduler",
        "isWeatherWarningStopSchedulerImmutable",
        "weatherWarningDelay",
        "isWeatherWarningDelayImmutable",
        "weatherAlertCloseDome",
        "isWeatherAlertCloseDomeImmutable",
        "weatherAlertCloseShutter",
        "isWeatherAlertCloseShutterImmutable",
        "weatherAlertStopScheduler",
        "isWeatherAlertStopSchedulerImmutable",
        "weatherAlertDelay",
        "isWeatherAlertDelayImmutable",
        "observatoryStatusUseDome",
        "isObservatoryStatusUseDomeImmutable",
        "observatoryStatusUseShutter",
        "isObservatoryStatusUseShutterImmutable",
        "observatoryStatusUseWeather",
        "isObservatoryStatusUseWeatherImmutable",
        "weatherAutoScaleValues",
        "isWeatherAutoScaleValuesImmutable",
        "aSTAPExecutable",
        "isASTAPExecutableImmutable",
        "aSTAPDownSample",
        "isASTAPDownSampleImmutable",
        "aSTAPDownSampleValue",
        "isASTAPDownSampleValueImmutable",
        "aSTAPSearchRadius",
        "isASTAPSearchRadiusImmutable",
        "aSTAPSearchRadiusValue",
        "isASTAPSearchRadiusValueImmutable",
        "aSTAPUpdateFITS",
        "isASTAPUpdateFITSImmutable",
        "aSTAPLargeSearchWindow",
        "isASTAPLargeSearchWindowImmutable",
        "mosaicTransparencyAuto",
        "isMosaicTransparencyAutoImmutable",
        "mosaicTransparencyLevel",
        "isMosaicTransparencyLevelImmutable",
        "mCPEnabled",
        "isMCPEnabledImmutable",
        "mCPPort",
        "isMCPPortImmutable",
        "mCPReadOnlyMode",
        "isMCPReadOnlyModeImmutable",
        "mCPDisabledTools",
        "isMCPDisabledToolsImmutable"
    };

    QtMocHelpers::UintData qt_methods {
        // Signal 'PositionTimeBoxChanged'
        QtMocHelpers::SignalData<void()>(1, 2, QMC::AccessPublic, QMetaType::Void),
        // Signal 'PositionFocusBoxChanged'
        QtMocHelpers::SignalData<void()>(3, 2, QMC::AccessPublic, QMetaType::Void),
        // Signal 'PositionGeoBoxChanged'
        QtMocHelpers::SignalData<void()>(4, 2, QMC::AccessPublic, QMetaType::Void),
        // Signal 'ShadeTimeBoxChanged'
        QtMocHelpers::SignalData<void()>(5, 2, QMC::AccessPublic, QMetaType::Void),
        // Signal 'ShadeFocusBoxChanged'
        QtMocHelpers::SignalData<void()>(6, 2, QMC::AccessPublic, QMetaType::Void),
        // Signal 'ShadeGeoBoxChanged'
        QtMocHelpers::SignalData<void()>(7, 2, QMC::AccessPublic, QMetaType::Void),
        // Signal 'ShowInfoBoxesChanged'
        QtMocHelpers::SignalData<void()>(8, 2, QMC::AccessPublic, QMetaType::Void),
        // Signal 'ShowTimeBoxChanged'
        QtMocHelpers::SignalData<void()>(9, 2, QMC::AccessPublic, QMetaType::Void),
        // Signal 'ShowFocusBoxChanged'
        QtMocHelpers::SignalData<void()>(10, 2, QMC::AccessPublic, QMetaType::Void),
        // Signal 'ShowGeoBoxChanged'
        QtMocHelpers::SignalData<void()>(11, 2, QMC::AccessPublic, QMetaType::Void),
        // Signal 'StickyTimeBoxChanged'
        QtMocHelpers::SignalData<void()>(12, 2, QMC::AccessPublic, QMetaType::Void),
        // Signal 'StickyFocusBoxChanged'
        QtMocHelpers::SignalData<void()>(13, 2, QMC::AccessPublic, QMetaType::Void),
        // Signal 'StickyGeoBoxChanged'
        QtMocHelpers::SignalData<void()>(14, 2, QMC::AccessPublic, QMetaType::Void),
        // Signal 'ShowStatusBarChanged'
        QtMocHelpers::SignalData<void()>(15, 2, QMC::AccessPublic, QMetaType::Void),
        // Signal 'ShowAltAzFieldChanged'
        QtMocHelpers::SignalData<void()>(16, 2, QMC::AccessPublic, QMetaType::Void),
        // Signal 'ShowRADecFieldChanged'
        QtMocHelpers::SignalData<void()>(17, 2, QMC::AccessPublic, QMetaType::Void),
        // Signal 'ShowJ2000RADecFieldChanged'
        QtMocHelpers::SignalData<void()>(18, 2, QMC::AccessPublic, QMetaType::Void),
        // Signal 'ShowSensorFOVChanged'
        QtMocHelpers::SignalData<void()>(19, 2, QMC::AccessPublic, QMetaType::Void),
        // Signal 'WindowWidthChanged'
        QtMocHelpers::SignalData<void()>(20, 2, QMC::AccessPublic, QMetaType::Void),
        // Signal 'WindowHeightChanged'
        QtMocHelpers::SignalData<void()>(21, 2, QMC::AccessPublic, QMetaType::Void),
        // Signal 'KStarsGeometryChanged'
        QtMocHelpers::SignalData<void()>(22, 2, QMC::AccessPublic, QMetaType::Void),
        // Signal 'RunStartupWizardChanged'
        QtMocHelpers::SignalData<void()>(23, 2, QMC::AccessPublic, QMetaType::Void),
        // Signal 'CurrentThemeChanged'
        QtMocHelpers::SignalData<void()>(24, 2, QMC::AccessPublic, QMetaType::Void),
        // Signal 'CatalogFileChanged'
        QtMocHelpers::SignalData<void()>(25, 2, QMC::AccessPublic, QMetaType::Void),
        // Signal 'ShowCatalogChanged'
        QtMocHelpers::SignalData<void()>(26, 2, QMC::AccessPublic, QMetaType::Void),
        // Signal 'ShowCatalogNamesChanged'
        QtMocHelpers::SignalData<void()>(27, 2, QMC::AccessPublic, QMetaType::Void),
        // Signal 'ResolveNamesOnlineChanged'
        QtMocHelpers::SignalData<void()>(28, 2, QMC::AccessPublic, QMetaType::Void),
        // Signal 'DSOCachePercentageChanged'
        QtMocHelpers::SignalData<void()>(29, 2, QMC::AccessPublic, QMetaType::Void),
        // Signal 'DSOMinZoomFactorChanged'
        QtMocHelpers::SignalData<void()>(30, 2, QMC::AccessPublic, QMetaType::Void),
        // Signal 'DSOCatalogFilenameChanged'
        QtMocHelpers::SignalData<void()>(31, 2, QMC::AccessPublic, QMetaType::Void),
        // Signal 'DSODefaultCatalogFilenameChanged'
        QtMocHelpers::SignalData<void()>(32, 2, QMC::AccessPublic, QMetaType::Void),
        // Signal 'INDIWindowWidthChanged'
        QtMocHelpers::SignalData<void()>(33, 2, QMC::AccessPublic, QMetaType::Void),
        // Signal 'INDIWindowHeightChanged'
        QtMocHelpers::SignalData<void()>(34, 2, QMC::AccessPublic, QMetaType::Void),
        // Signal 'INDIWindowGeometryChanged'
        QtMocHelpers::SignalData<void()>(35, 2, QMC::AccessPublic, QMetaType::Void),
        // Signal 'useGeographicUpdateChanged'
        QtMocHelpers::SignalData<void()>(36, 2, QMC::AccessPublic, QMetaType::Void),
        // Signal 'useTimeUpdateChanged'
        QtMocHelpers::SignalData<void()>(37, 2, QMC::AccessPublic, QMetaType::Void),
        // Signal 'independentWindowINDIChanged'
        QtMocHelpers::SignalData<void()>(38, 2, QMC::AccessPublic, QMetaType::Void),
        // Signal 'showTargetCrosshairChanged'
        QtMocHelpers::SignalData<void()>(39, 2, QMC::AccessPublic, QMetaType::Void),
        // Signal 'showINDIMessagesChanged'
        QtMocHelpers::SignalData<void()>(40, 2, QMC::AccessPublic, QMetaType::Void),
        // Signal 'showINDIwindowInitiallyChanged'
        QtMocHelpers::SignalData<void()>(41, 2, QMC::AccessPublic, QMetaType::Void),
        // Signal 'maxFocusFrameFilesChanged'
        QtMocHelpers::SignalData<void()>(42, 2, QMC::AccessPublic, QMetaType::Void),
        // Signal 'messageNotificationINDIChanged'
        QtMocHelpers::SignalData<void()>(43, 2, QMC::AccessPublic, QMetaType::Void),
        // Signal 'timeSourceChanged'
        QtMocHelpers::SignalData<void()>(44, 2, QMC::AccessPublic, QMetaType::Void),
        // Signal 'locationSourceChanged'
        QtMocHelpers::SignalData<void()>(45, 2, QMC::AccessPublic, QMetaType::Void),
        // Signal 'useExternalSkyMapChanged'
        QtMocHelpers::SignalData<void()>(46, 2, QMC::AccessPublic, QMetaType::Void),
        // Signal 'fitsDirChanged'
        QtMocHelpers::SignalData<void()>(47, 2, QMC::AccessPublic, QMetaType::Void),
        // Signal 'serverTransferBufferSizeChanged'
        QtMocHelpers::SignalData<void()>(48, 2, QMC::AccessPublic, QMetaType::Void),
        // Signal 'serverPortStartChanged'
        QtMocHelpers::SignalData<void()>(49, 2, QMC::AccessPublic, QMetaType::Void),
        // Signal 'serverPortEndChanged'
        QtMocHelpers::SignalData<void()>(50, 2, QMC::AccessPublic, QMetaType::Void),
        // Signal 'indiServerChanged'
        QtMocHelpers::SignalData<void()>(51, 2, QMC::AccessPublic, QMetaType::Void),
        // Signal 'indiServerIsInternalChanged'
        QtMocHelpers::SignalData<void()>(52, 2, QMC::AccessPublic, QMetaType::Void),
        // Signal 'indiDriversDirChanged'
        QtMocHelpers::SignalData<void()>(53, 2, QMC::AccessPublic, QMetaType::Void),
        // Signal 'indiDriversAreInternalChanged'
        QtMocHelpers::SignalData<void()>(54, 2, QMC::AccessPublic, QMetaType::Void),
        // Signal 'streamWindowWidthChanged'
        QtMocHelpers::SignalData<void()>(55, 2, QMC::AccessPublic, QMetaType::Void),
        // Signal 'streamWindowHeightChanged'
        QtMocHelpers::SignalData<void()>(56, 2, QMC::AccessPublic, QMetaType::Void),
        // Signal 'INDIMountLoggingChanged'
        QtMocHelpers::SignalData<void()>(57, 2, QMC::AccessPublic, QMetaType::Void),
        // Signal 'INDIFocuserLoggingChanged'
        QtMocHelpers::SignalData<void()>(58, 2, QMC::AccessPublic, QMetaType::Void),
        // Signal 'INDICCDLoggingChanged'
        QtMocHelpers::SignalData<void()>(59, 2, QMC::AccessPublic, QMetaType::Void),
        // Signal 'INDIFilterWheelLoggingChanged'
        QtMocHelpers::SignalData<void()>(60, 2, QMC::AccessPublic, QMetaType::Void),
        // Signal 'INDIDomeLoggingChanged'
        QtMocHelpers::SignalData<void()>(61, 2, QMC::AccessPublic, QMetaType::Void),
        // Signal 'INDIDetectorLoggingChanged'
        QtMocHelpers::SignalData<void()>(62, 2, QMC::AccessPublic, QMetaType::Void),
        // Signal 'INDIWeatherLoggingChanged'
        QtMocHelpers::SignalData<void()>(63, 2, QMC::AccessPublic, QMetaType::Void),
        // Signal 'INDIAuxiliaryLoggingChanged'
        QtMocHelpers::SignalData<void()>(64, 2, QMC::AccessPublic, QMetaType::Void),
        // Signal 'INDIRotatorLoggingChanged'
        QtMocHelpers::SignalData<void()>(65, 2, QMC::AccessPublic, QMetaType::Void),
        // Signal 'INDIGPSLoggingChanged'
        QtMocHelpers::SignalData<void()>(66, 2, QMC::AccessPublic, QMetaType::Void),
        // Signal 'INDIAOLoggingChanged'
        QtMocHelpers::SignalData<void()>(67, 2, QMC::AccessPublic, QMetaType::Void),
        // Signal 'CityNameChanged'
        QtMocHelpers::SignalData<void()>(68, 2, QMC::AccessPublic, QMetaType::Void),
        // Signal 'ProvinceNameChanged'
        QtMocHelpers::SignalData<void()>(69, 2, QMC::AccessPublic, QMetaType::Void),
        // Signal 'CountryNameChanged'
        QtMocHelpers::SignalData<void()>(70, 2, QMC::AccessPublic, QMetaType::Void),
        // Signal 'LongitudeChanged'
        QtMocHelpers::SignalData<void()>(71, 2, QMC::AccessPublic, QMetaType::Void),
        // Signal 'LatitudeChanged'
        QtMocHelpers::SignalData<void()>(72, 2, QMC::AccessPublic, QMetaType::Void),
        // Signal 'ElevationChanged'
        QtMocHelpers::SignalData<void()>(73, 2, QMC::AccessPublic, QMetaType::Void),
        // Signal 'TimeZoneChanged'
        QtMocHelpers::SignalData<void()>(74, 2, QMC::AccessPublic, QMetaType::Void),
        // Signal 'DSTChanged'
        QtMocHelpers::SignalData<void()>(75, 2, QMC::AccessPublic, QMetaType::Void),
        // Signal 'UseAnimatedSlewingChanged'
        QtMocHelpers::SignalData<void()>(76, 2, QMC::AccessPublic, QMetaType::Void),
        // Signal 'LeftClickSelectsObjectChanged'
        QtMocHelpers::SignalData<void()>(77, 2, QMC::AccessPublic, QMetaType::Void),
        // Signal 'DefaultCursorChanged'
        QtMocHelpers::SignalData<void()>(78, 2, QMC::AccessPublic, QMetaType::Void),
        // Signal 'FOVNamesChanged'
        QtMocHelpers::SignalData<void()>(79, 2, QMC::AccessPublic, QMetaType::Void),
        // Signal 'FadePlanetTrailsChanged'
        QtMocHelpers::SignalData<void()>(80, 2, QMC::AccessPublic, QMetaType::Void),
        // Signal 'FocusRAChanged'
        QtMocHelpers::SignalData<void()>(81, 2, QMC::AccessPublic, QMetaType::Void),
        // Signal 'FocusDecChanged'
        QtMocHelpers::SignalData<void()>(82, 2, QMC::AccessPublic, QMetaType::Void),
        // Signal 'FocusObjectChanged'
        QtMocHelpers::SignalData<void()>(83, 2, QMC::AccessPublic, QMetaType::Void),
        // Signal 'IsTrackingChanged'
        QtMocHelpers::SignalData<void()>(84, 2, QMC::AccessPublic, QMetaType::Void),
        // Signal 'HideOnSlewChanged'
        QtMocHelpers::SignalData<void()>(85, 2, QMC::AccessPublic, QMetaType::Void),
        // Signal 'HideCBoundsChanged'
        QtMocHelpers::SignalData<void()>(86, 2, QMC::AccessPublic, QMetaType::Void),
        // Signal 'HideCLinesChanged'
        QtMocHelpers::SignalData<void()>(87, 2, QMC::AccessPublic, QMetaType::Void),
        // Signal 'SkyCultureChanged'
        QtMocHelpers::SignalData<void()>(88, 2, QMC::AccessPublic, QMetaType::Void),
        // Signal 'HideCNamesChanged'
        QtMocHelpers::SignalData<void()>(89, 2, QMC::AccessPublic, QMetaType::Void),
        // Signal 'HideGridsChanged'
        QtMocHelpers::SignalData<void()>(90, 2, QMC::AccessPublic, QMetaType::Void),
        // Signal 'HideMilkyWayChanged'
        QtMocHelpers::SignalData<void()>(91, 2, QMC::AccessPublic, QMetaType::Void),
        // Signal 'HideOtherChanged'
        QtMocHelpers::SignalData<void()>(92, 2, QMC::AccessPublic, QMetaType::Void),
        // Signal 'HidePlanetsChanged'
        QtMocHelpers::SignalData<void()>(93, 2, QMC::AccessPublic, QMetaType::Void),
        // Signal 'HideStarsChanged'
        QtMocHelpers::SignalData<void()>(94, 2, QMC::AccessPublic, QMetaType::Void),
        // Signal 'HideLabelsChanged'
        QtMocHelpers::SignalData<void()>(95, 2, QMC::AccessPublic, QMetaType::Void),
        // Signal 'ShowAsteroidsChanged'
        QtMocHelpers::SignalData<void()>(96, 2, QMC::AccessPublic, QMetaType::Void),
        // Signal 'ShowAsteroidNamesChanged'
        QtMocHelpers::SignalData<void()>(97, 2, QMC::AccessPublic, QMetaType::Void),
        // Signal 'OrbitalElementsAutoUpdateChanged'
        QtMocHelpers::SignalData<void()>(98, 2, QMC::AccessPublic, QMetaType::Void),
        // Signal 'ShowCometsChanged'
        QtMocHelpers::SignalData<void()>(99, 2, QMC::AccessPublic, QMetaType::Void),
        // Signal 'ShowCometComasChanged'
        QtMocHelpers::SignalData<void()>(100, 2, QMC::AccessPublic, QMetaType::Void),
        // Signal 'ShowCometNamesChanged'
        QtMocHelpers::SignalData<void()>(101, 2, QMC::AccessPublic, QMetaType::Void),
        // Signal 'ShowSupernovaeChanged'
        QtMocHelpers::SignalData<void()>(102, 2, QMC::AccessPublic, QMetaType::Void),
        // Signal 'ShowSupernovaNamesChanged'
        QtMocHelpers::SignalData<void()>(103, 2, QMC::AccessPublic, QMetaType::Void),
        // Signal 'MagnitudeLimitShowSupernovaeChanged'
        QtMocHelpers::SignalData<void()>(104, 2, QMC::AccessPublic, QMetaType::Void),
        // Signal 'SupernovaDetectionAgeChanged'
        QtMocHelpers::SignalData<void()>(105, 2, QMC::AccessPublic, QMetaType::Void),
        // Signal 'SupernovaDownloadUrlChanged'
        QtMocHelpers::SignalData<void()>(106, 2, QMC::AccessPublic, QMetaType::Void),
        // Signal 'LimitSupernovaeByZoomChanged'
        QtMocHelpers::SignalData<void()>(107, 2, QMC::AccessPublic, QMetaType::Void),
        // Signal 'SupernovaeHostOnlyChanged'
        QtMocHelpers::SignalData<void()>(108, 2, QMC::AccessPublic, QMetaType::Void),
        // Signal 'SupernovaeClassifiedOnlyChanged'
        QtMocHelpers::SignalData<void()>(109, 2, QMC::AccessPublic, QMetaType::Void),
        // Signal 'ShowSupernovaAlertsChanged'
        QtMocHelpers::SignalData<void()>(110, 2, QMC::AccessPublic, QMetaType::Void),
        // Signal 'MagnitudeLimitAlertSupernovaeChanged'
        QtMocHelpers::SignalData<void()>(111, 2, QMC::AccessPublic, QMetaType::Void),
        // Signal 'ShowCBoundsChanged'
        QtMocHelpers::SignalData<void()>(112, 2, QMC::AccessPublic, QMetaType::Void),
        // Signal 'ShowHighlightedCBoundChanged'
        QtMocHelpers::SignalData<void()>(113, 2, QMC::AccessPublic, QMetaType::Void),
        // Signal 'ShowCLinesChanged'
        QtMocHelpers::SignalData<void()>(114, 2, QMC::AccessPublic, QMetaType::Void),
        // Signal 'ShowConstellationArtChanged'
        QtMocHelpers::SignalData<void()>(115, 2, QMC::AccessPublic, QMetaType::Void),
        // Signal 'ShowCNamesChanged'
        QtMocHelpers::SignalData<void()>(116, 2, QMC::AccessPublic, QMetaType::Void),
        // Signal 'ShowDeepSkyChanged'
        QtMocHelpers::SignalData<void()>(117, 2, QMC::AccessPublic, QMetaType::Void),
        // Signal 'ShowEclipticChanged'
        QtMocHelpers::SignalData<void()>(118, 2, QMC::AccessPublic, QMetaType::Void),
        // Signal 'ShowEquatorChanged'
        QtMocHelpers::SignalData<void()>(119, 2, QMC::AccessPublic, QMetaType::Void),
        // Signal 'AutoSelectGridChanged'
        QtMocHelpers::SignalData<void()>(120, 2, QMC::AccessPublic, QMetaType::Void),
        // Signal 'ShowEquatorialGridChanged'
        QtMocHelpers::SignalData<void()>(121, 2, QMC::AccessPublic, QMetaType::Void),
        // Signal 'ShowHorizontalGridChanged'
        QtMocHelpers::SignalData<void()>(122, 2, QMC::AccessPublic, QMetaType::Void),
        // Signal 'ShowLocalMeridianChanged'
        QtMocHelpers::SignalData<void()>(123, 2, QMC::AccessPublic, QMetaType::Void),
        // Signal 'ShowGroundChanged'
        QtMocHelpers::SignalData<void()>(124, 2, QMC::AccessPublic, QMetaType::Void),
        // Signal 'ShowHorizonChanged'
        QtMocHelpers::SignalData<void()>(125, 2, QMC::AccessPublic, QMetaType::Void),
        // Signal 'ShowFlagsChanged'
        QtMocHelpers::SignalData<void()>(126, 2, QMC::AccessPublic, QMetaType::Void),
        // Signal 'SimulateDaytimeChanged'
        QtMocHelpers::SignalData<void()>(127, 2, QMC::AccessPublic, QMetaType::Void),
        // Signal 'ShowOtherChanged'
        QtMocHelpers::SignalData<void()>(128, 2, QMC::AccessPublic, QMetaType::Void),
        // Signal 'ShowMilkyWayChanged'
        QtMocHelpers::SignalData<void()>(129, 2, QMC::AccessPublic, QMetaType::Void),
        // Signal 'FillMilkyWayChanged'
        QtMocHelpers::SignalData<void()>(130, 2, QMC::AccessPublic, QMetaType::Void),
        // Signal 'ShowSolarSystemChanged'
        QtMocHelpers::SignalData<void()>(131, 2, QMC::AccessPublic, QMetaType::Void),
        // Signal 'ShowPlanetImagesChanged'
        QtMocHelpers::SignalData<void()>(132, 2, QMC::AccessPublic, QMetaType::Void),
        // Signal 'ShowPlanetNamesChanged'
        QtMocHelpers::SignalData<void()>(133, 2, QMC::AccessPublic, QMetaType::Void),
        // Signal 'ShowSunChanged'
        QtMocHelpers::SignalData<void()>(134, 2, QMC::AccessPublic, QMetaType::Void),
        // Signal 'SunScaleChanged'
        QtMocHelpers::SignalData<void()>(135, 2, QMC::AccessPublic, QMetaType::Void),
        // Signal 'ShowMoonChanged'
        QtMocHelpers::SignalData<void()>(136, 2, QMC::AccessPublic, QMetaType::Void),
        // Signal 'MoonScaleChanged'
        QtMocHelpers::SignalData<void()>(137, 2, QMC::AccessPublic, QMetaType::Void),
        // Signal 'ShowMercuryChanged'
        QtMocHelpers::SignalData<void()>(138, 2, QMC::AccessPublic, QMetaType::Void),
        // Signal 'ShowVenusChanged'
        QtMocHelpers::SignalData<void()>(139, 2, QMC::AccessPublic, QMetaType::Void),
        // Signal 'ShowMarsChanged'
        QtMocHelpers::SignalData<void()>(140, 2, QMC::AccessPublic, QMetaType::Void),
        // Signal 'ShowJupiterChanged'
        QtMocHelpers::SignalData<void()>(141, 2, QMC::AccessPublic, QMetaType::Void),
        // Signal 'ShowSaturnChanged'
        QtMocHelpers::SignalData<void()>(142, 2, QMC::AccessPublic, QMetaType::Void),
        // Signal 'ShowUranusChanged'
        QtMocHelpers::SignalData<void()>(143, 2, QMC::AccessPublic, QMetaType::Void),
        // Signal 'ShowNeptuneChanged'
        QtMocHelpers::SignalData<void()>(144, 2, QMC::AccessPublic, QMetaType::Void),
        // Signal 'ShowPlutoChanged'
        QtMocHelpers::SignalData<void()>(145, 2, QMC::AccessPublic, QMetaType::Void),
        // Signal 'ShowStarsChanged'
        QtMocHelpers::SignalData<void()>(146, 2, QMC::AccessPublic, QMetaType::Void),
        // Signal 'ShowStarMagnitudesChanged'
        QtMocHelpers::SignalData<void()>(147, 2, QMC::AccessPublic, QMetaType::Void),
        // Signal 'ShowStarsOverHIPSChanged'
        QtMocHelpers::SignalData<void()>(148, 2, QMC::AccessPublic, QMetaType::Void),
        // Signal 'ShowStarNamesChanged'
        QtMocHelpers::SignalData<void()>(149, 2, QMC::AccessPublic, QMetaType::Void),
        // Signal 'ShowDeepSkyMagnitudesChanged'
        QtMocHelpers::SignalData<void()>(150, 2, QMC::AccessPublic, QMetaType::Void),
        // Signal 'ShowDeepSkyNamesChanged'
        QtMocHelpers::SignalData<void()>(151, 2, QMC::AccessPublic, QMetaType::Void),
        // Signal 'ShowMosaicPanelChanged'
        QtMocHelpers::SignalData<void()>(152, 2, QMC::AccessPublic, QMetaType::Void),
        // Signal 'SlewTimeScaleChanged'
        QtMocHelpers::SignalData<void()>(153, 2, QMC::AccessPublic, QMetaType::Void),
        // Signal 'BoxBGModeChanged'
        QtMocHelpers::SignalData<void()>(154, 2, QMC::AccessPublic, QMetaType::Void),
        // Signal 'ProjectionChanged'
        QtMocHelpers::SignalData<void()>(155, 2, QMC::AccessPublic, QMetaType::Void),
        // Signal 'UseAbbrevConstellNamesChanged'
        QtMocHelpers::SignalData<void()>(156, 2, QMC::AccessPublic, QMetaType::Void),
        // Signal 'UseLatinConstellNamesChanged'
        QtMocHelpers::SignalData<void()>(157, 2, QMC::AccessPublic, QMetaType::Void),
        // Signal 'UseLocalConstellNamesChanged'
        QtMocHelpers::SignalData<void()>(158, 2, QMC::AccessPublic, QMetaType::Void),
        // Signal 'UseAltAzChanged'
        QtMocHelpers::SignalData<void()>(159, 2, QMC::AccessPublic, QMetaType::Void),
        // Signal 'UseAutoLabelChanged'
        QtMocHelpers::SignalData<void()>(160, 2, QMC::AccessPublic, QMetaType::Void),
        // Signal 'UseAutoTrailChanged'
        QtMocHelpers::SignalData<void()>(161, 2, QMC::AccessPublic, QMetaType::Void),
        // Signal 'UseHoverLabelChanged'
        QtMocHelpers::SignalData<void()>(162, 2, QMC::AccessPublic, QMetaType::Void),
        // Signal 'UseRefractionChanged'
        QtMocHelpers::SignalData<void()>(163, 2, QMC::AccessPublic, QMetaType::Void),
        // Signal 'UseRelativisticChanged'
        QtMocHelpers::SignalData<void()>(164, 2, QMC::AccessPublic, QMetaType::Void),
        // Signal 'UseAntialiasChanged'
        QtMocHelpers::SignalData<void()>(165, 2, QMC::AccessPublic, QMetaType::Void),
        // Signal 'ZoomFactorChanged'
        QtMocHelpers::SignalData<void()>(166, 2, QMC::AccessPublic, QMetaType::Void),
        // Signal 'SkyRotationChanged'
        QtMocHelpers::SignalData<void()>(167, 2, QMC::AccessPublic, QMetaType::Void),
        // Signal 'MirrorSkyMapChanged'
        QtMocHelpers::SignalData<void()>(168, 2, QMC::AccessPublic, QMetaType::Void),
        // Signal 'ErectObserverCorrectionChanged'
        QtMocHelpers::SignalData<void()>(169, 2, QMC::AccessPublic, QMetaType::Void),
        // Signal 'ZoomScrollFactorChanged'
        QtMocHelpers::SignalData<void()>(170, 2, QMC::AccessPublic, QMetaType::Void),
        // Signal 'MagLimitAsteroidChanged'
        QtMocHelpers::SignalData<void()>(171, 2, QMC::AccessPublic, QMetaType::Void),
        // Signal 'MagLimitAsteroidDownloadChanged'
        QtMocHelpers::SignalData<void()>(172, 2, QMC::AccessPublic, QMetaType::Void),
        // Signal 'AsteroidLabelDensityChanged'
        QtMocHelpers::SignalData<void()>(173, 2, QMC::AccessPublic, QMetaType::Void),
        // Signal 'MagLimitDrawDeepSkyChanged'
        QtMocHelpers::SignalData<void()>(174, 2, QMC::AccessPublic, QMetaType::Void),
        // Signal 'MagLimitDrawDeepSkyZoomOutChanged'
        QtMocHelpers::SignalData<void()>(175, 2, QMC::AccessPublic, QMetaType::Void),
        // Signal 'ShowUnknownMagObjectsChanged'
        QtMocHelpers::SignalData<void()>(176, 2, QMC::AccessPublic, QMetaType::Void),
        // Signal 'ShowInlineImagesChanged'
        QtMocHelpers::SignalData<void()>(177, 2, QMC::AccessPublic, QMetaType::Void),
        // Signal 'StarDensityChanged'
        QtMocHelpers::SignalData<void()>(178, 2, QMC::AccessPublic, QMetaType::Void),
        // Signal 'MagLimitHideStarChanged'
        QtMocHelpers::SignalData<void()>(179, 2, QMC::AccessPublic, QMetaType::Void),
        // Signal 'StarLabelDensityChanged'
        QtMocHelpers::SignalData<void()>(180, 2, QMC::AccessPublic, QMetaType::Void),
        // Signal 'DeepSkyLabelDensityChanged'
        QtMocHelpers::SignalData<void()>(181, 2, QMC::AccessPublic, QMetaType::Void),
        // Signal 'DeepSkyLongLabelsChanged'
        QtMocHelpers::SignalData<void()>(182, 2, QMC::AccessPublic, QMetaType::Void),
        // Signal 'LabelFontScalingChanged'
        QtMocHelpers::SignalData<void()>(183, 2, QMC::AccessPublic, QMetaType::Void),
        // Signal 'MaxRadCometNameChanged'
        QtMocHelpers::SignalData<void()>(184, 2, QMC::AccessPublic, QMetaType::Void),
        // Signal 'UseGLChanged'
        QtMocHelpers::SignalData<void()>(185, 2, QMC::AccessPublic, QMetaType::Void),
        // Signal 'RunClockChanged'
        QtMocHelpers::SignalData<void()>(186, 2, QMC::AccessPublic, QMetaType::Void),
        // Signal 'ImagingPlannerAcceptOpenClusterChanged'
        QtMocHelpers::SignalData<void()>(187, 2, QMC::AccessPublic, QMetaType::Void),
        // Signal 'ImagingPlannerAcceptNebulaChanged'
        QtMocHelpers::SignalData<void()>(188, 2, QMC::AccessPublic, QMetaType::Void),
        // Signal 'ImagingPlannerAcceptGlobularClusterChanged'
        QtMocHelpers::SignalData<void()>(189, 2, QMC::AccessPublic, QMetaType::Void),
        // Signal 'ImagingPlannerAcceptPlanetaryChanged'
        QtMocHelpers::SignalData<void()>(190, 2, QMC::AccessPublic, QMetaType::Void),
        // Signal 'ImagingPlannerAcceptSupernovaRemnantChanged'
        QtMocHelpers::SignalData<void()>(191, 2, QMC::AccessPublic, QMetaType::Void),
        // Signal 'ImagingPlannerAcceptGalaxyChanged'
        QtMocHelpers::SignalData<void()>(192, 2, QMC::AccessPublic, QMetaType::Void),
        // Signal 'ImagingPlannerAcceptGalaxyClusterChanged'
        QtMocHelpers::SignalData<void()>(193, 2, QMC::AccessPublic, QMetaType::Void),
        // Signal 'ImagingPlannerAcceptDarkNebulaChanged'
        QtMocHelpers::SignalData<void()>(194, 2, QMC::AccessPublic, QMetaType::Void),
        // Signal 'ImagingPlannerAcceptOtherChanged'
        QtMocHelpers::SignalData<void()>(195, 2, QMC::AccessPublic, QMetaType::Void),
        // Signal 'AstrobinAwardChanged'
        QtMocHelpers::SignalData<void()>(196, 2, QMC::AccessPublic, QMetaType::Void),
        // Signal 'AstrobinMinRadiusChanged'
        QtMocHelpers::SignalData<void()>(197, 2, QMC::AccessPublic, QMetaType::Void),
        // Signal 'AstrobinMaxRadiusChanged'
        QtMocHelpers::SignalData<void()>(198, 2, QMC::AccessPublic, QMetaType::Void),
        // Signal 'ImagingPlannerUseArtificialHorizonChanged'
        QtMocHelpers::SignalData<void()>(199, 2, QMC::AccessPublic, QMetaType::Void),
        // Signal 'ImagingPlannerMinHoursChanged'
        QtMocHelpers::SignalData<void()>(200, 2, QMC::AccessPublic, QMetaType::Void),
        // Signal 'ImagingPlannerMinAltitudeChanged'
        QtMocHelpers::SignalData<void()>(201, 2, QMC::AccessPublic, QMetaType::Void),
        // Signal 'ImagingPlannerMinMoonSeparationChanged'
        QtMocHelpers::SignalData<void()>(202, 2, QMC::AccessPublic, QMetaType::Void),
        // Signal 'ImagingPlannerMaxMoonAltitudeChanged'
        QtMocHelpers::SignalData<void()>(203, 2, QMC::AccessPublic, QMetaType::Void),
        // Signal 'ImagingPlannerShowPickedChanged'
        QtMocHelpers::SignalData<void()>(204, 2, QMC::AccessPublic, QMetaType::Void),
        // Signal 'ImagingPlannerShowNotPickedChanged'
        QtMocHelpers::SignalData<void()>(205, 2, QMC::AccessPublic, QMetaType::Void),
        // Signal 'ImagingPlannerDontCarePickedChanged'
        QtMocHelpers::SignalData<void()>(206, 2, QMC::AccessPublic, QMetaType::Void),
        // Signal 'ImagingPlannerShowKeywordChanged'
        QtMocHelpers::SignalData<void()>(207, 2, QMC::AccessPublic, QMetaType::Void),
        // Signal 'ImagingPlannerShowNotKeywordChanged'
        QtMocHelpers::SignalData<void()>(208, 2, QMC::AccessPublic, QMetaType::Void),
        // Signal 'ImagingPlannerDontCareKeywordChanged'
        QtMocHelpers::SignalData<void()>(209, 2, QMC::AccessPublic, QMetaType::Void),
        // Signal 'ImagingPlannerKeywordChanged'
        QtMocHelpers::SignalData<void()>(210, 2, QMC::AccessPublic, QMetaType::Void),
        // Signal 'ImagingPlannerShowImagedChanged'
        QtMocHelpers::SignalData<void()>(211, 2, QMC::AccessPublic, QMetaType::Void),
        // Signal 'ImagingPlannerShowNotImagedChanged'
        QtMocHelpers::SignalData<void()>(212, 2, QMC::AccessPublic, QMetaType::Void),
        // Signal 'ImagingPlannerDontCareImagedChanged'
        QtMocHelpers::SignalData<void()>(213, 2, QMC::AccessPublic, QMetaType::Void),
        // Signal 'ImagingPlannerShowAddedChanged'
        QtMocHelpers::SignalData<void()>(214, 2, QMC::AccessPublic, QMetaType::Void),
        // Signal 'ImagingPlannerShowNotAddedChanged'
        QtMocHelpers::SignalData<void()>(215, 2, QMC::AccessPublic, QMetaType::Void),
        // Signal 'ImagingPlannerDontCareAddedChanged'
        QtMocHelpers::SignalData<void()>(216, 2, QMC::AccessPublic, QMetaType::Void),
        // Signal 'ImagingPlannerShowIgnoredChanged'
        QtMocHelpers::SignalData<void()>(217, 2, QMC::AccessPublic, QMetaType::Void),
        // Signal 'ImagingPlannerShowNotIgnoredChanged'
        QtMocHelpers::SignalData<void()>(218, 2, QMC::AccessPublic, QMetaType::Void),
        // Signal 'ImagingPlannerDontCareIgnoredChanged'
        QtMocHelpers::SignalData<void()>(219, 2, QMC::AccessPublic, QMetaType::Void),
        // Signal 'ImagingPlannerHideAstrobinDetailsChanged'
        QtMocHelpers::SignalData<void()>(220, 2, QMC::AccessPublic, QMetaType::Void),
        // Signal 'ImagingPlannerHideFiltersChanged'
        QtMocHelpers::SignalData<void()>(221, 2, QMC::AccessPublic, QMetaType::Void),
        // Signal 'ImagingPlannerHideImageChanged'
        QtMocHelpers::SignalData<void()>(222, 2, QMC::AccessPublic, QMetaType::Void),
        // Signal 'ImagingPlannerHideAltitudeGraphChanged'
        QtMocHelpers::SignalData<void()>(223, 2, QMC::AccessPublic, QMetaType::Void),
        // Signal 'ImagingPlannerCatalogPathChanged'
        QtMocHelpers::SignalData<void()>(224, 2, QMC::AccessPublic, QMetaType::Void),
        // Signal 'ImagingPlannerCenterOnSkyMapChanged'
        QtMocHelpers::SignalData<void()>(225, 2, QMC::AccessPublic, QMetaType::Void),
        // Signal 'ImagingPlannerIndependentWindowChanged'
        QtMocHelpers::SignalData<void()>(226, 2, QMC::AccessPublic, QMetaType::Void),
        // Signal 'ImagingPlannerStartSolvingImmediatelyChanged'
        QtMocHelpers::SignalData<void()>(227, 2, QMC::AccessPublic, QMetaType::Void),
        // Signal 'ObsListSymbolChanged'
        QtMocHelpers::SignalData<void()>(228, 2, QMC::AccessPublic, QMetaType::Void),
        // Signal 'ObsListTextChanged'
        QtMocHelpers::SignalData<void()>(229, 2, QMC::AccessPublic, QMetaType::Void),
        // Signal 'ObsListPreferDSSChanged'
        QtMocHelpers::SignalData<void()>(230, 2, QMC::AccessPublic, QMetaType::Void),
        // Signal 'ObsListPreferSDSSChanged'
        QtMocHelpers::SignalData<void()>(231, 2, QMC::AccessPublic, QMetaType::Void),
        // Signal 'ObsListDemoteHoleChanged'
        QtMocHelpers::SignalData<void()>(232, 2, QMC::AccessPublic, QMetaType::Void),
        // Signal 'ObsListHoleSizeChanged'
        QtMocHelpers::SignalData<void()>(233, 2, QMC::AccessPublic, QMetaType::Void),
        // Signal 'ObsListCoverageChanged'
        QtMocHelpers::SignalData<void()>(234, 2, QMC::AccessPublic, QMetaType::Void),
        // Signal 'ColorSchemeFileChanged'
        QtMocHelpers::SignalData<void()>(235, 2, QMC::AccessPublic, QMetaType::Void),
        // Signal 'StarColorModeChanged'
        QtMocHelpers::SignalData<void()>(236, 2, QMC::AccessPublic, QMetaType::Void),
        // Signal 'StarColorIntensityChanged'
        QtMocHelpers::SignalData<void()>(237, 2, QMC::AccessPublic, QMetaType::Void),
        // Signal 'DomeSlitInvertedChanged'
        QtMocHelpers::SignalData<void()>(238, 2, QMC::AccessPublic, QMetaType::Void),
        // Signal 'AngularRulerColorChanged'
        QtMocHelpers::SignalData<void()>(239, 2, QMC::AccessPublic, QMetaType::Void),
        // Signal 'BoxBGColorChanged'
        QtMocHelpers::SignalData<void()>(240, 2, QMC::AccessPublic, QMetaType::Void),
        // Signal 'BoxGrabColorChanged'
        QtMocHelpers::SignalData<void()>(241, 2, QMC::AccessPublic, QMetaType::Void),
        // Signal 'BoxTextColorChanged'
        QtMocHelpers::SignalData<void()>(242, 2, QMC::AccessPublic, QMetaType::Void),
        // Signal 'CBoundColorChanged'
        QtMocHelpers::SignalData<void()>(243, 2, QMC::AccessPublic, QMetaType::Void),
        // Signal 'CBoundHighColorChanged'
        QtMocHelpers::SignalData<void()>(244, 2, QMC::AccessPublic, QMetaType::Void),
        // Signal 'CLineColorChanged'
        QtMocHelpers::SignalData<void()>(245, 2, QMC::AccessPublic, QMetaType::Void),
        // Signal 'CNameColorChanged'
        QtMocHelpers::SignalData<void()>(246, 2, QMC::AccessPublic, QMetaType::Void),
        // Signal 'CompassColorChanged'
        QtMocHelpers::SignalData<void()>(247, 2, QMC::AccessPublic, QMetaType::Void),
        // Signal 'EclipticColorChanged'
        QtMocHelpers::SignalData<void()>(248, 2, QMC::AccessPublic, QMetaType::Void),
        // Signal 'EquatorColorChanged'
        QtMocHelpers::SignalData<void()>(249, 2, QMC::AccessPublic, QMetaType::Void),
        // Signal 'EquatorialGridColorChanged'
        QtMocHelpers::SignalData<void()>(250, 2, QMC::AccessPublic, QMetaType::Void),
        // Signal 'HorizontalGridColorChanged'
        QtMocHelpers::SignalData<void()>(251, 2, QMC::AccessPublic, QMetaType::Void),
        // Signal 'SpecialObjectColorChanged'
        QtMocHelpers::SignalData<void()>(252, 2, QMC::AccessPublic, QMetaType::Void),
        // Signal 'HorizonColorChanged'
        QtMocHelpers::SignalData<void()>(253, 2, QMC::AccessPublic, QMetaType::Void),
        // Signal 'LocalMeridianColorChanged'
        QtMocHelpers::SignalData<void()>(254, 2, QMC::AccessPublic, QMetaType::Void),
        // Signal 'MilkyWayWColorChanged'
        QtMocHelpers::SignalData<void()>(255, 2, QMC::AccessPublic, QMetaType::Void),
        // Signal 'StarNameColorChanged'
        QtMocHelpers::SignalData<void()>(256, 2, QMC::AccessPublic, QMetaType::Void),
        // Signal 'DeepSkyNameColorChanged'
        QtMocHelpers::SignalData<void()>(257, 2, QMC::AccessPublic, QMetaType::Void),
        // Signal 'PlanetNameColorChanged'
        QtMocHelpers::SignalData<void()>(258, 2, QMC::AccessPublic, QMetaType::Void),
        // Signal 'PlanetTrailColorChanged'
        QtMocHelpers::SignalData<void()>(259, 2, QMC::AccessPublic, QMetaType::Void),
        // Signal 'SkyColorChanged'
        QtMocHelpers::SignalData<void()>(260, 2, QMC::AccessPublic, QMetaType::Void),
        // Signal 'SkyColorDaytimeChanged'
        QtMocHelpers::SignalData<void()>(261, 2, QMC::AccessPublic, QMetaType::Void),
        // Signal 'ArtificialHorizonColorChanged'
        QtMocHelpers::SignalData<void()>(262, 2, QMC::AccessPublic, QMetaType::Void),
        // Signal 'TelescopeTargetColorChanged'
        QtMocHelpers::SignalData<void()>(263, 2, QMC::AccessPublic, QMetaType::Void),
        // Signal 'VisibleSatColorChanged'
        QtMocHelpers::SignalData<void()>(264, 2, QMC::AccessPublic, QMetaType::Void),
        // Signal 'SatColorChanged'
        QtMocHelpers::SignalData<void()>(265, 2, QMC::AccessPublic, QMetaType::Void),
        // Signal 'SatLabelColorChanged'
        QtMocHelpers::SignalData<void()>(266, 2, QMC::AccessPublic, QMetaType::Void),
        // Signal 'SupernovaColorChanged'
        QtMocHelpers::SignalData<void()>(267, 2, QMC::AccessPublic, QMetaType::Void),
        // Signal 'AsteroidColorChanged'
        QtMocHelpers::SignalData<void()>(268, 2, QMC::AccessPublic, QMetaType::Void),
        // Signal 'UserLabelColorChanged'
        QtMocHelpers::SignalData<void()>(269, 2, QMC::AccessPublic, QMetaType::Void),
        // Signal 'RAGuideColorChanged'
        QtMocHelpers::SignalData<void()>(270, 2, QMC::AccessPublic, QMetaType::Void),
        // Signal 'DEGuideColorChanged'
        QtMocHelpers::SignalData<void()>(271, 2, QMC::AccessPublic, QMetaType::Void),
        // Signal 'SolverFOVColorChanged'
        QtMocHelpers::SignalData<void()>(272, 2, QMC::AccessPublic, QMetaType::Void),
        // Signal 'xplanetIsInternalChanged'
        QtMocHelpers::SignalData<void()>(273, 2, QMC::AccessPublic, QMetaType::Void),
        // Signal 'XplanetPathChanged'
        QtMocHelpers::SignalData<void()>(274, 2, QMC::AccessPublic, QMetaType::Void),
        // Signal 'XplanetUseFIFOChanged'
        QtMocHelpers::SignalData<void()>(275, 2, QMC::AccessPublic, QMetaType::Void),
        // Signal 'XplanetTimeoutChanged'
        QtMocHelpers::SignalData<void()>(276, 2, QMC::AccessPublic, QMetaType::Void),
        // Signal 'XplanetAnimationDelayChanged'
        QtMocHelpers::SignalData<void()>(277, 2, QMC::AccessPublic, QMetaType::Void),
        // Signal 'XplanetWidthChanged'
        QtMocHelpers::SignalData<void()>(278, 2, QMC::AccessPublic, QMetaType::Void),
        // Signal 'XplanetHeightChanged'
        QtMocHelpers::SignalData<void()>(279, 2, QMC::AccessPublic, QMetaType::Void),
        // Signal 'XplanetLabelChanged'
        QtMocHelpers::SignalData<void()>(280, 2, QMC::AccessPublic, QMetaType::Void),
        // Signal 'XplanetLabelLocalTimeChanged'
        QtMocHelpers::SignalData<void()>(281, 2, QMC::AccessPublic, QMetaType::Void),
        // Signal 'XplanetLabelGMTChanged'
        QtMocHelpers::SignalData<void()>(282, 2, QMC::AccessPublic, QMetaType::Void),
        // Signal 'XplanetLabelStringChanged'
        QtMocHelpers::SignalData<void()>(283, 2, QMC::AccessPublic, QMetaType::Void),
        // Signal 'XplanetFontSizeChanged'
        QtMocHelpers::SignalData<void()>(284, 2, QMC::AccessPublic, QMetaType::Void),
        // Signal 'XplanetColorChanged'
        QtMocHelpers::SignalData<void()>(285, 2, QMC::AccessPublic, QMetaType::Void),
        // Signal 'XplanetDateFormatChanged'
        QtMocHelpers::SignalData<void()>(286, 2, QMC::AccessPublic, QMetaType::Void),
        // Signal 'XplanetLabelTLChanged'
        QtMocHelpers::SignalData<void()>(287, 2, QMC::AccessPublic, QMetaType::Void),
        // Signal 'XplanetLabelTRChanged'
        QtMocHelpers::SignalData<void()>(288, 2, QMC::AccessPublic, QMetaType::Void),
        // Signal 'XplanetLabelBRChanged'
        QtMocHelpers::SignalData<void()>(289, 2, QMC::AccessPublic, QMetaType::Void),
        // Signal 'XplanetLabelBLChanged'
        QtMocHelpers::SignalData<void()>(290, 2, QMC::AccessPublic, QMetaType::Void),
        // Signal 'XplanetGlareChanged'
        QtMocHelpers::SignalData<void()>(291, 2, QMC::AccessPublic, QMetaType::Void),
        // Signal 'XplanetRandomChanged'
        QtMocHelpers::SignalData<void()>(292, 2, QMC::AccessPublic, QMetaType::Void),
        // Signal 'XplanetLatLongChanged'
        QtMocHelpers::SignalData<void()>(293, 2, QMC::AccessPublic, QMetaType::Void),
        // Signal 'XplanetLatitudeChanged'
        QtMocHelpers::SignalData<void()>(294, 2, QMC::AccessPublic, QMetaType::Void),
        // Signal 'XplanetLongitudeChanged'
        QtMocHelpers::SignalData<void()>(295, 2, QMC::AccessPublic, QMetaType::Void),
        // Signal 'XplanetProjectionChanged'
        QtMocHelpers::SignalData<void()>(296, 2, QMC::AccessPublic, QMetaType::Void),
        // Signal 'XplanetBackgroundChanged'
        QtMocHelpers::SignalData<void()>(297, 2, QMC::AccessPublic, QMetaType::Void),
        // Signal 'XplanetBackgroundImageChanged'
        QtMocHelpers::SignalData<void()>(298, 2, QMC::AccessPublic, QMetaType::Void),
        // Signal 'XplanetBackgroundImagePathChanged'
        QtMocHelpers::SignalData<void()>(299, 2, QMC::AccessPublic, QMetaType::Void),
        // Signal 'XplanetBackgroundColorChanged'
        QtMocHelpers::SignalData<void()>(300, 2, QMC::AccessPublic, QMetaType::Void),
        // Signal 'XplanetBackgroundColorValueChanged'
        QtMocHelpers::SignalData<void()>(301, 2, QMC::AccessPublic, QMetaType::Void),
        // Signal 'XplanetMagnitudeChanged'
        QtMocHelpers::SignalData<void()>(302, 2, QMC::AccessPublic, QMetaType::Void),
        // Signal 'XplanetArcFileChanged'
        QtMocHelpers::SignalData<void()>(303, 2, QMC::AccessPublic, QMetaType::Void),
        // Signal 'XplanetArcFilePathChanged'
        QtMocHelpers::SignalData<void()>(304, 2, QMC::AccessPublic, QMetaType::Void),
        // Signal 'XplanetConfigFileChanged'
        QtMocHelpers::SignalData<void()>(305, 2, QMC::AccessPublic, QMetaType::Void),
        // Signal 'XplanetConfigFilePathChanged'
        QtMocHelpers::SignalData<void()>(306, 2, QMC::AccessPublic, QMetaType::Void),
        // Signal 'XplanetFOVChanged'
        QtMocHelpers::SignalData<void()>(307, 2, QMC::AccessPublic, QMetaType::Void),
        // Signal 'XplanetMarkerFileChanged'
        QtMocHelpers::SignalData<void()>(308, 2, QMC::AccessPublic, QMetaType::Void),
        // Signal 'XplanetMarkerFilePathChanged'
        QtMocHelpers::SignalData<void()>(309, 2, QMC::AccessPublic, QMetaType::Void),
        // Signal 'XplanetMarkerBoundsChanged'
        QtMocHelpers::SignalData<void()>(310, 2, QMC::AccessPublic, QMetaType::Void),
        // Signal 'XplanetMarkerBoundsPathChanged'
        QtMocHelpers::SignalData<void()>(311, 2, QMC::AccessPublic, QMetaType::Void),
        // Signal 'XplanetStarmapChanged'
        QtMocHelpers::SignalData<void()>(312, 2, QMC::AccessPublic, QMetaType::Void),
        // Signal 'XplanetStarmapPathChanged'
        QtMocHelpers::SignalData<void()>(313, 2, QMC::AccessPublic, QMetaType::Void),
        // Signal 'XplanetQualityChanged'
        QtMocHelpers::SignalData<void()>(314, 2, QMC::AccessPublic, QMetaType::Void),
        // Signal 'ShowSatellitesChanged'
        QtMocHelpers::SignalData<void()>(315, 2, QMC::AccessPublic, QMetaType::Void),
        // Signal 'ShowVisibleSatellitesChanged'
        QtMocHelpers::SignalData<void()>(316, 2, QMC::AccessPublic, QMetaType::Void),
        // Signal 'DrawSatellitesLikeStarsChanged'
        QtMocHelpers::SignalData<void()>(317, 2, QMC::AccessPublic, QMetaType::Void),
        // Signal 'ShowSatellitesLabelsChanged'
        QtMocHelpers::SignalData<void()>(318, 2, QMC::AccessPublic, QMetaType::Void),
        // Signal 'SelectedSatellitesChanged'
        QtMocHelpers::SignalData<void()>(319, 2, QMC::AccessPublic, QMetaType::Void),
        // Signal 'KStarsFirstRunChanged'
        QtMocHelpers::SignalData<void()>(320, 2, QMC::AccessPublic, QMetaType::Void),
        // Signal 'AlwaysRecomputeCoordinatesChanged'
        QtMocHelpers::SignalData<void()>(321, 2, QMC::AccessPublic, QMetaType::Void),
        // Signal 'DefaultDSSImageSizeChanged'
        QtMocHelpers::SignalData<void()>(322, 2, QMC::AccessPublic, QMetaType::Void),
        // Signal 'DSSPaddingChanged'
        QtMocHelpers::SignalData<void()>(323, 2, QMC::AccessPublic, QMetaType::Void),
        // Signal 'VerboseLoggingChanged'
        QtMocHelpers::SignalData<void()>(324, 2, QMC::AccessPublic, QMetaType::Void),
        // Signal 'RegularLoggingChanged'
        QtMocHelpers::SignalData<void()>(325, 2, QMC::AccessPublic, QMetaType::Void),
        // Signal 'DisableLoggingChanged'
        QtMocHelpers::SignalData<void()>(326, 2, QMC::AccessPublic, QMetaType::Void),
        // Signal 'LogToDefaultChanged'
        QtMocHelpers::SignalData<void()>(327, 2, QMC::AccessPublic, QMetaType::Void),
        // Signal 'LogToFileChanged'
        QtMocHelpers::SignalData<void()>(328, 2, QMC::AccessPublic, QMetaType::Void),
        // Signal 'FITSLoggingChanged'
        QtMocHelpers::SignalData<void()>(329, 2, QMC::AccessPublic, QMetaType::Void),
        // Signal 'INDILoggingChanged'
        QtMocHelpers::SignalData<void()>(330, 2, QMC::AccessPublic, QMetaType::Void),
        // Signal 'CaptureLoggingChanged'
        QtMocHelpers::SignalData<void()>(331, 2, QMC::AccessPublic, QMetaType::Void),
        // Signal 'FocusLoggingChanged'
        QtMocHelpers::SignalData<void()>(332, 2, QMC::AccessPublic, QMetaType::Void),
        // Signal 'SaveGuideImagesChanged'
        QtMocHelpers::SignalData<void()>(333, 2, QMC::AccessPublic, QMetaType::Void),
        // Signal 'SaveAlignImagesChanged'
        QtMocHelpers::SignalData<void()>(334, 2, QMC::AccessPublic, QMetaType::Void),
        // Signal 'SaveFailedAlignImagesChanged'
        QtMocHelpers::SignalData<void()>(335, 2, QMC::AccessPublic, QMetaType::Void),
        // Signal 'DontSyncToRealTimeChanged'
        QtMocHelpers::SignalData<void()>(336, 2, QMC::AccessPublic, QMetaType::Void),
        // Signal 'GuideLoggingChanged'
        QtMocHelpers::SignalData<void()>(337, 2, QMC::AccessPublic, QMetaType::Void),
        // Signal 'AlignmentLoggingChanged'
        QtMocHelpers::SignalData<void()>(338, 2, QMC::AccessPublic, QMetaType::Void),
        // Signal 'MountLoggingChanged'
        QtMocHelpers::SignalData<void()>(339, 2, QMC::AccessPublic, QMetaType::Void),
        // Signal 'ObservatoryLoggingChanged'
        QtMocHelpers::SignalData<void()>(340, 2, QMC::AccessPublic, QMetaType::Void),
        // Signal 'ImageDebayerEngineChanged'
        QtMocHelpers::SignalData<void()>(341, 2, QMC::AccessPublic, QMetaType::Void),
        // Signal 'ImageDebayerAlgoChanged'
        QtMocHelpers::SignalData<void()>(342, 2, QMC::AccessPublic, QMetaType::Void),
        // Signal 'StackDebayerEngineChanged'
        QtMocHelpers::SignalData<void()>(343, 2, QMC::AccessPublic, QMetaType::Void),
        // Signal 'StackDebayerAlgoChanged'
        QtMocHelpers::SignalData<void()>(344, 2, QMC::AccessPublic, QMetaType::Void),
        // Signal 'FITSWindowGeometryChanged'
        QtMocHelpers::SignalData<void()>(345, 2, QMC::AccessPublic, QMetaType::Void),
        // Signal 'useFITSViewerChanged'
        QtMocHelpers::SignalData<void()>(346, 2, QMC::AccessPublic, QMetaType::Void),
        // Signal 'singlePreviewFITSChanged'
        QtMocHelpers::SignalData<void()>(347, 2, QMC::AccessPublic, QMetaType::Void),
        // Signal 'singleWindowCapturedFITSChanged'
        QtMocHelpers::SignalData<void()>(348, 2, QMC::AccessPublic, QMetaType::Void),
        // Signal 'singleWindowOpenedFITSChanged'
        QtMocHelpers::SignalData<void()>(349, 2, QMC::AccessPublic, QMetaType::Void),
        // Signal 'focusFITSOnNewImageChanged'
        QtMocHelpers::SignalData<void()>(350, 2, QMC::AccessPublic, QMetaType::Void),
        // Signal 'independentWindowFITSChanged'
        QtMocHelpers::SignalData<void()>(351, 2, QMC::AccessPublic, QMetaType::Void),
        // Signal 'liveStackerOwnProcessChanged'
        QtMocHelpers::SignalData<void()>(352, 2, QMC::AccessPublic, QMetaType::Void),
        // Signal 'AutoDebayerChanged'
        QtMocHelpers::SignalData<void()>(353, 2, QMC::AccessPublic, QMetaType::Void),
        // Signal 'Auto3DCubeChanged'
        QtMocHelpers::SignalData<void()>(354, 2, QMC::AccessPublic, QMetaType::Void),
        // Signal 'AutoHFRChanged'
        QtMocHelpers::SignalData<void()>(355, 2, QMC::AccessPublic, QMetaType::Void),
        // Signal 'QuickHFRChanged'
        QtMocHelpers::SignalData<void()>(356, 2, QMC::AccessPublic, QMetaType::Void),
        // Signal 'StellarSolverPartitionChanged'
        QtMocHelpers::SignalData<void()>(357, 2, QMC::AccessPublic, QMetaType::Void),
        // Signal 'AutoWCSChanged'
        QtMocHelpers::SignalData<void()>(358, 2, QMC::AccessPublic, QMetaType::Void),
        // Signal 'LimitedResourcesModeChanged'
        QtMocHelpers::SignalData<void()>(359, 2, QMC::AccessPublic, QMetaType::Void),
        // Signal 'NonLinearHistogramChanged'
        QtMocHelpers::SignalData<void()>(360, 2, QMC::AccessPublic, QMetaType::Void),
        // Signal 'HIPSOpacityChanged'
        QtMocHelpers::SignalData<void()>(361, 2, QMC::AccessPublic, QMetaType::Void),
        // Signal 'HIPSOffsetXChanged'
        QtMocHelpers::SignalData<void()>(362, 2, QMC::AccessPublic, QMetaType::Void),
        // Signal 'HIPSOffsetYChanged'
        QtMocHelpers::SignalData<void()>(363, 2, QMC::AccessPublic, QMetaType::Void),
        // Signal 'FitsSolverProfileChanged'
        QtMocHelpers::SignalData<void()>(364, 2, QMC::AccessPublic, QMetaType::Void),
        // Signal 'FitsSolverModuleChanged'
        QtMocHelpers::SignalData<void()>(365, 2, QMC::AccessPublic, QMetaType::Void),
        // Signal 'FitsSolverProfileIndecesChanged'
        QtMocHelpers::SignalData<void()>(366, 2, QMC::AccessPublic, QMetaType::Void),
        // Signal 'FitsCatalogChanged'
        QtMocHelpers::SignalData<void()>(367, 2, QMC::AccessPublic, QMetaType::Void),
        // Signal 'FitsCatObjShowNamesChanged'
        QtMocHelpers::SignalData<void()>(368, 2, QMC::AccessPublic, QMetaType::Void),
        // Signal 'FitsSolverUseScaleChanged'
        QtMocHelpers::SignalData<void()>(369, 2, QMC::AccessPublic, QMetaType::Void),
        // Signal 'FitsSolverUsePositionChanged'
        QtMocHelpers::SignalData<void()>(370, 2, QMC::AccessPublic, QMetaType::Void),
        // Signal 'FitsSolverScaleChanged'
        QtMocHelpers::SignalData<void()>(371, 2, QMC::AccessPublic, QMetaType::Void),
        // Signal 'FitsSolverImageScaleUnitsChanged'
        QtMocHelpers::SignalData<void()>(372, 2, QMC::AccessPublic, QMetaType::Void),
        // Signal 'FitsSolverRadiusChanged'
        QtMocHelpers::SignalData<void()>(373, 2, QMC::AccessPublic, QMetaType::Void),
        // Signal 'fitsLSHideGeneralChanged'
        QtMocHelpers::SignalData<void()>(374, 2, QMC::AccessPublic, QMetaType::Void),
        // Signal 'fitsLSHideCalibrationChanged'
        QtMocHelpers::SignalData<void()>(375, 2, QMC::AccessPublic, QMetaType::Void),
        // Signal 'fitsLSHideAlignmentChanged'
        QtMocHelpers::SignalData<void()>(376, 2, QMC::AccessPublic, QMetaType::Void),
        // Signal 'fitsLSHideStackingChanged'
        QtMocHelpers::SignalData<void()>(377, 2, QMC::AccessPublic, QMetaType::Void),
        // Signal 'fitsLSHidePostProcChanged'
        QtMocHelpers::SignalData<void()>(378, 2, QMC::AccessPublic, QMetaType::Void),
        // Signal 'fitsLSCalcSNRChanged'
        QtMocHelpers::SignalData<void()>(379, 2, QMC::AccessPublic, QMetaType::Void),
        // Signal 'fitsLSMasterDarkChanged'
        QtMocHelpers::SignalData<void()>(380, 2, QMC::AccessPublic, QMetaType::Void),
        // Signal 'fitsLSMasterFlatChanged'
        QtMocHelpers::SignalData<void()>(381, 2, QMC::AccessPublic, QMetaType::Void),
        // Signal 'fitsLSHotPixelsChanged'
        QtMocHelpers::SignalData<void()>(382, 2, QMC::AccessPublic, QMetaType::Void),
        // Signal 'fitsLSColdPixelsChanged'
        QtMocHelpers::SignalData<void()>(383, 2, QMC::AccessPublic, QMetaType::Void),
        // Signal 'fitsLSAlignMethodChanged'
        QtMocHelpers::SignalData<void()>(384, 2, QMC::AccessPublic, QMetaType::Void),
        // Signal 'fitsLSNumInMemChanged'
        QtMocHelpers::SignalData<void()>(385, 2, QMC::AccessPublic, QMetaType::Void),
        // Signal 'fitsLSDownscaleChanged'
        QtMocHelpers::SignalData<void()>(386, 2, QMC::AccessPublic, QMetaType::Void),
        // Signal 'fitsLSWeightingChanged'
        QtMocHelpers::SignalData<void()>(387, 2, QMC::AccessPublic, QMetaType::Void),
        // Signal 'fitsLSNormalizationChanged'
        QtMocHelpers::SignalData<void()>(388, 2, QMC::AccessPublic, QMetaType::Void),
        // Signal 'fitsLSStackingMethodChanged'
        QtMocHelpers::SignalData<void()>(389, 2, QMC::AccessPublic, QMetaType::Void),
        // Signal 'fitsLSLowSigmaChanged'
        QtMocHelpers::SignalData<void()>(390, 2, QMC::AccessPublic, QMetaType::Void),
        // Signal 'fitsLSHighSigmaChanged'
        QtMocHelpers::SignalData<void()>(391, 2, QMC::AccessPublic, QMetaType::Void),
        // Signal 'fitsLSWinsorCutoffChanged'
        QtMocHelpers::SignalData<void()>(392, 2, QMC::AccessPublic, QMetaType::Void),
        // Signal 'fitsLSIterationsChanged'
        QtMocHelpers::SignalData<void()>(393, 2, QMC::AccessPublic, QMetaType::Void),
        // Signal 'fitsLSKappaChanged'
        QtMocHelpers::SignalData<void()>(394, 2, QMC::AccessPublic, QMetaType::Void),
        // Signal 'fitsLSAlphaChanged'
        QtMocHelpers::SignalData<void()>(395, 2, QMC::AccessPublic, QMetaType::Void),
        // Signal 'fitsLSSigmaChanged'
        QtMocHelpers::SignalData<void()>(396, 2, QMC::AccessPublic, QMetaType::Void),
        // Signal 'fitsPSFUpdateChanged'
        QtMocHelpers::SignalData<void()>(397, 2, QMC::AccessPublic, QMetaType::Void),
        // Signal 'fitsLSPostProcChanged'
        QtMocHelpers::SignalData<void()>(398, 2, QMC::AccessPublic, QMetaType::Void),
        // Signal 'fitsLSGradientAmtChanged'
        QtMocHelpers::SignalData<void()>(399, 2, QMC::AccessPublic, QMetaType::Void),
        // Signal 'fitsLSDeconvAmtChanged'
        QtMocHelpers::SignalData<void()>(400, 2, QMC::AccessPublic, QMetaType::Void),
        // Signal 'fitsLSPSFSigmaChanged'
        QtMocHelpers::SignalData<void()>(401, 2, QMC::AccessPublic, QMetaType::Void),
        // Signal 'fitsLSDenoiseAmtChanged'
        QtMocHelpers::SignalData<void()>(402, 2, QMC::AccessPublic, QMetaType::Void),
        // Signal 'fitsLSSharpenAmtChanged'
        QtMocHelpers::SignalData<void()>(403, 2, QMC::AccessPublic, QMetaType::Void),
        // Signal 'fitsLSSharpenKernalChanged'
        QtMocHelpers::SignalData<void()>(404, 2, QMC::AccessPublic, QMetaType::Void),
        // Signal 'fitsLSSharpenSigmaChanged'
        QtMocHelpers::SignalData<void()>(405, 2, QMC::AccessPublic, QMetaType::Void),
        // Signal 'fitsLSMWindowGeometryChanged'
        QtMocHelpers::SignalData<void()>(406, 2, QMC::AccessPublic, QMetaType::Void),
        // Signal 'fitsLSMVisibleColumnsChanged'
        QtMocHelpers::SignalData<void()>(407, 2, QMC::AccessPublic, QMetaType::Void),
        // Signal 'fitsLSMColumnWidthsChanged'
        QtMocHelpers::SignalData<void()>(408, 2, QMC::AccessPublic, QMetaType::Void),
        // Signal 'fitsLSMSortColumnChanged'
        QtMocHelpers::SignalData<void()>(409, 2, QMC::AccessPublic, QMetaType::Void),
        // Signal 'fitsLSMSortOrderChanged'
        QtMocHelpers::SignalData<void()>(410, 2, QMC::AccessPublic, QMetaType::Void),
        // Signal 'fitsLSMHighlightingChanged'
        QtMocHelpers::SignalData<void()>(411, 2, QMC::AccessPublic, QMetaType::Void),
        // Signal 'fitsLSWebcastTitleChanged'
        QtMocHelpers::SignalData<void()>(412, 2, QMC::AccessPublic, QMetaType::Void),
        // Signal 'fitsLSWebcastLogoLChanged'
        QtMocHelpers::SignalData<void()>(413, 2, QMC::AccessPublic, QMetaType::Void),
        // Signal 'fitsLSWebcastLogoRChanged'
        QtMocHelpers::SignalData<void()>(414, 2, QMC::AccessPublic, QMetaType::Void),
        // Signal 'fitsLSWebcastPortChanged'
        QtMocHelpers::SignalData<void()>(415, 2, QMC::AccessPublic, QMetaType::Void),
        // Signal 'fitsLSWebcastThrottleChanged'
        QtMocHelpers::SignalData<void()>(416, 2, QMC::AccessPublic, QMetaType::Void),
        // Signal 'BortleClassChanged'
        QtMocHelpers::SignalData<void()>(417, 2, QMC::AccessPublic, QMetaType::Void),
        // Signal 'TelescopeCheckChanged'
        QtMocHelpers::SignalData<void()>(418, 2, QMC::AccessPublic, QMetaType::Void),
        // Signal 'BinocularsCheckChanged'
        QtMocHelpers::SignalData<void()>(419, 2, QMC::AccessPublic, QMetaType::Void),
        // Signal 'BinocularsApertureChanged'
        QtMocHelpers::SignalData<void()>(420, 2, QMC::AccessPublic, QMetaType::Void),
        // Signal 'ScopeListIndexChanged'
        QtMocHelpers::SignalData<void()>(421, 2, QMC::AccessPublic, QMetaType::Void),
        // Signal 'EkosWindowWidthChanged'
        QtMocHelpers::SignalData<void()>(422, 2, QMC::AccessPublic, QMetaType::Void),
        // Signal 'EkosWindowHeightChanged'
        QtMocHelpers::SignalData<void()>(423, 2, QMC::AccessPublic, QMetaType::Void),
        // Signal 'EkosGeometryChanged'
        QtMocHelpers::SignalData<void()>(424, 2, QMC::AccessPublic, QMetaType::Void),
        // Signal 'EkosTopIconsChanged'
        QtMocHelpers::SignalData<void()>(425, 2, QMC::AccessPublic, QMetaType::Void),
        // Signal 'EkosLeftIconsChanged'
        QtMocHelpers::SignalData<void()>(426, 2, QMC::AccessPublic, QMetaType::Void),
        // Signal 'independentWindowEkosChanged'
        QtMocHelpers::SignalData<void()>(427, 2, QMC::AccessPublic, QMetaType::Void),
        // Signal 'profileChanged'
        QtMocHelpers::SignalData<void()>(428, 2, QMC::AccessPublic, QMetaType::Void),
        // Signal 'neverLoadConfigChanged'
        QtMocHelpers::SignalData<void()>(429, 2, QMC::AccessPublic, QMetaType::Void),
        // Signal 'loadConfigOnConnectionChanged'
        QtMocHelpers::SignalData<void()>(430, 2, QMC::AccessPublic, QMetaType::Void),
        // Signal 'loadDefaultConfigChanged'
        QtMocHelpers::SignalData<void()>(431, 2, QMC::AccessPublic, QMetaType::Void),
        // Signal 'autoLoadSerialAssistantChanged'
        QtMocHelpers::SignalData<void()>(432, 2, QMC::AccessPublic, QMetaType::Void),
        // Signal 'RememberCredentialsChanged'
        QtMocHelpers::SignalData<void()>(433, 2, QMC::AccessPublic, QMetaType::Void),
        // Signal 'AutoStartEkosLiveChanged'
        QtMocHelpers::SignalData<void()>(434, 2, QMC::AccessPublic, QMetaType::Void),
        // Signal 'EkosLiveUsernameChanged'
        QtMocHelpers::SignalData<void()>(435, 2, QMC::AccessPublic, QMetaType::Void),
        // Signal 'EkosLiveObservatoryChanged'
        QtMocHelpers::SignalData<void()>(436, 2, QMC::AccessPublic, QMetaType::Void),
        // Signal 'EkosLiveOfflineServerChanged'
        QtMocHelpers::SignalData<void()>(437, 2, QMC::AccessPublic, QMetaType::Void),
        // Signal 'EkosLiveOnlineServerChanged'
        QtMocHelpers::SignalData<void()>(438, 2, QMC::AccessPublic, QMetaType::Void),
        // Signal 'EkosLiveSoundChanged'
        QtMocHelpers::SignalData<void()>(439, 2, QMC::AccessPublic, QMetaType::Void),
        // Signal 'EkosLiveNotificationsChanged'
        QtMocHelpers::SignalData<void()>(440, 2, QMC::AccessPublic, QMetaType::Void),
        // Signal 'EkosLiveCloudChanged'
        QtMocHelpers::SignalData<void()>(441, 2, QMC::AccessPublic, QMetaType::Void),
        // Signal 'MaxDarkTemperatureDiffChanged'
        QtMocHelpers::SignalData<void()>(442, 2, QMC::AccessPublic, QMetaType::Void),
        // Signal 'shutterfulCCDsChanged'
        QtMocHelpers::SignalData<void()>(443, 2, QMC::AccessPublic, QMetaType::Void),
        // Signal 'shutterlessCCDsChanged'
        QtMocHelpers::SignalData<void()>(444, 2, QMC::AccessPublic, QMetaType::Void),
        // Signal 'DarkLibraryDurationChanged'
        QtMocHelpers::SignalData<void()>(445, 2, QMC::AccessPublic, QMetaType::Void),
        // Signal 'UseGraphicalCountsDisplayChanged'
        QtMocHelpers::SignalData<void()>(446, 2, QMC::AccessPublic, QMetaType::Void),
        // Signal 'MinimumAltLimitChanged'
        QtMocHelpers::SignalData<void()>(447, 2, QMC::AccessPublic, QMetaType::Void),
        // Signal 'MaximumAltLimitChanged'
        QtMocHelpers::SignalData<void()>(448, 2, QMC::AccessPublic, QMetaType::Void),
        // Signal 'EnableAltitudeLimitsChanged'
        QtMocHelpers::SignalData<void()>(449, 2, QMC::AccessPublic, QMetaType::Void),
        // Signal 'EnableAltitudeLimitsTrackingOnlyChanged'
        QtMocHelpers::SignalData<void()>(450, 2, QMC::AccessPublic, QMetaType::Void),
        // Signal 'ConfirmBelowHorizonChanged'
        QtMocHelpers::SignalData<void()>(451, 2, QMC::AccessPublic, QMetaType::Void),
        // Signal 'MeridianFlipOffsetDegreesChanged'
        QtMocHelpers::SignalData<void()>(452, 2, QMC::AccessPublic, QMetaType::Void),
        // Signal 'MaximumHaLimitChanged'
        QtMocHelpers::SignalData<void()>(453, 2, QMC::AccessPublic, QMetaType::Void),
        // Signal 'EnableHaLimitChanged'
        QtMocHelpers::SignalData<void()>(454, 2, QMC::AccessPublic, QMetaType::Void),
        // Signal 'ExecuteMeridianFlipChanged'
        QtMocHelpers::SignalData<void()>(455, 2, QMC::AccessPublic, QMetaType::Void),
        // Signal 'LeftRightReversedChanged'
        QtMocHelpers::SignalData<void()>(456, 2, QMC::AccessPublic, QMetaType::Void),
        // Signal 'UpDownReversedChanged'
        QtMocHelpers::SignalData<void()>(457, 2, QMC::AccessPublic, QMetaType::Void),
        // Signal 'ParkEveryDayChanged'
        QtMocHelpers::SignalData<void()>(458, 2, QMC::AccessPublic, QMetaType::Void),
        // Signal 'ParkTimeChanged'
        QtMocHelpers::SignalData<void()>(459, 2, QMC::AccessPublic, QMetaType::Void),
        // Signal 'DefaultObserverChanged'
        QtMocHelpers::SignalData<void()>(460, 2, QMC::AccessPublic, QMetaType::Void),
        // Signal 'SyncFOVPAChanged'
        QtMocHelpers::SignalData<void()>(461, 2, QMC::AccessPublic, QMetaType::Void),
        // Signal 'PAMultiplierChanged'
        QtMocHelpers::SignalData<void()>(462, 2, QMC::AccessPublic, QMetaType::Void),
        // Signal 'PAOffsetChanged'
        QtMocHelpers::SignalData<void()>(463, 2, QMC::AccessPublic, QMetaType::Void),
        // Signal 'PAPierSideChanged'
        QtMocHelpers::SignalData<void()>(464, 2, QMC::AccessPublic, QMetaType::Void),
        // Signal 'GuideDeviationChanged'
        QtMocHelpers::SignalData<void()>(465, 2, QMC::AccessPublic, QMetaType::Void),
        // Signal 'GuideDeviationRepsChanged'
        QtMocHelpers::SignalData<void()>(466, 2, QMC::AccessPublic, QMetaType::Void),
        // Signal 'StartGuideDeviationChanged'
        QtMocHelpers::SignalData<void()>(467, 2, QMC::AccessPublic, QMetaType::Void),
        // Signal 'GuideDitherPerJobFrequencyChanged'
        QtMocHelpers::SignalData<void()>(468, 2, QMC::AccessPublic, QMetaType::Void),
        // Signal 'HFRDeviationChanged'
        QtMocHelpers::SignalData<void()>(469, 2, QMC::AccessPublic, QMetaType::Void),
        // Signal 'MaxFocusTemperatureDeltaChanged'
        QtMocHelpers::SignalData<void()>(470, 2, QMC::AccessPublic, QMetaType::Void),
        // Signal 'AutoDarkChanged'
        QtMocHelpers::SignalData<void()>(471, 2, QMC::AccessPublic, QMetaType::Void),
        // Signal 'EnforceGuideDeviationChanged'
        QtMocHelpers::SignalData<void()>(472, 2, QMC::AccessPublic, QMetaType::Void),
        // Signal 'EnforceAutofocusHFRChanged'
        QtMocHelpers::SignalData<void()>(473, 2, QMC::AccessPublic, QMetaType::Void),
        // Signal 'EnforceAutofocusOnTemperatureChanged'
        QtMocHelpers::SignalData<void()>(474, 2, QMC::AccessPublic, QMetaType::Void),
        // Signal 'EnforceRefocusEveryNChanged'
        QtMocHelpers::SignalData<void()>(475, 2, QMC::AccessPublic, QMetaType::Void),
        // Signal 'RefocusEveryNChanged'
        QtMocHelpers::SignalData<void()>(476, 2, QMC::AccessPublic, QMetaType::Void),
        // Signal 'RefocusAfterMeridianFlipChanged'
        QtMocHelpers::SignalData<void()>(477, 2, QMC::AccessPublic, QMetaType::Void),
        // Signal 'ResetMountModelAfterMeridianChanged'
        QtMocHelpers::SignalData<void()>(478, 2, QMC::AccessPublic, QMetaType::Void),
        // Signal 'ForcedFlipChanged'
        QtMocHelpers::SignalData<void()>(479, 2, QMC::AccessPublic, QMetaType::Void),
        // Signal 'CalibrationADUValueChanged'
        QtMocHelpers::SignalData<void()>(480, 2, QMC::AccessPublic, QMetaType::Void),
        // Signal 'CalibrationADUValueToleranceChanged'
        QtMocHelpers::SignalData<void()>(481, 2, QMC::AccessPublic, QMetaType::Void),
        // Signal 'CalibrationPreActionIndexChanged'
        QtMocHelpers::SignalData<void()>(482, 2, QMC::AccessPublic, QMetaType::Void),
        // Signal 'CalibrationFlatDurationIndexChanged'
        QtMocHelpers::SignalData<void()>(483, 2, QMC::AccessPublic, QMetaType::Void),
        // Signal 'CalibrationWallAzChanged'
        QtMocHelpers::SignalData<void()>(484, 2, QMC::AccessPublic, QMetaType::Void),
        // Signal 'CalibrationWallAltChanged'
        QtMocHelpers::SignalData<void()>(485, 2, QMC::AccessPublic, QMetaType::Void),
        // Signal 'MaxTemperatureDiffChanged'
        QtMocHelpers::SignalData<void()>(486, 2, QMC::AccessPublic, QMetaType::Void),
        // Signal 'MaxStartGuiderDriftChanged'
        QtMocHelpers::SignalData<void()>(487, 2, QMC::AccessPublic, QMetaType::Void),
        // Signal 'EnforceStartGuiderDriftChanged'
        QtMocHelpers::SignalData<void()>(488, 2, QMC::AccessPublic, QMetaType::Void),
        // Signal 'GuidingSettleChanged'
        QtMocHelpers::SignalData<void()>(489, 2, QMC::AccessPublic, QMetaType::Void),
        // Signal 'AlwaysResetSequenceWhenStartingChanged'
        QtMocHelpers::SignalData<void()>(490, 2, QMC::AccessPublic, QMetaType::Void),
        // Signal 'FlatSyncFocusChanged'
        QtMocHelpers::SignalData<void()>(491, 2, QMC::AccessPublic, QMetaType::Void),
        // Signal 'HFRThresholdPercentageChanged'
        QtMocHelpers::SignalData<void()>(492, 2, QMC::AccessPublic, QMetaType::Void),
        // Signal 'HFRCheckAlgorithmChanged'
        QtMocHelpers::SignalData<void()>(493, 2, QMC::AccessPublic, QMetaType::Void),
        // Signal 'InSequenceCheckFramesChanged'
        QtMocHelpers::SignalData<void()>(494, 2, QMC::AccessPublic, QMetaType::Void),
        // Signal 'AutoStretchChanged'
        QtMocHelpers::SignalData<void()>(495, 2, QMC::AccessPublic, QMetaType::Void),
        // Signal 'StretchPreviewSamplingChanged'
        QtMocHelpers::SignalData<void()>(496, 2, QMC::AccessPublic, QMetaType::Void),
        // Signal 'Clipping64KValueChanged'
        QtMocHelpers::SignalData<void()>(497, 2, QMC::AccessPublic, QMetaType::Void),
        // Signal 'Clipping256ValueChanged'
        QtMocHelpers::SignalData<void()>(498, 2, QMC::AccessPublic, QMetaType::Void),
        // Signal 'AdaptiveSamplingChanged'
        QtMocHelpers::SignalData<void()>(499, 2, QMC::AccessPublic, QMetaType::Void),
        // Signal 'useSummaryPreviewChanged'
        QtMocHelpers::SignalData<void()>(500, 2, QMC::AccessPublic, QMetaType::Void),
        // Signal 'useDSLRImageViewerChanged'
        QtMocHelpers::SignalData<void()>(501, 2, QMC::AccessPublic, QMetaType::Void),
        // Signal 'ForceDSLRPresetsChanged'
        QtMocHelpers::SignalData<void()>(502, 2, QMC::AccessPublic, QMetaType::Void),
        // Signal 'CaptureDirectoryChanged'
        QtMocHelpers::SignalData<void()>(503, 2, QMC::AccessPublic, QMetaType::Void),
        // Signal 'PlaceholderFormatChanged'
        QtMocHelpers::SignalData<void()>(504, 2, QMC::AccessPublic, QMetaType::Void),
        // Signal 'RemoteCaptureDirectoryChanged'
        QtMocHelpers::SignalData<void()>(505, 2, QMC::AccessPublic, QMetaType::Void),
        // Signal 'ManualCoverTimeoutChanged'
        QtMocHelpers::SignalData<void()>(506, 2, QMC::AccessPublic, QMetaType::Void),
        // Signal 'CaptureOperationsTimeoutChanged'
        QtMocHelpers::SignalData<void()>(507, 2, QMC::AccessPublic, QMetaType::Void),
        // Signal 'MinFlipDurationChanged'
        QtMocHelpers::SignalData<void()>(508, 2, QMC::AccessPublic, QMetaType::Void),
        // Signal 'CapturePositionChanged'
        QtMocHelpers::SignalData<void()>(509, 2, QMC::AccessPublic, QMetaType::Void),
        // Signal 'CaptureTrainIDChanged'
        QtMocHelpers::SignalData<void()>(510, 2, QMC::AccessPublic, QMetaType::Void),
        // Signal 'CaptureCalibrationWallChanged'
        QtMocHelpers::SignalData<void()>(511, 2, QMC::AccessPublic, QMetaType::Void),
        // Signal 'CaptureCalibrationParkMountChanged'
        QtMocHelpers::SignalData<void()>(512, 2, QMC::AccessPublic, QMetaType::Void),
        // Signal 'CaptureCalibrationParkDomeChanged'
        QtMocHelpers::SignalData<void()>(513, 2, QMC::AccessPublic, QMetaType::Void),
        // Signal 'CaptureCalibrationUseManualChanged'
        QtMocHelpers::SignalData<void()>(514, 2, QMC::AccessPublic, QMetaType::Void),
        // Signal 'CaptureCalibrationUseADUChanged'
        QtMocHelpers::SignalData<void()>(515, 2, QMC::AccessPublic, QMetaType::Void),
        // Signal 'CaptureCalibrationADUValueChanged'
        QtMocHelpers::SignalData<void()>(516, 2, QMC::AccessPublic, QMetaType::Void),
        // Signal 'CaptureCalibrationADUToleranceChanged'
        QtMocHelpers::SignalData<void()>(517, 2, QMC::AccessPublic, QMetaType::Void),
        // Signal 'CaptureCalibrationSkyFlatsChanged'
        QtMocHelpers::SignalData<void()>(518, 2, QMC::AccessPublic, QMetaType::Void),
        // Signal 'AbsTicksSpinChanged'
        QtMocHelpers::SignalData<void()>(519, 2, QMC::AccessPublic, QMetaType::Void),
        // Signal 'FocusExposureChanged'
        QtMocHelpers::SignalData<void()>(520, 2, QMC::AccessPublic, QMetaType::Void),
        // Signal 'FocusBinningChanged'
        QtMocHelpers::SignalData<void()>(521, 2, QMC::AccessPublic, QMetaType::Void),
        // Signal 'FocusGainChanged'
        QtMocHelpers::SignalData<void()>(522, 2, QMC::AccessPublic, QMetaType::Void),
        // Signal 'FocusISOChanged'
        QtMocHelpers::SignalData<void()>(523, 2, QMC::AccessPublic, QMetaType::Void),
        // Signal 'DefaultFocusTemperatureSourceChanged'
        QtMocHelpers::SignalData<void()>(524, 2, QMC::AccessPublic, QMetaType::Void),
        // Signal 'FocusFilterChanged'
        QtMocHelpers::SignalData<void()>(525, 2, QMC::AccessPublic, QMetaType::Void),
        // Signal 'UseFocusDarkFrameChanged'
        QtMocHelpers::SignalData<void()>(526, 2, QMC::AccessPublic, QMetaType::Void),
        // Signal 'FocusSubFrameChanged'
        QtMocHelpers::SignalData<void()>(527, 2, QMC::AccessPublic, QMetaType::Void),
        // Signal 'FocusBoxSizeChanged'
        QtMocHelpers::SignalData<void()>(528, 2, QMC::AccessPublic, QMetaType::Void),
        // Signal 'FocusUseFullFieldChanged'
        QtMocHelpers::SignalData<void()>(529, 2, QMC::AccessPublic, QMetaType::Void),
        // Signal 'FocusNoMaskRBChanged'
        QtMocHelpers::SignalData<void()>(530, 2, QMC::AccessPublic, QMetaType::Void),
        // Signal 'focusRingMaskRBChanged'
        QtMocHelpers::SignalData<void()>(531, 2, QMC::AccessPublic, QMetaType::Void),
        // Signal 'focusMosaicMaskRBChanged'
        QtMocHelpers::SignalData<void()>(532, 2, QMC::AccessPublic, QMetaType::Void),
        // Signal 'FocusFullFieldInnerRadiusChanged'
        QtMocHelpers::SignalData<void()>(533, 2, QMC::AccessPublic, QMetaType::Void),
        // Signal 'FocusFullFieldOuterRadiusChanged'
        QtMocHelpers::SignalData<void()>(534, 2, QMC::AccessPublic, QMetaType::Void),
        // Signal 'FocusMosaicTileWidthChanged'
        QtMocHelpers::SignalData<void()>(535, 2, QMC::AccessPublic, QMetaType::Void),
        // Signal 'focusMosaicSpaceChanged'
        QtMocHelpers::SignalData<void()>(536, 2, QMC::AccessPublic, QMetaType::Void),
        // Signal 'FocusAutoStarEnabledChanged'
        QtMocHelpers::SignalData<void()>(537, 2, QMC::AccessPublic, QMetaType::Void),
        // Signal 'FocusSuspendGuidingChanged'
        QtMocHelpers::SignalData<void()>(538, 2, QMC::AccessPublic, QMetaType::Void),
        // Signal 'FocusGuideSettleTimeChanged'
        QtMocHelpers::SignalData<void()>(539, 2, QMC::AccessPublic, QMetaType::Void),
        // Signal 'FocusUnitsChanged'
        QtMocHelpers::SignalData<void()>(540, 2, QMC::AccessPublic, QMetaType::Void),
        // Signal 'FocusAdaptiveChanged'
        QtMocHelpers::SignalData<void()>(541, 2, QMC::AccessPublic, QMetaType::Void),
        // Signal 'focusAdaptiveMinMoveChanged'
        QtMocHelpers::SignalData<void()>(542, 2, QMC::AccessPublic, QMetaType::Void),
        // Signal 'FocusAdaptStartChanged'
        QtMocHelpers::SignalData<void()>(543, 2, QMC::AccessPublic, QMetaType::Void),
        // Signal 'focusAdaptiveMaxMoveChanged'
        QtMocHelpers::SignalData<void()>(544, 2, QMC::AccessPublic, QMetaType::Void),
        // Signal 'FocusDetectionChanged'
        QtMocHelpers::SignalData<void()>(545, 2, QMC::AccessPublic, QMetaType::Void),
        // Signal 'FocusSEPProfileChanged'
        QtMocHelpers::SignalData<void()>(546, 2, QMC::AccessPublic, QMetaType::Void),
        // Signal 'FocusAlgorithmChanged'
        QtMocHelpers::SignalData<void()>(547, 2, QMC::AccessPublic, QMetaType::Void),
        // Signal 'FocusCurveFitChanged'
        QtMocHelpers::SignalData<void()>(548, 2, QMC::AccessPublic, QMetaType::Void),
        // Signal 'FocusStarMeasureChanged'
        QtMocHelpers::SignalData<void()>(549, 2, QMC::AccessPublic, QMetaType::Void),
        // Signal 'FocusStarPSFChanged'
        QtMocHelpers::SignalData<void()>(550, 2, QMC::AccessPublic, QMetaType::Void),
        // Signal 'FocusUseWeightsChanged'
        QtMocHelpers::SignalData<void()>(551, 2, QMC::AccessPublic, QMetaType::Void),
        // Signal 'FocusR2LimitChanged'
        QtMocHelpers::SignalData<void()>(552, 2, QMC::AccessPublic, QMetaType::Void),
        // Signal 'FocusRefineCurveFitChanged'
        QtMocHelpers::SignalData<void()>(553, 2, QMC::AccessPublic, QMetaType::Void),
        // Signal 'focusFramesCountChanged'
        QtMocHelpers::SignalData<void()>(554, 2, QMC::AccessPublic, QMetaType::Void),
        // Signal 'focusHFRFramesCountChanged'
        QtMocHelpers::SignalData<void()>(555, 2, QMC::AccessPublic, QMetaType::Void),
        // Signal 'FocusMultiRowAverageChanged'
        QtMocHelpers::SignalData<void()>(556, 2, QMC::AccessPublic, QMetaType::Void),
        // Signal 'FocusGaussianSigmaChanged'
        QtMocHelpers::SignalData<void()>(557, 2, QMC::AccessPublic, QMetaType::Void),
        // Signal 'FocusThresholdChanged'
        QtMocHelpers::SignalData<void()>(558, 2, QMC::AccessPublic, QMetaType::Void),
        // Signal 'FocusDenoiseChanged'
        QtMocHelpers::SignalData<void()>(559, 2, QMC::AccessPublic, QMetaType::Void),
        // Signal 'FocusDonutChanged'
        QtMocHelpers::SignalData<void()>(560, 2, QMC::AccessPublic, QMetaType::Void),
        // Signal 'FocusTimeDilationChanged'
        QtMocHelpers::SignalData<void()>(561, 2, QMC::AccessPublic, QMetaType::Void),
        // Signal 'focusOutlierRejectionChanged'
        QtMocHelpers::SignalData<void()>(562, 2, QMC::AccessPublic, QMetaType::Void),
        // Signal 'focusScanStartPosChanged'
        QtMocHelpers::SignalData<void()>(563, 2, QMC::AccessPublic, QMetaType::Void),
        // Signal 'focusScanAlwaysOnChanged'
        QtMocHelpers::SignalData<void()>(564, 2, QMC::AccessPublic, QMetaType::Void),
        // Signal 'focusScanDatapointsChanged'
        QtMocHelpers::SignalData<void()>(565, 2, QMC::AccessPublic, QMetaType::Void),
        // Signal 'focusScanStepSizeFactorChanged'
        QtMocHelpers::SignalData<void()>(566, 2, QMC::AccessPublic, QMetaType::Void),
        // Signal 'FocusGaussianKernelSizeChanged'
        QtMocHelpers::SignalData<void()>(567, 2, QMC::AccessPublic, QMetaType::Void),
        // Signal 'FocusToleranceChanged'
        QtMocHelpers::SignalData<void()>(568, 2, QMC::AccessPublic, QMetaType::Void),
        // Signal 'FocusWalkChanged'
        QtMocHelpers::SignalData<void()>(569, 2, QMC::AccessPublic, QMetaType::Void),
        // Signal 'FocusSettleTimeChanged'
        QtMocHelpers::SignalData<void()>(570, 2, QMC::AccessPublic, QMetaType::Void),
        // Signal 'FocusTicksChanged'
        QtMocHelpers::SignalData<void()>(571, 2, QMC::AccessPublic, QMetaType::Void),
        // Signal 'FocusOutStepsChanged'
        QtMocHelpers::SignalData<void()>(572, 2, QMC::AccessPublic, QMetaType::Void),
        // Signal 'focusNumStepsChanged'
        QtMocHelpers::SignalData<void()>(573, 2, QMC::AccessPublic, QMetaType::Void),
        // Signal 'FocusMaxTravelChanged'
        QtMocHelpers::SignalData<void()>(574, 2, QMC::AccessPublic, QMetaType::Void),
        // Signal 'FocusMaxSingleStepChanged'
        QtMocHelpers::SignalData<void()>(575, 2, QMC::AccessPublic, QMetaType::Void),
        // Signal 'FocusBacklashChanged'
        QtMocHelpers::SignalData<void()>(576, 2, QMC::AccessPublic, QMetaType::Void),
        // Signal 'FocusAFOverscanChanged'
        QtMocHelpers::SignalData<void()>(577, 2, QMC::AccessPublic, QMetaType::Void),
        // Signal 'FocusOverscanDelayChanged'
        QtMocHelpers::SignalData<void()>(578, 2, QMC::AccessPublic, QMetaType::Void),
        // Signal 'FocusCaptureTimeoutChanged'
        QtMocHelpers::SignalData<void()>(579, 2, QMC::AccessPublic, QMetaType::Void),
        // Signal 'FocusMotionTimeoutChanged'
        QtMocHelpers::SignalData<void()>(580, 2, QMC::AccessPublic, QMetaType::Void),
        // Signal 'focusCFZAlgorithmChanged'
        QtMocHelpers::SignalData<void()>(581, 2, QMC::AccessPublic, QMetaType::Void),
        // Signal 'focusCFZToleranceChanged'
        QtMocHelpers::SignalData<void()>(582, 2, QMC::AccessPublic, QMetaType::Void),
        // Signal 'focusCFZTauChanged'
        QtMocHelpers::SignalData<void()>(583, 2, QMC::AccessPublic, QMetaType::Void),
        // Signal 'focusCFZDisplayVCurveChanged'
        QtMocHelpers::SignalData<void()>(584, 2, QMC::AccessPublic, QMetaType::Void),
        // Signal 'focusCFZWavelengthChanged'
        QtMocHelpers::SignalData<void()>(585, 2, QMC::AccessPublic, QMetaType::Void),
        // Signal 'focusCFZApertureChanged'
        QtMocHelpers::SignalData<void()>(586, 2, QMC::AccessPublic, QMetaType::Void),
        // Signal 'focusCFZFNumberChanged'
        QtMocHelpers::SignalData<void()>(587, 2, QMC::AccessPublic, QMetaType::Void),
        // Signal 'focusCFZSeeingChanged'
        QtMocHelpers::SignalData<void()>(588, 2, QMC::AccessPublic, QMetaType::Void),
        // Signal 'focusCFZStepSizeChanged'
        QtMocHelpers::SignalData<void()>(589, 2, QMC::AccessPublic, QMetaType::Void),
        // Signal 'focusAdvHelpOnlyChangesChanged'
        QtMocHelpers::SignalData<void()>(590, 2, QMC::AccessPublic, QMetaType::Void),
        // Signal 'focusAdvUpdateParamsChanged'
        QtMocHelpers::SignalData<void()>(591, 2, QMC::AccessPublic, QMetaType::Void),
        // Signal 'focusAdvFindStarsChanged'
        QtMocHelpers::SignalData<void()>(592, 2, QMC::AccessPublic, QMetaType::Void),
        // Signal 'focusAdvCourseAdjChanged'
        QtMocHelpers::SignalData<void()>(593, 2, QMC::AccessPublic, QMetaType::Void),
        // Signal 'focusAdvFineAdjChanged'
        QtMocHelpers::SignalData<void()>(594, 2, QMC::AccessPublic, QMetaType::Void),
        // Signal 'FocusSplitterChanged'
        QtMocHelpers::SignalData<void()>(595, 2, QMC::AccessPublic, QMetaType::Void),
        // Signal 'rightLayoutChanged'
        QtMocHelpers::SignalData<void()>(596, 2, QMC::AccessPublic, QMetaType::Void),
        // Signal 'adaptFocusBFOChanged'
        QtMocHelpers::SignalData<void()>(597, 2, QMC::AccessPublic, QMetaType::Void),
        // Signal 'abInsTileSelectionChanged'
        QtMocHelpers::SignalData<void()>(598, 2, QMC::AccessPublic, QMetaType::Void),
        // Signal 'abInsShowLabelsChanged'
        QtMocHelpers::SignalData<void()>(599, 2, QMC::AccessPublic, QMetaType::Void),
        // Signal 'abInsShowCFZChanged'
        QtMocHelpers::SignalData<void()>(600, 2, QMC::AccessPublic, QMetaType::Void),
        // Signal 'abInsOptCentresChanged'
        QtMocHelpers::SignalData<void()>(601, 2, QMC::AccessPublic, QMetaType::Void),
        // Signal 'abInsHSplitterChanged'
        QtMocHelpers::SignalData<void()>(602, 2, QMC::AccessPublic, QMetaType::Void),
        // Signal 'abInsVSplitterChanged'
        QtMocHelpers::SignalData<void()>(603, 2, QMC::AccessPublic, QMetaType::Void),
        // Signal 'abInsSelectionChanged'
        QtMocHelpers::SignalData<void()>(604, 2, QMC::AccessPublic, QMetaType::Void),
        // Signal 'abInsThemeChanged'
        QtMocHelpers::SignalData<void()>(605, 2, QMC::AccessPublic, QMetaType::Void),
        // Signal 'abInsLabelsChanged'
        QtMocHelpers::SignalData<void()>(606, 2, QMC::AccessPublic, QMetaType::Void),
        // Signal 'abInsSensorChanged'
        QtMocHelpers::SignalData<void()>(607, 2, QMC::AccessPublic, QMetaType::Void),
        // Signal 'abInsPetzvalWireChanged'
        QtMocHelpers::SignalData<void()>(608, 2, QMC::AccessPublic, QMetaType::Void),
        // Signal 'abInsPetzvalSurfaceChanged'
        QtMocHelpers::SignalData<void()>(609, 2, QMC::AccessPublic, QMetaType::Void),
        // Signal 'tiltPlateTypeChanged'
        QtMocHelpers::SignalData<void()>(610, 2, QMC::AccessPublic, QMetaType::Void),
        // Signal 'tiltRadiusChanged'
        QtMocHelpers::SignalData<void()>(611, 2, QMC::AccessPublic, QMetaType::Void),
        // Signal 'tiltThreadIndexChanged'
        QtMocHelpers::SignalData<void()>(612, 2, QMC::AccessPublic, QMetaType::Void),
        // Signal 'tiltScrewPitchChanged'
        QtMocHelpers::SignalData<void()>(613, 2, QMC::AccessPublic, QMetaType::Void),
        // Signal 'tiltRotationChanged'
        QtMocHelpers::SignalData<void()>(614, 2, QMC::AccessPublic, QMetaType::Void),
        // Signal 'tiltModeChanged'
        QtMocHelpers::SignalData<void()>(615, 2, QMC::AccessPublic, QMetaType::Void),
        // Signal 'tiltPlatePresentChanged'
        QtMocHelpers::SignalData<void()>(616, 2, QMC::AccessPublic, QMetaType::Void),
        // Signal 'FocusSextractorTypeChanged'
        QtMocHelpers::SignalData<void()>(617, 2, QMC::AccessPublic, QMetaType::Void),
        // Signal 'FocusOptionsProfileChanged'
        QtMocHelpers::SignalData<void()>(618, 2, QMC::AccessPublic, QMetaType::Void),
        // Signal 'HFRSextractorTypeChanged'
        QtMocHelpers::SignalData<void()>(619, 2, QMC::AccessPublic, QMetaType::Void),
        // Signal 'HFROptionsProfileChanged'
        QtMocHelpers::SignalData<void()>(620, 2, QMC::AccessPublic, QMetaType::Void),
        // Signal 'GuideSextractorTypeChanged'
        QtMocHelpers::SignalData<void()>(621, 2, QMC::AccessPublic, QMetaType::Void),
        // Signal 'GuideOptionsProfileChanged'
        QtMocHelpers::SignalData<void()>(622, 2, QMC::AccessPublic, QMetaType::Void),
        // Signal 'SolveSextractorTypeChanged'
        QtMocHelpers::SignalData<void()>(623, 2, QMC::AccessPublic, QMetaType::Void),
        // Signal 'SolverModeChanged'
        QtMocHelpers::SignalData<void()>(624, 2, QMC::AccessPublic, QMetaType::Void),
        // Signal 'SolverTypeChanged'
        QtMocHelpers::SignalData<void()>(625, 2, QMC::AccessPublic, QMetaType::Void),
        // Signal 'SolveOptionsProfileChanged'
        QtMocHelpers::SignalData<void()>(626, 2, QMC::AccessPublic, QMetaType::Void),
        // Signal 'LoggerLevelChanged'
        QtMocHelpers::SignalData<void()>(627, 2, QMC::AccessPublic, QMetaType::Void),
        // Signal 'AstrometryLogToFileChanged'
        QtMocHelpers::SignalData<void()>(628, 2, QMC::AccessPublic, QMetaType::Void),
        // Signal 'AstrometryLogFilepathChanged'
        QtMocHelpers::SignalData<void()>(629, 2, QMC::AccessPublic, QMetaType::Void),
        // Signal 'AstrometryIndexFolderListChanged'
        QtMocHelpers::SignalData<void()>(630, 2, QMC::AccessPublic, QMetaType::Void),
        // Signal 'AlignExposureChanged'
        QtMocHelpers::SignalData<void()>(631, 2, QMC::AccessPublic, QMetaType::Void),
        // Signal 'AlignBinningChanged'
        QtMocHelpers::SignalData<void()>(632, 2, QMC::AccessPublic, QMetaType::Void),
        // Signal 'AlignGainChanged'
        QtMocHelpers::SignalData<void()>(633, 2, QMC::AccessPublic, QMetaType::Void),
        // Signal 'AlignISOChanged'
        QtMocHelpers::SignalData<void()>(634, 2, QMC::AccessPublic, QMetaType::Void),
        // Signal 'AlignDarkFrameChanged'
        QtMocHelpers::SignalData<void()>(635, 2, QMC::AccessPublic, QMetaType::Void),
        // Signal 'AlignFilterChanged'
        QtMocHelpers::SignalData<void()>(636, 2, QMC::AccessPublic, QMetaType::Void),
        // Signal 'AlignUseCurrentFilterChanged'
        QtMocHelpers::SignalData<void()>(637, 2, QMC::AccessPublic, QMetaType::Void),
        // Signal 'AstrometryUseRotatorChanged'
        QtMocHelpers::SignalData<void()>(638, 2, QMC::AccessPublic, QMetaType::Void),
        // Signal 'AstrometryRotatorThresholdChanged'
        QtMocHelpers::SignalData<void()>(639, 2, QMC::AccessPublic, QMetaType::Void),
        // Signal 'AstrometryFlipRotationAllowedChanged'
        QtMocHelpers::SignalData<void()>(640, 2, QMC::AccessPublic, QMetaType::Void),
        // Signal 'RotatorParityReversedChanged'
        QtMocHelpers::SignalData<void()>(641, 2, QMC::AccessPublic, QMetaType::Void),
        // Signal 'AstrometrySolverWCSChanged'
        QtMocHelpers::SignalData<void()>(642, 2, QMC::AccessPublic, QMetaType::Void),
        // Signal 'AstrometrySolverOverlayChanged'
        QtMocHelpers::SignalData<void()>(643, 2, QMC::AccessPublic, QMetaType::Void),
        // Signal 'AstrometryDifferentialSlewingChanged'
        QtMocHelpers::SignalData<void()>(644, 2, QMC::AccessPublic, QMetaType::Void),
        // Signal 'AlignAccuracyThresholdChanged'
        QtMocHelpers::SignalData<void()>(645, 2, QMC::AccessPublic, QMetaType::Void),
        // Signal 'AlignSettlingTimeChanged'
        QtMocHelpers::SignalData<void()>(646, 2, QMC::AccessPublic, QMetaType::Void),
        // Signal 'AstrometryUseNoFITS2FITSChanged'
        QtMocHelpers::SignalData<void()>(647, 2, QMC::AccessPublic, QMetaType::Void),
        // Signal 'AstrometryUseResortChanged'
        QtMocHelpers::SignalData<void()>(648, 2, QMC::AccessPublic, QMetaType::Void),
        // Signal 'AstrometryUseNoVerifyChanged'
        QtMocHelpers::SignalData<void()>(649, 2, QMC::AccessPublic, QMetaType::Void),
        // Signal 'AstrometryUseImageScaleChanged'
        QtMocHelpers::SignalData<void()>(650, 2, QMC::AccessPublic, QMetaType::Void),
        // Signal 'AstrometryImageScaleLowChanged'
        QtMocHelpers::SignalData<void()>(651, 2, QMC::AccessPublic, QMetaType::Void),
        // Signal 'AstrometryImageScaleHighChanged'
        QtMocHelpers::SignalData<void()>(652, 2, QMC::AccessPublic, QMetaType::Void),
        // Signal 'AstrometryAutoUpdateImageScaleChanged'
        QtMocHelpers::SignalData<void()>(653, 2, QMC::AccessPublic, QMetaType::Void),
        // Signal 'AstrometryImageScaleUnitsChanged'
        QtMocHelpers::SignalData<void()>(654, 2, QMC::AccessPublic, QMetaType::Void),
        // Signal 'AstrometryUseDownsampleChanged'
        QtMocHelpers::SignalData<void()>(655, 2, QMC::AccessPublic, QMetaType::Void),
        // Signal 'AstrometryDownsampleChanged'
        QtMocHelpers::SignalData<void()>(656, 2, QMC::AccessPublic, QMetaType::Void),
        // Signal 'AstrometryAutoDownsampleChanged'
        QtMocHelpers::SignalData<void()>(657, 2, QMC::AccessPublic, QMetaType::Void),
        // Signal 'AstrometryDynamicThresholdChanged'
        QtMocHelpers::SignalData<void()>(658, 2, QMC::AccessPublic, QMetaType::Void),
        // Signal 'AstrometryUsePositionChanged'
        QtMocHelpers::SignalData<void()>(659, 2, QMC::AccessPublic, QMetaType::Void),
        // Signal 'AstrometryPositionRAChanged'
        QtMocHelpers::SignalData<void()>(660, 2, QMC::AccessPublic, QMetaType::Void),
        // Signal 'AstrometryPositionDEChanged'
        QtMocHelpers::SignalData<void()>(661, 2, QMC::AccessPublic, QMetaType::Void),
        // Signal 'AstrometryAutoUpdatePositionChanged'
        QtMocHelpers::SignalData<void()>(662, 2, QMC::AccessPublic, QMetaType::Void),
        // Signal 'AstrometryRadiusChanged'
        QtMocHelpers::SignalData<void()>(663, 2, QMC::AccessPublic, QMetaType::Void),
        // Signal 'AstrometryDetectParityChanged'
        QtMocHelpers::SignalData<void()>(664, 2, QMC::AccessPublic, QMetaType::Void),
        // Signal 'AstrometryCustomOptionsChanged'
        QtMocHelpers::SignalData<void()>(665, 2, QMC::AccessPublic, QMetaType::Void),
        // Signal 'AstrometrySolverBinaryChanged'
        QtMocHelpers::SignalData<void()>(666, 2, QMC::AccessPublic, QMetaType::Void),
        // Signal 'AstrometryWCSInfoChanged'
        QtMocHelpers::SignalData<void()>(667, 2, QMC::AccessPublic, QMetaType::Void),
        // Signal 'AstrometryConfFileChanged'
        QtMocHelpers::SignalData<void()>(668, 2, QMC::AccessPublic, QMetaType::Void),
        // Signal 'SextractorBinaryChanged'
        QtMocHelpers::SignalData<void()>(669, 2, QMC::AccessPublic, QMetaType::Void),
        // Signal 'WatneyBinaryChanged'
        QtMocHelpers::SignalData<void()>(670, 2, QMC::AccessPublic, QMetaType::Void),
        // Signal 'AstrometryAPIKeyChanged'
        QtMocHelpers::SignalData<void()>(671, 2, QMC::AccessPublic, QMetaType::Void),
        // Signal 'AstrometryAPIURLChanged'
        QtMocHelpers::SignalData<void()>(672, 2, QMC::AccessPublic, QMetaType::Void),
        // Signal 'AstrometryUseJPEGChanged'
        QtMocHelpers::SignalData<void()>(673, 2, QMC::AccessPublic, QMetaType::Void),
        // Signal 'AstrometryTimeoutChanged'
        QtMocHelpers::SignalData<void()>(674, 2, QMC::AccessPublic, QMetaType::Void),
        // Signal 'PAHMountSpeedChanged'
        QtMocHelpers::SignalData<void()>(675, 2, QMC::AccessPublic, QMetaType::Void),
        // Signal 'PAHRotaionChanged'
        QtMocHelpers::SignalData<void()>(676, 2, QMC::AccessPublic, QMetaType::Void),
        // Signal 'PAHRefreshAlgorithmChanged'
        QtMocHelpers::SignalData<void()>(677, 2, QMC::AccessPublic, QMetaType::Void),
        // Signal 'PAHDirectionChanged'
        QtMocHelpers::SignalData<void()>(678, 2, QMC::AccessPublic, QMetaType::Void),
        // Signal 'PAHAutoParkChanged'
        QtMocHelpers::SignalData<void()>(679, 2, QMC::AccessPublic, QMetaType::Void),
        // Signal 'PAHManualSlewChanged'
        QtMocHelpers::SignalData<void()>(680, 2, QMC::AccessPublic, QMetaType::Void),
        // Signal 'PAHExposureChanged'
        QtMocHelpers::SignalData<void()>(681, 2, QMC::AccessPublic, QMetaType::Void),
        // Signal 'PAHAutoPACCorrectionChanged'
        QtMocHelpers::SignalData<void()>(682, 2, QMC::AccessPublic, QMetaType::Void),
        // Signal 'PAHAutoChangeDirectionChanged'
        QtMocHelpers::SignalData<void()>(683, 2, QMC::AccessPublic, QMetaType::Void),
        // Signal 'PAHSuccessThresholdChanged'
        QtMocHelpers::SignalData<void()>(684, 2, QMC::AccessPublic, QMetaType::Void),
        // Signal 'PAHCorrectionTimeoutChanged'
        QtMocHelpers::SignalData<void()>(685, 2, QMC::AccessPublic, QMetaType::Void),
        // Signal 'GuideExposureChanged'
        QtMocHelpers::SignalData<void()>(686, 2, QMC::AccessPublic, QMetaType::Void),
        // Signal 'GuideDelayChanged'
        QtMocHelpers::SignalData<void()>(687, 2, QMC::AccessPublic, QMetaType::Void),
        // Signal 'GuiderTypeChanged'
        QtMocHelpers::SignalData<void()>(688, 2, QMC::AccessPublic, QMetaType::Void),
        // Signal 'GuideAlgorithmChanged'
        QtMocHelpers::SignalData<void()>(689, 2, QMC::AccessPublic, QMetaType::Void),
        // Signal 'RAGuidePulseAlgorithmChanged'
        QtMocHelpers::SignalData<void()>(690, 2, QMC::AccessPublic, QMetaType::Void),
        // Signal 'DECGuidePulseAlgorithmChanged'
        QtMocHelpers::SignalData<void()>(691, 2, QMC::AccessPublic, QMetaType::Void),
        // Signal 'AIGuiderWeightsFileChanged'
        QtMocHelpers::SignalData<void()>(692, 2, QMC::AccessPublic, QMetaType::Void),
        // Signal 'AIPredictionGainChanged'
        QtMocHelpers::SignalData<void()>(693, 2, QMC::AccessPublic, QMetaType::Void),
        // Signal 'AIProportionalBackoffChanged'
        QtMocHelpers::SignalData<void()>(694, 2, QMC::AccessPublic, QMetaType::Void),
        // Signal 'AIPIDAutoTuneChanged'
        QtMocHelpers::SignalData<void()>(695, 2, QMC::AccessPublic, QMetaType::Void),
        // Signal 'AIShadowModeChanged'
        QtMocHelpers::SignalData<void()>(696, 2, QMC::AccessPublic, QMetaType::Void),
        // Signal 'PHD2HostChanged'
        QtMocHelpers::SignalData<void()>(697, 2, QMC::AccessPublic, QMetaType::Void),
        // Signal 'PHD2PortChanged'
        QtMocHelpers::SignalData<void()>(698, 2, QMC::AccessPublic, QMetaType::Void),
        // Signal 'LinGuiderHostChanged'
        QtMocHelpers::SignalData<void()>(699, 2, QMC::AccessPublic, QMetaType::Void),
        // Signal 'LinGuiderPortChanged'
        QtMocHelpers::SignalData<void()>(700, 2, QMC::AccessPublic, QMetaType::Void),
        // Signal 'CalibrationPulseDurationChanged'
        QtMocHelpers::SignalData<void()>(701, 2, QMC::AccessPublic, QMetaType::Void),
        // Signal 'CalibrationMaxMoveChanged'
        QtMocHelpers::SignalData<void()>(702, 2, QMC::AccessPublic, QMetaType::Void),
        // Signal 'GuideSquareSizeChanged'
        QtMocHelpers::SignalData<void()>(703, 2, QMC::AccessPublic, QMetaType::Void),
        // Signal 'GuideBinningChanged'
        QtMocHelpers::SignalData<void()>(704, 2, QMC::AccessPublic, QMetaType::Void),
        // Signal 'GuideAutoStarChanged'
        QtMocHelpers::SignalData<void()>(705, 2, QMC::AccessPublic, QMetaType::Void),
        // Signal 'guideShowFrameChanged'
        QtMocHelpers::SignalData<void()>(706, 2, QMC::AccessPublic, QMetaType::Void),
        // Signal 'GuideAutoSquareSizeEnabledChanged'
        QtMocHelpers::SignalData<void()>(707, 2, QMC::AccessPublic, QMetaType::Void),
        // Signal 'AutoModeIterationsChanged'
        QtMocHelpers::SignalData<void()>(708, 2, QMC::AccessPublic, QMetaType::Void),
        // Signal 'GuideLostStarTimeoutChanged'
        QtMocHelpers::SignalData<void()>(709, 2, QMC::AccessPublic, QMetaType::Void),
        // Signal 'GuideCalibrationTimeoutChanged'
        QtMocHelpers::SignalData<void()>(710, 2, QMC::AccessPublic, QMetaType::Void),
        // Signal 'GuideMaxDeltaRMSChanged'
        QtMocHelpers::SignalData<void()>(711, 2, QMC::AccessPublic, QMetaType::Void),
        // Signal 'GuideMaxHFRChanged'
        QtMocHelpers::SignalData<void()>(712, 2, QMC::AccessPublic, QMetaType::Void),
        // Signal 'MinDetectionsSEPMultistarChanged'
        QtMocHelpers::SignalData<void()>(713, 2, QMC::AccessPublic, QMetaType::Void),
        // Signal 'MaxMultistarReferenceStarsChanged'
        QtMocHelpers::SignalData<void()>(714, 2, QMC::AccessPublic, QMetaType::Void),
        // Signal 'AlwaysInventGuideStarChanged'
        QtMocHelpers::SignalData<void()>(715, 2, QMC::AccessPublic, QMetaType::Void),
        // Signal 'TwoAxisEnabledChanged'
        QtMocHelpers::SignalData<void()>(716, 2, QMC::AccessPublic, QMetaType::Void),
        // Signal 'UseGuideHeadChanged'
        QtMocHelpers::SignalData<void()>(717, 2, QMC::AccessPublic, QMetaType::Void),
        // Signal 'SaveGuideLogChanged'
        QtMocHelpers::SignalData<void()>(718, 2, QMC::AccessPublic, QMetaType::Void),
        // Signal 'GuideDarkFrameChanged'
        QtMocHelpers::SignalData<void()>(719, 2, QMC::AccessPublic, QMetaType::Void),
        // Signal 'GuideSubframeChanged'
        QtMocHelpers::SignalData<void()>(720, 2, QMC::AccessPublic, QMetaType::Void),
        // Signal 'DitherPixelsChanged'
        QtMocHelpers::SignalData<void()>(721, 2, QMC::AccessPublic, QMetaType::Void),
        // Signal 'DitherFramesChanged'
        QtMocHelpers::SignalData<void()>(722, 2, QMC::AccessPublic, QMetaType::Void),
        // Signal 'DitherSettleChanged'
        QtMocHelpers::SignalData<void()>(723, 2, QMC::AccessPublic, QMetaType::Void),
        // Signal 'DitherThresholdChanged'
        QtMocHelpers::SignalData<void()>(724, 2, QMC::AccessPublic, QMetaType::Void),
        // Signal 'DitherTimeoutChanged'
        QtMocHelpers::SignalData<void()>(725, 2, QMC::AccessPublic, QMetaType::Void),
        // Signal 'DitherMaxIterationsChanged'
        QtMocHelpers::SignalData<void()>(726, 2, QMC::AccessPublic, QMetaType::Void),
        // Signal 'DitherNoGuidingPulseChanged'
        QtMocHelpers::SignalData<void()>(727, 2, QMC::AccessPublic, QMetaType::Void),
        // Signal 'DitherFailAbortsAutoGuideChanged'
        QtMocHelpers::SignalData<void()>(728, 2, QMC::AccessPublic, QMetaType::Void),
        // Signal 'DitherWithOnePulseChanged'
        QtMocHelpers::SignalData<void()>(729, 2, QMC::AccessPublic, QMetaType::Void),
        // Signal 'DitherEnabledChanged'
        QtMocHelpers::SignalData<void()>(730, 2, QMC::AccessPublic, QMetaType::Void),
        // Signal 'DitherNoGuidingChanged'
        QtMocHelpers::SignalData<void()>(731, 2, QMC::AccessPublic, QMetaType::Void),
        // Signal 'RAGuideEnabledChanged'
        QtMocHelpers::SignalData<void()>(732, 2, QMC::AccessPublic, QMetaType::Void),
        // Signal 'DECGuideEnabledChanged'
        QtMocHelpers::SignalData<void()>(733, 2, QMC::AccessPublic, QMetaType::Void),
        // Signal 'NorthDECGuideEnabledChanged'
        QtMocHelpers::SignalData<void()>(734, 2, QMC::AccessPublic, QMetaType::Void),
        // Signal 'SouthDECGuideEnabledChanged'
        QtMocHelpers::SignalData<void()>(735, 2, QMC::AccessPublic, QMetaType::Void),
        // Signal 'EastRAGuideEnabledChanged'
        QtMocHelpers::SignalData<void()>(736, 2, QMC::AccessPublic, QMetaType::Void),
        // Signal 'WestRAGuideEnabledChanged'
        QtMocHelpers::SignalData<void()>(737, 2, QMC::AccessPublic, QMetaType::Void),
        // Signal 'RAProportionalGainChanged'
        QtMocHelpers::SignalData<void()>(738, 2, QMC::AccessPublic, QMetaType::Void),
        // Signal 'DECProportionalGainChanged'
        QtMocHelpers::SignalData<void()>(739, 2, QMC::AccessPublic, QMetaType::Void),
        // Signal 'RAIntegralGainChanged'
        QtMocHelpers::SignalData<void()>(740, 2, QMC::AccessPublic, QMetaType::Void),
        // Signal 'DECIntegralGainChanged'
        QtMocHelpers::SignalData<void()>(741, 2, QMC::AccessPublic, QMetaType::Void),
        // Signal 'RAMinimumPulseArcSecChanged'
        QtMocHelpers::SignalData<void()>(742, 2, QMC::AccessPublic, QMetaType::Void),
        // Signal 'DECMinimumPulseArcSecChanged'
        QtMocHelpers::SignalData<void()>(743, 2, QMC::AccessPublic, QMetaType::Void),
        // Signal 'RAMaximumPulseArcSecChanged'
        QtMocHelpers::SignalData<void()>(744, 2, QMC::AccessPublic, QMetaType::Void),
        // Signal 'DECMaximumPulseArcSecChanged'
        QtMocHelpers::SignalData<void()>(745, 2, QMC::AccessPublic, QMetaType::Void),
        // Signal 'GPGEnabledChanged'
        QtMocHelpers::SignalData<void()>(746, 2, QMC::AccessPublic, QMetaType::Void),
        // Signal 'GPGDarkGuidingChanged'
        QtMocHelpers::SignalData<void()>(747, 2, QMC::AccessPublic, QMetaType::Void),
        // Signal 'GPGDarkGuidingIntervalChanged'
        QtMocHelpers::SignalData<void()>(748, 2, QMC::AccessPublic, QMetaType::Void),
        // Signal 'AIDarkGuidingChanged'
        QtMocHelpers::SignalData<void()>(749, 2, QMC::AccessPublic, QMetaType::Void),
        // Signal 'AIDarkGuidingIntervalChanged'
        QtMocHelpers::SignalData<void()>(750, 2, QMC::AccessPublic, QMetaType::Void),
        // Signal 'GPGcWeightChanged'
        QtMocHelpers::SignalData<void()>(751, 2, QMC::AccessPublic, QMetaType::Void),
        // Signal 'GPGMinPeriodsForInferenceChanged'
        QtMocHelpers::SignalData<void()>(752, 2, QMC::AccessPublic, QMetaType::Void),
        // Signal 'GPGMinMoveChanged'
        QtMocHelpers::SignalData<void()>(753, 2, QMC::AccessPublic, QMetaType::Void),
        // Signal 'GPGSE0KLengthScaleChanged'
        QtMocHelpers::SignalData<void()>(754, 2, QMC::AccessPublic, QMetaType::Void),
        // Signal 'GPGSE0KSignalVarianceChanged'
        QtMocHelpers::SignalData<void()>(755, 2, QMC::AccessPublic, QMetaType::Void),
        // Signal 'GPGPKLengthScaleChanged'
        QtMocHelpers::SignalData<void()>(756, 2, QMC::AccessPublic, QMetaType::Void),
        // Signal 'GPGPeriodChanged'
        QtMocHelpers::SignalData<void()>(757, 2, QMC::AccessPublic, QMetaType::Void),
        // Signal 'GPGPKSignalVarianceChanged'
        QtMocHelpers::SignalData<void()>(758, 2, QMC::AccessPublic, QMetaType::Void),
        // Signal 'GPGSE1KLengthScaleChanged'
        QtMocHelpers::SignalData<void()>(759, 2, QMC::AccessPublic, QMetaType::Void),
        // Signal 'GPGSE1KSignalVarianceChanged'
        QtMocHelpers::SignalData<void()>(760, 2, QMC::AccessPublic, QMetaType::Void),
        // Signal 'GPGMinPeriodsForPeriodEstimateChanged'
        QtMocHelpers::SignalData<void()>(761, 2, QMC::AccessPublic, QMetaType::Void),
        // Signal 'GPGPointsForApproximationChanged'
        QtMocHelpers::SignalData<void()>(762, 2, QMC::AccessPublic, QMetaType::Void),
        // Signal 'GPGpWeightChanged'
        QtMocHelpers::SignalData<void()>(763, 2, QMC::AccessPublic, QMetaType::Void),
        // Signal 'GPGEstimatePeriodChanged'
        QtMocHelpers::SignalData<void()>(764, 2, QMC::AccessPublic, QMetaType::Void),
        // Signal 'GuiderAccuracyThresholdChanged'
        QtMocHelpers::SignalData<void()>(765, 2, QMC::AccessPublic, QMetaType::Void),
        // Signal 'RADisplayedOnGuideGraphChanged'
        QtMocHelpers::SignalData<void()>(766, 2, QMC::AccessPublic, QMetaType::Void),
        // Signal 'DEDisplayedOnGuideGraphChanged'
        QtMocHelpers::SignalData<void()>(767, 2, QMC::AccessPublic, QMetaType::Void),
        // Signal 'RACorrDisplayedOnGuideGraphChanged'
        QtMocHelpers::SignalData<void()>(768, 2, QMC::AccessPublic, QMetaType::Void),
        // Signal 'DECorrDisplayedOnGuideGraphChanged'
        QtMocHelpers::SignalData<void()>(769, 2, QMC::AccessPublic, QMetaType::Void),
        // Signal 'SNRDisplayedOnGuideGraphChanged'
        QtMocHelpers::SignalData<void()>(770, 2, QMC::AccessPublic, QMetaType::Void),
        // Signal 'RMSDisplayedOnGuideGraphChanged'
        QtMocHelpers::SignalData<void()>(771, 2, QMC::AccessPublic, QMetaType::Void),
        // Signal 'RAHysteresisChanged'
        QtMocHelpers::SignalData<void()>(772, 2, QMC::AccessPublic, QMetaType::Void),
        // Signal 'DECHysteresisChanged'
        QtMocHelpers::SignalData<void()>(773, 2, QMC::AccessPublic, QMetaType::Void),
        // Signal 'SchedulerAlgorithmChanged'
        QtMocHelpers::SignalData<void()>(774, 2, QMC::AccessPublic, QMetaType::Void),
        // Signal 'SchedulerLoggingChanged'
        QtMocHelpers::SignalData<void()>(775, 2, QMC::AccessPublic, QMetaType::Void),
        // Signal 'StopEkosAfterShutdownChanged'
        QtMocHelpers::SignalData<void()>(776, 2, QMC::AccessPublic, QMetaType::Void),
        // Signal 'ShutdownScriptTerminatesINDIChanged'
        QtMocHelpers::SignalData<void()>(777, 2, QMC::AccessPublic, QMetaType::Void),
        // Signal 'CameraWarmupEnabledChanged'
        QtMocHelpers::SignalData<void()>(778, 2, QMC::AccessPublic, QMetaType::Void),
        // Signal 'CameraWarmupRampChanged'
        QtMocHelpers::SignalData<void()>(779, 2, QMC::AccessPublic, QMetaType::Void),
        // Signal 'PreemptiveShutdownChanged'
        QtMocHelpers::SignalData<void()>(780, 2, QMC::AccessPublic, QMetaType::Void),
        // Signal 'ResetMountModelOnAlignFailChanged'
        QtMocHelpers::SignalData<void()>(781, 2, QMC::AccessPublic, QMetaType::Void),
        // Signal 'ResetMountModelBeforeJobChanged'
        QtMocHelpers::SignalData<void()>(782, 2, QMC::AccessPublic, QMetaType::Void),
        // Signal 'ResetGuideCalibrationChanged'
        QtMocHelpers::SignalData<void()>(783, 2, QMC::AccessPublic, QMetaType::Void),
        // Signal 'ForceAlignmentBeforeJobChanged'
        QtMocHelpers::SignalData<void()>(784, 2, QMC::AccessPublic, QMetaType::Void),
        // Signal 'ReuseGuideCalibrationChanged'
        QtMocHelpers::SignalData<void()>(785, 2, QMC::AccessPublic, QMetaType::Void),
        // Signal 'ReverseDecOnPierSideChangeChanged'
        QtMocHelpers::SignalData<void()>(786, 2, QMC::AccessPublic, QMetaType::Void),
        // Signal 'GuideCalibrationBacklashChanged'
        QtMocHelpers::SignalData<void()>(787, 2, QMC::AccessPublic, QMetaType::Void),
        // Signal 'AssumeDecOrthogonalChanged'
        QtMocHelpers::SignalData<void()>(788, 2, QMC::AccessPublic, QMetaType::Void),
        // Signal 'SerializedCalibrationChanged'
        QtMocHelpers::SignalData<void()>(789, 2, QMC::AccessPublic, QMetaType::Void),
        // Signal 'RealignAfterCalibrationFailureChanged'
        QtMocHelpers::SignalData<void()>(790, 2, QMC::AccessPublic, QMetaType::Void),
        // Signal 'PreemptiveShutdownTimeChanged'
        QtMocHelpers::SignalData<void()>(791, 2, QMC::AccessPublic, QMetaType::Void),
        // Signal 'RememberJobProgressChanged'
        QtMocHelpers::SignalData<void()>(792, 2, QMC::AccessPublic, QMetaType::Void),
        // Signal 'GreedySchedulingChanged'
        QtMocHelpers::SignalData<void()>(793, 2, QMC::AccessPublic, QMetaType::Void),
        // Signal 'LeadTimeChanged'
        QtMocHelpers::SignalData<void()>(794, 2, QMC::AccessPublic, QMetaType::Void),
        // Signal 'PreDawnTimeChanged'
        QtMocHelpers::SignalData<void()>(795, 2, QMC::AccessPublic, QMetaType::Void),
        // Signal 'DawnOffsetChanged'
        QtMocHelpers::SignalData<void()>(796, 2, QMC::AccessPublic, QMetaType::Void),
        // Signal 'DuskOffsetChanged'
        QtMocHelpers::SignalData<void()>(797, 2, QMC::AccessPublic, QMetaType::Void),
        // Signal 'TelescopeFocalLengthChanged'
        QtMocHelpers::SignalData<void()>(798, 2, QMC::AccessPublic, QMetaType::Void),
        // Signal 'TelescopeFocalReducerChanged'
        QtMocHelpers::SignalData<void()>(799, 2, QMC::AccessPublic, QMetaType::Void),
        // Signal 'CameraPixelWidthChanged'
        QtMocHelpers::SignalData<void()>(800, 2, QMC::AccessPublic, QMetaType::Void),
        // Signal 'CameraPixelHeightChanged'
        QtMocHelpers::SignalData<void()>(801, 2, QMC::AccessPublic, QMetaType::Void),
        // Signal 'CameraWidthChanged'
        QtMocHelpers::SignalData<void()>(802, 2, QMC::AccessPublic, QMetaType::Void),
        // Signal 'CameraHeightChanged'
        QtMocHelpers::SignalData<void()>(803, 2, QMC::AccessPublic, QMetaType::Void),
        // Signal 'CameraRotationChanged'
        QtMocHelpers::SignalData<void()>(804, 2, QMC::AccessPublic, QMetaType::Void),
        // Signal 'ErrorHandlingStrategyChanged'
        QtMocHelpers::SignalData<void()>(805, 2, QMC::AccessPublic, QMetaType::Void),
        // Signal 'ErrorHandlingStrategyDelayChanged'
        QtMocHelpers::SignalData<void()>(806, 2, QMC::AccessPublic, QMetaType::Void),
        // Signal 'RescheduleErrorsChanged'
        QtMocHelpers::SignalData<void()>(807, 2, QMC::AccessPublic, QMetaType::Void),
        // Signal 'AlignCheckFrequencyChanged'
        QtMocHelpers::SignalData<void()>(808, 2, QMC::AccessPublic, QMetaType::Void),
        // Signal 'AlignCheckThresholdChanged'
        QtMocHelpers::SignalData<void()>(809, 2, QMC::AccessPublic, QMetaType::Void),
        // Signal 'SchedulerTrackStepChanged'
        QtMocHelpers::SignalData<void()>(810, 2, QMC::AccessPublic, QMetaType::Void),
        // Signal 'SchedulerStartupEnabledChanged'
        QtMocHelpers::SignalData<void()>(811, 2, QMC::AccessPublic, QMetaType::Void),
        // Signal 'SchedulerPreStartupScriptChanged'
        QtMocHelpers::SignalData<void()>(812, 2, QMC::AccessPublic, QMetaType::Void),
        // Signal 'SchedulerPostStartupScriptChanged'
        QtMocHelpers::SignalData<void()>(813, 2, QMC::AccessPublic, QMetaType::Void),
        // Signal 'SchedulerShutdownEnabledChanged'
        QtMocHelpers::SignalData<void()>(814, 2, QMC::AccessPublic, QMetaType::Void),
        // Signal 'SchedulerPreShutdownScriptChanged'
        QtMocHelpers::SignalData<void()>(815, 2, QMC::AccessPublic, QMetaType::Void),
        // Signal 'SchedulerPostShutdownScriptChanged'
        QtMocHelpers::SignalData<void()>(816, 2, QMC::AccessPublic, QMetaType::Void),
        // Signal 'SchedulerFocusStepChanged'
        QtMocHelpers::SignalData<void()>(817, 2, QMC::AccessPublic, QMetaType::Void),
        // Signal 'SchedulerGuideStepChanged'
        QtMocHelpers::SignalData<void()>(818, 2, QMC::AccessPublic, QMetaType::Void),
        // Signal 'SchedulerAlignStepChanged'
        QtMocHelpers::SignalData<void()>(819, 2, QMC::AccessPublic, QMetaType::Void),
        // Signal 'SchedulerAltitudeChanged'
        QtMocHelpers::SignalData<void()>(820, 2, QMC::AccessPublic, QMetaType::Void),
        // Signal 'SchedulerAltitudeValueChanged'
        QtMocHelpers::SignalData<void()>(821, 2, QMC::AccessPublic, QMetaType::Void),
        // Signal 'SchedulerHorizonChanged'
        QtMocHelpers::SignalData<void()>(822, 2, QMC::AccessPublic, QMetaType::Void),
        // Signal 'SchedulerMoonSeparationChanged'
        QtMocHelpers::SignalData<void()>(823, 2, QMC::AccessPublic, QMetaType::Void),
        // Signal 'SchedulerMoonSeparationValueChanged'
        QtMocHelpers::SignalData<void()>(824, 2, QMC::AccessPublic, QMetaType::Void),
        // Signal 'SchedulerMoonAltitudeChanged'
        QtMocHelpers::SignalData<void()>(825, 2, QMC::AccessPublic, QMetaType::Void),
        // Signal 'SchedulerMoonAltitudeMaxValueChanged'
        QtMocHelpers::SignalData<void()>(826, 2, QMC::AccessPublic, QMetaType::Void),
        // Signal 'SchedulerWeatherChanged'
        QtMocHelpers::SignalData<void()>(827, 2, QMC::AccessPublic, QMetaType::Void),
        // Signal 'SchedulerWeatherGracePeriodChanged'
        QtMocHelpers::SignalData<void()>(828, 2, QMC::AccessPublic, QMetaType::Void),
        // Signal 'SchedulerWeatherShutdownDelayChanged'
        QtMocHelpers::SignalData<void()>(829, 2, QMC::AccessPublic, QMetaType::Void),
        // Signal 'SchedulerSafetyMonitorConnectionStringChanged'
        QtMocHelpers::SignalData<void()>(830, 2, QMC::AccessPublic, QMetaType::Void),
        // Signal 'SchedulerTwilightChanged'
        QtMocHelpers::SignalData<void()>(831, 2, QMC::AccessPublic, QMetaType::Void),
        // Signal 'SchedulerCompleteSequencesChanged'
        QtMocHelpers::SignalData<void()>(832, 2, QMC::AccessPublic, QMetaType::Void),
        // Signal 'SchedulerRepeatEverythingChanged'
        QtMocHelpers::SignalData<void()>(833, 2, QMC::AccessPublic, QMetaType::Void),
        // Signal 'SchedulerRepeatSequencesChanged'
        QtMocHelpers::SignalData<void()>(834, 2, QMC::AccessPublic, QMetaType::Void),
        // Signal 'SchedulerUntilTerminatedChanged'
        QtMocHelpers::SignalData<void()>(835, 2, QMC::AccessPublic, QMetaType::Void),
        // Signal 'SchedulerUntilChanged'
        QtMocHelpers::SignalData<void()>(836, 2, QMC::AccessPublic, QMetaType::Void),
        // Signal 'SchedulerUntilValueChanged'
        QtMocHelpers::SignalData<void()>(837, 2, QMC::AccessPublic, QMetaType::Void),
        // Signal 'SchedulerExecutionSequencesLimitChanged'
        QtMocHelpers::SignalData<void()>(838, 2, QMC::AccessPublic, QMetaType::Void),
        // Signal 'AnalyzeRestartWithEkosChanged'
        QtMocHelpers::SignalData<void()>(839, 2, QMC::AccessPublic, QMetaType::Void),
        // Signal 'AnalyzeAlternativeDirectoryNameChanged'
        QtMocHelpers::SignalData<void()>(840, 2, QMC::AccessPublic, QMetaType::Void),
        // Signal 'AnalyzeHFRChanged'
        QtMocHelpers::SignalData<void()>(841, 2, QMC::AccessPublic, QMetaType::Void),
        // Signal 'AnalyzeNumCaptureStarsChanged'
        QtMocHelpers::SignalData<void()>(842, 2, QMC::AccessPublic, QMetaType::Void),
        // Signal 'AnalyzeMedianChanged'
        QtMocHelpers::SignalData<void()>(843, 2, QMC::AccessPublic, QMetaType::Void),
        // Signal 'AnalyzeEccentricityChanged'
        QtMocHelpers::SignalData<void()>(844, 2, QMC::AccessPublic, QMetaType::Void),
        // Signal 'AnalyzeTemperatureChanged'
        QtMocHelpers::SignalData<void()>(845, 2, QMC::AccessPublic, QMetaType::Void),
        // Signal 'FocusPositionChanged'
        QtMocHelpers::SignalData<void()>(846, 2, QMC::AccessPublic, QMetaType::Void),
        // Signal 'AnalyzeNumStarsChanged'
        QtMocHelpers::SignalData<void()>(847, 2, QMC::AccessPublic, QMetaType::Void),
        // Signal 'AnalyzeSkyBgChanged'
        QtMocHelpers::SignalData<void()>(848, 2, QMC::AccessPublic, QMetaType::Void),
        // Signal 'AnalyzeSNRChanged'
        QtMocHelpers::SignalData<void()>(849, 2, QMC::AccessPublic, QMetaType::Void),
        // Signal 'AnalyzeRAChanged'
        QtMocHelpers::SignalData<void()>(850, 2, QMC::AccessPublic, QMetaType::Void),
        // Signal 'AnalyzeDECChanged'
        QtMocHelpers::SignalData<void()>(851, 2, QMC::AccessPublic, QMetaType::Void),
        // Signal 'AnalyzeRApChanged'
        QtMocHelpers::SignalData<void()>(852, 2, QMC::AccessPublic, QMetaType::Void),
        // Signal 'AnalyzeDECpChanged'
        QtMocHelpers::SignalData<void()>(853, 2, QMC::AccessPublic, QMetaType::Void),
        // Signal 'AnalyzeDriftChanged'
        QtMocHelpers::SignalData<void()>(854, 2, QMC::AccessPublic, QMetaType::Void),
        // Signal 'AnalyzeRMSChanged'
        QtMocHelpers::SignalData<void()>(855, 2, QMC::AccessPublic, QMetaType::Void),
        // Signal 'AnalyzeTargetDistanceChanged'
        QtMocHelpers::SignalData<void()>(856, 2, QMC::AccessPublic, QMetaType::Void),
        // Signal 'AnalyzeRMSCChanged'
        QtMocHelpers::SignalData<void()>(857, 2, QMC::AccessPublic, QMetaType::Void),
        // Signal 'AnalyzeMountRAChanged'
        QtMocHelpers::SignalData<void()>(858, 2, QMC::AccessPublic, QMetaType::Void),
        // Signal 'AnalyzeMountDECChanged'
        QtMocHelpers::SignalData<void()>(859, 2, QMC::AccessPublic, QMetaType::Void),
        // Signal 'AnalyzeMountHAChanged'
        QtMocHelpers::SignalData<void()>(860, 2, QMC::AccessPublic, QMetaType::Void),
        // Signal 'AnalyzeAzChanged'
        QtMocHelpers::SignalData<void()>(861, 2, QMC::AccessPublic, QMetaType::Void),
        // Signal 'AnalyzeAltChanged'
        QtMocHelpers::SignalData<void()>(862, 2, QMC::AccessPublic, QMetaType::Void),
        // Signal 'AnalyzePierSideChanged'
        QtMocHelpers::SignalData<void()>(863, 2, QMC::AccessPublic, QMetaType::Void),
        // Signal 'AnalyzeStatsYAxisChanged'
        QtMocHelpers::SignalData<void()>(864, 2, QMC::AccessPublic, QMetaType::Void),
        // Signal 'LastServerChanged'
        QtMocHelpers::SignalData<void()>(865, 2, QMC::AccessPublic, QMetaType::Void),
        // Signal 'LastServerPortChanged'
        QtMocHelpers::SignalData<void()>(866, 2, QMC::AccessPublic, QMetaType::Void),
        // Signal 'LastWebManagerPortChanged'
        QtMocHelpers::SignalData<void()>(867, 2, QMC::AccessPublic, QMetaType::Void),
        // Signal 'HIPSMemoryCacheChanged'
        QtMocHelpers::SignalData<void()>(868, 2, QMC::AccessPublic, QMetaType::Void),
        // Signal 'HIPSNetCacheChanged'
        QtMocHelpers::SignalData<void()>(869, 2, QMC::AccessPublic, QMetaType::Void),
        // Signal 'HIPSSourceChanged'
        QtMocHelpers::SignalData<void()>(870, 2, QMC::AccessPublic, QMetaType::Void),
        // Signal 'HIPSBiLinearInterpolationChanged'
        QtMocHelpers::SignalData<void()>(871, 2, QMC::AccessPublic, QMetaType::Void),
        // Signal 'HIPSShowGridChanged'
        QtMocHelpers::SignalData<void()>(872, 2, QMC::AccessPublic, QMetaType::Void),
        // Signal 'HIPSPanningChanged'
        QtMocHelpers::SignalData<void()>(873, 2, QMC::AccessPublic, QMetaType::Void),
        // Signal 'ShowHIPSChanged'
        QtMocHelpers::SignalData<void()>(874, 2, QMC::AccessPublic, QMetaType::Void),
        // Signal 'HIPSUseOfflineSourceChanged'
        QtMocHelpers::SignalData<void()>(875, 2, QMC::AccessPublic, QMetaType::Void),
        // Signal 'HIPSOfflinePathChanged'
        QtMocHelpers::SignalData<void()>(876, 2, QMC::AccessPublic, QMetaType::Void),
        // Signal 'TerrainSourceChanged'
        QtMocHelpers::SignalData<void()>(877, 2, QMC::AccessPublic, QMetaType::Void),
        // Signal 'TerrainSourceCorrectAzChanged'
        QtMocHelpers::SignalData<void()>(878, 2, QMC::AccessPublic, QMetaType::Void),
        // Signal 'TerrainSourceCorrectAltChanged'
        QtMocHelpers::SignalData<void()>(879, 2, QMC::AccessPublic, QMetaType::Void),
        // Signal 'TerrainDownsamplingChanged'
        QtMocHelpers::SignalData<void()>(880, 2, QMC::AccessPublic, QMetaType::Void),
        // Signal 'TerrainPanningChanged'
        QtMocHelpers::SignalData<void()>(881, 2, QMC::AccessPublic, QMetaType::Void),
        // Signal 'ShowTerrainChanged'
        QtMocHelpers::SignalData<void()>(882, 2, QMC::AccessPublic, QMetaType::Void),
        // Signal 'TerrainSkipSpeedupChanged'
        QtMocHelpers::SignalData<void()>(883, 2, QMC::AccessPublic, QMetaType::Void),
        // Signal 'TerrainTransparencySpeedupChanged'
        QtMocHelpers::SignalData<void()>(884, 2, QMC::AccessPublic, QMetaType::Void),
        // Signal 'TerrainSmoothPixelsChanged'
        QtMocHelpers::SignalData<void()>(885, 2, QMC::AccessPublic, QMetaType::Void),
        // Signal 'ShowImageOverlaysChanged'
        QtMocHelpers::SignalData<void()>(886, 2, QMC::AccessPublic, QMetaType::Void),
        // Signal 'ShowImageOverlaysBelowCatalogsChanged'
        QtMocHelpers::SignalData<void()>(887, 2, QMC::AccessPublic, QMetaType::Void),
        // Signal 'ShowSelectedImageOverlayChanged'
        QtMocHelpers::SignalData<void()>(888, 2, QMC::AccessPublic, QMetaType::Void),
        // Signal 'ImageOverlayMaxDimensionChanged'
        QtMocHelpers::SignalData<void()>(889, 2, QMC::AccessPublic, QMetaType::Void),
        // Signal 'ImageOverlayTimeoutChanged'
        QtMocHelpers::SignalData<void()>(890, 2, QMC::AccessPublic, QMetaType::Void),
        // Signal 'ImageOverlayDefaultScaleChanged'
        QtMocHelpers::SignalData<void()>(891, 2, QMC::AccessPublic, QMetaType::Void),
        // Signal 'DefaultObservatoryWeatherSourceChanged'
        QtMocHelpers::SignalData<void()>(892, 2, QMC::AccessPublic, QMetaType::Void),
        // Signal 'warningActionsActiveChanged'
        QtMocHelpers::SignalData<void()>(893, 2, QMC::AccessPublic, QMetaType::Void),
        // Signal 'alertActionsActiveChanged'
        QtMocHelpers::SignalData<void()>(894, 2, QMC::AccessPublic, QMetaType::Void),
        // Signal 'weatherWarningCloseDomeChanged'
        QtMocHelpers::SignalData<void()>(895, 2, QMC::AccessPublic, QMetaType::Void),
        // Signal 'weatherWarningCloseShutterChanged'
        QtMocHelpers::SignalData<void()>(896, 2, QMC::AccessPublic, QMetaType::Void),
        // Signal 'weatherWarningStopSchedulerChanged'
        QtMocHelpers::SignalData<void()>(897, 2, QMC::AccessPublic, QMetaType::Void),
        // Signal 'weatherWarningDelayChanged'
        QtMocHelpers::SignalData<void()>(898, 2, QMC::AccessPublic, QMetaType::Void),
        // Signal 'weatherAlertCloseDomeChanged'
        QtMocHelpers::SignalData<void()>(899, 2, QMC::AccessPublic, QMetaType::Void),
        // Signal 'weatherAlertCloseShutterChanged'
        QtMocHelpers::SignalData<void()>(900, 2, QMC::AccessPublic, QMetaType::Void),
        // Signal 'weatherAlertStopSchedulerChanged'
        QtMocHelpers::SignalData<void()>(901, 2, QMC::AccessPublic, QMetaType::Void),
        // Signal 'weatherAlertDelayChanged'
        QtMocHelpers::SignalData<void()>(902, 2, QMC::AccessPublic, QMetaType::Void),
        // Signal 'observatoryStatusUseDomeChanged'
        QtMocHelpers::SignalData<void()>(903, 2, QMC::AccessPublic, QMetaType::Void),
        // Signal 'observatoryStatusUseShutterChanged'
        QtMocHelpers::SignalData<void()>(904, 2, QMC::AccessPublic, QMetaType::Void),
        // Signal 'observatoryStatusUseWeatherChanged'
        QtMocHelpers::SignalData<void()>(905, 2, QMC::AccessPublic, QMetaType::Void),
        // Signal 'weatherAutoScaleValuesChanged'
        QtMocHelpers::SignalData<void()>(906, 2, QMC::AccessPublic, QMetaType::Void),
        // Signal 'ASTAPExecutableChanged'
        QtMocHelpers::SignalData<void()>(907, 2, QMC::AccessPublic, QMetaType::Void),
        // Signal 'ASTAPDownSampleChanged'
        QtMocHelpers::SignalData<void()>(908, 2, QMC::AccessPublic, QMetaType::Void),
        // Signal 'ASTAPDownSampleValueChanged'
        QtMocHelpers::SignalData<void()>(909, 2, QMC::AccessPublic, QMetaType::Void),
        // Signal 'ASTAPSearchRadiusChanged'
        QtMocHelpers::SignalData<void()>(910, 2, QMC::AccessPublic, QMetaType::Void),
        // Signal 'ASTAPSearchRadiusValueChanged'
        QtMocHelpers::SignalData<void()>(911, 2, QMC::AccessPublic, QMetaType::Void),
        // Signal 'ASTAPUpdateFITSChanged'
        QtMocHelpers::SignalData<void()>(912, 2, QMC::AccessPublic, QMetaType::Void),
        // Signal 'ASTAPLargeSearchWindowChanged'
        QtMocHelpers::SignalData<void()>(913, 2, QMC::AccessPublic, QMetaType::Void),
        // Signal 'MosaicTransparencyAutoChanged'
        QtMocHelpers::SignalData<void()>(914, 2, QMC::AccessPublic, QMetaType::Void),
        // Signal 'MosaicTransparencyLevelChanged'
        QtMocHelpers::SignalData<void()>(915, 2, QMC::AccessPublic, QMetaType::Void),
        // Signal 'MCPEnabledChanged'
        QtMocHelpers::SignalData<void()>(916, 2, QMC::AccessPublic, QMetaType::Void),
        // Signal 'MCPPortChanged'
        QtMocHelpers::SignalData<void()>(917, 2, QMC::AccessPublic, QMetaType::Void),
        // Signal 'MCPReadOnlyModeChanged'
        QtMocHelpers::SignalData<void()>(918, 2, QMC::AccessPublic, QMetaType::Void),
        // Signal 'MCPDisabledToolsChanged'
        QtMocHelpers::SignalData<void()>(919, 2, QMC::AccessPublic, QMetaType::Void),
    };
    QtMocHelpers::UintData qt_properties {
        // property 'positionTimeBox'
        QtMocHelpers::PropertyData<QPoint>(920, 0x80000000 | 921, QMC::DefaultPropertyFlags | QMC::Writable | QMC::EnumOrFlag | QMC::StdCppSet, 0),
        // property 'isPositionTimeBoxImmutable'
        QtMocHelpers::PropertyData<bool>(922, QMetaType::Bool, QMC::DefaultPropertyFlags | QMC::Constant),
        // property 'positionFocusBox'
        QtMocHelpers::PropertyData<QPoint>(923, 0x80000000 | 921, QMC::DefaultPropertyFlags | QMC::Writable | QMC::EnumOrFlag | QMC::StdCppSet, 1),
        // property 'isPositionFocusBoxImmutable'
        QtMocHelpers::PropertyData<bool>(924, QMetaType::Bool, QMC::DefaultPropertyFlags | QMC::Constant),
        // property 'positionGeoBox'
        QtMocHelpers::PropertyData<QPoint>(925, 0x80000000 | 921, QMC::DefaultPropertyFlags | QMC::Writable | QMC::EnumOrFlag | QMC::StdCppSet, 2),
        // property 'isPositionGeoBoxImmutable'
        QtMocHelpers::PropertyData<bool>(926, QMetaType::Bool, QMC::DefaultPropertyFlags | QMC::Constant),
        // property 'shadeTimeBox'
        QtMocHelpers::PropertyData<bool>(927, QMetaType::Bool, QMC::DefaultPropertyFlags | QMC::Writable | QMC::StdCppSet, 3),
        // property 'isShadeTimeBoxImmutable'
        QtMocHelpers::PropertyData<bool>(928, QMetaType::Bool, QMC::DefaultPropertyFlags | QMC::Constant),
        // property 'shadeFocusBox'
        QtMocHelpers::PropertyData<bool>(929, QMetaType::Bool, QMC::DefaultPropertyFlags | QMC::Writable | QMC::StdCppSet, 4),
        // property 'isShadeFocusBoxImmutable'
        QtMocHelpers::PropertyData<bool>(930, QMetaType::Bool, QMC::DefaultPropertyFlags | QMC::Constant),
        // property 'shadeGeoBox'
        QtMocHelpers::PropertyData<bool>(931, QMetaType::Bool, QMC::DefaultPropertyFlags | QMC::Writable | QMC::StdCppSet, 5),
        // property 'isShadeGeoBoxImmutable'
        QtMocHelpers::PropertyData<bool>(932, QMetaType::Bool, QMC::DefaultPropertyFlags | QMC::Constant),
        // property 'showInfoBoxes'
        QtMocHelpers::PropertyData<bool>(933, QMetaType::Bool, QMC::DefaultPropertyFlags | QMC::Writable | QMC::StdCppSet, 6),
        // property 'isShowInfoBoxesImmutable'
        QtMocHelpers::PropertyData<bool>(934, QMetaType::Bool, QMC::DefaultPropertyFlags | QMC::Constant),
        // property 'showTimeBox'
        QtMocHelpers::PropertyData<bool>(935, QMetaType::Bool, QMC::DefaultPropertyFlags | QMC::Writable | QMC::StdCppSet, 7),
        // property 'isShowTimeBoxImmutable'
        QtMocHelpers::PropertyData<bool>(936, QMetaType::Bool, QMC::DefaultPropertyFlags | QMC::Constant),
        // property 'showFocusBox'
        QtMocHelpers::PropertyData<bool>(937, QMetaType::Bool, QMC::DefaultPropertyFlags | QMC::Writable | QMC::StdCppSet, 8),
        // property 'isShowFocusBoxImmutable'
        QtMocHelpers::PropertyData<bool>(938, QMetaType::Bool, QMC::DefaultPropertyFlags | QMC::Constant),
        // property 'showGeoBox'
        QtMocHelpers::PropertyData<bool>(939, QMetaType::Bool, QMC::DefaultPropertyFlags | QMC::Writable | QMC::StdCppSet, 9),
        // property 'isShowGeoBoxImmutable'
        QtMocHelpers::PropertyData<bool>(940, QMetaType::Bool, QMC::DefaultPropertyFlags | QMC::Constant),
        // property 'stickyTimeBox'
        QtMocHelpers::PropertyData<int>(941, QMetaType::Int, QMC::DefaultPropertyFlags | QMC::Writable | QMC::StdCppSet, 10),
        // property 'isStickyTimeBoxImmutable'
        QtMocHelpers::PropertyData<bool>(942, QMetaType::Bool, QMC::DefaultPropertyFlags | QMC::Constant),
        // property 'stickyFocusBox'
        QtMocHelpers::PropertyData<int>(943, QMetaType::Int, QMC::DefaultPropertyFlags | QMC::Writable | QMC::StdCppSet, 11),
        // property 'isStickyFocusBoxImmutable'
        QtMocHelpers::PropertyData<bool>(944, QMetaType::Bool, QMC::DefaultPropertyFlags | QMC::Constant),
        // property 'stickyGeoBox'
        QtMocHelpers::PropertyData<int>(945, QMetaType::Int, QMC::DefaultPropertyFlags | QMC::Writable | QMC::StdCppSet, 12),
        // property 'isStickyGeoBoxImmutable'
        QtMocHelpers::PropertyData<bool>(946, QMetaType::Bool, QMC::DefaultPropertyFlags | QMC::Constant),
        // property 'showStatusBar'
        QtMocHelpers::PropertyData<bool>(947, QMetaType::Bool, QMC::DefaultPropertyFlags | QMC::Writable | QMC::StdCppSet, 13),
        // property 'isShowStatusBarImmutable'
        QtMocHelpers::PropertyData<bool>(948, QMetaType::Bool, QMC::DefaultPropertyFlags | QMC::Constant),
        // property 'showAltAzField'
        QtMocHelpers::PropertyData<bool>(949, QMetaType::Bool, QMC::DefaultPropertyFlags | QMC::Writable | QMC::StdCppSet, 14),
        // property 'isShowAltAzFieldImmutable'
        QtMocHelpers::PropertyData<bool>(950, QMetaType::Bool, QMC::DefaultPropertyFlags | QMC::Constant),
        // property 'showRADecField'
        QtMocHelpers::PropertyData<bool>(951, QMetaType::Bool, QMC::DefaultPropertyFlags | QMC::Writable | QMC::StdCppSet, 15),
        // property 'isShowRADecFieldImmutable'
        QtMocHelpers::PropertyData<bool>(952, QMetaType::Bool, QMC::DefaultPropertyFlags | QMC::Constant),
        // property 'showJ2000RADecField'
        QtMocHelpers::PropertyData<bool>(953, QMetaType::Bool, QMC::DefaultPropertyFlags | QMC::Writable | QMC::StdCppSet, 16),
        // property 'isShowJ2000RADecFieldImmutable'
        QtMocHelpers::PropertyData<bool>(954, QMetaType::Bool, QMC::DefaultPropertyFlags | QMC::Constant),
        // property 'showSensorFOV'
        QtMocHelpers::PropertyData<bool>(955, QMetaType::Bool, QMC::DefaultPropertyFlags | QMC::Writable | QMC::StdCppSet, 17),
        // property 'isShowSensorFOVImmutable'
        QtMocHelpers::PropertyData<bool>(956, QMetaType::Bool, QMC::DefaultPropertyFlags | QMC::Constant),
        // property 'windowWidth'
        QtMocHelpers::PropertyData<uint>(957, QMetaType::UInt, QMC::DefaultPropertyFlags | QMC::Writable | QMC::StdCppSet, 18),
        // property 'isWindowWidthImmutable'
        QtMocHelpers::PropertyData<bool>(958, QMetaType::Bool, QMC::DefaultPropertyFlags | QMC::Constant),
        // property 'windowHeight'
        QtMocHelpers::PropertyData<uint>(959, QMetaType::UInt, QMC::DefaultPropertyFlags | QMC::Writable | QMC::StdCppSet, 19),
        // property 'isWindowHeightImmutable'
        QtMocHelpers::PropertyData<bool>(960, QMetaType::Bool, QMC::DefaultPropertyFlags | QMC::Constant),
        // property 'kStarsGeometry'
        QtMocHelpers::PropertyData<QString>(961, QMetaType::QString, QMC::DefaultPropertyFlags | QMC::Writable | QMC::StdCppSet, 20),
        // property 'isKStarsGeometryImmutable'
        QtMocHelpers::PropertyData<bool>(962, QMetaType::Bool, QMC::DefaultPropertyFlags | QMC::Constant),
        // property 'runStartupWizard'
        QtMocHelpers::PropertyData<bool>(963, QMetaType::Bool, QMC::DefaultPropertyFlags | QMC::Writable | QMC::StdCppSet, 21),
        // property 'isRunStartupWizardImmutable'
        QtMocHelpers::PropertyData<bool>(964, QMetaType::Bool, QMC::DefaultPropertyFlags | QMC::Constant),
        // property 'currentTheme'
        QtMocHelpers::PropertyData<QString>(965, QMetaType::QString, QMC::DefaultPropertyFlags | QMC::Writable | QMC::StdCppSet, 22),
        // property 'isCurrentThemeImmutable'
        QtMocHelpers::PropertyData<bool>(966, QMetaType::Bool, QMC::DefaultPropertyFlags | QMC::Constant),
        // property 'catalogFile'
        QtMocHelpers::PropertyData<QStringList>(967, QMetaType::QStringList, QMC::DefaultPropertyFlags | QMC::Writable | QMC::StdCppSet, 23),
        // property 'isCatalogFileImmutable'
        QtMocHelpers::PropertyData<bool>(968, QMetaType::Bool, QMC::DefaultPropertyFlags | QMC::Constant),
        // property 'showCatalog'
        QtMocHelpers::PropertyData<QList<int>>(969, 0x80000000 | 970, QMC::DefaultPropertyFlags | QMC::Writable | QMC::EnumOrFlag | QMC::StdCppSet, 24),
        // property 'isShowCatalogImmutable'
        QtMocHelpers::PropertyData<bool>(971, QMetaType::Bool, QMC::DefaultPropertyFlags | QMC::Constant),
        // property 'showCatalogNames'
        QtMocHelpers::PropertyData<QStringList>(972, QMetaType::QStringList, QMC::DefaultPropertyFlags | QMC::Writable | QMC::StdCppSet, 25),
        // property 'isShowCatalogNamesImmutable'
        QtMocHelpers::PropertyData<bool>(973, QMetaType::Bool, QMC::DefaultPropertyFlags | QMC::Constant),
        // property 'resolveNamesOnline'
        QtMocHelpers::PropertyData<bool>(974, QMetaType::Bool, QMC::DefaultPropertyFlags | QMC::Writable | QMC::StdCppSet, 26),
        // property 'isResolveNamesOnlineImmutable'
        QtMocHelpers::PropertyData<bool>(975, QMetaType::Bool, QMC::DefaultPropertyFlags | QMC::Constant),
        // property 'dSOCachePercentage'
        QtMocHelpers::PropertyData<uint>(976, QMetaType::UInt, QMC::DefaultPropertyFlags | QMC::Writable | QMC::StdCppSet, 27),
        // property 'isDSOCachePercentageImmutable'
        QtMocHelpers::PropertyData<bool>(977, QMetaType::Bool, QMC::DefaultPropertyFlags | QMC::Constant),
        // property 'dSOMinZoomFactor'
        QtMocHelpers::PropertyData<uint>(978, QMetaType::UInt, QMC::DefaultPropertyFlags | QMC::Writable | QMC::StdCppSet, 28),
        // property 'isDSOMinZoomFactorImmutable'
        QtMocHelpers::PropertyData<bool>(979, QMetaType::Bool, QMC::DefaultPropertyFlags | QMC::Constant),
        // property 'dSOCatalogFilename'
        QtMocHelpers::PropertyData<QString>(980, QMetaType::QString, QMC::DefaultPropertyFlags | QMC::Writable | QMC::StdCppSet, 29),
        // property 'isDSOCatalogFilenameImmutable'
        QtMocHelpers::PropertyData<bool>(981, QMetaType::Bool, QMC::DefaultPropertyFlags | QMC::Constant),
        // property 'dSODefaultCatalogFilename'
        QtMocHelpers::PropertyData<QString>(982, QMetaType::QString, QMC::DefaultPropertyFlags | QMC::Writable | QMC::StdCppSet, 30),
        // property 'isDSODefaultCatalogFilenameImmutable'
        QtMocHelpers::PropertyData<bool>(983, QMetaType::Bool, QMC::DefaultPropertyFlags | QMC::Constant),
        // property 'iNDIWindowWidth'
        QtMocHelpers::PropertyData<uint>(984, QMetaType::UInt, QMC::DefaultPropertyFlags | QMC::Writable | QMC::StdCppSet, 31),
        // property 'isINDIWindowWidthImmutable'
        QtMocHelpers::PropertyData<bool>(985, QMetaType::Bool, QMC::DefaultPropertyFlags | QMC::Constant),
        // property 'iNDIWindowHeight'
        QtMocHelpers::PropertyData<uint>(986, QMetaType::UInt, QMC::DefaultPropertyFlags | QMC::Writable | QMC::StdCppSet, 32),
        // property 'isINDIWindowHeightImmutable'
        QtMocHelpers::PropertyData<bool>(987, QMetaType::Bool, QMC::DefaultPropertyFlags | QMC::Constant),
        // property 'iNDIWindowGeometry'
        QtMocHelpers::PropertyData<QString>(988, QMetaType::QString, QMC::DefaultPropertyFlags | QMC::Writable | QMC::StdCppSet, 33),
        // property 'isINDIWindowGeometryImmutable'
        QtMocHelpers::PropertyData<bool>(989, QMetaType::Bool, QMC::DefaultPropertyFlags | QMC::Constant),
        // property 'useGeographicUpdate'
        QtMocHelpers::PropertyData<bool>(990, QMetaType::Bool, QMC::DefaultPropertyFlags | QMC::Writable | QMC::StdCppSet, 34),
        // property 'isUseGeographicUpdateImmutable'
        QtMocHelpers::PropertyData<bool>(991, QMetaType::Bool, QMC::DefaultPropertyFlags | QMC::Constant),
        // property 'useTimeUpdate'
        QtMocHelpers::PropertyData<bool>(992, QMetaType::Bool, QMC::DefaultPropertyFlags | QMC::Writable | QMC::StdCppSet, 35),
        // property 'isUseTimeUpdateImmutable'
        QtMocHelpers::PropertyData<bool>(993, QMetaType::Bool, QMC::DefaultPropertyFlags | QMC::Constant),
        // property 'independentWindowINDI'
        QtMocHelpers::PropertyData<bool>(994, QMetaType::Bool, QMC::DefaultPropertyFlags | QMC::Writable | QMC::StdCppSet, 36),
        // property 'isIndependentWindowINDIImmutable'
        QtMocHelpers::PropertyData<bool>(995, QMetaType::Bool, QMC::DefaultPropertyFlags | QMC::Constant),
        // property 'showTargetCrosshair'
        QtMocHelpers::PropertyData<bool>(996, QMetaType::Bool, QMC::DefaultPropertyFlags | QMC::Writable | QMC::StdCppSet, 37),
        // property 'isShowTargetCrosshairImmutable'
        QtMocHelpers::PropertyData<bool>(997, QMetaType::Bool, QMC::DefaultPropertyFlags | QMC::Constant),
        // property 'showINDIMessages'
        QtMocHelpers::PropertyData<bool>(998, QMetaType::Bool, QMC::DefaultPropertyFlags | QMC::Writable | QMC::StdCppSet, 38),
        // property 'isShowINDIMessagesImmutable'
        QtMocHelpers::PropertyData<bool>(999, QMetaType::Bool, QMC::DefaultPropertyFlags | QMC::Constant),
        // property 'showINDIwindowInitially'
        QtMocHelpers::PropertyData<bool>(1000, QMetaType::Bool, QMC::DefaultPropertyFlags | QMC::Writable | QMC::StdCppSet, 39),
        // property 'isShowINDIwindowInitiallyImmutable'
        QtMocHelpers::PropertyData<bool>(1001, QMetaType::Bool, QMC::DefaultPropertyFlags | QMC::Constant),
        // property 'maxFocusFrameFiles'
        QtMocHelpers::PropertyData<int>(1002, QMetaType::Int, QMC::DefaultPropertyFlags | QMC::Writable | QMC::StdCppSet, 40),
        // property 'isMaxFocusFrameFilesImmutable'
        QtMocHelpers::PropertyData<bool>(1003, QMetaType::Bool, QMC::DefaultPropertyFlags | QMC::Constant),
        // property 'messageNotificationINDI'
        QtMocHelpers::PropertyData<bool>(1004, QMetaType::Bool, QMC::DefaultPropertyFlags | QMC::Writable | QMC::StdCppSet, 41),
        // property 'isMessageNotificationINDIImmutable'
        QtMocHelpers::PropertyData<bool>(1005, QMetaType::Bool, QMC::DefaultPropertyFlags | QMC::Constant),
        // property 'timeSource'
        QtMocHelpers::PropertyData<QString>(1006, QMetaType::QString, QMC::DefaultPropertyFlags | QMC::Writable | QMC::StdCppSet, 42),
        // property 'isTimeSourceImmutable'
        QtMocHelpers::PropertyData<bool>(1007, QMetaType::Bool, QMC::DefaultPropertyFlags | QMC::Constant),
        // property 'locationSource'
        QtMocHelpers::PropertyData<QString>(1008, QMetaType::QString, QMC::DefaultPropertyFlags | QMC::Writable | QMC::StdCppSet, 43),
        // property 'isLocationSourceImmutable'
        QtMocHelpers::PropertyData<bool>(1009, QMetaType::Bool, QMC::DefaultPropertyFlags | QMC::Constant),
        // property 'useExternalSkyMap'
        QtMocHelpers::PropertyData<bool>(1010, QMetaType::Bool, QMC::DefaultPropertyFlags | QMC::Writable | QMC::StdCppSet, 44),
        // property 'isUseExternalSkyMapImmutable'
        QtMocHelpers::PropertyData<bool>(1011, QMetaType::Bool, QMC::DefaultPropertyFlags | QMC::Constant),
        // property 'fitsDir'
        QtMocHelpers::PropertyData<QString>(1012, QMetaType::QString, QMC::DefaultPropertyFlags | QMC::Writable | QMC::StdCppSet, 45),
        // property 'isFitsDirImmutable'
        QtMocHelpers::PropertyData<bool>(1013, QMetaType::Bool, QMC::DefaultPropertyFlags | QMC::Constant),
        // property 'serverTransferBufferSize'
        QtMocHelpers::PropertyData<int>(1014, QMetaType::Int, QMC::DefaultPropertyFlags | QMC::Writable | QMC::StdCppSet, 46),
        // property 'isServerTransferBufferSizeImmutable'
        QtMocHelpers::PropertyData<bool>(1015, QMetaType::Bool, QMC::DefaultPropertyFlags | QMC::Constant),
        // property 'serverPortStart'
        QtMocHelpers::PropertyData<int>(1016, QMetaType::Int, QMC::DefaultPropertyFlags | QMC::Writable | QMC::StdCppSet, 47),
        // property 'isServerPortStartImmutable'
        QtMocHelpers::PropertyData<bool>(1017, QMetaType::Bool, QMC::DefaultPropertyFlags | QMC::Constant),
        // property 'serverPortEnd'
        QtMocHelpers::PropertyData<int>(1018, QMetaType::Int, QMC::DefaultPropertyFlags | QMC::Writable | QMC::StdCppSet, 48),
        // property 'isServerPortEndImmutable'
        QtMocHelpers::PropertyData<bool>(1019, QMetaType::Bool, QMC::DefaultPropertyFlags | QMC::Constant),
        // property 'indiServer'
        QtMocHelpers::PropertyData<QString>(1020, QMetaType::QString, QMC::DefaultPropertyFlags | QMC::Writable | QMC::StdCppSet, 49),
        // property 'isIndiServerImmutable'
        QtMocHelpers::PropertyData<bool>(1021, QMetaType::Bool, QMC::DefaultPropertyFlags | QMC::Constant),
        // property 'indiServerIsInternal'
        QtMocHelpers::PropertyData<bool>(1022, QMetaType::Bool, QMC::DefaultPropertyFlags | QMC::Writable | QMC::StdCppSet, 50),
        // property 'isIndiServerIsInternalImmutable'
        QtMocHelpers::PropertyData<bool>(1023, QMetaType::Bool, QMC::DefaultPropertyFlags | QMC::Constant),
        // property 'indiDriversDir'
        QtMocHelpers::PropertyData<QString>(1024, QMetaType::QString, QMC::DefaultPropertyFlags | QMC::Writable | QMC::StdCppSet, 51),
        // property 'isIndiDriversDirImmutable'
        QtMocHelpers::PropertyData<bool>(1025, QMetaType::Bool, QMC::DefaultPropertyFlags | QMC::Constant),
        // property 'indiDriversAreInternal'
        QtMocHelpers::PropertyData<bool>(1026, QMetaType::Bool, QMC::DefaultPropertyFlags | QMC::Writable | QMC::StdCppSet, 52),
        // property 'isIndiDriversAreInternalImmutable'
        QtMocHelpers::PropertyData<bool>(1027, QMetaType::Bool, QMC::DefaultPropertyFlags | QMC::Constant),
        // property 'streamWindowWidth'
        QtMocHelpers::PropertyData<uint>(1028, QMetaType::UInt, QMC::DefaultPropertyFlags | QMC::Writable | QMC::StdCppSet, 53),
        // property 'isStreamWindowWidthImmutable'
        QtMocHelpers::PropertyData<bool>(1029, QMetaType::Bool, QMC::DefaultPropertyFlags | QMC::Constant),
        // property 'streamWindowHeight'
        QtMocHelpers::PropertyData<uint>(1030, QMetaType::UInt, QMC::DefaultPropertyFlags | QMC::Writable | QMC::StdCppSet, 54),
        // property 'isStreamWindowHeightImmutable'
        QtMocHelpers::PropertyData<bool>(1031, QMetaType::Bool, QMC::DefaultPropertyFlags | QMC::Constant),
        // property 'iNDIMountLogging'
        QtMocHelpers::PropertyData<bool>(1032, QMetaType::Bool, QMC::DefaultPropertyFlags | QMC::Writable | QMC::StdCppSet, 55),
        // property 'isINDIMountLoggingImmutable'
        QtMocHelpers::PropertyData<bool>(1033, QMetaType::Bool, QMC::DefaultPropertyFlags | QMC::Constant),
        // property 'iNDIFocuserLogging'
        QtMocHelpers::PropertyData<bool>(1034, QMetaType::Bool, QMC::DefaultPropertyFlags | QMC::Writable | QMC::StdCppSet, 56),
        // property 'isINDIFocuserLoggingImmutable'
        QtMocHelpers::PropertyData<bool>(1035, QMetaType::Bool, QMC::DefaultPropertyFlags | QMC::Constant),
        // property 'iNDICCDLogging'
        QtMocHelpers::PropertyData<bool>(1036, QMetaType::Bool, QMC::DefaultPropertyFlags | QMC::Writable | QMC::StdCppSet, 57),
        // property 'isINDICCDLoggingImmutable'
        QtMocHelpers::PropertyData<bool>(1037, QMetaType::Bool, QMC::DefaultPropertyFlags | QMC::Constant),
        // property 'iNDIFilterWheelLogging'
        QtMocHelpers::PropertyData<bool>(1038, QMetaType::Bool, QMC::DefaultPropertyFlags | QMC::Writable | QMC::StdCppSet, 58),
        // property 'isINDIFilterWheelLoggingImmutable'
        QtMocHelpers::PropertyData<bool>(1039, QMetaType::Bool, QMC::DefaultPropertyFlags | QMC::Constant),
        // property 'iNDIDomeLogging'
        QtMocHelpers::PropertyData<bool>(1040, QMetaType::Bool, QMC::DefaultPropertyFlags | QMC::Writable | QMC::StdCppSet, 59),
        // property 'isINDIDomeLoggingImmutable'
        QtMocHelpers::PropertyData<bool>(1041, QMetaType::Bool, QMC::DefaultPropertyFlags | QMC::Constant),
        // property 'iNDIDetectorLogging'
        QtMocHelpers::PropertyData<bool>(1042, QMetaType::Bool, QMC::DefaultPropertyFlags | QMC::Writable | QMC::StdCppSet, 60),
        // property 'isINDIDetectorLoggingImmutable'
        QtMocHelpers::PropertyData<bool>(1043, QMetaType::Bool, QMC::DefaultPropertyFlags | QMC::Constant),
        // property 'iNDIWeatherLogging'
        QtMocHelpers::PropertyData<bool>(1044, QMetaType::Bool, QMC::DefaultPropertyFlags | QMC::Writable | QMC::StdCppSet, 61),
        // property 'isINDIWeatherLoggingImmutable'
        QtMocHelpers::PropertyData<bool>(1045, QMetaType::Bool, QMC::DefaultPropertyFlags | QMC::Constant),
        // property 'iNDIAuxiliaryLogging'
        QtMocHelpers::PropertyData<bool>(1046, QMetaType::Bool, QMC::DefaultPropertyFlags | QMC::Writable | QMC::StdCppSet, 62),
        // property 'isINDIAuxiliaryLoggingImmutable'
        QtMocHelpers::PropertyData<bool>(1047, QMetaType::Bool, QMC::DefaultPropertyFlags | QMC::Constant),
        // property 'iNDIRotatorLogging'
        QtMocHelpers::PropertyData<bool>(1048, QMetaType::Bool, QMC::DefaultPropertyFlags | QMC::Writable | QMC::StdCppSet, 63),
        // property 'isINDIRotatorLoggingImmutable'
        QtMocHelpers::PropertyData<bool>(1049, QMetaType::Bool, QMC::DefaultPropertyFlags | QMC::Constant),
        // property 'iNDIGPSLogging'
        QtMocHelpers::PropertyData<bool>(1050, QMetaType::Bool, QMC::DefaultPropertyFlags | QMC::Writable | QMC::StdCppSet, 64),
        // property 'isINDIGPSLoggingImmutable'
        QtMocHelpers::PropertyData<bool>(1051, QMetaType::Bool, QMC::DefaultPropertyFlags | QMC::Constant),
        // property 'iNDIAOLogging'
        QtMocHelpers::PropertyData<bool>(1052, QMetaType::Bool, QMC::DefaultPropertyFlags | QMC::Writable | QMC::StdCppSet, 65),
        // property 'isINDIAOLoggingImmutable'
        QtMocHelpers::PropertyData<bool>(1053, QMetaType::Bool, QMC::DefaultPropertyFlags | QMC::Constant),
        // property 'cityName'
        QtMocHelpers::PropertyData<QString>(1054, QMetaType::QString, QMC::DefaultPropertyFlags | QMC::Writable | QMC::StdCppSet, 66),
        // property 'isCityNameImmutable'
        QtMocHelpers::PropertyData<bool>(1055, QMetaType::Bool, QMC::DefaultPropertyFlags | QMC::Constant),
        // property 'provinceName'
        QtMocHelpers::PropertyData<QString>(1056, QMetaType::QString, QMC::DefaultPropertyFlags | QMC::Writable | QMC::StdCppSet, 67),
        // property 'isProvinceNameImmutable'
        QtMocHelpers::PropertyData<bool>(1057, QMetaType::Bool, QMC::DefaultPropertyFlags | QMC::Constant),
        // property 'countryName'
        QtMocHelpers::PropertyData<QString>(1058, QMetaType::QString, QMC::DefaultPropertyFlags | QMC::Writable | QMC::StdCppSet, 68),
        // property 'isCountryNameImmutable'
        QtMocHelpers::PropertyData<bool>(1059, QMetaType::Bool, QMC::DefaultPropertyFlags | QMC::Constant),
        // property 'longitude'
        QtMocHelpers::PropertyData<double>(1060, QMetaType::Double, QMC::DefaultPropertyFlags | QMC::Writable | QMC::StdCppSet, 69),
        // property 'isLongitudeImmutable'
        QtMocHelpers::PropertyData<bool>(1061, QMetaType::Bool, QMC::DefaultPropertyFlags | QMC::Constant),
        // property 'latitude'
        QtMocHelpers::PropertyData<double>(1062, QMetaType::Double, QMC::DefaultPropertyFlags | QMC::Writable | QMC::StdCppSet, 70),
        // property 'isLatitudeImmutable'
        QtMocHelpers::PropertyData<bool>(1063, QMetaType::Bool, QMC::DefaultPropertyFlags | QMC::Constant),
        // property 'elevation'
        QtMocHelpers::PropertyData<double>(1064, QMetaType::Double, QMC::DefaultPropertyFlags | QMC::Writable | QMC::StdCppSet, 71),
        // property 'isElevationImmutable'
        QtMocHelpers::PropertyData<bool>(1065, QMetaType::Bool, QMC::DefaultPropertyFlags | QMC::Constant),
        // property 'timeZone'
        QtMocHelpers::PropertyData<double>(1066, QMetaType::Double, QMC::DefaultPropertyFlags | QMC::Writable | QMC::StdCppSet, 72),
        // property 'isTimeZoneImmutable'
        QtMocHelpers::PropertyData<bool>(1067, QMetaType::Bool, QMC::DefaultPropertyFlags | QMC::Constant),
        // property 'dST'
        QtMocHelpers::PropertyData<QString>(1068, QMetaType::QString, QMC::DefaultPropertyFlags | QMC::Writable | QMC::StdCppSet, 73),
        // property 'isDSTImmutable'
        QtMocHelpers::PropertyData<bool>(1069, QMetaType::Bool, QMC::DefaultPropertyFlags | QMC::Constant),
        // property 'useAnimatedSlewing'
        QtMocHelpers::PropertyData<bool>(1070, QMetaType::Bool, QMC::DefaultPropertyFlags | QMC::Writable | QMC::StdCppSet, 74),
        // property 'isUseAnimatedSlewingImmutable'
        QtMocHelpers::PropertyData<bool>(1071, QMetaType::Bool, QMC::DefaultPropertyFlags | QMC::Constant),
        // property 'leftClickSelectsObject'
        QtMocHelpers::PropertyData<bool>(1072, QMetaType::Bool, QMC::DefaultPropertyFlags | QMC::Writable | QMC::StdCppSet, 75),
        // property 'isLeftClickSelectsObjectImmutable'
        QtMocHelpers::PropertyData<bool>(1073, QMetaType::Bool, QMC::DefaultPropertyFlags | QMC::Constant),
        // property 'defaultCursor'
        QtMocHelpers::PropertyData<uint>(1074, QMetaType::UInt, QMC::DefaultPropertyFlags | QMC::Writable | QMC::StdCppSet, 76),
        // property 'isDefaultCursorImmutable'
        QtMocHelpers::PropertyData<bool>(1075, QMetaType::Bool, QMC::DefaultPropertyFlags | QMC::Constant),
        // property 'fOVNames'
        QtMocHelpers::PropertyData<QStringList>(1076, QMetaType::QStringList, QMC::DefaultPropertyFlags | QMC::Writable | QMC::StdCppSet, 77),
        // property 'isFOVNamesImmutable'
        QtMocHelpers::PropertyData<bool>(1077, QMetaType::Bool, QMC::DefaultPropertyFlags | QMC::Constant),
        // property 'fadePlanetTrails'
        QtMocHelpers::PropertyData<bool>(1078, QMetaType::Bool, QMC::DefaultPropertyFlags | QMC::Writable | QMC::StdCppSet, 78),
        // property 'isFadePlanetTrailsImmutable'
        QtMocHelpers::PropertyData<bool>(1079, QMetaType::Bool, QMC::DefaultPropertyFlags | QMC::Constant),
        // property 'focusRA'
        QtMocHelpers::PropertyData<double>(1080, QMetaType::Double, QMC::DefaultPropertyFlags | QMC::Writable | QMC::StdCppSet, 79),
        // property 'isFocusRAImmutable'
        QtMocHelpers::PropertyData<bool>(1081, QMetaType::Bool, QMC::DefaultPropertyFlags | QMC::Constant),
        // property 'focusDec'
        QtMocHelpers::PropertyData<double>(1082, QMetaType::Double, QMC::DefaultPropertyFlags | QMC::Writable | QMC::StdCppSet, 80),
        // property 'isFocusDecImmutable'
        QtMocHelpers::PropertyData<bool>(1083, QMetaType::Bool, QMC::DefaultPropertyFlags | QMC::Constant),
        // property 'focusObject'
        QtMocHelpers::PropertyData<QString>(1084, QMetaType::QString, QMC::DefaultPropertyFlags | QMC::Writable | QMC::StdCppSet, 81),
        // property 'isFocusObjectImmutable'
        QtMocHelpers::PropertyData<bool>(1085, QMetaType::Bool, QMC::DefaultPropertyFlags | QMC::Constant),
        // property 'isTracking'
        QtMocHelpers::PropertyData<bool>(1086, QMetaType::Bool, QMC::DefaultPropertyFlags | QMC::Writable | QMC::StdCppSet, 82),
        // property 'isIsTrackingImmutable'
        QtMocHelpers::PropertyData<bool>(1087, QMetaType::Bool, QMC::DefaultPropertyFlags | QMC::Constant),
        // property 'hideOnSlew'
        QtMocHelpers::PropertyData<bool>(1088, QMetaType::Bool, QMC::DefaultPropertyFlags | QMC::Writable | QMC::StdCppSet, 83),
        // property 'isHideOnSlewImmutable'
        QtMocHelpers::PropertyData<bool>(1089, QMetaType::Bool, QMC::DefaultPropertyFlags | QMC::Constant),
        // property 'hideCBounds'
        QtMocHelpers::PropertyData<bool>(1090, QMetaType::Bool, QMC::DefaultPropertyFlags | QMC::Writable | QMC::StdCppSet, 84),
        // property 'isHideCBoundsImmutable'
        QtMocHelpers::PropertyData<bool>(1091, QMetaType::Bool, QMC::DefaultPropertyFlags | QMC::Constant),
        // property 'hideCLines'
        QtMocHelpers::PropertyData<bool>(1092, QMetaType::Bool, QMC::DefaultPropertyFlags | QMC::Writable | QMC::StdCppSet, 85),
        // property 'isHideCLinesImmutable'
        QtMocHelpers::PropertyData<bool>(1093, QMetaType::Bool, QMC::DefaultPropertyFlags | QMC::Constant),
        // property 'skyCulture'
        QtMocHelpers::PropertyData<QString>(1094, QMetaType::QString, QMC::DefaultPropertyFlags | QMC::Writable | QMC::StdCppSet, 86),
        // property 'isSkyCultureImmutable'
        QtMocHelpers::PropertyData<bool>(1095, QMetaType::Bool, QMC::DefaultPropertyFlags | QMC::Constant),
        // property 'hideCNames'
        QtMocHelpers::PropertyData<bool>(1096, QMetaType::Bool, QMC::DefaultPropertyFlags | QMC::Writable | QMC::StdCppSet, 87),
        // property 'isHideCNamesImmutable'
        QtMocHelpers::PropertyData<bool>(1097, QMetaType::Bool, QMC::DefaultPropertyFlags | QMC::Constant),
        // property 'hideGrids'
        QtMocHelpers::PropertyData<bool>(1098, QMetaType::Bool, QMC::DefaultPropertyFlags | QMC::Writable | QMC::StdCppSet, 88),
        // property 'isHideGridsImmutable'
        QtMocHelpers::PropertyData<bool>(1099, QMetaType::Bool, QMC::DefaultPropertyFlags | QMC::Constant),
        // property 'hideMilkyWay'
        QtMocHelpers::PropertyData<bool>(1100, QMetaType::Bool, QMC::DefaultPropertyFlags | QMC::Writable | QMC::StdCppSet, 89),
        // property 'isHideMilkyWayImmutable'
        QtMocHelpers::PropertyData<bool>(1101, QMetaType::Bool, QMC::DefaultPropertyFlags | QMC::Constant),
        // property 'hideOther'
        QtMocHelpers::PropertyData<bool>(1102, QMetaType::Bool, QMC::DefaultPropertyFlags | QMC::Writable | QMC::StdCppSet, 90),
        // property 'isHideOtherImmutable'
        QtMocHelpers::PropertyData<bool>(1103, QMetaType::Bool, QMC::DefaultPropertyFlags | QMC::Constant),
        // property 'hidePlanets'
        QtMocHelpers::PropertyData<bool>(1104, QMetaType::Bool, QMC::DefaultPropertyFlags | QMC::Writable | QMC::StdCppSet, 91),
        // property 'isHidePlanetsImmutable'
        QtMocHelpers::PropertyData<bool>(1105, QMetaType::Bool, QMC::DefaultPropertyFlags | QMC::Constant),
        // property 'hideStars'
        QtMocHelpers::PropertyData<bool>(1106, QMetaType::Bool, QMC::DefaultPropertyFlags | QMC::Writable | QMC::StdCppSet, 92),
        // property 'isHideStarsImmutable'
        QtMocHelpers::PropertyData<bool>(1107, QMetaType::Bool, QMC::DefaultPropertyFlags | QMC::Constant),
        // property 'hideLabels'
        QtMocHelpers::PropertyData<bool>(1108, QMetaType::Bool, QMC::DefaultPropertyFlags | QMC::Writable | QMC::StdCppSet, 93),
        // property 'isHideLabelsImmutable'
        QtMocHelpers::PropertyData<bool>(1109, QMetaType::Bool, QMC::DefaultPropertyFlags | QMC::Constant),
        // property 'showAsteroids'
        QtMocHelpers::PropertyData<bool>(1110, QMetaType::Bool, QMC::DefaultPropertyFlags | QMC::Writable | QMC::StdCppSet, 94),
        // property 'isShowAsteroidsImmutable'
        QtMocHelpers::PropertyData<bool>(1111, QMetaType::Bool, QMC::DefaultPropertyFlags | QMC::Constant),
        // property 'showAsteroidNames'
        QtMocHelpers::PropertyData<bool>(1112, QMetaType::Bool, QMC::DefaultPropertyFlags | QMC::Writable | QMC::StdCppSet, 95),
        // property 'isShowAsteroidNamesImmutable'
        QtMocHelpers::PropertyData<bool>(1113, QMetaType::Bool, QMC::DefaultPropertyFlags | QMC::Constant),
        // property 'orbitalElementsAutoUpdate'
        QtMocHelpers::PropertyData<bool>(1114, QMetaType::Bool, QMC::DefaultPropertyFlags | QMC::Writable | QMC::StdCppSet, 96),
        // property 'isOrbitalElementsAutoUpdateImmutable'
        QtMocHelpers::PropertyData<bool>(1115, QMetaType::Bool, QMC::DefaultPropertyFlags | QMC::Constant),
        // property 'showComets'
        QtMocHelpers::PropertyData<bool>(1116, QMetaType::Bool, QMC::DefaultPropertyFlags | QMC::Writable | QMC::StdCppSet, 97),
        // property 'isShowCometsImmutable'
        QtMocHelpers::PropertyData<bool>(1117, QMetaType::Bool, QMC::DefaultPropertyFlags | QMC::Constant),
        // property 'showCometComas'
        QtMocHelpers::PropertyData<bool>(1118, QMetaType::Bool, QMC::DefaultPropertyFlags | QMC::Writable | QMC::StdCppSet, 98),
        // property 'isShowCometComasImmutable'
        QtMocHelpers::PropertyData<bool>(1119, QMetaType::Bool, QMC::DefaultPropertyFlags | QMC::Constant),
        // property 'showCometNames'
        QtMocHelpers::PropertyData<bool>(1120, QMetaType::Bool, QMC::DefaultPropertyFlags | QMC::Writable | QMC::StdCppSet, 99),
        // property 'isShowCometNamesImmutable'
        QtMocHelpers::PropertyData<bool>(1121, QMetaType::Bool, QMC::DefaultPropertyFlags | QMC::Constant),
        // property 'showSupernovae'
        QtMocHelpers::PropertyData<bool>(1122, QMetaType::Bool, QMC::DefaultPropertyFlags | QMC::Writable | QMC::StdCppSet, 100),
        // property 'isShowSupernovaeImmutable'
        QtMocHelpers::PropertyData<bool>(1123, QMetaType::Bool, QMC::DefaultPropertyFlags | QMC::Constant),
        // property 'showSupernovaNames'
        QtMocHelpers::PropertyData<bool>(1124, QMetaType::Bool, QMC::DefaultPropertyFlags | QMC::Writable | QMC::StdCppSet, 101),
        // property 'isShowSupernovaNamesImmutable'
        QtMocHelpers::PropertyData<bool>(1125, QMetaType::Bool, QMC::DefaultPropertyFlags | QMC::Constant),
        // property 'magnitudeLimitShowSupernovae'
        QtMocHelpers::PropertyData<double>(1126, QMetaType::Double, QMC::DefaultPropertyFlags | QMC::Writable | QMC::StdCppSet, 102),
        // property 'isMagnitudeLimitShowSupernovaeImmutable'
        QtMocHelpers::PropertyData<bool>(1127, QMetaType::Bool, QMC::DefaultPropertyFlags | QMC::Constant),
        // property 'supernovaDetectionAge'
        QtMocHelpers::PropertyData<double>(1128, QMetaType::Double, QMC::DefaultPropertyFlags | QMC::Writable | QMC::StdCppSet, 103),
        // property 'isSupernovaDetectionAgeImmutable'
        QtMocHelpers::PropertyData<bool>(1129, QMetaType::Bool, QMC::DefaultPropertyFlags | QMC::Constant),
        // property 'supernovaDownloadUrl'
        QtMocHelpers::PropertyData<QString>(1130, QMetaType::QString, QMC::DefaultPropertyFlags | QMC::Writable | QMC::StdCppSet, 104),
        // property 'isSupernovaDownloadUrlImmutable'
        QtMocHelpers::PropertyData<bool>(1131, QMetaType::Bool, QMC::DefaultPropertyFlags | QMC::Constant),
        // property 'limitSupernovaeByZoom'
        QtMocHelpers::PropertyData<bool>(1132, QMetaType::Bool, QMC::DefaultPropertyFlags | QMC::Writable | QMC::StdCppSet, 105),
        // property 'isLimitSupernovaeByZoomImmutable'
        QtMocHelpers::PropertyData<bool>(1133, QMetaType::Bool, QMC::DefaultPropertyFlags | QMC::Constant),
        // property 'supernovaeHostOnly'
        QtMocHelpers::PropertyData<bool>(1134, QMetaType::Bool, QMC::DefaultPropertyFlags | QMC::Writable | QMC::StdCppSet, 106),
        // property 'isSupernovaeHostOnlyImmutable'
        QtMocHelpers::PropertyData<bool>(1135, QMetaType::Bool, QMC::DefaultPropertyFlags | QMC::Constant),
        // property 'supernovaeClassifiedOnly'
        QtMocHelpers::PropertyData<bool>(1136, QMetaType::Bool, QMC::DefaultPropertyFlags | QMC::Writable | QMC::StdCppSet, 107),
        // property 'isSupernovaeClassifiedOnlyImmutable'
        QtMocHelpers::PropertyData<bool>(1137, QMetaType::Bool, QMC::DefaultPropertyFlags | QMC::Constant),
        // property 'showSupernovaAlerts'
        QtMocHelpers::PropertyData<bool>(1138, QMetaType::Bool, QMC::DefaultPropertyFlags | QMC::Writable | QMC::StdCppSet, 108),
        // property 'isShowSupernovaAlertsImmutable'
        QtMocHelpers::PropertyData<bool>(1139, QMetaType::Bool, QMC::DefaultPropertyFlags | QMC::Constant),
        // property 'magnitudeLimitAlertSupernovae'
        QtMocHelpers::PropertyData<double>(1140, QMetaType::Double, QMC::DefaultPropertyFlags | QMC::Writable | QMC::StdCppSet, 109),
        // property 'isMagnitudeLimitAlertSupernovaeImmutable'
        QtMocHelpers::PropertyData<bool>(1141, QMetaType::Bool, QMC::DefaultPropertyFlags | QMC::Constant),
        // property 'showCBounds'
        QtMocHelpers::PropertyData<bool>(1142, QMetaType::Bool, QMC::DefaultPropertyFlags | QMC::Writable | QMC::StdCppSet, 110),
        // property 'isShowCBoundsImmutable'
        QtMocHelpers::PropertyData<bool>(1143, QMetaType::Bool, QMC::DefaultPropertyFlags | QMC::Constant),
        // property 'showHighlightedCBound'
        QtMocHelpers::PropertyData<bool>(1144, QMetaType::Bool, QMC::DefaultPropertyFlags | QMC::Writable | QMC::StdCppSet, 111),
        // property 'isShowHighlightedCBoundImmutable'
        QtMocHelpers::PropertyData<bool>(1145, QMetaType::Bool, QMC::DefaultPropertyFlags | QMC::Constant),
        // property 'showCLines'
        QtMocHelpers::PropertyData<bool>(1146, QMetaType::Bool, QMC::DefaultPropertyFlags | QMC::Writable | QMC::StdCppSet, 112),
        // property 'isShowCLinesImmutable'
        QtMocHelpers::PropertyData<bool>(1147, QMetaType::Bool, QMC::DefaultPropertyFlags | QMC::Constant),
        // property 'showConstellationArt'
        QtMocHelpers::PropertyData<bool>(1148, QMetaType::Bool, QMC::DefaultPropertyFlags | QMC::Writable | QMC::StdCppSet, 113),
        // property 'isShowConstellationArtImmutable'
        QtMocHelpers::PropertyData<bool>(1149, QMetaType::Bool, QMC::DefaultPropertyFlags | QMC::Constant),
        // property 'showCNames'
        QtMocHelpers::PropertyData<bool>(1150, QMetaType::Bool, QMC::DefaultPropertyFlags | QMC::Writable | QMC::StdCppSet, 114),
        // property 'isShowCNamesImmutable'
        QtMocHelpers::PropertyData<bool>(1151, QMetaType::Bool, QMC::DefaultPropertyFlags | QMC::Constant),
        // property 'showDeepSky'
        QtMocHelpers::PropertyData<bool>(1152, QMetaType::Bool, QMC::DefaultPropertyFlags | QMC::Writable | QMC::StdCppSet, 115),
        // property 'isShowDeepSkyImmutable'
        QtMocHelpers::PropertyData<bool>(1153, QMetaType::Bool, QMC::DefaultPropertyFlags | QMC::Constant),
        // property 'showEcliptic'
        QtMocHelpers::PropertyData<bool>(1154, QMetaType::Bool, QMC::DefaultPropertyFlags | QMC::Writable | QMC::StdCppSet, 116),
        // property 'isShowEclipticImmutable'
        QtMocHelpers::PropertyData<bool>(1155, QMetaType::Bool, QMC::DefaultPropertyFlags | QMC::Constant),
        // property 'showEquator'
        QtMocHelpers::PropertyData<bool>(1156, QMetaType::Bool, QMC::DefaultPropertyFlags | QMC::Writable | QMC::StdCppSet, 117),
        // property 'isShowEquatorImmutable'
        QtMocHelpers::PropertyData<bool>(1157, QMetaType::Bool, QMC::DefaultPropertyFlags | QMC::Constant),
        // property 'autoSelectGrid'
        QtMocHelpers::PropertyData<bool>(1158, QMetaType::Bool, QMC::DefaultPropertyFlags | QMC::Writable | QMC::StdCppSet, 118),
        // property 'isAutoSelectGridImmutable'
        QtMocHelpers::PropertyData<bool>(1159, QMetaType::Bool, QMC::DefaultPropertyFlags | QMC::Constant),
        // property 'showEquatorialGrid'
        QtMocHelpers::PropertyData<bool>(1160, QMetaType::Bool, QMC::DefaultPropertyFlags | QMC::Writable | QMC::StdCppSet, 119),
        // property 'isShowEquatorialGridImmutable'
        QtMocHelpers::PropertyData<bool>(1161, QMetaType::Bool, QMC::DefaultPropertyFlags | QMC::Constant),
        // property 'showHorizontalGrid'
        QtMocHelpers::PropertyData<bool>(1162, QMetaType::Bool, QMC::DefaultPropertyFlags | QMC::Writable | QMC::StdCppSet, 120),
        // property 'isShowHorizontalGridImmutable'
        QtMocHelpers::PropertyData<bool>(1163, QMetaType::Bool, QMC::DefaultPropertyFlags | QMC::Constant),
        // property 'showLocalMeridian'
        QtMocHelpers::PropertyData<bool>(1164, QMetaType::Bool, QMC::DefaultPropertyFlags | QMC::Writable | QMC::StdCppSet, 121),
        // property 'isShowLocalMeridianImmutable'
        QtMocHelpers::PropertyData<bool>(1165, QMetaType::Bool, QMC::DefaultPropertyFlags | QMC::Constant),
        // property 'showGround'
        QtMocHelpers::PropertyData<bool>(1166, QMetaType::Bool, QMC::DefaultPropertyFlags | QMC::Writable | QMC::StdCppSet, 122),
        // property 'isShowGroundImmutable'
        QtMocHelpers::PropertyData<bool>(1167, QMetaType::Bool, QMC::DefaultPropertyFlags | QMC::Constant),
        // property 'showHorizon'
        QtMocHelpers::PropertyData<bool>(1168, QMetaType::Bool, QMC::DefaultPropertyFlags | QMC::Writable | QMC::StdCppSet, 123),
        // property 'isShowHorizonImmutable'
        QtMocHelpers::PropertyData<bool>(1169, QMetaType::Bool, QMC::DefaultPropertyFlags | QMC::Constant),
        // property 'showFlags'
        QtMocHelpers::PropertyData<bool>(1170, QMetaType::Bool, QMC::DefaultPropertyFlags | QMC::Writable | QMC::StdCppSet, 124),
        // property 'isShowFlagsImmutable'
        QtMocHelpers::PropertyData<bool>(1171, QMetaType::Bool, QMC::DefaultPropertyFlags | QMC::Constant),
        // property 'simulateDaytime'
        QtMocHelpers::PropertyData<bool>(1172, QMetaType::Bool, QMC::DefaultPropertyFlags | QMC::Writable | QMC::StdCppSet, 125),
        // property 'isSimulateDaytimeImmutable'
        QtMocHelpers::PropertyData<bool>(1173, QMetaType::Bool, QMC::DefaultPropertyFlags | QMC::Constant),
        // property 'showOther'
        QtMocHelpers::PropertyData<bool>(1174, QMetaType::Bool, QMC::DefaultPropertyFlags | QMC::Writable | QMC::StdCppSet, 126),
        // property 'isShowOtherImmutable'
        QtMocHelpers::PropertyData<bool>(1175, QMetaType::Bool, QMC::DefaultPropertyFlags | QMC::Constant),
        // property 'showMilkyWay'
        QtMocHelpers::PropertyData<bool>(1176, QMetaType::Bool, QMC::DefaultPropertyFlags | QMC::Writable | QMC::StdCppSet, 127),
        // property 'isShowMilkyWayImmutable'
        QtMocHelpers::PropertyData<bool>(1177, QMetaType::Bool, QMC::DefaultPropertyFlags | QMC::Constant),
        // property 'fillMilkyWay'
        QtMocHelpers::PropertyData<bool>(1178, QMetaType::Bool, QMC::DefaultPropertyFlags | QMC::Writable | QMC::StdCppSet, 128),
        // property 'isFillMilkyWayImmutable'
        QtMocHelpers::PropertyData<bool>(1179, QMetaType::Bool, QMC::DefaultPropertyFlags | QMC::Constant),
        // property 'showSolarSystem'
        QtMocHelpers::PropertyData<bool>(1180, QMetaType::Bool, QMC::DefaultPropertyFlags | QMC::Writable | QMC::StdCppSet, 129),
        // property 'isShowSolarSystemImmutable'
        QtMocHelpers::PropertyData<bool>(1181, QMetaType::Bool, QMC::DefaultPropertyFlags | QMC::Constant),
        // property 'showPlanetImages'
        QtMocHelpers::PropertyData<bool>(1182, QMetaType::Bool, QMC::DefaultPropertyFlags | QMC::Writable | QMC::StdCppSet, 130),
        // property 'isShowPlanetImagesImmutable'
        QtMocHelpers::PropertyData<bool>(1183, QMetaType::Bool, QMC::DefaultPropertyFlags | QMC::Constant),
        // property 'showPlanetNames'
        QtMocHelpers::PropertyData<bool>(1184, QMetaType::Bool, QMC::DefaultPropertyFlags | QMC::Writable | QMC::StdCppSet, 131),
        // property 'isShowPlanetNamesImmutable'
        QtMocHelpers::PropertyData<bool>(1185, QMetaType::Bool, QMC::DefaultPropertyFlags | QMC::Constant),
        // property 'showSun'
        QtMocHelpers::PropertyData<bool>(1186, QMetaType::Bool, QMC::DefaultPropertyFlags | QMC::Writable | QMC::StdCppSet, 132),
        // property 'isShowSunImmutable'
        QtMocHelpers::PropertyData<bool>(1187, QMetaType::Bool, QMC::DefaultPropertyFlags | QMC::Constant),
        // property 'sunScale'
        QtMocHelpers::PropertyData<double>(1188, QMetaType::Double, QMC::DefaultPropertyFlags | QMC::Writable | QMC::StdCppSet, 133),
        // property 'isSunScaleImmutable'
        QtMocHelpers::PropertyData<bool>(1189, QMetaType::Bool, QMC::DefaultPropertyFlags | QMC::Constant),
        // property 'showMoon'
        QtMocHelpers::PropertyData<bool>(1190, QMetaType::Bool, QMC::DefaultPropertyFlags | QMC::Writable | QMC::StdCppSet, 134),
        // property 'isShowMoonImmutable'
        QtMocHelpers::PropertyData<bool>(1191, QMetaType::Bool, QMC::DefaultPropertyFlags | QMC::Constant),
        // property 'moonScale'
        QtMocHelpers::PropertyData<double>(1192, QMetaType::Double, QMC::DefaultPropertyFlags | QMC::Writable | QMC::StdCppSet, 135),
        // property 'isMoonScaleImmutable'
        QtMocHelpers::PropertyData<bool>(1193, QMetaType::Bool, QMC::DefaultPropertyFlags | QMC::Constant),
        // property 'showMercury'
        QtMocHelpers::PropertyData<bool>(1194, QMetaType::Bool, QMC::DefaultPropertyFlags | QMC::Writable | QMC::StdCppSet, 136),
        // property 'isShowMercuryImmutable'
        QtMocHelpers::PropertyData<bool>(1195, QMetaType::Bool, QMC::DefaultPropertyFlags | QMC::Constant),
        // property 'showVenus'
        QtMocHelpers::PropertyData<bool>(1196, QMetaType::Bool, QMC::DefaultPropertyFlags | QMC::Writable | QMC::StdCppSet, 137),
        // property 'isShowVenusImmutable'
        QtMocHelpers::PropertyData<bool>(1197, QMetaType::Bool, QMC::DefaultPropertyFlags | QMC::Constant),
        // property 'showMars'
        QtMocHelpers::PropertyData<bool>(1198, QMetaType::Bool, QMC::DefaultPropertyFlags | QMC::Writable | QMC::StdCppSet, 138),
        // property 'isShowMarsImmutable'
        QtMocHelpers::PropertyData<bool>(1199, QMetaType::Bool, QMC::DefaultPropertyFlags | QMC::Constant),
        // property 'showJupiter'
        QtMocHelpers::PropertyData<bool>(1200, QMetaType::Bool, QMC::DefaultPropertyFlags | QMC::Writable | QMC::StdCppSet, 139),
        // property 'isShowJupiterImmutable'
        QtMocHelpers::PropertyData<bool>(1201, QMetaType::Bool, QMC::DefaultPropertyFlags | QMC::Constant),
        // property 'showSaturn'
        QtMocHelpers::PropertyData<bool>(1202, QMetaType::Bool, QMC::DefaultPropertyFlags | QMC::Writable | QMC::StdCppSet, 140),
        // property 'isShowSaturnImmutable'
        QtMocHelpers::PropertyData<bool>(1203, QMetaType::Bool, QMC::DefaultPropertyFlags | QMC::Constant),
        // property 'showUranus'
        QtMocHelpers::PropertyData<bool>(1204, QMetaType::Bool, QMC::DefaultPropertyFlags | QMC::Writable | QMC::StdCppSet, 141),
        // property 'isShowUranusImmutable'
        QtMocHelpers::PropertyData<bool>(1205, QMetaType::Bool, QMC::DefaultPropertyFlags | QMC::Constant),
        // property 'showNeptune'
        QtMocHelpers::PropertyData<bool>(1206, QMetaType::Bool, QMC::DefaultPropertyFlags | QMC::Writable | QMC::StdCppSet, 142),
        // property 'isShowNeptuneImmutable'
        QtMocHelpers::PropertyData<bool>(1207, QMetaType::Bool, QMC::DefaultPropertyFlags | QMC::Constant),
        // property 'showPluto'
        QtMocHelpers::PropertyData<bool>(1208, QMetaType::Bool, QMC::DefaultPropertyFlags | QMC::Writable | QMC::StdCppSet, 143),
        // property 'isShowPlutoImmutable'
        QtMocHelpers::PropertyData<bool>(1209, QMetaType::Bool, QMC::DefaultPropertyFlags | QMC::Constant),
        // property 'showStars'
        QtMocHelpers::PropertyData<bool>(1210, QMetaType::Bool, QMC::DefaultPropertyFlags | QMC::Writable | QMC::StdCppSet, 144),
        // property 'isShowStarsImmutable'
        QtMocHelpers::PropertyData<bool>(1211, QMetaType::Bool, QMC::DefaultPropertyFlags | QMC::Constant),
        // property 'showStarMagnitudes'
        QtMocHelpers::PropertyData<bool>(1212, QMetaType::Bool, QMC::DefaultPropertyFlags | QMC::Writable | QMC::StdCppSet, 145),
        // property 'isShowStarMagnitudesImmutable'
        QtMocHelpers::PropertyData<bool>(1213, QMetaType::Bool, QMC::DefaultPropertyFlags | QMC::Constant),
        // property 'showStarsOverHIPS'
        QtMocHelpers::PropertyData<bool>(1214, QMetaType::Bool, QMC::DefaultPropertyFlags | QMC::Writable | QMC::StdCppSet, 146),
        // property 'isShowStarsOverHIPSImmutable'
        QtMocHelpers::PropertyData<bool>(1215, QMetaType::Bool, QMC::DefaultPropertyFlags | QMC::Constant),
        // property 'showStarNames'
        QtMocHelpers::PropertyData<bool>(1216, QMetaType::Bool, QMC::DefaultPropertyFlags | QMC::Writable | QMC::StdCppSet, 147),
        // property 'isShowStarNamesImmutable'
        QtMocHelpers::PropertyData<bool>(1217, QMetaType::Bool, QMC::DefaultPropertyFlags | QMC::Constant),
        // property 'showDeepSkyMagnitudes'
        QtMocHelpers::PropertyData<bool>(1218, QMetaType::Bool, QMC::DefaultPropertyFlags | QMC::Writable | QMC::StdCppSet, 148),
        // property 'isShowDeepSkyMagnitudesImmutable'
        QtMocHelpers::PropertyData<bool>(1219, QMetaType::Bool, QMC::DefaultPropertyFlags | QMC::Constant),
        // property 'showDeepSkyNames'
        QtMocHelpers::PropertyData<bool>(1220, QMetaType::Bool, QMC::DefaultPropertyFlags | QMC::Writable | QMC::StdCppSet, 149),
        // property 'isShowDeepSkyNamesImmutable'
        QtMocHelpers::PropertyData<bool>(1221, QMetaType::Bool, QMC::DefaultPropertyFlags | QMC::Constant),
        // property 'showMosaicPanel'
        QtMocHelpers::PropertyData<bool>(1222, QMetaType::Bool, QMC::DefaultPropertyFlags | QMC::Writable | QMC::StdCppSet, 150),
        // property 'isShowMosaicPanelImmutable'
        QtMocHelpers::PropertyData<bool>(1223, QMetaType::Bool, QMC::DefaultPropertyFlags | QMC::Constant),
        // property 'slewTimeScale'
        QtMocHelpers::PropertyData<double>(1224, QMetaType::Double, QMC::DefaultPropertyFlags | QMC::Writable | QMC::StdCppSet, 151),
        // property 'isSlewTimeScaleImmutable'
        QtMocHelpers::PropertyData<bool>(1225, QMetaType::Bool, QMC::DefaultPropertyFlags | QMC::Constant),
        // property 'boxBGMode'
        QtMocHelpers::PropertyData<uint>(1226, QMetaType::UInt, QMC::DefaultPropertyFlags | QMC::Writable | QMC::StdCppSet, 152),
        // property 'isBoxBGModeImmutable'
        QtMocHelpers::PropertyData<bool>(1227, QMetaType::Bool, QMC::DefaultPropertyFlags | QMC::Constant),
        // property 'projection'
        QtMocHelpers::PropertyData<uint>(1228, QMetaType::UInt, QMC::DefaultPropertyFlags | QMC::Writable | QMC::StdCppSet, 153),
        // property 'isProjectionImmutable'
        QtMocHelpers::PropertyData<bool>(1229, QMetaType::Bool, QMC::DefaultPropertyFlags | QMC::Constant),
        // property 'useAbbrevConstellNames'
        QtMocHelpers::PropertyData<bool>(1230, QMetaType::Bool, QMC::DefaultPropertyFlags | QMC::Writable | QMC::StdCppSet, 154),
        // property 'isUseAbbrevConstellNamesImmutable'
        QtMocHelpers::PropertyData<bool>(1231, QMetaType::Bool, QMC::DefaultPropertyFlags | QMC::Constant),
        // property 'useLatinConstellNames'
        QtMocHelpers::PropertyData<bool>(1232, QMetaType::Bool, QMC::DefaultPropertyFlags | QMC::Writable | QMC::StdCppSet, 155),
        // property 'isUseLatinConstellNamesImmutable'
        QtMocHelpers::PropertyData<bool>(1233, QMetaType::Bool, QMC::DefaultPropertyFlags | QMC::Constant),
        // property 'useLocalConstellNames'
        QtMocHelpers::PropertyData<bool>(1234, QMetaType::Bool, QMC::DefaultPropertyFlags | QMC::Writable | QMC::StdCppSet, 156),
        // property 'isUseLocalConstellNamesImmutable'
        QtMocHelpers::PropertyData<bool>(1235, QMetaType::Bool, QMC::DefaultPropertyFlags | QMC::Constant),
        // property 'useAltAz'
        QtMocHelpers::PropertyData<bool>(1236, QMetaType::Bool, QMC::DefaultPropertyFlags | QMC::Writable | QMC::StdCppSet, 157),
        // property 'isUseAltAzImmutable'
        QtMocHelpers::PropertyData<bool>(1237, QMetaType::Bool, QMC::DefaultPropertyFlags | QMC::Constant),
        // property 'useAutoLabel'
        QtMocHelpers::PropertyData<bool>(1238, QMetaType::Bool, QMC::DefaultPropertyFlags | QMC::Writable | QMC::StdCppSet, 158),
        // property 'isUseAutoLabelImmutable'
        QtMocHelpers::PropertyData<bool>(1239, QMetaType::Bool, QMC::DefaultPropertyFlags | QMC::Constant),
        // property 'useAutoTrail'
        QtMocHelpers::PropertyData<bool>(1240, QMetaType::Bool, QMC::DefaultPropertyFlags | QMC::Writable | QMC::StdCppSet, 159),
        // property 'isUseAutoTrailImmutable'
        QtMocHelpers::PropertyData<bool>(1241, QMetaType::Bool, QMC::DefaultPropertyFlags | QMC::Constant),
        // property 'useHoverLabel'
        QtMocHelpers::PropertyData<bool>(1242, QMetaType::Bool, QMC::DefaultPropertyFlags | QMC::Writable | QMC::StdCppSet, 160),
        // property 'isUseHoverLabelImmutable'
        QtMocHelpers::PropertyData<bool>(1243, QMetaType::Bool, QMC::DefaultPropertyFlags | QMC::Constant),
        // property 'useRefraction'
        QtMocHelpers::PropertyData<bool>(1244, QMetaType::Bool, QMC::DefaultPropertyFlags | QMC::Writable | QMC::StdCppSet, 161),
        // property 'isUseRefractionImmutable'
        QtMocHelpers::PropertyData<bool>(1245, QMetaType::Bool, QMC::DefaultPropertyFlags | QMC::Constant),
        // property 'useRelativistic'
        QtMocHelpers::PropertyData<bool>(1246, QMetaType::Bool, QMC::DefaultPropertyFlags | QMC::Writable | QMC::StdCppSet, 162),
        // property 'isUseRelativisticImmutable'
        QtMocHelpers::PropertyData<bool>(1247, QMetaType::Bool, QMC::DefaultPropertyFlags | QMC::Constant),
        // property 'useAntialias'
        QtMocHelpers::PropertyData<bool>(1248, QMetaType::Bool, QMC::DefaultPropertyFlags | QMC::Writable | QMC::StdCppSet, 163),
        // property 'isUseAntialiasImmutable'
        QtMocHelpers::PropertyData<bool>(1249, QMetaType::Bool, QMC::DefaultPropertyFlags | QMC::Constant),
        // property 'zoomFactor'
        QtMocHelpers::PropertyData<double>(1250, QMetaType::Double, QMC::DefaultPropertyFlags | QMC::Writable | QMC::StdCppSet, 164),
        // property 'isZoomFactorImmutable'
        QtMocHelpers::PropertyData<bool>(1251, QMetaType::Bool, QMC::DefaultPropertyFlags | QMC::Constant),
        // property 'skyRotation'
        QtMocHelpers::PropertyData<double>(1252, QMetaType::Double, QMC::DefaultPropertyFlags | QMC::Writable | QMC::StdCppSet, 165),
        // property 'isSkyRotationImmutable'
        QtMocHelpers::PropertyData<bool>(1253, QMetaType::Bool, QMC::DefaultPropertyFlags | QMC::Constant),
        // property 'mirrorSkyMap'
        QtMocHelpers::PropertyData<bool>(1254, QMetaType::Bool, QMC::DefaultPropertyFlags | QMC::Writable | QMC::StdCppSet, 166),
        // property 'isMirrorSkyMapImmutable'
        QtMocHelpers::PropertyData<bool>(1255, QMetaType::Bool, QMC::DefaultPropertyFlags | QMC::Constant),
        // property 'erectObserverCorrection'
        QtMocHelpers::PropertyData<int>(1256, QMetaType::Int, QMC::DefaultPropertyFlags | QMC::Writable | QMC::StdCppSet, 167),
        // property 'isErectObserverCorrectionImmutable'
        QtMocHelpers::PropertyData<bool>(1257, QMetaType::Bool, QMC::DefaultPropertyFlags | QMC::Constant),
        // property 'zoomScrollFactor'
        QtMocHelpers::PropertyData<double>(1258, QMetaType::Double, QMC::DefaultPropertyFlags | QMC::Writable | QMC::StdCppSet, 168),
        // property 'isZoomScrollFactorImmutable'
        QtMocHelpers::PropertyData<bool>(1259, QMetaType::Bool, QMC::DefaultPropertyFlags | QMC::Constant),
        // property 'magLimitAsteroid'
        QtMocHelpers::PropertyData<double>(1260, QMetaType::Double, QMC::DefaultPropertyFlags | QMC::Writable | QMC::StdCppSet, 169),
        // property 'isMagLimitAsteroidImmutable'
        QtMocHelpers::PropertyData<bool>(1261, QMetaType::Bool, QMC::DefaultPropertyFlags | QMC::Constant),
        // property 'magLimitAsteroidDownload'
        QtMocHelpers::PropertyData<double>(1262, QMetaType::Double, QMC::DefaultPropertyFlags | QMC::Writable | QMC::StdCppSet, 170),
        // property 'isMagLimitAsteroidDownloadImmutable'
        QtMocHelpers::PropertyData<bool>(1263, QMetaType::Bool, QMC::DefaultPropertyFlags | QMC::Constant),
        // property 'asteroidLabelDensity'
        QtMocHelpers::PropertyData<double>(1264, QMetaType::Double, QMC::DefaultPropertyFlags | QMC::Writable | QMC::StdCppSet, 171),
        // property 'isAsteroidLabelDensityImmutable'
        QtMocHelpers::PropertyData<bool>(1265, QMetaType::Bool, QMC::DefaultPropertyFlags | QMC::Constant),
        // property 'magLimitDrawDeepSky'
        QtMocHelpers::PropertyData<double>(1266, QMetaType::Double, QMC::DefaultPropertyFlags | QMC::Writable | QMC::StdCppSet, 172),
        // property 'isMagLimitDrawDeepSkyImmutable'
        QtMocHelpers::PropertyData<bool>(1267, QMetaType::Bool, QMC::DefaultPropertyFlags | QMC::Constant),
        // property 'magLimitDrawDeepSkyZoomOut'
        QtMocHelpers::PropertyData<double>(1268, QMetaType::Double, QMC::DefaultPropertyFlags | QMC::Writable | QMC::StdCppSet, 173),
        // property 'isMagLimitDrawDeepSkyZoomOutImmutable'
        QtMocHelpers::PropertyData<bool>(1269, QMetaType::Bool, QMC::DefaultPropertyFlags | QMC::Constant),
        // property 'showUnknownMagObjects'
        QtMocHelpers::PropertyData<bool>(1270, QMetaType::Bool, QMC::DefaultPropertyFlags | QMC::Writable | QMC::StdCppSet, 174),
        // property 'isShowUnknownMagObjectsImmutable'
        QtMocHelpers::PropertyData<bool>(1271, QMetaType::Bool, QMC::DefaultPropertyFlags | QMC::Constant),
        // property 'showInlineImages'
        QtMocHelpers::PropertyData<bool>(1272, QMetaType::Bool, QMC::DefaultPropertyFlags | QMC::Writable | QMC::StdCppSet, 175),
        // property 'isShowInlineImagesImmutable'
        QtMocHelpers::PropertyData<bool>(1273, QMetaType::Bool, QMC::DefaultPropertyFlags | QMC::Constant),
        // property 'starDensity'
        QtMocHelpers::PropertyData<int>(1274, QMetaType::Int, QMC::DefaultPropertyFlags | QMC::Writable | QMC::StdCppSet, 176),
        // property 'isStarDensityImmutable'
        QtMocHelpers::PropertyData<bool>(1275, QMetaType::Bool, QMC::DefaultPropertyFlags | QMC::Constant),
        // property 'magLimitHideStar'
        QtMocHelpers::PropertyData<double>(1276, QMetaType::Double, QMC::DefaultPropertyFlags | QMC::Writable | QMC::StdCppSet, 177),
        // property 'isMagLimitHideStarImmutable'
        QtMocHelpers::PropertyData<bool>(1277, QMetaType::Bool, QMC::DefaultPropertyFlags | QMC::Constant),
        // property 'starLabelDensity'
        QtMocHelpers::PropertyData<double>(1278, QMetaType::Double, QMC::DefaultPropertyFlags | QMC::Writable | QMC::StdCppSet, 178),
        // property 'isStarLabelDensityImmutable'
        QtMocHelpers::PropertyData<bool>(1279, QMetaType::Bool, QMC::DefaultPropertyFlags | QMC::Constant),
        // property 'deepSkyLabelDensity'
        QtMocHelpers::PropertyData<double>(1280, QMetaType::Double, QMC::DefaultPropertyFlags | QMC::Writable | QMC::StdCppSet, 179),
        // property 'isDeepSkyLabelDensityImmutable'
        QtMocHelpers::PropertyData<bool>(1281, QMetaType::Bool, QMC::DefaultPropertyFlags | QMC::Constant),
        // property 'deepSkyLongLabels'
        QtMocHelpers::PropertyData<bool>(1282, QMetaType::Bool, QMC::DefaultPropertyFlags | QMC::Writable | QMC::StdCppSet, 180),
        // property 'isDeepSkyLongLabelsImmutable'
        QtMocHelpers::PropertyData<bool>(1283, QMetaType::Bool, QMC::DefaultPropertyFlags | QMC::Constant),
        // property 'labelFontScaling'
        QtMocHelpers::PropertyData<int>(1284, QMetaType::Int, QMC::DefaultPropertyFlags | QMC::Writable | QMC::StdCppSet, 181),
        // property 'isLabelFontScalingImmutable'
        QtMocHelpers::PropertyData<bool>(1285, QMetaType::Bool, QMC::DefaultPropertyFlags | QMC::Constant),
        // property 'maxRadCometName'
        QtMocHelpers::PropertyData<double>(1286, QMetaType::Double, QMC::DefaultPropertyFlags | QMC::Writable | QMC::StdCppSet, 182),
        // property 'isMaxRadCometNameImmutable'
        QtMocHelpers::PropertyData<bool>(1287, QMetaType::Bool, QMC::DefaultPropertyFlags | QMC::Constant),
        // property 'useGL'
        QtMocHelpers::PropertyData<bool>(1288, QMetaType::Bool, QMC::DefaultPropertyFlags | QMC::Writable | QMC::StdCppSet, 183),
        // property 'isUseGLImmutable'
        QtMocHelpers::PropertyData<bool>(1289, QMetaType::Bool, QMC::DefaultPropertyFlags | QMC::Constant),
        // property 'runClock'
        QtMocHelpers::PropertyData<bool>(1290, QMetaType::Bool, QMC::DefaultPropertyFlags | QMC::Writable | QMC::StdCppSet, 184),
        // property 'isRunClockImmutable'
        QtMocHelpers::PropertyData<bool>(1291, QMetaType::Bool, QMC::DefaultPropertyFlags | QMC::Constant),
        // property 'imagingPlannerAcceptOpenCluster'
        QtMocHelpers::PropertyData<bool>(1292, QMetaType::Bool, QMC::DefaultPropertyFlags | QMC::Writable | QMC::StdCppSet, 185),
        // property 'isImagingPlannerAcceptOpenClusterImmutable'
        QtMocHelpers::PropertyData<bool>(1293, QMetaType::Bool, QMC::DefaultPropertyFlags | QMC::Constant),
        // property 'imagingPlannerAcceptNebula'
        QtMocHelpers::PropertyData<bool>(1294, QMetaType::Bool, QMC::DefaultPropertyFlags | QMC::Writable | QMC::StdCppSet, 186),
        // property 'isImagingPlannerAcceptNebulaImmutable'
        QtMocHelpers::PropertyData<bool>(1295, QMetaType::Bool, QMC::DefaultPropertyFlags | QMC::Constant),
        // property 'imagingPlannerAcceptGlobularCluster'
        QtMocHelpers::PropertyData<bool>(1296, QMetaType::Bool, QMC::DefaultPropertyFlags | QMC::Writable | QMC::StdCppSet, 187),
        // property 'isImagingPlannerAcceptGlobularClusterImmutable'
        QtMocHelpers::PropertyData<bool>(1297, QMetaType::Bool, QMC::DefaultPropertyFlags | QMC::Constant),
        // property 'imagingPlannerAcceptPlanetary'
        QtMocHelpers::PropertyData<bool>(1298, QMetaType::Bool, QMC::DefaultPropertyFlags | QMC::Writable | QMC::StdCppSet, 188),
        // property 'isImagingPlannerAcceptPlanetaryImmutable'
        QtMocHelpers::PropertyData<bool>(1299, QMetaType::Bool, QMC::DefaultPropertyFlags | QMC::Constant),
        // property 'imagingPlannerAcceptSupernovaRemnant'
        QtMocHelpers::PropertyData<bool>(1300, QMetaType::Bool, QMC::DefaultPropertyFlags | QMC::Writable | QMC::StdCppSet, 189),
        // property 'isImagingPlannerAcceptSupernovaRemnantImmutable'
        QtMocHelpers::PropertyData<bool>(1301, QMetaType::Bool, QMC::DefaultPropertyFlags | QMC::Constant),
        // property 'imagingPlannerAcceptGalaxy'
        QtMocHelpers::PropertyData<bool>(1302, QMetaType::Bool, QMC::DefaultPropertyFlags | QMC::Writable | QMC::StdCppSet, 190),
        // property 'isImagingPlannerAcceptGalaxyImmutable'
        QtMocHelpers::PropertyData<bool>(1303, QMetaType::Bool, QMC::DefaultPropertyFlags | QMC::Constant),
        // property 'imagingPlannerAcceptGalaxyCluster'
        QtMocHelpers::PropertyData<bool>(1304, QMetaType::Bool, QMC::DefaultPropertyFlags | QMC::Writable | QMC::StdCppSet, 191),
        // property 'isImagingPlannerAcceptGalaxyClusterImmutable'
        QtMocHelpers::PropertyData<bool>(1305, QMetaType::Bool, QMC::DefaultPropertyFlags | QMC::Constant),
        // property 'imagingPlannerAcceptDarkNebula'
        QtMocHelpers::PropertyData<bool>(1306, QMetaType::Bool, QMC::DefaultPropertyFlags | QMC::Writable | QMC::StdCppSet, 192),
        // property 'isImagingPlannerAcceptDarkNebulaImmutable'
        QtMocHelpers::PropertyData<bool>(1307, QMetaType::Bool, QMC::DefaultPropertyFlags | QMC::Constant),
        // property 'imagingPlannerAcceptOther'
        QtMocHelpers::PropertyData<bool>(1308, QMetaType::Bool, QMC::DefaultPropertyFlags | QMC::Writable | QMC::StdCppSet, 193),
        // property 'isImagingPlannerAcceptOtherImmutable'
        QtMocHelpers::PropertyData<bool>(1309, QMetaType::Bool, QMC::DefaultPropertyFlags | QMC::Constant),
        // property 'astrobinAward'
        QtMocHelpers::PropertyData<bool>(1310, QMetaType::Bool, QMC::DefaultPropertyFlags | QMC::Writable | QMC::StdCppSet, 194),
        // property 'isAstrobinAwardImmutable'
        QtMocHelpers::PropertyData<bool>(1311, QMetaType::Bool, QMC::DefaultPropertyFlags | QMC::Constant),
        // property 'astrobinMinRadius'
        QtMocHelpers::PropertyData<double>(1312, QMetaType::Double, QMC::DefaultPropertyFlags | QMC::Writable | QMC::StdCppSet, 195),
        // property 'isAstrobinMinRadiusImmutable'
        QtMocHelpers::PropertyData<bool>(1313, QMetaType::Bool, QMC::DefaultPropertyFlags | QMC::Constant),
        // property 'astrobinMaxRadius'
        QtMocHelpers::PropertyData<double>(1314, QMetaType::Double, QMC::DefaultPropertyFlags | QMC::Writable | QMC::StdCppSet, 196),
        // property 'isAstrobinMaxRadiusImmutable'
        QtMocHelpers::PropertyData<bool>(1315, QMetaType::Bool, QMC::DefaultPropertyFlags | QMC::Constant),
        // property 'imagingPlannerUseArtificialHorizon'
        QtMocHelpers::PropertyData<bool>(1316, QMetaType::Bool, QMC::DefaultPropertyFlags | QMC::Writable | QMC::StdCppSet, 197),
        // property 'isImagingPlannerUseArtificialHorizonImmutable'
        QtMocHelpers::PropertyData<bool>(1317, QMetaType::Bool, QMC::DefaultPropertyFlags | QMC::Constant),
        // property 'imagingPlannerMinHours'
        QtMocHelpers::PropertyData<double>(1318, QMetaType::Double, QMC::DefaultPropertyFlags | QMC::Writable | QMC::StdCppSet, 198),
        // property 'isImagingPlannerMinHoursImmutable'
        QtMocHelpers::PropertyData<bool>(1319, QMetaType::Bool, QMC::DefaultPropertyFlags | QMC::Constant),
        // property 'imagingPlannerMinAltitude'
        QtMocHelpers::PropertyData<double>(1320, QMetaType::Double, QMC::DefaultPropertyFlags | QMC::Writable | QMC::StdCppSet, 199),
        // property 'isImagingPlannerMinAltitudeImmutable'
        QtMocHelpers::PropertyData<bool>(1321, QMetaType::Bool, QMC::DefaultPropertyFlags | QMC::Constant),
        // property 'imagingPlannerMinMoonSeparation'
        QtMocHelpers::PropertyData<double>(1322, QMetaType::Double, QMC::DefaultPropertyFlags | QMC::Writable | QMC::StdCppSet, 200),
        // property 'isImagingPlannerMinMoonSeparationImmutable'
        QtMocHelpers::PropertyData<bool>(1323, QMetaType::Bool, QMC::DefaultPropertyFlags | QMC::Constant),
        // property 'imagingPlannerMaxMoonAltitude'
        QtMocHelpers::PropertyData<double>(1324, QMetaType::Double, QMC::DefaultPropertyFlags | QMC::Writable | QMC::StdCppSet, 201),
        // property 'isImagingPlannerMaxMoonAltitudeImmutable'
        QtMocHelpers::PropertyData<bool>(1325, QMetaType::Bool, QMC::DefaultPropertyFlags | QMC::Constant),
        // property 'imagingPlannerShowPicked'
        QtMocHelpers::PropertyData<bool>(1326, QMetaType::Bool, QMC::DefaultPropertyFlags | QMC::Writable | QMC::StdCppSet, 202),
        // property 'isImagingPlannerShowPickedImmutable'
        QtMocHelpers::PropertyData<bool>(1327, QMetaType::Bool, QMC::DefaultPropertyFlags | QMC::Constant),
        // property 'imagingPlannerShowNotPicked'
        QtMocHelpers::PropertyData<bool>(1328, QMetaType::Bool, QMC::DefaultPropertyFlags | QMC::Writable | QMC::StdCppSet, 203),
        // property 'isImagingPlannerShowNotPickedImmutable'
        QtMocHelpers::PropertyData<bool>(1329, QMetaType::Bool, QMC::DefaultPropertyFlags | QMC::Constant),
        // property 'imagingPlannerDontCarePicked'
        QtMocHelpers::PropertyData<bool>(1330, QMetaType::Bool, QMC::DefaultPropertyFlags | QMC::Writable | QMC::StdCppSet, 204),
        // property 'isImagingPlannerDontCarePickedImmutable'
        QtMocHelpers::PropertyData<bool>(1331, QMetaType::Bool, QMC::DefaultPropertyFlags | QMC::Constant),
        // property 'imagingPlannerShowKeyword'
        QtMocHelpers::PropertyData<bool>(1332, QMetaType::Bool, QMC::DefaultPropertyFlags | QMC::Writable | QMC::StdCppSet, 205),
        // property 'isImagingPlannerShowKeywordImmutable'
        QtMocHelpers::PropertyData<bool>(1333, QMetaType::Bool, QMC::DefaultPropertyFlags | QMC::Constant),
        // property 'imagingPlannerShowNotKeyword'
        QtMocHelpers::PropertyData<bool>(1334, QMetaType::Bool, QMC::DefaultPropertyFlags | QMC::Writable | QMC::StdCppSet, 206),
        // property 'isImagingPlannerShowNotKeywordImmutable'
        QtMocHelpers::PropertyData<bool>(1335, QMetaType::Bool, QMC::DefaultPropertyFlags | QMC::Constant),
        // property 'imagingPlannerDontCareKeyword'
        QtMocHelpers::PropertyData<bool>(1336, QMetaType::Bool, QMC::DefaultPropertyFlags | QMC::Writable | QMC::StdCppSet, 207),
        // property 'isImagingPlannerDontCareKeywordImmutable'
        QtMocHelpers::PropertyData<bool>(1337, QMetaType::Bool, QMC::DefaultPropertyFlags | QMC::Constant),
        // property 'imagingPlannerKeyword'
        QtMocHelpers::PropertyData<QString>(1338, QMetaType::QString, QMC::DefaultPropertyFlags | QMC::Writable | QMC::StdCppSet, 208),
        // property 'isImagingPlannerKeywordImmutable'
        QtMocHelpers::PropertyData<bool>(1339, QMetaType::Bool, QMC::DefaultPropertyFlags | QMC::Constant),
        // property 'imagingPlannerShowImaged'
        QtMocHelpers::PropertyData<bool>(1340, QMetaType::Bool, QMC::DefaultPropertyFlags | QMC::Writable | QMC::StdCppSet, 209),
        // property 'isImagingPlannerShowImagedImmutable'
        QtMocHelpers::PropertyData<bool>(1341, QMetaType::Bool, QMC::DefaultPropertyFlags | QMC::Constant),
        // property 'imagingPlannerShowNotImaged'
        QtMocHelpers::PropertyData<bool>(1342, QMetaType::Bool, QMC::DefaultPropertyFlags | QMC::Writable | QMC::StdCppSet, 210),
        // property 'isImagingPlannerShowNotImagedImmutable'
        QtMocHelpers::PropertyData<bool>(1343, QMetaType::Bool, QMC::DefaultPropertyFlags | QMC::Constant),
        // property 'imagingPlannerDontCareImaged'
        QtMocHelpers::PropertyData<bool>(1344, QMetaType::Bool, QMC::DefaultPropertyFlags | QMC::Writable | QMC::StdCppSet, 211),
        // property 'isImagingPlannerDontCareImagedImmutable'
        QtMocHelpers::PropertyData<bool>(1345, QMetaType::Bool, QMC::DefaultPropertyFlags | QMC::Constant),
        // property 'imagingPlannerShowAdded'
        QtMocHelpers::PropertyData<bool>(1346, QMetaType::Bool, QMC::DefaultPropertyFlags | QMC::Writable | QMC::StdCppSet, 212),
        // property 'isImagingPlannerShowAddedImmutable'
        QtMocHelpers::PropertyData<bool>(1347, QMetaType::Bool, QMC::DefaultPropertyFlags | QMC::Constant),
        // property 'imagingPlannerShowNotAdded'
        QtMocHelpers::PropertyData<bool>(1348, QMetaType::Bool, QMC::DefaultPropertyFlags | QMC::Writable | QMC::StdCppSet, 213),
        // property 'isImagingPlannerShowNotAddedImmutable'
        QtMocHelpers::PropertyData<bool>(1349, QMetaType::Bool, QMC::DefaultPropertyFlags | QMC::Constant),
        // property 'imagingPlannerDontCareAdded'
        QtMocHelpers::PropertyData<bool>(1350, QMetaType::Bool, QMC::DefaultPropertyFlags | QMC::Writable | QMC::StdCppSet, 214),
        // property 'isImagingPlannerDontCareAddedImmutable'
        QtMocHelpers::PropertyData<bool>(1351, QMetaType::Bool, QMC::DefaultPropertyFlags | QMC::Constant),
        // property 'imagingPlannerShowIgnored'
        QtMocHelpers::PropertyData<bool>(1352, QMetaType::Bool, QMC::DefaultPropertyFlags | QMC::Writable | QMC::StdCppSet, 215),
        // property 'isImagingPlannerShowIgnoredImmutable'
        QtMocHelpers::PropertyData<bool>(1353, QMetaType::Bool, QMC::DefaultPropertyFlags | QMC::Constant),
        // property 'imagingPlannerShowNotIgnored'
        QtMocHelpers::PropertyData<bool>(1354, QMetaType::Bool, QMC::DefaultPropertyFlags | QMC::Writable | QMC::StdCppSet, 216),
        // property 'isImagingPlannerShowNotIgnoredImmutable'
        QtMocHelpers::PropertyData<bool>(1355, QMetaType::Bool, QMC::DefaultPropertyFlags | QMC::Constant),
        // property 'imagingPlannerDontCareIgnored'
        QtMocHelpers::PropertyData<bool>(1356, QMetaType::Bool, QMC::DefaultPropertyFlags | QMC::Writable | QMC::StdCppSet, 217),
        // property 'isImagingPlannerDontCareIgnoredImmutable'
        QtMocHelpers::PropertyData<bool>(1357, QMetaType::Bool, QMC::DefaultPropertyFlags | QMC::Constant),
        // property 'imagingPlannerHideAstrobinDetails'
        QtMocHelpers::PropertyData<bool>(1358, QMetaType::Bool, QMC::DefaultPropertyFlags | QMC::Writable | QMC::StdCppSet, 218),
        // property 'isImagingPlannerHideAstrobinDetailsImmutable'
        QtMocHelpers::PropertyData<bool>(1359, QMetaType::Bool, QMC::DefaultPropertyFlags | QMC::Constant),
        // property 'imagingPlannerHideFilters'
        QtMocHelpers::PropertyData<bool>(1360, QMetaType::Bool, QMC::DefaultPropertyFlags | QMC::Writable | QMC::StdCppSet, 219),
        // property 'isImagingPlannerHideFiltersImmutable'
        QtMocHelpers::PropertyData<bool>(1361, QMetaType::Bool, QMC::DefaultPropertyFlags | QMC::Constant),
        // property 'imagingPlannerHideImage'
        QtMocHelpers::PropertyData<bool>(1362, QMetaType::Bool, QMC::DefaultPropertyFlags | QMC::Writable | QMC::StdCppSet, 220),
        // property 'isImagingPlannerHideImageImmutable'
        QtMocHelpers::PropertyData<bool>(1363, QMetaType::Bool, QMC::DefaultPropertyFlags | QMC::Constant),
        // property 'imagingPlannerHideAltitudeGraph'
        QtMocHelpers::PropertyData<bool>(1364, QMetaType::Bool, QMC::DefaultPropertyFlags | QMC::Writable | QMC::StdCppSet, 221),
        // property 'isImagingPlannerHideAltitudeGraphImmutable'
        QtMocHelpers::PropertyData<bool>(1365, QMetaType::Bool, QMC::DefaultPropertyFlags | QMC::Constant),
        // property 'imagingPlannerCatalogPath'
        QtMocHelpers::PropertyData<QString>(1366, QMetaType::QString, QMC::DefaultPropertyFlags | QMC::Writable | QMC::StdCppSet, 222),
        // property 'isImagingPlannerCatalogPathImmutable'
        QtMocHelpers::PropertyData<bool>(1367, QMetaType::Bool, QMC::DefaultPropertyFlags | QMC::Constant),
        // property 'imagingPlannerCenterOnSkyMap'
        QtMocHelpers::PropertyData<bool>(1368, QMetaType::Bool, QMC::DefaultPropertyFlags | QMC::Writable | QMC::StdCppSet, 223),
        // property 'isImagingPlannerCenterOnSkyMapImmutable'
        QtMocHelpers::PropertyData<bool>(1369, QMetaType::Bool, QMC::DefaultPropertyFlags | QMC::Constant),
        // property 'imagingPlannerIndependentWindow'
        QtMocHelpers::PropertyData<bool>(1370, QMetaType::Bool, QMC::DefaultPropertyFlags | QMC::Writable | QMC::StdCppSet, 224),
        // property 'isImagingPlannerIndependentWindowImmutable'
        QtMocHelpers::PropertyData<bool>(1371, QMetaType::Bool, QMC::DefaultPropertyFlags | QMC::Constant),
        // property 'imagingPlannerStartSolvingImmediately'
        QtMocHelpers::PropertyData<bool>(1372, QMetaType::Bool, QMC::DefaultPropertyFlags | QMC::Writable | QMC::StdCppSet, 225),
        // property 'isImagingPlannerStartSolvingImmediatelyImmutable'
        QtMocHelpers::PropertyData<bool>(1373, QMetaType::Bool, QMC::DefaultPropertyFlags | QMC::Constant),
        // property 'obsListSymbol'
        QtMocHelpers::PropertyData<bool>(1374, QMetaType::Bool, QMC::DefaultPropertyFlags | QMC::Writable | QMC::StdCppSet, 226),
        // property 'isObsListSymbolImmutable'
        QtMocHelpers::PropertyData<bool>(1375, QMetaType::Bool, QMC::DefaultPropertyFlags | QMC::Constant),
        // property 'obsListText'
        QtMocHelpers::PropertyData<bool>(1376, QMetaType::Bool, QMC::DefaultPropertyFlags | QMC::Writable | QMC::StdCppSet, 227),
        // property 'isObsListTextImmutable'
        QtMocHelpers::PropertyData<bool>(1377, QMetaType::Bool, QMC::DefaultPropertyFlags | QMC::Constant),
        // property 'obsListPreferDSS'
        QtMocHelpers::PropertyData<bool>(1378, QMetaType::Bool, QMC::DefaultPropertyFlags | QMC::Writable | QMC::StdCppSet, 228),
        // property 'isObsListPreferDSSImmutable'
        QtMocHelpers::PropertyData<bool>(1379, QMetaType::Bool, QMC::DefaultPropertyFlags | QMC::Constant),
        // property 'obsListPreferSDSS'
        QtMocHelpers::PropertyData<bool>(1380, QMetaType::Bool, QMC::DefaultPropertyFlags | QMC::Writable | QMC::StdCppSet, 229),
        // property 'isObsListPreferSDSSImmutable'
        QtMocHelpers::PropertyData<bool>(1381, QMetaType::Bool, QMC::DefaultPropertyFlags | QMC::Constant),
        // property 'obsListDemoteHole'
        QtMocHelpers::PropertyData<bool>(1382, QMetaType::Bool, QMC::DefaultPropertyFlags | QMC::Writable | QMC::StdCppSet, 230),
        // property 'isObsListDemoteHoleImmutable'
        QtMocHelpers::PropertyData<bool>(1383, QMetaType::Bool, QMC::DefaultPropertyFlags | QMC::Constant),
        // property 'obsListHoleSize'
        QtMocHelpers::PropertyData<double>(1384, QMetaType::Double, QMC::DefaultPropertyFlags | QMC::Writable | QMC::StdCppSet, 231),
        // property 'isObsListHoleSizeImmutable'
        QtMocHelpers::PropertyData<bool>(1385, QMetaType::Bool, QMC::DefaultPropertyFlags | QMC::Constant),
        // property 'obsListCoverage'
        QtMocHelpers::PropertyData<double>(1386, QMetaType::Double, QMC::DefaultPropertyFlags | QMC::Writable | QMC::StdCppSet, 232),
        // property 'isObsListCoverageImmutable'
        QtMocHelpers::PropertyData<bool>(1387, QMetaType::Bool, QMC::DefaultPropertyFlags | QMC::Constant),
        // property 'colorSchemeFile'
        QtMocHelpers::PropertyData<QString>(1388, QMetaType::QString, QMC::DefaultPropertyFlags | QMC::Writable | QMC::StdCppSet, 233),
        // property 'isColorSchemeFileImmutable'
        QtMocHelpers::PropertyData<bool>(1389, QMetaType::Bool, QMC::DefaultPropertyFlags | QMC::Constant),
        // property 'starColorMode'
        QtMocHelpers::PropertyData<uint>(1390, QMetaType::UInt, QMC::DefaultPropertyFlags | QMC::Writable | QMC::StdCppSet, 234),
        // property 'isStarColorModeImmutable'
        QtMocHelpers::PropertyData<bool>(1391, QMetaType::Bool, QMC::DefaultPropertyFlags | QMC::Constant),
        // property 'starColorIntensity'
        QtMocHelpers::PropertyData<uint>(1392, QMetaType::UInt, QMC::DefaultPropertyFlags | QMC::Writable | QMC::StdCppSet, 235),
        // property 'isStarColorIntensityImmutable'
        QtMocHelpers::PropertyData<bool>(1393, QMetaType::Bool, QMC::DefaultPropertyFlags | QMC::Constant),
        // property 'domeSlitInverted'
        QtMocHelpers::PropertyData<bool>(1394, QMetaType::Bool, QMC::DefaultPropertyFlags | QMC::Writable | QMC::StdCppSet, 236),
        // property 'isDomeSlitInvertedImmutable'
        QtMocHelpers::PropertyData<bool>(1395, QMetaType::Bool, QMC::DefaultPropertyFlags | QMC::Constant),
        // property 'angularRulerColor'
        QtMocHelpers::PropertyData<QString>(1396, QMetaType::QString, QMC::DefaultPropertyFlags | QMC::Writable | QMC::StdCppSet, 237),
        // property 'isAngularRulerColorImmutable'
        QtMocHelpers::PropertyData<bool>(1397, QMetaType::Bool, QMC::DefaultPropertyFlags | QMC::Constant),
        // property 'boxBGColor'
        QtMocHelpers::PropertyData<QString>(1398, QMetaType::QString, QMC::DefaultPropertyFlags | QMC::Writable | QMC::StdCppSet, 238),
        // property 'isBoxBGColorImmutable'
        QtMocHelpers::PropertyData<bool>(1399, QMetaType::Bool, QMC::DefaultPropertyFlags | QMC::Constant),
        // property 'boxGrabColor'
        QtMocHelpers::PropertyData<QString>(1400, QMetaType::QString, QMC::DefaultPropertyFlags | QMC::Writable | QMC::StdCppSet, 239),
        // property 'isBoxGrabColorImmutable'
        QtMocHelpers::PropertyData<bool>(1401, QMetaType::Bool, QMC::DefaultPropertyFlags | QMC::Constant),
        // property 'boxTextColor'
        QtMocHelpers::PropertyData<QString>(1402, QMetaType::QString, QMC::DefaultPropertyFlags | QMC::Writable | QMC::StdCppSet, 240),
        // property 'isBoxTextColorImmutable'
        QtMocHelpers::PropertyData<bool>(1403, QMetaType::Bool, QMC::DefaultPropertyFlags | QMC::Constant),
        // property 'cBoundColor'
        QtMocHelpers::PropertyData<QString>(1404, QMetaType::QString, QMC::DefaultPropertyFlags | QMC::Writable | QMC::StdCppSet, 241),
        // property 'isCBoundColorImmutable'
        QtMocHelpers::PropertyData<bool>(1405, QMetaType::Bool, QMC::DefaultPropertyFlags | QMC::Constant),
        // property 'cBoundHighColor'
        QtMocHelpers::PropertyData<QString>(1406, QMetaType::QString, QMC::DefaultPropertyFlags | QMC::Writable | QMC::StdCppSet, 242),
        // property 'isCBoundHighColorImmutable'
        QtMocHelpers::PropertyData<bool>(1407, QMetaType::Bool, QMC::DefaultPropertyFlags | QMC::Constant),
        // property 'cLineColor'
        QtMocHelpers::PropertyData<QString>(1408, QMetaType::QString, QMC::DefaultPropertyFlags | QMC::Writable | QMC::StdCppSet, 243),
        // property 'isCLineColorImmutable'
        QtMocHelpers::PropertyData<bool>(1409, QMetaType::Bool, QMC::DefaultPropertyFlags | QMC::Constant),
        // property 'cNameColor'
        QtMocHelpers::PropertyData<QString>(1410, QMetaType::QString, QMC::DefaultPropertyFlags | QMC::Writable | QMC::StdCppSet, 244),
        // property 'isCNameColorImmutable'
        QtMocHelpers::PropertyData<bool>(1411, QMetaType::Bool, QMC::DefaultPropertyFlags | QMC::Constant),
        // property 'compassColor'
        QtMocHelpers::PropertyData<QString>(1412, QMetaType::QString, QMC::DefaultPropertyFlags | QMC::Writable | QMC::StdCppSet, 245),
        // property 'isCompassColorImmutable'
        QtMocHelpers::PropertyData<bool>(1413, QMetaType::Bool, QMC::DefaultPropertyFlags | QMC::Constant),
        // property 'eclipticColor'
        QtMocHelpers::PropertyData<QString>(1414, QMetaType::QString, QMC::DefaultPropertyFlags | QMC::Writable | QMC::StdCppSet, 246),
        // property 'isEclipticColorImmutable'
        QtMocHelpers::PropertyData<bool>(1415, QMetaType::Bool, QMC::DefaultPropertyFlags | QMC::Constant),
        // property 'equatorColor'
        QtMocHelpers::PropertyData<QString>(1416, QMetaType::QString, QMC::DefaultPropertyFlags | QMC::Writable | QMC::StdCppSet, 247),
        // property 'isEquatorColorImmutable'
        QtMocHelpers::PropertyData<bool>(1417, QMetaType::Bool, QMC::DefaultPropertyFlags | QMC::Constant),
        // property 'equatorialGridColor'
        QtMocHelpers::PropertyData<QString>(1418, QMetaType::QString, QMC::DefaultPropertyFlags | QMC::Writable | QMC::StdCppSet, 248),
        // property 'isEquatorialGridColorImmutable'
        QtMocHelpers::PropertyData<bool>(1419, QMetaType::Bool, QMC::DefaultPropertyFlags | QMC::Constant),
        // property 'horizontalGridColor'
        QtMocHelpers::PropertyData<QString>(1420, QMetaType::QString, QMC::DefaultPropertyFlags | QMC::Writable | QMC::StdCppSet, 249),
        // property 'isHorizontalGridColorImmutable'
        QtMocHelpers::PropertyData<bool>(1421, QMetaType::Bool, QMC::DefaultPropertyFlags | QMC::Constant),
        // property 'specialObjectColor'
        QtMocHelpers::PropertyData<QString>(1422, QMetaType::QString, QMC::DefaultPropertyFlags | QMC::Writable | QMC::StdCppSet, 250),
        // property 'isSpecialObjectColorImmutable'
        QtMocHelpers::PropertyData<bool>(1423, QMetaType::Bool, QMC::DefaultPropertyFlags | QMC::Constant),
        // property 'horizonColor'
        QtMocHelpers::PropertyData<QString>(1424, QMetaType::QString, QMC::DefaultPropertyFlags | QMC::Writable | QMC::StdCppSet, 251),
        // property 'isHorizonColorImmutable'
        QtMocHelpers::PropertyData<bool>(1425, QMetaType::Bool, QMC::DefaultPropertyFlags | QMC::Constant),
        // property 'localMeridianColor'
        QtMocHelpers::PropertyData<QString>(1426, QMetaType::QString, QMC::DefaultPropertyFlags | QMC::Writable | QMC::StdCppSet, 252),
        // property 'isLocalMeridianColorImmutable'
        QtMocHelpers::PropertyData<bool>(1427, QMetaType::Bool, QMC::DefaultPropertyFlags | QMC::Constant),
        // property 'milkyWayWColor'
        QtMocHelpers::PropertyData<QString>(1428, QMetaType::QString, QMC::DefaultPropertyFlags | QMC::Writable | QMC::StdCppSet, 253),
        // property 'isMilkyWayWColorImmutable'
        QtMocHelpers::PropertyData<bool>(1429, QMetaType::Bool, QMC::DefaultPropertyFlags | QMC::Constant),
        // property 'starNameColor'
        QtMocHelpers::PropertyData<QString>(1430, QMetaType::QString, QMC::DefaultPropertyFlags | QMC::Writable | QMC::StdCppSet, 254),
        // property 'isStarNameColorImmutable'
        QtMocHelpers::PropertyData<bool>(1431, QMetaType::Bool, QMC::DefaultPropertyFlags | QMC::Constant),
        // property 'deepSkyNameColor'
        QtMocHelpers::PropertyData<QString>(1432, QMetaType::QString, QMC::DefaultPropertyFlags | QMC::Writable | QMC::StdCppSet, 255),
        // property 'isDeepSkyNameColorImmutable'
        QtMocHelpers::PropertyData<bool>(1433, QMetaType::Bool, QMC::DefaultPropertyFlags | QMC::Constant),
        // property 'planetNameColor'
        QtMocHelpers::PropertyData<QString>(1434, QMetaType::QString, QMC::DefaultPropertyFlags | QMC::Writable | QMC::StdCppSet, 256),
        // property 'isPlanetNameColorImmutable'
        QtMocHelpers::PropertyData<bool>(1435, QMetaType::Bool, QMC::DefaultPropertyFlags | QMC::Constant),
        // property 'planetTrailColor'
        QtMocHelpers::PropertyData<QString>(1436, QMetaType::QString, QMC::DefaultPropertyFlags | QMC::Writable | QMC::StdCppSet, 257),
        // property 'isPlanetTrailColorImmutable'
        QtMocHelpers::PropertyData<bool>(1437, QMetaType::Bool, QMC::DefaultPropertyFlags | QMC::Constant),
        // property 'skyColor'
        QtMocHelpers::PropertyData<QString>(1438, QMetaType::QString, QMC::DefaultPropertyFlags | QMC::Writable | QMC::StdCppSet, 258),
        // property 'isSkyColorImmutable'
        QtMocHelpers::PropertyData<bool>(1439, QMetaType::Bool, QMC::DefaultPropertyFlags | QMC::Constant),
        // property 'skyColorDaytime'
        QtMocHelpers::PropertyData<QString>(1440, QMetaType::QString, QMC::DefaultPropertyFlags | QMC::Writable | QMC::StdCppSet, 259),
        // property 'isSkyColorDaytimeImmutable'
        QtMocHelpers::PropertyData<bool>(1441, QMetaType::Bool, QMC::DefaultPropertyFlags | QMC::Constant),
        // property 'artificialHorizonColor'
        QtMocHelpers::PropertyData<QString>(1442, QMetaType::QString, QMC::DefaultPropertyFlags | QMC::Writable | QMC::StdCppSet, 260),
        // property 'isArtificialHorizonColorImmutable'
        QtMocHelpers::PropertyData<bool>(1443, QMetaType::Bool, QMC::DefaultPropertyFlags | QMC::Constant),
        // property 'telescopeTargetColor'
        QtMocHelpers::PropertyData<QString>(1444, QMetaType::QString, QMC::DefaultPropertyFlags | QMC::Writable | QMC::StdCppSet, 261),
        // property 'isTelescopeTargetColorImmutable'
        QtMocHelpers::PropertyData<bool>(1445, QMetaType::Bool, QMC::DefaultPropertyFlags | QMC::Constant),
        // property 'visibleSatColor'
        QtMocHelpers::PropertyData<QString>(1446, QMetaType::QString, QMC::DefaultPropertyFlags | QMC::Writable | QMC::StdCppSet, 262),
        // property 'isVisibleSatColorImmutable'
        QtMocHelpers::PropertyData<bool>(1447, QMetaType::Bool, QMC::DefaultPropertyFlags | QMC::Constant),
        // property 'satColor'
        QtMocHelpers::PropertyData<QString>(1448, QMetaType::QString, QMC::DefaultPropertyFlags | QMC::Writable | QMC::StdCppSet, 263),
        // property 'isSatColorImmutable'
        QtMocHelpers::PropertyData<bool>(1449, QMetaType::Bool, QMC::DefaultPropertyFlags | QMC::Constant),
        // property 'satLabelColor'
        QtMocHelpers::PropertyData<QString>(1450, QMetaType::QString, QMC::DefaultPropertyFlags | QMC::Writable | QMC::StdCppSet, 264),
        // property 'isSatLabelColorImmutable'
        QtMocHelpers::PropertyData<bool>(1451, QMetaType::Bool, QMC::DefaultPropertyFlags | QMC::Constant),
        // property 'supernovaColor'
        QtMocHelpers::PropertyData<QString>(1452, QMetaType::QString, QMC::DefaultPropertyFlags | QMC::Writable | QMC::StdCppSet, 265),
        // property 'isSupernovaColorImmutable'
        QtMocHelpers::PropertyData<bool>(1453, QMetaType::Bool, QMC::DefaultPropertyFlags | QMC::Constant),
        // property 'asteroidColor'
        QtMocHelpers::PropertyData<QString>(1454, QMetaType::QString, QMC::DefaultPropertyFlags | QMC::Writable | QMC::StdCppSet, 266),
        // property 'isAsteroidColorImmutable'
        QtMocHelpers::PropertyData<bool>(1455, QMetaType::Bool, QMC::DefaultPropertyFlags | QMC::Constant),
        // property 'userLabelColor'
        QtMocHelpers::PropertyData<QString>(1456, QMetaType::QString, QMC::DefaultPropertyFlags | QMC::Writable | QMC::StdCppSet, 267),
        // property 'isUserLabelColorImmutable'
        QtMocHelpers::PropertyData<bool>(1457, QMetaType::Bool, QMC::DefaultPropertyFlags | QMC::Constant),
        // property 'rAGuideColor'
        QtMocHelpers::PropertyData<QString>(1458, QMetaType::QString, QMC::DefaultPropertyFlags | QMC::Writable | QMC::StdCppSet, 268),
        // property 'isRAGuideColorImmutable'
        QtMocHelpers::PropertyData<bool>(1459, QMetaType::Bool, QMC::DefaultPropertyFlags | QMC::Constant),
        // property 'dEGuideColor'
        QtMocHelpers::PropertyData<QString>(1460, QMetaType::QString, QMC::DefaultPropertyFlags | QMC::Writable | QMC::StdCppSet, 269),
        // property 'isDEGuideColorImmutable'
        QtMocHelpers::PropertyData<bool>(1461, QMetaType::Bool, QMC::DefaultPropertyFlags | QMC::Constant),
        // property 'solverFOVColor'
        QtMocHelpers::PropertyData<QString>(1462, QMetaType::QString, QMC::DefaultPropertyFlags | QMC::Writable | QMC::StdCppSet, 270),
        // property 'isSolverFOVColorImmutable'
        QtMocHelpers::PropertyData<bool>(1463, QMetaType::Bool, QMC::DefaultPropertyFlags | QMC::Constant),
        // property 'xplanetIsInternal'
        QtMocHelpers::PropertyData<bool>(1464, QMetaType::Bool, QMC::DefaultPropertyFlags | QMC::Writable | QMC::StdCppSet, 271),
        // property 'isXplanetIsInternalImmutable'
        QtMocHelpers::PropertyData<bool>(1465, QMetaType::Bool, QMC::DefaultPropertyFlags | QMC::Constant),
        // property 'xplanetPath'
        QtMocHelpers::PropertyData<QString>(1466, QMetaType::QString, QMC::DefaultPropertyFlags | QMC::Writable | QMC::StdCppSet, 272),
        // property 'isXplanetPathImmutable'
        QtMocHelpers::PropertyData<bool>(1467, QMetaType::Bool, QMC::DefaultPropertyFlags | QMC::Constant),
        // property 'xplanetUseFIFO'
        QtMocHelpers::PropertyData<bool>(1468, QMetaType::Bool, QMC::DefaultPropertyFlags | QMC::Writable | QMC::StdCppSet, 273),
        // property 'isXplanetUseFIFOImmutable'
        QtMocHelpers::PropertyData<bool>(1469, QMetaType::Bool, QMC::DefaultPropertyFlags | QMC::Constant),
        // property 'xplanetTimeout'
        QtMocHelpers::PropertyData<uint>(1470, QMetaType::UInt, QMC::DefaultPropertyFlags | QMC::Writable | QMC::StdCppSet, 274),
        // property 'isXplanetTimeoutImmutable'
        QtMocHelpers::PropertyData<bool>(1471, QMetaType::Bool, QMC::DefaultPropertyFlags | QMC::Constant),
        // property 'xplanetAnimationDelay'
        QtMocHelpers::PropertyData<uint>(1472, QMetaType::UInt, QMC::DefaultPropertyFlags | QMC::Writable | QMC::StdCppSet, 275),
        // property 'isXplanetAnimationDelayImmutable'
        QtMocHelpers::PropertyData<bool>(1473, QMetaType::Bool, QMC::DefaultPropertyFlags | QMC::Constant),
        // property 'xplanetWidth'
        QtMocHelpers::PropertyData<uint>(1474, QMetaType::UInt, QMC::DefaultPropertyFlags | QMC::Writable | QMC::StdCppSet, 276),
        // property 'isXplanetWidthImmutable'
        QtMocHelpers::PropertyData<bool>(1475, QMetaType::Bool, QMC::DefaultPropertyFlags | QMC::Constant),
        // property 'xplanetHeight'
        QtMocHelpers::PropertyData<uint>(1476, QMetaType::UInt, QMC::DefaultPropertyFlags | QMC::Writable | QMC::StdCppSet, 277),
        // property 'isXplanetHeightImmutable'
        QtMocHelpers::PropertyData<bool>(1477, QMetaType::Bool, QMC::DefaultPropertyFlags | QMC::Constant),
        // property 'xplanetLabel'
        QtMocHelpers::PropertyData<bool>(1478, QMetaType::Bool, QMC::DefaultPropertyFlags | QMC::Writable | QMC::StdCppSet, 278),
        // property 'isXplanetLabelImmutable'
        QtMocHelpers::PropertyData<bool>(1479, QMetaType::Bool, QMC::DefaultPropertyFlags | QMC::Constant),
        // property 'xplanetLabelLocalTime'
        QtMocHelpers::PropertyData<bool>(1480, QMetaType::Bool, QMC::DefaultPropertyFlags | QMC::Writable | QMC::StdCppSet, 279),
        // property 'isXplanetLabelLocalTimeImmutable'
        QtMocHelpers::PropertyData<bool>(1481, QMetaType::Bool, QMC::DefaultPropertyFlags | QMC::Constant),
        // property 'xplanetLabelGMT'
        QtMocHelpers::PropertyData<bool>(1482, QMetaType::Bool, QMC::DefaultPropertyFlags | QMC::Writable | QMC::StdCppSet, 280),
        // property 'isXplanetLabelGMTImmutable'
        QtMocHelpers::PropertyData<bool>(1483, QMetaType::Bool, QMC::DefaultPropertyFlags | QMC::Constant),
        // property 'xplanetLabelString'
        QtMocHelpers::PropertyData<QString>(1484, QMetaType::QString, QMC::DefaultPropertyFlags | QMC::Writable | QMC::StdCppSet, 281),
        // property 'isXplanetLabelStringImmutable'
        QtMocHelpers::PropertyData<bool>(1485, QMetaType::Bool, QMC::DefaultPropertyFlags | QMC::Constant),
        // property 'xplanetFontSize'
        QtMocHelpers::PropertyData<QString>(1486, QMetaType::QString, QMC::DefaultPropertyFlags | QMC::Writable | QMC::StdCppSet, 282),
        // property 'isXplanetFontSizeImmutable'
        QtMocHelpers::PropertyData<bool>(1487, QMetaType::Bool, QMC::DefaultPropertyFlags | QMC::Constant),
        // property 'xplanetColor'
        QtMocHelpers::PropertyData<QString>(1488, QMetaType::QString, QMC::DefaultPropertyFlags | QMC::Writable | QMC::StdCppSet, 283),
        // property 'isXplanetColorImmutable'
        QtMocHelpers::PropertyData<bool>(1489, QMetaType::Bool, QMC::DefaultPropertyFlags | QMC::Constant),
        // property 'xplanetDateFormat'
        QtMocHelpers::PropertyData<QString>(1490, QMetaType::QString, QMC::DefaultPropertyFlags | QMC::Writable | QMC::StdCppSet, 284),
        // property 'isXplanetDateFormatImmutable'
        QtMocHelpers::PropertyData<bool>(1491, QMetaType::Bool, QMC::DefaultPropertyFlags | QMC::Constant),
        // property 'xplanetLabelTL'
        QtMocHelpers::PropertyData<bool>(1492, QMetaType::Bool, QMC::DefaultPropertyFlags | QMC::Writable | QMC::StdCppSet, 285),
        // property 'isXplanetLabelTLImmutable'
        QtMocHelpers::PropertyData<bool>(1493, QMetaType::Bool, QMC::DefaultPropertyFlags | QMC::Constant),
        // property 'xplanetLabelTR'
        QtMocHelpers::PropertyData<bool>(1494, QMetaType::Bool, QMC::DefaultPropertyFlags | QMC::Writable | QMC::StdCppSet, 286),
        // property 'isXplanetLabelTRImmutable'
        QtMocHelpers::PropertyData<bool>(1495, QMetaType::Bool, QMC::DefaultPropertyFlags | QMC::Constant),
        // property 'xplanetLabelBR'
        QtMocHelpers::PropertyData<bool>(1496, QMetaType::Bool, QMC::DefaultPropertyFlags | QMC::Writable | QMC::StdCppSet, 287),
        // property 'isXplanetLabelBRImmutable'
        QtMocHelpers::PropertyData<bool>(1497, QMetaType::Bool, QMC::DefaultPropertyFlags | QMC::Constant),
        // property 'xplanetLabelBL'
        QtMocHelpers::PropertyData<bool>(1498, QMetaType::Bool, QMC::DefaultPropertyFlags | QMC::Writable | QMC::StdCppSet, 288),
        // property 'isXplanetLabelBLImmutable'
        QtMocHelpers::PropertyData<bool>(1499, QMetaType::Bool, QMC::DefaultPropertyFlags | QMC::Constant),
        // property 'xplanetGlare'
        QtMocHelpers::PropertyData<QString>(1500, QMetaType::QString, QMC::DefaultPropertyFlags | QMC::Writable | QMC::StdCppSet, 289),
        // property 'isXplanetGlareImmutable'
        QtMocHelpers::PropertyData<bool>(1501, QMetaType::Bool, QMC::DefaultPropertyFlags | QMC::Constant),
        // property 'xplanetRandom'
        QtMocHelpers::PropertyData<bool>(1502, QMetaType::Bool, QMC::DefaultPropertyFlags | QMC::Writable | QMC::StdCppSet, 290),
        // property 'isXplanetRandomImmutable'
        QtMocHelpers::PropertyData<bool>(1503, QMetaType::Bool, QMC::DefaultPropertyFlags | QMC::Constant),
        // property 'xplanetLatLong'
        QtMocHelpers::PropertyData<bool>(1504, QMetaType::Bool, QMC::DefaultPropertyFlags | QMC::Writable | QMC::StdCppSet, 291),
        // property 'isXplanetLatLongImmutable'
        QtMocHelpers::PropertyData<bool>(1505, QMetaType::Bool, QMC::DefaultPropertyFlags | QMC::Constant),
        // property 'xplanetLatitude'
        QtMocHelpers::PropertyData<QString>(1506, QMetaType::QString, QMC::DefaultPropertyFlags | QMC::Writable | QMC::StdCppSet, 292),
        // property 'isXplanetLatitudeImmutable'
        QtMocHelpers::PropertyData<bool>(1507, QMetaType::Bool, QMC::DefaultPropertyFlags | QMC::Constant),
        // property 'xplanetLongitude'
        QtMocHelpers::PropertyData<QString>(1508, QMetaType::QString, QMC::DefaultPropertyFlags | QMC::Writable | QMC::StdCppSet, 293),
        // property 'isXplanetLongitudeImmutable'
        QtMocHelpers::PropertyData<bool>(1509, QMetaType::Bool, QMC::DefaultPropertyFlags | QMC::Constant),
        // property 'xplanetProjection'
        QtMocHelpers::PropertyData<uint>(1510, QMetaType::UInt, QMC::DefaultPropertyFlags | QMC::Writable | QMC::StdCppSet, 294),
        // property 'isXplanetProjectionImmutable'
        QtMocHelpers::PropertyData<bool>(1511, QMetaType::Bool, QMC::DefaultPropertyFlags | QMC::Constant),
        // property 'xplanetBackground'
        QtMocHelpers::PropertyData<bool>(1512, QMetaType::Bool, QMC::DefaultPropertyFlags | QMC::Writable | QMC::StdCppSet, 295),
        // property 'isXplanetBackgroundImmutable'
        QtMocHelpers::PropertyData<bool>(1513, QMetaType::Bool, QMC::DefaultPropertyFlags | QMC::Constant),
        // property 'xplanetBackgroundImage'
        QtMocHelpers::PropertyData<bool>(1514, QMetaType::Bool, QMC::DefaultPropertyFlags | QMC::Writable | QMC::StdCppSet, 296),
        // property 'isXplanetBackgroundImageImmutable'
        QtMocHelpers::PropertyData<bool>(1515, QMetaType::Bool, QMC::DefaultPropertyFlags | QMC::Constant),
        // property 'xplanetBackgroundImagePath'
        QtMocHelpers::PropertyData<QString>(1516, QMetaType::QString, QMC::DefaultPropertyFlags | QMC::Writable | QMC::StdCppSet, 297),
        // property 'isXplanetBackgroundImagePathImmutable'
        QtMocHelpers::PropertyData<bool>(1517, QMetaType::Bool, QMC::DefaultPropertyFlags | QMC::Constant),
        // property 'xplanetBackgroundColor'
        QtMocHelpers::PropertyData<bool>(1518, QMetaType::Bool, QMC::DefaultPropertyFlags | QMC::Writable | QMC::StdCppSet, 298),
        // property 'isXplanetBackgroundColorImmutable'
        QtMocHelpers::PropertyData<bool>(1519, QMetaType::Bool, QMC::DefaultPropertyFlags | QMC::Constant),
        // property 'xplanetBackgroundColorValue'
        QtMocHelpers::PropertyData<QString>(1520, QMetaType::QString, QMC::DefaultPropertyFlags | QMC::Writable | QMC::StdCppSet, 299),
        // property 'isXplanetBackgroundColorValueImmutable'
        QtMocHelpers::PropertyData<bool>(1521, QMetaType::Bool, QMC::DefaultPropertyFlags | QMC::Constant),
        // property 'xplanetMagnitude'
        QtMocHelpers::PropertyData<QString>(1522, QMetaType::QString, QMC::DefaultPropertyFlags | QMC::Writable | QMC::StdCppSet, 300),
        // property 'isXplanetMagnitudeImmutable'
        QtMocHelpers::PropertyData<bool>(1523, QMetaType::Bool, QMC::DefaultPropertyFlags | QMC::Constant),
        // property 'xplanetArcFile'
        QtMocHelpers::PropertyData<bool>(1524, QMetaType::Bool, QMC::DefaultPropertyFlags | QMC::Writable | QMC::StdCppSet, 301),
        // property 'isXplanetArcFileImmutable'
        QtMocHelpers::PropertyData<bool>(1525, QMetaType::Bool, QMC::DefaultPropertyFlags | QMC::Constant),
        // property 'xplanetArcFilePath'
        QtMocHelpers::PropertyData<QString>(1526, QMetaType::QString, QMC::DefaultPropertyFlags | QMC::Writable | QMC::StdCppSet, 302),
        // property 'isXplanetArcFilePathImmutable'
        QtMocHelpers::PropertyData<bool>(1527, QMetaType::Bool, QMC::DefaultPropertyFlags | QMC::Constant),
        // property 'xplanetConfigFile'
        QtMocHelpers::PropertyData<bool>(1528, QMetaType::Bool, QMC::DefaultPropertyFlags | QMC::Writable | QMC::StdCppSet, 303),
        // property 'isXplanetConfigFileImmutable'
        QtMocHelpers::PropertyData<bool>(1529, QMetaType::Bool, QMC::DefaultPropertyFlags | QMC::Constant),
        // property 'xplanetConfigFilePath'
        QtMocHelpers::PropertyData<QString>(1530, QMetaType::QString, QMC::DefaultPropertyFlags | QMC::Writable | QMC::StdCppSet, 304),
        // property 'isXplanetConfigFilePathImmutable'
        QtMocHelpers::PropertyData<bool>(1531, QMetaType::Bool, QMC::DefaultPropertyFlags | QMC::Constant),
        // property 'xplanetFOV'
        QtMocHelpers::PropertyData<bool>(1532, QMetaType::Bool, QMC::DefaultPropertyFlags | QMC::Writable | QMC::StdCppSet, 305),
        // property 'isXplanetFOVImmutable'
        QtMocHelpers::PropertyData<bool>(1533, QMetaType::Bool, QMC::DefaultPropertyFlags | QMC::Constant),
        // property 'xplanetMarkerFile'
        QtMocHelpers::PropertyData<bool>(1534, QMetaType::Bool, QMC::DefaultPropertyFlags | QMC::Writable | QMC::StdCppSet, 306),
        // property 'isXplanetMarkerFileImmutable'
        QtMocHelpers::PropertyData<bool>(1535, QMetaType::Bool, QMC::DefaultPropertyFlags | QMC::Constant),
        // property 'xplanetMarkerFilePath'
        QtMocHelpers::PropertyData<QString>(1536, QMetaType::QString, QMC::DefaultPropertyFlags | QMC::Writable | QMC::StdCppSet, 307),
        // property 'isXplanetMarkerFilePathImmutable'
        QtMocHelpers::PropertyData<bool>(1537, QMetaType::Bool, QMC::DefaultPropertyFlags | QMC::Constant),
        // property 'xplanetMarkerBounds'
        QtMocHelpers::PropertyData<bool>(1538, QMetaType::Bool, QMC::DefaultPropertyFlags | QMC::Writable | QMC::StdCppSet, 308),
        // property 'isXplanetMarkerBoundsImmutable'
        QtMocHelpers::PropertyData<bool>(1539, QMetaType::Bool, QMC::DefaultPropertyFlags | QMC::Constant),
        // property 'xplanetMarkerBoundsPath'
        QtMocHelpers::PropertyData<QString>(1540, QMetaType::QString, QMC::DefaultPropertyFlags | QMC::Writable | QMC::StdCppSet, 309),
        // property 'isXplanetMarkerBoundsPathImmutable'
        QtMocHelpers::PropertyData<bool>(1541, QMetaType::Bool, QMC::DefaultPropertyFlags | QMC::Constant),
        // property 'xplanetStarmap'
        QtMocHelpers::PropertyData<bool>(1542, QMetaType::Bool, QMC::DefaultPropertyFlags | QMC::Writable | QMC::StdCppSet, 310),
        // property 'isXplanetStarmapImmutable'
        QtMocHelpers::PropertyData<bool>(1543, QMetaType::Bool, QMC::DefaultPropertyFlags | QMC::Constant),
        // property 'xplanetStarmapPath'
        QtMocHelpers::PropertyData<QString>(1544, QMetaType::QString, QMC::DefaultPropertyFlags | QMC::Writable | QMC::StdCppSet, 311),
        // property 'isXplanetStarmapPathImmutable'
        QtMocHelpers::PropertyData<bool>(1545, QMetaType::Bool, QMC::DefaultPropertyFlags | QMC::Constant),
        // property 'xplanetQuality'
        QtMocHelpers::PropertyData<QString>(1546, QMetaType::QString, QMC::DefaultPropertyFlags | QMC::Writable | QMC::StdCppSet, 312),
        // property 'isXplanetQualityImmutable'
        QtMocHelpers::PropertyData<bool>(1547, QMetaType::Bool, QMC::DefaultPropertyFlags | QMC::Constant),
        // property 'showSatellites'
        QtMocHelpers::PropertyData<bool>(1548, QMetaType::Bool, QMC::DefaultPropertyFlags | QMC::Writable | QMC::StdCppSet, 313),
        // property 'isShowSatellitesImmutable'
        QtMocHelpers::PropertyData<bool>(1549, QMetaType::Bool, QMC::DefaultPropertyFlags | QMC::Constant),
        // property 'showVisibleSatellites'
        QtMocHelpers::PropertyData<bool>(1550, QMetaType::Bool, QMC::DefaultPropertyFlags | QMC::Writable | QMC::StdCppSet, 314),
        // property 'isShowVisibleSatellitesImmutable'
        QtMocHelpers::PropertyData<bool>(1551, QMetaType::Bool, QMC::DefaultPropertyFlags | QMC::Constant),
        // property 'drawSatellitesLikeStars'
        QtMocHelpers::PropertyData<bool>(1552, QMetaType::Bool, QMC::DefaultPropertyFlags | QMC::Writable | QMC::StdCppSet, 315),
        // property 'isDrawSatellitesLikeStarsImmutable'
        QtMocHelpers::PropertyData<bool>(1553, QMetaType::Bool, QMC::DefaultPropertyFlags | QMC::Constant),
        // property 'showSatellitesLabels'
        QtMocHelpers::PropertyData<bool>(1554, QMetaType::Bool, QMC::DefaultPropertyFlags | QMC::Writable | QMC::StdCppSet, 316),
        // property 'isShowSatellitesLabelsImmutable'
        QtMocHelpers::PropertyData<bool>(1555, QMetaType::Bool, QMC::DefaultPropertyFlags | QMC::Constant),
        // property 'selectedSatellites'
        QtMocHelpers::PropertyData<QStringList>(1556, QMetaType::QStringList, QMC::DefaultPropertyFlags | QMC::Writable | QMC::StdCppSet, 317),
        // property 'isSelectedSatellitesImmutable'
        QtMocHelpers::PropertyData<bool>(1557, QMetaType::Bool, QMC::DefaultPropertyFlags | QMC::Constant),
        // property 'kStarsFirstRun'
        QtMocHelpers::PropertyData<bool>(1558, QMetaType::Bool, QMC::DefaultPropertyFlags | QMC::Writable | QMC::StdCppSet, 318),
        // property 'isKStarsFirstRunImmutable'
        QtMocHelpers::PropertyData<bool>(1559, QMetaType::Bool, QMC::DefaultPropertyFlags | QMC::Constant),
        // property 'alwaysRecomputeCoordinates'
        QtMocHelpers::PropertyData<bool>(1560, QMetaType::Bool, QMC::DefaultPropertyFlags | QMC::Writable | QMC::StdCppSet, 319),
        // property 'isAlwaysRecomputeCoordinatesImmutable'
        QtMocHelpers::PropertyData<bool>(1561, QMetaType::Bool, QMC::DefaultPropertyFlags | QMC::Constant),
        // property 'defaultDSSImageSize'
        QtMocHelpers::PropertyData<double>(1562, QMetaType::Double, QMC::DefaultPropertyFlags | QMC::Writable | QMC::StdCppSet, 320),
        // property 'isDefaultDSSImageSizeImmutable'
        QtMocHelpers::PropertyData<bool>(1563, QMetaType::Bool, QMC::DefaultPropertyFlags | QMC::Constant),
        // property 'dSSPadding'
        QtMocHelpers::PropertyData<double>(1564, QMetaType::Double, QMC::DefaultPropertyFlags | QMC::Writable | QMC::StdCppSet, 321),
        // property 'isDSSPaddingImmutable'
        QtMocHelpers::PropertyData<bool>(1565, QMetaType::Bool, QMC::DefaultPropertyFlags | QMC::Constant),
        // property 'verboseLogging'
        QtMocHelpers::PropertyData<bool>(1566, QMetaType::Bool, QMC::DefaultPropertyFlags | QMC::Writable | QMC::StdCppSet, 322),
        // property 'isVerboseLoggingImmutable'
        QtMocHelpers::PropertyData<bool>(1567, QMetaType::Bool, QMC::DefaultPropertyFlags | QMC::Constant),
        // property 'regularLogging'
        QtMocHelpers::PropertyData<bool>(1568, QMetaType::Bool, QMC::DefaultPropertyFlags | QMC::Writable | QMC::StdCppSet, 323),
        // property 'isRegularLoggingImmutable'
        QtMocHelpers::PropertyData<bool>(1569, QMetaType::Bool, QMC::DefaultPropertyFlags | QMC::Constant),
        // property 'disableLogging'
        QtMocHelpers::PropertyData<bool>(1570, QMetaType::Bool, QMC::DefaultPropertyFlags | QMC::Writable | QMC::StdCppSet, 324),
        // property 'isDisableLoggingImmutable'
        QtMocHelpers::PropertyData<bool>(1571, QMetaType::Bool, QMC::DefaultPropertyFlags | QMC::Constant),
        // property 'logToDefault'
        QtMocHelpers::PropertyData<bool>(1572, QMetaType::Bool, QMC::DefaultPropertyFlags | QMC::Writable | QMC::StdCppSet, 325),
        // property 'isLogToDefaultImmutable'
        QtMocHelpers::PropertyData<bool>(1573, QMetaType::Bool, QMC::DefaultPropertyFlags | QMC::Constant),
        // property 'logToFile'
        QtMocHelpers::PropertyData<bool>(1574, QMetaType::Bool, QMC::DefaultPropertyFlags | QMC::Writable | QMC::StdCppSet, 326),
        // property 'isLogToFileImmutable'
        QtMocHelpers::PropertyData<bool>(1575, QMetaType::Bool, QMC::DefaultPropertyFlags | QMC::Constant),
        // property 'fITSLogging'
        QtMocHelpers::PropertyData<bool>(1576, QMetaType::Bool, QMC::DefaultPropertyFlags | QMC::Writable | QMC::StdCppSet, 327),
        // property 'isFITSLoggingImmutable'
        QtMocHelpers::PropertyData<bool>(1577, QMetaType::Bool, QMC::DefaultPropertyFlags | QMC::Constant),
        // property 'iNDILogging'
        QtMocHelpers::PropertyData<bool>(1578, QMetaType::Bool, QMC::DefaultPropertyFlags | QMC::Writable | QMC::StdCppSet, 328),
        // property 'isINDILoggingImmutable'
        QtMocHelpers::PropertyData<bool>(1579, QMetaType::Bool, QMC::DefaultPropertyFlags | QMC::Constant),
        // property 'captureLogging'
        QtMocHelpers::PropertyData<bool>(1580, QMetaType::Bool, QMC::DefaultPropertyFlags | QMC::Writable | QMC::StdCppSet, 329),
        // property 'isCaptureLoggingImmutable'
        QtMocHelpers::PropertyData<bool>(1581, QMetaType::Bool, QMC::DefaultPropertyFlags | QMC::Constant),
        // property 'focusLogging'
        QtMocHelpers::PropertyData<bool>(1582, QMetaType::Bool, QMC::DefaultPropertyFlags | QMC::Writable | QMC::StdCppSet, 330),
        // property 'isFocusLoggingImmutable'
        QtMocHelpers::PropertyData<bool>(1583, QMetaType::Bool, QMC::DefaultPropertyFlags | QMC::Constant),
        // property 'saveGuideImages'
        QtMocHelpers::PropertyData<bool>(1584, QMetaType::Bool, QMC::DefaultPropertyFlags | QMC::Writable | QMC::StdCppSet, 331),
        // property 'isSaveGuideImagesImmutable'
        QtMocHelpers::PropertyData<bool>(1585, QMetaType::Bool, QMC::DefaultPropertyFlags | QMC::Constant),
        // property 'saveAlignImages'
        QtMocHelpers::PropertyData<bool>(1586, QMetaType::Bool, QMC::DefaultPropertyFlags | QMC::Writable | QMC::StdCppSet, 332),
        // property 'isSaveAlignImagesImmutable'
        QtMocHelpers::PropertyData<bool>(1587, QMetaType::Bool, QMC::DefaultPropertyFlags | QMC::Constant),
        // property 'saveFailedAlignImages'
        QtMocHelpers::PropertyData<bool>(1588, QMetaType::Bool, QMC::DefaultPropertyFlags | QMC::Writable | QMC::StdCppSet, 333),
        // property 'isSaveFailedAlignImagesImmutable'
        QtMocHelpers::PropertyData<bool>(1589, QMetaType::Bool, QMC::DefaultPropertyFlags | QMC::Constant),
        // property 'dontSyncToRealTime'
        QtMocHelpers::PropertyData<bool>(1590, QMetaType::Bool, QMC::DefaultPropertyFlags | QMC::Writable | QMC::StdCppSet, 334),
        // property 'isDontSyncToRealTimeImmutable'
        QtMocHelpers::PropertyData<bool>(1591, QMetaType::Bool, QMC::DefaultPropertyFlags | QMC::Constant),
        // property 'guideLogging'
        QtMocHelpers::PropertyData<bool>(1592, QMetaType::Bool, QMC::DefaultPropertyFlags | QMC::Writable | QMC::StdCppSet, 335),
        // property 'isGuideLoggingImmutable'
        QtMocHelpers::PropertyData<bool>(1593, QMetaType::Bool, QMC::DefaultPropertyFlags | QMC::Constant),
        // property 'alignmentLogging'
        QtMocHelpers::PropertyData<bool>(1594, QMetaType::Bool, QMC::DefaultPropertyFlags | QMC::Writable | QMC::StdCppSet, 336),
        // property 'isAlignmentLoggingImmutable'
        QtMocHelpers::PropertyData<bool>(1595, QMetaType::Bool, QMC::DefaultPropertyFlags | QMC::Constant),
        // property 'mountLogging'
        QtMocHelpers::PropertyData<bool>(1596, QMetaType::Bool, QMC::DefaultPropertyFlags | QMC::Writable | QMC::StdCppSet, 337),
        // property 'isMountLoggingImmutable'
        QtMocHelpers::PropertyData<bool>(1597, QMetaType::Bool, QMC::DefaultPropertyFlags | QMC::Constant),
        // property 'observatoryLogging'
        QtMocHelpers::PropertyData<bool>(1598, QMetaType::Bool, QMC::DefaultPropertyFlags | QMC::Writable | QMC::StdCppSet, 338),
        // property 'isObservatoryLoggingImmutable'
        QtMocHelpers::PropertyData<bool>(1599, QMetaType::Bool, QMC::DefaultPropertyFlags | QMC::Constant),
        // property 'imageDebayerEngine'
        QtMocHelpers::PropertyData<int>(1600, QMetaType::Int, QMC::DefaultPropertyFlags | QMC::Writable | QMC::StdCppSet, 339),
        // property 'isImageDebayerEngineImmutable'
        QtMocHelpers::PropertyData<bool>(1601, QMetaType::Bool, QMC::DefaultPropertyFlags | QMC::Constant),
        // property 'imageDebayerAlgo'
        QtMocHelpers::PropertyData<int>(1602, QMetaType::Int, QMC::DefaultPropertyFlags | QMC::Writable | QMC::StdCppSet, 340),
        // property 'isImageDebayerAlgoImmutable'
        QtMocHelpers::PropertyData<bool>(1603, QMetaType::Bool, QMC::DefaultPropertyFlags | QMC::Constant),
        // property 'stackDebayerEngine'
        QtMocHelpers::PropertyData<int>(1604, QMetaType::Int, QMC::DefaultPropertyFlags | QMC::Writable | QMC::StdCppSet, 341),
        // property 'isStackDebayerEngineImmutable'
        QtMocHelpers::PropertyData<bool>(1605, QMetaType::Bool, QMC::DefaultPropertyFlags | QMC::Constant),
        // property 'stackDebayerAlgo'
        QtMocHelpers::PropertyData<int>(1606, QMetaType::Int, QMC::DefaultPropertyFlags | QMC::Writable | QMC::StdCppSet, 342),
        // property 'isStackDebayerAlgoImmutable'
        QtMocHelpers::PropertyData<bool>(1607, QMetaType::Bool, QMC::DefaultPropertyFlags | QMC::Constant),
        // property 'fITSWindowGeometry'
        QtMocHelpers::PropertyData<QString>(1608, QMetaType::QString, QMC::DefaultPropertyFlags | QMC::Writable | QMC::StdCppSet, 343),
        // property 'isFITSWindowGeometryImmutable'
        QtMocHelpers::PropertyData<bool>(1609, QMetaType::Bool, QMC::DefaultPropertyFlags | QMC::Constant),
        // property 'useFITSViewer'
        QtMocHelpers::PropertyData<bool>(1610, QMetaType::Bool, QMC::DefaultPropertyFlags | QMC::Writable | QMC::StdCppSet, 344),
        // property 'isUseFITSViewerImmutable'
        QtMocHelpers::PropertyData<bool>(1611, QMetaType::Bool, QMC::DefaultPropertyFlags | QMC::Constant),
        // property 'singlePreviewFITS'
        QtMocHelpers::PropertyData<bool>(1612, QMetaType::Bool, QMC::DefaultPropertyFlags | QMC::Writable | QMC::StdCppSet, 345),
        // property 'isSinglePreviewFITSImmutable'
        QtMocHelpers::PropertyData<bool>(1613, QMetaType::Bool, QMC::DefaultPropertyFlags | QMC::Constant),
        // property 'singleWindowCapturedFITS'
        QtMocHelpers::PropertyData<bool>(1614, QMetaType::Bool, QMC::DefaultPropertyFlags | QMC::Writable | QMC::StdCppSet, 346),
        // property 'isSingleWindowCapturedFITSImmutable'
        QtMocHelpers::PropertyData<bool>(1615, QMetaType::Bool, QMC::DefaultPropertyFlags | QMC::Constant),
        // property 'singleWindowOpenedFITS'
        QtMocHelpers::PropertyData<bool>(1616, QMetaType::Bool, QMC::DefaultPropertyFlags | QMC::Writable | QMC::StdCppSet, 347),
        // property 'isSingleWindowOpenedFITSImmutable'
        QtMocHelpers::PropertyData<bool>(1617, QMetaType::Bool, QMC::DefaultPropertyFlags | QMC::Constant),
        // property 'focusFITSOnNewImage'
        QtMocHelpers::PropertyData<bool>(1618, QMetaType::Bool, QMC::DefaultPropertyFlags | QMC::Writable | QMC::StdCppSet, 348),
        // property 'isFocusFITSOnNewImageImmutable'
        QtMocHelpers::PropertyData<bool>(1619, QMetaType::Bool, QMC::DefaultPropertyFlags | QMC::Constant),
        // property 'independentWindowFITS'
        QtMocHelpers::PropertyData<bool>(1620, QMetaType::Bool, QMC::DefaultPropertyFlags | QMC::Writable | QMC::StdCppSet, 349),
        // property 'isIndependentWindowFITSImmutable'
        QtMocHelpers::PropertyData<bool>(1621, QMetaType::Bool, QMC::DefaultPropertyFlags | QMC::Constant),
        // property 'liveStackerOwnProcess'
        QtMocHelpers::PropertyData<bool>(1622, QMetaType::Bool, QMC::DefaultPropertyFlags | QMC::Writable | QMC::StdCppSet, 350),
        // property 'isLiveStackerOwnProcessImmutable'
        QtMocHelpers::PropertyData<bool>(1623, QMetaType::Bool, QMC::DefaultPropertyFlags | QMC::Constant),
        // property 'autoDebayer'
        QtMocHelpers::PropertyData<bool>(1624, QMetaType::Bool, QMC::DefaultPropertyFlags | QMC::Writable | QMC::StdCppSet, 351),
        // property 'isAutoDebayerImmutable'
        QtMocHelpers::PropertyData<bool>(1625, QMetaType::Bool, QMC::DefaultPropertyFlags | QMC::Constant),
        // property 'auto3DCube'
        QtMocHelpers::PropertyData<bool>(1626, QMetaType::Bool, QMC::DefaultPropertyFlags | QMC::Writable | QMC::StdCppSet, 352),
        // property 'isAuto3DCubeImmutable'
        QtMocHelpers::PropertyData<bool>(1627, QMetaType::Bool, QMC::DefaultPropertyFlags | QMC::Constant),
        // property 'autoHFR'
        QtMocHelpers::PropertyData<bool>(1628, QMetaType::Bool, QMC::DefaultPropertyFlags | QMC::Writable | QMC::StdCppSet, 353),
        // property 'isAutoHFRImmutable'
        QtMocHelpers::PropertyData<bool>(1629, QMetaType::Bool, QMC::DefaultPropertyFlags | QMC::Constant),
        // property 'quickHFR'
        QtMocHelpers::PropertyData<bool>(1630, QMetaType::Bool, QMC::DefaultPropertyFlags | QMC::Writable | QMC::StdCppSet, 354),
        // property 'isQuickHFRImmutable'
        QtMocHelpers::PropertyData<bool>(1631, QMetaType::Bool, QMC::DefaultPropertyFlags | QMC::Constant),
        // property 'stellarSolverPartition'
        QtMocHelpers::PropertyData<bool>(1632, QMetaType::Bool, QMC::DefaultPropertyFlags | QMC::Writable | QMC::StdCppSet, 355),
        // property 'isStellarSolverPartitionImmutable'
        QtMocHelpers::PropertyData<bool>(1633, QMetaType::Bool, QMC::DefaultPropertyFlags | QMC::Constant),
        // property 'autoWCS'
        QtMocHelpers::PropertyData<bool>(1634, QMetaType::Bool, QMC::DefaultPropertyFlags | QMC::Writable | QMC::StdCppSet, 356),
        // property 'isAutoWCSImmutable'
        QtMocHelpers::PropertyData<bool>(1635, QMetaType::Bool, QMC::DefaultPropertyFlags | QMC::Constant),
        // property 'limitedResourcesMode'
        QtMocHelpers::PropertyData<bool>(1636, QMetaType::Bool, QMC::DefaultPropertyFlags | QMC::Writable | QMC::StdCppSet, 357),
        // property 'isLimitedResourcesModeImmutable'
        QtMocHelpers::PropertyData<bool>(1637, QMetaType::Bool, QMC::DefaultPropertyFlags | QMC::Constant),
        // property 'nonLinearHistogram'
        QtMocHelpers::PropertyData<bool>(1638, QMetaType::Bool, QMC::DefaultPropertyFlags | QMC::Writable | QMC::StdCppSet, 358),
        // property 'isNonLinearHistogramImmutable'
        QtMocHelpers::PropertyData<bool>(1639, QMetaType::Bool, QMC::DefaultPropertyFlags | QMC::Constant),
        // property 'hIPSOpacity'
        QtMocHelpers::PropertyData<double>(1640, QMetaType::Double, QMC::DefaultPropertyFlags | QMC::Writable | QMC::StdCppSet, 359),
        // property 'isHIPSOpacityImmutable'
        QtMocHelpers::PropertyData<bool>(1641, QMetaType::Bool, QMC::DefaultPropertyFlags | QMC::Constant),
        // property 'hIPSOffsetX'
        QtMocHelpers::PropertyData<int>(1642, QMetaType::Int, QMC::DefaultPropertyFlags | QMC::Writable | QMC::StdCppSet, 360),
        // property 'isHIPSOffsetXImmutable'
        QtMocHelpers::PropertyData<bool>(1643, QMetaType::Bool, QMC::DefaultPropertyFlags | QMC::Constant),
        // property 'hIPSOffsetY'
        QtMocHelpers::PropertyData<int>(1644, QMetaType::Int, QMC::DefaultPropertyFlags | QMC::Writable | QMC::StdCppSet, 361),
        // property 'isHIPSOffsetYImmutable'
        QtMocHelpers::PropertyData<bool>(1645, QMetaType::Bool, QMC::DefaultPropertyFlags | QMC::Constant),
        // property 'fitsSolverProfile'
        QtMocHelpers::PropertyData<uint>(1646, QMetaType::UInt, QMC::DefaultPropertyFlags | QMC::Writable | QMC::StdCppSet, 362),
        // property 'isFitsSolverProfileImmutable'
        QtMocHelpers::PropertyData<bool>(1647, QMetaType::Bool, QMC::DefaultPropertyFlags | QMC::Constant),
        // property 'fitsSolverModule'
        QtMocHelpers::PropertyData<uint>(1648, QMetaType::UInt, QMC::DefaultPropertyFlags | QMC::Writable | QMC::StdCppSet, 363),
        // property 'isFitsSolverModuleImmutable'
        QtMocHelpers::PropertyData<bool>(1649, QMetaType::Bool, QMC::DefaultPropertyFlags | QMC::Constant),
        // property 'fitsSolverProfileIndeces'
        QtMocHelpers::PropertyData<QString>(1650, QMetaType::QString, QMC::DefaultPropertyFlags | QMC::Writable | QMC::StdCppSet, 364),
        // property 'isFitsSolverProfileIndecesImmutable'
        QtMocHelpers::PropertyData<bool>(1651, QMetaType::Bool, QMC::DefaultPropertyFlags | QMC::Constant),
        // property 'fitsCatalog'
        QtMocHelpers::PropertyData<uint>(1652, QMetaType::UInt, QMC::DefaultPropertyFlags | QMC::Writable | QMC::StdCppSet, 365),
        // property 'isFitsCatalogImmutable'
        QtMocHelpers::PropertyData<bool>(1653, QMetaType::Bool, QMC::DefaultPropertyFlags | QMC::Constant),
        // property 'fitsCatObjShowNames'
        QtMocHelpers::PropertyData<bool>(1654, QMetaType::Bool, QMC::DefaultPropertyFlags | QMC::Writable | QMC::StdCppSet, 366),
        // property 'isFitsCatObjShowNamesImmutable'
        QtMocHelpers::PropertyData<bool>(1655, QMetaType::Bool, QMC::DefaultPropertyFlags | QMC::Constant),
        // property 'fitsSolverUseScale'
        QtMocHelpers::PropertyData<bool>(1656, QMetaType::Bool, QMC::DefaultPropertyFlags | QMC::Writable | QMC::StdCppSet, 367),
        // property 'isFitsSolverUseScaleImmutable'
        QtMocHelpers::PropertyData<bool>(1657, QMetaType::Bool, QMC::DefaultPropertyFlags | QMC::Constant),
        // property 'fitsSolverUsePosition'
        QtMocHelpers::PropertyData<bool>(1658, QMetaType::Bool, QMC::DefaultPropertyFlags | QMC::Writable | QMC::StdCppSet, 368),
        // property 'isFitsSolverUsePositionImmutable'
        QtMocHelpers::PropertyData<bool>(1659, QMetaType::Bool, QMC::DefaultPropertyFlags | QMC::Constant),
        // property 'fitsSolverScale'
        QtMocHelpers::PropertyData<double>(1660, QMetaType::Double, QMC::DefaultPropertyFlags | QMC::Writable | QMC::StdCppSet, 369),
        // property 'isFitsSolverScaleImmutable'
        QtMocHelpers::PropertyData<bool>(1661, QMetaType::Bool, QMC::DefaultPropertyFlags | QMC::Constant),
        // property 'fitsSolverImageScaleUnits'
        QtMocHelpers::PropertyData<uint>(1662, QMetaType::UInt, QMC::DefaultPropertyFlags | QMC::Writable | QMC::StdCppSet, 370),
        // property 'isFitsSolverImageScaleUnitsImmutable'
        QtMocHelpers::PropertyData<bool>(1663, QMetaType::Bool, QMC::DefaultPropertyFlags | QMC::Constant),
        // property 'fitsSolverRadius'
        QtMocHelpers::PropertyData<double>(1664, QMetaType::Double, QMC::DefaultPropertyFlags | QMC::Writable | QMC::StdCppSet, 371),
        // property 'isFitsSolverRadiusImmutable'
        QtMocHelpers::PropertyData<bool>(1665, QMetaType::Bool, QMC::DefaultPropertyFlags | QMC::Constant),
        // property 'fitsLSHideGeneral'
        QtMocHelpers::PropertyData<bool>(1666, QMetaType::Bool, QMC::DefaultPropertyFlags | QMC::Writable | QMC::StdCppSet, 372),
        // property 'isFitsLSHideGeneralImmutable'
        QtMocHelpers::PropertyData<bool>(1667, QMetaType::Bool, QMC::DefaultPropertyFlags | QMC::Constant),
        // property 'fitsLSHideCalibration'
        QtMocHelpers::PropertyData<bool>(1668, QMetaType::Bool, QMC::DefaultPropertyFlags | QMC::Writable | QMC::StdCppSet, 373),
        // property 'isFitsLSHideCalibrationImmutable'
        QtMocHelpers::PropertyData<bool>(1669, QMetaType::Bool, QMC::DefaultPropertyFlags | QMC::Constant),
        // property 'fitsLSHideAlignment'
        QtMocHelpers::PropertyData<bool>(1670, QMetaType::Bool, QMC::DefaultPropertyFlags | QMC::Writable | QMC::StdCppSet, 374),
        // property 'isFitsLSHideAlignmentImmutable'
        QtMocHelpers::PropertyData<bool>(1671, QMetaType::Bool, QMC::DefaultPropertyFlags | QMC::Constant),
        // property 'fitsLSHideStacking'
        QtMocHelpers::PropertyData<bool>(1672, QMetaType::Bool, QMC::DefaultPropertyFlags | QMC::Writable | QMC::StdCppSet, 375),
        // property 'isFitsLSHideStackingImmutable'
        QtMocHelpers::PropertyData<bool>(1673, QMetaType::Bool, QMC::DefaultPropertyFlags | QMC::Constant),
        // property 'fitsLSHidePostProc'
        QtMocHelpers::PropertyData<bool>(1674, QMetaType::Bool, QMC::DefaultPropertyFlags | QMC::Writable | QMC::StdCppSet, 376),
        // property 'isFitsLSHidePostProcImmutable'
        QtMocHelpers::PropertyData<bool>(1675, QMetaType::Bool, QMC::DefaultPropertyFlags | QMC::Constant),
        // property 'fitsLSCalcSNR'
        QtMocHelpers::PropertyData<bool>(1676, QMetaType::Bool, QMC::DefaultPropertyFlags | QMC::Writable | QMC::StdCppSet, 377),
        // property 'isFitsLSCalcSNRImmutable'
        QtMocHelpers::PropertyData<bool>(1677, QMetaType::Bool, QMC::DefaultPropertyFlags | QMC::Constant),
        // property 'fitsLSMasterDark'
        QtMocHelpers::PropertyData<QString>(1678, QMetaType::QString, QMC::DefaultPropertyFlags | QMC::Writable | QMC::StdCppSet, 378),
        // property 'isFitsLSMasterDarkImmutable'
        QtMocHelpers::PropertyData<bool>(1679, QMetaType::Bool, QMC::DefaultPropertyFlags | QMC::Constant),
        // property 'fitsLSMasterFlat'
        QtMocHelpers::PropertyData<QString>(1680, QMetaType::QString, QMC::DefaultPropertyFlags | QMC::Writable | QMC::StdCppSet, 379),
        // property 'isFitsLSMasterFlatImmutable'
        QtMocHelpers::PropertyData<bool>(1681, QMetaType::Bool, QMC::DefaultPropertyFlags | QMC::Constant),
        // property 'fitsLSHotPixels'
        QtMocHelpers::PropertyData<bool>(1682, QMetaType::Bool, QMC::DefaultPropertyFlags | QMC::Writable | QMC::StdCppSet, 380),
        // property 'isFitsLSHotPixelsImmutable'
        QtMocHelpers::PropertyData<bool>(1683, QMetaType::Bool, QMC::DefaultPropertyFlags | QMC::Constant),
        // property 'fitsLSColdPixels'
        QtMocHelpers::PropertyData<bool>(1684, QMetaType::Bool, QMC::DefaultPropertyFlags | QMC::Writable | QMC::StdCppSet, 381),
        // property 'isFitsLSColdPixelsImmutable'
        QtMocHelpers::PropertyData<bool>(1685, QMetaType::Bool, QMC::DefaultPropertyFlags | QMC::Constant),
        // property 'fitsLSAlignMethod'
        QtMocHelpers::PropertyData<uint>(1686, QMetaType::UInt, QMC::DefaultPropertyFlags | QMC::Writable | QMC::StdCppSet, 382),
        // property 'isFitsLSAlignMethodImmutable'
        QtMocHelpers::PropertyData<bool>(1687, QMetaType::Bool, QMC::DefaultPropertyFlags | QMC::Constant),
        // property 'fitsLSNumInMem'
        QtMocHelpers::PropertyData<uint>(1688, QMetaType::UInt, QMC::DefaultPropertyFlags | QMC::Writable | QMC::StdCppSet, 383),
        // property 'isFitsLSNumInMemImmutable'
        QtMocHelpers::PropertyData<bool>(1689, QMetaType::Bool, QMC::DefaultPropertyFlags | QMC::Constant),
        // property 'fitsLSDownscale'
        QtMocHelpers::PropertyData<uint>(1690, QMetaType::UInt, QMC::DefaultPropertyFlags | QMC::Writable | QMC::StdCppSet, 384),
        // property 'isFitsLSDownscaleImmutable'
        QtMocHelpers::PropertyData<bool>(1691, QMetaType::Bool, QMC::DefaultPropertyFlags | QMC::Constant),
        // property 'fitsLSWeighting'
        QtMocHelpers::PropertyData<uint>(1692, QMetaType::UInt, QMC::DefaultPropertyFlags | QMC::Writable | QMC::StdCppSet, 385),
        // property 'isFitsLSWeightingImmutable'
        QtMocHelpers::PropertyData<bool>(1693, QMetaType::Bool, QMC::DefaultPropertyFlags | QMC::Constant),
        // property 'fitsLSNormalization'
        QtMocHelpers::PropertyData<uint>(1694, QMetaType::UInt, QMC::DefaultPropertyFlags | QMC::Writable | QMC::StdCppSet, 386),
        // property 'isFitsLSNormalizationImmutable'
        QtMocHelpers::PropertyData<bool>(1695, QMetaType::Bool, QMC::DefaultPropertyFlags | QMC::Constant),
        // property 'fitsLSStackingMethod'
        QtMocHelpers::PropertyData<uint>(1696, QMetaType::UInt, QMC::DefaultPropertyFlags | QMC::Writable | QMC::StdCppSet, 387),
        // property 'isFitsLSStackingMethodImmutable'
        QtMocHelpers::PropertyData<bool>(1697, QMetaType::Bool, QMC::DefaultPropertyFlags | QMC::Constant),
        // property 'fitsLSLowSigma'
        QtMocHelpers::PropertyData<double>(1698, QMetaType::Double, QMC::DefaultPropertyFlags | QMC::Writable | QMC::StdCppSet, 388),
        // property 'isFitsLSLowSigmaImmutable'
        QtMocHelpers::PropertyData<bool>(1699, QMetaType::Bool, QMC::DefaultPropertyFlags | QMC::Constant),
        // property 'fitsLSHighSigma'
        QtMocHelpers::PropertyData<double>(1700, QMetaType::Double, QMC::DefaultPropertyFlags | QMC::Writable | QMC::StdCppSet, 389),
        // property 'isFitsLSHighSigmaImmutable'
        QtMocHelpers::PropertyData<bool>(1701, QMetaType::Bool, QMC::DefaultPropertyFlags | QMC::Constant),
        // property 'fitsLSWinsorCutoff'
        QtMocHelpers::PropertyData<double>(1702, QMetaType::Double, QMC::DefaultPropertyFlags | QMC::Writable | QMC::StdCppSet, 390),
        // property 'isFitsLSWinsorCutoffImmutable'
        QtMocHelpers::PropertyData<bool>(1703, QMetaType::Bool, QMC::DefaultPropertyFlags | QMC::Constant),
        // property 'fitsLSIterations'
        QtMocHelpers::PropertyData<uint>(1704, QMetaType::UInt, QMC::DefaultPropertyFlags | QMC::Writable | QMC::StdCppSet, 391),
        // property 'isFitsLSIterationsImmutable'
        QtMocHelpers::PropertyData<bool>(1705, QMetaType::Bool, QMC::DefaultPropertyFlags | QMC::Constant),
        // property 'fitsLSKappa'
        QtMocHelpers::PropertyData<double>(1706, QMetaType::Double, QMC::DefaultPropertyFlags | QMC::Writable | QMC::StdCppSet, 392),
        // property 'isFitsLSKappaImmutable'
        QtMocHelpers::PropertyData<bool>(1707, QMetaType::Bool, QMC::DefaultPropertyFlags | QMC::Constant),
        // property 'fitsLSAlpha'
        QtMocHelpers::PropertyData<double>(1708, QMetaType::Double, QMC::DefaultPropertyFlags | QMC::Writable | QMC::StdCppSet, 393),
        // property 'isFitsLSAlphaImmutable'
        QtMocHelpers::PropertyData<bool>(1709, QMetaType::Bool, QMC::DefaultPropertyFlags | QMC::Constant),
        // property 'fitsLSSigma'
        QtMocHelpers::PropertyData<double>(1710, QMetaType::Double, QMC::DefaultPropertyFlags | QMC::Writable | QMC::StdCppSet, 394),
        // property 'isFitsLSSigmaImmutable'
        QtMocHelpers::PropertyData<bool>(1711, QMetaType::Bool, QMC::DefaultPropertyFlags | QMC::Constant),
        // property 'fitsPSFUpdate'
        QtMocHelpers::PropertyData<uint>(1712, QMetaType::UInt, QMC::DefaultPropertyFlags | QMC::Writable | QMC::StdCppSet, 395),
        // property 'isFitsPSFUpdateImmutable'
        QtMocHelpers::PropertyData<bool>(1713, QMetaType::Bool, QMC::DefaultPropertyFlags | QMC::Constant),
        // property 'fitsLSPostProc'
        QtMocHelpers::PropertyData<bool>(1714, QMetaType::Bool, QMC::DefaultPropertyFlags | QMC::Writable | QMC::StdCppSet, 396),
        // property 'isFitsLSPostProcImmutable'
        QtMocHelpers::PropertyData<bool>(1715, QMetaType::Bool, QMC::DefaultPropertyFlags | QMC::Constant),
        // property 'fitsLSGradientAmt'
        QtMocHelpers::PropertyData<double>(1716, QMetaType::Double, QMC::DefaultPropertyFlags | QMC::Writable | QMC::StdCppSet, 397),
        // property 'isFitsLSGradientAmtImmutable'
        QtMocHelpers::PropertyData<bool>(1717, QMetaType::Bool, QMC::DefaultPropertyFlags | QMC::Constant),
        // property 'fitsLSDeconvAmt'
        QtMocHelpers::PropertyData<double>(1718, QMetaType::Double, QMC::DefaultPropertyFlags | QMC::Writable | QMC::StdCppSet, 398),
        // property 'isFitsLSDeconvAmtImmutable'
        QtMocHelpers::PropertyData<bool>(1719, QMetaType::Bool, QMC::DefaultPropertyFlags | QMC::Constant),
        // property 'fitsLSPSFSigma'
        QtMocHelpers::PropertyData<double>(1720, QMetaType::Double, QMC::DefaultPropertyFlags | QMC::Writable | QMC::StdCppSet, 399),
        // property 'isFitsLSPSFSigmaImmutable'
        QtMocHelpers::PropertyData<bool>(1721, QMetaType::Bool, QMC::DefaultPropertyFlags | QMC::Constant),
        // property 'fitsLSDenoiseAmt'
        QtMocHelpers::PropertyData<double>(1722, QMetaType::Double, QMC::DefaultPropertyFlags | QMC::Writable | QMC::StdCppSet, 400),
        // property 'isFitsLSDenoiseAmtImmutable'
        QtMocHelpers::PropertyData<bool>(1723, QMetaType::Bool, QMC::DefaultPropertyFlags | QMC::Constant),
        // property 'fitsLSSharpenAmt'
        QtMocHelpers::PropertyData<double>(1724, QMetaType::Double, QMC::DefaultPropertyFlags | QMC::Writable | QMC::StdCppSet, 401),
        // property 'isFitsLSSharpenAmtImmutable'
        QtMocHelpers::PropertyData<bool>(1725, QMetaType::Bool, QMC::DefaultPropertyFlags | QMC::Constant),
        // property 'fitsLSSharpenKernal'
        QtMocHelpers::PropertyData<uint>(1726, QMetaType::UInt, QMC::DefaultPropertyFlags | QMC::Writable | QMC::StdCppSet, 402),
        // property 'isFitsLSSharpenKernalImmutable'
        QtMocHelpers::PropertyData<bool>(1727, QMetaType::Bool, QMC::DefaultPropertyFlags | QMC::Constant),
        // property 'fitsLSSharpenSigma'
        QtMocHelpers::PropertyData<double>(1728, QMetaType::Double, QMC::DefaultPropertyFlags | QMC::Writable | QMC::StdCppSet, 403),
        // property 'isFitsLSSharpenSigmaImmutable'
        QtMocHelpers::PropertyData<bool>(1729, QMetaType::Bool, QMC::DefaultPropertyFlags | QMC::Constant),
        // property 'fitsLSMWindowGeometry'
        QtMocHelpers::PropertyData<QString>(1730, QMetaType::QString, QMC::DefaultPropertyFlags | QMC::Writable | QMC::StdCppSet, 404),
        // property 'isFitsLSMWindowGeometryImmutable'
        QtMocHelpers::PropertyData<bool>(1731, QMetaType::Bool, QMC::DefaultPropertyFlags | QMC::Constant),
        // property 'fitsLSMVisibleColumns'
        QtMocHelpers::PropertyData<QStringList>(1732, QMetaType::QStringList, QMC::DefaultPropertyFlags | QMC::Writable | QMC::StdCppSet, 405),
        // property 'isFitsLSMVisibleColumnsImmutable'
        QtMocHelpers::PropertyData<bool>(1733, QMetaType::Bool, QMC::DefaultPropertyFlags | QMC::Constant),
        // property 'fitsLSMColumnWidths'
        QtMocHelpers::PropertyData<QList<int>>(1734, 0x80000000 | 970, QMC::DefaultPropertyFlags | QMC::Writable | QMC::EnumOrFlag | QMC::StdCppSet, 406),
        // property 'isFitsLSMColumnWidthsImmutable'
        QtMocHelpers::PropertyData<bool>(1735, QMetaType::Bool, QMC::DefaultPropertyFlags | QMC::Constant),
        // property 'fitsLSMSortColumn'
        QtMocHelpers::PropertyData<int>(1736, QMetaType::Int, QMC::DefaultPropertyFlags | QMC::Writable | QMC::StdCppSet, 407),
        // property 'isFitsLSMSortColumnImmutable'
        QtMocHelpers::PropertyData<bool>(1737, QMetaType::Bool, QMC::DefaultPropertyFlags | QMC::Constant),
        // property 'fitsLSMSortOrder'
        QtMocHelpers::PropertyData<int>(1738, QMetaType::Int, QMC::DefaultPropertyFlags | QMC::Writable | QMC::StdCppSet, 408),
        // property 'isFitsLSMSortOrderImmutable'
        QtMocHelpers::PropertyData<bool>(1739, QMetaType::Bool, QMC::DefaultPropertyFlags | QMC::Constant),
        // property 'fitsLSMHighlighting'
        QtMocHelpers::PropertyData<bool>(1740, QMetaType::Bool, QMC::DefaultPropertyFlags | QMC::Writable | QMC::StdCppSet, 409),
        // property 'isFitsLSMHighlightingImmutable'
        QtMocHelpers::PropertyData<bool>(1741, QMetaType::Bool, QMC::DefaultPropertyFlags | QMC::Constant),
        // property 'fitsLSWebcastTitle'
        QtMocHelpers::PropertyData<QString>(1742, QMetaType::QString, QMC::DefaultPropertyFlags | QMC::Writable | QMC::StdCppSet, 410),
        // property 'isFitsLSWebcastTitleImmutable'
        QtMocHelpers::PropertyData<bool>(1743, QMetaType::Bool, QMC::DefaultPropertyFlags | QMC::Constant),
        // property 'fitsLSWebcastLogoL'
        QtMocHelpers::PropertyData<QString>(1744, QMetaType::QString, QMC::DefaultPropertyFlags | QMC::Writable | QMC::StdCppSet, 411),
        // property 'isFitsLSWebcastLogoLImmutable'
        QtMocHelpers::PropertyData<bool>(1745, QMetaType::Bool, QMC::DefaultPropertyFlags | QMC::Constant),
        // property 'fitsLSWebcastLogoR'
        QtMocHelpers::PropertyData<QString>(1746, QMetaType::QString, QMC::DefaultPropertyFlags | QMC::Writable | QMC::StdCppSet, 412),
        // property 'isFitsLSWebcastLogoRImmutable'
        QtMocHelpers::PropertyData<bool>(1747, QMetaType::Bool, QMC::DefaultPropertyFlags | QMC::Constant),
        // property 'fitsLSWebcastPort'
        QtMocHelpers::PropertyData<uint>(1748, QMetaType::UInt, QMC::DefaultPropertyFlags | QMC::Writable | QMC::StdCppSet, 413),
        // property 'isFitsLSWebcastPortImmutable'
        QtMocHelpers::PropertyData<bool>(1749, QMetaType::Bool, QMC::DefaultPropertyFlags | QMC::Constant),
        // property 'fitsLSWebcastThrottle'
        QtMocHelpers::PropertyData<uint>(1750, QMetaType::UInt, QMC::DefaultPropertyFlags | QMC::Writable | QMC::StdCppSet, 414),
        // property 'isFitsLSWebcastThrottleImmutable'
        QtMocHelpers::PropertyData<bool>(1751, QMetaType::Bool, QMC::DefaultPropertyFlags | QMC::Constant),
        // property 'bortleClass'
        QtMocHelpers::PropertyData<uint>(1752, QMetaType::UInt, QMC::DefaultPropertyFlags | QMC::Writable | QMC::StdCppSet, 415),
        // property 'isBortleClassImmutable'
        QtMocHelpers::PropertyData<bool>(1753, QMetaType::Bool, QMC::DefaultPropertyFlags | QMC::Constant),
        // property 'telescopeCheck'
        QtMocHelpers::PropertyData<bool>(1754, QMetaType::Bool, QMC::DefaultPropertyFlags | QMC::Writable | QMC::StdCppSet, 416),
        // property 'isTelescopeCheckImmutable'
        QtMocHelpers::PropertyData<bool>(1755, QMetaType::Bool, QMC::DefaultPropertyFlags | QMC::Constant),
        // property 'binocularsCheck'
        QtMocHelpers::PropertyData<bool>(1756, QMetaType::Bool, QMC::DefaultPropertyFlags | QMC::Writable | QMC::StdCppSet, 417),
        // property 'isBinocularsCheckImmutable'
        QtMocHelpers::PropertyData<bool>(1757, QMetaType::Bool, QMC::DefaultPropertyFlags | QMC::Constant),
        // property 'binocularsAperture'
        QtMocHelpers::PropertyData<double>(1758, QMetaType::Double, QMC::DefaultPropertyFlags | QMC::Writable | QMC::StdCppSet, 418),
        // property 'isBinocularsApertureImmutable'
        QtMocHelpers::PropertyData<bool>(1759, QMetaType::Bool, QMC::DefaultPropertyFlags | QMC::Constant),
        // property 'scopeListIndex'
        QtMocHelpers::PropertyData<uint>(1760, QMetaType::UInt, QMC::DefaultPropertyFlags | QMC::Writable | QMC::StdCppSet, 419),
        // property 'isScopeListIndexImmutable'
        QtMocHelpers::PropertyData<bool>(1761, QMetaType::Bool, QMC::DefaultPropertyFlags | QMC::Constant),
        // property 'ekosWindowWidth'
        QtMocHelpers::PropertyData<uint>(1762, QMetaType::UInt, QMC::DefaultPropertyFlags | QMC::Writable | QMC::StdCppSet, 420),
        // property 'isEkosWindowWidthImmutable'
        QtMocHelpers::PropertyData<bool>(1763, QMetaType::Bool, QMC::DefaultPropertyFlags | QMC::Constant),
        // property 'ekosWindowHeight'
        QtMocHelpers::PropertyData<uint>(1764, QMetaType::UInt, QMC::DefaultPropertyFlags | QMC::Writable | QMC::StdCppSet, 421),
        // property 'isEkosWindowHeightImmutable'
        QtMocHelpers::PropertyData<bool>(1765, QMetaType::Bool, QMC::DefaultPropertyFlags | QMC::Constant),
        // property 'ekosGeometry'
        QtMocHelpers::PropertyData<QString>(1766, QMetaType::QString, QMC::DefaultPropertyFlags | QMC::Writable | QMC::StdCppSet, 422),
        // property 'isEkosGeometryImmutable'
        QtMocHelpers::PropertyData<bool>(1767, QMetaType::Bool, QMC::DefaultPropertyFlags | QMC::Constant),
        // property 'ekosTopIcons'
        QtMocHelpers::PropertyData<bool>(1768, QMetaType::Bool, QMC::DefaultPropertyFlags | QMC::Writable | QMC::StdCppSet, 423),
        // property 'isEkosTopIconsImmutable'
        QtMocHelpers::PropertyData<bool>(1769, QMetaType::Bool, QMC::DefaultPropertyFlags | QMC::Constant),
        // property 'ekosLeftIcons'
        QtMocHelpers::PropertyData<bool>(1770, QMetaType::Bool, QMC::DefaultPropertyFlags | QMC::Writable | QMC::StdCppSet, 424),
        // property 'isEkosLeftIconsImmutable'
        QtMocHelpers::PropertyData<bool>(1771, QMetaType::Bool, QMC::DefaultPropertyFlags | QMC::Constant),
        // property 'independentWindowEkos'
        QtMocHelpers::PropertyData<bool>(1772, QMetaType::Bool, QMC::DefaultPropertyFlags | QMC::Writable | QMC::StdCppSet, 425),
        // property 'isIndependentWindowEkosImmutable'
        QtMocHelpers::PropertyData<bool>(1773, QMetaType::Bool, QMC::DefaultPropertyFlags | QMC::Constant),
        // property 'profile'
        QtMocHelpers::PropertyData<QString>(1774, QMetaType::QString, QMC::DefaultPropertyFlags | QMC::Writable | QMC::StdCppSet, 426),
        // property 'isProfileImmutable'
        QtMocHelpers::PropertyData<bool>(1775, QMetaType::Bool, QMC::DefaultPropertyFlags | QMC::Constant),
        // property 'neverLoadConfig'
        QtMocHelpers::PropertyData<bool>(1776, QMetaType::Bool, QMC::DefaultPropertyFlags | QMC::Writable | QMC::StdCppSet, 427),
        // property 'isNeverLoadConfigImmutable'
        QtMocHelpers::PropertyData<bool>(1777, QMetaType::Bool, QMC::DefaultPropertyFlags | QMC::Constant),
        // property 'loadConfigOnConnection'
        QtMocHelpers::PropertyData<bool>(1778, QMetaType::Bool, QMC::DefaultPropertyFlags | QMC::Writable | QMC::StdCppSet, 428),
        // property 'isLoadConfigOnConnectionImmutable'
        QtMocHelpers::PropertyData<bool>(1779, QMetaType::Bool, QMC::DefaultPropertyFlags | QMC::Constant),
        // property 'loadDefaultConfig'
        QtMocHelpers::PropertyData<bool>(1780, QMetaType::Bool, QMC::DefaultPropertyFlags | QMC::Writable | QMC::StdCppSet, 429),
        // property 'isLoadDefaultConfigImmutable'
        QtMocHelpers::PropertyData<bool>(1781, QMetaType::Bool, QMC::DefaultPropertyFlags | QMC::Constant),
        // property 'autoLoadSerialAssistant'
        QtMocHelpers::PropertyData<bool>(1782, QMetaType::Bool, QMC::DefaultPropertyFlags | QMC::Writable | QMC::StdCppSet, 430),
        // property 'isAutoLoadSerialAssistantImmutable'
        QtMocHelpers::PropertyData<bool>(1783, QMetaType::Bool, QMC::DefaultPropertyFlags | QMC::Constant),
        // property 'rememberCredentials'
        QtMocHelpers::PropertyData<bool>(1784, QMetaType::Bool, QMC::DefaultPropertyFlags | QMC::Writable | QMC::StdCppSet, 431),
        // property 'isRememberCredentialsImmutable'
        QtMocHelpers::PropertyData<bool>(1785, QMetaType::Bool, QMC::DefaultPropertyFlags | QMC::Constant),
        // property 'autoStartEkosLive'
        QtMocHelpers::PropertyData<bool>(1786, QMetaType::Bool, QMC::DefaultPropertyFlags | QMC::Writable | QMC::StdCppSet, 432),
        // property 'isAutoStartEkosLiveImmutable'
        QtMocHelpers::PropertyData<bool>(1787, QMetaType::Bool, QMC::DefaultPropertyFlags | QMC::Constant),
        // property 'ekosLiveUsername'
        QtMocHelpers::PropertyData<QString>(1788, QMetaType::QString, QMC::DefaultPropertyFlags | QMC::Writable | QMC::StdCppSet, 433),
        // property 'isEkosLiveUsernameImmutable'
        QtMocHelpers::PropertyData<bool>(1789, QMetaType::Bool, QMC::DefaultPropertyFlags | QMC::Constant),
        // property 'ekosLiveObservatory'
        QtMocHelpers::PropertyData<QString>(1790, QMetaType::QString, QMC::DefaultPropertyFlags | QMC::Writable | QMC::StdCppSet, 434),
        // property 'isEkosLiveObservatoryImmutable'
        QtMocHelpers::PropertyData<bool>(1791, QMetaType::Bool, QMC::DefaultPropertyFlags | QMC::Constant),
        // property 'ekosLiveOfflineServer'
        QtMocHelpers::PropertyData<QString>(1792, QMetaType::QString, QMC::DefaultPropertyFlags | QMC::Writable | QMC::StdCppSet, 435),
        // property 'isEkosLiveOfflineServerImmutable'
        QtMocHelpers::PropertyData<bool>(1793, QMetaType::Bool, QMC::DefaultPropertyFlags | QMC::Constant),
        // property 'ekosLiveOnlineServer'
        QtMocHelpers::PropertyData<QString>(1794, QMetaType::QString, QMC::DefaultPropertyFlags | QMC::Writable | QMC::StdCppSet, 436),
        // property 'isEkosLiveOnlineServerImmutable'
        QtMocHelpers::PropertyData<bool>(1795, QMetaType::Bool, QMC::DefaultPropertyFlags | QMC::Constant),
        // property 'ekosLiveSound'
        QtMocHelpers::PropertyData<bool>(1796, QMetaType::Bool, QMC::DefaultPropertyFlags | QMC::Writable | QMC::StdCppSet, 437),
        // property 'isEkosLiveSoundImmutable'
        QtMocHelpers::PropertyData<bool>(1797, QMetaType::Bool, QMC::DefaultPropertyFlags | QMC::Constant),
        // property 'ekosLiveNotifications'
        QtMocHelpers::PropertyData<bool>(1798, QMetaType::Bool, QMC::DefaultPropertyFlags | QMC::Writable | QMC::StdCppSet, 438),
        // property 'isEkosLiveNotificationsImmutable'
        QtMocHelpers::PropertyData<bool>(1799, QMetaType::Bool, QMC::DefaultPropertyFlags | QMC::Constant),
        // property 'ekosLiveCloud'
        QtMocHelpers::PropertyData<bool>(1800, QMetaType::Bool, QMC::DefaultPropertyFlags | QMC::Writable | QMC::StdCppSet, 439),
        // property 'isEkosLiveCloudImmutable'
        QtMocHelpers::PropertyData<bool>(1801, QMetaType::Bool, QMC::DefaultPropertyFlags | QMC::Constant),
        // property 'maxDarkTemperatureDiff'
        QtMocHelpers::PropertyData<double>(1802, QMetaType::Double, QMC::DefaultPropertyFlags | QMC::Writable | QMC::StdCppSet, 440),
        // property 'isMaxDarkTemperatureDiffImmutable'
        QtMocHelpers::PropertyData<bool>(1803, QMetaType::Bool, QMC::DefaultPropertyFlags | QMC::Constant),
        // property 'shutterfulCCDs'
        QtMocHelpers::PropertyData<QStringList>(1804, QMetaType::QStringList, QMC::DefaultPropertyFlags | QMC::Writable | QMC::StdCppSet, 441),
        // property 'isShutterfulCCDsImmutable'
        QtMocHelpers::PropertyData<bool>(1805, QMetaType::Bool, QMC::DefaultPropertyFlags | QMC::Constant),
        // property 'shutterlessCCDs'
        QtMocHelpers::PropertyData<QStringList>(1806, QMetaType::QStringList, QMC::DefaultPropertyFlags | QMC::Writable | QMC::StdCppSet, 442),
        // property 'isShutterlessCCDsImmutable'
        QtMocHelpers::PropertyData<bool>(1807, QMetaType::Bool, QMC::DefaultPropertyFlags | QMC::Constant),
        // property 'darkLibraryDuration'
        QtMocHelpers::PropertyData<uint>(1808, QMetaType::UInt, QMC::DefaultPropertyFlags | QMC::Writable | QMC::StdCppSet, 443),
        // property 'isDarkLibraryDurationImmutable'
        QtMocHelpers::PropertyData<bool>(1809, QMetaType::Bool, QMC::DefaultPropertyFlags | QMC::Constant),
        // property 'useGraphicalCountsDisplay'
        QtMocHelpers::PropertyData<bool>(1810, QMetaType::Bool, QMC::DefaultPropertyFlags | QMC::Writable | QMC::StdCppSet, 444),
        // property 'isUseGraphicalCountsDisplayImmutable'
        QtMocHelpers::PropertyData<bool>(1811, QMetaType::Bool, QMC::DefaultPropertyFlags | QMC::Constant),
        // property 'minimumAltLimit'
        QtMocHelpers::PropertyData<double>(1812, QMetaType::Double, QMC::DefaultPropertyFlags | QMC::Writable | QMC::StdCppSet, 445),
        // property 'isMinimumAltLimitImmutable'
        QtMocHelpers::PropertyData<bool>(1813, QMetaType::Bool, QMC::DefaultPropertyFlags | QMC::Constant),
        // property 'maximumAltLimit'
        QtMocHelpers::PropertyData<double>(1814, QMetaType::Double, QMC::DefaultPropertyFlags | QMC::Writable | QMC::StdCppSet, 446),
        // property 'isMaximumAltLimitImmutable'
        QtMocHelpers::PropertyData<bool>(1815, QMetaType::Bool, QMC::DefaultPropertyFlags | QMC::Constant),
        // property 'enableAltitudeLimits'
        QtMocHelpers::PropertyData<bool>(1816, QMetaType::Bool, QMC::DefaultPropertyFlags | QMC::Writable | QMC::StdCppSet, 447),
        // property 'isEnableAltitudeLimitsImmutable'
        QtMocHelpers::PropertyData<bool>(1817, QMetaType::Bool, QMC::DefaultPropertyFlags | QMC::Constant),
        // property 'enableAltitudeLimitsTrackingOnly'
        QtMocHelpers::PropertyData<bool>(1818, QMetaType::Bool, QMC::DefaultPropertyFlags | QMC::Writable | QMC::StdCppSet, 448),
        // property 'isEnableAltitudeLimitsTrackingOnlyImmutable'
        QtMocHelpers::PropertyData<bool>(1819, QMetaType::Bool, QMC::DefaultPropertyFlags | QMC::Constant),
        // property 'confirmBelowHorizon'
        QtMocHelpers::PropertyData<bool>(1820, QMetaType::Bool, QMC::DefaultPropertyFlags | QMC::Writable | QMC::StdCppSet, 449),
        // property 'isConfirmBelowHorizonImmutable'
        QtMocHelpers::PropertyData<bool>(1821, QMetaType::Bool, QMC::DefaultPropertyFlags | QMC::Constant),
        // property 'meridianFlipOffsetDegrees'
        QtMocHelpers::PropertyData<double>(1822, QMetaType::Double, QMC::DefaultPropertyFlags | QMC::Writable | QMC::StdCppSet, 450),
        // property 'isMeridianFlipOffsetDegreesImmutable'
        QtMocHelpers::PropertyData<bool>(1823, QMetaType::Bool, QMC::DefaultPropertyFlags | QMC::Constant),
        // property 'maximumHaLimit'
        QtMocHelpers::PropertyData<double>(1824, QMetaType::Double, QMC::DefaultPropertyFlags | QMC::Writable | QMC::StdCppSet, 451),
        // property 'isMaximumHaLimitImmutable'
        QtMocHelpers::PropertyData<bool>(1825, QMetaType::Bool, QMC::DefaultPropertyFlags | QMC::Constant),
        // property 'enableHaLimit'
        QtMocHelpers::PropertyData<bool>(1826, QMetaType::Bool, QMC::DefaultPropertyFlags | QMC::Writable | QMC::StdCppSet, 452),
        // property 'isEnableHaLimitImmutable'
        QtMocHelpers::PropertyData<bool>(1827, QMetaType::Bool, QMC::DefaultPropertyFlags | QMC::Constant),
        // property 'executeMeridianFlip'
        QtMocHelpers::PropertyData<bool>(1828, QMetaType::Bool, QMC::DefaultPropertyFlags | QMC::Writable | QMC::StdCppSet, 453),
        // property 'isExecuteMeridianFlipImmutable'
        QtMocHelpers::PropertyData<bool>(1829, QMetaType::Bool, QMC::DefaultPropertyFlags | QMC::Constant),
        // property 'leftRightReversed'
        QtMocHelpers::PropertyData<bool>(1830, QMetaType::Bool, QMC::DefaultPropertyFlags | QMC::Writable | QMC::StdCppSet, 454),
        // property 'isLeftRightReversedImmutable'
        QtMocHelpers::PropertyData<bool>(1831, QMetaType::Bool, QMC::DefaultPropertyFlags | QMC::Constant),
        // property 'upDownReversed'
        QtMocHelpers::PropertyData<bool>(1832, QMetaType::Bool, QMC::DefaultPropertyFlags | QMC::Writable | QMC::StdCppSet, 455),
        // property 'isUpDownReversedImmutable'
        QtMocHelpers::PropertyData<bool>(1833, QMetaType::Bool, QMC::DefaultPropertyFlags | QMC::Constant),
        // property 'parkEveryDay'
        QtMocHelpers::PropertyData<bool>(1834, QMetaType::Bool, QMC::DefaultPropertyFlags | QMC::Writable | QMC::StdCppSet, 456),
        // property 'isParkEveryDayImmutable'
        QtMocHelpers::PropertyData<bool>(1835, QMetaType::Bool, QMC::DefaultPropertyFlags | QMC::Constant),
        // property 'parkTime'
        QtMocHelpers::PropertyData<QString>(1836, QMetaType::QString, QMC::DefaultPropertyFlags | QMC::Writable | QMC::StdCppSet, 457),
        // property 'isParkTimeImmutable'
        QtMocHelpers::PropertyData<bool>(1837, QMetaType::Bool, QMC::DefaultPropertyFlags | QMC::Constant),
        // property 'defaultObserver'
        QtMocHelpers::PropertyData<QString>(1838, QMetaType::QString, QMC::DefaultPropertyFlags | QMC::Writable | QMC::StdCppSet, 458),
        // property 'isDefaultObserverImmutable'
        QtMocHelpers::PropertyData<bool>(1839, QMetaType::Bool, QMC::DefaultPropertyFlags | QMC::Constant),
        // property 'syncFOVPA'
        QtMocHelpers::PropertyData<bool>(1840, QMetaType::Bool, QMC::DefaultPropertyFlags | QMC::Writable | QMC::StdCppSet, 459),
        // property 'isSyncFOVPAImmutable'
        QtMocHelpers::PropertyData<bool>(1841, QMetaType::Bool, QMC::DefaultPropertyFlags | QMC::Constant),
        // property 'pAMultiplier'
        QtMocHelpers::PropertyData<double>(1842, QMetaType::Double, QMC::DefaultPropertyFlags | QMC::Writable | QMC::StdCppSet, 460),
        // property 'isPAMultiplierImmutable'
        QtMocHelpers::PropertyData<bool>(1843, QMetaType::Bool, QMC::DefaultPropertyFlags | QMC::Constant),
        // property 'pAOffset'
        QtMocHelpers::PropertyData<double>(1844, QMetaType::Double, QMC::DefaultPropertyFlags | QMC::Writable | QMC::StdCppSet, 461),
        // property 'isPAOffsetImmutable'
        QtMocHelpers::PropertyData<bool>(1845, QMetaType::Bool, QMC::DefaultPropertyFlags | QMC::Constant),
        // property 'pAPierSide'
        QtMocHelpers::PropertyData<uint>(1846, QMetaType::UInt, QMC::DefaultPropertyFlags | QMC::Writable | QMC::StdCppSet, 462),
        // property 'isPAPierSideImmutable'
        QtMocHelpers::PropertyData<bool>(1847, QMetaType::Bool, QMC::DefaultPropertyFlags | QMC::Constant),
        // property 'guideDeviation'
        QtMocHelpers::PropertyData<double>(1848, QMetaType::Double, QMC::DefaultPropertyFlags | QMC::Writable | QMC::StdCppSet, 463),
        // property 'isGuideDeviationImmutable'
        QtMocHelpers::PropertyData<bool>(1849, QMetaType::Bool, QMC::DefaultPropertyFlags | QMC::Constant),
        // property 'guideDeviationReps'
        QtMocHelpers::PropertyData<uint>(1850, QMetaType::UInt, QMC::DefaultPropertyFlags | QMC::Writable | QMC::StdCppSet, 464),
        // property 'isGuideDeviationRepsImmutable'
        QtMocHelpers::PropertyData<bool>(1851, QMetaType::Bool, QMC::DefaultPropertyFlags | QMC::Constant),
        // property 'startGuideDeviation'
        QtMocHelpers::PropertyData<double>(1852, QMetaType::Double, QMC::DefaultPropertyFlags | QMC::Writable | QMC::StdCppSet, 465),
        // property 'isStartGuideDeviationImmutable'
        QtMocHelpers::PropertyData<bool>(1853, QMetaType::Bool, QMC::DefaultPropertyFlags | QMC::Constant),
        // property 'guideDitherPerJobFrequency'
        QtMocHelpers::PropertyData<uint>(1854, QMetaType::UInt, QMC::DefaultPropertyFlags | QMC::Writable | QMC::StdCppSet, 466),
        // property 'isGuideDitherPerJobFrequencyImmutable'
        QtMocHelpers::PropertyData<bool>(1855, QMetaType::Bool, QMC::DefaultPropertyFlags | QMC::Constant),
        // property 'hFRDeviation'
        QtMocHelpers::PropertyData<double>(1856, QMetaType::Double, QMC::DefaultPropertyFlags | QMC::Writable | QMC::StdCppSet, 467),
        // property 'isHFRDeviationImmutable'
        QtMocHelpers::PropertyData<bool>(1857, QMetaType::Bool, QMC::DefaultPropertyFlags | QMC::Constant),
        // property 'maxFocusTemperatureDelta'
        QtMocHelpers::PropertyData<double>(1858, QMetaType::Double, QMC::DefaultPropertyFlags | QMC::Writable | QMC::StdCppSet, 468),
        // property 'isMaxFocusTemperatureDeltaImmutable'
        QtMocHelpers::PropertyData<bool>(1859, QMetaType::Bool, QMC::DefaultPropertyFlags | QMC::Constant),
        // property 'autoDark'
        QtMocHelpers::PropertyData<bool>(1860, QMetaType::Bool, QMC::DefaultPropertyFlags | QMC::Writable | QMC::StdCppSet, 469),
        // property 'isAutoDarkImmutable'
        QtMocHelpers::PropertyData<bool>(1861, QMetaType::Bool, QMC::DefaultPropertyFlags | QMC::Constant),
        // property 'enforceGuideDeviation'
        QtMocHelpers::PropertyData<bool>(1862, QMetaType::Bool, QMC::DefaultPropertyFlags | QMC::Writable | QMC::StdCppSet, 470),
        // property 'isEnforceGuideDeviationImmutable'
        QtMocHelpers::PropertyData<bool>(1863, QMetaType::Bool, QMC::DefaultPropertyFlags | QMC::Constant),
        // property 'enforceAutofocusHFR'
        QtMocHelpers::PropertyData<bool>(1864, QMetaType::Bool, QMC::DefaultPropertyFlags | QMC::Writable | QMC::StdCppSet, 471),
        // property 'isEnforceAutofocusHFRImmutable'
        QtMocHelpers::PropertyData<bool>(1865, QMetaType::Bool, QMC::DefaultPropertyFlags | QMC::Constant),
        // property 'enforceAutofocusOnTemperature'
        QtMocHelpers::PropertyData<bool>(1866, QMetaType::Bool, QMC::DefaultPropertyFlags | QMC::Writable | QMC::StdCppSet, 472),
        // property 'isEnforceAutofocusOnTemperatureImmutable'
        QtMocHelpers::PropertyData<bool>(1867, QMetaType::Bool, QMC::DefaultPropertyFlags | QMC::Constant),
        // property 'enforceRefocusEveryN'
        QtMocHelpers::PropertyData<bool>(1868, QMetaType::Bool, QMC::DefaultPropertyFlags | QMC::Writable | QMC::StdCppSet, 473),
        // property 'isEnforceRefocusEveryNImmutable'
        QtMocHelpers::PropertyData<bool>(1869, QMetaType::Bool, QMC::DefaultPropertyFlags | QMC::Constant),
        // property 'refocusEveryN'
        QtMocHelpers::PropertyData<uint>(1870, QMetaType::UInt, QMC::DefaultPropertyFlags | QMC::Writable | QMC::StdCppSet, 474),
        // property 'isRefocusEveryNImmutable'
        QtMocHelpers::PropertyData<bool>(1871, QMetaType::Bool, QMC::DefaultPropertyFlags | QMC::Constant),
        // property 'refocusAfterMeridianFlip'
        QtMocHelpers::PropertyData<bool>(1872, QMetaType::Bool, QMC::DefaultPropertyFlags | QMC::Writable | QMC::StdCppSet, 475),
        // property 'isRefocusAfterMeridianFlipImmutable'
        QtMocHelpers::PropertyData<bool>(1873, QMetaType::Bool, QMC::DefaultPropertyFlags | QMC::Constant),
        // property 'resetMountModelAfterMeridian'
        QtMocHelpers::PropertyData<bool>(1874, QMetaType::Bool, QMC::DefaultPropertyFlags | QMC::Writable | QMC::StdCppSet, 476),
        // property 'isResetMountModelAfterMeridianImmutable'
        QtMocHelpers::PropertyData<bool>(1875, QMetaType::Bool, QMC::DefaultPropertyFlags | QMC::Constant),
        // property 'forcedFlip'
        QtMocHelpers::PropertyData<bool>(1876, QMetaType::Bool, QMC::DefaultPropertyFlags | QMC::Writable | QMC::StdCppSet, 477),
        // property 'isForcedFlipImmutable'
        QtMocHelpers::PropertyData<bool>(1877, QMetaType::Bool, QMC::DefaultPropertyFlags | QMC::Constant),
        // property 'calibrationADUValue'
        QtMocHelpers::PropertyData<uint>(1878, QMetaType::UInt, QMC::DefaultPropertyFlags | QMC::Writable | QMC::StdCppSet, 478),
        // property 'isCalibrationADUValueImmutable'
        QtMocHelpers::PropertyData<bool>(1879, QMetaType::Bool, QMC::DefaultPropertyFlags | QMC::Constant),
        // property 'calibrationADUValueTolerance'
        QtMocHelpers::PropertyData<uint>(1880, QMetaType::UInt, QMC::DefaultPropertyFlags | QMC::Writable | QMC::StdCppSet, 479),
        // property 'isCalibrationADUValueToleranceImmutable'
        QtMocHelpers::PropertyData<bool>(1881, QMetaType::Bool, QMC::DefaultPropertyFlags | QMC::Constant),
        // property 'calibrationPreActionIndex'
        QtMocHelpers::PropertyData<uint>(1882, QMetaType::UInt, QMC::DefaultPropertyFlags | QMC::Writable | QMC::StdCppSet, 480),
        // property 'isCalibrationPreActionIndexImmutable'
        QtMocHelpers::PropertyData<bool>(1883, QMetaType::Bool, QMC::DefaultPropertyFlags | QMC::Constant),
        // property 'calibrationFlatDurationIndex'
        QtMocHelpers::PropertyData<uint>(1884, QMetaType::UInt, QMC::DefaultPropertyFlags | QMC::Writable | QMC::StdCppSet, 481),
        // property 'isCalibrationFlatDurationIndexImmutable'
        QtMocHelpers::PropertyData<bool>(1885, QMetaType::Bool, QMC::DefaultPropertyFlags | QMC::Constant),
        // property 'calibrationWallAz'
        QtMocHelpers::PropertyData<double>(1886, QMetaType::Double, QMC::DefaultPropertyFlags | QMC::Writable | QMC::StdCppSet, 482),
        // property 'isCalibrationWallAzImmutable'
        QtMocHelpers::PropertyData<bool>(1887, QMetaType::Bool, QMC::DefaultPropertyFlags | QMC::Constant),
        // property 'calibrationWallAlt'
        QtMocHelpers::PropertyData<double>(1888, QMetaType::Double, QMC::DefaultPropertyFlags | QMC::Writable | QMC::StdCppSet, 483),
        // property 'isCalibrationWallAltImmutable'
        QtMocHelpers::PropertyData<bool>(1889, QMetaType::Bool, QMC::DefaultPropertyFlags | QMC::Constant),
        // property 'maxTemperatureDiff'
        QtMocHelpers::PropertyData<double>(1890, QMetaType::Double, QMC::DefaultPropertyFlags | QMC::Writable | QMC::StdCppSet, 484),
        // property 'isMaxTemperatureDiffImmutable'
        QtMocHelpers::PropertyData<bool>(1891, QMetaType::Bool, QMC::DefaultPropertyFlags | QMC::Constant),
        // property 'maxStartGuiderDrift'
        QtMocHelpers::PropertyData<double>(1892, QMetaType::Double, QMC::DefaultPropertyFlags | QMC::Writable | QMC::StdCppSet, 485),
        // property 'isMaxStartGuiderDriftImmutable'
        QtMocHelpers::PropertyData<bool>(1893, QMetaType::Bool, QMC::DefaultPropertyFlags | QMC::Constant),
        // property 'enforceStartGuiderDrift'
        QtMocHelpers::PropertyData<bool>(1894, QMetaType::Bool, QMC::DefaultPropertyFlags | QMC::Writable | QMC::StdCppSet, 486),
        // property 'isEnforceStartGuiderDriftImmutable'
        QtMocHelpers::PropertyData<bool>(1895, QMetaType::Bool, QMC::DefaultPropertyFlags | QMC::Constant),
        // property 'guidingSettle'
        QtMocHelpers::PropertyData<double>(1896, QMetaType::Double, QMC::DefaultPropertyFlags | QMC::Writable | QMC::StdCppSet, 487),
        // property 'isGuidingSettleImmutable'
        QtMocHelpers::PropertyData<bool>(1897, QMetaType::Bool, QMC::DefaultPropertyFlags | QMC::Constant),
        // property 'alwaysResetSequenceWhenStarting'
        QtMocHelpers::PropertyData<bool>(1898, QMetaType::Bool, QMC::DefaultPropertyFlags | QMC::Writable | QMC::StdCppSet, 488),
        // property 'isAlwaysResetSequenceWhenStartingImmutable'
        QtMocHelpers::PropertyData<bool>(1899, QMetaType::Bool, QMC::DefaultPropertyFlags | QMC::Constant),
        // property 'flatSyncFocus'
        QtMocHelpers::PropertyData<bool>(1900, QMetaType::Bool, QMC::DefaultPropertyFlags | QMC::Writable | QMC::StdCppSet, 489),
        // property 'isFlatSyncFocusImmutable'
        QtMocHelpers::PropertyData<bool>(1901, QMetaType::Bool, QMC::DefaultPropertyFlags | QMC::Constant),
        // property 'hFRThresholdPercentage'
        QtMocHelpers::PropertyData<double>(1902, QMetaType::Double, QMC::DefaultPropertyFlags | QMC::Writable | QMC::StdCppSet, 490),
        // property 'isHFRThresholdPercentageImmutable'
        QtMocHelpers::PropertyData<bool>(1903, QMetaType::Bool, QMC::DefaultPropertyFlags | QMC::Constant),
        // property 'hFRCheckAlgorithm'
        QtMocHelpers::PropertyData<int>(1904, QMetaType::Int, QMC::DefaultPropertyFlags | QMC::Writable | QMC::StdCppSet, 491),
        // property 'isHFRCheckAlgorithmImmutable'
        QtMocHelpers::PropertyData<bool>(1905, QMetaType::Bool, QMC::DefaultPropertyFlags | QMC::Constant),
        // property 'inSequenceCheckFrames'
        QtMocHelpers::PropertyData<uint>(1906, QMetaType::UInt, QMC::DefaultPropertyFlags | QMC::Writable | QMC::StdCppSet, 492),
        // property 'isInSequenceCheckFramesImmutable'
        QtMocHelpers::PropertyData<bool>(1907, QMetaType::Bool, QMC::DefaultPropertyFlags | QMC::Constant),
        // property 'autoStretch'
        QtMocHelpers::PropertyData<bool>(1908, QMetaType::Bool, QMC::DefaultPropertyFlags | QMC::Writable | QMC::StdCppSet, 493),
        // property 'isAutoStretchImmutable'
        QtMocHelpers::PropertyData<bool>(1909, QMetaType::Bool, QMC::DefaultPropertyFlags | QMC::Constant),
        // property 'stretchPreviewSampling'
        QtMocHelpers::PropertyData<uint>(1910, QMetaType::UInt, QMC::DefaultPropertyFlags | QMC::Writable | QMC::StdCppSet, 494),
        // property 'isStretchPreviewSamplingImmutable'
        QtMocHelpers::PropertyData<bool>(1911, QMetaType::Bool, QMC::DefaultPropertyFlags | QMC::Constant),
        // property 'clipping64KValue'
        QtMocHelpers::PropertyData<uint>(1912, QMetaType::UInt, QMC::DefaultPropertyFlags | QMC::Writable | QMC::StdCppSet, 495),
        // property 'isClipping64KValueImmutable'
        QtMocHelpers::PropertyData<bool>(1913, QMetaType::Bool, QMC::DefaultPropertyFlags | QMC::Constant),
        // property 'clipping256Value'
        QtMocHelpers::PropertyData<uint>(1914, QMetaType::UInt, QMC::DefaultPropertyFlags | QMC::Writable | QMC::StdCppSet, 496),
        // property 'isClipping256ValueImmutable'
        QtMocHelpers::PropertyData<bool>(1915, QMetaType::Bool, QMC::DefaultPropertyFlags | QMC::Constant),
        // property 'adaptiveSampling'
        QtMocHelpers::PropertyData<bool>(1916, QMetaType::Bool, QMC::DefaultPropertyFlags | QMC::Writable | QMC::StdCppSet, 497),
        // property 'isAdaptiveSamplingImmutable'
        QtMocHelpers::PropertyData<bool>(1917, QMetaType::Bool, QMC::DefaultPropertyFlags | QMC::Constant),
        // property 'useSummaryPreview'
        QtMocHelpers::PropertyData<bool>(1918, QMetaType::Bool, QMC::DefaultPropertyFlags | QMC::Writable | QMC::StdCppSet, 498),
        // property 'isUseSummaryPreviewImmutable'
        QtMocHelpers::PropertyData<bool>(1919, QMetaType::Bool, QMC::DefaultPropertyFlags | QMC::Constant),
        // property 'useDSLRImageViewer'
        QtMocHelpers::PropertyData<bool>(1920, QMetaType::Bool, QMC::DefaultPropertyFlags | QMC::Writable | QMC::StdCppSet, 499),
        // property 'isUseDSLRImageViewerImmutable'
        QtMocHelpers::PropertyData<bool>(1921, QMetaType::Bool, QMC::DefaultPropertyFlags | QMC::Constant),
        // property 'forceDSLRPresets'
        QtMocHelpers::PropertyData<bool>(1922, QMetaType::Bool, QMC::DefaultPropertyFlags | QMC::Writable | QMC::StdCppSet, 500),
        // property 'isForceDSLRPresetsImmutable'
        QtMocHelpers::PropertyData<bool>(1923, QMetaType::Bool, QMC::DefaultPropertyFlags | QMC::Constant),
        // property 'captureDirectory'
        QtMocHelpers::PropertyData<QString>(1924, QMetaType::QString, QMC::DefaultPropertyFlags | QMC::Writable | QMC::StdCppSet, 501),
        // property 'isCaptureDirectoryImmutable'
        QtMocHelpers::PropertyData<bool>(1925, QMetaType::Bool, QMC::DefaultPropertyFlags | QMC::Constant),
        // property 'placeholderFormat'
        QtMocHelpers::PropertyData<QString>(1926, QMetaType::QString, QMC::DefaultPropertyFlags | QMC::Writable | QMC::StdCppSet, 502),
        // property 'isPlaceholderFormatImmutable'
        QtMocHelpers::PropertyData<bool>(1927, QMetaType::Bool, QMC::DefaultPropertyFlags | QMC::Constant),
        // property 'remoteCaptureDirectory'
        QtMocHelpers::PropertyData<QString>(1928, QMetaType::QString, QMC::DefaultPropertyFlags | QMC::Writable | QMC::StdCppSet, 503),
        // property 'isRemoteCaptureDirectoryImmutable'
        QtMocHelpers::PropertyData<bool>(1929, QMetaType::Bool, QMC::DefaultPropertyFlags | QMC::Constant),
        // property 'manualCoverTimeout'
        QtMocHelpers::PropertyData<uint>(1930, QMetaType::UInt, QMC::DefaultPropertyFlags | QMC::Writable | QMC::StdCppSet, 504),
        // property 'isManualCoverTimeoutImmutable'
        QtMocHelpers::PropertyData<bool>(1931, QMetaType::Bool, QMC::DefaultPropertyFlags | QMC::Constant),
        // property 'captureOperationsTimeout'
        QtMocHelpers::PropertyData<uint>(1932, QMetaType::UInt, QMC::DefaultPropertyFlags | QMC::Writable | QMC::StdCppSet, 505),
        // property 'isCaptureOperationsTimeoutImmutable'
        QtMocHelpers::PropertyData<bool>(1933, QMetaType::Bool, QMC::DefaultPropertyFlags | QMC::Constant),
        // property 'minFlipDuration'
        QtMocHelpers::PropertyData<uint>(1934, QMetaType::UInt, QMC::DefaultPropertyFlags | QMC::Writable | QMC::StdCppSet, 506),
        // property 'isMinFlipDurationImmutable'
        QtMocHelpers::PropertyData<bool>(1935, QMetaType::Bool, QMC::DefaultPropertyFlags | QMC::Constant),
        // property 'capturePosition'
        QtMocHelpers::PropertyData<bool>(1936, QMetaType::Bool, QMC::DefaultPropertyFlags | QMC::Writable | QMC::StdCppSet, 507),
        // property 'isCapturePositionImmutable'
        QtMocHelpers::PropertyData<bool>(1937, QMetaType::Bool, QMC::DefaultPropertyFlags | QMC::Constant),
        // property 'captureTrainID'
        QtMocHelpers::PropertyData<uint>(1938, QMetaType::UInt, QMC::DefaultPropertyFlags | QMC::Writable | QMC::StdCppSet, 508),
        // property 'isCaptureTrainIDImmutable'
        QtMocHelpers::PropertyData<bool>(1939, QMetaType::Bool, QMC::DefaultPropertyFlags | QMC::Constant),
        // property 'captureCalibrationWall'
        QtMocHelpers::PropertyData<bool>(1940, QMetaType::Bool, QMC::DefaultPropertyFlags | QMC::Writable | QMC::StdCppSet, 509),
        // property 'isCaptureCalibrationWallImmutable'
        QtMocHelpers::PropertyData<bool>(1941, QMetaType::Bool, QMC::DefaultPropertyFlags | QMC::Constant),
        // property 'captureCalibrationParkMount'
        QtMocHelpers::PropertyData<bool>(1942, QMetaType::Bool, QMC::DefaultPropertyFlags | QMC::Writable | QMC::StdCppSet, 510),
        // property 'isCaptureCalibrationParkMountImmutable'
        QtMocHelpers::PropertyData<bool>(1943, QMetaType::Bool, QMC::DefaultPropertyFlags | QMC::Constant),
        // property 'captureCalibrationParkDome'
        QtMocHelpers::PropertyData<bool>(1944, QMetaType::Bool, QMC::DefaultPropertyFlags | QMC::Writable | QMC::StdCppSet, 511),
        // property 'isCaptureCalibrationParkDomeImmutable'
        QtMocHelpers::PropertyData<bool>(1945, QMetaType::Bool, QMC::DefaultPropertyFlags | QMC::Constant),
        // property 'captureCalibrationUseManual'
        QtMocHelpers::PropertyData<bool>(1946, QMetaType::Bool, QMC::DefaultPropertyFlags | QMC::Writable | QMC::StdCppSet, 512),
        // property 'isCaptureCalibrationUseManualImmutable'
        QtMocHelpers::PropertyData<bool>(1947, QMetaType::Bool, QMC::DefaultPropertyFlags | QMC::Constant),
        // property 'captureCalibrationUseADU'
        QtMocHelpers::PropertyData<bool>(1948, QMetaType::Bool, QMC::DefaultPropertyFlags | QMC::Writable | QMC::StdCppSet, 513),
        // property 'isCaptureCalibrationUseADUImmutable'
        QtMocHelpers::PropertyData<bool>(1949, QMetaType::Bool, QMC::DefaultPropertyFlags | QMC::Constant),
        // property 'captureCalibrationADUValue'
        QtMocHelpers::PropertyData<double>(1950, QMetaType::Double, QMC::DefaultPropertyFlags | QMC::Writable | QMC::StdCppSet, 514),
        // property 'isCaptureCalibrationADUValueImmutable'
        QtMocHelpers::PropertyData<bool>(1951, QMetaType::Bool, QMC::DefaultPropertyFlags | QMC::Constant),
        // property 'captureCalibrationADUTolerance'
        QtMocHelpers::PropertyData<double>(1952, QMetaType::Double, QMC::DefaultPropertyFlags | QMC::Writable | QMC::StdCppSet, 515),
        // property 'isCaptureCalibrationADUToleranceImmutable'
        QtMocHelpers::PropertyData<bool>(1953, QMetaType::Bool, QMC::DefaultPropertyFlags | QMC::Constant),
        // property 'captureCalibrationSkyFlats'
        QtMocHelpers::PropertyData<bool>(1954, QMetaType::Bool, QMC::DefaultPropertyFlags | QMC::Writable | QMC::StdCppSet, 516),
        // property 'isCaptureCalibrationSkyFlatsImmutable'
        QtMocHelpers::PropertyData<bool>(1955, QMetaType::Bool, QMC::DefaultPropertyFlags | QMC::Constant),
        // property 'absTicksSpin'
        QtMocHelpers::PropertyData<uint>(1956, QMetaType::UInt, QMC::DefaultPropertyFlags | QMC::Writable | QMC::StdCppSet, 517),
        // property 'isAbsTicksSpinImmutable'
        QtMocHelpers::PropertyData<bool>(1957, QMetaType::Bool, QMC::DefaultPropertyFlags | QMC::Constant),
        // property 'focusExposure'
        QtMocHelpers::PropertyData<double>(1958, QMetaType::Double, QMC::DefaultPropertyFlags | QMC::Writable | QMC::StdCppSet, 518),
        // property 'isFocusExposureImmutable'
        QtMocHelpers::PropertyData<bool>(1959, QMetaType::Bool, QMC::DefaultPropertyFlags | QMC::Constant),
        // property 'focusBinning'
        QtMocHelpers::PropertyData<QString>(1960, QMetaType::QString, QMC::DefaultPropertyFlags | QMC::Writable | QMC::StdCppSet, 519),
        // property 'isFocusBinningImmutable'
        QtMocHelpers::PropertyData<bool>(1961, QMetaType::Bool, QMC::DefaultPropertyFlags | QMC::Constant),
        // property 'focusGain'
        QtMocHelpers::PropertyData<double>(1962, QMetaType::Double, QMC::DefaultPropertyFlags | QMC::Writable | QMC::StdCppSet, 520),
        // property 'isFocusGainImmutable'
        QtMocHelpers::PropertyData<bool>(1963, QMetaType::Bool, QMC::DefaultPropertyFlags | QMC::Constant),
        // property 'focusISO'
        QtMocHelpers::PropertyData<QString>(1964, QMetaType::QString, QMC::DefaultPropertyFlags | QMC::Writable | QMC::StdCppSet, 521),
        // property 'isFocusISOImmutable'
        QtMocHelpers::PropertyData<bool>(1965, QMetaType::Bool, QMC::DefaultPropertyFlags | QMC::Constant),
        // property 'defaultFocusTemperatureSource'
        QtMocHelpers::PropertyData<QString>(1966, QMetaType::QString, QMC::DefaultPropertyFlags | QMC::Writable | QMC::StdCppSet, 522),
        // property 'isDefaultFocusTemperatureSourceImmutable'
        QtMocHelpers::PropertyData<bool>(1967, QMetaType::Bool, QMC::DefaultPropertyFlags | QMC::Constant),
        // property 'focusFilter'
        QtMocHelpers::PropertyData<QString>(1968, QMetaType::QString, QMC::DefaultPropertyFlags | QMC::Writable | QMC::StdCppSet, 523),
        // property 'isFocusFilterImmutable'
        QtMocHelpers::PropertyData<bool>(1969, QMetaType::Bool, QMC::DefaultPropertyFlags | QMC::Constant),
        // property 'useFocusDarkFrame'
        QtMocHelpers::PropertyData<bool>(1970, QMetaType::Bool, QMC::DefaultPropertyFlags | QMC::Writable | QMC::StdCppSet, 524),
        // property 'isUseFocusDarkFrameImmutable'
        QtMocHelpers::PropertyData<bool>(1971, QMetaType::Bool, QMC::DefaultPropertyFlags | QMC::Constant),
        // property 'focusSubFrame'
        QtMocHelpers::PropertyData<bool>(1972, QMetaType::Bool, QMC::DefaultPropertyFlags | QMC::Writable | QMC::StdCppSet, 525),
        // property 'isFocusSubFrameImmutable'
        QtMocHelpers::PropertyData<bool>(1973, QMetaType::Bool, QMC::DefaultPropertyFlags | QMC::Constant),
        // property 'focusBoxSize'
        QtMocHelpers::PropertyData<uint>(1974, QMetaType::UInt, QMC::DefaultPropertyFlags | QMC::Writable | QMC::StdCppSet, 526),
        // property 'isFocusBoxSizeImmutable'
        QtMocHelpers::PropertyData<bool>(1975, QMetaType::Bool, QMC::DefaultPropertyFlags | QMC::Constant),
        // property 'focusUseFullField'
        QtMocHelpers::PropertyData<bool>(1976, QMetaType::Bool, QMC::DefaultPropertyFlags | QMC::Writable | QMC::StdCppSet, 527),
        // property 'isFocusUseFullFieldImmutable'
        QtMocHelpers::PropertyData<bool>(1977, QMetaType::Bool, QMC::DefaultPropertyFlags | QMC::Constant),
        // property 'focusNoMaskRB'
        QtMocHelpers::PropertyData<bool>(1978, QMetaType::Bool, QMC::DefaultPropertyFlags | QMC::Writable | QMC::StdCppSet, 528),
        // property 'isFocusNoMaskRBImmutable'
        QtMocHelpers::PropertyData<bool>(1979, QMetaType::Bool, QMC::DefaultPropertyFlags | QMC::Constant),
        // property 'focusRingMaskRB'
        QtMocHelpers::PropertyData<bool>(1980, QMetaType::Bool, QMC::DefaultPropertyFlags | QMC::Writable | QMC::StdCppSet, 529),
        // property 'isFocusRingMaskRBImmutable'
        QtMocHelpers::PropertyData<bool>(1981, QMetaType::Bool, QMC::DefaultPropertyFlags | QMC::Constant),
        // property 'focusMosaicMaskRB'
        QtMocHelpers::PropertyData<bool>(1982, QMetaType::Bool, QMC::DefaultPropertyFlags | QMC::Writable | QMC::StdCppSet, 530),
        // property 'isFocusMosaicMaskRBImmutable'
        QtMocHelpers::PropertyData<bool>(1983, QMetaType::Bool, QMC::DefaultPropertyFlags | QMC::Constant),
        // property 'focusFullFieldInnerRadius'
        QtMocHelpers::PropertyData<double>(1984, QMetaType::Double, QMC::DefaultPropertyFlags | QMC::Writable | QMC::StdCppSet, 531),
        // property 'isFocusFullFieldInnerRadiusImmutable'
        QtMocHelpers::PropertyData<bool>(1985, QMetaType::Bool, QMC::DefaultPropertyFlags | QMC::Constant),
        // property 'focusFullFieldOuterRadius'
        QtMocHelpers::PropertyData<double>(1986, QMetaType::Double, QMC::DefaultPropertyFlags | QMC::Writable | QMC::StdCppSet, 532),
        // property 'isFocusFullFieldOuterRadiusImmutable'
        QtMocHelpers::PropertyData<bool>(1987, QMetaType::Bool, QMC::DefaultPropertyFlags | QMC::Constant),
        // property 'focusMosaicTileWidth'
        QtMocHelpers::PropertyData<double>(1988, QMetaType::Double, QMC::DefaultPropertyFlags | QMC::Writable | QMC::StdCppSet, 533),
        // property 'isFocusMosaicTileWidthImmutable'
        QtMocHelpers::PropertyData<bool>(1989, QMetaType::Bool, QMC::DefaultPropertyFlags | QMC::Constant),
        // property 'focusMosaicSpace'
        QtMocHelpers::PropertyData<uint>(1990, QMetaType::UInt, QMC::DefaultPropertyFlags | QMC::Writable | QMC::StdCppSet, 534),
        // property 'isFocusMosaicSpaceImmutable'
        QtMocHelpers::PropertyData<bool>(1991, QMetaType::Bool, QMC::DefaultPropertyFlags | QMC::Constant),
        // property 'focusAutoStarEnabled'
        QtMocHelpers::PropertyData<bool>(1992, QMetaType::Bool, QMC::DefaultPropertyFlags | QMC::Writable | QMC::StdCppSet, 535),
        // property 'isFocusAutoStarEnabledImmutable'
        QtMocHelpers::PropertyData<bool>(1993, QMetaType::Bool, QMC::DefaultPropertyFlags | QMC::Constant),
        // property 'focusSuspendGuiding'
        QtMocHelpers::PropertyData<bool>(1994, QMetaType::Bool, QMC::DefaultPropertyFlags | QMC::Writable | QMC::StdCppSet, 536),
        // property 'isFocusSuspendGuidingImmutable'
        QtMocHelpers::PropertyData<bool>(1995, QMetaType::Bool, QMC::DefaultPropertyFlags | QMC::Constant),
        // property 'focusGuideSettleTime'
        QtMocHelpers::PropertyData<double>(1996, QMetaType::Double, QMC::DefaultPropertyFlags | QMC::Writable | QMC::StdCppSet, 537),
        // property 'isFocusGuideSettleTimeImmutable'
        QtMocHelpers::PropertyData<bool>(1997, QMetaType::Bool, QMC::DefaultPropertyFlags | QMC::Constant),
        // property 'focusUnits'
        QtMocHelpers::PropertyData<QString>(1998, QMetaType::QString, QMC::DefaultPropertyFlags | QMC::Writable | QMC::StdCppSet, 538),
        // property 'isFocusUnitsImmutable'
        QtMocHelpers::PropertyData<bool>(1999, QMetaType::Bool, QMC::DefaultPropertyFlags | QMC::Constant),
        // property 'focusAdaptive'
        QtMocHelpers::PropertyData<bool>(2000, QMetaType::Bool, QMC::DefaultPropertyFlags | QMC::Writable | QMC::StdCppSet, 539),
        // property 'isFocusAdaptiveImmutable'
        QtMocHelpers::PropertyData<bool>(2001, QMetaType::Bool, QMC::DefaultPropertyFlags | QMC::Constant),
        // property 'focusAdaptiveMinMove'
        QtMocHelpers::PropertyData<uint>(2002, QMetaType::UInt, QMC::DefaultPropertyFlags | QMC::Writable | QMC::StdCppSet, 540),
        // property 'isFocusAdaptiveMinMoveImmutable'
        QtMocHelpers::PropertyData<bool>(2003, QMetaType::Bool, QMC::DefaultPropertyFlags | QMC::Constant),
        // property 'focusAdaptStart'
        QtMocHelpers::PropertyData<bool>(2004, QMetaType::Bool, QMC::DefaultPropertyFlags | QMC::Writable | QMC::StdCppSet, 541),
        // property 'isFocusAdaptStartImmutable'
        QtMocHelpers::PropertyData<bool>(2005, QMetaType::Bool, QMC::DefaultPropertyFlags | QMC::Constant),
        // property 'focusAdaptiveMaxMove'
        QtMocHelpers::PropertyData<uint>(2006, QMetaType::UInt, QMC::DefaultPropertyFlags | QMC::Writable | QMC::StdCppSet, 542),
        // property 'isFocusAdaptiveMaxMoveImmutable'
        QtMocHelpers::PropertyData<bool>(2007, QMetaType::Bool, QMC::DefaultPropertyFlags | QMC::Constant),
        // property 'focusDetection'
        QtMocHelpers::PropertyData<QString>(2008, QMetaType::QString, QMC::DefaultPropertyFlags | QMC::Writable | QMC::StdCppSet, 543),
        // property 'isFocusDetectionImmutable'
        QtMocHelpers::PropertyData<bool>(2009, QMetaType::Bool, QMC::DefaultPropertyFlags | QMC::Constant),
        // property 'focusSEPProfile'
        QtMocHelpers::PropertyData<QString>(2010, QMetaType::QString, QMC::DefaultPropertyFlags | QMC::Writable | QMC::StdCppSet, 544),
        // property 'isFocusSEPProfileImmutable'
        QtMocHelpers::PropertyData<bool>(2011, QMetaType::Bool, QMC::DefaultPropertyFlags | QMC::Constant),
        // property 'focusAlgorithm'
        QtMocHelpers::PropertyData<QString>(2012, QMetaType::QString, QMC::DefaultPropertyFlags | QMC::Writable | QMC::StdCppSet, 545),
        // property 'isFocusAlgorithmImmutable'
        QtMocHelpers::PropertyData<bool>(2013, QMetaType::Bool, QMC::DefaultPropertyFlags | QMC::Constant),
        // property 'focusCurveFit'
        QtMocHelpers::PropertyData<QString>(2014, QMetaType::QString, QMC::DefaultPropertyFlags | QMC::Writable | QMC::StdCppSet, 546),
        // property 'isFocusCurveFitImmutable'
        QtMocHelpers::PropertyData<bool>(2015, QMetaType::Bool, QMC::DefaultPropertyFlags | QMC::Constant),
        // property 'focusStarMeasure'
        QtMocHelpers::PropertyData<QString>(2016, QMetaType::QString, QMC::DefaultPropertyFlags | QMC::Writable | QMC::StdCppSet, 547),
        // property 'isFocusStarMeasureImmutable'
        QtMocHelpers::PropertyData<bool>(2017, QMetaType::Bool, QMC::DefaultPropertyFlags | QMC::Constant),
        // property 'focusStarPSF'
        QtMocHelpers::PropertyData<QString>(2018, QMetaType::QString, QMC::DefaultPropertyFlags | QMC::Writable | QMC::StdCppSet, 548),
        // property 'isFocusStarPSFImmutable'
        QtMocHelpers::PropertyData<bool>(2019, QMetaType::Bool, QMC::DefaultPropertyFlags | QMC::Constant),
        // property 'focusUseWeights'
        QtMocHelpers::PropertyData<bool>(2020, QMetaType::Bool, QMC::DefaultPropertyFlags | QMC::Writable | QMC::StdCppSet, 549),
        // property 'isFocusUseWeightsImmutable'
        QtMocHelpers::PropertyData<bool>(2021, QMetaType::Bool, QMC::DefaultPropertyFlags | QMC::Constant),
        // property 'focusR2Limit'
        QtMocHelpers::PropertyData<double>(2022, QMetaType::Double, QMC::DefaultPropertyFlags | QMC::Writable | QMC::StdCppSet, 550),
        // property 'isFocusR2LimitImmutable'
        QtMocHelpers::PropertyData<bool>(2023, QMetaType::Bool, QMC::DefaultPropertyFlags | QMC::Constant),
        // property 'focusRefineCurveFit'
        QtMocHelpers::PropertyData<bool>(2024, QMetaType::Bool, QMC::DefaultPropertyFlags | QMC::Writable | QMC::StdCppSet, 551),
        // property 'isFocusRefineCurveFitImmutable'
        QtMocHelpers::PropertyData<bool>(2025, QMetaType::Bool, QMC::DefaultPropertyFlags | QMC::Constant),
        // property 'focusFramesCount'
        QtMocHelpers::PropertyData<uint>(2026, QMetaType::UInt, QMC::DefaultPropertyFlags | QMC::Writable | QMC::StdCppSet, 552),
        // property 'isFocusFramesCountImmutable'
        QtMocHelpers::PropertyData<bool>(2027, QMetaType::Bool, QMC::DefaultPropertyFlags | QMC::Constant),
        // property 'focusHFRFramesCount'
        QtMocHelpers::PropertyData<uint>(2028, QMetaType::UInt, QMC::DefaultPropertyFlags | QMC::Writable | QMC::StdCppSet, 553),
        // property 'isFocusHFRFramesCountImmutable'
        QtMocHelpers::PropertyData<bool>(2029, QMetaType::Bool, QMC::DefaultPropertyFlags | QMC::Constant),
        // property 'focusMultiRowAverage'
        QtMocHelpers::PropertyData<int>(2030, QMetaType::Int, QMC::DefaultPropertyFlags | QMC::Writable | QMC::StdCppSet, 554),
        // property 'isFocusMultiRowAverageImmutable'
        QtMocHelpers::PropertyData<bool>(2031, QMetaType::Bool, QMC::DefaultPropertyFlags | QMC::Constant),
        // property 'focusGaussianSigma'
        QtMocHelpers::PropertyData<double>(2032, QMetaType::Double, QMC::DefaultPropertyFlags | QMC::Writable | QMC::StdCppSet, 555),
        // property 'isFocusGaussianSigmaImmutable'
        QtMocHelpers::PropertyData<bool>(2033, QMetaType::Bool, QMC::DefaultPropertyFlags | QMC::Constant),
        // property 'focusThreshold'
        QtMocHelpers::PropertyData<double>(2034, QMetaType::Double, QMC::DefaultPropertyFlags | QMC::Writable | QMC::StdCppSet, 556),
        // property 'isFocusThresholdImmutable'
        QtMocHelpers::PropertyData<bool>(2035, QMetaType::Bool, QMC::DefaultPropertyFlags | QMC::Constant),
        // property 'focusDenoise'
        QtMocHelpers::PropertyData<bool>(2036, QMetaType::Bool, QMC::DefaultPropertyFlags | QMC::Writable | QMC::StdCppSet, 557),
        // property 'isFocusDenoiseImmutable'
        QtMocHelpers::PropertyData<bool>(2037, QMetaType::Bool, QMC::DefaultPropertyFlags | QMC::Constant),
        // property 'focusDonut'
        QtMocHelpers::PropertyData<bool>(2038, QMetaType::Bool, QMC::DefaultPropertyFlags | QMC::Writable | QMC::StdCppSet, 558),
        // property 'isFocusDonutImmutable'
        QtMocHelpers::PropertyData<bool>(2039, QMetaType::Bool, QMC::DefaultPropertyFlags | QMC::Constant),
        // property 'focusTimeDilation'
        QtMocHelpers::PropertyData<double>(2040, QMetaType::Double, QMC::DefaultPropertyFlags | QMC::Writable | QMC::StdCppSet, 559),
        // property 'isFocusTimeDilationImmutable'
        QtMocHelpers::PropertyData<bool>(2041, QMetaType::Bool, QMC::DefaultPropertyFlags | QMC::Constant),
        // property 'focusOutlierRejection'
        QtMocHelpers::PropertyData<double>(2042, QMetaType::Double, QMC::DefaultPropertyFlags | QMC::Writable | QMC::StdCppSet, 560),
        // property 'isFocusOutlierRejectionImmutable'
        QtMocHelpers::PropertyData<bool>(2043, QMetaType::Bool, QMC::DefaultPropertyFlags | QMC::Constant),
        // property 'focusScanStartPos'
        QtMocHelpers::PropertyData<bool>(2044, QMetaType::Bool, QMC::DefaultPropertyFlags | QMC::Writable | QMC::StdCppSet, 561),
        // property 'isFocusScanStartPosImmutable'
        QtMocHelpers::PropertyData<bool>(2045, QMetaType::Bool, QMC::DefaultPropertyFlags | QMC::Constant),
        // property 'focusScanAlwaysOn'
        QtMocHelpers::PropertyData<bool>(2046, QMetaType::Bool, QMC::DefaultPropertyFlags | QMC::Writable | QMC::StdCppSet, 562),
        // property 'isFocusScanAlwaysOnImmutable'
        QtMocHelpers::PropertyData<bool>(2047, QMetaType::Bool, QMC::DefaultPropertyFlags | QMC::Constant),
        // property 'focusScanDatapoints'
        QtMocHelpers::PropertyData<uint>(2048, QMetaType::UInt, QMC::DefaultPropertyFlags | QMC::Writable | QMC::StdCppSet, 563),
        // property 'isFocusScanDatapointsImmutable'
        QtMocHelpers::PropertyData<bool>(2049, QMetaType::Bool, QMC::DefaultPropertyFlags | QMC::Constant),
        // property 'focusScanStepSizeFactor'
        QtMocHelpers::PropertyData<double>(2050, QMetaType::Double, QMC::DefaultPropertyFlags | QMC::Writable | QMC::StdCppSet, 564),
        // property 'isFocusScanStepSizeFactorImmutable'
        QtMocHelpers::PropertyData<bool>(2051, QMetaType::Bool, QMC::DefaultPropertyFlags | QMC::Constant),
        // property 'focusGaussianKernelSize'
        QtMocHelpers::PropertyData<int>(2052, QMetaType::Int, QMC::DefaultPropertyFlags | QMC::Writable | QMC::StdCppSet, 565),
        // property 'isFocusGaussianKernelSizeImmutable'
        QtMocHelpers::PropertyData<bool>(2053, QMetaType::Bool, QMC::DefaultPropertyFlags | QMC::Constant),
        // property 'focusTolerance'
        QtMocHelpers::PropertyData<double>(2054, QMetaType::Double, QMC::DefaultPropertyFlags | QMC::Writable | QMC::StdCppSet, 566),
        // property 'isFocusToleranceImmutable'
        QtMocHelpers::PropertyData<bool>(2055, QMetaType::Bool, QMC::DefaultPropertyFlags | QMC::Constant),
        // property 'focusWalk'
        QtMocHelpers::PropertyData<QString>(2056, QMetaType::QString, QMC::DefaultPropertyFlags | QMC::Writable | QMC::StdCppSet, 567),
        // property 'isFocusWalkImmutable'
        QtMocHelpers::PropertyData<bool>(2057, QMetaType::Bool, QMC::DefaultPropertyFlags | QMC::Constant),
        // property 'focusSettleTime'
        QtMocHelpers::PropertyData<double>(2058, QMetaType::Double, QMC::DefaultPropertyFlags | QMC::Writable | QMC::StdCppSet, 568),
        // property 'isFocusSettleTimeImmutable'
        QtMocHelpers::PropertyData<bool>(2059, QMetaType::Bool, QMC::DefaultPropertyFlags | QMC::Constant),
        // property 'focusTicks'
        QtMocHelpers::PropertyData<uint>(2060, QMetaType::UInt, QMC::DefaultPropertyFlags | QMC::Writable | QMC::StdCppSet, 569),
        // property 'isFocusTicksImmutable'
        QtMocHelpers::PropertyData<bool>(2061, QMetaType::Bool, QMC::DefaultPropertyFlags | QMC::Constant),
        // property 'focusOutSteps'
        QtMocHelpers::PropertyData<double>(2062, QMetaType::Double, QMC::DefaultPropertyFlags | QMC::Writable | QMC::StdCppSet, 570),
        // property 'isFocusOutStepsImmutable'
        QtMocHelpers::PropertyData<bool>(2063, QMetaType::Bool, QMC::DefaultPropertyFlags | QMC::Constant),
        // property 'focusNumSteps'
        QtMocHelpers::PropertyData<uint>(2064, QMetaType::UInt, QMC::DefaultPropertyFlags | QMC::Writable | QMC::StdCppSet, 571),
        // property 'isFocusNumStepsImmutable'
        QtMocHelpers::PropertyData<bool>(2065, QMetaType::Bool, QMC::DefaultPropertyFlags | QMC::Constant),
        // property 'focusMaxTravel'
        QtMocHelpers::PropertyData<uint>(2066, QMetaType::UInt, QMC::DefaultPropertyFlags | QMC::Writable | QMC::StdCppSet, 572),
        // property 'isFocusMaxTravelImmutable'
        QtMocHelpers::PropertyData<bool>(2067, QMetaType::Bool, QMC::DefaultPropertyFlags | QMC::Constant),
        // property 'focusMaxSingleStep'
        QtMocHelpers::PropertyData<uint>(2068, QMetaType::UInt, QMC::DefaultPropertyFlags | QMC::Writable | QMC::StdCppSet, 573),
        // property 'isFocusMaxSingleStepImmutable'
        QtMocHelpers::PropertyData<bool>(2069, QMetaType::Bool, QMC::DefaultPropertyFlags | QMC::Constant),
        // property 'focusBacklash'
        QtMocHelpers::PropertyData<uint>(2070, QMetaType::UInt, QMC::DefaultPropertyFlags | QMC::Writable | QMC::StdCppSet, 574),
        // property 'isFocusBacklashImmutable'
        QtMocHelpers::PropertyData<bool>(2071, QMetaType::Bool, QMC::DefaultPropertyFlags | QMC::Constant),
        // property 'focusAFOverscan'
        QtMocHelpers::PropertyData<uint>(2072, QMetaType::UInt, QMC::DefaultPropertyFlags | QMC::Writable | QMC::StdCppSet, 575),
        // property 'isFocusAFOverscanImmutable'
        QtMocHelpers::PropertyData<bool>(2073, QMetaType::Bool, QMC::DefaultPropertyFlags | QMC::Constant),
        // property 'focusOverscanDelay'
        QtMocHelpers::PropertyData<double>(2074, QMetaType::Double, QMC::DefaultPropertyFlags | QMC::Writable | QMC::StdCppSet, 576),
        // property 'isFocusOverscanDelayImmutable'
        QtMocHelpers::PropertyData<bool>(2075, QMetaType::Bool, QMC::DefaultPropertyFlags | QMC::Constant),
        // property 'focusCaptureTimeout'
        QtMocHelpers::PropertyData<uint>(2076, QMetaType::UInt, QMC::DefaultPropertyFlags | QMC::Writable | QMC::StdCppSet, 577),
        // property 'isFocusCaptureTimeoutImmutable'
        QtMocHelpers::PropertyData<bool>(2077, QMetaType::Bool, QMC::DefaultPropertyFlags | QMC::Constant),
        // property 'focusMotionTimeout'
        QtMocHelpers::PropertyData<uint>(2078, QMetaType::UInt, QMC::DefaultPropertyFlags | QMC::Writable | QMC::StdCppSet, 578),
        // property 'isFocusMotionTimeoutImmutable'
        QtMocHelpers::PropertyData<bool>(2079, QMetaType::Bool, QMC::DefaultPropertyFlags | QMC::Constant),
        // property 'focusCFZAlgorithm'
        QtMocHelpers::PropertyData<QString>(2080, QMetaType::QString, QMC::DefaultPropertyFlags | QMC::Writable | QMC::StdCppSet, 579),
        // property 'isFocusCFZAlgorithmImmutable'
        QtMocHelpers::PropertyData<bool>(2081, QMetaType::Bool, QMC::DefaultPropertyFlags | QMC::Constant),
        // property 'focusCFZTolerance'
        QtMocHelpers::PropertyData<double>(2082, QMetaType::Double, QMC::DefaultPropertyFlags | QMC::Writable | QMC::StdCppSet, 580),
        // property 'isFocusCFZToleranceImmutable'
        QtMocHelpers::PropertyData<bool>(2083, QMetaType::Bool, QMC::DefaultPropertyFlags | QMC::Constant),
        // property 'focusCFZTau'
        QtMocHelpers::PropertyData<double>(2084, QMetaType::Double, QMC::DefaultPropertyFlags | QMC::Writable | QMC::StdCppSet, 581),
        // property 'isFocusCFZTauImmutable'
        QtMocHelpers::PropertyData<bool>(2085, QMetaType::Bool, QMC::DefaultPropertyFlags | QMC::Constant),
        // property 'focusCFZDisplayVCurve'
        QtMocHelpers::PropertyData<bool>(2086, QMetaType::Bool, QMC::DefaultPropertyFlags | QMC::Writable | QMC::StdCppSet, 582),
        // property 'isFocusCFZDisplayVCurveImmutable'
        QtMocHelpers::PropertyData<bool>(2087, QMetaType::Bool, QMC::DefaultPropertyFlags | QMC::Constant),
        // property 'focusCFZWavelength'
        QtMocHelpers::PropertyData<double>(2088, QMetaType::Double, QMC::DefaultPropertyFlags | QMC::Writable | QMC::StdCppSet, 583),
        // property 'isFocusCFZWavelengthImmutable'
        QtMocHelpers::PropertyData<bool>(2089, QMetaType::Bool, QMC::DefaultPropertyFlags | QMC::Constant),
        // property 'focusCFZAperture'
        QtMocHelpers::PropertyData<uint>(2090, QMetaType::UInt, QMC::DefaultPropertyFlags | QMC::Writable | QMC::StdCppSet, 584),
        // property 'isFocusCFZApertureImmutable'
        QtMocHelpers::PropertyData<bool>(2091, QMetaType::Bool, QMC::DefaultPropertyFlags | QMC::Constant),
        // property 'focusCFZFNumber'
        QtMocHelpers::PropertyData<double>(2092, QMetaType::Double, QMC::DefaultPropertyFlags | QMC::Writable | QMC::StdCppSet, 585),
        // property 'isFocusCFZFNumberImmutable'
        QtMocHelpers::PropertyData<bool>(2093, QMetaType::Bool, QMC::DefaultPropertyFlags | QMC::Constant),
        // property 'focusCFZSeeing'
        QtMocHelpers::PropertyData<double>(2094, QMetaType::Double, QMC::DefaultPropertyFlags | QMC::Writable | QMC::StdCppSet, 586),
        // property 'isFocusCFZSeeingImmutable'
        QtMocHelpers::PropertyData<bool>(2095, QMetaType::Bool, QMC::DefaultPropertyFlags | QMC::Constant),
        // property 'focusCFZStepSize'
        QtMocHelpers::PropertyData<double>(2096, QMetaType::Double, QMC::DefaultPropertyFlags | QMC::Writable | QMC::StdCppSet, 587),
        // property 'isFocusCFZStepSizeImmutable'
        QtMocHelpers::PropertyData<bool>(2097, QMetaType::Bool, QMC::DefaultPropertyFlags | QMC::Constant),
        // property 'focusAdvHelpOnlyChanges'
        QtMocHelpers::PropertyData<bool>(2098, QMetaType::Bool, QMC::DefaultPropertyFlags | QMC::Writable | QMC::StdCppSet, 588),
        // property 'isFocusAdvHelpOnlyChangesImmutable'
        QtMocHelpers::PropertyData<bool>(2099, QMetaType::Bool, QMC::DefaultPropertyFlags | QMC::Constant),
        // property 'focusAdvUpdateParams'
        QtMocHelpers::PropertyData<bool>(2100, QMetaType::Bool, QMC::DefaultPropertyFlags | QMC::Writable | QMC::StdCppSet, 589),
        // property 'isFocusAdvUpdateParamsImmutable'
        QtMocHelpers::PropertyData<bool>(2101, QMetaType::Bool, QMC::DefaultPropertyFlags | QMC::Constant),
        // property 'focusAdvFindStars'
        QtMocHelpers::PropertyData<bool>(2102, QMetaType::Bool, QMC::DefaultPropertyFlags | QMC::Writable | QMC::StdCppSet, 590),
        // property 'isFocusAdvFindStarsImmutable'
        QtMocHelpers::PropertyData<bool>(2103, QMetaType::Bool, QMC::DefaultPropertyFlags | QMC::Constant),
        // property 'focusAdvCourseAdj'
        QtMocHelpers::PropertyData<bool>(2104, QMetaType::Bool, QMC::DefaultPropertyFlags | QMC::Writable | QMC::StdCppSet, 591),
        // property 'isFocusAdvCourseAdjImmutable'
        QtMocHelpers::PropertyData<bool>(2105, QMetaType::Bool, QMC::DefaultPropertyFlags | QMC::Constant),
        // property 'focusAdvFineAdj'
        QtMocHelpers::PropertyData<bool>(2106, QMetaType::Bool, QMC::DefaultPropertyFlags | QMC::Writable | QMC::StdCppSet, 592),
        // property 'isFocusAdvFineAdjImmutable'
        QtMocHelpers::PropertyData<bool>(2107, QMetaType::Bool, QMC::DefaultPropertyFlags | QMC::Constant),
        // property 'focusSplitter'
        QtMocHelpers::PropertyData<QString>(2108, QMetaType::QString, QMC::DefaultPropertyFlags | QMC::Writable | QMC::StdCppSet, 593),
        // property 'isFocusSplitterImmutable'
        QtMocHelpers::PropertyData<bool>(2109, QMetaType::Bool, QMC::DefaultPropertyFlags | QMC::Constant),
        // property 'rightLayout'
        QtMocHelpers::PropertyData<QString>(2110, QMetaType::QString, QMC::DefaultPropertyFlags | QMC::Writable | QMC::StdCppSet, 594),
        // property 'isRightLayoutImmutable'
        QtMocHelpers::PropertyData<bool>(2111, QMetaType::Bool, QMC::DefaultPropertyFlags | QMC::Constant),
        // property 'adaptFocusBFO'
        QtMocHelpers::PropertyData<bool>(2112, QMetaType::Bool, QMC::DefaultPropertyFlags | QMC::Writable | QMC::StdCppSet, 595),
        // property 'isAdaptFocusBFOImmutable'
        QtMocHelpers::PropertyData<bool>(2113, QMetaType::Bool, QMC::DefaultPropertyFlags | QMC::Constant),
        // property 'abInsTileSelection'
        QtMocHelpers::PropertyData<QString>(2114, QMetaType::QString, QMC::DefaultPropertyFlags | QMC::Writable | QMC::StdCppSet, 596),
        // property 'isAbInsTileSelectionImmutable'
        QtMocHelpers::PropertyData<bool>(2115, QMetaType::Bool, QMC::DefaultPropertyFlags | QMC::Constant),
        // property 'abInsShowLabels'
        QtMocHelpers::PropertyData<bool>(2116, QMetaType::Bool, QMC::DefaultPropertyFlags | QMC::Writable | QMC::StdCppSet, 597),
        // property 'isAbInsShowLabelsImmutable'
        QtMocHelpers::PropertyData<bool>(2117, QMetaType::Bool, QMC::DefaultPropertyFlags | QMC::Constant),
        // property 'abInsShowCFZ'
        QtMocHelpers::PropertyData<bool>(2118, QMetaType::Bool, QMC::DefaultPropertyFlags | QMC::Writable | QMC::StdCppSet, 598),
        // property 'isAbInsShowCFZImmutable'
        QtMocHelpers::PropertyData<bool>(2119, QMetaType::Bool, QMC::DefaultPropertyFlags | QMC::Constant),
        // property 'abInsOptCentres'
        QtMocHelpers::PropertyData<bool>(2120, QMetaType::Bool, QMC::DefaultPropertyFlags | QMC::Writable | QMC::StdCppSet, 599),
        // property 'isAbInsOptCentresImmutable'
        QtMocHelpers::PropertyData<bool>(2121, QMetaType::Bool, QMC::DefaultPropertyFlags | QMC::Constant),
        // property 'abInsHSplitter'
        QtMocHelpers::PropertyData<QString>(2122, QMetaType::QString, QMC::DefaultPropertyFlags | QMC::Writable | QMC::StdCppSet, 600),
        // property 'isAbInsHSplitterImmutable'
        QtMocHelpers::PropertyData<bool>(2123, QMetaType::Bool, QMC::DefaultPropertyFlags | QMC::Constant),
        // property 'abInsVSplitter'
        QtMocHelpers::PropertyData<QString>(2124, QMetaType::QString, QMC::DefaultPropertyFlags | QMC::Writable | QMC::StdCppSet, 601),
        // property 'isAbInsVSplitterImmutable'
        QtMocHelpers::PropertyData<bool>(2125, QMetaType::Bool, QMC::DefaultPropertyFlags | QMC::Constant),
        // property 'abInsSelection'
        QtMocHelpers::PropertyData<QString>(2126, QMetaType::QString, QMC::DefaultPropertyFlags | QMC::Writable | QMC::StdCppSet, 602),
        // property 'isAbInsSelectionImmutable'
        QtMocHelpers::PropertyData<bool>(2127, QMetaType::Bool, QMC::DefaultPropertyFlags | QMC::Constant),
        // property 'abInsTheme'
        QtMocHelpers::PropertyData<QString>(2128, QMetaType::QString, QMC::DefaultPropertyFlags | QMC::Writable | QMC::StdCppSet, 603),
        // property 'isAbInsThemeImmutable'
        QtMocHelpers::PropertyData<bool>(2129, QMetaType::Bool, QMC::DefaultPropertyFlags | QMC::Constant),
        // property 'abInsLabels'
        QtMocHelpers::PropertyData<bool>(2130, QMetaType::Bool, QMC::DefaultPropertyFlags | QMC::Writable | QMC::StdCppSet, 604),
        // property 'isAbInsLabelsImmutable'
        QtMocHelpers::PropertyData<bool>(2131, QMetaType::Bool, QMC::DefaultPropertyFlags | QMC::Constant),
        // property 'abInsSensor'
        QtMocHelpers::PropertyData<bool>(2132, QMetaType::Bool, QMC::DefaultPropertyFlags | QMC::Writable | QMC::StdCppSet, 605),
        // property 'isAbInsSensorImmutable'
        QtMocHelpers::PropertyData<bool>(2133, QMetaType::Bool, QMC::DefaultPropertyFlags | QMC::Constant),
        // property 'abInsPetzvalWire'
        QtMocHelpers::PropertyData<bool>(2134, QMetaType::Bool, QMC::DefaultPropertyFlags | QMC::Writable | QMC::StdCppSet, 606),
        // property 'isAbInsPetzvalWireImmutable'
        QtMocHelpers::PropertyData<bool>(2135, QMetaType::Bool, QMC::DefaultPropertyFlags | QMC::Constant),
        // property 'abInsPetzvalSurface'
        QtMocHelpers::PropertyData<bool>(2136, QMetaType::Bool, QMC::DefaultPropertyFlags | QMC::Writable | QMC::StdCppSet, 607),
        // property 'isAbInsPetzvalSurfaceImmutable'
        QtMocHelpers::PropertyData<bool>(2137, QMetaType::Bool, QMC::DefaultPropertyFlags | QMC::Constant),
        // property 'tiltPlateType'
        QtMocHelpers::PropertyData<uint>(2138, QMetaType::UInt, QMC::DefaultPropertyFlags | QMC::Writable | QMC::StdCppSet, 608),
        // property 'isTiltPlateTypeImmutable'
        QtMocHelpers::PropertyData<bool>(2139, QMetaType::Bool, QMC::DefaultPropertyFlags | QMC::Constant),
        // property 'tiltRadius'
        QtMocHelpers::PropertyData<double>(2140, QMetaType::Double, QMC::DefaultPropertyFlags | QMC::Writable | QMC::StdCppSet, 609),
        // property 'isTiltRadiusImmutable'
        QtMocHelpers::PropertyData<bool>(2141, QMetaType::Bool, QMC::DefaultPropertyFlags | QMC::Constant),
        // property 'tiltThreadIndex'
        QtMocHelpers::PropertyData<uint>(2142, QMetaType::UInt, QMC::DefaultPropertyFlags | QMC::Writable | QMC::StdCppSet, 610),
        // property 'isTiltThreadIndexImmutable'
        QtMocHelpers::PropertyData<bool>(2143, QMetaType::Bool, QMC::DefaultPropertyFlags | QMC::Constant),
        // property 'tiltScrewPitch'
        QtMocHelpers::PropertyData<double>(2144, QMetaType::Double, QMC::DefaultPropertyFlags | QMC::Writable | QMC::StdCppSet, 611),
        // property 'isTiltScrewPitchImmutable'
        QtMocHelpers::PropertyData<bool>(2145, QMetaType::Bool, QMC::DefaultPropertyFlags | QMC::Constant),
        // property 'tiltRotation'
        QtMocHelpers::PropertyData<double>(2146, QMetaType::Double, QMC::DefaultPropertyFlags | QMC::Writable | QMC::StdCppSet, 612),
        // property 'isTiltRotationImmutable'
        QtMocHelpers::PropertyData<bool>(2147, QMetaType::Bool, QMC::DefaultPropertyFlags | QMC::Constant),
        // property 'tiltMode'
        QtMocHelpers::PropertyData<uint>(2148, QMetaType::UInt, QMC::DefaultPropertyFlags | QMC::Writable | QMC::StdCppSet, 613),
        // property 'isTiltModeImmutable'
        QtMocHelpers::PropertyData<bool>(2149, QMetaType::Bool, QMC::DefaultPropertyFlags | QMC::Constant),
        // property 'tiltPlatePresent'
        QtMocHelpers::PropertyData<bool>(2150, QMetaType::Bool, QMC::DefaultPropertyFlags | QMC::Writable | QMC::StdCppSet, 614),
        // property 'isTiltPlatePresentImmutable'
        QtMocHelpers::PropertyData<bool>(2151, QMetaType::Bool, QMC::DefaultPropertyFlags | QMC::Constant),
        // property 'focusSextractorType'
        QtMocHelpers::PropertyData<uint>(2152, QMetaType::UInt, QMC::DefaultPropertyFlags | QMC::Writable | QMC::StdCppSet, 615),
        // property 'isFocusSextractorTypeImmutable'
        QtMocHelpers::PropertyData<bool>(2153, QMetaType::Bool, QMC::DefaultPropertyFlags | QMC::Constant),
        // property 'focusOptionsProfile'
        QtMocHelpers::PropertyData<uint>(2154, QMetaType::UInt, QMC::DefaultPropertyFlags | QMC::Writable | QMC::StdCppSet, 616),
        // property 'isFocusOptionsProfileImmutable'
        QtMocHelpers::PropertyData<bool>(2155, QMetaType::Bool, QMC::DefaultPropertyFlags | QMC::Constant),
        // property 'hFRSextractorType'
        QtMocHelpers::PropertyData<uint>(2156, QMetaType::UInt, QMC::DefaultPropertyFlags | QMC::Writable | QMC::StdCppSet, 617),
        // property 'isHFRSextractorTypeImmutable'
        QtMocHelpers::PropertyData<bool>(2157, QMetaType::Bool, QMC::DefaultPropertyFlags | QMC::Constant),
        // property 'hFROptionsProfile'
        QtMocHelpers::PropertyData<uint>(2158, QMetaType::UInt, QMC::DefaultPropertyFlags | QMC::Writable | QMC::StdCppSet, 618),
        // property 'isHFROptionsProfileImmutable'
        QtMocHelpers::PropertyData<bool>(2159, QMetaType::Bool, QMC::DefaultPropertyFlags | QMC::Constant),
        // property 'guideSextractorType'
        QtMocHelpers::PropertyData<uint>(2160, QMetaType::UInt, QMC::DefaultPropertyFlags | QMC::Writable | QMC::StdCppSet, 619),
        // property 'isGuideSextractorTypeImmutable'
        QtMocHelpers::PropertyData<bool>(2161, QMetaType::Bool, QMC::DefaultPropertyFlags | QMC::Constant),
        // property 'guideOptionsProfile'
        QtMocHelpers::PropertyData<uint>(2162, QMetaType::UInt, QMC::DefaultPropertyFlags | QMC::Writable | QMC::StdCppSet, 620),
        // property 'isGuideOptionsProfileImmutable'
        QtMocHelpers::PropertyData<bool>(2163, QMetaType::Bool, QMC::DefaultPropertyFlags | QMC::Constant),
        // property 'solveSextractorType'
        QtMocHelpers::PropertyData<uint>(2164, QMetaType::UInt, QMC::DefaultPropertyFlags | QMC::Writable | QMC::StdCppSet, 621),
        // property 'isSolveSextractorTypeImmutable'
        QtMocHelpers::PropertyData<bool>(2165, QMetaType::Bool, QMC::DefaultPropertyFlags | QMC::Constant),
        // property 'solverMode'
        QtMocHelpers::PropertyData<uint>(2166, QMetaType::UInt, QMC::DefaultPropertyFlags | QMC::Writable | QMC::StdCppSet, 622),
        // property 'isSolverModeImmutable'
        QtMocHelpers::PropertyData<bool>(2167, QMetaType::Bool, QMC::DefaultPropertyFlags | QMC::Constant),
        // property 'solverType'
        QtMocHelpers::PropertyData<uint>(2168, QMetaType::UInt, QMC::DefaultPropertyFlags | QMC::Writable | QMC::StdCppSet, 623),
        // property 'isSolverTypeImmutable'
        QtMocHelpers::PropertyData<bool>(2169, QMetaType::Bool, QMC::DefaultPropertyFlags | QMC::Constant),
        // property 'solveOptionsProfile'
        QtMocHelpers::PropertyData<uint>(2170, QMetaType::UInt, QMC::DefaultPropertyFlags | QMC::Writable | QMC::StdCppSet, 624),
        // property 'isSolveOptionsProfileImmutable'
        QtMocHelpers::PropertyData<bool>(2171, QMetaType::Bool, QMC::DefaultPropertyFlags | QMC::Constant),
        // property 'loggerLevel'
        QtMocHelpers::PropertyData<uint>(2172, QMetaType::UInt, QMC::DefaultPropertyFlags | QMC::Writable | QMC::StdCppSet, 625),
        // property 'isLoggerLevelImmutable'
        QtMocHelpers::PropertyData<bool>(2173, QMetaType::Bool, QMC::DefaultPropertyFlags | QMC::Constant),
        // property 'astrometryLogToFile'
        QtMocHelpers::PropertyData<bool>(2174, QMetaType::Bool, QMC::DefaultPropertyFlags | QMC::Writable | QMC::StdCppSet, 626),
        // property 'isAstrometryLogToFileImmutable'
        QtMocHelpers::PropertyData<bool>(2175, QMetaType::Bool, QMC::DefaultPropertyFlags | QMC::Constant),
        // property 'astrometryLogFilepath'
        QtMocHelpers::PropertyData<QString>(2176, QMetaType::QString, QMC::DefaultPropertyFlags | QMC::Writable | QMC::StdCppSet, 627),
        // property 'isAstrometryLogFilepathImmutable'
        QtMocHelpers::PropertyData<bool>(2177, QMetaType::Bool, QMC::DefaultPropertyFlags | QMC::Constant),
        // property 'astrometryIndexFolderList'
        QtMocHelpers::PropertyData<QStringList>(2178, QMetaType::QStringList, QMC::DefaultPropertyFlags | QMC::Writable | QMC::StdCppSet, 628),
        // property 'isAstrometryIndexFolderListImmutable'
        QtMocHelpers::PropertyData<bool>(2179, QMetaType::Bool, QMC::DefaultPropertyFlags | QMC::Constant),
        // property 'alignExposure'
        QtMocHelpers::PropertyData<double>(2180, QMetaType::Double, QMC::DefaultPropertyFlags | QMC::Writable | QMC::StdCppSet, 629),
        // property 'isAlignExposureImmutable'
        QtMocHelpers::PropertyData<bool>(2181, QMetaType::Bool, QMC::DefaultPropertyFlags | QMC::Constant),
        // property 'alignBinning'
        QtMocHelpers::PropertyData<QString>(2182, QMetaType::QString, QMC::DefaultPropertyFlags | QMC::Writable | QMC::StdCppSet, 630),
        // property 'isAlignBinningImmutable'
        QtMocHelpers::PropertyData<bool>(2183, QMetaType::Bool, QMC::DefaultPropertyFlags | QMC::Constant),
        // property 'alignGain'
        QtMocHelpers::PropertyData<double>(2184, QMetaType::Double, QMC::DefaultPropertyFlags | QMC::Writable | QMC::StdCppSet, 631),
        // property 'isAlignGainImmutable'
        QtMocHelpers::PropertyData<bool>(2185, QMetaType::Bool, QMC::DefaultPropertyFlags | QMC::Constant),
        // property 'alignISO'
        QtMocHelpers::PropertyData<double>(2186, QMetaType::Double, QMC::DefaultPropertyFlags | QMC::Writable | QMC::StdCppSet, 632),
        // property 'isAlignISOImmutable'
        QtMocHelpers::PropertyData<bool>(2187, QMetaType::Bool, QMC::DefaultPropertyFlags | QMC::Constant),
        // property 'alignDarkFrame'
        QtMocHelpers::PropertyData<bool>(2188, QMetaType::Bool, QMC::DefaultPropertyFlags | QMC::Writable | QMC::StdCppSet, 633),
        // property 'isAlignDarkFrameImmutable'
        QtMocHelpers::PropertyData<bool>(2189, QMetaType::Bool, QMC::DefaultPropertyFlags | QMC::Constant),
        // property 'alignFilter'
        QtMocHelpers::PropertyData<QString>(2190, QMetaType::QString, QMC::DefaultPropertyFlags | QMC::Writable | QMC::StdCppSet, 634),
        // property 'isAlignFilterImmutable'
        QtMocHelpers::PropertyData<bool>(2191, QMetaType::Bool, QMC::DefaultPropertyFlags | QMC::Constant),
        // property 'alignUseCurrentFilter'
        QtMocHelpers::PropertyData<bool>(2192, QMetaType::Bool, QMC::DefaultPropertyFlags | QMC::Writable | QMC::StdCppSet, 635),
        // property 'isAlignUseCurrentFilterImmutable'
        QtMocHelpers::PropertyData<bool>(2193, QMetaType::Bool, QMC::DefaultPropertyFlags | QMC::Constant),
        // property 'astrometryUseRotator'
        QtMocHelpers::PropertyData<bool>(2194, QMetaType::Bool, QMC::DefaultPropertyFlags | QMC::Writable | QMC::StdCppSet, 636),
        // property 'isAstrometryUseRotatorImmutable'
        QtMocHelpers::PropertyData<bool>(2195, QMetaType::Bool, QMC::DefaultPropertyFlags | QMC::Constant),
        // property 'astrometryRotatorThreshold'
        QtMocHelpers::PropertyData<double>(2196, QMetaType::Double, QMC::DefaultPropertyFlags | QMC::Writable | QMC::StdCppSet, 637),
        // property 'isAstrometryRotatorThresholdImmutable'
        QtMocHelpers::PropertyData<bool>(2197, QMetaType::Bool, QMC::DefaultPropertyFlags | QMC::Constant),
        // property 'astrometryFlipRotationAllowed'
        QtMocHelpers::PropertyData<bool>(2198, QMetaType::Bool, QMC::DefaultPropertyFlags | QMC::Writable | QMC::StdCppSet, 638),
        // property 'isAstrometryFlipRotationAllowedImmutable'
        QtMocHelpers::PropertyData<bool>(2199, QMetaType::Bool, QMC::DefaultPropertyFlags | QMC::Constant),
        // property 'rotatorParityReversed'
        QtMocHelpers::PropertyData<bool>(2200, QMetaType::Bool, QMC::DefaultPropertyFlags | QMC::Writable | QMC::StdCppSet, 639),
        // property 'isRotatorParityReversedImmutable'
        QtMocHelpers::PropertyData<bool>(2201, QMetaType::Bool, QMC::DefaultPropertyFlags | QMC::Constant),
        // property 'astrometrySolverWCS'
        QtMocHelpers::PropertyData<bool>(2202, QMetaType::Bool, QMC::DefaultPropertyFlags | QMC::Writable | QMC::StdCppSet, 640),
        // property 'isAstrometrySolverWCSImmutable'
        QtMocHelpers::PropertyData<bool>(2203, QMetaType::Bool, QMC::DefaultPropertyFlags | QMC::Constant),
        // property 'astrometrySolverOverlay'
        QtMocHelpers::PropertyData<bool>(2204, QMetaType::Bool, QMC::DefaultPropertyFlags | QMC::Writable | QMC::StdCppSet, 641),
        // property 'isAstrometrySolverOverlayImmutable'
        QtMocHelpers::PropertyData<bool>(2205, QMetaType::Bool, QMC::DefaultPropertyFlags | QMC::Constant),
        // property 'astrometryDifferentialSlewing'
        QtMocHelpers::PropertyData<bool>(2206, QMetaType::Bool, QMC::DefaultPropertyFlags | QMC::Writable | QMC::StdCppSet, 642),
        // property 'isAstrometryDifferentialSlewingImmutable'
        QtMocHelpers::PropertyData<bool>(2207, QMetaType::Bool, QMC::DefaultPropertyFlags | QMC::Constant),
        // property 'alignAccuracyThreshold'
        QtMocHelpers::PropertyData<uint>(2208, QMetaType::UInt, QMC::DefaultPropertyFlags | QMC::Writable | QMC::StdCppSet, 643),
        // property 'isAlignAccuracyThresholdImmutable'
        QtMocHelpers::PropertyData<bool>(2209, QMetaType::Bool, QMC::DefaultPropertyFlags | QMC::Constant),
        // property 'alignSettlingTime'
        QtMocHelpers::PropertyData<uint>(2210, QMetaType::UInt, QMC::DefaultPropertyFlags | QMC::Writable | QMC::StdCppSet, 644),
        // property 'isAlignSettlingTimeImmutable'
        QtMocHelpers::PropertyData<bool>(2211, QMetaType::Bool, QMC::DefaultPropertyFlags | QMC::Constant),
        // property 'astrometryUseNoFITS2FITS'
        QtMocHelpers::PropertyData<bool>(2212, QMetaType::Bool, QMC::DefaultPropertyFlags | QMC::Writable | QMC::StdCppSet, 645),
        // property 'isAstrometryUseNoFITS2FITSImmutable'
        QtMocHelpers::PropertyData<bool>(2213, QMetaType::Bool, QMC::DefaultPropertyFlags | QMC::Constant),
        // property 'astrometryUseResort'
        QtMocHelpers::PropertyData<bool>(2214, QMetaType::Bool, QMC::DefaultPropertyFlags | QMC::Writable | QMC::StdCppSet, 646),
        // property 'isAstrometryUseResortImmutable'
        QtMocHelpers::PropertyData<bool>(2215, QMetaType::Bool, QMC::DefaultPropertyFlags | QMC::Constant),
        // property 'astrometryUseNoVerify'
        QtMocHelpers::PropertyData<bool>(2216, QMetaType::Bool, QMC::DefaultPropertyFlags | QMC::Writable | QMC::StdCppSet, 647),
        // property 'isAstrometryUseNoVerifyImmutable'
        QtMocHelpers::PropertyData<bool>(2217, QMetaType::Bool, QMC::DefaultPropertyFlags | QMC::Constant),
        // property 'astrometryUseImageScale'
        QtMocHelpers::PropertyData<bool>(2218, QMetaType::Bool, QMC::DefaultPropertyFlags | QMC::Writable | QMC::StdCppSet, 648),
        // property 'isAstrometryUseImageScaleImmutable'
        QtMocHelpers::PropertyData<bool>(2219, QMetaType::Bool, QMC::DefaultPropertyFlags | QMC::Constant),
        // property 'astrometryImageScaleLow'
        QtMocHelpers::PropertyData<double>(2220, QMetaType::Double, QMC::DefaultPropertyFlags | QMC::Writable | QMC::StdCppSet, 649),
        // property 'isAstrometryImageScaleLowImmutable'
        QtMocHelpers::PropertyData<bool>(2221, QMetaType::Bool, QMC::DefaultPropertyFlags | QMC::Constant),
        // property 'astrometryImageScaleHigh'
        QtMocHelpers::PropertyData<double>(2222, QMetaType::Double, QMC::DefaultPropertyFlags | QMC::Writable | QMC::StdCppSet, 650),
        // property 'isAstrometryImageScaleHighImmutable'
        QtMocHelpers::PropertyData<bool>(2223, QMetaType::Bool, QMC::DefaultPropertyFlags | QMC::Constant),
        // property 'astrometryAutoUpdateImageScale'
        QtMocHelpers::PropertyData<bool>(2224, QMetaType::Bool, QMC::DefaultPropertyFlags | QMC::Writable | QMC::StdCppSet, 651),
        // property 'isAstrometryAutoUpdateImageScaleImmutable'
        QtMocHelpers::PropertyData<bool>(2225, QMetaType::Bool, QMC::DefaultPropertyFlags | QMC::Constant),
        // property 'astrometryImageScaleUnits'
        QtMocHelpers::PropertyData<uint>(2226, QMetaType::UInt, QMC::DefaultPropertyFlags | QMC::Writable | QMC::StdCppSet, 652),
        // property 'isAstrometryImageScaleUnitsImmutable'
        QtMocHelpers::PropertyData<bool>(2227, QMetaType::Bool, QMC::DefaultPropertyFlags | QMC::Constant),
        // property 'astrometryUseDownsample'
        QtMocHelpers::PropertyData<bool>(2228, QMetaType::Bool, QMC::DefaultPropertyFlags | QMC::Writable | QMC::StdCppSet, 653),
        // property 'isAstrometryUseDownsampleImmutable'
        QtMocHelpers::PropertyData<bool>(2229, QMetaType::Bool, QMC::DefaultPropertyFlags | QMC::Constant),
        // property 'astrometryDownsample'
        QtMocHelpers::PropertyData<uint>(2230, QMetaType::UInt, QMC::DefaultPropertyFlags | QMC::Writable | QMC::StdCppSet, 654),
        // property 'isAstrometryDownsampleImmutable'
        QtMocHelpers::PropertyData<bool>(2231, QMetaType::Bool, QMC::DefaultPropertyFlags | QMC::Constant),
        // property 'astrometryAutoDownsample'
        QtMocHelpers::PropertyData<bool>(2232, QMetaType::Bool, QMC::DefaultPropertyFlags | QMC::Writable | QMC::StdCppSet, 655),
        // property 'isAstrometryAutoDownsampleImmutable'
        QtMocHelpers::PropertyData<bool>(2233, QMetaType::Bool, QMC::DefaultPropertyFlags | QMC::Constant),
        // property 'astrometryDynamicThreshold'
        QtMocHelpers::PropertyData<bool>(2234, QMetaType::Bool, QMC::DefaultPropertyFlags | QMC::Writable | QMC::StdCppSet, 656),
        // property 'isAstrometryDynamicThresholdImmutable'
        QtMocHelpers::PropertyData<bool>(2235, QMetaType::Bool, QMC::DefaultPropertyFlags | QMC::Constant),
        // property 'astrometryUsePosition'
        QtMocHelpers::PropertyData<bool>(2236, QMetaType::Bool, QMC::DefaultPropertyFlags | QMC::Writable | QMC::StdCppSet, 657),
        // property 'isAstrometryUsePositionImmutable'
        QtMocHelpers::PropertyData<bool>(2237, QMetaType::Bool, QMC::DefaultPropertyFlags | QMC::Constant),
        // property 'astrometryPositionRA'
        QtMocHelpers::PropertyData<double>(2238, QMetaType::Double, QMC::DefaultPropertyFlags | QMC::Writable | QMC::StdCppSet, 658),
        // property 'isAstrometryPositionRAImmutable'
        QtMocHelpers::PropertyData<bool>(2239, QMetaType::Bool, QMC::DefaultPropertyFlags | QMC::Constant),
        // property 'astrometryPositionDE'
        QtMocHelpers::PropertyData<double>(2240, QMetaType::Double, QMC::DefaultPropertyFlags | QMC::Writable | QMC::StdCppSet, 659),
        // property 'isAstrometryPositionDEImmutable'
        QtMocHelpers::PropertyData<bool>(2241, QMetaType::Bool, QMC::DefaultPropertyFlags | QMC::Constant),
        // property 'astrometryAutoUpdatePosition'
        QtMocHelpers::PropertyData<bool>(2242, QMetaType::Bool, QMC::DefaultPropertyFlags | QMC::Writable | QMC::StdCppSet, 660),
        // property 'isAstrometryAutoUpdatePositionImmutable'
        QtMocHelpers::PropertyData<bool>(2243, QMetaType::Bool, QMC::DefaultPropertyFlags | QMC::Constant),
        // property 'astrometryRadius'
        QtMocHelpers::PropertyData<double>(2244, QMetaType::Double, QMC::DefaultPropertyFlags | QMC::Writable | QMC::StdCppSet, 661),
        // property 'isAstrometryRadiusImmutable'
        QtMocHelpers::PropertyData<bool>(2245, QMetaType::Bool, QMC::DefaultPropertyFlags | QMC::Constant),
        // property 'astrometryDetectParity'
        QtMocHelpers::PropertyData<bool>(2246, QMetaType::Bool, QMC::DefaultPropertyFlags | QMC::Writable | QMC::StdCppSet, 662),
        // property 'isAstrometryDetectParityImmutable'
        QtMocHelpers::PropertyData<bool>(2247, QMetaType::Bool, QMC::DefaultPropertyFlags | QMC::Constant),
        // property 'astrometryCustomOptions'
        QtMocHelpers::PropertyData<QString>(2248, QMetaType::QString, QMC::DefaultPropertyFlags | QMC::Writable | QMC::StdCppSet, 663),
        // property 'isAstrometryCustomOptionsImmutable'
        QtMocHelpers::PropertyData<bool>(2249, QMetaType::Bool, QMC::DefaultPropertyFlags | QMC::Constant),
        // property 'astrometrySolverBinary'
        QtMocHelpers::PropertyData<QString>(2250, QMetaType::QString, QMC::DefaultPropertyFlags | QMC::Writable | QMC::StdCppSet, 664),
        // property 'isAstrometrySolverBinaryImmutable'
        QtMocHelpers::PropertyData<bool>(2251, QMetaType::Bool, QMC::DefaultPropertyFlags | QMC::Constant),
        // property 'astrometryWCSInfo'
        QtMocHelpers::PropertyData<QString>(2252, QMetaType::QString, QMC::DefaultPropertyFlags | QMC::Writable | QMC::StdCppSet, 665),
        // property 'isAstrometryWCSInfoImmutable'
        QtMocHelpers::PropertyData<bool>(2253, QMetaType::Bool, QMC::DefaultPropertyFlags | QMC::Constant),
        // property 'astrometryConfFile'
        QtMocHelpers::PropertyData<QString>(2254, QMetaType::QString, QMC::DefaultPropertyFlags | QMC::Writable | QMC::StdCppSet, 666),
        // property 'isAstrometryConfFileImmutable'
        QtMocHelpers::PropertyData<bool>(2255, QMetaType::Bool, QMC::DefaultPropertyFlags | QMC::Constant),
        // property 'sextractorBinary'
        QtMocHelpers::PropertyData<QString>(2256, QMetaType::QString, QMC::DefaultPropertyFlags | QMC::Writable | QMC::StdCppSet, 667),
        // property 'isSextractorBinaryImmutable'
        QtMocHelpers::PropertyData<bool>(2257, QMetaType::Bool, QMC::DefaultPropertyFlags | QMC::Constant),
        // property 'watneyBinary'
        QtMocHelpers::PropertyData<QString>(2258, QMetaType::QString, QMC::DefaultPropertyFlags | QMC::Writable | QMC::StdCppSet, 668),
        // property 'isWatneyBinaryImmutable'
        QtMocHelpers::PropertyData<bool>(2259, QMetaType::Bool, QMC::DefaultPropertyFlags | QMC::Constant),
        // property 'astrometryAPIKey'
        QtMocHelpers::PropertyData<QString>(2260, QMetaType::QString, QMC::DefaultPropertyFlags | QMC::Writable | QMC::StdCppSet, 669),
        // property 'isAstrometryAPIKeyImmutable'
        QtMocHelpers::PropertyData<bool>(2261, QMetaType::Bool, QMC::DefaultPropertyFlags | QMC::Constant),
        // property 'astrometryAPIURL'
        QtMocHelpers::PropertyData<QString>(2262, QMetaType::QString, QMC::DefaultPropertyFlags | QMC::Writable | QMC::StdCppSet, 670),
        // property 'isAstrometryAPIURLImmutable'
        QtMocHelpers::PropertyData<bool>(2263, QMetaType::Bool, QMC::DefaultPropertyFlags | QMC::Constant),
        // property 'astrometryUseJPEG'
        QtMocHelpers::PropertyData<bool>(2264, QMetaType::Bool, QMC::DefaultPropertyFlags | QMC::Writable | QMC::StdCppSet, 671),
        // property 'isAstrometryUseJPEGImmutable'
        QtMocHelpers::PropertyData<bool>(2265, QMetaType::Bool, QMC::DefaultPropertyFlags | QMC::Constant),
        // property 'astrometryTimeout'
        QtMocHelpers::PropertyData<uint>(2266, QMetaType::UInt, QMC::DefaultPropertyFlags | QMC::Writable | QMC::StdCppSet, 672),
        // property 'isAstrometryTimeoutImmutable'
        QtMocHelpers::PropertyData<bool>(2267, QMetaType::Bool, QMC::DefaultPropertyFlags | QMC::Constant),
        // property 'pAHMountSpeed'
        QtMocHelpers::PropertyData<QString>(2268, QMetaType::QString, QMC::DefaultPropertyFlags | QMC::Writable | QMC::StdCppSet, 673),
        // property 'isPAHMountSpeedImmutable'
        QtMocHelpers::PropertyData<bool>(2269, QMetaType::Bool, QMC::DefaultPropertyFlags | QMC::Constant),
        // property 'pAHRotaion'
        QtMocHelpers::PropertyData<double>(2270, QMetaType::Double, QMC::DefaultPropertyFlags | QMC::Writable | QMC::StdCppSet, 674),
        // property 'isPAHRotaionImmutable'
        QtMocHelpers::PropertyData<bool>(2271, QMetaType::Bool, QMC::DefaultPropertyFlags | QMC::Constant),
        // property 'pAHRefreshAlgorithm'
        QtMocHelpers::PropertyData<QString>(2272, QMetaType::QString, QMC::DefaultPropertyFlags | QMC::Writable | QMC::StdCppSet, 675),
        // property 'isPAHRefreshAlgorithmImmutable'
        QtMocHelpers::PropertyData<bool>(2273, QMetaType::Bool, QMC::DefaultPropertyFlags | QMC::Constant),
        // property 'pAHDirection'
        QtMocHelpers::PropertyData<QString>(2274, QMetaType::QString, QMC::DefaultPropertyFlags | QMC::Writable | QMC::StdCppSet, 676),
        // property 'isPAHDirectionImmutable'
        QtMocHelpers::PropertyData<bool>(2275, QMetaType::Bool, QMC::DefaultPropertyFlags | QMC::Constant),
        // property 'pAHAutoPark'
        QtMocHelpers::PropertyData<bool>(2276, QMetaType::Bool, QMC::DefaultPropertyFlags | QMC::Writable | QMC::StdCppSet, 677),
        // property 'isPAHAutoParkImmutable'
        QtMocHelpers::PropertyData<bool>(2277, QMetaType::Bool, QMC::DefaultPropertyFlags | QMC::Constant),
        // property 'pAHManualSlew'
        QtMocHelpers::PropertyData<bool>(2278, QMetaType::Bool, QMC::DefaultPropertyFlags | QMC::Writable | QMC::StdCppSet, 678),
        // property 'isPAHManualSlewImmutable'
        QtMocHelpers::PropertyData<bool>(2279, QMetaType::Bool, QMC::DefaultPropertyFlags | QMC::Constant),
        // property 'pAHExposure'
        QtMocHelpers::PropertyData<double>(2280, QMetaType::Double, QMC::DefaultPropertyFlags | QMC::Writable | QMC::StdCppSet, 679),
        // property 'isPAHExposureImmutable'
        QtMocHelpers::PropertyData<bool>(2281, QMetaType::Bool, QMC::DefaultPropertyFlags | QMC::Constant),
        // property 'pAHAutoPACCorrection'
        QtMocHelpers::PropertyData<bool>(2282, QMetaType::Bool, QMC::DefaultPropertyFlags | QMC::Writable | QMC::StdCppSet, 680),
        // property 'isPAHAutoPACCorrectionImmutable'
        QtMocHelpers::PropertyData<bool>(2283, QMetaType::Bool, QMC::DefaultPropertyFlags | QMC::Constant),
        // property 'pAHAutoChangeDirection'
        QtMocHelpers::PropertyData<bool>(2284, QMetaType::Bool, QMC::DefaultPropertyFlags | QMC::Writable | QMC::StdCppSet, 681),
        // property 'isPAHAutoChangeDirectionImmutable'
        QtMocHelpers::PropertyData<bool>(2285, QMetaType::Bool, QMC::DefaultPropertyFlags | QMC::Constant),
        // property 'pAHSuccessThreshold'
        QtMocHelpers::PropertyData<double>(2286, QMetaType::Double, QMC::DefaultPropertyFlags | QMC::Writable | QMC::StdCppSet, 682),
        // property 'isPAHSuccessThresholdImmutable'
        QtMocHelpers::PropertyData<bool>(2287, QMetaType::Bool, QMC::DefaultPropertyFlags | QMC::Constant),
        // property 'pAHCorrectionTimeout'
        QtMocHelpers::PropertyData<uint>(2288, QMetaType::UInt, QMC::DefaultPropertyFlags | QMC::Writable | QMC::StdCppSet, 683),
        // property 'isPAHCorrectionTimeoutImmutable'
        QtMocHelpers::PropertyData<bool>(2289, QMetaType::Bool, QMC::DefaultPropertyFlags | QMC::Constant),
        // property 'guideExposure'
        QtMocHelpers::PropertyData<double>(2290, QMetaType::Double, QMC::DefaultPropertyFlags | QMC::Writable | QMC::StdCppSet, 684),
        // property 'isGuideExposureImmutable'
        QtMocHelpers::PropertyData<bool>(2291, QMetaType::Bool, QMC::DefaultPropertyFlags | QMC::Constant),
        // property 'guideDelay'
        QtMocHelpers::PropertyData<double>(2292, QMetaType::Double, QMC::DefaultPropertyFlags | QMC::Writable | QMC::StdCppSet, 685),
        // property 'isGuideDelayImmutable'
        QtMocHelpers::PropertyData<bool>(2293, QMetaType::Bool, QMC::DefaultPropertyFlags | QMC::Constant),
        // property 'guiderType'
        QtMocHelpers::PropertyData<uint>(2294, QMetaType::UInt, QMC::DefaultPropertyFlags | QMC::Writable | QMC::StdCppSet, 686),
        // property 'isGuiderTypeImmutable'
        QtMocHelpers::PropertyData<bool>(2295, QMetaType::Bool, QMC::DefaultPropertyFlags | QMC::Constant),
        // property 'guideAlgorithm'
        QtMocHelpers::PropertyData<uint>(2296, QMetaType::UInt, QMC::DefaultPropertyFlags | QMC::Writable | QMC::StdCppSet, 687),
        // property 'isGuideAlgorithmImmutable'
        QtMocHelpers::PropertyData<bool>(2297, QMetaType::Bool, QMC::DefaultPropertyFlags | QMC::Constant),
        // property 'rAGuidePulseAlgorithm'
        QtMocHelpers::PropertyData<uint>(2298, QMetaType::UInt, QMC::DefaultPropertyFlags | QMC::Writable | QMC::StdCppSet, 688),
        // property 'isRAGuidePulseAlgorithmImmutable'
        QtMocHelpers::PropertyData<bool>(2299, QMetaType::Bool, QMC::DefaultPropertyFlags | QMC::Constant),
        // property 'dECGuidePulseAlgorithm'
        QtMocHelpers::PropertyData<uint>(2300, QMetaType::UInt, QMC::DefaultPropertyFlags | QMC::Writable | QMC::StdCppSet, 689),
        // property 'isDECGuidePulseAlgorithmImmutable'
        QtMocHelpers::PropertyData<bool>(2301, QMetaType::Bool, QMC::DefaultPropertyFlags | QMC::Constant),
        // property 'aIGuiderWeightsFile'
        QtMocHelpers::PropertyData<QUrl>(2302, 0x80000000 | 2303, QMC::DefaultPropertyFlags | QMC::Writable | QMC::EnumOrFlag | QMC::StdCppSet, 690),
        // property 'isAIGuiderWeightsFileImmutable'
        QtMocHelpers::PropertyData<bool>(2304, QMetaType::Bool, QMC::DefaultPropertyFlags | QMC::Constant),
        // property 'aIPredictionGain'
        QtMocHelpers::PropertyData<double>(2305, QMetaType::Double, QMC::DefaultPropertyFlags | QMC::Writable | QMC::StdCppSet, 691),
        // property 'isAIPredictionGainImmutable'
        QtMocHelpers::PropertyData<bool>(2306, QMetaType::Bool, QMC::DefaultPropertyFlags | QMC::Constant),
        // property 'aIProportionalBackoff'
        QtMocHelpers::PropertyData<bool>(2307, QMetaType::Bool, QMC::DefaultPropertyFlags | QMC::Writable | QMC::StdCppSet, 692),
        // property 'isAIProportionalBackoffImmutable'
        QtMocHelpers::PropertyData<bool>(2308, QMetaType::Bool, QMC::DefaultPropertyFlags | QMC::Constant),
        // property 'aIPIDAutoTune'
        QtMocHelpers::PropertyData<bool>(2309, QMetaType::Bool, QMC::DefaultPropertyFlags | QMC::Writable | QMC::StdCppSet, 693),
        // property 'isAIPIDAutoTuneImmutable'
        QtMocHelpers::PropertyData<bool>(2310, QMetaType::Bool, QMC::DefaultPropertyFlags | QMC::Constant),
        // property 'aIShadowMode'
        QtMocHelpers::PropertyData<bool>(2311, QMetaType::Bool, QMC::DefaultPropertyFlags | QMC::Writable | QMC::StdCppSet, 694),
        // property 'isAIShadowModeImmutable'
        QtMocHelpers::PropertyData<bool>(2312, QMetaType::Bool, QMC::DefaultPropertyFlags | QMC::Constant),
        // property 'pHD2Host'
        QtMocHelpers::PropertyData<QString>(2313, QMetaType::QString, QMC::DefaultPropertyFlags | QMC::Writable | QMC::StdCppSet, 695),
        // property 'isPHD2HostImmutable'
        QtMocHelpers::PropertyData<bool>(2314, QMetaType::Bool, QMC::DefaultPropertyFlags | QMC::Constant),
        // property 'pHD2Port'
        QtMocHelpers::PropertyData<uint>(2315, QMetaType::UInt, QMC::DefaultPropertyFlags | QMC::Writable | QMC::StdCppSet, 696),
        // property 'isPHD2PortImmutable'
        QtMocHelpers::PropertyData<bool>(2316, QMetaType::Bool, QMC::DefaultPropertyFlags | QMC::Constant),
        // property 'linGuiderHost'
        QtMocHelpers::PropertyData<QString>(2317, QMetaType::QString, QMC::DefaultPropertyFlags | QMC::Writable | QMC::StdCppSet, 697),
        // property 'isLinGuiderHostImmutable'
        QtMocHelpers::PropertyData<bool>(2318, QMetaType::Bool, QMC::DefaultPropertyFlags | QMC::Constant),
        // property 'linGuiderPort'
        QtMocHelpers::PropertyData<uint>(2319, QMetaType::UInt, QMC::DefaultPropertyFlags | QMC::Writable | QMC::StdCppSet, 698),
        // property 'isLinGuiderPortImmutable'
        QtMocHelpers::PropertyData<bool>(2320, QMetaType::Bool, QMC::DefaultPropertyFlags | QMC::Constant),
        // property 'calibrationPulseDuration'
        QtMocHelpers::PropertyData<uint>(2321, QMetaType::UInt, QMC::DefaultPropertyFlags | QMC::Writable | QMC::StdCppSet, 699),
        // property 'isCalibrationPulseDurationImmutable'
        QtMocHelpers::PropertyData<bool>(2322, QMetaType::Bool, QMC::DefaultPropertyFlags | QMC::Constant),
        // property 'calibrationMaxMove'
        QtMocHelpers::PropertyData<uint>(2323, QMetaType::UInt, QMC::DefaultPropertyFlags | QMC::Writable | QMC::StdCppSet, 700),
        // property 'isCalibrationMaxMoveImmutable'
        QtMocHelpers::PropertyData<bool>(2324, QMetaType::Bool, QMC::DefaultPropertyFlags | QMC::Constant),
        // property 'guideSquareSize'
        QtMocHelpers::PropertyData<QString>(2325, QMetaType::QString, QMC::DefaultPropertyFlags | QMC::Writable | QMC::StdCppSet, 701),
        // property 'isGuideSquareSizeImmutable'
        QtMocHelpers::PropertyData<bool>(2326, QMetaType::Bool, QMC::DefaultPropertyFlags | QMC::Constant),
        // property 'guideBinning'
        QtMocHelpers::PropertyData<QString>(2327, QMetaType::QString, QMC::DefaultPropertyFlags | QMC::Writable | QMC::StdCppSet, 702),
        // property 'isGuideBinningImmutable'
        QtMocHelpers::PropertyData<bool>(2328, QMetaType::Bool, QMC::DefaultPropertyFlags | QMC::Constant),
        // property 'guideAutoStar'
        QtMocHelpers::PropertyData<bool>(2329, QMetaType::Bool, QMC::DefaultPropertyFlags | QMC::Writable | QMC::StdCppSet, 703),
        // property 'isGuideAutoStarImmutable'
        QtMocHelpers::PropertyData<bool>(2330, QMetaType::Bool, QMC::DefaultPropertyFlags | QMC::Constant),
        // property 'guideShowFrame'
        QtMocHelpers::PropertyData<bool>(2331, QMetaType::Bool, QMC::DefaultPropertyFlags | QMC::Writable | QMC::StdCppSet, 704),
        // property 'isGuideShowFrameImmutable'
        QtMocHelpers::PropertyData<bool>(2332, QMetaType::Bool, QMC::DefaultPropertyFlags | QMC::Constant),
        // property 'guideAutoSquareSizeEnabled'
        QtMocHelpers::PropertyData<bool>(2333, QMetaType::Bool, QMC::DefaultPropertyFlags | QMC::Writable | QMC::StdCppSet, 705),
        // property 'isGuideAutoSquareSizeEnabledImmutable'
        QtMocHelpers::PropertyData<bool>(2334, QMetaType::Bool, QMC::DefaultPropertyFlags | QMC::Constant),
        // property 'autoModeIterations'
        QtMocHelpers::PropertyData<uint>(2335, QMetaType::UInt, QMC::DefaultPropertyFlags | QMC::Writable | QMC::StdCppSet, 706),
        // property 'isAutoModeIterationsImmutable'
        QtMocHelpers::PropertyData<bool>(2336, QMetaType::Bool, QMC::DefaultPropertyFlags | QMC::Constant),
        // property 'guideLostStarTimeout'
        QtMocHelpers::PropertyData<uint>(2337, QMetaType::UInt, QMC::DefaultPropertyFlags | QMC::Writable | QMC::StdCppSet, 707),
        // property 'isGuideLostStarTimeoutImmutable'
        QtMocHelpers::PropertyData<bool>(2338, QMetaType::Bool, QMC::DefaultPropertyFlags | QMC::Constant),
        // property 'guideCalibrationTimeout'
        QtMocHelpers::PropertyData<uint>(2339, QMetaType::UInt, QMC::DefaultPropertyFlags | QMC::Writable | QMC::StdCppSet, 708),
        // property 'isGuideCalibrationTimeoutImmutable'
        QtMocHelpers::PropertyData<bool>(2340, QMetaType::Bool, QMC::DefaultPropertyFlags | QMC::Constant),
        // property 'guideMaxDeltaRMS'
        QtMocHelpers::PropertyData<double>(2341, QMetaType::Double, QMC::DefaultPropertyFlags | QMC::Writable | QMC::StdCppSet, 709),
        // property 'isGuideMaxDeltaRMSImmutable'
        QtMocHelpers::PropertyData<bool>(2342, QMetaType::Bool, QMC::DefaultPropertyFlags | QMC::Constant),
        // property 'guideMaxHFR'
        QtMocHelpers::PropertyData<double>(2343, QMetaType::Double, QMC::DefaultPropertyFlags | QMC::Writable | QMC::StdCppSet, 710),
        // property 'isGuideMaxHFRImmutable'
        QtMocHelpers::PropertyData<bool>(2344, QMetaType::Bool, QMC::DefaultPropertyFlags | QMC::Constant),
        // property 'minDetectionsSEPMultistar'
        QtMocHelpers::PropertyData<uint>(2345, QMetaType::UInt, QMC::DefaultPropertyFlags | QMC::Writable | QMC::StdCppSet, 711),
        // property 'isMinDetectionsSEPMultistarImmutable'
        QtMocHelpers::PropertyData<bool>(2346, QMetaType::Bool, QMC::DefaultPropertyFlags | QMC::Constant),
        // property 'maxMultistarReferenceStars'
        QtMocHelpers::PropertyData<uint>(2347, QMetaType::UInt, QMC::DefaultPropertyFlags | QMC::Writable | QMC::StdCppSet, 712),
        // property 'isMaxMultistarReferenceStarsImmutable'
        QtMocHelpers::PropertyData<bool>(2348, QMetaType::Bool, QMC::DefaultPropertyFlags | QMC::Constant),
        // property 'alwaysInventGuideStar'
        QtMocHelpers::PropertyData<bool>(2349, QMetaType::Bool, QMC::DefaultPropertyFlags | QMC::Writable | QMC::StdCppSet, 713),
        // property 'isAlwaysInventGuideStarImmutable'
        QtMocHelpers::PropertyData<bool>(2350, QMetaType::Bool, QMC::DefaultPropertyFlags | QMC::Constant),
        // property 'twoAxisEnabled'
        QtMocHelpers::PropertyData<bool>(2351, QMetaType::Bool, QMC::DefaultPropertyFlags | QMC::Writable | QMC::StdCppSet, 714),
        // property 'isTwoAxisEnabledImmutable'
        QtMocHelpers::PropertyData<bool>(2352, QMetaType::Bool, QMC::DefaultPropertyFlags | QMC::Constant),
        // property 'useGuideHead'
        QtMocHelpers::PropertyData<bool>(2353, QMetaType::Bool, QMC::DefaultPropertyFlags | QMC::Writable | QMC::StdCppSet, 715),
        // property 'isUseGuideHeadImmutable'
        QtMocHelpers::PropertyData<bool>(2354, QMetaType::Bool, QMC::DefaultPropertyFlags | QMC::Constant),
        // property 'saveGuideLog'
        QtMocHelpers::PropertyData<bool>(2355, QMetaType::Bool, QMC::DefaultPropertyFlags | QMC::Writable | QMC::StdCppSet, 716),
        // property 'isSaveGuideLogImmutable'
        QtMocHelpers::PropertyData<bool>(2356, QMetaType::Bool, QMC::DefaultPropertyFlags | QMC::Constant),
        // property 'guideDarkFrame'
        QtMocHelpers::PropertyData<bool>(2357, QMetaType::Bool, QMC::DefaultPropertyFlags | QMC::Writable | QMC::StdCppSet, 717),
        // property 'isGuideDarkFrameImmutable'
        QtMocHelpers::PropertyData<bool>(2358, QMetaType::Bool, QMC::DefaultPropertyFlags | QMC::Constant),
        // property 'guideSubframe'
        QtMocHelpers::PropertyData<bool>(2359, QMetaType::Bool, QMC::DefaultPropertyFlags | QMC::Writable | QMC::StdCppSet, 718),
        // property 'isGuideSubframeImmutable'
        QtMocHelpers::PropertyData<bool>(2360, QMetaType::Bool, QMC::DefaultPropertyFlags | QMC::Constant),
        // property 'ditherPixels'
        QtMocHelpers::PropertyData<double>(2361, QMetaType::Double, QMC::DefaultPropertyFlags | QMC::Writable | QMC::StdCppSet, 719),
        // property 'isDitherPixelsImmutable'
        QtMocHelpers::PropertyData<bool>(2362, QMetaType::Bool, QMC::DefaultPropertyFlags | QMC::Constant),
        // property 'ditherFrames'
        QtMocHelpers::PropertyData<uint>(2363, QMetaType::UInt, QMC::DefaultPropertyFlags | QMC::Writable | QMC::StdCppSet, 720),
        // property 'isDitherFramesImmutable'
        QtMocHelpers::PropertyData<bool>(2364, QMetaType::Bool, QMC::DefaultPropertyFlags | QMC::Constant),
        // property 'ditherSettle'
        QtMocHelpers::PropertyData<uint>(2365, QMetaType::UInt, QMC::DefaultPropertyFlags | QMC::Writable | QMC::StdCppSet, 721),
        // property 'isDitherSettleImmutable'
        QtMocHelpers::PropertyData<bool>(2366, QMetaType::Bool, QMC::DefaultPropertyFlags | QMC::Constant),
        // property 'ditherThreshold'
        QtMocHelpers::PropertyData<double>(2367, QMetaType::Double, QMC::DefaultPropertyFlags | QMC::Writable | QMC::StdCppSet, 722),
        // property 'isDitherThresholdImmutable'
        QtMocHelpers::PropertyData<bool>(2368, QMetaType::Bool, QMC::DefaultPropertyFlags | QMC::Constant),
        // property 'ditherTimeout'
        QtMocHelpers::PropertyData<uint>(2369, QMetaType::UInt, QMC::DefaultPropertyFlags | QMC::Writable | QMC::StdCppSet, 723),
        // property 'isDitherTimeoutImmutable'
        QtMocHelpers::PropertyData<bool>(2370, QMetaType::Bool, QMC::DefaultPropertyFlags | QMC::Constant),
        // property 'ditherMaxIterations'
        QtMocHelpers::PropertyData<uint>(2371, QMetaType::UInt, QMC::DefaultPropertyFlags | QMC::Writable | QMC::StdCppSet, 724),
        // property 'isDitherMaxIterationsImmutable'
        QtMocHelpers::PropertyData<bool>(2372, QMetaType::Bool, QMC::DefaultPropertyFlags | QMC::Constant),
        // property 'ditherNoGuidingPulse'
        QtMocHelpers::PropertyData<uint>(2373, QMetaType::UInt, QMC::DefaultPropertyFlags | QMC::Writable | QMC::StdCppSet, 725),
        // property 'isDitherNoGuidingPulseImmutable'
        QtMocHelpers::PropertyData<bool>(2374, QMetaType::Bool, QMC::DefaultPropertyFlags | QMC::Constant),
        // property 'ditherFailAbortsAutoGuide'
        QtMocHelpers::PropertyData<bool>(2375, QMetaType::Bool, QMC::DefaultPropertyFlags | QMC::Writable | QMC::StdCppSet, 726),
        // property 'isDitherFailAbortsAutoGuideImmutable'
        QtMocHelpers::PropertyData<bool>(2376, QMetaType::Bool, QMC::DefaultPropertyFlags | QMC::Constant),
        // property 'ditherWithOnePulse'
        QtMocHelpers::PropertyData<bool>(2377, QMetaType::Bool, QMC::DefaultPropertyFlags | QMC::Writable | QMC::StdCppSet, 727),
        // property 'isDitherWithOnePulseImmutable'
        QtMocHelpers::PropertyData<bool>(2378, QMetaType::Bool, QMC::DefaultPropertyFlags | QMC::Constant),
        // property 'ditherEnabled'
        QtMocHelpers::PropertyData<bool>(2379, QMetaType::Bool, QMC::DefaultPropertyFlags | QMC::Writable | QMC::StdCppSet, 728),
        // property 'isDitherEnabledImmutable'
        QtMocHelpers::PropertyData<bool>(2380, QMetaType::Bool, QMC::DefaultPropertyFlags | QMC::Constant),
        // property 'ditherNoGuiding'
        QtMocHelpers::PropertyData<bool>(2381, QMetaType::Bool, QMC::DefaultPropertyFlags | QMC::Writable | QMC::StdCppSet, 729),
        // property 'isDitherNoGuidingImmutable'
        QtMocHelpers::PropertyData<bool>(2382, QMetaType::Bool, QMC::DefaultPropertyFlags | QMC::Constant),
        // property 'rAGuideEnabled'
        QtMocHelpers::PropertyData<bool>(2383, QMetaType::Bool, QMC::DefaultPropertyFlags | QMC::Writable | QMC::StdCppSet, 730),
        // property 'isRAGuideEnabledImmutable'
        QtMocHelpers::PropertyData<bool>(2384, QMetaType::Bool, QMC::DefaultPropertyFlags | QMC::Constant),
        // property 'dECGuideEnabled'
        QtMocHelpers::PropertyData<bool>(2385, QMetaType::Bool, QMC::DefaultPropertyFlags | QMC::Writable | QMC::StdCppSet, 731),
        // property 'isDECGuideEnabledImmutable'
        QtMocHelpers::PropertyData<bool>(2386, QMetaType::Bool, QMC::DefaultPropertyFlags | QMC::Constant),
        // property 'northDECGuideEnabled'
        QtMocHelpers::PropertyData<bool>(2387, QMetaType::Bool, QMC::DefaultPropertyFlags | QMC::Writable | QMC::StdCppSet, 732),
        // property 'isNorthDECGuideEnabledImmutable'
        QtMocHelpers::PropertyData<bool>(2388, QMetaType::Bool, QMC::DefaultPropertyFlags | QMC::Constant),
        // property 'southDECGuideEnabled'
        QtMocHelpers::PropertyData<bool>(2389, QMetaType::Bool, QMC::DefaultPropertyFlags | QMC::Writable | QMC::StdCppSet, 733),
        // property 'isSouthDECGuideEnabledImmutable'
        QtMocHelpers::PropertyData<bool>(2390, QMetaType::Bool, QMC::DefaultPropertyFlags | QMC::Constant),
        // property 'eastRAGuideEnabled'
        QtMocHelpers::PropertyData<bool>(2391, QMetaType::Bool, QMC::DefaultPropertyFlags | QMC::Writable | QMC::StdCppSet, 734),
        // property 'isEastRAGuideEnabledImmutable'
        QtMocHelpers::PropertyData<bool>(2392, QMetaType::Bool, QMC::DefaultPropertyFlags | QMC::Constant),
        // property 'westRAGuideEnabled'
        QtMocHelpers::PropertyData<bool>(2393, QMetaType::Bool, QMC::DefaultPropertyFlags | QMC::Writable | QMC::StdCppSet, 735),
        // property 'isWestRAGuideEnabledImmutable'
        QtMocHelpers::PropertyData<bool>(2394, QMetaType::Bool, QMC::DefaultPropertyFlags | QMC::Constant),
        // property 'rAProportionalGain'
        QtMocHelpers::PropertyData<double>(2395, QMetaType::Double, QMC::DefaultPropertyFlags | QMC::Writable | QMC::StdCppSet, 736),
        // property 'isRAProportionalGainImmutable'
        QtMocHelpers::PropertyData<bool>(2396, QMetaType::Bool, QMC::DefaultPropertyFlags | QMC::Constant),
        // property 'dECProportionalGain'
        QtMocHelpers::PropertyData<double>(2397, QMetaType::Double, QMC::DefaultPropertyFlags | QMC::Writable | QMC::StdCppSet, 737),
        // property 'isDECProportionalGainImmutable'
        QtMocHelpers::PropertyData<bool>(2398, QMetaType::Bool, QMC::DefaultPropertyFlags | QMC::Constant),
        // property 'rAIntegralGain'
        QtMocHelpers::PropertyData<double>(2399, QMetaType::Double, QMC::DefaultPropertyFlags | QMC::Writable | QMC::StdCppSet, 738),
        // property 'isRAIntegralGainImmutable'
        QtMocHelpers::PropertyData<bool>(2400, QMetaType::Bool, QMC::DefaultPropertyFlags | QMC::Constant),
        // property 'dECIntegralGain'
        QtMocHelpers::PropertyData<double>(2401, QMetaType::Double, QMC::DefaultPropertyFlags | QMC::Writable | QMC::StdCppSet, 739),
        // property 'isDECIntegralGainImmutable'
        QtMocHelpers::PropertyData<bool>(2402, QMetaType::Bool, QMC::DefaultPropertyFlags | QMC::Constant),
        // property 'rAMinimumPulseArcSec'
        QtMocHelpers::PropertyData<double>(2403, QMetaType::Double, QMC::DefaultPropertyFlags | QMC::Writable | QMC::StdCppSet, 740),
        // property 'isRAMinimumPulseArcSecImmutable'
        QtMocHelpers::PropertyData<bool>(2404, QMetaType::Bool, QMC::DefaultPropertyFlags | QMC::Constant),
        // property 'dECMinimumPulseArcSec'
        QtMocHelpers::PropertyData<double>(2405, QMetaType::Double, QMC::DefaultPropertyFlags | QMC::Writable | QMC::StdCppSet, 741),
        // property 'isDECMinimumPulseArcSecImmutable'
        QtMocHelpers::PropertyData<bool>(2406, QMetaType::Bool, QMC::DefaultPropertyFlags | QMC::Constant),
        // property 'rAMaximumPulseArcSec'
        QtMocHelpers::PropertyData<uint>(2407, QMetaType::UInt, QMC::DefaultPropertyFlags | QMC::Writable | QMC::StdCppSet, 742),
        // property 'isRAMaximumPulseArcSecImmutable'
        QtMocHelpers::PropertyData<bool>(2408, QMetaType::Bool, QMC::DefaultPropertyFlags | QMC::Constant),
        // property 'dECMaximumPulseArcSec'
        QtMocHelpers::PropertyData<uint>(2409, QMetaType::UInt, QMC::DefaultPropertyFlags | QMC::Writable | QMC::StdCppSet, 743),
        // property 'isDECMaximumPulseArcSecImmutable'
        QtMocHelpers::PropertyData<bool>(2410, QMetaType::Bool, QMC::DefaultPropertyFlags | QMC::Constant),
        // property 'gPGEnabled'
        QtMocHelpers::PropertyData<bool>(2411, QMetaType::Bool, QMC::DefaultPropertyFlags | QMC::Writable | QMC::StdCppSet, 744),
        // property 'isGPGEnabledImmutable'
        QtMocHelpers::PropertyData<bool>(2412, QMetaType::Bool, QMC::DefaultPropertyFlags | QMC::Constant),
        // property 'gPGDarkGuiding'
        QtMocHelpers::PropertyData<bool>(2413, QMetaType::Bool, QMC::DefaultPropertyFlags | QMC::Writable | QMC::StdCppSet, 745),
        // property 'isGPGDarkGuidingImmutable'
        QtMocHelpers::PropertyData<bool>(2414, QMetaType::Bool, QMC::DefaultPropertyFlags | QMC::Constant),
        // property 'gPGDarkGuidingInterval'
        QtMocHelpers::PropertyData<double>(2415, QMetaType::Double, QMC::DefaultPropertyFlags | QMC::Writable | QMC::StdCppSet, 746),
        // property 'isGPGDarkGuidingIntervalImmutable'
        QtMocHelpers::PropertyData<bool>(2416, QMetaType::Bool, QMC::DefaultPropertyFlags | QMC::Constant),
        // property 'aIDarkGuiding'
        QtMocHelpers::PropertyData<bool>(2417, QMetaType::Bool, QMC::DefaultPropertyFlags | QMC::Writable | QMC::StdCppSet, 747),
        // property 'isAIDarkGuidingImmutable'
        QtMocHelpers::PropertyData<bool>(2418, QMetaType::Bool, QMC::DefaultPropertyFlags | QMC::Constant),
        // property 'aIDarkGuidingInterval'
        QtMocHelpers::PropertyData<double>(2419, QMetaType::Double, QMC::DefaultPropertyFlags | QMC::Writable | QMC::StdCppSet, 748),
        // property 'isAIDarkGuidingIntervalImmutable'
        QtMocHelpers::PropertyData<bool>(2420, QMetaType::Bool, QMC::DefaultPropertyFlags | QMC::Constant),
        // property 'gPGcWeight'
        QtMocHelpers::PropertyData<double>(2421, QMetaType::Double, QMC::DefaultPropertyFlags | QMC::Writable | QMC::StdCppSet, 749),
        // property 'isGPGcWeightImmutable'
        QtMocHelpers::PropertyData<bool>(2422, QMetaType::Bool, QMC::DefaultPropertyFlags | QMC::Constant),
        // property 'gPGMinPeriodsForInference'
        QtMocHelpers::PropertyData<uint>(2423, QMetaType::UInt, QMC::DefaultPropertyFlags | QMC::Writable | QMC::StdCppSet, 750),
        // property 'isGPGMinPeriodsForInferenceImmutable'
        QtMocHelpers::PropertyData<bool>(2424, QMetaType::Bool, QMC::DefaultPropertyFlags | QMC::Constant),
        // property 'gPGMinMove'
        QtMocHelpers::PropertyData<double>(2425, QMetaType::Double, QMC::DefaultPropertyFlags | QMC::Writable | QMC::StdCppSet, 751),
        // property 'isGPGMinMoveImmutable'
        QtMocHelpers::PropertyData<bool>(2426, QMetaType::Bool, QMC::DefaultPropertyFlags | QMC::Constant),
        // property 'gPGSE0KLengthScale'
        QtMocHelpers::PropertyData<uint>(2427, QMetaType::UInt, QMC::DefaultPropertyFlags | QMC::Writable | QMC::StdCppSet, 752),
        // property 'isGPGSE0KLengthScaleImmutable'
        QtMocHelpers::PropertyData<bool>(2428, QMetaType::Bool, QMC::DefaultPropertyFlags | QMC::Constant),
        // property 'gPGSE0KSignalVariance'
        QtMocHelpers::PropertyData<double>(2429, QMetaType::Double, QMC::DefaultPropertyFlags | QMC::Writable | QMC::StdCppSet, 753),
        // property 'isGPGSE0KSignalVarianceImmutable'
        QtMocHelpers::PropertyData<bool>(2430, QMetaType::Bool, QMC::DefaultPropertyFlags | QMC::Constant),
        // property 'gPGPKLengthScale'
        QtMocHelpers::PropertyData<double>(2431, QMetaType::Double, QMC::DefaultPropertyFlags | QMC::Writable | QMC::StdCppSet, 754),
        // property 'isGPGPKLengthScaleImmutable'
        QtMocHelpers::PropertyData<bool>(2432, QMetaType::Bool, QMC::DefaultPropertyFlags | QMC::Constant),
        // property 'gPGPeriod'
        QtMocHelpers::PropertyData<double>(2433, QMetaType::Double, QMC::DefaultPropertyFlags | QMC::Writable | QMC::StdCppSet, 755),
        // property 'isGPGPeriodImmutable'
        QtMocHelpers::PropertyData<bool>(2434, QMetaType::Bool, QMC::DefaultPropertyFlags | QMC::Constant),
        // property 'gPGPKSignalVariance'
        QtMocHelpers::PropertyData<double>(2435, QMetaType::Double, QMC::DefaultPropertyFlags | QMC::Writable | QMC::StdCppSet, 756),
        // property 'isGPGPKSignalVarianceImmutable'
        QtMocHelpers::PropertyData<bool>(2436, QMetaType::Bool, QMC::DefaultPropertyFlags | QMC::Constant),
        // property 'gPGSE1KLengthScale'
        QtMocHelpers::PropertyData<double>(2437, QMetaType::Double, QMC::DefaultPropertyFlags | QMC::Writable | QMC::StdCppSet, 757),
        // property 'isGPGSE1KLengthScaleImmutable'
        QtMocHelpers::PropertyData<bool>(2438, QMetaType::Bool, QMC::DefaultPropertyFlags | QMC::Constant),
        // property 'gPGSE1KSignalVariance'
        QtMocHelpers::PropertyData<double>(2439, QMetaType::Double, QMC::DefaultPropertyFlags | QMC::Writable | QMC::StdCppSet, 758),
        // property 'isGPGSE1KSignalVarianceImmutable'
        QtMocHelpers::PropertyData<bool>(2440, QMetaType::Bool, QMC::DefaultPropertyFlags | QMC::Constant),
        // property 'gPGMinPeriodsForPeriodEstimate'
        QtMocHelpers::PropertyData<uint>(2441, QMetaType::UInt, QMC::DefaultPropertyFlags | QMC::Writable | QMC::StdCppSet, 759),
        // property 'isGPGMinPeriodsForPeriodEstimateImmutable'
        QtMocHelpers::PropertyData<bool>(2442, QMetaType::Bool, QMC::DefaultPropertyFlags | QMC::Constant),
        // property 'gPGPointsForApproximation'
        QtMocHelpers::PropertyData<uint>(2443, QMetaType::UInt, QMC::DefaultPropertyFlags | QMC::Writable | QMC::StdCppSet, 760),
        // property 'isGPGPointsForApproximationImmutable'
        QtMocHelpers::PropertyData<bool>(2444, QMetaType::Bool, QMC::DefaultPropertyFlags | QMC::Constant),
        // property 'gPGpWeight'
        QtMocHelpers::PropertyData<double>(2445, QMetaType::Double, QMC::DefaultPropertyFlags | QMC::Writable | QMC::StdCppSet, 761),
        // property 'isGPGpWeightImmutable'
        QtMocHelpers::PropertyData<bool>(2446, QMetaType::Bool, QMC::DefaultPropertyFlags | QMC::Constant),
        // property 'gPGEstimatePeriod'
        QtMocHelpers::PropertyData<bool>(2447, QMetaType::Bool, QMC::DefaultPropertyFlags | QMC::Writable | QMC::StdCppSet, 762),
        // property 'isGPGEstimatePeriodImmutable'
        QtMocHelpers::PropertyData<bool>(2448, QMetaType::Bool, QMC::DefaultPropertyFlags | QMC::Constant),
        // property 'guiderAccuracyThreshold'
        QtMocHelpers::PropertyData<uint>(2449, QMetaType::UInt, QMC::DefaultPropertyFlags | QMC::Writable | QMC::StdCppSet, 763),
        // property 'isGuiderAccuracyThresholdImmutable'
        QtMocHelpers::PropertyData<bool>(2450, QMetaType::Bool, QMC::DefaultPropertyFlags | QMC::Constant),
        // property 'rADisplayedOnGuideGraph'
        QtMocHelpers::PropertyData<bool>(2451, QMetaType::Bool, QMC::DefaultPropertyFlags | QMC::Writable | QMC::StdCppSet, 764),
        // property 'isRADisplayedOnGuideGraphImmutable'
        QtMocHelpers::PropertyData<bool>(2452, QMetaType::Bool, QMC::DefaultPropertyFlags | QMC::Constant),
        // property 'dEDisplayedOnGuideGraph'
        QtMocHelpers::PropertyData<bool>(2453, QMetaType::Bool, QMC::DefaultPropertyFlags | QMC::Writable | QMC::StdCppSet, 765),
        // property 'isDEDisplayedOnGuideGraphImmutable'
        QtMocHelpers::PropertyData<bool>(2454, QMetaType::Bool, QMC::DefaultPropertyFlags | QMC::Constant),
        // property 'rACorrDisplayedOnGuideGraph'
        QtMocHelpers::PropertyData<bool>(2455, QMetaType::Bool, QMC::DefaultPropertyFlags | QMC::Writable | QMC::StdCppSet, 766),
        // property 'isRACorrDisplayedOnGuideGraphImmutable'
        QtMocHelpers::PropertyData<bool>(2456, QMetaType::Bool, QMC::DefaultPropertyFlags | QMC::Constant),
        // property 'dECorrDisplayedOnGuideGraph'
        QtMocHelpers::PropertyData<bool>(2457, QMetaType::Bool, QMC::DefaultPropertyFlags | QMC::Writable | QMC::StdCppSet, 767),
        // property 'isDECorrDisplayedOnGuideGraphImmutable'
        QtMocHelpers::PropertyData<bool>(2458, QMetaType::Bool, QMC::DefaultPropertyFlags | QMC::Constant),
        // property 'sNRDisplayedOnGuideGraph'
        QtMocHelpers::PropertyData<bool>(2459, QMetaType::Bool, QMC::DefaultPropertyFlags | QMC::Writable | QMC::StdCppSet, 768),
        // property 'isSNRDisplayedOnGuideGraphImmutable'
        QtMocHelpers::PropertyData<bool>(2460, QMetaType::Bool, QMC::DefaultPropertyFlags | QMC::Constant),
        // property 'rMSDisplayedOnGuideGraph'
        QtMocHelpers::PropertyData<bool>(2461, QMetaType::Bool, QMC::DefaultPropertyFlags | QMC::Writable | QMC::StdCppSet, 769),
        // property 'isRMSDisplayedOnGuideGraphImmutable'
        QtMocHelpers::PropertyData<bool>(2462, QMetaType::Bool, QMC::DefaultPropertyFlags | QMC::Constant),
        // property 'rAHysteresis'
        QtMocHelpers::PropertyData<double>(2463, QMetaType::Double, QMC::DefaultPropertyFlags | QMC::Writable | QMC::StdCppSet, 770),
        // property 'isRAHysteresisImmutable'
        QtMocHelpers::PropertyData<bool>(2464, QMetaType::Bool, QMC::DefaultPropertyFlags | QMC::Constant),
        // property 'dECHysteresis'
        QtMocHelpers::PropertyData<double>(2465, QMetaType::Double, QMC::DefaultPropertyFlags | QMC::Writable | QMC::StdCppSet, 771),
        // property 'isDECHysteresisImmutable'
        QtMocHelpers::PropertyData<bool>(2466, QMetaType::Bool, QMC::DefaultPropertyFlags | QMC::Constant),
        // property 'schedulerAlgorithm'
        QtMocHelpers::PropertyData<uint>(2467, QMetaType::UInt, QMC::DefaultPropertyFlags | QMC::Writable | QMC::StdCppSet, 772),
        // property 'isSchedulerAlgorithmImmutable'
        QtMocHelpers::PropertyData<bool>(2468, QMetaType::Bool, QMC::DefaultPropertyFlags | QMC::Constant),
        // property 'schedulerLogging'
        QtMocHelpers::PropertyData<bool>(2469, QMetaType::Bool, QMC::DefaultPropertyFlags | QMC::Writable | QMC::StdCppSet, 773),
        // property 'isSchedulerLoggingImmutable'
        QtMocHelpers::PropertyData<bool>(2470, QMetaType::Bool, QMC::DefaultPropertyFlags | QMC::Constant),
        // property 'stopEkosAfterShutdown'
        QtMocHelpers::PropertyData<bool>(2471, QMetaType::Bool, QMC::DefaultPropertyFlags | QMC::Writable | QMC::StdCppSet, 774),
        // property 'isStopEkosAfterShutdownImmutable'
        QtMocHelpers::PropertyData<bool>(2472, QMetaType::Bool, QMC::DefaultPropertyFlags | QMC::Constant),
        // property 'shutdownScriptTerminatesINDI'
        QtMocHelpers::PropertyData<bool>(2473, QMetaType::Bool, QMC::DefaultPropertyFlags | QMC::Writable | QMC::StdCppSet, 775),
        // property 'isShutdownScriptTerminatesINDIImmutable'
        QtMocHelpers::PropertyData<bool>(2474, QMetaType::Bool, QMC::DefaultPropertyFlags | QMC::Constant),
        // property 'cameraWarmupEnabled'
        QtMocHelpers::PropertyData<bool>(2475, QMetaType::Bool, QMC::DefaultPropertyFlags | QMC::Writable | QMC::StdCppSet, 776),
        // property 'isCameraWarmupEnabledImmutable'
        QtMocHelpers::PropertyData<bool>(2476, QMetaType::Bool, QMC::DefaultPropertyFlags | QMC::Constant),
        // property 'cameraWarmupRamp'
        QtMocHelpers::PropertyData<uint>(2477, QMetaType::UInt, QMC::DefaultPropertyFlags | QMC::Writable | QMC::StdCppSet, 777),
        // property 'isCameraWarmupRampImmutable'
        QtMocHelpers::PropertyData<bool>(2478, QMetaType::Bool, QMC::DefaultPropertyFlags | QMC::Constant),
        // property 'preemptiveShutdown'
        QtMocHelpers::PropertyData<bool>(2479, QMetaType::Bool, QMC::DefaultPropertyFlags | QMC::Writable | QMC::StdCppSet, 778),
        // property 'isPreemptiveShutdownImmutable'
        QtMocHelpers::PropertyData<bool>(2480, QMetaType::Bool, QMC::DefaultPropertyFlags | QMC::Constant),
        // property 'resetMountModelOnAlignFail'
        QtMocHelpers::PropertyData<bool>(2481, QMetaType::Bool, QMC::DefaultPropertyFlags | QMC::Writable | QMC::StdCppSet, 779),
        // property 'isResetMountModelOnAlignFailImmutable'
        QtMocHelpers::PropertyData<bool>(2482, QMetaType::Bool, QMC::DefaultPropertyFlags | QMC::Constant),
        // property 'resetMountModelBeforeJob'
        QtMocHelpers::PropertyData<bool>(2483, QMetaType::Bool, QMC::DefaultPropertyFlags | QMC::Writable | QMC::StdCppSet, 780),
        // property 'isResetMountModelBeforeJobImmutable'
        QtMocHelpers::PropertyData<bool>(2484, QMetaType::Bool, QMC::DefaultPropertyFlags | QMC::Constant),
        // property 'resetGuideCalibration'
        QtMocHelpers::PropertyData<bool>(2485, QMetaType::Bool, QMC::DefaultPropertyFlags | QMC::Writable | QMC::StdCppSet, 781),
        // property 'isResetGuideCalibrationImmutable'
        QtMocHelpers::PropertyData<bool>(2486, QMetaType::Bool, QMC::DefaultPropertyFlags | QMC::Constant),
        // property 'forceAlignmentBeforeJob'
        QtMocHelpers::PropertyData<bool>(2487, QMetaType::Bool, QMC::DefaultPropertyFlags | QMC::Writable | QMC::StdCppSet, 782),
        // property 'isForceAlignmentBeforeJobImmutable'
        QtMocHelpers::PropertyData<bool>(2488, QMetaType::Bool, QMC::DefaultPropertyFlags | QMC::Constant),
        // property 'reuseGuideCalibration'
        QtMocHelpers::PropertyData<bool>(2489, QMetaType::Bool, QMC::DefaultPropertyFlags | QMC::Writable | QMC::StdCppSet, 783),
        // property 'isReuseGuideCalibrationImmutable'
        QtMocHelpers::PropertyData<bool>(2490, QMetaType::Bool, QMC::DefaultPropertyFlags | QMC::Constant),
        // property 'reverseDecOnPierSideChange'
        QtMocHelpers::PropertyData<bool>(2491, QMetaType::Bool, QMC::DefaultPropertyFlags | QMC::Writable | QMC::StdCppSet, 784),
        // property 'isReverseDecOnPierSideChangeImmutable'
        QtMocHelpers::PropertyData<bool>(2492, QMetaType::Bool, QMC::DefaultPropertyFlags | QMC::Constant),
        // property 'guideCalibrationBacklash'
        QtMocHelpers::PropertyData<bool>(2493, QMetaType::Bool, QMC::DefaultPropertyFlags | QMC::Writable | QMC::StdCppSet, 785),
        // property 'isGuideCalibrationBacklashImmutable'
        QtMocHelpers::PropertyData<bool>(2494, QMetaType::Bool, QMC::DefaultPropertyFlags | QMC::Constant),
        // property 'assumeDecOrthogonal'
        QtMocHelpers::PropertyData<bool>(2495, QMetaType::Bool, QMC::DefaultPropertyFlags | QMC::Writable | QMC::StdCppSet, 786),
        // property 'isAssumeDecOrthogonalImmutable'
        QtMocHelpers::PropertyData<bool>(2496, QMetaType::Bool, QMC::DefaultPropertyFlags | QMC::Constant),
        // property 'serializedCalibration'
        QtMocHelpers::PropertyData<QString>(2497, QMetaType::QString, QMC::DefaultPropertyFlags | QMC::Writable | QMC::StdCppSet, 787),
        // property 'isSerializedCalibrationImmutable'
        QtMocHelpers::PropertyData<bool>(2498, QMetaType::Bool, QMC::DefaultPropertyFlags | QMC::Constant),
        // property 'realignAfterCalibrationFailure'
        QtMocHelpers::PropertyData<bool>(2499, QMetaType::Bool, QMC::DefaultPropertyFlags | QMC::Writable | QMC::StdCppSet, 788),
        // property 'isRealignAfterCalibrationFailureImmutable'
        QtMocHelpers::PropertyData<bool>(2500, QMetaType::Bool, QMC::DefaultPropertyFlags | QMC::Constant),
        // property 'preemptiveShutdownTime'
        QtMocHelpers::PropertyData<double>(2501, QMetaType::Double, QMC::DefaultPropertyFlags | QMC::Writable | QMC::StdCppSet, 789),
        // property 'isPreemptiveShutdownTimeImmutable'
        QtMocHelpers::PropertyData<bool>(2502, QMetaType::Bool, QMC::DefaultPropertyFlags | QMC::Constant),
        // property 'rememberJobProgress'
        QtMocHelpers::PropertyData<bool>(2503, QMetaType::Bool, QMC::DefaultPropertyFlags | QMC::Writable | QMC::StdCppSet, 790),
        // property 'isRememberJobProgressImmutable'
        QtMocHelpers::PropertyData<bool>(2504, QMetaType::Bool, QMC::DefaultPropertyFlags | QMC::Constant),
        // property 'greedyScheduling'
        QtMocHelpers::PropertyData<bool>(2505, QMetaType::Bool, QMC::DefaultPropertyFlags | QMC::Writable | QMC::StdCppSet, 791),
        // property 'isGreedySchedulingImmutable'
        QtMocHelpers::PropertyData<bool>(2506, QMetaType::Bool, QMC::DefaultPropertyFlags | QMC::Constant),
        // property 'leadTime'
        QtMocHelpers::PropertyData<double>(2507, QMetaType::Double, QMC::DefaultPropertyFlags | QMC::Writable | QMC::StdCppSet, 792),
        // property 'isLeadTimeImmutable'
        QtMocHelpers::PropertyData<bool>(2508, QMetaType::Bool, QMC::DefaultPropertyFlags | QMC::Constant),
        // property 'preDawnTime'
        QtMocHelpers::PropertyData<double>(2509, QMetaType::Double, QMC::DefaultPropertyFlags | QMC::Writable | QMC::StdCppSet, 793),
        // property 'isPreDawnTimeImmutable'
        QtMocHelpers::PropertyData<bool>(2510, QMetaType::Bool, QMC::DefaultPropertyFlags | QMC::Constant),
        // property 'dawnOffset'
        QtMocHelpers::PropertyData<double>(2511, QMetaType::Double, QMC::DefaultPropertyFlags | QMC::Writable | QMC::StdCppSet, 794),
        // property 'isDawnOffsetImmutable'
        QtMocHelpers::PropertyData<bool>(2512, QMetaType::Bool, QMC::DefaultPropertyFlags | QMC::Constant),
        // property 'duskOffset'
        QtMocHelpers::PropertyData<double>(2513, QMetaType::Double, QMC::DefaultPropertyFlags | QMC::Writable | QMC::StdCppSet, 795),
        // property 'isDuskOffsetImmutable'
        QtMocHelpers::PropertyData<bool>(2514, QMetaType::Bool, QMC::DefaultPropertyFlags | QMC::Constant),
        // property 'telescopeFocalLength'
        QtMocHelpers::PropertyData<double>(2515, QMetaType::Double, QMC::DefaultPropertyFlags | QMC::Writable | QMC::StdCppSet, 796),
        // property 'isTelescopeFocalLengthImmutable'
        QtMocHelpers::PropertyData<bool>(2516, QMetaType::Bool, QMC::DefaultPropertyFlags | QMC::Constant),
        // property 'telescopeFocalReducer'
        QtMocHelpers::PropertyData<double>(2517, QMetaType::Double, QMC::DefaultPropertyFlags | QMC::Writable | QMC::StdCppSet, 797),
        // property 'isTelescopeFocalReducerImmutable'
        QtMocHelpers::PropertyData<bool>(2518, QMetaType::Bool, QMC::DefaultPropertyFlags | QMC::Constant),
        // property 'cameraPixelWidth'
        QtMocHelpers::PropertyData<double>(2519, QMetaType::Double, QMC::DefaultPropertyFlags | QMC::Writable | QMC::StdCppSet, 798),
        // property 'isCameraPixelWidthImmutable'
        QtMocHelpers::PropertyData<bool>(2520, QMetaType::Bool, QMC::DefaultPropertyFlags | QMC::Constant),
        // property 'cameraPixelHeight'
        QtMocHelpers::PropertyData<double>(2521, QMetaType::Double, QMC::DefaultPropertyFlags | QMC::Writable | QMC::StdCppSet, 799),
        // property 'isCameraPixelHeightImmutable'
        QtMocHelpers::PropertyData<bool>(2522, QMetaType::Bool, QMC::DefaultPropertyFlags | QMC::Constant),
        // property 'cameraWidth'
        QtMocHelpers::PropertyData<uint>(2523, QMetaType::UInt, QMC::DefaultPropertyFlags | QMC::Writable | QMC::StdCppSet, 800),
        // property 'isCameraWidthImmutable'
        QtMocHelpers::PropertyData<bool>(2524, QMetaType::Bool, QMC::DefaultPropertyFlags | QMC::Constant),
        // property 'cameraHeight'
        QtMocHelpers::PropertyData<uint>(2525, QMetaType::UInt, QMC::DefaultPropertyFlags | QMC::Writable | QMC::StdCppSet, 801),
        // property 'isCameraHeightImmutable'
        QtMocHelpers::PropertyData<bool>(2526, QMetaType::Bool, QMC::DefaultPropertyFlags | QMC::Constant),
        // property 'cameraRotation'
        QtMocHelpers::PropertyData<double>(2527, QMetaType::Double, QMC::DefaultPropertyFlags | QMC::Writable | QMC::StdCppSet, 802),
        // property 'isCameraRotationImmutable'
        QtMocHelpers::PropertyData<bool>(2528, QMetaType::Bool, QMC::DefaultPropertyFlags | QMC::Constant),
        // property 'errorHandlingStrategy'
        QtMocHelpers::PropertyData<uint>(2529, QMetaType::UInt, QMC::DefaultPropertyFlags | QMC::Writable | QMC::StdCppSet, 803),
        // property 'isErrorHandlingStrategyImmutable'
        QtMocHelpers::PropertyData<bool>(2530, QMetaType::Bool, QMC::DefaultPropertyFlags | QMC::Constant),
        // property 'errorHandlingStrategyDelay'
        QtMocHelpers::PropertyData<uint>(2531, QMetaType::UInt, QMC::DefaultPropertyFlags | QMC::Writable | QMC::StdCppSet, 804),
        // property 'isErrorHandlingStrategyDelayImmutable'
        QtMocHelpers::PropertyData<bool>(2532, QMetaType::Bool, QMC::DefaultPropertyFlags | QMC::Constant),
        // property 'rescheduleErrors'
        QtMocHelpers::PropertyData<bool>(2533, QMetaType::Bool, QMC::DefaultPropertyFlags | QMC::Writable | QMC::StdCppSet, 805),
        // property 'isRescheduleErrorsImmutable'
        QtMocHelpers::PropertyData<bool>(2534, QMetaType::Bool, QMC::DefaultPropertyFlags | QMC::Constant),
        // property 'alignCheckFrequency'
        QtMocHelpers::PropertyData<uint>(2535, QMetaType::UInt, QMC::DefaultPropertyFlags | QMC::Writable | QMC::StdCppSet, 806),
        // property 'isAlignCheckFrequencyImmutable'
        QtMocHelpers::PropertyData<bool>(2536, QMetaType::Bool, QMC::DefaultPropertyFlags | QMC::Constant),
        // property 'alignCheckThreshold'
        QtMocHelpers::PropertyData<double>(2537, QMetaType::Double, QMC::DefaultPropertyFlags | QMC::Writable | QMC::StdCppSet, 807),
        // property 'isAlignCheckThresholdImmutable'
        QtMocHelpers::PropertyData<bool>(2538, QMetaType::Bool, QMC::DefaultPropertyFlags | QMC::Constant),
        // property 'schedulerTrackStep'
        QtMocHelpers::PropertyData<bool>(2539, QMetaType::Bool, QMC::DefaultPropertyFlags | QMC::Writable | QMC::StdCppSet, 808),
        // property 'isSchedulerTrackStepImmutable'
        QtMocHelpers::PropertyData<bool>(2540, QMetaType::Bool, QMC::DefaultPropertyFlags | QMC::Constant),
        // property 'schedulerStartupEnabled'
        QtMocHelpers::PropertyData<bool>(2541, QMetaType::Bool, QMC::DefaultPropertyFlags | QMC::Writable | QMC::StdCppSet, 809),
        // property 'isSchedulerStartupEnabledImmutable'
        QtMocHelpers::PropertyData<bool>(2542, QMetaType::Bool, QMC::DefaultPropertyFlags | QMC::Constant),
        // property 'schedulerPreStartupScript'
        QtMocHelpers::PropertyData<QString>(2543, QMetaType::QString, QMC::DefaultPropertyFlags | QMC::Writable | QMC::StdCppSet, 810),
        // property 'isSchedulerPreStartupScriptImmutable'
        QtMocHelpers::PropertyData<bool>(2544, QMetaType::Bool, QMC::DefaultPropertyFlags | QMC::Constant),
        // property 'schedulerPostStartupScript'
        QtMocHelpers::PropertyData<QString>(2545, QMetaType::QString, QMC::DefaultPropertyFlags | QMC::Writable | QMC::StdCppSet, 811),
        // property 'isSchedulerPostStartupScriptImmutable'
        QtMocHelpers::PropertyData<bool>(2546, QMetaType::Bool, QMC::DefaultPropertyFlags | QMC::Constant),
        // property 'schedulerShutdownEnabled'
        QtMocHelpers::PropertyData<bool>(2547, QMetaType::Bool, QMC::DefaultPropertyFlags | QMC::Writable | QMC::StdCppSet, 812),
        // property 'isSchedulerShutdownEnabledImmutable'
        QtMocHelpers::PropertyData<bool>(2548, QMetaType::Bool, QMC::DefaultPropertyFlags | QMC::Constant),
        // property 'schedulerPreShutdownScript'
        QtMocHelpers::PropertyData<QString>(2549, QMetaType::QString, QMC::DefaultPropertyFlags | QMC::Writable | QMC::StdCppSet, 813),
        // property 'isSchedulerPreShutdownScriptImmutable'
        QtMocHelpers::PropertyData<bool>(2550, QMetaType::Bool, QMC::DefaultPropertyFlags | QMC::Constant),
        // property 'schedulerPostShutdownScript'
        QtMocHelpers::PropertyData<QString>(2551, QMetaType::QString, QMC::DefaultPropertyFlags | QMC::Writable | QMC::StdCppSet, 814),
        // property 'isSchedulerPostShutdownScriptImmutable'
        QtMocHelpers::PropertyData<bool>(2552, QMetaType::Bool, QMC::DefaultPropertyFlags | QMC::Constant),
        // property 'schedulerFocusStep'
        QtMocHelpers::PropertyData<bool>(2553, QMetaType::Bool, QMC::DefaultPropertyFlags | QMC::Writable | QMC::StdCppSet, 815),
        // property 'isSchedulerFocusStepImmutable'
        QtMocHelpers::PropertyData<bool>(2554, QMetaType::Bool, QMC::DefaultPropertyFlags | QMC::Constant),
        // property 'schedulerGuideStep'
        QtMocHelpers::PropertyData<bool>(2555, QMetaType::Bool, QMC::DefaultPropertyFlags | QMC::Writable | QMC::StdCppSet, 816),
        // property 'isSchedulerGuideStepImmutable'
        QtMocHelpers::PropertyData<bool>(2556, QMetaType::Bool, QMC::DefaultPropertyFlags | QMC::Constant),
        // property 'schedulerAlignStep'
        QtMocHelpers::PropertyData<bool>(2557, QMetaType::Bool, QMC::DefaultPropertyFlags | QMC::Writable | QMC::StdCppSet, 817),
        // property 'isSchedulerAlignStepImmutable'
        QtMocHelpers::PropertyData<bool>(2558, QMetaType::Bool, QMC::DefaultPropertyFlags | QMC::Constant),
        // property 'schedulerAltitude'
        QtMocHelpers::PropertyData<bool>(2559, QMetaType::Bool, QMC::DefaultPropertyFlags | QMC::Writable | QMC::StdCppSet, 818),
        // property 'isSchedulerAltitudeImmutable'
        QtMocHelpers::PropertyData<bool>(2560, QMetaType::Bool, QMC::DefaultPropertyFlags | QMC::Constant),
        // property 'schedulerAltitudeValue'
        QtMocHelpers::PropertyData<double>(2561, QMetaType::Double, QMC::DefaultPropertyFlags | QMC::Writable | QMC::StdCppSet, 819),
        // property 'isSchedulerAltitudeValueImmutable'
        QtMocHelpers::PropertyData<bool>(2562, QMetaType::Bool, QMC::DefaultPropertyFlags | QMC::Constant),
        // property 'schedulerHorizon'
        QtMocHelpers::PropertyData<bool>(2563, QMetaType::Bool, QMC::DefaultPropertyFlags | QMC::Writable | QMC::StdCppSet, 820),
        // property 'isSchedulerHorizonImmutable'
        QtMocHelpers::PropertyData<bool>(2564, QMetaType::Bool, QMC::DefaultPropertyFlags | QMC::Constant),
        // property 'schedulerMoonSeparation'
        QtMocHelpers::PropertyData<bool>(2565, QMetaType::Bool, QMC::DefaultPropertyFlags | QMC::Writable | QMC::StdCppSet, 821),
        // property 'isSchedulerMoonSeparationImmutable'
        QtMocHelpers::PropertyData<bool>(2566, QMetaType::Bool, QMC::DefaultPropertyFlags | QMC::Constant),
        // property 'schedulerMoonSeparationValue'
        QtMocHelpers::PropertyData<double>(2567, QMetaType::Double, QMC::DefaultPropertyFlags | QMC::Writable | QMC::StdCppSet, 822),
        // property 'isSchedulerMoonSeparationValueImmutable'
        QtMocHelpers::PropertyData<bool>(2568, QMetaType::Bool, QMC::DefaultPropertyFlags | QMC::Constant),
        // property 'schedulerMoonAltitude'
        QtMocHelpers::PropertyData<bool>(2569, QMetaType::Bool, QMC::DefaultPropertyFlags | QMC::Writable | QMC::StdCppSet, 823),
        // property 'isSchedulerMoonAltitudeImmutable'
        QtMocHelpers::PropertyData<bool>(2570, QMetaType::Bool, QMC::DefaultPropertyFlags | QMC::Constant),
        // property 'schedulerMoonAltitudeMaxValue'
        QtMocHelpers::PropertyData<double>(2571, QMetaType::Double, QMC::DefaultPropertyFlags | QMC::Writable | QMC::StdCppSet, 824),
        // property 'isSchedulerMoonAltitudeMaxValueImmutable'
        QtMocHelpers::PropertyData<bool>(2572, QMetaType::Bool, QMC::DefaultPropertyFlags | QMC::Constant),
        // property 'schedulerWeather'
        QtMocHelpers::PropertyData<bool>(2573, QMetaType::Bool, QMC::DefaultPropertyFlags | QMC::Writable | QMC::StdCppSet, 825),
        // property 'isSchedulerWeatherImmutable'
        QtMocHelpers::PropertyData<bool>(2574, QMetaType::Bool, QMC::DefaultPropertyFlags | QMC::Constant),
        // property 'schedulerWeatherGracePeriod'
        QtMocHelpers::PropertyData<uint>(2575, QMetaType::UInt, QMC::DefaultPropertyFlags | QMC::Writable | QMC::StdCppSet, 826),
        // property 'isSchedulerWeatherGracePeriodImmutable'
        QtMocHelpers::PropertyData<bool>(2576, QMetaType::Bool, QMC::DefaultPropertyFlags | QMC::Constant),
        // property 'schedulerWeatherShutdownDelay'
        QtMocHelpers::PropertyData<uint>(2577, QMetaType::UInt, QMC::DefaultPropertyFlags | QMC::Writable | QMC::StdCppSet, 827),
        // property 'isSchedulerWeatherShutdownDelayImmutable'
        QtMocHelpers::PropertyData<bool>(2578, QMetaType::Bool, QMC::DefaultPropertyFlags | QMC::Constant),
        // property 'schedulerSafetyMonitorConnectionString'
        QtMocHelpers::PropertyData<QString>(2579, QMetaType::QString, QMC::DefaultPropertyFlags | QMC::Writable | QMC::StdCppSet, 828),
        // property 'isSchedulerSafetyMonitorConnectionStringImmutable'
        QtMocHelpers::PropertyData<bool>(2580, QMetaType::Bool, QMC::DefaultPropertyFlags | QMC::Constant),
        // property 'schedulerTwilight'
        QtMocHelpers::PropertyData<bool>(2581, QMetaType::Bool, QMC::DefaultPropertyFlags | QMC::Writable | QMC::StdCppSet, 829),
        // property 'isSchedulerTwilightImmutable'
        QtMocHelpers::PropertyData<bool>(2582, QMetaType::Bool, QMC::DefaultPropertyFlags | QMC::Constant),
        // property 'schedulerCompleteSequences'
        QtMocHelpers::PropertyData<bool>(2583, QMetaType::Bool, QMC::DefaultPropertyFlags | QMC::Writable | QMC::StdCppSet, 830),
        // property 'isSchedulerCompleteSequencesImmutable'
        QtMocHelpers::PropertyData<bool>(2584, QMetaType::Bool, QMC::DefaultPropertyFlags | QMC::Constant),
        // property 'schedulerRepeatEverything'
        QtMocHelpers::PropertyData<bool>(2585, QMetaType::Bool, QMC::DefaultPropertyFlags | QMC::Writable | QMC::StdCppSet, 831),
        // property 'isSchedulerRepeatEverythingImmutable'
        QtMocHelpers::PropertyData<bool>(2586, QMetaType::Bool, QMC::DefaultPropertyFlags | QMC::Constant),
        // property 'schedulerRepeatSequences'
        QtMocHelpers::PropertyData<bool>(2587, QMetaType::Bool, QMC::DefaultPropertyFlags | QMC::Writable | QMC::StdCppSet, 832),
        // property 'isSchedulerRepeatSequencesImmutable'
        QtMocHelpers::PropertyData<bool>(2588, QMetaType::Bool, QMC::DefaultPropertyFlags | QMC::Constant),
        // property 'schedulerUntilTerminated'
        QtMocHelpers::PropertyData<bool>(2589, QMetaType::Bool, QMC::DefaultPropertyFlags | QMC::Writable | QMC::StdCppSet, 833),
        // property 'isSchedulerUntilTerminatedImmutable'
        QtMocHelpers::PropertyData<bool>(2590, QMetaType::Bool, QMC::DefaultPropertyFlags | QMC::Constant),
        // property 'schedulerUntil'
        QtMocHelpers::PropertyData<bool>(2591, QMetaType::Bool, QMC::DefaultPropertyFlags | QMC::Writable | QMC::StdCppSet, 834),
        // property 'isSchedulerUntilImmutable'
        QtMocHelpers::PropertyData<bool>(2592, QMetaType::Bool, QMC::DefaultPropertyFlags | QMC::Constant),
        // property 'schedulerUntilValue'
        QtMocHelpers::PropertyData<QString>(2593, QMetaType::QString, QMC::DefaultPropertyFlags | QMC::Writable | QMC::StdCppSet, 835),
        // property 'isSchedulerUntilValueImmutable'
        QtMocHelpers::PropertyData<bool>(2594, QMetaType::Bool, QMC::DefaultPropertyFlags | QMC::Constant),
        // property 'schedulerExecutionSequencesLimit'
        QtMocHelpers::PropertyData<uint>(2595, QMetaType::UInt, QMC::DefaultPropertyFlags | QMC::Writable | QMC::StdCppSet, 836),
        // property 'isSchedulerExecutionSequencesLimitImmutable'
        QtMocHelpers::PropertyData<bool>(2596, QMetaType::Bool, QMC::DefaultPropertyFlags | QMC::Constant),
        // property 'analyzeRestartWithEkos'
        QtMocHelpers::PropertyData<bool>(2597, QMetaType::Bool, QMC::DefaultPropertyFlags | QMC::Writable | QMC::StdCppSet, 837),
        // property 'isAnalyzeRestartWithEkosImmutable'
        QtMocHelpers::PropertyData<bool>(2598, QMetaType::Bool, QMC::DefaultPropertyFlags | QMC::Constant),
        // property 'analyzeAlternativeDirectoryName'
        QtMocHelpers::PropertyData<QString>(2599, QMetaType::QString, QMC::DefaultPropertyFlags | QMC::Writable | QMC::StdCppSet, 838),
        // property 'isAnalyzeAlternativeDirectoryNameImmutable'
        QtMocHelpers::PropertyData<bool>(2600, QMetaType::Bool, QMC::DefaultPropertyFlags | QMC::Constant),
        // property 'analyzeHFR'
        QtMocHelpers::PropertyData<bool>(2601, QMetaType::Bool, QMC::DefaultPropertyFlags | QMC::Writable | QMC::StdCppSet, 839),
        // property 'isAnalyzeHFRImmutable'
        QtMocHelpers::PropertyData<bool>(2602, QMetaType::Bool, QMC::DefaultPropertyFlags | QMC::Constant),
        // property 'analyzeNumCaptureStars'
        QtMocHelpers::PropertyData<bool>(2603, QMetaType::Bool, QMC::DefaultPropertyFlags | QMC::Writable | QMC::StdCppSet, 840),
        // property 'isAnalyzeNumCaptureStarsImmutable'
        QtMocHelpers::PropertyData<bool>(2604, QMetaType::Bool, QMC::DefaultPropertyFlags | QMC::Constant),
        // property 'analyzeMedian'
        QtMocHelpers::PropertyData<bool>(2605, QMetaType::Bool, QMC::DefaultPropertyFlags | QMC::Writable | QMC::StdCppSet, 841),
        // property 'isAnalyzeMedianImmutable'
        QtMocHelpers::PropertyData<bool>(2606, QMetaType::Bool, QMC::DefaultPropertyFlags | QMC::Constant),
        // property 'analyzeEccentricity'
        QtMocHelpers::PropertyData<bool>(2607, QMetaType::Bool, QMC::DefaultPropertyFlags | QMC::Writable | QMC::StdCppSet, 842),
        // property 'isAnalyzeEccentricityImmutable'
        QtMocHelpers::PropertyData<bool>(2608, QMetaType::Bool, QMC::DefaultPropertyFlags | QMC::Constant),
        // property 'analyzeTemperature'
        QtMocHelpers::PropertyData<bool>(2609, QMetaType::Bool, QMC::DefaultPropertyFlags | QMC::Writable | QMC::StdCppSet, 843),
        // property 'isAnalyzeTemperatureImmutable'
        QtMocHelpers::PropertyData<bool>(2610, QMetaType::Bool, QMC::DefaultPropertyFlags | QMC::Constant),
        // property 'focusPosition'
        QtMocHelpers::PropertyData<bool>(2611, QMetaType::Bool, QMC::DefaultPropertyFlags | QMC::Writable | QMC::StdCppSet, 844),
        // property 'isFocusPositionImmutable'
        QtMocHelpers::PropertyData<bool>(2612, QMetaType::Bool, QMC::DefaultPropertyFlags | QMC::Constant),
        // property 'analyzeNumStars'
        QtMocHelpers::PropertyData<bool>(2613, QMetaType::Bool, QMC::DefaultPropertyFlags | QMC::Writable | QMC::StdCppSet, 845),
        // property 'isAnalyzeNumStarsImmutable'
        QtMocHelpers::PropertyData<bool>(2614, QMetaType::Bool, QMC::DefaultPropertyFlags | QMC::Constant),
        // property 'analyzeSkyBg'
        QtMocHelpers::PropertyData<bool>(2615, QMetaType::Bool, QMC::DefaultPropertyFlags | QMC::Writable | QMC::StdCppSet, 846),
        // property 'isAnalyzeSkyBgImmutable'
        QtMocHelpers::PropertyData<bool>(2616, QMetaType::Bool, QMC::DefaultPropertyFlags | QMC::Constant),
        // property 'analyzeSNR'
        QtMocHelpers::PropertyData<bool>(2617, QMetaType::Bool, QMC::DefaultPropertyFlags | QMC::Writable | QMC::StdCppSet, 847),
        // property 'isAnalyzeSNRImmutable'
        QtMocHelpers::PropertyData<bool>(2618, QMetaType::Bool, QMC::DefaultPropertyFlags | QMC::Constant),
        // property 'analyzeRA'
        QtMocHelpers::PropertyData<bool>(2619, QMetaType::Bool, QMC::DefaultPropertyFlags | QMC::Writable | QMC::StdCppSet, 848),
        // property 'isAnalyzeRAImmutable'
        QtMocHelpers::PropertyData<bool>(2620, QMetaType::Bool, QMC::DefaultPropertyFlags | QMC::Constant),
        // property 'analyzeDEC'
        QtMocHelpers::PropertyData<bool>(2621, QMetaType::Bool, QMC::DefaultPropertyFlags | QMC::Writable | QMC::StdCppSet, 849),
        // property 'isAnalyzeDECImmutable'
        QtMocHelpers::PropertyData<bool>(2622, QMetaType::Bool, QMC::DefaultPropertyFlags | QMC::Constant),
        // property 'analyzeRAp'
        QtMocHelpers::PropertyData<bool>(2623, QMetaType::Bool, QMC::DefaultPropertyFlags | QMC::Writable | QMC::StdCppSet, 850),
        // property 'isAnalyzeRApImmutable'
        QtMocHelpers::PropertyData<bool>(2624, QMetaType::Bool, QMC::DefaultPropertyFlags | QMC::Constant),
        // property 'analyzeDECp'
        QtMocHelpers::PropertyData<bool>(2625, QMetaType::Bool, QMC::DefaultPropertyFlags | QMC::Writable | QMC::StdCppSet, 851),
        // property 'isAnalyzeDECpImmutable'
        QtMocHelpers::PropertyData<bool>(2626, QMetaType::Bool, QMC::DefaultPropertyFlags | QMC::Constant),
        // property 'analyzeDrift'
        QtMocHelpers::PropertyData<bool>(2627, QMetaType::Bool, QMC::DefaultPropertyFlags | QMC::Writable | QMC::StdCppSet, 852),
        // property 'isAnalyzeDriftImmutable'
        QtMocHelpers::PropertyData<bool>(2628, QMetaType::Bool, QMC::DefaultPropertyFlags | QMC::Constant),
        // property 'analyzeRMS'
        QtMocHelpers::PropertyData<bool>(2629, QMetaType::Bool, QMC::DefaultPropertyFlags | QMC::Writable | QMC::StdCppSet, 853),
        // property 'isAnalyzeRMSImmutable'
        QtMocHelpers::PropertyData<bool>(2630, QMetaType::Bool, QMC::DefaultPropertyFlags | QMC::Constant),
        // property 'analyzeTargetDistance'
        QtMocHelpers::PropertyData<bool>(2631, QMetaType::Bool, QMC::DefaultPropertyFlags | QMC::Writable | QMC::StdCppSet, 854),
        // property 'isAnalyzeTargetDistanceImmutable'
        QtMocHelpers::PropertyData<bool>(2632, QMetaType::Bool, QMC::DefaultPropertyFlags | QMC::Constant),
        // property 'analyzeRMSC'
        QtMocHelpers::PropertyData<bool>(2633, QMetaType::Bool, QMC::DefaultPropertyFlags | QMC::Writable | QMC::StdCppSet, 855),
        // property 'isAnalyzeRMSCImmutable'
        QtMocHelpers::PropertyData<bool>(2634, QMetaType::Bool, QMC::DefaultPropertyFlags | QMC::Constant),
        // property 'analyzeMountRA'
        QtMocHelpers::PropertyData<bool>(2635, QMetaType::Bool, QMC::DefaultPropertyFlags | QMC::Writable | QMC::StdCppSet, 856),
        // property 'isAnalyzeMountRAImmutable'
        QtMocHelpers::PropertyData<bool>(2636, QMetaType::Bool, QMC::DefaultPropertyFlags | QMC::Constant),
        // property 'analyzeMountDEC'
        QtMocHelpers::PropertyData<bool>(2637, QMetaType::Bool, QMC::DefaultPropertyFlags | QMC::Writable | QMC::StdCppSet, 857),
        // property 'isAnalyzeMountDECImmutable'
        QtMocHelpers::PropertyData<bool>(2638, QMetaType::Bool, QMC::DefaultPropertyFlags | QMC::Constant),
        // property 'analyzeMountHA'
        QtMocHelpers::PropertyData<bool>(2639, QMetaType::Bool, QMC::DefaultPropertyFlags | QMC::Writable | QMC::StdCppSet, 858),
        // property 'isAnalyzeMountHAImmutable'
        QtMocHelpers::PropertyData<bool>(2640, QMetaType::Bool, QMC::DefaultPropertyFlags | QMC::Constant),
        // property 'analyzeAz'
        QtMocHelpers::PropertyData<bool>(2641, QMetaType::Bool, QMC::DefaultPropertyFlags | QMC::Writable | QMC::StdCppSet, 859),
        // property 'isAnalyzeAzImmutable'
        QtMocHelpers::PropertyData<bool>(2642, QMetaType::Bool, QMC::DefaultPropertyFlags | QMC::Constant),
        // property 'analyzeAlt'
        QtMocHelpers::PropertyData<bool>(2643, QMetaType::Bool, QMC::DefaultPropertyFlags | QMC::Writable | QMC::StdCppSet, 860),
        // property 'isAnalyzeAltImmutable'
        QtMocHelpers::PropertyData<bool>(2644, QMetaType::Bool, QMC::DefaultPropertyFlags | QMC::Constant),
        // property 'analyzePierSide'
        QtMocHelpers::PropertyData<bool>(2645, QMetaType::Bool, QMC::DefaultPropertyFlags | QMC::Writable | QMC::StdCppSet, 861),
        // property 'isAnalyzePierSideImmutable'
        QtMocHelpers::PropertyData<bool>(2646, QMetaType::Bool, QMC::DefaultPropertyFlags | QMC::Constant),
        // property 'analyzeStatsYAxis'
        QtMocHelpers::PropertyData<QString>(2647, QMetaType::QString, QMC::DefaultPropertyFlags | QMC::Writable | QMC::StdCppSet, 862),
        // property 'isAnalyzeStatsYAxisImmutable'
        QtMocHelpers::PropertyData<bool>(2648, QMetaType::Bool, QMC::DefaultPropertyFlags | QMC::Constant),
        // property 'lastServer'
        QtMocHelpers::PropertyData<QString>(2649, QMetaType::QString, QMC::DefaultPropertyFlags | QMC::Writable | QMC::StdCppSet, 863),
        // property 'isLastServerImmutable'
        QtMocHelpers::PropertyData<bool>(2650, QMetaType::Bool, QMC::DefaultPropertyFlags | QMC::Constant),
        // property 'lastServerPort'
        QtMocHelpers::PropertyData<uint>(2651, QMetaType::UInt, QMC::DefaultPropertyFlags | QMC::Writable | QMC::StdCppSet, 864),
        // property 'isLastServerPortImmutable'
        QtMocHelpers::PropertyData<bool>(2652, QMetaType::Bool, QMC::DefaultPropertyFlags | QMC::Constant),
        // property 'lastWebManagerPort'
        QtMocHelpers::PropertyData<uint>(2653, QMetaType::UInt, QMC::DefaultPropertyFlags | QMC::Writable | QMC::StdCppSet, 865),
        // property 'isLastWebManagerPortImmutable'
        QtMocHelpers::PropertyData<bool>(2654, QMetaType::Bool, QMC::DefaultPropertyFlags | QMC::Constant),
        // property 'hIPSMemoryCache'
        QtMocHelpers::PropertyData<uint>(2655, QMetaType::UInt, QMC::DefaultPropertyFlags | QMC::Writable | QMC::StdCppSet, 866),
        // property 'isHIPSMemoryCacheImmutable'
        QtMocHelpers::PropertyData<bool>(2656, QMetaType::Bool, QMC::DefaultPropertyFlags | QMC::Constant),
        // property 'hIPSNetCache'
        QtMocHelpers::PropertyData<uint>(2657, QMetaType::UInt, QMC::DefaultPropertyFlags | QMC::Writable | QMC::StdCppSet, 867),
        // property 'isHIPSNetCacheImmutable'
        QtMocHelpers::PropertyData<bool>(2658, QMetaType::Bool, QMC::DefaultPropertyFlags | QMC::Constant),
        // property 'hIPSSource'
        QtMocHelpers::PropertyData<QString>(2659, QMetaType::QString, QMC::DefaultPropertyFlags | QMC::Writable | QMC::StdCppSet, 868),
        // property 'isHIPSSourceImmutable'
        QtMocHelpers::PropertyData<bool>(2660, QMetaType::Bool, QMC::DefaultPropertyFlags | QMC::Constant),
        // property 'hIPSBiLinearInterpolation'
        QtMocHelpers::PropertyData<bool>(2661, QMetaType::Bool, QMC::DefaultPropertyFlags | QMC::Writable | QMC::StdCppSet, 869),
        // property 'isHIPSBiLinearInterpolationImmutable'
        QtMocHelpers::PropertyData<bool>(2662, QMetaType::Bool, QMC::DefaultPropertyFlags | QMC::Constant),
        // property 'hIPSShowGrid'
        QtMocHelpers::PropertyData<bool>(2663, QMetaType::Bool, QMC::DefaultPropertyFlags | QMC::Writable | QMC::StdCppSet, 870),
        // property 'isHIPSShowGridImmutable'
        QtMocHelpers::PropertyData<bool>(2664, QMetaType::Bool, QMC::DefaultPropertyFlags | QMC::Constant),
        // property 'hIPSPanning'
        QtMocHelpers::PropertyData<bool>(2665, QMetaType::Bool, QMC::DefaultPropertyFlags | QMC::Writable | QMC::StdCppSet, 871),
        // property 'isHIPSPanningImmutable'
        QtMocHelpers::PropertyData<bool>(2666, QMetaType::Bool, QMC::DefaultPropertyFlags | QMC::Constant),
        // property 'showHIPS'
        QtMocHelpers::PropertyData<bool>(2667, QMetaType::Bool, QMC::DefaultPropertyFlags | QMC::Writable | QMC::StdCppSet, 872),
        // property 'isShowHIPSImmutable'
        QtMocHelpers::PropertyData<bool>(2668, QMetaType::Bool, QMC::DefaultPropertyFlags | QMC::Constant),
        // property 'hIPSUseOfflineSource'
        QtMocHelpers::PropertyData<bool>(2669, QMetaType::Bool, QMC::DefaultPropertyFlags | QMC::Writable | QMC::StdCppSet, 873),
        // property 'isHIPSUseOfflineSourceImmutable'
        QtMocHelpers::PropertyData<bool>(2670, QMetaType::Bool, QMC::DefaultPropertyFlags | QMC::Constant),
        // property 'hIPSOfflinePath'
        QtMocHelpers::PropertyData<QString>(2671, QMetaType::QString, QMC::DefaultPropertyFlags | QMC::Writable | QMC::StdCppSet, 874),
        // property 'isHIPSOfflinePathImmutable'
        QtMocHelpers::PropertyData<bool>(2672, QMetaType::Bool, QMC::DefaultPropertyFlags | QMC::Constant),
        // property 'terrainSource'
        QtMocHelpers::PropertyData<QString>(2673, QMetaType::QString, QMC::DefaultPropertyFlags | QMC::Writable | QMC::StdCppSet, 875),
        // property 'isTerrainSourceImmutable'
        QtMocHelpers::PropertyData<bool>(2674, QMetaType::Bool, QMC::DefaultPropertyFlags | QMC::Constant),
        // property 'terrainSourceCorrectAz'
        QtMocHelpers::PropertyData<int>(2675, QMetaType::Int, QMC::DefaultPropertyFlags | QMC::Writable | QMC::StdCppSet, 876),
        // property 'isTerrainSourceCorrectAzImmutable'
        QtMocHelpers::PropertyData<bool>(2676, QMetaType::Bool, QMC::DefaultPropertyFlags | QMC::Constant),
        // property 'terrainSourceCorrectAlt'
        QtMocHelpers::PropertyData<int>(2677, QMetaType::Int, QMC::DefaultPropertyFlags | QMC::Writable | QMC::StdCppSet, 877),
        // property 'isTerrainSourceCorrectAltImmutable'
        QtMocHelpers::PropertyData<bool>(2678, QMetaType::Bool, QMC::DefaultPropertyFlags | QMC::Constant),
        // property 'terrainDownsampling'
        QtMocHelpers::PropertyData<int>(2679, QMetaType::Int, QMC::DefaultPropertyFlags | QMC::Writable | QMC::StdCppSet, 878),
        // property 'isTerrainDownsamplingImmutable'
        QtMocHelpers::PropertyData<bool>(2680, QMetaType::Bool, QMC::DefaultPropertyFlags | QMC::Constant),
        // property 'terrainPanning'
        QtMocHelpers::PropertyData<bool>(2681, QMetaType::Bool, QMC::DefaultPropertyFlags | QMC::Writable | QMC::StdCppSet, 879),
        // property 'isTerrainPanningImmutable'
        QtMocHelpers::PropertyData<bool>(2682, QMetaType::Bool, QMC::DefaultPropertyFlags | QMC::Constant),
        // property 'showTerrain'
        QtMocHelpers::PropertyData<bool>(2683, QMetaType::Bool, QMC::DefaultPropertyFlags | QMC::Writable | QMC::StdCppSet, 880),
        // property 'isShowTerrainImmutable'
        QtMocHelpers::PropertyData<bool>(2684, QMetaType::Bool, QMC::DefaultPropertyFlags | QMC::Constant),
        // property 'terrainSkipSpeedup'
        QtMocHelpers::PropertyData<bool>(2685, QMetaType::Bool, QMC::DefaultPropertyFlags | QMC::Writable | QMC::StdCppSet, 881),
        // property 'isTerrainSkipSpeedupImmutable'
        QtMocHelpers::PropertyData<bool>(2686, QMetaType::Bool, QMC::DefaultPropertyFlags | QMC::Constant),
        // property 'terrainTransparencySpeedup'
        QtMocHelpers::PropertyData<bool>(2687, QMetaType::Bool, QMC::DefaultPropertyFlags | QMC::Writable | QMC::StdCppSet, 882),
        // property 'isTerrainTransparencySpeedupImmutable'
        QtMocHelpers::PropertyData<bool>(2688, QMetaType::Bool, QMC::DefaultPropertyFlags | QMC::Constant),
        // property 'terrainSmoothPixels'
        QtMocHelpers::PropertyData<bool>(2689, QMetaType::Bool, QMC::DefaultPropertyFlags | QMC::Writable | QMC::StdCppSet, 883),
        // property 'isTerrainSmoothPixelsImmutable'
        QtMocHelpers::PropertyData<bool>(2690, QMetaType::Bool, QMC::DefaultPropertyFlags | QMC::Constant),
        // property 'showImageOverlays'
        QtMocHelpers::PropertyData<bool>(2691, QMetaType::Bool, QMC::DefaultPropertyFlags | QMC::Writable | QMC::StdCppSet, 884),
        // property 'isShowImageOverlaysImmutable'
        QtMocHelpers::PropertyData<bool>(2692, QMetaType::Bool, QMC::DefaultPropertyFlags | QMC::Constant),
        // property 'showImageOverlaysBelowCatalogs'
        QtMocHelpers::PropertyData<bool>(2693, QMetaType::Bool, QMC::DefaultPropertyFlags | QMC::Writable | QMC::StdCppSet, 885),
        // property 'isShowImageOverlaysBelowCatalogsImmutable'
        QtMocHelpers::PropertyData<bool>(2694, QMetaType::Bool, QMC::DefaultPropertyFlags | QMC::Constant),
        // property 'showSelectedImageOverlay'
        QtMocHelpers::PropertyData<bool>(2695, QMetaType::Bool, QMC::DefaultPropertyFlags | QMC::Writable | QMC::StdCppSet, 886),
        // property 'isShowSelectedImageOverlayImmutable'
        QtMocHelpers::PropertyData<bool>(2696, QMetaType::Bool, QMC::DefaultPropertyFlags | QMC::Constant),
        // property 'imageOverlayMaxDimension'
        QtMocHelpers::PropertyData<int>(2697, QMetaType::Int, QMC::DefaultPropertyFlags | QMC::Writable | QMC::StdCppSet, 887),
        // property 'isImageOverlayMaxDimensionImmutable'
        QtMocHelpers::PropertyData<bool>(2698, QMetaType::Bool, QMC::DefaultPropertyFlags | QMC::Constant),
        // property 'imageOverlayTimeout'
        QtMocHelpers::PropertyData<int>(2699, QMetaType::Int, QMC::DefaultPropertyFlags | QMC::Writable | QMC::StdCppSet, 888),
        // property 'isImageOverlayTimeoutImmutable'
        QtMocHelpers::PropertyData<bool>(2700, QMetaType::Bool, QMC::DefaultPropertyFlags | QMC::Constant),
        // property 'imageOverlayDefaultScale'
        QtMocHelpers::PropertyData<double>(2701, QMetaType::Double, QMC::DefaultPropertyFlags | QMC::Writable | QMC::StdCppSet, 889),
        // property 'isImageOverlayDefaultScaleImmutable'
        QtMocHelpers::PropertyData<bool>(2702, QMetaType::Bool, QMC::DefaultPropertyFlags | QMC::Constant),
        // property 'defaultObservatoryWeatherSource'
        QtMocHelpers::PropertyData<QString>(2703, QMetaType::QString, QMC::DefaultPropertyFlags | QMC::Writable | QMC::StdCppSet, 890),
        // property 'isDefaultObservatoryWeatherSourceImmutable'
        QtMocHelpers::PropertyData<bool>(2704, QMetaType::Bool, QMC::DefaultPropertyFlags | QMC::Constant),
        // property 'warningActionsActive'
        QtMocHelpers::PropertyData<bool>(2705, QMetaType::Bool, QMC::DefaultPropertyFlags | QMC::Writable | QMC::StdCppSet, 891),
        // property 'isWarningActionsActiveImmutable'
        QtMocHelpers::PropertyData<bool>(2706, QMetaType::Bool, QMC::DefaultPropertyFlags | QMC::Constant),
        // property 'alertActionsActive'
        QtMocHelpers::PropertyData<bool>(2707, QMetaType::Bool, QMC::DefaultPropertyFlags | QMC::Writable | QMC::StdCppSet, 892),
        // property 'isAlertActionsActiveImmutable'
        QtMocHelpers::PropertyData<bool>(2708, QMetaType::Bool, QMC::DefaultPropertyFlags | QMC::Constant),
        // property 'weatherWarningCloseDome'
        QtMocHelpers::PropertyData<bool>(2709, QMetaType::Bool, QMC::DefaultPropertyFlags | QMC::Writable | QMC::StdCppSet, 893),
        // property 'isWeatherWarningCloseDomeImmutable'
        QtMocHelpers::PropertyData<bool>(2710, QMetaType::Bool, QMC::DefaultPropertyFlags | QMC::Constant),
        // property 'weatherWarningCloseShutter'
        QtMocHelpers::PropertyData<bool>(2711, QMetaType::Bool, QMC::DefaultPropertyFlags | QMC::Writable | QMC::StdCppSet, 894),
        // property 'isWeatherWarningCloseShutterImmutable'
        QtMocHelpers::PropertyData<bool>(2712, QMetaType::Bool, QMC::DefaultPropertyFlags | QMC::Constant),
        // property 'weatherWarningStopScheduler'
        QtMocHelpers::PropertyData<bool>(2713, QMetaType::Bool, QMC::DefaultPropertyFlags | QMC::Writable | QMC::StdCppSet, 895),
        // property 'isWeatherWarningStopSchedulerImmutable'
        QtMocHelpers::PropertyData<bool>(2714, QMetaType::Bool, QMC::DefaultPropertyFlags | QMC::Constant),
        // property 'weatherWarningDelay'
        QtMocHelpers::PropertyData<uint>(2715, QMetaType::UInt, QMC::DefaultPropertyFlags | QMC::Writable | QMC::StdCppSet, 896),
        // property 'isWeatherWarningDelayImmutable'
        QtMocHelpers::PropertyData<bool>(2716, QMetaType::Bool, QMC::DefaultPropertyFlags | QMC::Constant),
        // property 'weatherAlertCloseDome'
        QtMocHelpers::PropertyData<bool>(2717, QMetaType::Bool, QMC::DefaultPropertyFlags | QMC::Writable | QMC::StdCppSet, 897),
        // property 'isWeatherAlertCloseDomeImmutable'
        QtMocHelpers::PropertyData<bool>(2718, QMetaType::Bool, QMC::DefaultPropertyFlags | QMC::Constant),
        // property 'weatherAlertCloseShutter'
        QtMocHelpers::PropertyData<bool>(2719, QMetaType::Bool, QMC::DefaultPropertyFlags | QMC::Writable | QMC::StdCppSet, 898),
        // property 'isWeatherAlertCloseShutterImmutable'
        QtMocHelpers::PropertyData<bool>(2720, QMetaType::Bool, QMC::DefaultPropertyFlags | QMC::Constant),
        // property 'weatherAlertStopScheduler'
        QtMocHelpers::PropertyData<bool>(2721, QMetaType::Bool, QMC::DefaultPropertyFlags | QMC::Writable | QMC::StdCppSet, 899),
        // property 'isWeatherAlertStopSchedulerImmutable'
        QtMocHelpers::PropertyData<bool>(2722, QMetaType::Bool, QMC::DefaultPropertyFlags | QMC::Constant),
        // property 'weatherAlertDelay'
        QtMocHelpers::PropertyData<uint>(2723, QMetaType::UInt, QMC::DefaultPropertyFlags | QMC::Writable | QMC::StdCppSet, 900),
        // property 'isWeatherAlertDelayImmutable'
        QtMocHelpers::PropertyData<bool>(2724, QMetaType::Bool, QMC::DefaultPropertyFlags | QMC::Constant),
        // property 'observatoryStatusUseDome'
        QtMocHelpers::PropertyData<bool>(2725, QMetaType::Bool, QMC::DefaultPropertyFlags | QMC::Writable | QMC::StdCppSet, 901),
        // property 'isObservatoryStatusUseDomeImmutable'
        QtMocHelpers::PropertyData<bool>(2726, QMetaType::Bool, QMC::DefaultPropertyFlags | QMC::Constant),
        // property 'observatoryStatusUseShutter'
        QtMocHelpers::PropertyData<bool>(2727, QMetaType::Bool, QMC::DefaultPropertyFlags | QMC::Writable | QMC::StdCppSet, 902),
        // property 'isObservatoryStatusUseShutterImmutable'
        QtMocHelpers::PropertyData<bool>(2728, QMetaType::Bool, QMC::DefaultPropertyFlags | QMC::Constant),
        // property 'observatoryStatusUseWeather'
        QtMocHelpers::PropertyData<bool>(2729, QMetaType::Bool, QMC::DefaultPropertyFlags | QMC::Writable | QMC::StdCppSet, 903),
        // property 'isObservatoryStatusUseWeatherImmutable'
        QtMocHelpers::PropertyData<bool>(2730, QMetaType::Bool, QMC::DefaultPropertyFlags | QMC::Constant),
        // property 'weatherAutoScaleValues'
        QtMocHelpers::PropertyData<bool>(2731, QMetaType::Bool, QMC::DefaultPropertyFlags | QMC::Writable | QMC::StdCppSet, 904),
        // property 'isWeatherAutoScaleValuesImmutable'
        QtMocHelpers::PropertyData<bool>(2732, QMetaType::Bool, QMC::DefaultPropertyFlags | QMC::Constant),
        // property 'aSTAPExecutable'
        QtMocHelpers::PropertyData<QString>(2733, QMetaType::QString, QMC::DefaultPropertyFlags | QMC::Writable | QMC::StdCppSet, 905),
        // property 'isASTAPExecutableImmutable'
        QtMocHelpers::PropertyData<bool>(2734, QMetaType::Bool, QMC::DefaultPropertyFlags | QMC::Constant),
        // property 'aSTAPDownSample'
        QtMocHelpers::PropertyData<bool>(2735, QMetaType::Bool, QMC::DefaultPropertyFlags | QMC::Writable | QMC::StdCppSet, 906),
        // property 'isASTAPDownSampleImmutable'
        QtMocHelpers::PropertyData<bool>(2736, QMetaType::Bool, QMC::DefaultPropertyFlags | QMC::Constant),
        // property 'aSTAPDownSampleValue'
        QtMocHelpers::PropertyData<double>(2737, QMetaType::Double, QMC::DefaultPropertyFlags | QMC::Writable | QMC::StdCppSet, 907),
        // property 'isASTAPDownSampleValueImmutable'
        QtMocHelpers::PropertyData<bool>(2738, QMetaType::Bool, QMC::DefaultPropertyFlags | QMC::Constant),
        // property 'aSTAPSearchRadius'
        QtMocHelpers::PropertyData<bool>(2739, QMetaType::Bool, QMC::DefaultPropertyFlags | QMC::Writable | QMC::StdCppSet, 908),
        // property 'isASTAPSearchRadiusImmutable'
        QtMocHelpers::PropertyData<bool>(2740, QMetaType::Bool, QMC::DefaultPropertyFlags | QMC::Constant),
        // property 'aSTAPSearchRadiusValue'
        QtMocHelpers::PropertyData<double>(2741, QMetaType::Double, QMC::DefaultPropertyFlags | QMC::Writable | QMC::StdCppSet, 909),
        // property 'isASTAPSearchRadiusValueImmutable'
        QtMocHelpers::PropertyData<bool>(2742, QMetaType::Bool, QMC::DefaultPropertyFlags | QMC::Constant),
        // property 'aSTAPUpdateFITS'
        QtMocHelpers::PropertyData<bool>(2743, QMetaType::Bool, QMC::DefaultPropertyFlags | QMC::Writable | QMC::StdCppSet, 910),
        // property 'isASTAPUpdateFITSImmutable'
        QtMocHelpers::PropertyData<bool>(2744, QMetaType::Bool, QMC::DefaultPropertyFlags | QMC::Constant),
        // property 'aSTAPLargeSearchWindow'
        QtMocHelpers::PropertyData<bool>(2745, QMetaType::Bool, QMC::DefaultPropertyFlags | QMC::Writable | QMC::StdCppSet, 911),
        // property 'isASTAPLargeSearchWindowImmutable'
        QtMocHelpers::PropertyData<bool>(2746, QMetaType::Bool, QMC::DefaultPropertyFlags | QMC::Constant),
        // property 'mosaicTransparencyAuto'
        QtMocHelpers::PropertyData<bool>(2747, QMetaType::Bool, QMC::DefaultPropertyFlags | QMC::Writable | QMC::StdCppSet, 912),
        // property 'isMosaicTransparencyAutoImmutable'
        QtMocHelpers::PropertyData<bool>(2748, QMetaType::Bool, QMC::DefaultPropertyFlags | QMC::Constant),
        // property 'mosaicTransparencyLevel'
        QtMocHelpers::PropertyData<double>(2749, QMetaType::Double, QMC::DefaultPropertyFlags | QMC::Writable | QMC::StdCppSet, 913),
        // property 'isMosaicTransparencyLevelImmutable'
        QtMocHelpers::PropertyData<bool>(2750, QMetaType::Bool, QMC::DefaultPropertyFlags | QMC::Constant),
        // property 'mCPEnabled'
        QtMocHelpers::PropertyData<bool>(2751, QMetaType::Bool, QMC::DefaultPropertyFlags | QMC::Writable | QMC::StdCppSet, 914),
        // property 'isMCPEnabledImmutable'
        QtMocHelpers::PropertyData<bool>(2752, QMetaType::Bool, QMC::DefaultPropertyFlags | QMC::Constant),
        // property 'mCPPort'
        QtMocHelpers::PropertyData<uint>(2753, QMetaType::UInt, QMC::DefaultPropertyFlags | QMC::Writable | QMC::StdCppSet, 915),
        // property 'isMCPPortImmutable'
        QtMocHelpers::PropertyData<bool>(2754, QMetaType::Bool, QMC::DefaultPropertyFlags | QMC::Constant),
        // property 'mCPReadOnlyMode'
        QtMocHelpers::PropertyData<bool>(2755, QMetaType::Bool, QMC::DefaultPropertyFlags | QMC::Writable | QMC::StdCppSet, 916),
        // property 'isMCPReadOnlyModeImmutable'
        QtMocHelpers::PropertyData<bool>(2756, QMetaType::Bool, QMC::DefaultPropertyFlags | QMC::Constant),
        // property 'mCPDisabledTools'
        QtMocHelpers::PropertyData<QStringList>(2757, QMetaType::QStringList, QMC::DefaultPropertyFlags | QMC::Writable | QMC::StdCppSet, 917),
        // property 'isMCPDisabledToolsImmutable'
        QtMocHelpers::PropertyData<bool>(2758, QMetaType::Bool, QMC::DefaultPropertyFlags | QMC::Constant),
    };
    QtMocHelpers::UintData qt_enums {
    };
    return QtMocHelpers::metaObjectData<Options, qt_meta_tag_ZN7OptionsE_t>(QMC::MetaObjectFlag{}, qt_stringData,
            qt_methods, qt_properties, qt_enums);
}
Q_CONSTINIT const QMetaObject Options::staticMetaObject = { {
    QMetaObject::SuperData::link<KConfigSkeleton::staticMetaObject>(),
    qt_staticMetaObjectStaticContent<qt_meta_tag_ZN7OptionsE_t>.stringdata,
    qt_staticMetaObjectStaticContent<qt_meta_tag_ZN7OptionsE_t>.data,
    qt_static_metacall,
    nullptr,
    qt_staticMetaObjectRelocatingContent<qt_meta_tag_ZN7OptionsE_t>.metaTypes,
    nullptr
} };

void Options::qt_static_metacall(QObject *_o, QMetaObject::Call _c, int _id, void **_a)
{
    auto *_t = static_cast<Options *>(_o);
    if (_c == QMetaObject::InvokeMetaMethod) {
        switch (_id) {
        case 0: _t->PositionTimeBoxChanged(); break;
        case 1: _t->PositionFocusBoxChanged(); break;
        case 2: _t->PositionGeoBoxChanged(); break;
        case 3: _t->ShadeTimeBoxChanged(); break;
        case 4: _t->ShadeFocusBoxChanged(); break;
        case 5: _t->ShadeGeoBoxChanged(); break;
        case 6: _t->ShowInfoBoxesChanged(); break;
        case 7: _t->ShowTimeBoxChanged(); break;
        case 8: _t->ShowFocusBoxChanged(); break;
        case 9: _t->ShowGeoBoxChanged(); break;
        case 10: _t->StickyTimeBoxChanged(); break;
        case 11: _t->StickyFocusBoxChanged(); break;
        case 12: _t->StickyGeoBoxChanged(); break;
        case 13: _t->ShowStatusBarChanged(); break;
        case 14: _t->ShowAltAzFieldChanged(); break;
        case 15: _t->ShowRADecFieldChanged(); break;
        case 16: _t->ShowJ2000RADecFieldChanged(); break;
        case 17: _t->ShowSensorFOVChanged(); break;
        case 18: _t->WindowWidthChanged(); break;
        case 19: _t->WindowHeightChanged(); break;
        case 20: _t->KStarsGeometryChanged(); break;
        case 21: _t->RunStartupWizardChanged(); break;
        case 22: _t->CurrentThemeChanged(); break;
        case 23: _t->CatalogFileChanged(); break;
        case 24: _t->ShowCatalogChanged(); break;
        case 25: _t->ShowCatalogNamesChanged(); break;
        case 26: _t->ResolveNamesOnlineChanged(); break;
        case 27: _t->DSOCachePercentageChanged(); break;
        case 28: _t->DSOMinZoomFactorChanged(); break;
        case 29: _t->DSOCatalogFilenameChanged(); break;
        case 30: _t->DSODefaultCatalogFilenameChanged(); break;
        case 31: _t->INDIWindowWidthChanged(); break;
        case 32: _t->INDIWindowHeightChanged(); break;
        case 33: _t->INDIWindowGeometryChanged(); break;
        case 34: _t->useGeographicUpdateChanged(); break;
        case 35: _t->useTimeUpdateChanged(); break;
        case 36: _t->independentWindowINDIChanged(); break;
        case 37: _t->showTargetCrosshairChanged(); break;
        case 38: _t->showINDIMessagesChanged(); break;
        case 39: _t->showINDIwindowInitiallyChanged(); break;
        case 40: _t->maxFocusFrameFilesChanged(); break;
        case 41: _t->messageNotificationINDIChanged(); break;
        case 42: _t->timeSourceChanged(); break;
        case 43: _t->locationSourceChanged(); break;
        case 44: _t->useExternalSkyMapChanged(); break;
        case 45: _t->fitsDirChanged(); break;
        case 46: _t->serverTransferBufferSizeChanged(); break;
        case 47: _t->serverPortStartChanged(); break;
        case 48: _t->serverPortEndChanged(); break;
        case 49: _t->indiServerChanged(); break;
        case 50: _t->indiServerIsInternalChanged(); break;
        case 51: _t->indiDriversDirChanged(); break;
        case 52: _t->indiDriversAreInternalChanged(); break;
        case 53: _t->streamWindowWidthChanged(); break;
        case 54: _t->streamWindowHeightChanged(); break;
        case 55: _t->INDIMountLoggingChanged(); break;
        case 56: _t->INDIFocuserLoggingChanged(); break;
        case 57: _t->INDICCDLoggingChanged(); break;
        case 58: _t->INDIFilterWheelLoggingChanged(); break;
        case 59: _t->INDIDomeLoggingChanged(); break;
        case 60: _t->INDIDetectorLoggingChanged(); break;
        case 61: _t->INDIWeatherLoggingChanged(); break;
        case 62: _t->INDIAuxiliaryLoggingChanged(); break;
        case 63: _t->INDIRotatorLoggingChanged(); break;
        case 64: _t->INDIGPSLoggingChanged(); break;
        case 65: _t->INDIAOLoggingChanged(); break;
        case 66: _t->CityNameChanged(); break;
        case 67: _t->ProvinceNameChanged(); break;
        case 68: _t->CountryNameChanged(); break;
        case 69: _t->LongitudeChanged(); break;
        case 70: _t->LatitudeChanged(); break;
        case 71: _t->ElevationChanged(); break;
        case 72: _t->TimeZoneChanged(); break;
        case 73: _t->DSTChanged(); break;
        case 74: _t->UseAnimatedSlewingChanged(); break;
        case 75: _t->LeftClickSelectsObjectChanged(); break;
        case 76: _t->DefaultCursorChanged(); break;
        case 77: _t->FOVNamesChanged(); break;
        case 78: _t->FadePlanetTrailsChanged(); break;
        case 79: _t->FocusRAChanged(); break;
        case 80: _t->FocusDecChanged(); break;
        case 81: _t->FocusObjectChanged(); break;
        case 82: _t->IsTrackingChanged(); break;
        case 83: _t->HideOnSlewChanged(); break;
        case 84: _t->HideCBoundsChanged(); break;
        case 85: _t->HideCLinesChanged(); break;
        case 86: _t->SkyCultureChanged(); break;
        case 87: _t->HideCNamesChanged(); break;
        case 88: _t->HideGridsChanged(); break;
        case 89: _t->HideMilkyWayChanged(); break;
        case 90: _t->HideOtherChanged(); break;
        case 91: _t->HidePlanetsChanged(); break;
        case 92: _t->HideStarsChanged(); break;
        case 93: _t->HideLabelsChanged(); break;
        case 94: _t->ShowAsteroidsChanged(); break;
        case 95: _t->ShowAsteroidNamesChanged(); break;
        case 96: _t->OrbitalElementsAutoUpdateChanged(); break;
        case 97: _t->ShowCometsChanged(); break;
        case 98: _t->ShowCometComasChanged(); break;
        case 99: _t->ShowCometNamesChanged(); break;
        case 100: _t->ShowSupernovaeChanged(); break;
        case 101: _t->ShowSupernovaNamesChanged(); break;
        case 102: _t->MagnitudeLimitShowSupernovaeChanged(); break;
        case 103: _t->SupernovaDetectionAgeChanged(); break;
        case 104: _t->SupernovaDownloadUrlChanged(); break;
        case 105: _t->LimitSupernovaeByZoomChanged(); break;
        case 106: _t->SupernovaeHostOnlyChanged(); break;
        case 107: _t->SupernovaeClassifiedOnlyChanged(); break;
        case 108: _t->ShowSupernovaAlertsChanged(); break;
        case 109: _t->MagnitudeLimitAlertSupernovaeChanged(); break;
        case 110: _t->ShowCBoundsChanged(); break;
        case 111: _t->ShowHighlightedCBoundChanged(); break;
        case 112: _t->ShowCLinesChanged(); break;
        case 113: _t->ShowConstellationArtChanged(); break;
        case 114: _t->ShowCNamesChanged(); break;
        case 115: _t->ShowDeepSkyChanged(); break;
        case 116: _t->ShowEclipticChanged(); break;
        case 117: _t->ShowEquatorChanged(); break;
        case 118: _t->AutoSelectGridChanged(); break;
        case 119: _t->ShowEquatorialGridChanged(); break;
        case 120: _t->ShowHorizontalGridChanged(); break;
        case 121: _t->ShowLocalMeridianChanged(); break;
        case 122: _t->ShowGroundChanged(); break;
        case 123: _t->ShowHorizonChanged(); break;
        case 124: _t->ShowFlagsChanged(); break;
        case 125: _t->SimulateDaytimeChanged(); break;
        case 126: _t->ShowOtherChanged(); break;
        case 127: _t->ShowMilkyWayChanged(); break;
        case 128: _t->FillMilkyWayChanged(); break;
        case 129: _t->ShowSolarSystemChanged(); break;
        case 130: _t->ShowPlanetImagesChanged(); break;
        case 131: _t->ShowPlanetNamesChanged(); break;
        case 132: _t->ShowSunChanged(); break;
        case 133: _t->SunScaleChanged(); break;
        case 134: _t->ShowMoonChanged(); break;
        case 135: _t->MoonScaleChanged(); break;
        case 136: _t->ShowMercuryChanged(); break;
        case 137: _t->ShowVenusChanged(); break;
        case 138: _t->ShowMarsChanged(); break;
        case 139: _t->ShowJupiterChanged(); break;
        case 140: _t->ShowSaturnChanged(); break;
        case 141: _t->ShowUranusChanged(); break;
        case 142: _t->ShowNeptuneChanged(); break;
        case 143: _t->ShowPlutoChanged(); break;
        case 144: _t->ShowStarsChanged(); break;
        case 145: _t->ShowStarMagnitudesChanged(); break;
        case 146: _t->ShowStarsOverHIPSChanged(); break;
        case 147: _t->ShowStarNamesChanged(); break;
        case 148: _t->ShowDeepSkyMagnitudesChanged(); break;
        case 149: _t->ShowDeepSkyNamesChanged(); break;
        case 150: _t->ShowMosaicPanelChanged(); break;
        case 151: _t->SlewTimeScaleChanged(); break;
        case 152: _t->BoxBGModeChanged(); break;
        case 153: _t->ProjectionChanged(); break;
        case 154: _t->UseAbbrevConstellNamesChanged(); break;
        case 155: _t->UseLatinConstellNamesChanged(); break;
        case 156: _t->UseLocalConstellNamesChanged(); break;
        case 157: _t->UseAltAzChanged(); break;
        case 158: _t->UseAutoLabelChanged(); break;
        case 159: _t->UseAutoTrailChanged(); break;
        case 160: _t->UseHoverLabelChanged(); break;
        case 161: _t->UseRefractionChanged(); break;
        case 162: _t->UseRelativisticChanged(); break;
        case 163: _t->UseAntialiasChanged(); break;
        case 164: _t->ZoomFactorChanged(); break;
        case 165: _t->SkyRotationChanged(); break;
        case 166: _t->MirrorSkyMapChanged(); break;
        case 167: _t->ErectObserverCorrectionChanged(); break;
        case 168: _t->ZoomScrollFactorChanged(); break;
        case 169: _t->MagLimitAsteroidChanged(); break;
        case 170: _t->MagLimitAsteroidDownloadChanged(); break;
        case 171: _t->AsteroidLabelDensityChanged(); break;
        case 172: _t->MagLimitDrawDeepSkyChanged(); break;
        case 173: _t->MagLimitDrawDeepSkyZoomOutChanged(); break;
        case 174: _t->ShowUnknownMagObjectsChanged(); break;
        case 175: _t->ShowInlineImagesChanged(); break;
        case 176: _t->StarDensityChanged(); break;
        case 177: _t->MagLimitHideStarChanged(); break;
        case 178: _t->StarLabelDensityChanged(); break;
        case 179: _t->DeepSkyLabelDensityChanged(); break;
        case 180: _t->DeepSkyLongLabelsChanged(); break;
        case 181: _t->LabelFontScalingChanged(); break;
        case 182: _t->MaxRadCometNameChanged(); break;
        case 183: _t->UseGLChanged(); break;
        case 184: _t->RunClockChanged(); break;
        case 185: _t->ImagingPlannerAcceptOpenClusterChanged(); break;
        case 186: _t->ImagingPlannerAcceptNebulaChanged(); break;
        case 187: _t->ImagingPlannerAcceptGlobularClusterChanged(); break;
        case 188: _t->ImagingPlannerAcceptPlanetaryChanged(); break;
        case 189: _t->ImagingPlannerAcceptSupernovaRemnantChanged(); break;
        case 190: _t->ImagingPlannerAcceptGalaxyChanged(); break;
        case 191: _t->ImagingPlannerAcceptGalaxyClusterChanged(); break;
        case 192: _t->ImagingPlannerAcceptDarkNebulaChanged(); break;
        case 193: _t->ImagingPlannerAcceptOtherChanged(); break;
        case 194: _t->AstrobinAwardChanged(); break;
        case 195: _t->AstrobinMinRadiusChanged(); break;
        case 196: _t->AstrobinMaxRadiusChanged(); break;
        case 197: _t->ImagingPlannerUseArtificialHorizonChanged(); break;
        case 198: _t->ImagingPlannerMinHoursChanged(); break;
        case 199: _t->ImagingPlannerMinAltitudeChanged(); break;
        case 200: _t->ImagingPlannerMinMoonSeparationChanged(); break;
        case 201: _t->ImagingPlannerMaxMoonAltitudeChanged(); break;
        case 202: _t->ImagingPlannerShowPickedChanged(); break;
        case 203: _t->ImagingPlannerShowNotPickedChanged(); break;
        case 204: _t->ImagingPlannerDontCarePickedChanged(); break;
        case 205: _t->ImagingPlannerShowKeywordChanged(); break;
        case 206: _t->ImagingPlannerShowNotKeywordChanged(); break;
        case 207: _t->ImagingPlannerDontCareKeywordChanged(); break;
        case 208: _t->ImagingPlannerKeywordChanged(); break;
        case 209: _t->ImagingPlannerShowImagedChanged(); break;
        case 210: _t->ImagingPlannerShowNotImagedChanged(); break;
        case 211: _t->ImagingPlannerDontCareImagedChanged(); break;
        case 212: _t->ImagingPlannerShowAddedChanged(); break;
        case 213: _t->ImagingPlannerShowNotAddedChanged(); break;
        case 214: _t->ImagingPlannerDontCareAddedChanged(); break;
        case 215: _t->ImagingPlannerShowIgnoredChanged(); break;
        case 216: _t->ImagingPlannerShowNotIgnoredChanged(); break;
        case 217: _t->ImagingPlannerDontCareIgnoredChanged(); break;
        case 218: _t->ImagingPlannerHideAstrobinDetailsChanged(); break;
        case 219: _t->ImagingPlannerHideFiltersChanged(); break;
        case 220: _t->ImagingPlannerHideImageChanged(); break;
        case 221: _t->ImagingPlannerHideAltitudeGraphChanged(); break;
        case 222: _t->ImagingPlannerCatalogPathChanged(); break;
        case 223: _t->ImagingPlannerCenterOnSkyMapChanged(); break;
        case 224: _t->ImagingPlannerIndependentWindowChanged(); break;
        case 225: _t->ImagingPlannerStartSolvingImmediatelyChanged(); break;
        case 226: _t->ObsListSymbolChanged(); break;
        case 227: _t->ObsListTextChanged(); break;
        case 228: _t->ObsListPreferDSSChanged(); break;
        case 229: _t->ObsListPreferSDSSChanged(); break;
        case 230: _t->ObsListDemoteHoleChanged(); break;
        case 231: _t->ObsListHoleSizeChanged(); break;
        case 232: _t->ObsListCoverageChanged(); break;
        case 233: _t->ColorSchemeFileChanged(); break;
        case 234: _t->StarColorModeChanged(); break;
        case 235: _t->StarColorIntensityChanged(); break;
        case 236: _t->DomeSlitInvertedChanged(); break;
        case 237: _t->AngularRulerColorChanged(); break;
        case 238: _t->BoxBGColorChanged(); break;
        case 239: _t->BoxGrabColorChanged(); break;
        case 240: _t->BoxTextColorChanged(); break;
        case 241: _t->CBoundColorChanged(); break;
        case 242: _t->CBoundHighColorChanged(); break;
        case 243: _t->CLineColorChanged(); break;
        case 244: _t->CNameColorChanged(); break;
        case 245: _t->CompassColorChanged(); break;
        case 246: _t->EclipticColorChanged(); break;
        case 247: _t->EquatorColorChanged(); break;
        case 248: _t->EquatorialGridColorChanged(); break;
        case 249: _t->HorizontalGridColorChanged(); break;
        case 250: _t->SpecialObjectColorChanged(); break;
        case 251: _t->HorizonColorChanged(); break;
        case 252: _t->LocalMeridianColorChanged(); break;
        case 253: _t->MilkyWayWColorChanged(); break;
        case 254: _t->StarNameColorChanged(); break;
        case 255: _t->DeepSkyNameColorChanged(); break;
        case 256: _t->PlanetNameColorChanged(); break;
        case 257: _t->PlanetTrailColorChanged(); break;
        case 258: _t->SkyColorChanged(); break;
        case 259: _t->SkyColorDaytimeChanged(); break;
        case 260: _t->ArtificialHorizonColorChanged(); break;
        case 261: _t->TelescopeTargetColorChanged(); break;
        case 262: _t->VisibleSatColorChanged(); break;
        case 263: _t->SatColorChanged(); break;
        case 264: _t->SatLabelColorChanged(); break;
        case 265: _t->SupernovaColorChanged(); break;
        case 266: _t->AsteroidColorChanged(); break;
        case 267: _t->UserLabelColorChanged(); break;
        case 268: _t->RAGuideColorChanged(); break;
        case 269: _t->DEGuideColorChanged(); break;
        case 270: _t->SolverFOVColorChanged(); break;
        case 271: _t->xplanetIsInternalChanged(); break;
        case 272: _t->XplanetPathChanged(); break;
        case 273: _t->XplanetUseFIFOChanged(); break;
        case 274: _t->XplanetTimeoutChanged(); break;
        case 275: _t->XplanetAnimationDelayChanged(); break;
        case 276: _t->XplanetWidthChanged(); break;
        case 277: _t->XplanetHeightChanged(); break;
        case 278: _t->XplanetLabelChanged(); break;
        case 279: _t->XplanetLabelLocalTimeChanged(); break;
        case 280: _t->XplanetLabelGMTChanged(); break;
        case 281: _t->XplanetLabelStringChanged(); break;
        case 282: _t->XplanetFontSizeChanged(); break;
        case 283: _t->XplanetColorChanged(); break;
        case 284: _t->XplanetDateFormatChanged(); break;
        case 285: _t->XplanetLabelTLChanged(); break;
        case 286: _t->XplanetLabelTRChanged(); break;
        case 287: _t->XplanetLabelBRChanged(); break;
        case 288: _t->XplanetLabelBLChanged(); break;
        case 289: _t->XplanetGlareChanged(); break;
        case 290: _t->XplanetRandomChanged(); break;
        case 291: _t->XplanetLatLongChanged(); break;
        case 292: _t->XplanetLatitudeChanged(); break;
        case 293: _t->XplanetLongitudeChanged(); break;
        case 294: _t->XplanetProjectionChanged(); break;
        case 295: _t->XplanetBackgroundChanged(); break;
        case 296: _t->XplanetBackgroundImageChanged(); break;
        case 297: _t->XplanetBackgroundImagePathChanged(); break;
        case 298: _t->XplanetBackgroundColorChanged(); break;
        case 299: _t->XplanetBackgroundColorValueChanged(); break;
        case 300: _t->XplanetMagnitudeChanged(); break;
        case 301: _t->XplanetArcFileChanged(); break;
        case 302: _t->XplanetArcFilePathChanged(); break;
        case 303: _t->XplanetConfigFileChanged(); break;
        case 304: _t->XplanetConfigFilePathChanged(); break;
        case 305: _t->XplanetFOVChanged(); break;
        case 306: _t->XplanetMarkerFileChanged(); break;
        case 307: _t->XplanetMarkerFilePathChanged(); break;
        case 308: _t->XplanetMarkerBoundsChanged(); break;
        case 309: _t->XplanetMarkerBoundsPathChanged(); break;
        case 310: _t->XplanetStarmapChanged(); break;
        case 311: _t->XplanetStarmapPathChanged(); break;
        case 312: _t->XplanetQualityChanged(); break;
        case 313: _t->ShowSatellitesChanged(); break;
        case 314: _t->ShowVisibleSatellitesChanged(); break;
        case 315: _t->DrawSatellitesLikeStarsChanged(); break;
        case 316: _t->ShowSatellitesLabelsChanged(); break;
        case 317: _t->SelectedSatellitesChanged(); break;
        case 318: _t->KStarsFirstRunChanged(); break;
        case 319: _t->AlwaysRecomputeCoordinatesChanged(); break;
        case 320: _t->DefaultDSSImageSizeChanged(); break;
        case 321: _t->DSSPaddingChanged(); break;
        case 322: _t->VerboseLoggingChanged(); break;
        case 323: _t->RegularLoggingChanged(); break;
        case 324: _t->DisableLoggingChanged(); break;
        case 325: _t->LogToDefaultChanged(); break;
        case 326: _t->LogToFileChanged(); break;
        case 327: _t->FITSLoggingChanged(); break;
        case 328: _t->INDILoggingChanged(); break;
        case 329: _t->CaptureLoggingChanged(); break;
        case 330: _t->FocusLoggingChanged(); break;
        case 331: _t->SaveGuideImagesChanged(); break;
        case 332: _t->SaveAlignImagesChanged(); break;
        case 333: _t->SaveFailedAlignImagesChanged(); break;
        case 334: _t->DontSyncToRealTimeChanged(); break;
        case 335: _t->GuideLoggingChanged(); break;
        case 336: _t->AlignmentLoggingChanged(); break;
        case 337: _t->MountLoggingChanged(); break;
        case 338: _t->ObservatoryLoggingChanged(); break;
        case 339: _t->ImageDebayerEngineChanged(); break;
        case 340: _t->ImageDebayerAlgoChanged(); break;
        case 341: _t->StackDebayerEngineChanged(); break;
        case 342: _t->StackDebayerAlgoChanged(); break;
        case 343: _t->FITSWindowGeometryChanged(); break;
        case 344: _t->useFITSViewerChanged(); break;
        case 345: _t->singlePreviewFITSChanged(); break;
        case 346: _t->singleWindowCapturedFITSChanged(); break;
        case 347: _t->singleWindowOpenedFITSChanged(); break;
        case 348: _t->focusFITSOnNewImageChanged(); break;
        case 349: _t->independentWindowFITSChanged(); break;
        case 350: _t->liveStackerOwnProcessChanged(); break;
        case 351: _t->AutoDebayerChanged(); break;
        case 352: _t->Auto3DCubeChanged(); break;
        case 353: _t->AutoHFRChanged(); break;
        case 354: _t->QuickHFRChanged(); break;
        case 355: _t->StellarSolverPartitionChanged(); break;
        case 356: _t->AutoWCSChanged(); break;
        case 357: _t->LimitedResourcesModeChanged(); break;
        case 358: _t->NonLinearHistogramChanged(); break;
        case 359: _t->HIPSOpacityChanged(); break;
        case 360: _t->HIPSOffsetXChanged(); break;
        case 361: _t->HIPSOffsetYChanged(); break;
        case 362: _t->FitsSolverProfileChanged(); break;
        case 363: _t->FitsSolverModuleChanged(); break;
        case 364: _t->FitsSolverProfileIndecesChanged(); break;
        case 365: _t->FitsCatalogChanged(); break;
        case 366: _t->FitsCatObjShowNamesChanged(); break;
        case 367: _t->FitsSolverUseScaleChanged(); break;
        case 368: _t->FitsSolverUsePositionChanged(); break;
        case 369: _t->FitsSolverScaleChanged(); break;
        case 370: _t->FitsSolverImageScaleUnitsChanged(); break;
        case 371: _t->FitsSolverRadiusChanged(); break;
        case 372: _t->fitsLSHideGeneralChanged(); break;
        case 373: _t->fitsLSHideCalibrationChanged(); break;
        case 374: _t->fitsLSHideAlignmentChanged(); break;
        case 375: _t->fitsLSHideStackingChanged(); break;
        case 376: _t->fitsLSHidePostProcChanged(); break;
        case 377: _t->fitsLSCalcSNRChanged(); break;
        case 378: _t->fitsLSMasterDarkChanged(); break;
        case 379: _t->fitsLSMasterFlatChanged(); break;
        case 380: _t->fitsLSHotPixelsChanged(); break;
        case 381: _t->fitsLSColdPixelsChanged(); break;
        case 382: _t->fitsLSAlignMethodChanged(); break;
        case 383: _t->fitsLSNumInMemChanged(); break;
        case 384: _t->fitsLSDownscaleChanged(); break;
        case 385: _t->fitsLSWeightingChanged(); break;
        case 386: _t->fitsLSNormalizationChanged(); break;
        case 387: _t->fitsLSStackingMethodChanged(); break;
        case 388: _t->fitsLSLowSigmaChanged(); break;
        case 389: _t->fitsLSHighSigmaChanged(); break;
        case 390: _t->fitsLSWinsorCutoffChanged(); break;
        case 391: _t->fitsLSIterationsChanged(); break;
        case 392: _t->fitsLSKappaChanged(); break;
        case 393: _t->fitsLSAlphaChanged(); break;
        case 394: _t->fitsLSSigmaChanged(); break;
        case 395: _t->fitsPSFUpdateChanged(); break;
        case 396: _t->fitsLSPostProcChanged(); break;
        case 397: _t->fitsLSGradientAmtChanged(); break;
        case 398: _t->fitsLSDeconvAmtChanged(); break;
        case 399: _t->fitsLSPSFSigmaChanged(); break;
        case 400: _t->fitsLSDenoiseAmtChanged(); break;
        case 401: _t->fitsLSSharpenAmtChanged(); break;
        case 402: _t->fitsLSSharpenKernalChanged(); break;
        case 403: _t->fitsLSSharpenSigmaChanged(); break;
        case 404: _t->fitsLSMWindowGeometryChanged(); break;
        case 405: _t->fitsLSMVisibleColumnsChanged(); break;
        case 406: _t->fitsLSMColumnWidthsChanged(); break;
        case 407: _t->fitsLSMSortColumnChanged(); break;
        case 408: _t->fitsLSMSortOrderChanged(); break;
        case 409: _t->fitsLSMHighlightingChanged(); break;
        case 410: _t->fitsLSWebcastTitleChanged(); break;
        case 411: _t->fitsLSWebcastLogoLChanged(); break;
        case 412: _t->fitsLSWebcastLogoRChanged(); break;
        case 413: _t->fitsLSWebcastPortChanged(); break;
        case 414: _t->fitsLSWebcastThrottleChanged(); break;
        case 415: _t->BortleClassChanged(); break;
        case 416: _t->TelescopeCheckChanged(); break;
        case 417: _t->BinocularsCheckChanged(); break;
        case 418: _t->BinocularsApertureChanged(); break;
        case 419: _t->ScopeListIndexChanged(); break;
        case 420: _t->EkosWindowWidthChanged(); break;
        case 421: _t->EkosWindowHeightChanged(); break;
        case 422: _t->EkosGeometryChanged(); break;
        case 423: _t->EkosTopIconsChanged(); break;
        case 424: _t->EkosLeftIconsChanged(); break;
        case 425: _t->independentWindowEkosChanged(); break;
        case 426: _t->profileChanged(); break;
        case 427: _t->neverLoadConfigChanged(); break;
        case 428: _t->loadConfigOnConnectionChanged(); break;
        case 429: _t->loadDefaultConfigChanged(); break;
        case 430: _t->autoLoadSerialAssistantChanged(); break;
        case 431: _t->RememberCredentialsChanged(); break;
        case 432: _t->AutoStartEkosLiveChanged(); break;
        case 433: _t->EkosLiveUsernameChanged(); break;
        case 434: _t->EkosLiveObservatoryChanged(); break;
        case 435: _t->EkosLiveOfflineServerChanged(); break;
        case 436: _t->EkosLiveOnlineServerChanged(); break;
        case 437: _t->EkosLiveSoundChanged(); break;
        case 438: _t->EkosLiveNotificationsChanged(); break;
        case 439: _t->EkosLiveCloudChanged(); break;
        case 440: _t->MaxDarkTemperatureDiffChanged(); break;
        case 441: _t->shutterfulCCDsChanged(); break;
        case 442: _t->shutterlessCCDsChanged(); break;
        case 443: _t->DarkLibraryDurationChanged(); break;
        case 444: _t->UseGraphicalCountsDisplayChanged(); break;
        case 445: _t->MinimumAltLimitChanged(); break;
        case 446: _t->MaximumAltLimitChanged(); break;
        case 447: _t->EnableAltitudeLimitsChanged(); break;
        case 448: _t->EnableAltitudeLimitsTrackingOnlyChanged(); break;
        case 449: _t->ConfirmBelowHorizonChanged(); break;
        case 450: _t->MeridianFlipOffsetDegreesChanged(); break;
        case 451: _t->MaximumHaLimitChanged(); break;
        case 452: _t->EnableHaLimitChanged(); break;
        case 453: _t->ExecuteMeridianFlipChanged(); break;
        case 454: _t->LeftRightReversedChanged(); break;
        case 455: _t->UpDownReversedChanged(); break;
        case 456: _t->ParkEveryDayChanged(); break;
        case 457: _t->ParkTimeChanged(); break;
        case 458: _t->DefaultObserverChanged(); break;
        case 459: _t->SyncFOVPAChanged(); break;
        case 460: _t->PAMultiplierChanged(); break;
        case 461: _t->PAOffsetChanged(); break;
        case 462: _t->PAPierSideChanged(); break;
        case 463: _t->GuideDeviationChanged(); break;
        case 464: _t->GuideDeviationRepsChanged(); break;
        case 465: _t->StartGuideDeviationChanged(); break;
        case 466: _t->GuideDitherPerJobFrequencyChanged(); break;
        case 467: _t->HFRDeviationChanged(); break;
        case 468: _t->MaxFocusTemperatureDeltaChanged(); break;
        case 469: _t->AutoDarkChanged(); break;
        case 470: _t->EnforceGuideDeviationChanged(); break;
        case 471: _t->EnforceAutofocusHFRChanged(); break;
        case 472: _t->EnforceAutofocusOnTemperatureChanged(); break;
        case 473: _t->EnforceRefocusEveryNChanged(); break;
        case 474: _t->RefocusEveryNChanged(); break;
        case 475: _t->RefocusAfterMeridianFlipChanged(); break;
        case 476: _t->ResetMountModelAfterMeridianChanged(); break;
        case 477: _t->ForcedFlipChanged(); break;
        case 478: _t->CalibrationADUValueChanged(); break;
        case 479: _t->CalibrationADUValueToleranceChanged(); break;
        case 480: _t->CalibrationPreActionIndexChanged(); break;
        case 481: _t->CalibrationFlatDurationIndexChanged(); break;
        case 482: _t->CalibrationWallAzChanged(); break;
        case 483: _t->CalibrationWallAltChanged(); break;
        case 484: _t->MaxTemperatureDiffChanged(); break;
        case 485: _t->MaxStartGuiderDriftChanged(); break;
        case 486: _t->EnforceStartGuiderDriftChanged(); break;
        case 487: _t->GuidingSettleChanged(); break;
        case 488: _t->AlwaysResetSequenceWhenStartingChanged(); break;
        case 489: _t->FlatSyncFocusChanged(); break;
        case 490: _t->HFRThresholdPercentageChanged(); break;
        case 491: _t->HFRCheckAlgorithmChanged(); break;
        case 492: _t->InSequenceCheckFramesChanged(); break;
        case 493: _t->AutoStretchChanged(); break;
        case 494: _t->StretchPreviewSamplingChanged(); break;
        case 495: _t->Clipping64KValueChanged(); break;
        case 496: _t->Clipping256ValueChanged(); break;
        case 497: _t->AdaptiveSamplingChanged(); break;
        case 498: _t->useSummaryPreviewChanged(); break;
        case 499: _t->useDSLRImageViewerChanged(); break;
        case 500: _t->ForceDSLRPresetsChanged(); break;
        case 501: _t->CaptureDirectoryChanged(); break;
        case 502: _t->PlaceholderFormatChanged(); break;
        case 503: _t->RemoteCaptureDirectoryChanged(); break;
        case 504: _t->ManualCoverTimeoutChanged(); break;
        case 505: _t->CaptureOperationsTimeoutChanged(); break;
        case 506: _t->MinFlipDurationChanged(); break;
        case 507: _t->CapturePositionChanged(); break;
        case 508: _t->CaptureTrainIDChanged(); break;
        case 509: _t->CaptureCalibrationWallChanged(); break;
        case 510: _t->CaptureCalibrationParkMountChanged(); break;
        case 511: _t->CaptureCalibrationParkDomeChanged(); break;
        case 512: _t->CaptureCalibrationUseManualChanged(); break;
        case 513: _t->CaptureCalibrationUseADUChanged(); break;
        case 514: _t->CaptureCalibrationADUValueChanged(); break;
        case 515: _t->CaptureCalibrationADUToleranceChanged(); break;
        case 516: _t->CaptureCalibrationSkyFlatsChanged(); break;
        case 517: _t->AbsTicksSpinChanged(); break;
        case 518: _t->FocusExposureChanged(); break;
        case 519: _t->FocusBinningChanged(); break;
        case 520: _t->FocusGainChanged(); break;
        case 521: _t->FocusISOChanged(); break;
        case 522: _t->DefaultFocusTemperatureSourceChanged(); break;
        case 523: _t->FocusFilterChanged(); break;
        case 524: _t->UseFocusDarkFrameChanged(); break;
        case 525: _t->FocusSubFrameChanged(); break;
        case 526: _t->FocusBoxSizeChanged(); break;
        case 527: _t->FocusUseFullFieldChanged(); break;
        case 528: _t->FocusNoMaskRBChanged(); break;
        case 529: _t->focusRingMaskRBChanged(); break;
        case 530: _t->focusMosaicMaskRBChanged(); break;
        case 531: _t->FocusFullFieldInnerRadiusChanged(); break;
        case 532: _t->FocusFullFieldOuterRadiusChanged(); break;
        case 533: _t->FocusMosaicTileWidthChanged(); break;
        case 534: _t->focusMosaicSpaceChanged(); break;
        case 535: _t->FocusAutoStarEnabledChanged(); break;
        case 536: _t->FocusSuspendGuidingChanged(); break;
        case 537: _t->FocusGuideSettleTimeChanged(); break;
        case 538: _t->FocusUnitsChanged(); break;
        case 539: _t->FocusAdaptiveChanged(); break;
        case 540: _t->focusAdaptiveMinMoveChanged(); break;
        case 541: _t->FocusAdaptStartChanged(); break;
        case 542: _t->focusAdaptiveMaxMoveChanged(); break;
        case 543: _t->FocusDetectionChanged(); break;
        case 544: _t->FocusSEPProfileChanged(); break;
        case 545: _t->FocusAlgorithmChanged(); break;
        case 546: _t->FocusCurveFitChanged(); break;
        case 547: _t->FocusStarMeasureChanged(); break;
        case 548: _t->FocusStarPSFChanged(); break;
        case 549: _t->FocusUseWeightsChanged(); break;
        case 550: _t->FocusR2LimitChanged(); break;
        case 551: _t->FocusRefineCurveFitChanged(); break;
        case 552: _t->focusFramesCountChanged(); break;
        case 553: _t->focusHFRFramesCountChanged(); break;
        case 554: _t->FocusMultiRowAverageChanged(); break;
        case 555: _t->FocusGaussianSigmaChanged(); break;
        case 556: _t->FocusThresholdChanged(); break;
        case 557: _t->FocusDenoiseChanged(); break;
        case 558: _t->FocusDonutChanged(); break;
        case 559: _t->FocusTimeDilationChanged(); break;
        case 560: _t->focusOutlierRejectionChanged(); break;
        case 561: _t->focusScanStartPosChanged(); break;
        case 562: _t->focusScanAlwaysOnChanged(); break;
        case 563: _t->focusScanDatapointsChanged(); break;
        case 564: _t->focusScanStepSizeFactorChanged(); break;
        case 565: _t->FocusGaussianKernelSizeChanged(); break;
        case 566: _t->FocusToleranceChanged(); break;
        case 567: _t->FocusWalkChanged(); break;
        case 568: _t->FocusSettleTimeChanged(); break;
        case 569: _t->FocusTicksChanged(); break;
        case 570: _t->FocusOutStepsChanged(); break;
        case 571: _t->focusNumStepsChanged(); break;
        case 572: _t->FocusMaxTravelChanged(); break;
        case 573: _t->FocusMaxSingleStepChanged(); break;
        case 574: _t->FocusBacklashChanged(); break;
        case 575: _t->FocusAFOverscanChanged(); break;
        case 576: _t->FocusOverscanDelayChanged(); break;
        case 577: _t->FocusCaptureTimeoutChanged(); break;
        case 578: _t->FocusMotionTimeoutChanged(); break;
        case 579: _t->focusCFZAlgorithmChanged(); break;
        case 580: _t->focusCFZToleranceChanged(); break;
        case 581: _t->focusCFZTauChanged(); break;
        case 582: _t->focusCFZDisplayVCurveChanged(); break;
        case 583: _t->focusCFZWavelengthChanged(); break;
        case 584: _t->focusCFZApertureChanged(); break;
        case 585: _t->focusCFZFNumberChanged(); break;
        case 586: _t->focusCFZSeeingChanged(); break;
        case 587: _t->focusCFZStepSizeChanged(); break;
        case 588: _t->focusAdvHelpOnlyChangesChanged(); break;
        case 589: _t->focusAdvUpdateParamsChanged(); break;
        case 590: _t->focusAdvFindStarsChanged(); break;
        case 591: _t->focusAdvCourseAdjChanged(); break;
        case 592: _t->focusAdvFineAdjChanged(); break;
        case 593: _t->FocusSplitterChanged(); break;
        case 594: _t->rightLayoutChanged(); break;
        case 595: _t->adaptFocusBFOChanged(); break;
        case 596: _t->abInsTileSelectionChanged(); break;
        case 597: _t->abInsShowLabelsChanged(); break;
        case 598: _t->abInsShowCFZChanged(); break;
        case 599: _t->abInsOptCentresChanged(); break;
        case 600: _t->abInsHSplitterChanged(); break;
        case 601: _t->abInsVSplitterChanged(); break;
        case 602: _t->abInsSelectionChanged(); break;
        case 603: _t->abInsThemeChanged(); break;
        case 604: _t->abInsLabelsChanged(); break;
        case 605: _t->abInsSensorChanged(); break;
        case 606: _t->abInsPetzvalWireChanged(); break;
        case 607: _t->abInsPetzvalSurfaceChanged(); break;
        case 608: _t->tiltPlateTypeChanged(); break;
        case 609: _t->tiltRadiusChanged(); break;
        case 610: _t->tiltThreadIndexChanged(); break;
        case 611: _t->tiltScrewPitchChanged(); break;
        case 612: _t->tiltRotationChanged(); break;
        case 613: _t->tiltModeChanged(); break;
        case 614: _t->tiltPlatePresentChanged(); break;
        case 615: _t->FocusSextractorTypeChanged(); break;
        case 616: _t->FocusOptionsProfileChanged(); break;
        case 617: _t->HFRSextractorTypeChanged(); break;
        case 618: _t->HFROptionsProfileChanged(); break;
        case 619: _t->GuideSextractorTypeChanged(); break;
        case 620: _t->GuideOptionsProfileChanged(); break;
        case 621: _t->SolveSextractorTypeChanged(); break;
        case 622: _t->SolverModeChanged(); break;
        case 623: _t->SolverTypeChanged(); break;
        case 624: _t->SolveOptionsProfileChanged(); break;
        case 625: _t->LoggerLevelChanged(); break;
        case 626: _t->AstrometryLogToFileChanged(); break;
        case 627: _t->AstrometryLogFilepathChanged(); break;
        case 628: _t->AstrometryIndexFolderListChanged(); break;
        case 629: _t->AlignExposureChanged(); break;
        case 630: _t->AlignBinningChanged(); break;
        case 631: _t->AlignGainChanged(); break;
        case 632: _t->AlignISOChanged(); break;
        case 633: _t->AlignDarkFrameChanged(); break;
        case 634: _t->AlignFilterChanged(); break;
        case 635: _t->AlignUseCurrentFilterChanged(); break;
        case 636: _t->AstrometryUseRotatorChanged(); break;
        case 637: _t->AstrometryRotatorThresholdChanged(); break;
        case 638: _t->AstrometryFlipRotationAllowedChanged(); break;
        case 639: _t->RotatorParityReversedChanged(); break;
        case 640: _t->AstrometrySolverWCSChanged(); break;
        case 641: _t->AstrometrySolverOverlayChanged(); break;
        case 642: _t->AstrometryDifferentialSlewingChanged(); break;
        case 643: _t->AlignAccuracyThresholdChanged(); break;
        case 644: _t->AlignSettlingTimeChanged(); break;
        case 645: _t->AstrometryUseNoFITS2FITSChanged(); break;
        case 646: _t->AstrometryUseResortChanged(); break;
        case 647: _t->AstrometryUseNoVerifyChanged(); break;
        case 648: _t->AstrometryUseImageScaleChanged(); break;
        case 649: _t->AstrometryImageScaleLowChanged(); break;
        case 650: _t->AstrometryImageScaleHighChanged(); break;
        case 651: _t->AstrometryAutoUpdateImageScaleChanged(); break;
        case 652: _t->AstrometryImageScaleUnitsChanged(); break;
        case 653: _t->AstrometryUseDownsampleChanged(); break;
        case 654: _t->AstrometryDownsampleChanged(); break;
        case 655: _t->AstrometryAutoDownsampleChanged(); break;
        case 656: _t->AstrometryDynamicThresholdChanged(); break;
        case 657: _t->AstrometryUsePositionChanged(); break;
        case 658: _t->AstrometryPositionRAChanged(); break;
        case 659: _t->AstrometryPositionDEChanged(); break;
        case 660: _t->AstrometryAutoUpdatePositionChanged(); break;
        case 661: _t->AstrometryRadiusChanged(); break;
        case 662: _t->AstrometryDetectParityChanged(); break;
        case 663: _t->AstrometryCustomOptionsChanged(); break;
        case 664: _t->AstrometrySolverBinaryChanged(); break;
        case 665: _t->AstrometryWCSInfoChanged(); break;
        case 666: _t->AstrometryConfFileChanged(); break;
        case 667: _t->SextractorBinaryChanged(); break;
        case 668: _t->WatneyBinaryChanged(); break;
        case 669: _t->AstrometryAPIKeyChanged(); break;
        case 670: _t->AstrometryAPIURLChanged(); break;
        case 671: _t->AstrometryUseJPEGChanged(); break;
        case 672: _t->AstrometryTimeoutChanged(); break;
        case 673: _t->PAHMountSpeedChanged(); break;
        case 674: _t->PAHRotaionChanged(); break;
        case 675: _t->PAHRefreshAlgorithmChanged(); break;
        case 676: _t->PAHDirectionChanged(); break;
        case 677: _t->PAHAutoParkChanged(); break;
        case 678: _t->PAHManualSlewChanged(); break;
        case 679: _t->PAHExposureChanged(); break;
        case 680: _t->PAHAutoPACCorrectionChanged(); break;
        case 681: _t->PAHAutoChangeDirectionChanged(); break;
        case 682: _t->PAHSuccessThresholdChanged(); break;
        case 683: _t->PAHCorrectionTimeoutChanged(); break;
        case 684: _t->GuideExposureChanged(); break;
        case 685: _t->GuideDelayChanged(); break;
        case 686: _t->GuiderTypeChanged(); break;
        case 687: _t->GuideAlgorithmChanged(); break;
        case 688: _t->RAGuidePulseAlgorithmChanged(); break;
        case 689: _t->DECGuidePulseAlgorithmChanged(); break;
        case 690: _t->AIGuiderWeightsFileChanged(); break;
        case 691: _t->AIPredictionGainChanged(); break;
        case 692: _t->AIProportionalBackoffChanged(); break;
        case 693: _t->AIPIDAutoTuneChanged(); break;
        case 694: _t->AIShadowModeChanged(); break;
        case 695: _t->PHD2HostChanged(); break;
        case 696: _t->PHD2PortChanged(); break;
        case 697: _t->LinGuiderHostChanged(); break;
        case 698: _t->LinGuiderPortChanged(); break;
        case 699: _t->CalibrationPulseDurationChanged(); break;
        case 700: _t->CalibrationMaxMoveChanged(); break;
        case 701: _t->GuideSquareSizeChanged(); break;
        case 702: _t->GuideBinningChanged(); break;
        case 703: _t->GuideAutoStarChanged(); break;
        case 704: _t->guideShowFrameChanged(); break;
        case 705: _t->GuideAutoSquareSizeEnabledChanged(); break;
        case 706: _t->AutoModeIterationsChanged(); break;
        case 707: _t->GuideLostStarTimeoutChanged(); break;
        case 708: _t->GuideCalibrationTimeoutChanged(); break;
        case 709: _t->GuideMaxDeltaRMSChanged(); break;
        case 710: _t->GuideMaxHFRChanged(); break;
        case 711: _t->MinDetectionsSEPMultistarChanged(); break;
        case 712: _t->MaxMultistarReferenceStarsChanged(); break;
        case 713: _t->AlwaysInventGuideStarChanged(); break;
        case 714: _t->TwoAxisEnabledChanged(); break;
        case 715: _t->UseGuideHeadChanged(); break;
        case 716: _t->SaveGuideLogChanged(); break;
        case 717: _t->GuideDarkFrameChanged(); break;
        case 718: _t->GuideSubframeChanged(); break;
        case 719: _t->DitherPixelsChanged(); break;
        case 720: _t->DitherFramesChanged(); break;
        case 721: _t->DitherSettleChanged(); break;
        case 722: _t->DitherThresholdChanged(); break;
        case 723: _t->DitherTimeoutChanged(); break;
        case 724: _t->DitherMaxIterationsChanged(); break;
        case 725: _t->DitherNoGuidingPulseChanged(); break;
        case 726: _t->DitherFailAbortsAutoGuideChanged(); break;
        case 727: _t->DitherWithOnePulseChanged(); break;
        case 728: _t->DitherEnabledChanged(); break;
        case 729: _t->DitherNoGuidingChanged(); break;
        case 730: _t->RAGuideEnabledChanged(); break;
        case 731: _t->DECGuideEnabledChanged(); break;
        case 732: _t->NorthDECGuideEnabledChanged(); break;
        case 733: _t->SouthDECGuideEnabledChanged(); break;
        case 734: _t->EastRAGuideEnabledChanged(); break;
        case 735: _t->WestRAGuideEnabledChanged(); break;
        case 736: _t->RAProportionalGainChanged(); break;
        case 737: _t->DECProportionalGainChanged(); break;
        case 738: _t->RAIntegralGainChanged(); break;
        case 739: _t->DECIntegralGainChanged(); break;
        case 740: _t->RAMinimumPulseArcSecChanged(); break;
        case 741: _t->DECMinimumPulseArcSecChanged(); break;
        case 742: _t->RAMaximumPulseArcSecChanged(); break;
        case 743: _t->DECMaximumPulseArcSecChanged(); break;
        case 744: _t->GPGEnabledChanged(); break;
        case 745: _t->GPGDarkGuidingChanged(); break;
        case 746: _t->GPGDarkGuidingIntervalChanged(); break;
        case 747: _t->AIDarkGuidingChanged(); break;
        case 748: _t->AIDarkGuidingIntervalChanged(); break;
        case 749: _t->GPGcWeightChanged(); break;
        case 750: _t->GPGMinPeriodsForInferenceChanged(); break;
        case 751: _t->GPGMinMoveChanged(); break;
        case 752: _t->GPGSE0KLengthScaleChanged(); break;
        case 753: _t->GPGSE0KSignalVarianceChanged(); break;
        case 754: _t->GPGPKLengthScaleChanged(); break;
        case 755: _t->GPGPeriodChanged(); break;
        case 756: _t->GPGPKSignalVarianceChanged(); break;
        case 757: _t->GPGSE1KLengthScaleChanged(); break;
        case 758: _t->GPGSE1KSignalVarianceChanged(); break;
        case 759: _t->GPGMinPeriodsForPeriodEstimateChanged(); break;
        case 760: _t->GPGPointsForApproximationChanged(); break;
        case 761: _t->GPGpWeightChanged(); break;
        case 762: _t->GPGEstimatePeriodChanged(); break;
        case 763: _t->GuiderAccuracyThresholdChanged(); break;
        case 764: _t->RADisplayedOnGuideGraphChanged(); break;
        case 765: _t->DEDisplayedOnGuideGraphChanged(); break;
        case 766: _t->RACorrDisplayedOnGuideGraphChanged(); break;
        case 767: _t->DECorrDisplayedOnGuideGraphChanged(); break;
        case 768: _t->SNRDisplayedOnGuideGraphChanged(); break;
        case 769: _t->RMSDisplayedOnGuideGraphChanged(); break;
        case 770: _t->RAHysteresisChanged(); break;
        case 771: _t->DECHysteresisChanged(); break;
        case 772: _t->SchedulerAlgorithmChanged(); break;
        case 773: _t->SchedulerLoggingChanged(); break;
        case 774: _t->StopEkosAfterShutdownChanged(); break;
        case 775: _t->ShutdownScriptTerminatesINDIChanged(); break;
        case 776: _t->CameraWarmupEnabledChanged(); break;
        case 777: _t->CameraWarmupRampChanged(); break;
        case 778: _t->PreemptiveShutdownChanged(); break;
        case 779: _t->ResetMountModelOnAlignFailChanged(); break;
        case 780: _t->ResetMountModelBeforeJobChanged(); break;
        case 781: _t->ResetGuideCalibrationChanged(); break;
        case 782: _t->ForceAlignmentBeforeJobChanged(); break;
        case 783: _t->ReuseGuideCalibrationChanged(); break;
        case 784: _t->ReverseDecOnPierSideChangeChanged(); break;
        case 785: _t->GuideCalibrationBacklashChanged(); break;
        case 786: _t->AssumeDecOrthogonalChanged(); break;
        case 787: _t->SerializedCalibrationChanged(); break;
        case 788: _t->RealignAfterCalibrationFailureChanged(); break;
        case 789: _t->PreemptiveShutdownTimeChanged(); break;
        case 790: _t->RememberJobProgressChanged(); break;
        case 791: _t->GreedySchedulingChanged(); break;
        case 792: _t->LeadTimeChanged(); break;
        case 793: _t->PreDawnTimeChanged(); break;
        case 794: _t->DawnOffsetChanged(); break;
        case 795: _t->DuskOffsetChanged(); break;
        case 796: _t->TelescopeFocalLengthChanged(); break;
        case 797: _t->TelescopeFocalReducerChanged(); break;
        case 798: _t->CameraPixelWidthChanged(); break;
        case 799: _t->CameraPixelHeightChanged(); break;
        case 800: _t->CameraWidthChanged(); break;
        case 801: _t->CameraHeightChanged(); break;
        case 802: _t->CameraRotationChanged(); break;
        case 803: _t->ErrorHandlingStrategyChanged(); break;
        case 804: _t->ErrorHandlingStrategyDelayChanged(); break;
        case 805: _t->RescheduleErrorsChanged(); break;
        case 806: _t->AlignCheckFrequencyChanged(); break;
        case 807: _t->AlignCheckThresholdChanged(); break;
        case 808: _t->SchedulerTrackStepChanged(); break;
        case 809: _t->SchedulerStartupEnabledChanged(); break;
        case 810: _t->SchedulerPreStartupScriptChanged(); break;
        case 811: _t->SchedulerPostStartupScriptChanged(); break;
        case 812: _t->SchedulerShutdownEnabledChanged(); break;
        case 813: _t->SchedulerPreShutdownScriptChanged(); break;
        case 814: _t->SchedulerPostShutdownScriptChanged(); break;
        case 815: _t->SchedulerFocusStepChanged(); break;
        case 816: _t->SchedulerGuideStepChanged(); break;
        case 817: _t->SchedulerAlignStepChanged(); break;
        case 818: _t->SchedulerAltitudeChanged(); break;
        case 819: _t->SchedulerAltitudeValueChanged(); break;
        case 820: _t->SchedulerHorizonChanged(); break;
        case 821: _t->SchedulerMoonSeparationChanged(); break;
        case 822: _t->SchedulerMoonSeparationValueChanged(); break;
        case 823: _t->SchedulerMoonAltitudeChanged(); break;
        case 824: _t->SchedulerMoonAltitudeMaxValueChanged(); break;
        case 825: _t->SchedulerWeatherChanged(); break;
        case 826: _t->SchedulerWeatherGracePeriodChanged(); break;
        case 827: _t->SchedulerWeatherShutdownDelayChanged(); break;
        case 828: _t->SchedulerSafetyMonitorConnectionStringChanged(); break;
        case 829: _t->SchedulerTwilightChanged(); break;
        case 830: _t->SchedulerCompleteSequencesChanged(); break;
        case 831: _t->SchedulerRepeatEverythingChanged(); break;
        case 832: _t->SchedulerRepeatSequencesChanged(); break;
        case 833: _t->SchedulerUntilTerminatedChanged(); break;
        case 834: _t->SchedulerUntilChanged(); break;
        case 835: _t->SchedulerUntilValueChanged(); break;
        case 836: _t->SchedulerExecutionSequencesLimitChanged(); break;
        case 837: _t->AnalyzeRestartWithEkosChanged(); break;
        case 838: _t->AnalyzeAlternativeDirectoryNameChanged(); break;
        case 839: _t->AnalyzeHFRChanged(); break;
        case 840: _t->AnalyzeNumCaptureStarsChanged(); break;
        case 841: _t->AnalyzeMedianChanged(); break;
        case 842: _t->AnalyzeEccentricityChanged(); break;
        case 843: _t->AnalyzeTemperatureChanged(); break;
        case 844: _t->FocusPositionChanged(); break;
        case 845: _t->AnalyzeNumStarsChanged(); break;
        case 846: _t->AnalyzeSkyBgChanged(); break;
        case 847: _t->AnalyzeSNRChanged(); break;
        case 848: _t->AnalyzeRAChanged(); break;
        case 849: _t->AnalyzeDECChanged(); break;
        case 850: _t->AnalyzeRApChanged(); break;
        case 851: _t->AnalyzeDECpChanged(); break;
        case 852: _t->AnalyzeDriftChanged(); break;
        case 853: _t->AnalyzeRMSChanged(); break;
        case 854: _t->AnalyzeTargetDistanceChanged(); break;
        case 855: _t->AnalyzeRMSCChanged(); break;
        case 856: _t->AnalyzeMountRAChanged(); break;
        case 857: _t->AnalyzeMountDECChanged(); break;
        case 858: _t->AnalyzeMountHAChanged(); break;
        case 859: _t->AnalyzeAzChanged(); break;
        case 860: _t->AnalyzeAltChanged(); break;
        case 861: _t->AnalyzePierSideChanged(); break;
        case 862: _t->AnalyzeStatsYAxisChanged(); break;
        case 863: _t->LastServerChanged(); break;
        case 864: _t->LastServerPortChanged(); break;
        case 865: _t->LastWebManagerPortChanged(); break;
        case 866: _t->HIPSMemoryCacheChanged(); break;
        case 867: _t->HIPSNetCacheChanged(); break;
        case 868: _t->HIPSSourceChanged(); break;
        case 869: _t->HIPSBiLinearInterpolationChanged(); break;
        case 870: _t->HIPSShowGridChanged(); break;
        case 871: _t->HIPSPanningChanged(); break;
        case 872: _t->ShowHIPSChanged(); break;
        case 873: _t->HIPSUseOfflineSourceChanged(); break;
        case 874: _t->HIPSOfflinePathChanged(); break;
        case 875: _t->TerrainSourceChanged(); break;
        case 876: _t->TerrainSourceCorrectAzChanged(); break;
        case 877: _t->TerrainSourceCorrectAltChanged(); break;
        case 878: _t->TerrainDownsamplingChanged(); break;
        case 879: _t->TerrainPanningChanged(); break;
        case 880: _t->ShowTerrainChanged(); break;
        case 881: _t->TerrainSkipSpeedupChanged(); break;
        case 882: _t->TerrainTransparencySpeedupChanged(); break;
        case 883: _t->TerrainSmoothPixelsChanged(); break;
        case 884: _t->ShowImageOverlaysChanged(); break;
        case 885: _t->ShowImageOverlaysBelowCatalogsChanged(); break;
        case 886: _t->ShowSelectedImageOverlayChanged(); break;
        case 887: _t->ImageOverlayMaxDimensionChanged(); break;
        case 888: _t->ImageOverlayTimeoutChanged(); break;
        case 889: _t->ImageOverlayDefaultScaleChanged(); break;
        case 890: _t->DefaultObservatoryWeatherSourceChanged(); break;
        case 891: _t->warningActionsActiveChanged(); break;
        case 892: _t->alertActionsActiveChanged(); break;
        case 893: _t->weatherWarningCloseDomeChanged(); break;
        case 894: _t->weatherWarningCloseShutterChanged(); break;
        case 895: _t->weatherWarningStopSchedulerChanged(); break;
        case 896: _t->weatherWarningDelayChanged(); break;
        case 897: _t->weatherAlertCloseDomeChanged(); break;
        case 898: _t->weatherAlertCloseShutterChanged(); break;
        case 899: _t->weatherAlertStopSchedulerChanged(); break;
        case 900: _t->weatherAlertDelayChanged(); break;
        case 901: _t->observatoryStatusUseDomeChanged(); break;
        case 902: _t->observatoryStatusUseShutterChanged(); break;
        case 903: _t->observatoryStatusUseWeatherChanged(); break;
        case 904: _t->weatherAutoScaleValuesChanged(); break;
        case 905: _t->ASTAPExecutableChanged(); break;
        case 906: _t->ASTAPDownSampleChanged(); break;
        case 907: _t->ASTAPDownSampleValueChanged(); break;
        case 908: _t->ASTAPSearchRadiusChanged(); break;
        case 909: _t->ASTAPSearchRadiusValueChanged(); break;
        case 910: _t->ASTAPUpdateFITSChanged(); break;
        case 911: _t->ASTAPLargeSearchWindowChanged(); break;
        case 912: _t->MosaicTransparencyAutoChanged(); break;
        case 913: _t->MosaicTransparencyLevelChanged(); break;
        case 914: _t->MCPEnabledChanged(); break;
        case 915: _t->MCPPortChanged(); break;
        case 916: _t->MCPReadOnlyModeChanged(); break;
        case 917: _t->MCPDisabledToolsChanged(); break;
        default: ;
        }
    }
    if (_c == QMetaObject::IndexOfMethod) {
        if (QtMocHelpers::indexOfMethod<void (Options::*)()>(_a, &Options::PositionTimeBoxChanged, 0))
            return;
        if (QtMocHelpers::indexOfMethod<void (Options::*)()>(_a, &Options::PositionFocusBoxChanged, 1))
            return;
        if (QtMocHelpers::indexOfMethod<void (Options::*)()>(_a, &Options::PositionGeoBoxChanged, 2))
            return;
        if (QtMocHelpers::indexOfMethod<void (Options::*)()>(_a, &Options::ShadeTimeBoxChanged, 3))
            return;
        if (QtMocHelpers::indexOfMethod<void (Options::*)()>(_a, &Options::ShadeFocusBoxChanged, 4))
            return;
        if (QtMocHelpers::indexOfMethod<void (Options::*)()>(_a, &Options::ShadeGeoBoxChanged, 5))
            return;
        if (QtMocHelpers::indexOfMethod<void (Options::*)()>(_a, &Options::ShowInfoBoxesChanged, 6))
            return;
        if (QtMocHelpers::indexOfMethod<void (Options::*)()>(_a, &Options::ShowTimeBoxChanged, 7))
            return;
        if (QtMocHelpers::indexOfMethod<void (Options::*)()>(_a, &Options::ShowFocusBoxChanged, 8))
            return;
        if (QtMocHelpers::indexOfMethod<void (Options::*)()>(_a, &Options::ShowGeoBoxChanged, 9))
            return;
        if (QtMocHelpers::indexOfMethod<void (Options::*)()>(_a, &Options::StickyTimeBoxChanged, 10))
            return;
        if (QtMocHelpers::indexOfMethod<void (Options::*)()>(_a, &Options::StickyFocusBoxChanged, 11))
            return;
        if (QtMocHelpers::indexOfMethod<void (Options::*)()>(_a, &Options::StickyGeoBoxChanged, 12))
            return;
        if (QtMocHelpers::indexOfMethod<void (Options::*)()>(_a, &Options::ShowStatusBarChanged, 13))
            return;
        if (QtMocHelpers::indexOfMethod<void (Options::*)()>(_a, &Options::ShowAltAzFieldChanged, 14))
            return;
        if (QtMocHelpers::indexOfMethod<void (Options::*)()>(_a, &Options::ShowRADecFieldChanged, 15))
            return;
        if (QtMocHelpers::indexOfMethod<void (Options::*)()>(_a, &Options::ShowJ2000RADecFieldChanged, 16))
            return;
        if (QtMocHelpers::indexOfMethod<void (Options::*)()>(_a, &Options::ShowSensorFOVChanged, 17))
            return;
        if (QtMocHelpers::indexOfMethod<void (Options::*)()>(_a, &Options::WindowWidthChanged, 18))
            return;
        if (QtMocHelpers::indexOfMethod<void (Options::*)()>(_a, &Options::WindowHeightChanged, 19))
            return;
        if (QtMocHelpers::indexOfMethod<void (Options::*)()>(_a, &Options::KStarsGeometryChanged, 20))
            return;
        if (QtMocHelpers::indexOfMethod<void (Options::*)()>(_a, &Options::RunStartupWizardChanged, 21))
            return;
        if (QtMocHelpers::indexOfMethod<void (Options::*)()>(_a, &Options::CurrentThemeChanged, 22))
            return;
        if (QtMocHelpers::indexOfMethod<void (Options::*)()>(_a, &Options::CatalogFileChanged, 23))
            return;
        if (QtMocHelpers::indexOfMethod<void (Options::*)()>(_a, &Options::ShowCatalogChanged, 24))
            return;
        if (QtMocHelpers::indexOfMethod<void (Options::*)()>(_a, &Options::ShowCatalogNamesChanged, 25))
            return;
        if (QtMocHelpers::indexOfMethod<void (Options::*)()>(_a, &Options::ResolveNamesOnlineChanged, 26))
            return;
        if (QtMocHelpers::indexOfMethod<void (Options::*)()>(_a, &Options::DSOCachePercentageChanged, 27))
            return;
        if (QtMocHelpers::indexOfMethod<void (Options::*)()>(_a, &Options::DSOMinZoomFactorChanged, 28))
            return;
        if (QtMocHelpers::indexOfMethod<void (Options::*)()>(_a, &Options::DSOCatalogFilenameChanged, 29))
            return;
        if (QtMocHelpers::indexOfMethod<void (Options::*)()>(_a, &Options::DSODefaultCatalogFilenameChanged, 30))
            return;
        if (QtMocHelpers::indexOfMethod<void (Options::*)()>(_a, &Options::INDIWindowWidthChanged, 31))
            return;
        if (QtMocHelpers::indexOfMethod<void (Options::*)()>(_a, &Options::INDIWindowHeightChanged, 32))
            return;
        if (QtMocHelpers::indexOfMethod<void (Options::*)()>(_a, &Options::INDIWindowGeometryChanged, 33))
            return;
        if (QtMocHelpers::indexOfMethod<void (Options::*)()>(_a, &Options::useGeographicUpdateChanged, 34))
            return;
        if (QtMocHelpers::indexOfMethod<void (Options::*)()>(_a, &Options::useTimeUpdateChanged, 35))
            return;
        if (QtMocHelpers::indexOfMethod<void (Options::*)()>(_a, &Options::independentWindowINDIChanged, 36))
            return;
        if (QtMocHelpers::indexOfMethod<void (Options::*)()>(_a, &Options::showTargetCrosshairChanged, 37))
            return;
        if (QtMocHelpers::indexOfMethod<void (Options::*)()>(_a, &Options::showINDIMessagesChanged, 38))
            return;
        if (QtMocHelpers::indexOfMethod<void (Options::*)()>(_a, &Options::showINDIwindowInitiallyChanged, 39))
            return;
        if (QtMocHelpers::indexOfMethod<void (Options::*)()>(_a, &Options::maxFocusFrameFilesChanged, 40))
            return;
        if (QtMocHelpers::indexOfMethod<void (Options::*)()>(_a, &Options::messageNotificationINDIChanged, 41))
            return;
        if (QtMocHelpers::indexOfMethod<void (Options::*)()>(_a, &Options::timeSourceChanged, 42))
            return;
        if (QtMocHelpers::indexOfMethod<void (Options::*)()>(_a, &Options::locationSourceChanged, 43))
            return;
        if (QtMocHelpers::indexOfMethod<void (Options::*)()>(_a, &Options::useExternalSkyMapChanged, 44))
            return;
        if (QtMocHelpers::indexOfMethod<void (Options::*)()>(_a, &Options::fitsDirChanged, 45))
            return;
        if (QtMocHelpers::indexOfMethod<void (Options::*)()>(_a, &Options::serverTransferBufferSizeChanged, 46))
            return;
        if (QtMocHelpers::indexOfMethod<void (Options::*)()>(_a, &Options::serverPortStartChanged, 47))
            return;
        if (QtMocHelpers::indexOfMethod<void (Options::*)()>(_a, &Options::serverPortEndChanged, 48))
            return;
        if (QtMocHelpers::indexOfMethod<void (Options::*)()>(_a, &Options::indiServerChanged, 49))
            return;
        if (QtMocHelpers::indexOfMethod<void (Options::*)()>(_a, &Options::indiServerIsInternalChanged, 50))
            return;
        if (QtMocHelpers::indexOfMethod<void (Options::*)()>(_a, &Options::indiDriversDirChanged, 51))
            return;
        if (QtMocHelpers::indexOfMethod<void (Options::*)()>(_a, &Options::indiDriversAreInternalChanged, 52))
            return;
        if (QtMocHelpers::indexOfMethod<void (Options::*)()>(_a, &Options::streamWindowWidthChanged, 53))
            return;
        if (QtMocHelpers::indexOfMethod<void (Options::*)()>(_a, &Options::streamWindowHeightChanged, 54))
            return;
        if (QtMocHelpers::indexOfMethod<void (Options::*)()>(_a, &Options::INDIMountLoggingChanged, 55))
            return;
        if (QtMocHelpers::indexOfMethod<void (Options::*)()>(_a, &Options::INDIFocuserLoggingChanged, 56))
            return;
        if (QtMocHelpers::indexOfMethod<void (Options::*)()>(_a, &Options::INDICCDLoggingChanged, 57))
            return;
        if (QtMocHelpers::indexOfMethod<void (Options::*)()>(_a, &Options::INDIFilterWheelLoggingChanged, 58))
            return;
        if (QtMocHelpers::indexOfMethod<void (Options::*)()>(_a, &Options::INDIDomeLoggingChanged, 59))
            return;
        if (QtMocHelpers::indexOfMethod<void (Options::*)()>(_a, &Options::INDIDetectorLoggingChanged, 60))
            return;
        if (QtMocHelpers::indexOfMethod<void (Options::*)()>(_a, &Options::INDIWeatherLoggingChanged, 61))
            return;
        if (QtMocHelpers::indexOfMethod<void (Options::*)()>(_a, &Options::INDIAuxiliaryLoggingChanged, 62))
            return;
        if (QtMocHelpers::indexOfMethod<void (Options::*)()>(_a, &Options::INDIRotatorLoggingChanged, 63))
            return;
        if (QtMocHelpers::indexOfMethod<void (Options::*)()>(_a, &Options::INDIGPSLoggingChanged, 64))
            return;
        if (QtMocHelpers::indexOfMethod<void (Options::*)()>(_a, &Options::INDIAOLoggingChanged, 65))
            return;
        if (QtMocHelpers::indexOfMethod<void (Options::*)()>(_a, &Options::CityNameChanged, 66))
            return;
        if (QtMocHelpers::indexOfMethod<void (Options::*)()>(_a, &Options::ProvinceNameChanged, 67))
            return;
        if (QtMocHelpers::indexOfMethod<void (Options::*)()>(_a, &Options::CountryNameChanged, 68))
            return;
        if (QtMocHelpers::indexOfMethod<void (Options::*)()>(_a, &Options::LongitudeChanged, 69))
            return;
        if (QtMocHelpers::indexOfMethod<void (Options::*)()>(_a, &Options::LatitudeChanged, 70))
            return;
        if (QtMocHelpers::indexOfMethod<void (Options::*)()>(_a, &Options::ElevationChanged, 71))
            return;
        if (QtMocHelpers::indexOfMethod<void (Options::*)()>(_a, &Options::TimeZoneChanged, 72))
            return;
        if (QtMocHelpers::indexOfMethod<void (Options::*)()>(_a, &Options::DSTChanged, 73))
            return;
        if (QtMocHelpers::indexOfMethod<void (Options::*)()>(_a, &Options::UseAnimatedSlewingChanged, 74))
            return;
        if (QtMocHelpers::indexOfMethod<void (Options::*)()>(_a, &Options::LeftClickSelectsObjectChanged, 75))
            return;
        if (QtMocHelpers::indexOfMethod<void (Options::*)()>(_a, &Options::DefaultCursorChanged, 76))
            return;
        if (QtMocHelpers::indexOfMethod<void (Options::*)()>(_a, &Options::FOVNamesChanged, 77))
            return;
        if (QtMocHelpers::indexOfMethod<void (Options::*)()>(_a, &Options::FadePlanetTrailsChanged, 78))
            return;
        if (QtMocHelpers::indexOfMethod<void (Options::*)()>(_a, &Options::FocusRAChanged, 79))
            return;
        if (QtMocHelpers::indexOfMethod<void (Options::*)()>(_a, &Options::FocusDecChanged, 80))
            return;
        if (QtMocHelpers::indexOfMethod<void (Options::*)()>(_a, &Options::FocusObjectChanged, 81))
            return;
        if (QtMocHelpers::indexOfMethod<void (Options::*)()>(_a, &Options::IsTrackingChanged, 82))
            return;
        if (QtMocHelpers::indexOfMethod<void (Options::*)()>(_a, &Options::HideOnSlewChanged, 83))
            return;
        if (QtMocHelpers::indexOfMethod<void (Options::*)()>(_a, &Options::HideCBoundsChanged, 84))
            return;
        if (QtMocHelpers::indexOfMethod<void (Options::*)()>(_a, &Options::HideCLinesChanged, 85))
            return;
        if (QtMocHelpers::indexOfMethod<void (Options::*)()>(_a, &Options::SkyCultureChanged, 86))
            return;
        if (QtMocHelpers::indexOfMethod<void (Options::*)()>(_a, &Options::HideCNamesChanged, 87))
            return;
        if (QtMocHelpers::indexOfMethod<void (Options::*)()>(_a, &Options::HideGridsChanged, 88))
            return;
        if (QtMocHelpers::indexOfMethod<void (Options::*)()>(_a, &Options::HideMilkyWayChanged, 89))
            return;
        if (QtMocHelpers::indexOfMethod<void (Options::*)()>(_a, &Options::HideOtherChanged, 90))
            return;
        if (QtMocHelpers::indexOfMethod<void (Options::*)()>(_a, &Options::HidePlanetsChanged, 91))
            return;
        if (QtMocHelpers::indexOfMethod<void (Options::*)()>(_a, &Options::HideStarsChanged, 92))
            return;
        if (QtMocHelpers::indexOfMethod<void (Options::*)()>(_a, &Options::HideLabelsChanged, 93))
            return;
        if (QtMocHelpers::indexOfMethod<void (Options::*)()>(_a, &Options::ShowAsteroidsChanged, 94))
            return;
        if (QtMocHelpers::indexOfMethod<void (Options::*)()>(_a, &Options::ShowAsteroidNamesChanged, 95))
            return;
        if (QtMocHelpers::indexOfMethod<void (Options::*)()>(_a, &Options::OrbitalElementsAutoUpdateChanged, 96))
            return;
        if (QtMocHelpers::indexOfMethod<void (Options::*)()>(_a, &Options::ShowCometsChanged, 97))
            return;
        if (QtMocHelpers::indexOfMethod<void (Options::*)()>(_a, &Options::ShowCometComasChanged, 98))
            return;
        if (QtMocHelpers::indexOfMethod<void (Options::*)()>(_a, &Options::ShowCometNamesChanged, 99))
            return;
        if (QtMocHelpers::indexOfMethod<void (Options::*)()>(_a, &Options::ShowSupernovaeChanged, 100))
            return;
        if (QtMocHelpers::indexOfMethod<void (Options::*)()>(_a, &Options::ShowSupernovaNamesChanged, 101))
            return;
        if (QtMocHelpers::indexOfMethod<void (Options::*)()>(_a, &Options::MagnitudeLimitShowSupernovaeChanged, 102))
            return;
        if (QtMocHelpers::indexOfMethod<void (Options::*)()>(_a, &Options::SupernovaDetectionAgeChanged, 103))
            return;
        if (QtMocHelpers::indexOfMethod<void (Options::*)()>(_a, &Options::SupernovaDownloadUrlChanged, 104))
            return;
        if (QtMocHelpers::indexOfMethod<void (Options::*)()>(_a, &Options::LimitSupernovaeByZoomChanged, 105))
            return;
        if (QtMocHelpers::indexOfMethod<void (Options::*)()>(_a, &Options::SupernovaeHostOnlyChanged, 106))
            return;
        if (QtMocHelpers::indexOfMethod<void (Options::*)()>(_a, &Options::SupernovaeClassifiedOnlyChanged, 107))
            return;
        if (QtMocHelpers::indexOfMethod<void (Options::*)()>(_a, &Options::ShowSupernovaAlertsChanged, 108))
            return;
        if (QtMocHelpers::indexOfMethod<void (Options::*)()>(_a, &Options::MagnitudeLimitAlertSupernovaeChanged, 109))
            return;
        if (QtMocHelpers::indexOfMethod<void (Options::*)()>(_a, &Options::ShowCBoundsChanged, 110))
            return;
        if (QtMocHelpers::indexOfMethod<void (Options::*)()>(_a, &Options::ShowHighlightedCBoundChanged, 111))
            return;
        if (QtMocHelpers::indexOfMethod<void (Options::*)()>(_a, &Options::ShowCLinesChanged, 112))
            return;
        if (QtMocHelpers::indexOfMethod<void (Options::*)()>(_a, &Options::ShowConstellationArtChanged, 113))
            return;
        if (QtMocHelpers::indexOfMethod<void (Options::*)()>(_a, &Options::ShowCNamesChanged, 114))
            return;
        if (QtMocHelpers::indexOfMethod<void (Options::*)()>(_a, &Options::ShowDeepSkyChanged, 115))
            return;
        if (QtMocHelpers::indexOfMethod<void (Options::*)()>(_a, &Options::ShowEclipticChanged, 116))
            return;
        if (QtMocHelpers::indexOfMethod<void (Options::*)()>(_a, &Options::ShowEquatorChanged, 117))
            return;
        if (QtMocHelpers::indexOfMethod<void (Options::*)()>(_a, &Options::AutoSelectGridChanged, 118))
            return;
        if (QtMocHelpers::indexOfMethod<void (Options::*)()>(_a, &Options::ShowEquatorialGridChanged, 119))
            return;
        if (QtMocHelpers::indexOfMethod<void (Options::*)()>(_a, &Options::ShowHorizontalGridChanged, 120))
            return;
        if (QtMocHelpers::indexOfMethod<void (Options::*)()>(_a, &Options::ShowLocalMeridianChanged, 121))
            return;
        if (QtMocHelpers::indexOfMethod<void (Options::*)()>(_a, &Options::ShowGroundChanged, 122))
            return;
        if (QtMocHelpers::indexOfMethod<void (Options::*)()>(_a, &Options::ShowHorizonChanged, 123))
            return;
        if (QtMocHelpers::indexOfMethod<void (Options::*)()>(_a, &Options::ShowFlagsChanged, 124))
            return;
        if (QtMocHelpers::indexOfMethod<void (Options::*)()>(_a, &Options::SimulateDaytimeChanged, 125))
            return;
        if (QtMocHelpers::indexOfMethod<void (Options::*)()>(_a, &Options::ShowOtherChanged, 126))
            return;
        if (QtMocHelpers::indexOfMethod<void (Options::*)()>(_a, &Options::ShowMilkyWayChanged, 127))
            return;
        if (QtMocHelpers::indexOfMethod<void (Options::*)()>(_a, &Options::FillMilkyWayChanged, 128))
            return;
        if (QtMocHelpers::indexOfMethod<void (Options::*)()>(_a, &Options::ShowSolarSystemChanged, 129))
            return;
        if (QtMocHelpers::indexOfMethod<void (Options::*)()>(_a, &Options::ShowPlanetImagesChanged, 130))
            return;
        if (QtMocHelpers::indexOfMethod<void (Options::*)()>(_a, &Options::ShowPlanetNamesChanged, 131))
            return;
        if (QtMocHelpers::indexOfMethod<void (Options::*)()>(_a, &Options::ShowSunChanged, 132))
            return;
        if (QtMocHelpers::indexOfMethod<void (Options::*)()>(_a, &Options::SunScaleChanged, 133))
            return;
        if (QtMocHelpers::indexOfMethod<void (Options::*)()>(_a, &Options::ShowMoonChanged, 134))
            return;
        if (QtMocHelpers::indexOfMethod<void (Options::*)()>(_a, &Options::MoonScaleChanged, 135))
            return;
        if (QtMocHelpers::indexOfMethod<void (Options::*)()>(_a, &Options::ShowMercuryChanged, 136))
            return;
        if (QtMocHelpers::indexOfMethod<void (Options::*)()>(_a, &Options::ShowVenusChanged, 137))
            return;
        if (QtMocHelpers::indexOfMethod<void (Options::*)()>(_a, &Options::ShowMarsChanged, 138))
            return;
        if (QtMocHelpers::indexOfMethod<void (Options::*)()>(_a, &Options::ShowJupiterChanged, 139))
            return;
        if (QtMocHelpers::indexOfMethod<void (Options::*)()>(_a, &Options::ShowSaturnChanged, 140))
            return;
        if (QtMocHelpers::indexOfMethod<void (Options::*)()>(_a, &Options::ShowUranusChanged, 141))
            return;
        if (QtMocHelpers::indexOfMethod<void (Options::*)()>(_a, &Options::ShowNeptuneChanged, 142))
            return;
        if (QtMocHelpers::indexOfMethod<void (Options::*)()>(_a, &Options::ShowPlutoChanged, 143))
            return;
        if (QtMocHelpers::indexOfMethod<void (Options::*)()>(_a, &Options::ShowStarsChanged, 144))
            return;
        if (QtMocHelpers::indexOfMethod<void (Options::*)()>(_a, &Options::ShowStarMagnitudesChanged, 145))
            return;
        if (QtMocHelpers::indexOfMethod<void (Options::*)()>(_a, &Options::ShowStarsOverHIPSChanged, 146))
            return;
        if (QtMocHelpers::indexOfMethod<void (Options::*)()>(_a, &Options::ShowStarNamesChanged, 147))
            return;
        if (QtMocHelpers::indexOfMethod<void (Options::*)()>(_a, &Options::ShowDeepSkyMagnitudesChanged, 148))
            return;
        if (QtMocHelpers::indexOfMethod<void (Options::*)()>(_a, &Options::ShowDeepSkyNamesChanged, 149))
            return;
        if (QtMocHelpers::indexOfMethod<void (Options::*)()>(_a, &Options::ShowMosaicPanelChanged, 150))
            return;
        if (QtMocHelpers::indexOfMethod<void (Options::*)()>(_a, &Options::SlewTimeScaleChanged, 151))
            return;
        if (QtMocHelpers::indexOfMethod<void (Options::*)()>(_a, &Options::BoxBGModeChanged, 152))
            return;
        if (QtMocHelpers::indexOfMethod<void (Options::*)()>(_a, &Options::ProjectionChanged, 153))
            return;
        if (QtMocHelpers::indexOfMethod<void (Options::*)()>(_a, &Options::UseAbbrevConstellNamesChanged, 154))
            return;
        if (QtMocHelpers::indexOfMethod<void (Options::*)()>(_a, &Options::UseLatinConstellNamesChanged, 155))
            return;
        if (QtMocHelpers::indexOfMethod<void (Options::*)()>(_a, &Options::UseLocalConstellNamesChanged, 156))
            return;
        if (QtMocHelpers::indexOfMethod<void (Options::*)()>(_a, &Options::UseAltAzChanged, 157))
            return;
        if (QtMocHelpers::indexOfMethod<void (Options::*)()>(_a, &Options::UseAutoLabelChanged, 158))
            return;
        if (QtMocHelpers::indexOfMethod<void (Options::*)()>(_a, &Options::UseAutoTrailChanged, 159))
            return;
        if (QtMocHelpers::indexOfMethod<void (Options::*)()>(_a, &Options::UseHoverLabelChanged, 160))
            return;
        if (QtMocHelpers::indexOfMethod<void (Options::*)()>(_a, &Options::UseRefractionChanged, 161))
            return;
        if (QtMocHelpers::indexOfMethod<void (Options::*)()>(_a, &Options::UseRelativisticChanged, 162))
            return;
        if (QtMocHelpers::indexOfMethod<void (Options::*)()>(_a, &Options::UseAntialiasChanged, 163))
            return;
        if (QtMocHelpers::indexOfMethod<void (Options::*)()>(_a, &Options::ZoomFactorChanged, 164))
            return;
        if (QtMocHelpers::indexOfMethod<void (Options::*)()>(_a, &Options::SkyRotationChanged, 165))
            return;
        if (QtMocHelpers::indexOfMethod<void (Options::*)()>(_a, &Options::MirrorSkyMapChanged, 166))
            return;
        if (QtMocHelpers::indexOfMethod<void (Options::*)()>(_a, &Options::ErectObserverCorrectionChanged, 167))
            return;
        if (QtMocHelpers::indexOfMethod<void (Options::*)()>(_a, &Options::ZoomScrollFactorChanged, 168))
            return;
        if (QtMocHelpers::indexOfMethod<void (Options::*)()>(_a, &Options::MagLimitAsteroidChanged, 169))
            return;
        if (QtMocHelpers::indexOfMethod<void (Options::*)()>(_a, &Options::MagLimitAsteroidDownloadChanged, 170))
            return;
        if (QtMocHelpers::indexOfMethod<void (Options::*)()>(_a, &Options::AsteroidLabelDensityChanged, 171))
            return;
        if (QtMocHelpers::indexOfMethod<void (Options::*)()>(_a, &Options::MagLimitDrawDeepSkyChanged, 172))
            return;
        if (QtMocHelpers::indexOfMethod<void (Options::*)()>(_a, &Options::MagLimitDrawDeepSkyZoomOutChanged, 173))
            return;
        if (QtMocHelpers::indexOfMethod<void (Options::*)()>(_a, &Options::ShowUnknownMagObjectsChanged, 174))
            return;
        if (QtMocHelpers::indexOfMethod<void (Options::*)()>(_a, &Options::ShowInlineImagesChanged, 175))
            return;
        if (QtMocHelpers::indexOfMethod<void (Options::*)()>(_a, &Options::StarDensityChanged, 176))
            return;
        if (QtMocHelpers::indexOfMethod<void (Options::*)()>(_a, &Options::MagLimitHideStarChanged, 177))
            return;
        if (QtMocHelpers::indexOfMethod<void (Options::*)()>(_a, &Options::StarLabelDensityChanged, 178))
            return;
        if (QtMocHelpers::indexOfMethod<void (Options::*)()>(_a, &Options::DeepSkyLabelDensityChanged, 179))
            return;
        if (QtMocHelpers::indexOfMethod<void (Options::*)()>(_a, &Options::DeepSkyLongLabelsChanged, 180))
            return;
        if (QtMocHelpers::indexOfMethod<void (Options::*)()>(_a, &Options::LabelFontScalingChanged, 181))
            return;
        if (QtMocHelpers::indexOfMethod<void (Options::*)()>(_a, &Options::MaxRadCometNameChanged, 182))
            return;
        if (QtMocHelpers::indexOfMethod<void (Options::*)()>(_a, &Options::UseGLChanged, 183))
            return;
        if (QtMocHelpers::indexOfMethod<void (Options::*)()>(_a, &Options::RunClockChanged, 184))
            return;
        if (QtMocHelpers::indexOfMethod<void (Options::*)()>(_a, &Options::ImagingPlannerAcceptOpenClusterChanged, 185))
            return;
        if (QtMocHelpers::indexOfMethod<void (Options::*)()>(_a, &Options::ImagingPlannerAcceptNebulaChanged, 186))
            return;
        if (QtMocHelpers::indexOfMethod<void (Options::*)()>(_a, &Options::ImagingPlannerAcceptGlobularClusterChanged, 187))
            return;
        if (QtMocHelpers::indexOfMethod<void (Options::*)()>(_a, &Options::ImagingPlannerAcceptPlanetaryChanged, 188))
            return;
        if (QtMocHelpers::indexOfMethod<void (Options::*)()>(_a, &Options::ImagingPlannerAcceptSupernovaRemnantChanged, 189))
            return;
        if (QtMocHelpers::indexOfMethod<void (Options::*)()>(_a, &Options::ImagingPlannerAcceptGalaxyChanged, 190))
            return;
        if (QtMocHelpers::indexOfMethod<void (Options::*)()>(_a, &Options::ImagingPlannerAcceptGalaxyClusterChanged, 191))
            return;
        if (QtMocHelpers::indexOfMethod<void (Options::*)()>(_a, &Options::ImagingPlannerAcceptDarkNebulaChanged, 192))
            return;
        if (QtMocHelpers::indexOfMethod<void (Options::*)()>(_a, &Options::ImagingPlannerAcceptOtherChanged, 193))
            return;
        if (QtMocHelpers::indexOfMethod<void (Options::*)()>(_a, &Options::AstrobinAwardChanged, 194))
            return;
        if (QtMocHelpers::indexOfMethod<void (Options::*)()>(_a, &Options::AstrobinMinRadiusChanged, 195))
            return;
        if (QtMocHelpers::indexOfMethod<void (Options::*)()>(_a, &Options::AstrobinMaxRadiusChanged, 196))
            return;
        if (QtMocHelpers::indexOfMethod<void (Options::*)()>(_a, &Options::ImagingPlannerUseArtificialHorizonChanged, 197))
            return;
        if (QtMocHelpers::indexOfMethod<void (Options::*)()>(_a, &Options::ImagingPlannerMinHoursChanged, 198))
            return;
        if (QtMocHelpers::indexOfMethod<void (Options::*)()>(_a, &Options::ImagingPlannerMinAltitudeChanged, 199))
            return;
        if (QtMocHelpers::indexOfMethod<void (Options::*)()>(_a, &Options::ImagingPlannerMinMoonSeparationChanged, 200))
            return;
        if (QtMocHelpers::indexOfMethod<void (Options::*)()>(_a, &Options::ImagingPlannerMaxMoonAltitudeChanged, 201))
            return;
        if (QtMocHelpers::indexOfMethod<void (Options::*)()>(_a, &Options::ImagingPlannerShowPickedChanged, 202))
            return;
        if (QtMocHelpers::indexOfMethod<void (Options::*)()>(_a, &Options::ImagingPlannerShowNotPickedChanged, 203))
            return;
        if (QtMocHelpers::indexOfMethod<void (Options::*)()>(_a, &Options::ImagingPlannerDontCarePickedChanged, 204))
            return;
        if (QtMocHelpers::indexOfMethod<void (Options::*)()>(_a, &Options::ImagingPlannerShowKeywordChanged, 205))
            return;
        if (QtMocHelpers::indexOfMethod<void (Options::*)()>(_a, &Options::ImagingPlannerShowNotKeywordChanged, 206))
            return;
        if (QtMocHelpers::indexOfMethod<void (Options::*)()>(_a, &Options::ImagingPlannerDontCareKeywordChanged, 207))
            return;
        if (QtMocHelpers::indexOfMethod<void (Options::*)()>(_a, &Options::ImagingPlannerKeywordChanged, 208))
            return;
        if (QtMocHelpers::indexOfMethod<void (Options::*)()>(_a, &Options::ImagingPlannerShowImagedChanged, 209))
            return;
        if (QtMocHelpers::indexOfMethod<void (Options::*)()>(_a, &Options::ImagingPlannerShowNotImagedChanged, 210))
            return;
        if (QtMocHelpers::indexOfMethod<void (Options::*)()>(_a, &Options::ImagingPlannerDontCareImagedChanged, 211))
            return;
        if (QtMocHelpers::indexOfMethod<void (Options::*)()>(_a, &Options::ImagingPlannerShowAddedChanged, 212))
            return;
        if (QtMocHelpers::indexOfMethod<void (Options::*)()>(_a, &Options::ImagingPlannerShowNotAddedChanged, 213))
            return;
        if (QtMocHelpers::indexOfMethod<void (Options::*)()>(_a, &Options::ImagingPlannerDontCareAddedChanged, 214))
            return;
        if (QtMocHelpers::indexOfMethod<void (Options::*)()>(_a, &Options::ImagingPlannerShowIgnoredChanged, 215))
            return;
        if (QtMocHelpers::indexOfMethod<void (Options::*)()>(_a, &Options::ImagingPlannerShowNotIgnoredChanged, 216))
            return;
        if (QtMocHelpers::indexOfMethod<void (Options::*)()>(_a, &Options::ImagingPlannerDontCareIgnoredChanged, 217))
            return;
        if (QtMocHelpers::indexOfMethod<void (Options::*)()>(_a, &Options::ImagingPlannerHideAstrobinDetailsChanged, 218))
            return;
        if (QtMocHelpers::indexOfMethod<void (Options::*)()>(_a, &Options::ImagingPlannerHideFiltersChanged, 219))
            return;
        if (QtMocHelpers::indexOfMethod<void (Options::*)()>(_a, &Options::ImagingPlannerHideImageChanged, 220))
            return;
        if (QtMocHelpers::indexOfMethod<void (Options::*)()>(_a, &Options::ImagingPlannerHideAltitudeGraphChanged, 221))
            return;
        if (QtMocHelpers::indexOfMethod<void (Options::*)()>(_a, &Options::ImagingPlannerCatalogPathChanged, 222))
            return;
        if (QtMocHelpers::indexOfMethod<void (Options::*)()>(_a, &Options::ImagingPlannerCenterOnSkyMapChanged, 223))
            return;
        if (QtMocHelpers::indexOfMethod<void (Options::*)()>(_a, &Options::ImagingPlannerIndependentWindowChanged, 224))
            return;
        if (QtMocHelpers::indexOfMethod<void (Options::*)()>(_a, &Options::ImagingPlannerStartSolvingImmediatelyChanged, 225))
            return;
        if (QtMocHelpers::indexOfMethod<void (Options::*)()>(_a, &Options::ObsListSymbolChanged, 226))
            return;
        if (QtMocHelpers::indexOfMethod<void (Options::*)()>(_a, &Options::ObsListTextChanged, 227))
            return;
        if (QtMocHelpers::indexOfMethod<void (Options::*)()>(_a, &Options::ObsListPreferDSSChanged, 228))
            return;
        if (QtMocHelpers::indexOfMethod<void (Options::*)()>(_a, &Options::ObsListPreferSDSSChanged, 229))
            return;
        if (QtMocHelpers::indexOfMethod<void (Options::*)()>(_a, &Options::ObsListDemoteHoleChanged, 230))
            return;
        if (QtMocHelpers::indexOfMethod<void (Options::*)()>(_a, &Options::ObsListHoleSizeChanged, 231))
            return;
        if (QtMocHelpers::indexOfMethod<void (Options::*)()>(_a, &Options::ObsListCoverageChanged, 232))
            return;
        if (QtMocHelpers::indexOfMethod<void (Options::*)()>(_a, &Options::ColorSchemeFileChanged, 233))
            return;
        if (QtMocHelpers::indexOfMethod<void (Options::*)()>(_a, &Options::StarColorModeChanged, 234))
            return;
        if (QtMocHelpers::indexOfMethod<void (Options::*)()>(_a, &Options::StarColorIntensityChanged, 235))
            return;
        if (QtMocHelpers::indexOfMethod<void (Options::*)()>(_a, &Options::DomeSlitInvertedChanged, 236))
            return;
        if (QtMocHelpers::indexOfMethod<void (Options::*)()>(_a, &Options::AngularRulerColorChanged, 237))
            return;
        if (QtMocHelpers::indexOfMethod<void (Options::*)()>(_a, &Options::BoxBGColorChanged, 238))
            return;
        if (QtMocHelpers::indexOfMethod<void (Options::*)()>(_a, &Options::BoxGrabColorChanged, 239))
            return;
        if (QtMocHelpers::indexOfMethod<void (Options::*)()>(_a, &Options::BoxTextColorChanged, 240))
            return;
        if (QtMocHelpers::indexOfMethod<void (Options::*)()>(_a, &Options::CBoundColorChanged, 241))
            return;
        if (QtMocHelpers::indexOfMethod<void (Options::*)()>(_a, &Options::CBoundHighColorChanged, 242))
            return;
        if (QtMocHelpers::indexOfMethod<void (Options::*)()>(_a, &Options::CLineColorChanged, 243))
            return;
        if (QtMocHelpers::indexOfMethod<void (Options::*)()>(_a, &Options::CNameColorChanged, 244))
            return;
        if (QtMocHelpers::indexOfMethod<void (Options::*)()>(_a, &Options::CompassColorChanged, 245))
            return;
        if (QtMocHelpers::indexOfMethod<void (Options::*)()>(_a, &Options::EclipticColorChanged, 246))
            return;
        if (QtMocHelpers::indexOfMethod<void (Options::*)()>(_a, &Options::EquatorColorChanged, 247))
            return;
        if (QtMocHelpers::indexOfMethod<void (Options::*)()>(_a, &Options::EquatorialGridColorChanged, 248))
            return;
        if (QtMocHelpers::indexOfMethod<void (Options::*)()>(_a, &Options::HorizontalGridColorChanged, 249))
            return;
        if (QtMocHelpers::indexOfMethod<void (Options::*)()>(_a, &Options::SpecialObjectColorChanged, 250))
            return;
        if (QtMocHelpers::indexOfMethod<void (Options::*)()>(_a, &Options::HorizonColorChanged, 251))
            return;
        if (QtMocHelpers::indexOfMethod<void (Options::*)()>(_a, &Options::LocalMeridianColorChanged, 252))
            return;
        if (QtMocHelpers::indexOfMethod<void (Options::*)()>(_a, &Options::MilkyWayWColorChanged, 253))
            return;
        if (QtMocHelpers::indexOfMethod<void (Options::*)()>(_a, &Options::StarNameColorChanged, 254))
            return;
        if (QtMocHelpers::indexOfMethod<void (Options::*)()>(_a, &Options::DeepSkyNameColorChanged, 255))
            return;
        if (QtMocHelpers::indexOfMethod<void (Options::*)()>(_a, &Options::PlanetNameColorChanged, 256))
            return;
        if (QtMocHelpers::indexOfMethod<void (Options::*)()>(_a, &Options::PlanetTrailColorChanged, 257))
            return;
        if (QtMocHelpers::indexOfMethod<void (Options::*)()>(_a, &Options::SkyColorChanged, 258))
            return;
        if (QtMocHelpers::indexOfMethod<void (Options::*)()>(_a, &Options::SkyColorDaytimeChanged, 259))
            return;
        if (QtMocHelpers::indexOfMethod<void (Options::*)()>(_a, &Options::ArtificialHorizonColorChanged, 260))
            return;
        if (QtMocHelpers::indexOfMethod<void (Options::*)()>(_a, &Options::TelescopeTargetColorChanged, 261))
            return;
        if (QtMocHelpers::indexOfMethod<void (Options::*)()>(_a, &Options::VisibleSatColorChanged, 262))
            return;
        if (QtMocHelpers::indexOfMethod<void (Options::*)()>(_a, &Options::SatColorChanged, 263))
            return;
        if (QtMocHelpers::indexOfMethod<void (Options::*)()>(_a, &Options::SatLabelColorChanged, 264))
            return;
        if (QtMocHelpers::indexOfMethod<void (Options::*)()>(_a, &Options::SupernovaColorChanged, 265))
            return;
        if (QtMocHelpers::indexOfMethod<void (Options::*)()>(_a, &Options::AsteroidColorChanged, 266))
            return;
        if (QtMocHelpers::indexOfMethod<void (Options::*)()>(_a, &Options::UserLabelColorChanged, 267))
            return;
        if (QtMocHelpers::indexOfMethod<void (Options::*)()>(_a, &Options::RAGuideColorChanged, 268))
            return;
        if (QtMocHelpers::indexOfMethod<void (Options::*)()>(_a, &Options::DEGuideColorChanged, 269))
            return;
        if (QtMocHelpers::indexOfMethod<void (Options::*)()>(_a, &Options::SolverFOVColorChanged, 270))
            return;
        if (QtMocHelpers::indexOfMethod<void (Options::*)()>(_a, &Options::xplanetIsInternalChanged, 271))
            return;
        if (QtMocHelpers::indexOfMethod<void (Options::*)()>(_a, &Options::XplanetPathChanged, 272))
            return;
        if (QtMocHelpers::indexOfMethod<void (Options::*)()>(_a, &Options::XplanetUseFIFOChanged, 273))
            return;
        if (QtMocHelpers::indexOfMethod<void (Options::*)()>(_a, &Options::XplanetTimeoutChanged, 274))
            return;
        if (QtMocHelpers::indexOfMethod<void (Options::*)()>(_a, &Options::XplanetAnimationDelayChanged, 275))
            return;
        if (QtMocHelpers::indexOfMethod<void (Options::*)()>(_a, &Options::XplanetWidthChanged, 276))
            return;
        if (QtMocHelpers::indexOfMethod<void (Options::*)()>(_a, &Options::XplanetHeightChanged, 277))
            return;
        if (QtMocHelpers::indexOfMethod<void (Options::*)()>(_a, &Options::XplanetLabelChanged, 278))
            return;
        if (QtMocHelpers::indexOfMethod<void (Options::*)()>(_a, &Options::XplanetLabelLocalTimeChanged, 279))
            return;
        if (QtMocHelpers::indexOfMethod<void (Options::*)()>(_a, &Options::XplanetLabelGMTChanged, 280))
            return;
        if (QtMocHelpers::indexOfMethod<void (Options::*)()>(_a, &Options::XplanetLabelStringChanged, 281))
            return;
        if (QtMocHelpers::indexOfMethod<void (Options::*)()>(_a, &Options::XplanetFontSizeChanged, 282))
            return;
        if (QtMocHelpers::indexOfMethod<void (Options::*)()>(_a, &Options::XplanetColorChanged, 283))
            return;
        if (QtMocHelpers::indexOfMethod<void (Options::*)()>(_a, &Options::XplanetDateFormatChanged, 284))
            return;
        if (QtMocHelpers::indexOfMethod<void (Options::*)()>(_a, &Options::XplanetLabelTLChanged, 285))
            return;
        if (QtMocHelpers::indexOfMethod<void (Options::*)()>(_a, &Options::XplanetLabelTRChanged, 286))
            return;
        if (QtMocHelpers::indexOfMethod<void (Options::*)()>(_a, &Options::XplanetLabelBRChanged, 287))
            return;
        if (QtMocHelpers::indexOfMethod<void (Options::*)()>(_a, &Options::XplanetLabelBLChanged, 288))
            return;
        if (QtMocHelpers::indexOfMethod<void (Options::*)()>(_a, &Options::XplanetGlareChanged, 289))
            return;
        if (QtMocHelpers::indexOfMethod<void (Options::*)()>(_a, &Options::XplanetRandomChanged, 290))
            return;
        if (QtMocHelpers::indexOfMethod<void (Options::*)()>(_a, &Options::XplanetLatLongChanged, 291))
            return;
        if (QtMocHelpers::indexOfMethod<void (Options::*)()>(_a, &Options::XplanetLatitudeChanged, 292))
            return;
        if (QtMocHelpers::indexOfMethod<void (Options::*)()>(_a, &Options::XplanetLongitudeChanged, 293))
            return;
        if (QtMocHelpers::indexOfMethod<void (Options::*)()>(_a, &Options::XplanetProjectionChanged, 294))
            return;
        if (QtMocHelpers::indexOfMethod<void (Options::*)()>(_a, &Options::XplanetBackgroundChanged, 295))
            return;
        if (QtMocHelpers::indexOfMethod<void (Options::*)()>(_a, &Options::XplanetBackgroundImageChanged, 296))
            return;
        if (QtMocHelpers::indexOfMethod<void (Options::*)()>(_a, &Options::XplanetBackgroundImagePathChanged, 297))
            return;
        if (QtMocHelpers::indexOfMethod<void (Options::*)()>(_a, &Options::XplanetBackgroundColorChanged, 298))
            return;
        if (QtMocHelpers::indexOfMethod<void (Options::*)()>(_a, &Options::XplanetBackgroundColorValueChanged, 299))
            return;
        if (QtMocHelpers::indexOfMethod<void (Options::*)()>(_a, &Options::XplanetMagnitudeChanged, 300))
            return;
        if (QtMocHelpers::indexOfMethod<void (Options::*)()>(_a, &Options::XplanetArcFileChanged, 301))
            return;
        if (QtMocHelpers::indexOfMethod<void (Options::*)()>(_a, &Options::XplanetArcFilePathChanged, 302))
            return;
        if (QtMocHelpers::indexOfMethod<void (Options::*)()>(_a, &Options::XplanetConfigFileChanged, 303))
            return;
        if (QtMocHelpers::indexOfMethod<void (Options::*)()>(_a, &Options::XplanetConfigFilePathChanged, 304))
            return;
        if (QtMocHelpers::indexOfMethod<void (Options::*)()>(_a, &Options::XplanetFOVChanged, 305))
            return;
        if (QtMocHelpers::indexOfMethod<void (Options::*)()>(_a, &Options::XplanetMarkerFileChanged, 306))
            return;
        if (QtMocHelpers::indexOfMethod<void (Options::*)()>(_a, &Options::XplanetMarkerFilePathChanged, 307))
            return;
        if (QtMocHelpers::indexOfMethod<void (Options::*)()>(_a, &Options::XplanetMarkerBoundsChanged, 308))
            return;
        if (QtMocHelpers::indexOfMethod<void (Options::*)()>(_a, &Options::XplanetMarkerBoundsPathChanged, 309))
            return;
        if (QtMocHelpers::indexOfMethod<void (Options::*)()>(_a, &Options::XplanetStarmapChanged, 310))
            return;
        if (QtMocHelpers::indexOfMethod<void (Options::*)()>(_a, &Options::XplanetStarmapPathChanged, 311))
            return;
        if (QtMocHelpers::indexOfMethod<void (Options::*)()>(_a, &Options::XplanetQualityChanged, 312))
            return;
        if (QtMocHelpers::indexOfMethod<void (Options::*)()>(_a, &Options::ShowSatellitesChanged, 313))
            return;
        if (QtMocHelpers::indexOfMethod<void (Options::*)()>(_a, &Options::ShowVisibleSatellitesChanged, 314))
            return;
        if (QtMocHelpers::indexOfMethod<void (Options::*)()>(_a, &Options::DrawSatellitesLikeStarsChanged, 315))
            return;
        if (QtMocHelpers::indexOfMethod<void (Options::*)()>(_a, &Options::ShowSatellitesLabelsChanged, 316))
            return;
        if (QtMocHelpers::indexOfMethod<void (Options::*)()>(_a, &Options::SelectedSatellitesChanged, 317))
            return;
        if (QtMocHelpers::indexOfMethod<void (Options::*)()>(_a, &Options::KStarsFirstRunChanged, 318))
            return;
        if (QtMocHelpers::indexOfMethod<void (Options::*)()>(_a, &Options::AlwaysRecomputeCoordinatesChanged, 319))
            return;
        if (QtMocHelpers::indexOfMethod<void (Options::*)()>(_a, &Options::DefaultDSSImageSizeChanged, 320))
            return;
        if (QtMocHelpers::indexOfMethod<void (Options::*)()>(_a, &Options::DSSPaddingChanged, 321))
            return;
        if (QtMocHelpers::indexOfMethod<void (Options::*)()>(_a, &Options::VerboseLoggingChanged, 322))
            return;
        if (QtMocHelpers::indexOfMethod<void (Options::*)()>(_a, &Options::RegularLoggingChanged, 323))
            return;
        if (QtMocHelpers::indexOfMethod<void (Options::*)()>(_a, &Options::DisableLoggingChanged, 324))
            return;
        if (QtMocHelpers::indexOfMethod<void (Options::*)()>(_a, &Options::LogToDefaultChanged, 325))
            return;
        if (QtMocHelpers::indexOfMethod<void (Options::*)()>(_a, &Options::LogToFileChanged, 326))
            return;
        if (QtMocHelpers::indexOfMethod<void (Options::*)()>(_a, &Options::FITSLoggingChanged, 327))
            return;
        if (QtMocHelpers::indexOfMethod<void (Options::*)()>(_a, &Options::INDILoggingChanged, 328))
            return;
        if (QtMocHelpers::indexOfMethod<void (Options::*)()>(_a, &Options::CaptureLoggingChanged, 329))
            return;
        if (QtMocHelpers::indexOfMethod<void (Options::*)()>(_a, &Options::FocusLoggingChanged, 330))
            return;
        if (QtMocHelpers::indexOfMethod<void (Options::*)()>(_a, &Options::SaveGuideImagesChanged, 331))
            return;
        if (QtMocHelpers::indexOfMethod<void (Options::*)()>(_a, &Options::SaveAlignImagesChanged, 332))
            return;
        if (QtMocHelpers::indexOfMethod<void (Options::*)()>(_a, &Options::SaveFailedAlignImagesChanged, 333))
            return;
        if (QtMocHelpers::indexOfMethod<void (Options::*)()>(_a, &Options::DontSyncToRealTimeChanged, 334))
            return;
        if (QtMocHelpers::indexOfMethod<void (Options::*)()>(_a, &Options::GuideLoggingChanged, 335))
            return;
        if (QtMocHelpers::indexOfMethod<void (Options::*)()>(_a, &Options::AlignmentLoggingChanged, 336))
            return;
        if (QtMocHelpers::indexOfMethod<void (Options::*)()>(_a, &Options::MountLoggingChanged, 337))
            return;
        if (QtMocHelpers::indexOfMethod<void (Options::*)()>(_a, &Options::ObservatoryLoggingChanged, 338))
            return;
        if (QtMocHelpers::indexOfMethod<void (Options::*)()>(_a, &Options::ImageDebayerEngineChanged, 339))
            return;
        if (QtMocHelpers::indexOfMethod<void (Options::*)()>(_a, &Options::ImageDebayerAlgoChanged, 340))
            return;
        if (QtMocHelpers::indexOfMethod<void (Options::*)()>(_a, &Options::StackDebayerEngineChanged, 341))
            return;
        if (QtMocHelpers::indexOfMethod<void (Options::*)()>(_a, &Options::StackDebayerAlgoChanged, 342))
            return;
        if (QtMocHelpers::indexOfMethod<void (Options::*)()>(_a, &Options::FITSWindowGeometryChanged, 343))
            return;
        if (QtMocHelpers::indexOfMethod<void (Options::*)()>(_a, &Options::useFITSViewerChanged, 344))
            return;
        if (QtMocHelpers::indexOfMethod<void (Options::*)()>(_a, &Options::singlePreviewFITSChanged, 345))
            return;
        if (QtMocHelpers::indexOfMethod<void (Options::*)()>(_a, &Options::singleWindowCapturedFITSChanged, 346))
            return;
        if (QtMocHelpers::indexOfMethod<void (Options::*)()>(_a, &Options::singleWindowOpenedFITSChanged, 347))
            return;
        if (QtMocHelpers::indexOfMethod<void (Options::*)()>(_a, &Options::focusFITSOnNewImageChanged, 348))
            return;
        if (QtMocHelpers::indexOfMethod<void (Options::*)()>(_a, &Options::independentWindowFITSChanged, 349))
            return;
        if (QtMocHelpers::indexOfMethod<void (Options::*)()>(_a, &Options::liveStackerOwnProcessChanged, 350))
            return;
        if (QtMocHelpers::indexOfMethod<void (Options::*)()>(_a, &Options::AutoDebayerChanged, 351))
            return;
        if (QtMocHelpers::indexOfMethod<void (Options::*)()>(_a, &Options::Auto3DCubeChanged, 352))
            return;
        if (QtMocHelpers::indexOfMethod<void (Options::*)()>(_a, &Options::AutoHFRChanged, 353))
            return;
        if (QtMocHelpers::indexOfMethod<void (Options::*)()>(_a, &Options::QuickHFRChanged, 354))
            return;
        if (QtMocHelpers::indexOfMethod<void (Options::*)()>(_a, &Options::StellarSolverPartitionChanged, 355))
            return;
        if (QtMocHelpers::indexOfMethod<void (Options::*)()>(_a, &Options::AutoWCSChanged, 356))
            return;
        if (QtMocHelpers::indexOfMethod<void (Options::*)()>(_a, &Options::LimitedResourcesModeChanged, 357))
            return;
        if (QtMocHelpers::indexOfMethod<void (Options::*)()>(_a, &Options::NonLinearHistogramChanged, 358))
            return;
        if (QtMocHelpers::indexOfMethod<void (Options::*)()>(_a, &Options::HIPSOpacityChanged, 359))
            return;
        if (QtMocHelpers::indexOfMethod<void (Options::*)()>(_a, &Options::HIPSOffsetXChanged, 360))
            return;
        if (QtMocHelpers::indexOfMethod<void (Options::*)()>(_a, &Options::HIPSOffsetYChanged, 361))
            return;
        if (QtMocHelpers::indexOfMethod<void (Options::*)()>(_a, &Options::FitsSolverProfileChanged, 362))
            return;
        if (QtMocHelpers::indexOfMethod<void (Options::*)()>(_a, &Options::FitsSolverModuleChanged, 363))
            return;
        if (QtMocHelpers::indexOfMethod<void (Options::*)()>(_a, &Options::FitsSolverProfileIndecesChanged, 364))
            return;
        if (QtMocHelpers::indexOfMethod<void (Options::*)()>(_a, &Options::FitsCatalogChanged, 365))
            return;
        if (QtMocHelpers::indexOfMethod<void (Options::*)()>(_a, &Options::FitsCatObjShowNamesChanged, 366))
            return;
        if (QtMocHelpers::indexOfMethod<void (Options::*)()>(_a, &Options::FitsSolverUseScaleChanged, 367))
            return;
        if (QtMocHelpers::indexOfMethod<void (Options::*)()>(_a, &Options::FitsSolverUsePositionChanged, 368))
            return;
        if (QtMocHelpers::indexOfMethod<void (Options::*)()>(_a, &Options::FitsSolverScaleChanged, 369))
            return;
        if (QtMocHelpers::indexOfMethod<void (Options::*)()>(_a, &Options::FitsSolverImageScaleUnitsChanged, 370))
            return;
        if (QtMocHelpers::indexOfMethod<void (Options::*)()>(_a, &Options::FitsSolverRadiusChanged, 371))
            return;
        if (QtMocHelpers::indexOfMethod<void (Options::*)()>(_a, &Options::fitsLSHideGeneralChanged, 372))
            return;
        if (QtMocHelpers::indexOfMethod<void (Options::*)()>(_a, &Options::fitsLSHideCalibrationChanged, 373))
            return;
        if (QtMocHelpers::indexOfMethod<void (Options::*)()>(_a, &Options::fitsLSHideAlignmentChanged, 374))
            return;
        if (QtMocHelpers::indexOfMethod<void (Options::*)()>(_a, &Options::fitsLSHideStackingChanged, 375))
            return;
        if (QtMocHelpers::indexOfMethod<void (Options::*)()>(_a, &Options::fitsLSHidePostProcChanged, 376))
            return;
        if (QtMocHelpers::indexOfMethod<void (Options::*)()>(_a, &Options::fitsLSCalcSNRChanged, 377))
            return;
        if (QtMocHelpers::indexOfMethod<void (Options::*)()>(_a, &Options::fitsLSMasterDarkChanged, 378))
            return;
        if (QtMocHelpers::indexOfMethod<void (Options::*)()>(_a, &Options::fitsLSMasterFlatChanged, 379))
            return;
        if (QtMocHelpers::indexOfMethod<void (Options::*)()>(_a, &Options::fitsLSHotPixelsChanged, 380))
            return;
        if (QtMocHelpers::indexOfMethod<void (Options::*)()>(_a, &Options::fitsLSColdPixelsChanged, 381))
            return;
        if (QtMocHelpers::indexOfMethod<void (Options::*)()>(_a, &Options::fitsLSAlignMethodChanged, 382))
            return;
        if (QtMocHelpers::indexOfMethod<void (Options::*)()>(_a, &Options::fitsLSNumInMemChanged, 383))
            return;
        if (QtMocHelpers::indexOfMethod<void (Options::*)()>(_a, &Options::fitsLSDownscaleChanged, 384))
            return;
        if (QtMocHelpers::indexOfMethod<void (Options::*)()>(_a, &Options::fitsLSWeightingChanged, 385))
            return;
        if (QtMocHelpers::indexOfMethod<void (Options::*)()>(_a, &Options::fitsLSNormalizationChanged, 386))
            return;
        if (QtMocHelpers::indexOfMethod<void (Options::*)()>(_a, &Options::fitsLSStackingMethodChanged, 387))
            return;
        if (QtMocHelpers::indexOfMethod<void (Options::*)()>(_a, &Options::fitsLSLowSigmaChanged, 388))
            return;
        if (QtMocHelpers::indexOfMethod<void (Options::*)()>(_a, &Options::fitsLSHighSigmaChanged, 389))
            return;
        if (QtMocHelpers::indexOfMethod<void (Options::*)()>(_a, &Options::fitsLSWinsorCutoffChanged, 390))
            return;
        if (QtMocHelpers::indexOfMethod<void (Options::*)()>(_a, &Options::fitsLSIterationsChanged, 391))
            return;
        if (QtMocHelpers::indexOfMethod<void (Options::*)()>(_a, &Options::fitsLSKappaChanged, 392))
            return;
        if (QtMocHelpers::indexOfMethod<void (Options::*)()>(_a, &Options::fitsLSAlphaChanged, 393))
            return;
        if (QtMocHelpers::indexOfMethod<void (Options::*)()>(_a, &Options::fitsLSSigmaChanged, 394))
            return;
        if (QtMocHelpers::indexOfMethod<void (Options::*)()>(_a, &Options::fitsPSFUpdateChanged, 395))
            return;
        if (QtMocHelpers::indexOfMethod<void (Options::*)()>(_a, &Options::fitsLSPostProcChanged, 396))
            return;
        if (QtMocHelpers::indexOfMethod<void (Options::*)()>(_a, &Options::fitsLSGradientAmtChanged, 397))
            return;
        if (QtMocHelpers::indexOfMethod<void (Options::*)()>(_a, &Options::fitsLSDeconvAmtChanged, 398))
            return;
        if (QtMocHelpers::indexOfMethod<void (Options::*)()>(_a, &Options::fitsLSPSFSigmaChanged, 399))
            return;
        if (QtMocHelpers::indexOfMethod<void (Options::*)()>(_a, &Options::fitsLSDenoiseAmtChanged, 400))
            return;
        if (QtMocHelpers::indexOfMethod<void (Options::*)()>(_a, &Options::fitsLSSharpenAmtChanged, 401))
            return;
        if (QtMocHelpers::indexOfMethod<void (Options::*)()>(_a, &Options::fitsLSSharpenKernalChanged, 402))
            return;
        if (QtMocHelpers::indexOfMethod<void (Options::*)()>(_a, &Options::fitsLSSharpenSigmaChanged, 403))
            return;
        if (QtMocHelpers::indexOfMethod<void (Options::*)()>(_a, &Options::fitsLSMWindowGeometryChanged, 404))
            return;
        if (QtMocHelpers::indexOfMethod<void (Options::*)()>(_a, &Options::fitsLSMVisibleColumnsChanged, 405))
            return;
        if (QtMocHelpers::indexOfMethod<void (Options::*)()>(_a, &Options::fitsLSMColumnWidthsChanged, 406))
            return;
        if (QtMocHelpers::indexOfMethod<void (Options::*)()>(_a, &Options::fitsLSMSortColumnChanged, 407))
            return;
        if (QtMocHelpers::indexOfMethod<void (Options::*)()>(_a, &Options::fitsLSMSortOrderChanged, 408))
            return;
        if (QtMocHelpers::indexOfMethod<void (Options::*)()>(_a, &Options::fitsLSMHighlightingChanged, 409))
            return;
        if (QtMocHelpers::indexOfMethod<void (Options::*)()>(_a, &Options::fitsLSWebcastTitleChanged, 410))
            return;
        if (QtMocHelpers::indexOfMethod<void (Options::*)()>(_a, &Options::fitsLSWebcastLogoLChanged, 411))
            return;
        if (QtMocHelpers::indexOfMethod<void (Options::*)()>(_a, &Options::fitsLSWebcastLogoRChanged, 412))
            return;
        if (QtMocHelpers::indexOfMethod<void (Options::*)()>(_a, &Options::fitsLSWebcastPortChanged, 413))
            return;
        if (QtMocHelpers::indexOfMethod<void (Options::*)()>(_a, &Options::fitsLSWebcastThrottleChanged, 414))
            return;
        if (QtMocHelpers::indexOfMethod<void (Options::*)()>(_a, &Options::BortleClassChanged, 415))
            return;
        if (QtMocHelpers::indexOfMethod<void (Options::*)()>(_a, &Options::TelescopeCheckChanged, 416))
            return;
        if (QtMocHelpers::indexOfMethod<void (Options::*)()>(_a, &Options::BinocularsCheckChanged, 417))
            return;
        if (QtMocHelpers::indexOfMethod<void (Options::*)()>(_a, &Options::BinocularsApertureChanged, 418))
            return;
        if (QtMocHelpers::indexOfMethod<void (Options::*)()>(_a, &Options::ScopeListIndexChanged, 419))
            return;
        if (QtMocHelpers::indexOfMethod<void (Options::*)()>(_a, &Options::EkosWindowWidthChanged, 420))
            return;
        if (QtMocHelpers::indexOfMethod<void (Options::*)()>(_a, &Options::EkosWindowHeightChanged, 421))
            return;
        if (QtMocHelpers::indexOfMethod<void (Options::*)()>(_a, &Options::EkosGeometryChanged, 422))
            return;
        if (QtMocHelpers::indexOfMethod<void (Options::*)()>(_a, &Options::EkosTopIconsChanged, 423))
            return;
        if (QtMocHelpers::indexOfMethod<void (Options::*)()>(_a, &Options::EkosLeftIconsChanged, 424))
            return;
        if (QtMocHelpers::indexOfMethod<void (Options::*)()>(_a, &Options::independentWindowEkosChanged, 425))
            return;
        if (QtMocHelpers::indexOfMethod<void (Options::*)()>(_a, &Options::profileChanged, 426))
            return;
        if (QtMocHelpers::indexOfMethod<void (Options::*)()>(_a, &Options::neverLoadConfigChanged, 427))
            return;
        if (QtMocHelpers::indexOfMethod<void (Options::*)()>(_a, &Options::loadConfigOnConnectionChanged, 428))
            return;
        if (QtMocHelpers::indexOfMethod<void (Options::*)()>(_a, &Options::loadDefaultConfigChanged, 429))
            return;
        if (QtMocHelpers::indexOfMethod<void (Options::*)()>(_a, &Options::autoLoadSerialAssistantChanged, 430))
            return;
        if (QtMocHelpers::indexOfMethod<void (Options::*)()>(_a, &Options::RememberCredentialsChanged, 431))
            return;
        if (QtMocHelpers::indexOfMethod<void (Options::*)()>(_a, &Options::AutoStartEkosLiveChanged, 432))
            return;
        if (QtMocHelpers::indexOfMethod<void (Options::*)()>(_a, &Options::EkosLiveUsernameChanged, 433))
            return;
        if (QtMocHelpers::indexOfMethod<void (Options::*)()>(_a, &Options::EkosLiveObservatoryChanged, 434))
            return;
        if (QtMocHelpers::indexOfMethod<void (Options::*)()>(_a, &Options::EkosLiveOfflineServerChanged, 435))
            return;
        if (QtMocHelpers::indexOfMethod<void (Options::*)()>(_a, &Options::EkosLiveOnlineServerChanged, 436))
            return;
        if (QtMocHelpers::indexOfMethod<void (Options::*)()>(_a, &Options::EkosLiveSoundChanged, 437))
            return;
        if (QtMocHelpers::indexOfMethod<void (Options::*)()>(_a, &Options::EkosLiveNotificationsChanged, 438))
            return;
        if (QtMocHelpers::indexOfMethod<void (Options::*)()>(_a, &Options::EkosLiveCloudChanged, 439))
            return;
        if (QtMocHelpers::indexOfMethod<void (Options::*)()>(_a, &Options::MaxDarkTemperatureDiffChanged, 440))
            return;
        if (QtMocHelpers::indexOfMethod<void (Options::*)()>(_a, &Options::shutterfulCCDsChanged, 441))
            return;
        if (QtMocHelpers::indexOfMethod<void (Options::*)()>(_a, &Options::shutterlessCCDsChanged, 442))
            return;
        if (QtMocHelpers::indexOfMethod<void (Options::*)()>(_a, &Options::DarkLibraryDurationChanged, 443))
            return;
        if (QtMocHelpers::indexOfMethod<void (Options::*)()>(_a, &Options::UseGraphicalCountsDisplayChanged, 444))
            return;
        if (QtMocHelpers::indexOfMethod<void (Options::*)()>(_a, &Options::MinimumAltLimitChanged, 445))
            return;
        if (QtMocHelpers::indexOfMethod<void (Options::*)()>(_a, &Options::MaximumAltLimitChanged, 446))
            return;
        if (QtMocHelpers::indexOfMethod<void (Options::*)()>(_a, &Options::EnableAltitudeLimitsChanged, 447))
            return;
        if (QtMocHelpers::indexOfMethod<void (Options::*)()>(_a, &Options::EnableAltitudeLimitsTrackingOnlyChanged, 448))
            return;
        if (QtMocHelpers::indexOfMethod<void (Options::*)()>(_a, &Options::ConfirmBelowHorizonChanged, 449))
            return;
        if (QtMocHelpers::indexOfMethod<void (Options::*)()>(_a, &Options::MeridianFlipOffsetDegreesChanged, 450))
            return;
        if (QtMocHelpers::indexOfMethod<void (Options::*)()>(_a, &Options::MaximumHaLimitChanged, 451))
            return;
        if (QtMocHelpers::indexOfMethod<void (Options::*)()>(_a, &Options::EnableHaLimitChanged, 452))
            return;
        if (QtMocHelpers::indexOfMethod<void (Options::*)()>(_a, &Options::ExecuteMeridianFlipChanged, 453))
            return;
        if (QtMocHelpers::indexOfMethod<void (Options::*)()>(_a, &Options::LeftRightReversedChanged, 454))
            return;
        if (QtMocHelpers::indexOfMethod<void (Options::*)()>(_a, &Options::UpDownReversedChanged, 455))
            return;
        if (QtMocHelpers::indexOfMethod<void (Options::*)()>(_a, &Options::ParkEveryDayChanged, 456))
            return;
        if (QtMocHelpers::indexOfMethod<void (Options::*)()>(_a, &Options::ParkTimeChanged, 457))
            return;
        if (QtMocHelpers::indexOfMethod<void (Options::*)()>(_a, &Options::DefaultObserverChanged, 458))
            return;
        if (QtMocHelpers::indexOfMethod<void (Options::*)()>(_a, &Options::SyncFOVPAChanged, 459))
            return;
        if (QtMocHelpers::indexOfMethod<void (Options::*)()>(_a, &Options::PAMultiplierChanged, 460))
            return;
        if (QtMocHelpers::indexOfMethod<void (Options::*)()>(_a, &Options::PAOffsetChanged, 461))
            return;
        if (QtMocHelpers::indexOfMethod<void (Options::*)()>(_a, &Options::PAPierSideChanged, 462))
            return;
        if (QtMocHelpers::indexOfMethod<void (Options::*)()>(_a, &Options::GuideDeviationChanged, 463))
            return;
        if (QtMocHelpers::indexOfMethod<void (Options::*)()>(_a, &Options::GuideDeviationRepsChanged, 464))
            return;
        if (QtMocHelpers::indexOfMethod<void (Options::*)()>(_a, &Options::StartGuideDeviationChanged, 465))
            return;
        if (QtMocHelpers::indexOfMethod<void (Options::*)()>(_a, &Options::GuideDitherPerJobFrequencyChanged, 466))
            return;
        if (QtMocHelpers::indexOfMethod<void (Options::*)()>(_a, &Options::HFRDeviationChanged, 467))
            return;
        if (QtMocHelpers::indexOfMethod<void (Options::*)()>(_a, &Options::MaxFocusTemperatureDeltaChanged, 468))
            return;
        if (QtMocHelpers::indexOfMethod<void (Options::*)()>(_a, &Options::AutoDarkChanged, 469))
            return;
        if (QtMocHelpers::indexOfMethod<void (Options::*)()>(_a, &Options::EnforceGuideDeviationChanged, 470))
            return;
        if (QtMocHelpers::indexOfMethod<void (Options::*)()>(_a, &Options::EnforceAutofocusHFRChanged, 471))
            return;
        if (QtMocHelpers::indexOfMethod<void (Options::*)()>(_a, &Options::EnforceAutofocusOnTemperatureChanged, 472))
            return;
        if (QtMocHelpers::indexOfMethod<void (Options::*)()>(_a, &Options::EnforceRefocusEveryNChanged, 473))
            return;
        if (QtMocHelpers::indexOfMethod<void (Options::*)()>(_a, &Options::RefocusEveryNChanged, 474))
            return;
        if (QtMocHelpers::indexOfMethod<void (Options::*)()>(_a, &Options::RefocusAfterMeridianFlipChanged, 475))
            return;
        if (QtMocHelpers::indexOfMethod<void (Options::*)()>(_a, &Options::ResetMountModelAfterMeridianChanged, 476))
            return;
        if (QtMocHelpers::indexOfMethod<void (Options::*)()>(_a, &Options::ForcedFlipChanged, 477))
            return;
        if (QtMocHelpers::indexOfMethod<void (Options::*)()>(_a, &Options::CalibrationADUValueChanged, 478))
            return;
        if (QtMocHelpers::indexOfMethod<void (Options::*)()>(_a, &Options::CalibrationADUValueToleranceChanged, 479))
            return;
        if (QtMocHelpers::indexOfMethod<void (Options::*)()>(_a, &Options::CalibrationPreActionIndexChanged, 480))
            return;
        if (QtMocHelpers::indexOfMethod<void (Options::*)()>(_a, &Options::CalibrationFlatDurationIndexChanged, 481))
            return;
        if (QtMocHelpers::indexOfMethod<void (Options::*)()>(_a, &Options::CalibrationWallAzChanged, 482))
            return;
        if (QtMocHelpers::indexOfMethod<void (Options::*)()>(_a, &Options::CalibrationWallAltChanged, 483))
            return;
        if (QtMocHelpers::indexOfMethod<void (Options::*)()>(_a, &Options::MaxTemperatureDiffChanged, 484))
            return;
        if (QtMocHelpers::indexOfMethod<void (Options::*)()>(_a, &Options::MaxStartGuiderDriftChanged, 485))
            return;
        if (QtMocHelpers::indexOfMethod<void (Options::*)()>(_a, &Options::EnforceStartGuiderDriftChanged, 486))
            return;
        if (QtMocHelpers::indexOfMethod<void (Options::*)()>(_a, &Options::GuidingSettleChanged, 487))
            return;
        if (QtMocHelpers::indexOfMethod<void (Options::*)()>(_a, &Options::AlwaysResetSequenceWhenStartingChanged, 488))
            return;
        if (QtMocHelpers::indexOfMethod<void (Options::*)()>(_a, &Options::FlatSyncFocusChanged, 489))
            return;
        if (QtMocHelpers::indexOfMethod<void (Options::*)()>(_a, &Options::HFRThresholdPercentageChanged, 490))
            return;
        if (QtMocHelpers::indexOfMethod<void (Options::*)()>(_a, &Options::HFRCheckAlgorithmChanged, 491))
            return;
        if (QtMocHelpers::indexOfMethod<void (Options::*)()>(_a, &Options::InSequenceCheckFramesChanged, 492))
            return;
        if (QtMocHelpers::indexOfMethod<void (Options::*)()>(_a, &Options::AutoStretchChanged, 493))
            return;
        if (QtMocHelpers::indexOfMethod<void (Options::*)()>(_a, &Options::StretchPreviewSamplingChanged, 494))
            return;
        if (QtMocHelpers::indexOfMethod<void (Options::*)()>(_a, &Options::Clipping64KValueChanged, 495))
            return;
        if (QtMocHelpers::indexOfMethod<void (Options::*)()>(_a, &Options::Clipping256ValueChanged, 496))
            return;
        if (QtMocHelpers::indexOfMethod<void (Options::*)()>(_a, &Options::AdaptiveSamplingChanged, 497))
            return;
        if (QtMocHelpers::indexOfMethod<void (Options::*)()>(_a, &Options::useSummaryPreviewChanged, 498))
            return;
        if (QtMocHelpers::indexOfMethod<void (Options::*)()>(_a, &Options::useDSLRImageViewerChanged, 499))
            return;
        if (QtMocHelpers::indexOfMethod<void (Options::*)()>(_a, &Options::ForceDSLRPresetsChanged, 500))
            return;
        if (QtMocHelpers::indexOfMethod<void (Options::*)()>(_a, &Options::CaptureDirectoryChanged, 501))
            return;
        if (QtMocHelpers::indexOfMethod<void (Options::*)()>(_a, &Options::PlaceholderFormatChanged, 502))
            return;
        if (QtMocHelpers::indexOfMethod<void (Options::*)()>(_a, &Options::RemoteCaptureDirectoryChanged, 503))
            return;
        if (QtMocHelpers::indexOfMethod<void (Options::*)()>(_a, &Options::ManualCoverTimeoutChanged, 504))
            return;
        if (QtMocHelpers::indexOfMethod<void (Options::*)()>(_a, &Options::CaptureOperationsTimeoutChanged, 505))
            return;
        if (QtMocHelpers::indexOfMethod<void (Options::*)()>(_a, &Options::MinFlipDurationChanged, 506))
            return;
        if (QtMocHelpers::indexOfMethod<void (Options::*)()>(_a, &Options::CapturePositionChanged, 507))
            return;
        if (QtMocHelpers::indexOfMethod<void (Options::*)()>(_a, &Options::CaptureTrainIDChanged, 508))
            return;
        if (QtMocHelpers::indexOfMethod<void (Options::*)()>(_a, &Options::CaptureCalibrationWallChanged, 509))
            return;
        if (QtMocHelpers::indexOfMethod<void (Options::*)()>(_a, &Options::CaptureCalibrationParkMountChanged, 510))
            return;
        if (QtMocHelpers::indexOfMethod<void (Options::*)()>(_a, &Options::CaptureCalibrationParkDomeChanged, 511))
            return;
        if (QtMocHelpers::indexOfMethod<void (Options::*)()>(_a, &Options::CaptureCalibrationUseManualChanged, 512))
            return;
        if (QtMocHelpers::indexOfMethod<void (Options::*)()>(_a, &Options::CaptureCalibrationUseADUChanged, 513))
            return;
        if (QtMocHelpers::indexOfMethod<void (Options::*)()>(_a, &Options::CaptureCalibrationADUValueChanged, 514))
            return;
        if (QtMocHelpers::indexOfMethod<void (Options::*)()>(_a, &Options::CaptureCalibrationADUToleranceChanged, 515))
            return;
        if (QtMocHelpers::indexOfMethod<void (Options::*)()>(_a, &Options::CaptureCalibrationSkyFlatsChanged, 516))
            return;
        if (QtMocHelpers::indexOfMethod<void (Options::*)()>(_a, &Options::AbsTicksSpinChanged, 517))
            return;
        if (QtMocHelpers::indexOfMethod<void (Options::*)()>(_a, &Options::FocusExposureChanged, 518))
            return;
        if (QtMocHelpers::indexOfMethod<void (Options::*)()>(_a, &Options::FocusBinningChanged, 519))
            return;
        if (QtMocHelpers::indexOfMethod<void (Options::*)()>(_a, &Options::FocusGainChanged, 520))
            return;
        if (QtMocHelpers::indexOfMethod<void (Options::*)()>(_a, &Options::FocusISOChanged, 521))
            return;
        if (QtMocHelpers::indexOfMethod<void (Options::*)()>(_a, &Options::DefaultFocusTemperatureSourceChanged, 522))
            return;
        if (QtMocHelpers::indexOfMethod<void (Options::*)()>(_a, &Options::FocusFilterChanged, 523))
            return;
        if (QtMocHelpers::indexOfMethod<void (Options::*)()>(_a, &Options::UseFocusDarkFrameChanged, 524))
            return;
        if (QtMocHelpers::indexOfMethod<void (Options::*)()>(_a, &Options::FocusSubFrameChanged, 525))
            return;
        if (QtMocHelpers::indexOfMethod<void (Options::*)()>(_a, &Options::FocusBoxSizeChanged, 526))
            return;
        if (QtMocHelpers::indexOfMethod<void (Options::*)()>(_a, &Options::FocusUseFullFieldChanged, 527))
            return;
        if (QtMocHelpers::indexOfMethod<void (Options::*)()>(_a, &Options::FocusNoMaskRBChanged, 528))
            return;
        if (QtMocHelpers::indexOfMethod<void (Options::*)()>(_a, &Options::focusRingMaskRBChanged, 529))
            return;
        if (QtMocHelpers::indexOfMethod<void (Options::*)()>(_a, &Options::focusMosaicMaskRBChanged, 530))
            return;
        if (QtMocHelpers::indexOfMethod<void (Options::*)()>(_a, &Options::FocusFullFieldInnerRadiusChanged, 531))
            return;
        if (QtMocHelpers::indexOfMethod<void (Options::*)()>(_a, &Options::FocusFullFieldOuterRadiusChanged, 532))
            return;
        if (QtMocHelpers::indexOfMethod<void (Options::*)()>(_a, &Options::FocusMosaicTileWidthChanged, 533))
            return;
        if (QtMocHelpers::indexOfMethod<void (Options::*)()>(_a, &Options::focusMosaicSpaceChanged, 534))
            return;
        if (QtMocHelpers::indexOfMethod<void (Options::*)()>(_a, &Options::FocusAutoStarEnabledChanged, 535))
            return;
        if (QtMocHelpers::indexOfMethod<void (Options::*)()>(_a, &Options::FocusSuspendGuidingChanged, 536))
            return;
        if (QtMocHelpers::indexOfMethod<void (Options::*)()>(_a, &Options::FocusGuideSettleTimeChanged, 537))
            return;
        if (QtMocHelpers::indexOfMethod<void (Options::*)()>(_a, &Options::FocusUnitsChanged, 538))
            return;
        if (QtMocHelpers::indexOfMethod<void (Options::*)()>(_a, &Options::FocusAdaptiveChanged, 539))
            return;
        if (QtMocHelpers::indexOfMethod<void (Options::*)()>(_a, &Options::focusAdaptiveMinMoveChanged, 540))
            return;
        if (QtMocHelpers::indexOfMethod<void (Options::*)()>(_a, &Options::FocusAdaptStartChanged, 541))
            return;
        if (QtMocHelpers::indexOfMethod<void (Options::*)()>(_a, &Options::focusAdaptiveMaxMoveChanged, 542))
            return;
        if (QtMocHelpers::indexOfMethod<void (Options::*)()>(_a, &Options::FocusDetectionChanged, 543))
            return;
        if (QtMocHelpers::indexOfMethod<void (Options::*)()>(_a, &Options::FocusSEPProfileChanged, 544))
            return;
        if (QtMocHelpers::indexOfMethod<void (Options::*)()>(_a, &Options::FocusAlgorithmChanged, 545))
            return;
        if (QtMocHelpers::indexOfMethod<void (Options::*)()>(_a, &Options::FocusCurveFitChanged, 546))
            return;
        if (QtMocHelpers::indexOfMethod<void (Options::*)()>(_a, &Options::FocusStarMeasureChanged, 547))
            return;
        if (QtMocHelpers::indexOfMethod<void (Options::*)()>(_a, &Options::FocusStarPSFChanged, 548))
            return;
        if (QtMocHelpers::indexOfMethod<void (Options::*)()>(_a, &Options::FocusUseWeightsChanged, 549))
            return;
        if (QtMocHelpers::indexOfMethod<void (Options::*)()>(_a, &Options::FocusR2LimitChanged, 550))
            return;
        if (QtMocHelpers::indexOfMethod<void (Options::*)()>(_a, &Options::FocusRefineCurveFitChanged, 551))
            return;
        if (QtMocHelpers::indexOfMethod<void (Options::*)()>(_a, &Options::focusFramesCountChanged, 552))
            return;
        if (QtMocHelpers::indexOfMethod<void (Options::*)()>(_a, &Options::focusHFRFramesCountChanged, 553))
            return;
        if (QtMocHelpers::indexOfMethod<void (Options::*)()>(_a, &Options::FocusMultiRowAverageChanged, 554))
            return;
        if (QtMocHelpers::indexOfMethod<void (Options::*)()>(_a, &Options::FocusGaussianSigmaChanged, 555))
            return;
        if (QtMocHelpers::indexOfMethod<void (Options::*)()>(_a, &Options::FocusThresholdChanged, 556))
            return;
        if (QtMocHelpers::indexOfMethod<void (Options::*)()>(_a, &Options::FocusDenoiseChanged, 557))
            return;
        if (QtMocHelpers::indexOfMethod<void (Options::*)()>(_a, &Options::FocusDonutChanged, 558))
            return;
        if (QtMocHelpers::indexOfMethod<void (Options::*)()>(_a, &Options::FocusTimeDilationChanged, 559))
            return;
        if (QtMocHelpers::indexOfMethod<void (Options::*)()>(_a, &Options::focusOutlierRejectionChanged, 560))
            return;
        if (QtMocHelpers::indexOfMethod<void (Options::*)()>(_a, &Options::focusScanStartPosChanged, 561))
            return;
        if (QtMocHelpers::indexOfMethod<void (Options::*)()>(_a, &Options::focusScanAlwaysOnChanged, 562))
            return;
        if (QtMocHelpers::indexOfMethod<void (Options::*)()>(_a, &Options::focusScanDatapointsChanged, 563))
            return;
        if (QtMocHelpers::indexOfMethod<void (Options::*)()>(_a, &Options::focusScanStepSizeFactorChanged, 564))
            return;
        if (QtMocHelpers::indexOfMethod<void (Options::*)()>(_a, &Options::FocusGaussianKernelSizeChanged, 565))
            return;
        if (QtMocHelpers::indexOfMethod<void (Options::*)()>(_a, &Options::FocusToleranceChanged, 566))
            return;
        if (QtMocHelpers::indexOfMethod<void (Options::*)()>(_a, &Options::FocusWalkChanged, 567))
            return;
        if (QtMocHelpers::indexOfMethod<void (Options::*)()>(_a, &Options::FocusSettleTimeChanged, 568))
            return;
        if (QtMocHelpers::indexOfMethod<void (Options::*)()>(_a, &Options::FocusTicksChanged, 569))
            return;
        if (QtMocHelpers::indexOfMethod<void (Options::*)()>(_a, &Options::FocusOutStepsChanged, 570))
            return;
        if (QtMocHelpers::indexOfMethod<void (Options::*)()>(_a, &Options::focusNumStepsChanged, 571))
            return;
        if (QtMocHelpers::indexOfMethod<void (Options::*)()>(_a, &Options::FocusMaxTravelChanged, 572))
            return;
        if (QtMocHelpers::indexOfMethod<void (Options::*)()>(_a, &Options::FocusMaxSingleStepChanged, 573))
            return;
        if (QtMocHelpers::indexOfMethod<void (Options::*)()>(_a, &Options::FocusBacklashChanged, 574))
            return;
        if (QtMocHelpers::indexOfMethod<void (Options::*)()>(_a, &Options::FocusAFOverscanChanged, 575))
            return;
        if (QtMocHelpers::indexOfMethod<void (Options::*)()>(_a, &Options::FocusOverscanDelayChanged, 576))
            return;
        if (QtMocHelpers::indexOfMethod<void (Options::*)()>(_a, &Options::FocusCaptureTimeoutChanged, 577))
            return;
        if (QtMocHelpers::indexOfMethod<void (Options::*)()>(_a, &Options::FocusMotionTimeoutChanged, 578))
            return;
        if (QtMocHelpers::indexOfMethod<void (Options::*)()>(_a, &Options::focusCFZAlgorithmChanged, 579))
            return;
        if (QtMocHelpers::indexOfMethod<void (Options::*)()>(_a, &Options::focusCFZToleranceChanged, 580))
            return;
        if (QtMocHelpers::indexOfMethod<void (Options::*)()>(_a, &Options::focusCFZTauChanged, 581))
            return;
        if (QtMocHelpers::indexOfMethod<void (Options::*)()>(_a, &Options::focusCFZDisplayVCurveChanged, 582))
            return;
        if (QtMocHelpers::indexOfMethod<void (Options::*)()>(_a, &Options::focusCFZWavelengthChanged, 583))
            return;
        if (QtMocHelpers::indexOfMethod<void (Options::*)()>(_a, &Options::focusCFZApertureChanged, 584))
            return;
        if (QtMocHelpers::indexOfMethod<void (Options::*)()>(_a, &Options::focusCFZFNumberChanged, 585))
            return;
        if (QtMocHelpers::indexOfMethod<void (Options::*)()>(_a, &Options::focusCFZSeeingChanged, 586))
            return;
        if (QtMocHelpers::indexOfMethod<void (Options::*)()>(_a, &Options::focusCFZStepSizeChanged, 587))
            return;
        if (QtMocHelpers::indexOfMethod<void (Options::*)()>(_a, &Options::focusAdvHelpOnlyChangesChanged, 588))
            return;
        if (QtMocHelpers::indexOfMethod<void (Options::*)()>(_a, &Options::focusAdvUpdateParamsChanged, 589))
            return;
        if (QtMocHelpers::indexOfMethod<void (Options::*)()>(_a, &Options::focusAdvFindStarsChanged, 590))
            return;
        if (QtMocHelpers::indexOfMethod<void (Options::*)()>(_a, &Options::focusAdvCourseAdjChanged, 591))
            return;
        if (QtMocHelpers::indexOfMethod<void (Options::*)()>(_a, &Options::focusAdvFineAdjChanged, 592))
            return;
        if (QtMocHelpers::indexOfMethod<void (Options::*)()>(_a, &Options::FocusSplitterChanged, 593))
            return;
        if (QtMocHelpers::indexOfMethod<void (Options::*)()>(_a, &Options::rightLayoutChanged, 594))
            return;
        if (QtMocHelpers::indexOfMethod<void (Options::*)()>(_a, &Options::adaptFocusBFOChanged, 595))
            return;
        if (QtMocHelpers::indexOfMethod<void (Options::*)()>(_a, &Options::abInsTileSelectionChanged, 596))
            return;
        if (QtMocHelpers::indexOfMethod<void (Options::*)()>(_a, &Options::abInsShowLabelsChanged, 597))
            return;
        if (QtMocHelpers::indexOfMethod<void (Options::*)()>(_a, &Options::abInsShowCFZChanged, 598))
            return;
        if (QtMocHelpers::indexOfMethod<void (Options::*)()>(_a, &Options::abInsOptCentresChanged, 599))
            return;
        if (QtMocHelpers::indexOfMethod<void (Options::*)()>(_a, &Options::abInsHSplitterChanged, 600))
            return;
        if (QtMocHelpers::indexOfMethod<void (Options::*)()>(_a, &Options::abInsVSplitterChanged, 601))
            return;
        if (QtMocHelpers::indexOfMethod<void (Options::*)()>(_a, &Options::abInsSelectionChanged, 602))
            return;
        if (QtMocHelpers::indexOfMethod<void (Options::*)()>(_a, &Options::abInsThemeChanged, 603))
            return;
        if (QtMocHelpers::indexOfMethod<void (Options::*)()>(_a, &Options::abInsLabelsChanged, 604))
            return;
        if (QtMocHelpers::indexOfMethod<void (Options::*)()>(_a, &Options::abInsSensorChanged, 605))
            return;
        if (QtMocHelpers::indexOfMethod<void (Options::*)()>(_a, &Options::abInsPetzvalWireChanged, 606))
            return;
        if (QtMocHelpers::indexOfMethod<void (Options::*)()>(_a, &Options::abInsPetzvalSurfaceChanged, 607))
            return;
        if (QtMocHelpers::indexOfMethod<void (Options::*)()>(_a, &Options::tiltPlateTypeChanged, 608))
            return;
        if (QtMocHelpers::indexOfMethod<void (Options::*)()>(_a, &Options::tiltRadiusChanged, 609))
            return;
        if (QtMocHelpers::indexOfMethod<void (Options::*)()>(_a, &Options::tiltThreadIndexChanged, 610))
            return;
        if (QtMocHelpers::indexOfMethod<void (Options::*)()>(_a, &Options::tiltScrewPitchChanged, 611))
            return;
        if (QtMocHelpers::indexOfMethod<void (Options::*)()>(_a, &Options::tiltRotationChanged, 612))
            return;
        if (QtMocHelpers::indexOfMethod<void (Options::*)()>(_a, &Options::tiltModeChanged, 613))
            return;
        if (QtMocHelpers::indexOfMethod<void (Options::*)()>(_a, &Options::tiltPlatePresentChanged, 614))
            return;
        if (QtMocHelpers::indexOfMethod<void (Options::*)()>(_a, &Options::FocusSextractorTypeChanged, 615))
            return;
        if (QtMocHelpers::indexOfMethod<void (Options::*)()>(_a, &Options::FocusOptionsProfileChanged, 616))
            return;
        if (QtMocHelpers::indexOfMethod<void (Options::*)()>(_a, &Options::HFRSextractorTypeChanged, 617))
            return;
        if (QtMocHelpers::indexOfMethod<void (Options::*)()>(_a, &Options::HFROptionsProfileChanged, 618))
            return;
        if (QtMocHelpers::indexOfMethod<void (Options::*)()>(_a, &Options::GuideSextractorTypeChanged, 619))
            return;
        if (QtMocHelpers::indexOfMethod<void (Options::*)()>(_a, &Options::GuideOptionsProfileChanged, 620))
            return;
        if (QtMocHelpers::indexOfMethod<void (Options::*)()>(_a, &Options::SolveSextractorTypeChanged, 621))
            return;
        if (QtMocHelpers::indexOfMethod<void (Options::*)()>(_a, &Options::SolverModeChanged, 622))
            return;
        if (QtMocHelpers::indexOfMethod<void (Options::*)()>(_a, &Options::SolverTypeChanged, 623))
            return;
        if (QtMocHelpers::indexOfMethod<void (Options::*)()>(_a, &Options::SolveOptionsProfileChanged, 624))
            return;
        if (QtMocHelpers::indexOfMethod<void (Options::*)()>(_a, &Options::LoggerLevelChanged, 625))
            return;
        if (QtMocHelpers::indexOfMethod<void (Options::*)()>(_a, &Options::AstrometryLogToFileChanged, 626))
            return;
        if (QtMocHelpers::indexOfMethod<void (Options::*)()>(_a, &Options::AstrometryLogFilepathChanged, 627))
            return;
        if (QtMocHelpers::indexOfMethod<void (Options::*)()>(_a, &Options::AstrometryIndexFolderListChanged, 628))
            return;
        if (QtMocHelpers::indexOfMethod<void (Options::*)()>(_a, &Options::AlignExposureChanged, 629))
            return;
        if (QtMocHelpers::indexOfMethod<void (Options::*)()>(_a, &Options::AlignBinningChanged, 630))
            return;
        if (QtMocHelpers::indexOfMethod<void (Options::*)()>(_a, &Options::AlignGainChanged, 631))
            return;
        if (QtMocHelpers::indexOfMethod<void (Options::*)()>(_a, &Options::AlignISOChanged, 632))
            return;
        if (QtMocHelpers::indexOfMethod<void (Options::*)()>(_a, &Options::AlignDarkFrameChanged, 633))
            return;
        if (QtMocHelpers::indexOfMethod<void (Options::*)()>(_a, &Options::AlignFilterChanged, 634))
            return;
        if (QtMocHelpers::indexOfMethod<void (Options::*)()>(_a, &Options::AlignUseCurrentFilterChanged, 635))
            return;
        if (QtMocHelpers::indexOfMethod<void (Options::*)()>(_a, &Options::AstrometryUseRotatorChanged, 636))
            return;
        if (QtMocHelpers::indexOfMethod<void (Options::*)()>(_a, &Options::AstrometryRotatorThresholdChanged, 637))
            return;
        if (QtMocHelpers::indexOfMethod<void (Options::*)()>(_a, &Options::AstrometryFlipRotationAllowedChanged, 638))
            return;
        if (QtMocHelpers::indexOfMethod<void (Options::*)()>(_a, &Options::RotatorParityReversedChanged, 639))
            return;
        if (QtMocHelpers::indexOfMethod<void (Options::*)()>(_a, &Options::AstrometrySolverWCSChanged, 640))
            return;
        if (QtMocHelpers::indexOfMethod<void (Options::*)()>(_a, &Options::AstrometrySolverOverlayChanged, 641))
            return;
        if (QtMocHelpers::indexOfMethod<void (Options::*)()>(_a, &Options::AstrometryDifferentialSlewingChanged, 642))
            return;
        if (QtMocHelpers::indexOfMethod<void (Options::*)()>(_a, &Options::AlignAccuracyThresholdChanged, 643))
            return;
        if (QtMocHelpers::indexOfMethod<void (Options::*)()>(_a, &Options::AlignSettlingTimeChanged, 644))
            return;
        if (QtMocHelpers::indexOfMethod<void (Options::*)()>(_a, &Options::AstrometryUseNoFITS2FITSChanged, 645))
            return;
        if (QtMocHelpers::indexOfMethod<void (Options::*)()>(_a, &Options::AstrometryUseResortChanged, 646))
            return;
        if (QtMocHelpers::indexOfMethod<void (Options::*)()>(_a, &Options::AstrometryUseNoVerifyChanged, 647))
            return;
        if (QtMocHelpers::indexOfMethod<void (Options::*)()>(_a, &Options::AstrometryUseImageScaleChanged, 648))
            return;
        if (QtMocHelpers::indexOfMethod<void (Options::*)()>(_a, &Options::AstrometryImageScaleLowChanged, 649))
            return;
        if (QtMocHelpers::indexOfMethod<void (Options::*)()>(_a, &Options::AstrometryImageScaleHighChanged, 650))
            return;
        if (QtMocHelpers::indexOfMethod<void (Options::*)()>(_a, &Options::AstrometryAutoUpdateImageScaleChanged, 651))
            return;
        if (QtMocHelpers::indexOfMethod<void (Options::*)()>(_a, &Options::AstrometryImageScaleUnitsChanged, 652))
            return;
        if (QtMocHelpers::indexOfMethod<void (Options::*)()>(_a, &Options::AstrometryUseDownsampleChanged, 653))
            return;
        if (QtMocHelpers::indexOfMethod<void (Options::*)()>(_a, &Options::AstrometryDownsampleChanged, 654))
            return;
        if (QtMocHelpers::indexOfMethod<void (Options::*)()>(_a, &Options::AstrometryAutoDownsampleChanged, 655))
            return;
        if (QtMocHelpers::indexOfMethod<void (Options::*)()>(_a, &Options::AstrometryDynamicThresholdChanged, 656))
            return;
        if (QtMocHelpers::indexOfMethod<void (Options::*)()>(_a, &Options::AstrometryUsePositionChanged, 657))
            return;
        if (QtMocHelpers::indexOfMethod<void (Options::*)()>(_a, &Options::AstrometryPositionRAChanged, 658))
            return;
        if (QtMocHelpers::indexOfMethod<void (Options::*)()>(_a, &Options::AstrometryPositionDEChanged, 659))
            return;
        if (QtMocHelpers::indexOfMethod<void (Options::*)()>(_a, &Options::AstrometryAutoUpdatePositionChanged, 660))
            return;
        if (QtMocHelpers::indexOfMethod<void (Options::*)()>(_a, &Options::AstrometryRadiusChanged, 661))
            return;
        if (QtMocHelpers::indexOfMethod<void (Options::*)()>(_a, &Options::AstrometryDetectParityChanged, 662))
            return;
        if (QtMocHelpers::indexOfMethod<void (Options::*)()>(_a, &Options::AstrometryCustomOptionsChanged, 663))
            return;
        if (QtMocHelpers::indexOfMethod<void (Options::*)()>(_a, &Options::AstrometrySolverBinaryChanged, 664))
            return;
        if (QtMocHelpers::indexOfMethod<void (Options::*)()>(_a, &Options::AstrometryWCSInfoChanged, 665))
            return;
        if (QtMocHelpers::indexOfMethod<void (Options::*)()>(_a, &Options::AstrometryConfFileChanged, 666))
            return;
        if (QtMocHelpers::indexOfMethod<void (Options::*)()>(_a, &Options::SextractorBinaryChanged, 667))
            return;
        if (QtMocHelpers::indexOfMethod<void (Options::*)()>(_a, &Options::WatneyBinaryChanged, 668))
            return;
        if (QtMocHelpers::indexOfMethod<void (Options::*)()>(_a, &Options::AstrometryAPIKeyChanged, 669))
            return;
        if (QtMocHelpers::indexOfMethod<void (Options::*)()>(_a, &Options::AstrometryAPIURLChanged, 670))
            return;
        if (QtMocHelpers::indexOfMethod<void (Options::*)()>(_a, &Options::AstrometryUseJPEGChanged, 671))
            return;
        if (QtMocHelpers::indexOfMethod<void (Options::*)()>(_a, &Options::AstrometryTimeoutChanged, 672))
            return;
        if (QtMocHelpers::indexOfMethod<void (Options::*)()>(_a, &Options::PAHMountSpeedChanged, 673))
            return;
        if (QtMocHelpers::indexOfMethod<void (Options::*)()>(_a, &Options::PAHRotaionChanged, 674))
            return;
        if (QtMocHelpers::indexOfMethod<void (Options::*)()>(_a, &Options::PAHRefreshAlgorithmChanged, 675))
            return;
        if (QtMocHelpers::indexOfMethod<void (Options::*)()>(_a, &Options::PAHDirectionChanged, 676))
            return;
        if (QtMocHelpers::indexOfMethod<void (Options::*)()>(_a, &Options::PAHAutoParkChanged, 677))
            return;
        if (QtMocHelpers::indexOfMethod<void (Options::*)()>(_a, &Options::PAHManualSlewChanged, 678))
            return;
        if (QtMocHelpers::indexOfMethod<void (Options::*)()>(_a, &Options::PAHExposureChanged, 679))
            return;
        if (QtMocHelpers::indexOfMethod<void (Options::*)()>(_a, &Options::PAHAutoPACCorrectionChanged, 680))
            return;
        if (QtMocHelpers::indexOfMethod<void (Options::*)()>(_a, &Options::PAHAutoChangeDirectionChanged, 681))
            return;
        if (QtMocHelpers::indexOfMethod<void (Options::*)()>(_a, &Options::PAHSuccessThresholdChanged, 682))
            return;
        if (QtMocHelpers::indexOfMethod<void (Options::*)()>(_a, &Options::PAHCorrectionTimeoutChanged, 683))
            return;
        if (QtMocHelpers::indexOfMethod<void (Options::*)()>(_a, &Options::GuideExposureChanged, 684))
            return;
        if (QtMocHelpers::indexOfMethod<void (Options::*)()>(_a, &Options::GuideDelayChanged, 685))
            return;
        if (QtMocHelpers::indexOfMethod<void (Options::*)()>(_a, &Options::GuiderTypeChanged, 686))
            return;
        if (QtMocHelpers::indexOfMethod<void (Options::*)()>(_a, &Options::GuideAlgorithmChanged, 687))
            return;
        if (QtMocHelpers::indexOfMethod<void (Options::*)()>(_a, &Options::RAGuidePulseAlgorithmChanged, 688))
            return;
        if (QtMocHelpers::indexOfMethod<void (Options::*)()>(_a, &Options::DECGuidePulseAlgorithmChanged, 689))
            return;
        if (QtMocHelpers::indexOfMethod<void (Options::*)()>(_a, &Options::AIGuiderWeightsFileChanged, 690))
            return;
        if (QtMocHelpers::indexOfMethod<void (Options::*)()>(_a, &Options::AIPredictionGainChanged, 691))
            return;
        if (QtMocHelpers::indexOfMethod<void (Options::*)()>(_a, &Options::AIProportionalBackoffChanged, 692))
            return;
        if (QtMocHelpers::indexOfMethod<void (Options::*)()>(_a, &Options::AIPIDAutoTuneChanged, 693))
            return;
        if (QtMocHelpers::indexOfMethod<void (Options::*)()>(_a, &Options::AIShadowModeChanged, 694))
            return;
        if (QtMocHelpers::indexOfMethod<void (Options::*)()>(_a, &Options::PHD2HostChanged, 695))
            return;
        if (QtMocHelpers::indexOfMethod<void (Options::*)()>(_a, &Options::PHD2PortChanged, 696))
            return;
        if (QtMocHelpers::indexOfMethod<void (Options::*)()>(_a, &Options::LinGuiderHostChanged, 697))
            return;
        if (QtMocHelpers::indexOfMethod<void (Options::*)()>(_a, &Options::LinGuiderPortChanged, 698))
            return;
        if (QtMocHelpers::indexOfMethod<void (Options::*)()>(_a, &Options::CalibrationPulseDurationChanged, 699))
            return;
        if (QtMocHelpers::indexOfMethod<void (Options::*)()>(_a, &Options::CalibrationMaxMoveChanged, 700))
            return;
        if (QtMocHelpers::indexOfMethod<void (Options::*)()>(_a, &Options::GuideSquareSizeChanged, 701))
            return;
        if (QtMocHelpers::indexOfMethod<void (Options::*)()>(_a, &Options::GuideBinningChanged, 702))
            return;
        if (QtMocHelpers::indexOfMethod<void (Options::*)()>(_a, &Options::GuideAutoStarChanged, 703))
            return;
        if (QtMocHelpers::indexOfMethod<void (Options::*)()>(_a, &Options::guideShowFrameChanged, 704))
            return;
        if (QtMocHelpers::indexOfMethod<void (Options::*)()>(_a, &Options::GuideAutoSquareSizeEnabledChanged, 705))
            return;
        if (QtMocHelpers::indexOfMethod<void (Options::*)()>(_a, &Options::AutoModeIterationsChanged, 706))
            return;
        if (QtMocHelpers::indexOfMethod<void (Options::*)()>(_a, &Options::GuideLostStarTimeoutChanged, 707))
            return;
        if (QtMocHelpers::indexOfMethod<void (Options::*)()>(_a, &Options::GuideCalibrationTimeoutChanged, 708))
            return;
        if (QtMocHelpers::indexOfMethod<void (Options::*)()>(_a, &Options::GuideMaxDeltaRMSChanged, 709))
            return;
        if (QtMocHelpers::indexOfMethod<void (Options::*)()>(_a, &Options::GuideMaxHFRChanged, 710))
            return;
        if (QtMocHelpers::indexOfMethod<void (Options::*)()>(_a, &Options::MinDetectionsSEPMultistarChanged, 711))
            return;
        if (QtMocHelpers::indexOfMethod<void (Options::*)()>(_a, &Options::MaxMultistarReferenceStarsChanged, 712))
            return;
        if (QtMocHelpers::indexOfMethod<void (Options::*)()>(_a, &Options::AlwaysInventGuideStarChanged, 713))
            return;
        if (QtMocHelpers::indexOfMethod<void (Options::*)()>(_a, &Options::TwoAxisEnabledChanged, 714))
            return;
        if (QtMocHelpers::indexOfMethod<void (Options::*)()>(_a, &Options::UseGuideHeadChanged, 715))
            return;
        if (QtMocHelpers::indexOfMethod<void (Options::*)()>(_a, &Options::SaveGuideLogChanged, 716))
            return;
        if (QtMocHelpers::indexOfMethod<void (Options::*)()>(_a, &Options::GuideDarkFrameChanged, 717))
            return;
        if (QtMocHelpers::indexOfMethod<void (Options::*)()>(_a, &Options::GuideSubframeChanged, 718))
            return;
        if (QtMocHelpers::indexOfMethod<void (Options::*)()>(_a, &Options::DitherPixelsChanged, 719))
            return;
        if (QtMocHelpers::indexOfMethod<void (Options::*)()>(_a, &Options::DitherFramesChanged, 720))
            return;
        if (QtMocHelpers::indexOfMethod<void (Options::*)()>(_a, &Options::DitherSettleChanged, 721))
            return;
        if (QtMocHelpers::indexOfMethod<void (Options::*)()>(_a, &Options::DitherThresholdChanged, 722))
            return;
        if (QtMocHelpers::indexOfMethod<void (Options::*)()>(_a, &Options::DitherTimeoutChanged, 723))
            return;
        if (QtMocHelpers::indexOfMethod<void (Options::*)()>(_a, &Options::DitherMaxIterationsChanged, 724))
            return;
        if (QtMocHelpers::indexOfMethod<void (Options::*)()>(_a, &Options::DitherNoGuidingPulseChanged, 725))
            return;
        if (QtMocHelpers::indexOfMethod<void (Options::*)()>(_a, &Options::DitherFailAbortsAutoGuideChanged, 726))
            return;
        if (QtMocHelpers::indexOfMethod<void (Options::*)()>(_a, &Options::DitherWithOnePulseChanged, 727))
            return;
        if (QtMocHelpers::indexOfMethod<void (Options::*)()>(_a, &Options::DitherEnabledChanged, 728))
            return;
        if (QtMocHelpers::indexOfMethod<void (Options::*)()>(_a, &Options::DitherNoGuidingChanged, 729))
            return;
        if (QtMocHelpers::indexOfMethod<void (Options::*)()>(_a, &Options::RAGuideEnabledChanged, 730))
            return;
        if (QtMocHelpers::indexOfMethod<void (Options::*)()>(_a, &Options::DECGuideEnabledChanged, 731))
            return;
        if (QtMocHelpers::indexOfMethod<void (Options::*)()>(_a, &Options::NorthDECGuideEnabledChanged, 732))
            return;
        if (QtMocHelpers::indexOfMethod<void (Options::*)()>(_a, &Options::SouthDECGuideEnabledChanged, 733))
            return;
        if (QtMocHelpers::indexOfMethod<void (Options::*)()>(_a, &Options::EastRAGuideEnabledChanged, 734))
            return;
        if (QtMocHelpers::indexOfMethod<void (Options::*)()>(_a, &Options::WestRAGuideEnabledChanged, 735))
            return;
        if (QtMocHelpers::indexOfMethod<void (Options::*)()>(_a, &Options::RAProportionalGainChanged, 736))
            return;
        if (QtMocHelpers::indexOfMethod<void (Options::*)()>(_a, &Options::DECProportionalGainChanged, 737))
            return;
        if (QtMocHelpers::indexOfMethod<void (Options::*)()>(_a, &Options::RAIntegralGainChanged, 738))
            return;
        if (QtMocHelpers::indexOfMethod<void (Options::*)()>(_a, &Options::DECIntegralGainChanged, 739))
            return;
        if (QtMocHelpers::indexOfMethod<void (Options::*)()>(_a, &Options::RAMinimumPulseArcSecChanged, 740))
            return;
        if (QtMocHelpers::indexOfMethod<void (Options::*)()>(_a, &Options::DECMinimumPulseArcSecChanged, 741))
            return;
        if (QtMocHelpers::indexOfMethod<void (Options::*)()>(_a, &Options::RAMaximumPulseArcSecChanged, 742))
            return;
        if (QtMocHelpers::indexOfMethod<void (Options::*)()>(_a, &Options::DECMaximumPulseArcSecChanged, 743))
            return;
        if (QtMocHelpers::indexOfMethod<void (Options::*)()>(_a, &Options::GPGEnabledChanged, 744))
            return;
        if (QtMocHelpers::indexOfMethod<void (Options::*)()>(_a, &Options::GPGDarkGuidingChanged, 745))
            return;
        if (QtMocHelpers::indexOfMethod<void (Options::*)()>(_a, &Options::GPGDarkGuidingIntervalChanged, 746))
            return;
        if (QtMocHelpers::indexOfMethod<void (Options::*)()>(_a, &Options::AIDarkGuidingChanged, 747))
            return;
        if (QtMocHelpers::indexOfMethod<void (Options::*)()>(_a, &Options::AIDarkGuidingIntervalChanged, 748))
            return;
        if (QtMocHelpers::indexOfMethod<void (Options::*)()>(_a, &Options::GPGcWeightChanged, 749))
            return;
        if (QtMocHelpers::indexOfMethod<void (Options::*)()>(_a, &Options::GPGMinPeriodsForInferenceChanged, 750))
            return;
        if (QtMocHelpers::indexOfMethod<void (Options::*)()>(_a, &Options::GPGMinMoveChanged, 751))
            return;
        if (QtMocHelpers::indexOfMethod<void (Options::*)()>(_a, &Options::GPGSE0KLengthScaleChanged, 752))
            return;
        if (QtMocHelpers::indexOfMethod<void (Options::*)()>(_a, &Options::GPGSE0KSignalVarianceChanged, 753))
            return;
        if (QtMocHelpers::indexOfMethod<void (Options::*)()>(_a, &Options::GPGPKLengthScaleChanged, 754))
            return;
        if (QtMocHelpers::indexOfMethod<void (Options::*)()>(_a, &Options::GPGPeriodChanged, 755))
            return;
        if (QtMocHelpers::indexOfMethod<void (Options::*)()>(_a, &Options::GPGPKSignalVarianceChanged, 756))
            return;
        if (QtMocHelpers::indexOfMethod<void (Options::*)()>(_a, &Options::GPGSE1KLengthScaleChanged, 757))
            return;
        if (QtMocHelpers::indexOfMethod<void (Options::*)()>(_a, &Options::GPGSE1KSignalVarianceChanged, 758))
            return;
        if (QtMocHelpers::indexOfMethod<void (Options::*)()>(_a, &Options::GPGMinPeriodsForPeriodEstimateChanged, 759))
            return;
        if (QtMocHelpers::indexOfMethod<void (Options::*)()>(_a, &Options::GPGPointsForApproximationChanged, 760))
            return;
        if (QtMocHelpers::indexOfMethod<void (Options::*)()>(_a, &Options::GPGpWeightChanged, 761))
            return;
        if (QtMocHelpers::indexOfMethod<void (Options::*)()>(_a, &Options::GPGEstimatePeriodChanged, 762))
            return;
        if (QtMocHelpers::indexOfMethod<void (Options::*)()>(_a, &Options::GuiderAccuracyThresholdChanged, 763))
            return;
        if (QtMocHelpers::indexOfMethod<void (Options::*)()>(_a, &Options::RADisplayedOnGuideGraphChanged, 764))
            return;
        if (QtMocHelpers::indexOfMethod<void (Options::*)()>(_a, &Options::DEDisplayedOnGuideGraphChanged, 765))
            return;
        if (QtMocHelpers::indexOfMethod<void (Options::*)()>(_a, &Options::RACorrDisplayedOnGuideGraphChanged, 766))
            return;
        if (QtMocHelpers::indexOfMethod<void (Options::*)()>(_a, &Options::DECorrDisplayedOnGuideGraphChanged, 767))
            return;
        if (QtMocHelpers::indexOfMethod<void (Options::*)()>(_a, &Options::SNRDisplayedOnGuideGraphChanged, 768))
            return;
        if (QtMocHelpers::indexOfMethod<void (Options::*)()>(_a, &Options::RMSDisplayedOnGuideGraphChanged, 769))
            return;
        if (QtMocHelpers::indexOfMethod<void (Options::*)()>(_a, &Options::RAHysteresisChanged, 770))
            return;
        if (QtMocHelpers::indexOfMethod<void (Options::*)()>(_a, &Options::DECHysteresisChanged, 771))
            return;
        if (QtMocHelpers::indexOfMethod<void (Options::*)()>(_a, &Options::SchedulerAlgorithmChanged, 772))
            return;
        if (QtMocHelpers::indexOfMethod<void (Options::*)()>(_a, &Options::SchedulerLoggingChanged, 773))
            return;
        if (QtMocHelpers::indexOfMethod<void (Options::*)()>(_a, &Options::StopEkosAfterShutdownChanged, 774))
            return;
        if (QtMocHelpers::indexOfMethod<void (Options::*)()>(_a, &Options::ShutdownScriptTerminatesINDIChanged, 775))
            return;
        if (QtMocHelpers::indexOfMethod<void (Options::*)()>(_a, &Options::CameraWarmupEnabledChanged, 776))
            return;
        if (QtMocHelpers::indexOfMethod<void (Options::*)()>(_a, &Options::CameraWarmupRampChanged, 777))
            return;
        if (QtMocHelpers::indexOfMethod<void (Options::*)()>(_a, &Options::PreemptiveShutdownChanged, 778))
            return;
        if (QtMocHelpers::indexOfMethod<void (Options::*)()>(_a, &Options::ResetMountModelOnAlignFailChanged, 779))
            return;
        if (QtMocHelpers::indexOfMethod<void (Options::*)()>(_a, &Options::ResetMountModelBeforeJobChanged, 780))
            return;
        if (QtMocHelpers::indexOfMethod<void (Options::*)()>(_a, &Options::ResetGuideCalibrationChanged, 781))
            return;
        if (QtMocHelpers::indexOfMethod<void (Options::*)()>(_a, &Options::ForceAlignmentBeforeJobChanged, 782))
            return;
        if (QtMocHelpers::indexOfMethod<void (Options::*)()>(_a, &Options::ReuseGuideCalibrationChanged, 783))
            return;
        if (QtMocHelpers::indexOfMethod<void (Options::*)()>(_a, &Options::ReverseDecOnPierSideChangeChanged, 784))
            return;
        if (QtMocHelpers::indexOfMethod<void (Options::*)()>(_a, &Options::GuideCalibrationBacklashChanged, 785))
            return;
        if (QtMocHelpers::indexOfMethod<void (Options::*)()>(_a, &Options::AssumeDecOrthogonalChanged, 786))
            return;
        if (QtMocHelpers::indexOfMethod<void (Options::*)()>(_a, &Options::SerializedCalibrationChanged, 787))
            return;
        if (QtMocHelpers::indexOfMethod<void (Options::*)()>(_a, &Options::RealignAfterCalibrationFailureChanged, 788))
            return;
        if (QtMocHelpers::indexOfMethod<void (Options::*)()>(_a, &Options::PreemptiveShutdownTimeChanged, 789))
            return;
        if (QtMocHelpers::indexOfMethod<void (Options::*)()>(_a, &Options::RememberJobProgressChanged, 790))
            return;
        if (QtMocHelpers::indexOfMethod<void (Options::*)()>(_a, &Options::GreedySchedulingChanged, 791))
            return;
        if (QtMocHelpers::indexOfMethod<void (Options::*)()>(_a, &Options::LeadTimeChanged, 792))
            return;
        if (QtMocHelpers::indexOfMethod<void (Options::*)()>(_a, &Options::PreDawnTimeChanged, 793))
            return;
        if (QtMocHelpers::indexOfMethod<void (Options::*)()>(_a, &Options::DawnOffsetChanged, 794))
            return;
        if (QtMocHelpers::indexOfMethod<void (Options::*)()>(_a, &Options::DuskOffsetChanged, 795))
            return;
        if (QtMocHelpers::indexOfMethod<void (Options::*)()>(_a, &Options::TelescopeFocalLengthChanged, 796))
            return;
        if (QtMocHelpers::indexOfMethod<void (Options::*)()>(_a, &Options::TelescopeFocalReducerChanged, 797))
            return;
        if (QtMocHelpers::indexOfMethod<void (Options::*)()>(_a, &Options::CameraPixelWidthChanged, 798))
            return;
        if (QtMocHelpers::indexOfMethod<void (Options::*)()>(_a, &Options::CameraPixelHeightChanged, 799))
            return;
        if (QtMocHelpers::indexOfMethod<void (Options::*)()>(_a, &Options::CameraWidthChanged, 800))
            return;
        if (QtMocHelpers::indexOfMethod<void (Options::*)()>(_a, &Options::CameraHeightChanged, 801))
            return;
        if (QtMocHelpers::indexOfMethod<void (Options::*)()>(_a, &Options::CameraRotationChanged, 802))
            return;
        if (QtMocHelpers::indexOfMethod<void (Options::*)()>(_a, &Options::ErrorHandlingStrategyChanged, 803))
            return;
        if (QtMocHelpers::indexOfMethod<void (Options::*)()>(_a, &Options::ErrorHandlingStrategyDelayChanged, 804))
            return;
        if (QtMocHelpers::indexOfMethod<void (Options::*)()>(_a, &Options::RescheduleErrorsChanged, 805))
            return;
        if (QtMocHelpers::indexOfMethod<void (Options::*)()>(_a, &Options::AlignCheckFrequencyChanged, 806))
            return;
        if (QtMocHelpers::indexOfMethod<void (Options::*)()>(_a, &Options::AlignCheckThresholdChanged, 807))
            return;
        if (QtMocHelpers::indexOfMethod<void (Options::*)()>(_a, &Options::SchedulerTrackStepChanged, 808))
            return;
        if (QtMocHelpers::indexOfMethod<void (Options::*)()>(_a, &Options::SchedulerStartupEnabledChanged, 809))
            return;
        if (QtMocHelpers::indexOfMethod<void (Options::*)()>(_a, &Options::SchedulerPreStartupScriptChanged, 810))
            return;
        if (QtMocHelpers::indexOfMethod<void (Options::*)()>(_a, &Options::SchedulerPostStartupScriptChanged, 811))
            return;
        if (QtMocHelpers::indexOfMethod<void (Options::*)()>(_a, &Options::SchedulerShutdownEnabledChanged, 812))
            return;
        if (QtMocHelpers::indexOfMethod<void (Options::*)()>(_a, &Options::SchedulerPreShutdownScriptChanged, 813))
            return;
        if (QtMocHelpers::indexOfMethod<void (Options::*)()>(_a, &Options::SchedulerPostShutdownScriptChanged, 814))
            return;
        if (QtMocHelpers::indexOfMethod<void (Options::*)()>(_a, &Options::SchedulerFocusStepChanged, 815))
            return;
        if (QtMocHelpers::indexOfMethod<void (Options::*)()>(_a, &Options::SchedulerGuideStepChanged, 816))
            return;
        if (QtMocHelpers::indexOfMethod<void (Options::*)()>(_a, &Options::SchedulerAlignStepChanged, 817))
            return;
        if (QtMocHelpers::indexOfMethod<void (Options::*)()>(_a, &Options::SchedulerAltitudeChanged, 818))
            return;
        if (QtMocHelpers::indexOfMethod<void (Options::*)()>(_a, &Options::SchedulerAltitudeValueChanged, 819))
            return;
        if (QtMocHelpers::indexOfMethod<void (Options::*)()>(_a, &Options::SchedulerHorizonChanged, 820))
            return;
        if (QtMocHelpers::indexOfMethod<void (Options::*)()>(_a, &Options::SchedulerMoonSeparationChanged, 821))
            return;
        if (QtMocHelpers::indexOfMethod<void (Options::*)()>(_a, &Options::SchedulerMoonSeparationValueChanged, 822))
            return;
        if (QtMocHelpers::indexOfMethod<void (Options::*)()>(_a, &Options::SchedulerMoonAltitudeChanged, 823))
            return;
        if (QtMocHelpers::indexOfMethod<void (Options::*)()>(_a, &Options::SchedulerMoonAltitudeMaxValueChanged, 824))
            return;
        if (QtMocHelpers::indexOfMethod<void (Options::*)()>(_a, &Options::SchedulerWeatherChanged, 825))
            return;
        if (QtMocHelpers::indexOfMethod<void (Options::*)()>(_a, &Options::SchedulerWeatherGracePeriodChanged, 826))
            return;
        if (QtMocHelpers::indexOfMethod<void (Options::*)()>(_a, &Options::SchedulerWeatherShutdownDelayChanged, 827))
            return;
        if (QtMocHelpers::indexOfMethod<void (Options::*)()>(_a, &Options::SchedulerSafetyMonitorConnectionStringChanged, 828))
            return;
        if (QtMocHelpers::indexOfMethod<void (Options::*)()>(_a, &Options::SchedulerTwilightChanged, 829))
            return;
        if (QtMocHelpers::indexOfMethod<void (Options::*)()>(_a, &Options::SchedulerCompleteSequencesChanged, 830))
            return;
        if (QtMocHelpers::indexOfMethod<void (Options::*)()>(_a, &Options::SchedulerRepeatEverythingChanged, 831))
            return;
        if (QtMocHelpers::indexOfMethod<void (Options::*)()>(_a, &Options::SchedulerRepeatSequencesChanged, 832))
            return;
        if (QtMocHelpers::indexOfMethod<void (Options::*)()>(_a, &Options::SchedulerUntilTerminatedChanged, 833))
            return;
        if (QtMocHelpers::indexOfMethod<void (Options::*)()>(_a, &Options::SchedulerUntilChanged, 834))
            return;
        if (QtMocHelpers::indexOfMethod<void (Options::*)()>(_a, &Options::SchedulerUntilValueChanged, 835))
            return;
        if (QtMocHelpers::indexOfMethod<void (Options::*)()>(_a, &Options::SchedulerExecutionSequencesLimitChanged, 836))
            return;
        if (QtMocHelpers::indexOfMethod<void (Options::*)()>(_a, &Options::AnalyzeRestartWithEkosChanged, 837))
            return;
        if (QtMocHelpers::indexOfMethod<void (Options::*)()>(_a, &Options::AnalyzeAlternativeDirectoryNameChanged, 838))
            return;
        if (QtMocHelpers::indexOfMethod<void (Options::*)()>(_a, &Options::AnalyzeHFRChanged, 839))
            return;
        if (QtMocHelpers::indexOfMethod<void (Options::*)()>(_a, &Options::AnalyzeNumCaptureStarsChanged, 840))
            return;
        if (QtMocHelpers::indexOfMethod<void (Options::*)()>(_a, &Options::AnalyzeMedianChanged, 841))
            return;
        if (QtMocHelpers::indexOfMethod<void (Options::*)()>(_a, &Options::AnalyzeEccentricityChanged, 842))
            return;
        if (QtMocHelpers::indexOfMethod<void (Options::*)()>(_a, &Options::AnalyzeTemperatureChanged, 843))
            return;
        if (QtMocHelpers::indexOfMethod<void (Options::*)()>(_a, &Options::FocusPositionChanged, 844))
            return;
        if (QtMocHelpers::indexOfMethod<void (Options::*)()>(_a, &Options::AnalyzeNumStarsChanged, 845))
            return;
        if (QtMocHelpers::indexOfMethod<void (Options::*)()>(_a, &Options::AnalyzeSkyBgChanged, 846))
            return;
        if (QtMocHelpers::indexOfMethod<void (Options::*)()>(_a, &Options::AnalyzeSNRChanged, 847))
            return;
        if (QtMocHelpers::indexOfMethod<void (Options::*)()>(_a, &Options::AnalyzeRAChanged, 848))
            return;
        if (QtMocHelpers::indexOfMethod<void (Options::*)()>(_a, &Options::AnalyzeDECChanged, 849))
            return;
        if (QtMocHelpers::indexOfMethod<void (Options::*)()>(_a, &Options::AnalyzeRApChanged, 850))
            return;
        if (QtMocHelpers::indexOfMethod<void (Options::*)()>(_a, &Options::AnalyzeDECpChanged, 851))
            return;
        if (QtMocHelpers::indexOfMethod<void (Options::*)()>(_a, &Options::AnalyzeDriftChanged, 852))
            return;
        if (QtMocHelpers::indexOfMethod<void (Options::*)()>(_a, &Options::AnalyzeRMSChanged, 853))
            return;
        if (QtMocHelpers::indexOfMethod<void (Options::*)()>(_a, &Options::AnalyzeTargetDistanceChanged, 854))
            return;
        if (QtMocHelpers::indexOfMethod<void (Options::*)()>(_a, &Options::AnalyzeRMSCChanged, 855))
            return;
        if (QtMocHelpers::indexOfMethod<void (Options::*)()>(_a, &Options::AnalyzeMountRAChanged, 856))
            return;
        if (QtMocHelpers::indexOfMethod<void (Options::*)()>(_a, &Options::AnalyzeMountDECChanged, 857))
            return;
        if (QtMocHelpers::indexOfMethod<void (Options::*)()>(_a, &Options::AnalyzeMountHAChanged, 858))
            return;
        if (QtMocHelpers::indexOfMethod<void (Options::*)()>(_a, &Options::AnalyzeAzChanged, 859))
            return;
        if (QtMocHelpers::indexOfMethod<void (Options::*)()>(_a, &Options::AnalyzeAltChanged, 860))
            return;
        if (QtMocHelpers::indexOfMethod<void (Options::*)()>(_a, &Options::AnalyzePierSideChanged, 861))
            return;
        if (QtMocHelpers::indexOfMethod<void (Options::*)()>(_a, &Options::AnalyzeStatsYAxisChanged, 862))
            return;
        if (QtMocHelpers::indexOfMethod<void (Options::*)()>(_a, &Options::LastServerChanged, 863))
            return;
        if (QtMocHelpers::indexOfMethod<void (Options::*)()>(_a, &Options::LastServerPortChanged, 864))
            return;
        if (QtMocHelpers::indexOfMethod<void (Options::*)()>(_a, &Options::LastWebManagerPortChanged, 865))
            return;
        if (QtMocHelpers::indexOfMethod<void (Options::*)()>(_a, &Options::HIPSMemoryCacheChanged, 866))
            return;
        if (QtMocHelpers::indexOfMethod<void (Options::*)()>(_a, &Options::HIPSNetCacheChanged, 867))
            return;
        if (QtMocHelpers::indexOfMethod<void (Options::*)()>(_a, &Options::HIPSSourceChanged, 868))
            return;
        if (QtMocHelpers::indexOfMethod<void (Options::*)()>(_a, &Options::HIPSBiLinearInterpolationChanged, 869))
            return;
        if (QtMocHelpers::indexOfMethod<void (Options::*)()>(_a, &Options::HIPSShowGridChanged, 870))
            return;
        if (QtMocHelpers::indexOfMethod<void (Options::*)()>(_a, &Options::HIPSPanningChanged, 871))
            return;
        if (QtMocHelpers::indexOfMethod<void (Options::*)()>(_a, &Options::ShowHIPSChanged, 872))
            return;
        if (QtMocHelpers::indexOfMethod<void (Options::*)()>(_a, &Options::HIPSUseOfflineSourceChanged, 873))
            return;
        if (QtMocHelpers::indexOfMethod<void (Options::*)()>(_a, &Options::HIPSOfflinePathChanged, 874))
            return;
        if (QtMocHelpers::indexOfMethod<void (Options::*)()>(_a, &Options::TerrainSourceChanged, 875))
            return;
        if (QtMocHelpers::indexOfMethod<void (Options::*)()>(_a, &Options::TerrainSourceCorrectAzChanged, 876))
            return;
        if (QtMocHelpers::indexOfMethod<void (Options::*)()>(_a, &Options::TerrainSourceCorrectAltChanged, 877))
            return;
        if (QtMocHelpers::indexOfMethod<void (Options::*)()>(_a, &Options::TerrainDownsamplingChanged, 878))
            return;
        if (QtMocHelpers::indexOfMethod<void (Options::*)()>(_a, &Options::TerrainPanningChanged, 879))
            return;
        if (QtMocHelpers::indexOfMethod<void (Options::*)()>(_a, &Options::ShowTerrainChanged, 880))
            return;
        if (QtMocHelpers::indexOfMethod<void (Options::*)()>(_a, &Options::TerrainSkipSpeedupChanged, 881))
            return;
        if (QtMocHelpers::indexOfMethod<void (Options::*)()>(_a, &Options::TerrainTransparencySpeedupChanged, 882))
            return;
        if (QtMocHelpers::indexOfMethod<void (Options::*)()>(_a, &Options::TerrainSmoothPixelsChanged, 883))
            return;
        if (QtMocHelpers::indexOfMethod<void (Options::*)()>(_a, &Options::ShowImageOverlaysChanged, 884))
            return;
        if (QtMocHelpers::indexOfMethod<void (Options::*)()>(_a, &Options::ShowImageOverlaysBelowCatalogsChanged, 885))
            return;
        if (QtMocHelpers::indexOfMethod<void (Options::*)()>(_a, &Options::ShowSelectedImageOverlayChanged, 886))
            return;
        if (QtMocHelpers::indexOfMethod<void (Options::*)()>(_a, &Options::ImageOverlayMaxDimensionChanged, 887))
            return;
        if (QtMocHelpers::indexOfMethod<void (Options::*)()>(_a, &Options::ImageOverlayTimeoutChanged, 888))
            return;
        if (QtMocHelpers::indexOfMethod<void (Options::*)()>(_a, &Options::ImageOverlayDefaultScaleChanged, 889))
            return;
        if (QtMocHelpers::indexOfMethod<void (Options::*)()>(_a, &Options::DefaultObservatoryWeatherSourceChanged, 890))
            return;
        if (QtMocHelpers::indexOfMethod<void (Options::*)()>(_a, &Options::warningActionsActiveChanged, 891))
            return;
        if (QtMocHelpers::indexOfMethod<void (Options::*)()>(_a, &Options::alertActionsActiveChanged, 892))
            return;
        if (QtMocHelpers::indexOfMethod<void (Options::*)()>(_a, &Options::weatherWarningCloseDomeChanged, 893))
            return;
        if (QtMocHelpers::indexOfMethod<void (Options::*)()>(_a, &Options::weatherWarningCloseShutterChanged, 894))
            return;
        if (QtMocHelpers::indexOfMethod<void (Options::*)()>(_a, &Options::weatherWarningStopSchedulerChanged, 895))
            return;
        if (QtMocHelpers::indexOfMethod<void (Options::*)()>(_a, &Options::weatherWarningDelayChanged, 896))
            return;
        if (QtMocHelpers::indexOfMethod<void (Options::*)()>(_a, &Options::weatherAlertCloseDomeChanged, 897))
            return;
        if (QtMocHelpers::indexOfMethod<void (Options::*)()>(_a, &Options::weatherAlertCloseShutterChanged, 898))
            return;
        if (QtMocHelpers::indexOfMethod<void (Options::*)()>(_a, &Options::weatherAlertStopSchedulerChanged, 899))
            return;
        if (QtMocHelpers::indexOfMethod<void (Options::*)()>(_a, &Options::weatherAlertDelayChanged, 900))
            return;
        if (QtMocHelpers::indexOfMethod<void (Options::*)()>(_a, &Options::observatoryStatusUseDomeChanged, 901))
            return;
        if (QtMocHelpers::indexOfMethod<void (Options::*)()>(_a, &Options::observatoryStatusUseShutterChanged, 902))
            return;
        if (QtMocHelpers::indexOfMethod<void (Options::*)()>(_a, &Options::observatoryStatusUseWeatherChanged, 903))
            return;
        if (QtMocHelpers::indexOfMethod<void (Options::*)()>(_a, &Options::weatherAutoScaleValuesChanged, 904))
            return;
        if (QtMocHelpers::indexOfMethod<void (Options::*)()>(_a, &Options::ASTAPExecutableChanged, 905))
            return;
        if (QtMocHelpers::indexOfMethod<void (Options::*)()>(_a, &Options::ASTAPDownSampleChanged, 906))
            return;
        if (QtMocHelpers::indexOfMethod<void (Options::*)()>(_a, &Options::ASTAPDownSampleValueChanged, 907))
            return;
        if (QtMocHelpers::indexOfMethod<void (Options::*)()>(_a, &Options::ASTAPSearchRadiusChanged, 908))
            return;
        if (QtMocHelpers::indexOfMethod<void (Options::*)()>(_a, &Options::ASTAPSearchRadiusValueChanged, 909))
            return;
        if (QtMocHelpers::indexOfMethod<void (Options::*)()>(_a, &Options::ASTAPUpdateFITSChanged, 910))
            return;
        if (QtMocHelpers::indexOfMethod<void (Options::*)()>(_a, &Options::ASTAPLargeSearchWindowChanged, 911))
            return;
        if (QtMocHelpers::indexOfMethod<void (Options::*)()>(_a, &Options::MosaicTransparencyAutoChanged, 912))
            return;
        if (QtMocHelpers::indexOfMethod<void (Options::*)()>(_a, &Options::MosaicTransparencyLevelChanged, 913))
            return;
        if (QtMocHelpers::indexOfMethod<void (Options::*)()>(_a, &Options::MCPEnabledChanged, 914))
            return;
        if (QtMocHelpers::indexOfMethod<void (Options::*)()>(_a, &Options::MCPPortChanged, 915))
            return;
        if (QtMocHelpers::indexOfMethod<void (Options::*)()>(_a, &Options::MCPReadOnlyModeChanged, 916))
            return;
        if (QtMocHelpers::indexOfMethod<void (Options::*)()>(_a, &Options::MCPDisabledToolsChanged, 917))
            return;
    }
    if (_c == QMetaObject::RegisterPropertyMetaType) {
        switch (_id) {
        default: *reinterpret_cast<int*>(_a[0]) = -1; break;
        case 812:
        case 48:
            *reinterpret_cast<int*>(_a[0]) = qRegisterMetaType< QList<int> >(); break;
        }
    }
    if (_c == QMetaObject::ReadProperty) {
        void *_v = _a[0];
        switch (_id) {
        case 0: *reinterpret_cast<QPoint*>(_v) = _t->positionTimeBox(); break;
        case 1: *reinterpret_cast<bool*>(_v) = _t->isPositionTimeBoxImmutable(); break;
        case 2: *reinterpret_cast<QPoint*>(_v) = _t->positionFocusBox(); break;
        case 3: *reinterpret_cast<bool*>(_v) = _t->isPositionFocusBoxImmutable(); break;
        case 4: *reinterpret_cast<QPoint*>(_v) = _t->positionGeoBox(); break;
        case 5: *reinterpret_cast<bool*>(_v) = _t->isPositionGeoBoxImmutable(); break;
        case 6: *reinterpret_cast<bool*>(_v) = _t->shadeTimeBox(); break;
        case 7: *reinterpret_cast<bool*>(_v) = _t->isShadeTimeBoxImmutable(); break;
        case 8: *reinterpret_cast<bool*>(_v) = _t->shadeFocusBox(); break;
        case 9: *reinterpret_cast<bool*>(_v) = _t->isShadeFocusBoxImmutable(); break;
        case 10: *reinterpret_cast<bool*>(_v) = _t->shadeGeoBox(); break;
        case 11: *reinterpret_cast<bool*>(_v) = _t->isShadeGeoBoxImmutable(); break;
        case 12: *reinterpret_cast<bool*>(_v) = _t->showInfoBoxes(); break;
        case 13: *reinterpret_cast<bool*>(_v) = _t->isShowInfoBoxesImmutable(); break;
        case 14: *reinterpret_cast<bool*>(_v) = _t->showTimeBox(); break;
        case 15: *reinterpret_cast<bool*>(_v) = _t->isShowTimeBoxImmutable(); break;
        case 16: *reinterpret_cast<bool*>(_v) = _t->showFocusBox(); break;
        case 17: *reinterpret_cast<bool*>(_v) = _t->isShowFocusBoxImmutable(); break;
        case 18: *reinterpret_cast<bool*>(_v) = _t->showGeoBox(); break;
        case 19: *reinterpret_cast<bool*>(_v) = _t->isShowGeoBoxImmutable(); break;
        case 20: *reinterpret_cast<int*>(_v) = _t->stickyTimeBox(); break;
        case 21: *reinterpret_cast<bool*>(_v) = _t->isStickyTimeBoxImmutable(); break;
        case 22: *reinterpret_cast<int*>(_v) = _t->stickyFocusBox(); break;
        case 23: *reinterpret_cast<bool*>(_v) = _t->isStickyFocusBoxImmutable(); break;
        case 24: *reinterpret_cast<int*>(_v) = _t->stickyGeoBox(); break;
        case 25: *reinterpret_cast<bool*>(_v) = _t->isStickyGeoBoxImmutable(); break;
        case 26: *reinterpret_cast<bool*>(_v) = _t->showStatusBar(); break;
        case 27: *reinterpret_cast<bool*>(_v) = _t->isShowStatusBarImmutable(); break;
        case 28: *reinterpret_cast<bool*>(_v) = _t->showAltAzField(); break;
        case 29: *reinterpret_cast<bool*>(_v) = _t->isShowAltAzFieldImmutable(); break;
        case 30: *reinterpret_cast<bool*>(_v) = _t->showRADecField(); break;
        case 31: *reinterpret_cast<bool*>(_v) = _t->isShowRADecFieldImmutable(); break;
        case 32: *reinterpret_cast<bool*>(_v) = _t->showJ2000RADecField(); break;
        case 33: *reinterpret_cast<bool*>(_v) = _t->isShowJ2000RADecFieldImmutable(); break;
        case 34: *reinterpret_cast<bool*>(_v) = _t->showSensorFOV(); break;
        case 35: *reinterpret_cast<bool*>(_v) = _t->isShowSensorFOVImmutable(); break;
        case 36: *reinterpret_cast<uint*>(_v) = _t->windowWidth(); break;
        case 37: *reinterpret_cast<bool*>(_v) = _t->isWindowWidthImmutable(); break;
        case 38: *reinterpret_cast<uint*>(_v) = _t->windowHeight(); break;
        case 39: *reinterpret_cast<bool*>(_v) = _t->isWindowHeightImmutable(); break;
        case 40: *reinterpret_cast<QString*>(_v) = _t->kStarsGeometry(); break;
        case 41: *reinterpret_cast<bool*>(_v) = _t->isKStarsGeometryImmutable(); break;
        case 42: *reinterpret_cast<bool*>(_v) = _t->runStartupWizard(); break;
        case 43: *reinterpret_cast<bool*>(_v) = _t->isRunStartupWizardImmutable(); break;
        case 44: *reinterpret_cast<QString*>(_v) = _t->currentTheme(); break;
        case 45: *reinterpret_cast<bool*>(_v) = _t->isCurrentThemeImmutable(); break;
        case 46: *reinterpret_cast<QStringList*>(_v) = _t->catalogFile(); break;
        case 47: *reinterpret_cast<bool*>(_v) = _t->isCatalogFileImmutable(); break;
        case 48: *reinterpret_cast<QList<int>*>(_v) = _t->showCatalog(); break;
        case 49: *reinterpret_cast<bool*>(_v) = _t->isShowCatalogImmutable(); break;
        case 50: *reinterpret_cast<QStringList*>(_v) = _t->showCatalogNames(); break;
        case 51: *reinterpret_cast<bool*>(_v) = _t->isShowCatalogNamesImmutable(); break;
        case 52: *reinterpret_cast<bool*>(_v) = _t->resolveNamesOnline(); break;
        case 53: *reinterpret_cast<bool*>(_v) = _t->isResolveNamesOnlineImmutable(); break;
        case 54: *reinterpret_cast<uint*>(_v) = _t->dSOCachePercentage(); break;
        case 55: *reinterpret_cast<bool*>(_v) = _t->isDSOCachePercentageImmutable(); break;
        case 56: *reinterpret_cast<uint*>(_v) = _t->dSOMinZoomFactor(); break;
        case 57: *reinterpret_cast<bool*>(_v) = _t->isDSOMinZoomFactorImmutable(); break;
        case 58: *reinterpret_cast<QString*>(_v) = _t->dSOCatalogFilename(); break;
        case 59: *reinterpret_cast<bool*>(_v) = _t->isDSOCatalogFilenameImmutable(); break;
        case 60: *reinterpret_cast<QString*>(_v) = _t->dSODefaultCatalogFilename(); break;
        case 61: *reinterpret_cast<bool*>(_v) = _t->isDSODefaultCatalogFilenameImmutable(); break;
        case 62: *reinterpret_cast<uint*>(_v) = _t->iNDIWindowWidth(); break;
        case 63: *reinterpret_cast<bool*>(_v) = _t->isINDIWindowWidthImmutable(); break;
        case 64: *reinterpret_cast<uint*>(_v) = _t->iNDIWindowHeight(); break;
        case 65: *reinterpret_cast<bool*>(_v) = _t->isINDIWindowHeightImmutable(); break;
        case 66: *reinterpret_cast<QString*>(_v) = _t->iNDIWindowGeometry(); break;
        case 67: *reinterpret_cast<bool*>(_v) = _t->isINDIWindowGeometryImmutable(); break;
        case 68: *reinterpret_cast<bool*>(_v) = _t->useGeographicUpdate(); break;
        case 69: *reinterpret_cast<bool*>(_v) = _t->isUseGeographicUpdateImmutable(); break;
        case 70: *reinterpret_cast<bool*>(_v) = _t->useTimeUpdate(); break;
        case 71: *reinterpret_cast<bool*>(_v) = _t->isUseTimeUpdateImmutable(); break;
        case 72: *reinterpret_cast<bool*>(_v) = _t->independentWindowINDI(); break;
        case 73: *reinterpret_cast<bool*>(_v) = _t->isIndependentWindowINDIImmutable(); break;
        case 74: *reinterpret_cast<bool*>(_v) = _t->showTargetCrosshair(); break;
        case 75: *reinterpret_cast<bool*>(_v) = _t->isShowTargetCrosshairImmutable(); break;
        case 76: *reinterpret_cast<bool*>(_v) = _t->showINDIMessages(); break;
        case 77: *reinterpret_cast<bool*>(_v) = _t->isShowINDIMessagesImmutable(); break;
        case 78: *reinterpret_cast<bool*>(_v) = _t->showINDIwindowInitially(); break;
        case 79: *reinterpret_cast<bool*>(_v) = _t->isShowINDIwindowInitiallyImmutable(); break;
        case 80: *reinterpret_cast<int*>(_v) = _t->maxFocusFrameFiles(); break;
        case 81: *reinterpret_cast<bool*>(_v) = _t->isMaxFocusFrameFilesImmutable(); break;
        case 82: *reinterpret_cast<bool*>(_v) = _t->messageNotificationINDI(); break;
        case 83: *reinterpret_cast<bool*>(_v) = _t->isMessageNotificationINDIImmutable(); break;
        case 84: *reinterpret_cast<QString*>(_v) = _t->timeSource(); break;
        case 85: *reinterpret_cast<bool*>(_v) = _t->isTimeSourceImmutable(); break;
        case 86: *reinterpret_cast<QString*>(_v) = _t->locationSource(); break;
        case 87: *reinterpret_cast<bool*>(_v) = _t->isLocationSourceImmutable(); break;
        case 88: *reinterpret_cast<bool*>(_v) = _t->useExternalSkyMap(); break;
        case 89: *reinterpret_cast<bool*>(_v) = _t->isUseExternalSkyMapImmutable(); break;
        case 90: *reinterpret_cast<QString*>(_v) = _t->fitsDir(); break;
        case 91: *reinterpret_cast<bool*>(_v) = _t->isFitsDirImmutable(); break;
        case 92: *reinterpret_cast<int*>(_v) = _t->serverTransferBufferSize(); break;
        case 93: *reinterpret_cast<bool*>(_v) = _t->isServerTransferBufferSizeImmutable(); break;
        case 94: *reinterpret_cast<int*>(_v) = _t->serverPortStart(); break;
        case 95: *reinterpret_cast<bool*>(_v) = _t->isServerPortStartImmutable(); break;
        case 96: *reinterpret_cast<int*>(_v) = _t->serverPortEnd(); break;
        case 97: *reinterpret_cast<bool*>(_v) = _t->isServerPortEndImmutable(); break;
        case 98: *reinterpret_cast<QString*>(_v) = _t->indiServer(); break;
        case 99: *reinterpret_cast<bool*>(_v) = _t->isIndiServerImmutable(); break;
        case 100: *reinterpret_cast<bool*>(_v) = _t->indiServerIsInternal(); break;
        case 101: *reinterpret_cast<bool*>(_v) = _t->isIndiServerIsInternalImmutable(); break;
        case 102: *reinterpret_cast<QString*>(_v) = _t->indiDriversDir(); break;
        case 103: *reinterpret_cast<bool*>(_v) = _t->isIndiDriversDirImmutable(); break;
        case 104: *reinterpret_cast<bool*>(_v) = _t->indiDriversAreInternal(); break;
        case 105: *reinterpret_cast<bool*>(_v) = _t->isIndiDriversAreInternalImmutable(); break;
        case 106: *reinterpret_cast<uint*>(_v) = _t->streamWindowWidth(); break;
        case 107: *reinterpret_cast<bool*>(_v) = _t->isStreamWindowWidthImmutable(); break;
        case 108: *reinterpret_cast<uint*>(_v) = _t->streamWindowHeight(); break;
        case 109: *reinterpret_cast<bool*>(_v) = _t->isStreamWindowHeightImmutable(); break;
        case 110: *reinterpret_cast<bool*>(_v) = _t->iNDIMountLogging(); break;
        case 111: *reinterpret_cast<bool*>(_v) = _t->isINDIMountLoggingImmutable(); break;
        case 112: *reinterpret_cast<bool*>(_v) = _t->iNDIFocuserLogging(); break;
        case 113: *reinterpret_cast<bool*>(_v) = _t->isINDIFocuserLoggingImmutable(); break;
        case 114: *reinterpret_cast<bool*>(_v) = _t->iNDICCDLogging(); break;
        case 115: *reinterpret_cast<bool*>(_v) = _t->isINDICCDLoggingImmutable(); break;
        case 116: *reinterpret_cast<bool*>(_v) = _t->iNDIFilterWheelLogging(); break;
        case 117: *reinterpret_cast<bool*>(_v) = _t->isINDIFilterWheelLoggingImmutable(); break;
        case 118: *reinterpret_cast<bool*>(_v) = _t->iNDIDomeLogging(); break;
        case 119: *reinterpret_cast<bool*>(_v) = _t->isINDIDomeLoggingImmutable(); break;
        case 120: *reinterpret_cast<bool*>(_v) = _t->iNDIDetectorLogging(); break;
        case 121: *reinterpret_cast<bool*>(_v) = _t->isINDIDetectorLoggingImmutable(); break;
        case 122: *reinterpret_cast<bool*>(_v) = _t->iNDIWeatherLogging(); break;
        case 123: *reinterpret_cast<bool*>(_v) = _t->isINDIWeatherLoggingImmutable(); break;
        case 124: *reinterpret_cast<bool*>(_v) = _t->iNDIAuxiliaryLogging(); break;
        case 125: *reinterpret_cast<bool*>(_v) = _t->isINDIAuxiliaryLoggingImmutable(); break;
        case 126: *reinterpret_cast<bool*>(_v) = _t->iNDIRotatorLogging(); break;
        case 127: *reinterpret_cast<bool*>(_v) = _t->isINDIRotatorLoggingImmutable(); break;
        case 128: *reinterpret_cast<bool*>(_v) = _t->iNDIGPSLogging(); break;
        case 129: *reinterpret_cast<bool*>(_v) = _t->isINDIGPSLoggingImmutable(); break;
        case 130: *reinterpret_cast<bool*>(_v) = _t->iNDIAOLogging(); break;
        case 131: *reinterpret_cast<bool*>(_v) = _t->isINDIAOLoggingImmutable(); break;
        case 132: *reinterpret_cast<QString*>(_v) = _t->cityName(); break;
        case 133: *reinterpret_cast<bool*>(_v) = _t->isCityNameImmutable(); break;
        case 134: *reinterpret_cast<QString*>(_v) = _t->provinceName(); break;
        case 135: *reinterpret_cast<bool*>(_v) = _t->isProvinceNameImmutable(); break;
        case 136: *reinterpret_cast<QString*>(_v) = _t->countryName(); break;
        case 137: *reinterpret_cast<bool*>(_v) = _t->isCountryNameImmutable(); break;
        case 138: *reinterpret_cast<double*>(_v) = _t->longitude(); break;
        case 139: *reinterpret_cast<bool*>(_v) = _t->isLongitudeImmutable(); break;
        case 140: *reinterpret_cast<double*>(_v) = _t->latitude(); break;
        case 141: *reinterpret_cast<bool*>(_v) = _t->isLatitudeImmutable(); break;
        case 142: *reinterpret_cast<double*>(_v) = _t->elevation(); break;
        case 143: *reinterpret_cast<bool*>(_v) = _t->isElevationImmutable(); break;
        case 144: *reinterpret_cast<double*>(_v) = _t->timeZone(); break;
        case 145: *reinterpret_cast<bool*>(_v) = _t->isTimeZoneImmutable(); break;
        case 146: *reinterpret_cast<QString*>(_v) = _t->dST(); break;
        case 147: *reinterpret_cast<bool*>(_v) = _t->isDSTImmutable(); break;
        case 148: *reinterpret_cast<bool*>(_v) = _t->useAnimatedSlewing(); break;
        case 149: *reinterpret_cast<bool*>(_v) = _t->isUseAnimatedSlewingImmutable(); break;
        case 150: *reinterpret_cast<bool*>(_v) = _t->leftClickSelectsObject(); break;
        case 151: *reinterpret_cast<bool*>(_v) = _t->isLeftClickSelectsObjectImmutable(); break;
        case 152: *reinterpret_cast<uint*>(_v) = _t->defaultCursor(); break;
        case 153: *reinterpret_cast<bool*>(_v) = _t->isDefaultCursorImmutable(); break;
        case 154: *reinterpret_cast<QStringList*>(_v) = _t->fOVNames(); break;
        case 155: *reinterpret_cast<bool*>(_v) = _t->isFOVNamesImmutable(); break;
        case 156: *reinterpret_cast<bool*>(_v) = _t->fadePlanetTrails(); break;
        case 157: *reinterpret_cast<bool*>(_v) = _t->isFadePlanetTrailsImmutable(); break;
        case 158: *reinterpret_cast<double*>(_v) = _t->focusRA(); break;
        case 159: *reinterpret_cast<bool*>(_v) = _t->isFocusRAImmutable(); break;
        case 160: *reinterpret_cast<double*>(_v) = _t->focusDec(); break;
        case 161: *reinterpret_cast<bool*>(_v) = _t->isFocusDecImmutable(); break;
        case 162: *reinterpret_cast<QString*>(_v) = _t->focusObject(); break;
        case 163: *reinterpret_cast<bool*>(_v) = _t->isFocusObjectImmutable(); break;
        case 164: *reinterpret_cast<bool*>(_v) = _t->isTracking(); break;
        case 165: *reinterpret_cast<bool*>(_v) = _t->isIsTrackingImmutable(); break;
        case 166: *reinterpret_cast<bool*>(_v) = _t->hideOnSlew(); break;
        case 167: *reinterpret_cast<bool*>(_v) = _t->isHideOnSlewImmutable(); break;
        case 168: *reinterpret_cast<bool*>(_v) = _t->hideCBounds(); break;
        case 169: *reinterpret_cast<bool*>(_v) = _t->isHideCBoundsImmutable(); break;
        case 170: *reinterpret_cast<bool*>(_v) = _t->hideCLines(); break;
        case 171: *reinterpret_cast<bool*>(_v) = _t->isHideCLinesImmutable(); break;
        case 172: *reinterpret_cast<QString*>(_v) = _t->skyCulture(); break;
        case 173: *reinterpret_cast<bool*>(_v) = _t->isSkyCultureImmutable(); break;
        case 174: *reinterpret_cast<bool*>(_v) = _t->hideCNames(); break;
        case 175: *reinterpret_cast<bool*>(_v) = _t->isHideCNamesImmutable(); break;
        case 176: *reinterpret_cast<bool*>(_v) = _t->hideGrids(); break;
        case 177: *reinterpret_cast<bool*>(_v) = _t->isHideGridsImmutable(); break;
        case 178: *reinterpret_cast<bool*>(_v) = _t->hideMilkyWay(); break;
        case 179: *reinterpret_cast<bool*>(_v) = _t->isHideMilkyWayImmutable(); break;
        case 180: *reinterpret_cast<bool*>(_v) = _t->hideOther(); break;
        case 181: *reinterpret_cast<bool*>(_v) = _t->isHideOtherImmutable(); break;
        case 182: *reinterpret_cast<bool*>(_v) = _t->hidePlanets(); break;
        case 183: *reinterpret_cast<bool*>(_v) = _t->isHidePlanetsImmutable(); break;
        case 184: *reinterpret_cast<bool*>(_v) = _t->hideStars(); break;
        case 185: *reinterpret_cast<bool*>(_v) = _t->isHideStarsImmutable(); break;
        case 186: *reinterpret_cast<bool*>(_v) = _t->hideLabels(); break;
        case 187: *reinterpret_cast<bool*>(_v) = _t->isHideLabelsImmutable(); break;
        case 188: *reinterpret_cast<bool*>(_v) = _t->showAsteroids(); break;
        case 189: *reinterpret_cast<bool*>(_v) = _t->isShowAsteroidsImmutable(); break;
        case 190: *reinterpret_cast<bool*>(_v) = _t->showAsteroidNames(); break;
        case 191: *reinterpret_cast<bool*>(_v) = _t->isShowAsteroidNamesImmutable(); break;
        case 192: *reinterpret_cast<bool*>(_v) = _t->orbitalElementsAutoUpdate(); break;
        case 193: *reinterpret_cast<bool*>(_v) = _t->isOrbitalElementsAutoUpdateImmutable(); break;
        case 194: *reinterpret_cast<bool*>(_v) = _t->showComets(); break;
        case 195: *reinterpret_cast<bool*>(_v) = _t->isShowCometsImmutable(); break;
        case 196: *reinterpret_cast<bool*>(_v) = _t->showCometComas(); break;
        case 197: *reinterpret_cast<bool*>(_v) = _t->isShowCometComasImmutable(); break;
        case 198: *reinterpret_cast<bool*>(_v) = _t->showCometNames(); break;
        case 199: *reinterpret_cast<bool*>(_v) = _t->isShowCometNamesImmutable(); break;
        case 200: *reinterpret_cast<bool*>(_v) = _t->showSupernovae(); break;
        case 201: *reinterpret_cast<bool*>(_v) = _t->isShowSupernovaeImmutable(); break;
        case 202: *reinterpret_cast<bool*>(_v) = _t->showSupernovaNames(); break;
        case 203: *reinterpret_cast<bool*>(_v) = _t->isShowSupernovaNamesImmutable(); break;
        case 204: *reinterpret_cast<double*>(_v) = _t->magnitudeLimitShowSupernovae(); break;
        case 205: *reinterpret_cast<bool*>(_v) = _t->isMagnitudeLimitShowSupernovaeImmutable(); break;
        case 206: *reinterpret_cast<double*>(_v) = _t->supernovaDetectionAge(); break;
        case 207: *reinterpret_cast<bool*>(_v) = _t->isSupernovaDetectionAgeImmutable(); break;
        case 208: *reinterpret_cast<QString*>(_v) = _t->supernovaDownloadUrl(); break;
        case 209: *reinterpret_cast<bool*>(_v) = _t->isSupernovaDownloadUrlImmutable(); break;
        case 210: *reinterpret_cast<bool*>(_v) = _t->limitSupernovaeByZoom(); break;
        case 211: *reinterpret_cast<bool*>(_v) = _t->isLimitSupernovaeByZoomImmutable(); break;
        case 212: *reinterpret_cast<bool*>(_v) = _t->supernovaeHostOnly(); break;
        case 213: *reinterpret_cast<bool*>(_v) = _t->isSupernovaeHostOnlyImmutable(); break;
        case 214: *reinterpret_cast<bool*>(_v) = _t->supernovaeClassifiedOnly(); break;
        case 215: *reinterpret_cast<bool*>(_v) = _t->isSupernovaeClassifiedOnlyImmutable(); break;
        case 216: *reinterpret_cast<bool*>(_v) = _t->showSupernovaAlerts(); break;
        case 217: *reinterpret_cast<bool*>(_v) = _t->isShowSupernovaAlertsImmutable(); break;
        case 218: *reinterpret_cast<double*>(_v) = _t->magnitudeLimitAlertSupernovae(); break;
        case 219: *reinterpret_cast<bool*>(_v) = _t->isMagnitudeLimitAlertSupernovaeImmutable(); break;
        case 220: *reinterpret_cast<bool*>(_v) = _t->showCBounds(); break;
        case 221: *reinterpret_cast<bool*>(_v) = _t->isShowCBoundsImmutable(); break;
        case 222: *reinterpret_cast<bool*>(_v) = _t->showHighlightedCBound(); break;
        case 223: *reinterpret_cast<bool*>(_v) = _t->isShowHighlightedCBoundImmutable(); break;
        case 224: *reinterpret_cast<bool*>(_v) = _t->showCLines(); break;
        case 225: *reinterpret_cast<bool*>(_v) = _t->isShowCLinesImmutable(); break;
        case 226: *reinterpret_cast<bool*>(_v) = _t->showConstellationArt(); break;
        case 227: *reinterpret_cast<bool*>(_v) = _t->isShowConstellationArtImmutable(); break;
        case 228: *reinterpret_cast<bool*>(_v) = _t->showCNames(); break;
        case 229: *reinterpret_cast<bool*>(_v) = _t->isShowCNamesImmutable(); break;
        case 230: *reinterpret_cast<bool*>(_v) = _t->showDeepSky(); break;
        case 231: *reinterpret_cast<bool*>(_v) = _t->isShowDeepSkyImmutable(); break;
        case 232: *reinterpret_cast<bool*>(_v) = _t->showEcliptic(); break;
        case 233: *reinterpret_cast<bool*>(_v) = _t->isShowEclipticImmutable(); break;
        case 234: *reinterpret_cast<bool*>(_v) = _t->showEquator(); break;
        case 235: *reinterpret_cast<bool*>(_v) = _t->isShowEquatorImmutable(); break;
        case 236: *reinterpret_cast<bool*>(_v) = _t->autoSelectGrid(); break;
        case 237: *reinterpret_cast<bool*>(_v) = _t->isAutoSelectGridImmutable(); break;
        case 238: *reinterpret_cast<bool*>(_v) = _t->showEquatorialGrid(); break;
        case 239: *reinterpret_cast<bool*>(_v) = _t->isShowEquatorialGridImmutable(); break;
        case 240: *reinterpret_cast<bool*>(_v) = _t->showHorizontalGrid(); break;
        case 241: *reinterpret_cast<bool*>(_v) = _t->isShowHorizontalGridImmutable(); break;
        case 242: *reinterpret_cast<bool*>(_v) = _t->showLocalMeridian(); break;
        case 243: *reinterpret_cast<bool*>(_v) = _t->isShowLocalMeridianImmutable(); break;
        case 244: *reinterpret_cast<bool*>(_v) = _t->showGround(); break;
        case 245: *reinterpret_cast<bool*>(_v) = _t->isShowGroundImmutable(); break;
        case 246: *reinterpret_cast<bool*>(_v) = _t->showHorizon(); break;
        case 247: *reinterpret_cast<bool*>(_v) = _t->isShowHorizonImmutable(); break;
        case 248: *reinterpret_cast<bool*>(_v) = _t->showFlags(); break;
        case 249: *reinterpret_cast<bool*>(_v) = _t->isShowFlagsImmutable(); break;
        case 250: *reinterpret_cast<bool*>(_v) = _t->simulateDaytime(); break;
        case 251: *reinterpret_cast<bool*>(_v) = _t->isSimulateDaytimeImmutable(); break;
        case 252: *reinterpret_cast<bool*>(_v) = _t->showOther(); break;
        case 253: *reinterpret_cast<bool*>(_v) = _t->isShowOtherImmutable(); break;
        case 254: *reinterpret_cast<bool*>(_v) = _t->showMilkyWay(); break;
        case 255: *reinterpret_cast<bool*>(_v) = _t->isShowMilkyWayImmutable(); break;
        case 256: *reinterpret_cast<bool*>(_v) = _t->fillMilkyWay(); break;
        case 257: *reinterpret_cast<bool*>(_v) = _t->isFillMilkyWayImmutable(); break;
        case 258: *reinterpret_cast<bool*>(_v) = _t->showSolarSystem(); break;
        case 259: *reinterpret_cast<bool*>(_v) = _t->isShowSolarSystemImmutable(); break;
        case 260: *reinterpret_cast<bool*>(_v) = _t->showPlanetImages(); break;
        case 261: *reinterpret_cast<bool*>(_v) = _t->isShowPlanetImagesImmutable(); break;
        case 262: *reinterpret_cast<bool*>(_v) = _t->showPlanetNames(); break;
        case 263: *reinterpret_cast<bool*>(_v) = _t->isShowPlanetNamesImmutable(); break;
        case 264: *reinterpret_cast<bool*>(_v) = _t->showSun(); break;
        case 265: *reinterpret_cast<bool*>(_v) = _t->isShowSunImmutable(); break;
        case 266: *reinterpret_cast<double*>(_v) = _t->sunScale(); break;
        case 267: *reinterpret_cast<bool*>(_v) = _t->isSunScaleImmutable(); break;
        case 268: *reinterpret_cast<bool*>(_v) = _t->showMoon(); break;
        case 269: *reinterpret_cast<bool*>(_v) = _t->isShowMoonImmutable(); break;
        case 270: *reinterpret_cast<double*>(_v) = _t->moonScale(); break;
        case 271: *reinterpret_cast<bool*>(_v) = _t->isMoonScaleImmutable(); break;
        case 272: *reinterpret_cast<bool*>(_v) = _t->showMercury(); break;
        case 273: *reinterpret_cast<bool*>(_v) = _t->isShowMercuryImmutable(); break;
        case 274: *reinterpret_cast<bool*>(_v) = _t->showVenus(); break;
        case 275: *reinterpret_cast<bool*>(_v) = _t->isShowVenusImmutable(); break;
        case 276: *reinterpret_cast<bool*>(_v) = _t->showMars(); break;
        case 277: *reinterpret_cast<bool*>(_v) = _t->isShowMarsImmutable(); break;
        case 278: *reinterpret_cast<bool*>(_v) = _t->showJupiter(); break;
        case 279: *reinterpret_cast<bool*>(_v) = _t->isShowJupiterImmutable(); break;
        case 280: *reinterpret_cast<bool*>(_v) = _t->showSaturn(); break;
        case 281: *reinterpret_cast<bool*>(_v) = _t->isShowSaturnImmutable(); break;
        case 282: *reinterpret_cast<bool*>(_v) = _t->showUranus(); break;
        case 283: *reinterpret_cast<bool*>(_v) = _t->isShowUranusImmutable(); break;
        case 284: *reinterpret_cast<bool*>(_v) = _t->showNeptune(); break;
        case 285: *reinterpret_cast<bool*>(_v) = _t->isShowNeptuneImmutable(); break;
        case 286: *reinterpret_cast<bool*>(_v) = _t->showPluto(); break;
        case 287: *reinterpret_cast<bool*>(_v) = _t->isShowPlutoImmutable(); break;
        case 288: *reinterpret_cast<bool*>(_v) = _t->showStars(); break;
        case 289: *reinterpret_cast<bool*>(_v) = _t->isShowStarsImmutable(); break;
        case 290: *reinterpret_cast<bool*>(_v) = _t->showStarMagnitudes(); break;
        case 291: *reinterpret_cast<bool*>(_v) = _t->isShowStarMagnitudesImmutable(); break;
        case 292: *reinterpret_cast<bool*>(_v) = _t->showStarsOverHIPS(); break;
        case 293: *reinterpret_cast<bool*>(_v) = _t->isShowStarsOverHIPSImmutable(); break;
        case 294: *reinterpret_cast<bool*>(_v) = _t->showStarNames(); break;
        case 295: *reinterpret_cast<bool*>(_v) = _t->isShowStarNamesImmutable(); break;
        case 296: *reinterpret_cast<bool*>(_v) = _t->showDeepSkyMagnitudes(); break;
        case 297: *reinterpret_cast<bool*>(_v) = _t->isShowDeepSkyMagnitudesImmutable(); break;
        case 298: *reinterpret_cast<bool*>(_v) = _t->showDeepSkyNames(); break;
        case 299: *reinterpret_cast<bool*>(_v) = _t->isShowDeepSkyNamesImmutable(); break;
        case 300: *reinterpret_cast<bool*>(_v) = _t->showMosaicPanel(); break;
        case 301: *reinterpret_cast<bool*>(_v) = _t->isShowMosaicPanelImmutable(); break;
        case 302: *reinterpret_cast<double*>(_v) = _t->slewTimeScale(); break;
        case 303: *reinterpret_cast<bool*>(_v) = _t->isSlewTimeScaleImmutable(); break;
        case 304: *reinterpret_cast<uint*>(_v) = _t->boxBGMode(); break;
        case 305: *reinterpret_cast<bool*>(_v) = _t->isBoxBGModeImmutable(); break;
        case 306: *reinterpret_cast<uint*>(_v) = _t->projection(); break;
        case 307: *reinterpret_cast<bool*>(_v) = _t->isProjectionImmutable(); break;
        case 308: *reinterpret_cast<bool*>(_v) = _t->useAbbrevConstellNames(); break;
        case 309: *reinterpret_cast<bool*>(_v) = _t->isUseAbbrevConstellNamesImmutable(); break;
        case 310: *reinterpret_cast<bool*>(_v) = _t->useLatinConstellNames(); break;
        case 311: *reinterpret_cast<bool*>(_v) = _t->isUseLatinConstellNamesImmutable(); break;
        case 312: *reinterpret_cast<bool*>(_v) = _t->useLocalConstellNames(); break;
        case 313: *reinterpret_cast<bool*>(_v) = _t->isUseLocalConstellNamesImmutable(); break;
        case 314: *reinterpret_cast<bool*>(_v) = _t->useAltAz(); break;
        case 315: *reinterpret_cast<bool*>(_v) = _t->isUseAltAzImmutable(); break;
        case 316: *reinterpret_cast<bool*>(_v) = _t->useAutoLabel(); break;
        case 317: *reinterpret_cast<bool*>(_v) = _t->isUseAutoLabelImmutable(); break;
        case 318: *reinterpret_cast<bool*>(_v) = _t->useAutoTrail(); break;
        case 319: *reinterpret_cast<bool*>(_v) = _t->isUseAutoTrailImmutable(); break;
        case 320: *reinterpret_cast<bool*>(_v) = _t->useHoverLabel(); break;
        case 321: *reinterpret_cast<bool*>(_v) = _t->isUseHoverLabelImmutable(); break;
        case 322: *reinterpret_cast<bool*>(_v) = _t->useRefraction(); break;
        case 323: *reinterpret_cast<bool*>(_v) = _t->isUseRefractionImmutable(); break;
        case 324: *reinterpret_cast<bool*>(_v) = _t->useRelativistic(); break;
        case 325: *reinterpret_cast<bool*>(_v) = _t->isUseRelativisticImmutable(); break;
        case 326: *reinterpret_cast<bool*>(_v) = _t->useAntialias(); break;
        case 327: *reinterpret_cast<bool*>(_v) = _t->isUseAntialiasImmutable(); break;
        case 328: *reinterpret_cast<double*>(_v) = _t->zoomFactor(); break;
        case 329: *reinterpret_cast<bool*>(_v) = _t->isZoomFactorImmutable(); break;
        case 330: *reinterpret_cast<double*>(_v) = _t->skyRotation(); break;
        case 331: *reinterpret_cast<bool*>(_v) = _t->isSkyRotationImmutable(); break;
        case 332: *reinterpret_cast<bool*>(_v) = _t->mirrorSkyMap(); break;
        case 333: *reinterpret_cast<bool*>(_v) = _t->isMirrorSkyMapImmutable(); break;
        case 334: *reinterpret_cast<int*>(_v) = _t->erectObserverCorrection(); break;
        case 335: *reinterpret_cast<bool*>(_v) = _t->isErectObserverCorrectionImmutable(); break;
        case 336: *reinterpret_cast<double*>(_v) = _t->zoomScrollFactor(); break;
        case 337: *reinterpret_cast<bool*>(_v) = _t->isZoomScrollFactorImmutable(); break;
        case 338: *reinterpret_cast<double*>(_v) = _t->magLimitAsteroid(); break;
        case 339: *reinterpret_cast<bool*>(_v) = _t->isMagLimitAsteroidImmutable(); break;
        case 340: *reinterpret_cast<double*>(_v) = _t->magLimitAsteroidDownload(); break;
        case 341: *reinterpret_cast<bool*>(_v) = _t->isMagLimitAsteroidDownloadImmutable(); break;
        case 342: *reinterpret_cast<double*>(_v) = _t->asteroidLabelDensity(); break;
        case 343: *reinterpret_cast<bool*>(_v) = _t->isAsteroidLabelDensityImmutable(); break;
        case 344: *reinterpret_cast<double*>(_v) = _t->magLimitDrawDeepSky(); break;
        case 345: *reinterpret_cast<bool*>(_v) = _t->isMagLimitDrawDeepSkyImmutable(); break;
        case 346: *reinterpret_cast<double*>(_v) = _t->magLimitDrawDeepSkyZoomOut(); break;
        case 347: *reinterpret_cast<bool*>(_v) = _t->isMagLimitDrawDeepSkyZoomOutImmutable(); break;
        case 348: *reinterpret_cast<bool*>(_v) = _t->showUnknownMagObjects(); break;
        case 349: *reinterpret_cast<bool*>(_v) = _t->isShowUnknownMagObjectsImmutable(); break;
        case 350: *reinterpret_cast<bool*>(_v) = _t->showInlineImages(); break;
        case 351: *reinterpret_cast<bool*>(_v) = _t->isShowInlineImagesImmutable(); break;
        case 352: *reinterpret_cast<int*>(_v) = _t->starDensity(); break;
        case 353: *reinterpret_cast<bool*>(_v) = _t->isStarDensityImmutable(); break;
        case 354: *reinterpret_cast<double*>(_v) = _t->magLimitHideStar(); break;
        case 355: *reinterpret_cast<bool*>(_v) = _t->isMagLimitHideStarImmutable(); break;
        case 356: *reinterpret_cast<double*>(_v) = _t->starLabelDensity(); break;
        case 357: *reinterpret_cast<bool*>(_v) = _t->isStarLabelDensityImmutable(); break;
        case 358: *reinterpret_cast<double*>(_v) = _t->deepSkyLabelDensity(); break;
        case 359: *reinterpret_cast<bool*>(_v) = _t->isDeepSkyLabelDensityImmutable(); break;
        case 360: *reinterpret_cast<bool*>(_v) = _t->deepSkyLongLabels(); break;
        case 361: *reinterpret_cast<bool*>(_v) = _t->isDeepSkyLongLabelsImmutable(); break;
        case 362: *reinterpret_cast<int*>(_v) = _t->labelFontScaling(); break;
        case 363: *reinterpret_cast<bool*>(_v) = _t->isLabelFontScalingImmutable(); break;
        case 364: *reinterpret_cast<double*>(_v) = _t->maxRadCometName(); break;
        case 365: *reinterpret_cast<bool*>(_v) = _t->isMaxRadCometNameImmutable(); break;
        case 366: *reinterpret_cast<bool*>(_v) = _t->useGL(); break;
        case 367: *reinterpret_cast<bool*>(_v) = _t->isUseGLImmutable(); break;
        case 368: *reinterpret_cast<bool*>(_v) = _t->runClock(); break;
        case 369: *reinterpret_cast<bool*>(_v) = _t->isRunClockImmutable(); break;
        case 370: *reinterpret_cast<bool*>(_v) = _t->imagingPlannerAcceptOpenCluster(); break;
        case 371: *reinterpret_cast<bool*>(_v) = _t->isImagingPlannerAcceptOpenClusterImmutable(); break;
        case 372: *reinterpret_cast<bool*>(_v) = _t->imagingPlannerAcceptNebula(); break;
        case 373: *reinterpret_cast<bool*>(_v) = _t->isImagingPlannerAcceptNebulaImmutable(); break;
        case 374: *reinterpret_cast<bool*>(_v) = _t->imagingPlannerAcceptGlobularCluster(); break;
        case 375: *reinterpret_cast<bool*>(_v) = _t->isImagingPlannerAcceptGlobularClusterImmutable(); break;
        case 376: *reinterpret_cast<bool*>(_v) = _t->imagingPlannerAcceptPlanetary(); break;
        case 377: *reinterpret_cast<bool*>(_v) = _t->isImagingPlannerAcceptPlanetaryImmutable(); break;
        case 378: *reinterpret_cast<bool*>(_v) = _t->imagingPlannerAcceptSupernovaRemnant(); break;
        case 379: *reinterpret_cast<bool*>(_v) = _t->isImagingPlannerAcceptSupernovaRemnantImmutable(); break;
        case 380: *reinterpret_cast<bool*>(_v) = _t->imagingPlannerAcceptGalaxy(); break;
        case 381: *reinterpret_cast<bool*>(_v) = _t->isImagingPlannerAcceptGalaxyImmutable(); break;
        case 382: *reinterpret_cast<bool*>(_v) = _t->imagingPlannerAcceptGalaxyCluster(); break;
        case 383: *reinterpret_cast<bool*>(_v) = _t->isImagingPlannerAcceptGalaxyClusterImmutable(); break;
        case 384: *reinterpret_cast<bool*>(_v) = _t->imagingPlannerAcceptDarkNebula(); break;
        case 385: *reinterpret_cast<bool*>(_v) = _t->isImagingPlannerAcceptDarkNebulaImmutable(); break;
        case 386: *reinterpret_cast<bool*>(_v) = _t->imagingPlannerAcceptOther(); break;
        case 387: *reinterpret_cast<bool*>(_v) = _t->isImagingPlannerAcceptOtherImmutable(); break;
        case 388: *reinterpret_cast<bool*>(_v) = _t->astrobinAward(); break;
        case 389: *reinterpret_cast<bool*>(_v) = _t->isAstrobinAwardImmutable(); break;
        case 390: *reinterpret_cast<double*>(_v) = _t->astrobinMinRadius(); break;
        case 391: *reinterpret_cast<bool*>(_v) = _t->isAstrobinMinRadiusImmutable(); break;
        case 392: *reinterpret_cast<double*>(_v) = _t->astrobinMaxRadius(); break;
        case 393: *reinterpret_cast<bool*>(_v) = _t->isAstrobinMaxRadiusImmutable(); break;
        case 394: *reinterpret_cast<bool*>(_v) = _t->imagingPlannerUseArtificialHorizon(); break;
        case 395: *reinterpret_cast<bool*>(_v) = _t->isImagingPlannerUseArtificialHorizonImmutable(); break;
        case 396: *reinterpret_cast<double*>(_v) = _t->imagingPlannerMinHours(); break;
        case 397: *reinterpret_cast<bool*>(_v) = _t->isImagingPlannerMinHoursImmutable(); break;
        case 398: *reinterpret_cast<double*>(_v) = _t->imagingPlannerMinAltitude(); break;
        case 399: *reinterpret_cast<bool*>(_v) = _t->isImagingPlannerMinAltitudeImmutable(); break;
        case 400: *reinterpret_cast<double*>(_v) = _t->imagingPlannerMinMoonSeparation(); break;
        case 401: *reinterpret_cast<bool*>(_v) = _t->isImagingPlannerMinMoonSeparationImmutable(); break;
        case 402: *reinterpret_cast<double*>(_v) = _t->imagingPlannerMaxMoonAltitude(); break;
        case 403: *reinterpret_cast<bool*>(_v) = _t->isImagingPlannerMaxMoonAltitudeImmutable(); break;
        case 404: *reinterpret_cast<bool*>(_v) = _t->imagingPlannerShowPicked(); break;
        case 405: *reinterpret_cast<bool*>(_v) = _t->isImagingPlannerShowPickedImmutable(); break;
        case 406: *reinterpret_cast<bool*>(_v) = _t->imagingPlannerShowNotPicked(); break;
        case 407: *reinterpret_cast<bool*>(_v) = _t->isImagingPlannerShowNotPickedImmutable(); break;
        case 408: *reinterpret_cast<bool*>(_v) = _t->imagingPlannerDontCarePicked(); break;
        case 409: *reinterpret_cast<bool*>(_v) = _t->isImagingPlannerDontCarePickedImmutable(); break;
        case 410: *reinterpret_cast<bool*>(_v) = _t->imagingPlannerShowKeyword(); break;
        case 411: *reinterpret_cast<bool*>(_v) = _t->isImagingPlannerShowKeywordImmutable(); break;
        case 412: *reinterpret_cast<bool*>(_v) = _t->imagingPlannerShowNotKeyword(); break;
        case 413: *reinterpret_cast<bool*>(_v) = _t->isImagingPlannerShowNotKeywordImmutable(); break;
        case 414: *reinterpret_cast<bool*>(_v) = _t->imagingPlannerDontCareKeyword(); break;
        case 415: *reinterpret_cast<bool*>(_v) = _t->isImagingPlannerDontCareKeywordImmutable(); break;
        case 416: *reinterpret_cast<QString*>(_v) = _t->imagingPlannerKeyword(); break;
        case 417: *reinterpret_cast<bool*>(_v) = _t->isImagingPlannerKeywordImmutable(); break;
        case 418: *reinterpret_cast<bool*>(_v) = _t->imagingPlannerShowImaged(); break;
        case 419: *reinterpret_cast<bool*>(_v) = _t->isImagingPlannerShowImagedImmutable(); break;
        case 420: *reinterpret_cast<bool*>(_v) = _t->imagingPlannerShowNotImaged(); break;
        case 421: *reinterpret_cast<bool*>(_v) = _t->isImagingPlannerShowNotImagedImmutable(); break;
        case 422: *reinterpret_cast<bool*>(_v) = _t->imagingPlannerDontCareImaged(); break;
        case 423: *reinterpret_cast<bool*>(_v) = _t->isImagingPlannerDontCareImagedImmutable(); break;
        case 424: *reinterpret_cast<bool*>(_v) = _t->imagingPlannerShowAdded(); break;
        case 425: *reinterpret_cast<bool*>(_v) = _t->isImagingPlannerShowAddedImmutable(); break;
        case 426: *reinterpret_cast<bool*>(_v) = _t->imagingPlannerShowNotAdded(); break;
        case 427: *reinterpret_cast<bool*>(_v) = _t->isImagingPlannerShowNotAddedImmutable(); break;
        case 428: *reinterpret_cast<bool*>(_v) = _t->imagingPlannerDontCareAdded(); break;
        case 429: *reinterpret_cast<bool*>(_v) = _t->isImagingPlannerDontCareAddedImmutable(); break;
        case 430: *reinterpret_cast<bool*>(_v) = _t->imagingPlannerShowIgnored(); break;
        case 431: *reinterpret_cast<bool*>(_v) = _t->isImagingPlannerShowIgnoredImmutable(); break;
        case 432: *reinterpret_cast<bool*>(_v) = _t->imagingPlannerShowNotIgnored(); break;
        case 433: *reinterpret_cast<bool*>(_v) = _t->isImagingPlannerShowNotIgnoredImmutable(); break;
        case 434: *reinterpret_cast<bool*>(_v) = _t->imagingPlannerDontCareIgnored(); break;
        case 435: *reinterpret_cast<bool*>(_v) = _t->isImagingPlannerDontCareIgnoredImmutable(); break;
        case 436: *reinterpret_cast<bool*>(_v) = _t->imagingPlannerHideAstrobinDetails(); break;
        case 437: *reinterpret_cast<bool*>(_v) = _t->isImagingPlannerHideAstrobinDetailsImmutable(); break;
        case 438: *reinterpret_cast<bool*>(_v) = _t->imagingPlannerHideFilters(); break;
        case 439: *reinterpret_cast<bool*>(_v) = _t->isImagingPlannerHideFiltersImmutable(); break;
        case 440: *reinterpret_cast<bool*>(_v) = _t->imagingPlannerHideImage(); break;
        case 441: *reinterpret_cast<bool*>(_v) = _t->isImagingPlannerHideImageImmutable(); break;
        case 442: *reinterpret_cast<bool*>(_v) = _t->imagingPlannerHideAltitudeGraph(); break;
        case 443: *reinterpret_cast<bool*>(_v) = _t->isImagingPlannerHideAltitudeGraphImmutable(); break;
        case 444: *reinterpret_cast<QString*>(_v) = _t->imagingPlannerCatalogPath(); break;
        case 445: *reinterpret_cast<bool*>(_v) = _t->isImagingPlannerCatalogPathImmutable(); break;
        case 446: *reinterpret_cast<bool*>(_v) = _t->imagingPlannerCenterOnSkyMap(); break;
        case 447: *reinterpret_cast<bool*>(_v) = _t->isImagingPlannerCenterOnSkyMapImmutable(); break;
        case 448: *reinterpret_cast<bool*>(_v) = _t->imagingPlannerIndependentWindow(); break;
        case 449: *reinterpret_cast<bool*>(_v) = _t->isImagingPlannerIndependentWindowImmutable(); break;
        case 450: *reinterpret_cast<bool*>(_v) = _t->imagingPlannerStartSolvingImmediately(); break;
        case 451: *reinterpret_cast<bool*>(_v) = _t->isImagingPlannerStartSolvingImmediatelyImmutable(); break;
        case 452: *reinterpret_cast<bool*>(_v) = _t->obsListSymbol(); break;
        case 453: *reinterpret_cast<bool*>(_v) = _t->isObsListSymbolImmutable(); break;
        case 454: *reinterpret_cast<bool*>(_v) = _t->obsListText(); break;
        case 455: *reinterpret_cast<bool*>(_v) = _t->isObsListTextImmutable(); break;
        case 456: *reinterpret_cast<bool*>(_v) = _t->obsListPreferDSS(); break;
        case 457: *reinterpret_cast<bool*>(_v) = _t->isObsListPreferDSSImmutable(); break;
        case 458: *reinterpret_cast<bool*>(_v) = _t->obsListPreferSDSS(); break;
        case 459: *reinterpret_cast<bool*>(_v) = _t->isObsListPreferSDSSImmutable(); break;
        case 460: *reinterpret_cast<bool*>(_v) = _t->obsListDemoteHole(); break;
        case 461: *reinterpret_cast<bool*>(_v) = _t->isObsListDemoteHoleImmutable(); break;
        case 462: *reinterpret_cast<double*>(_v) = _t->obsListHoleSize(); break;
        case 463: *reinterpret_cast<bool*>(_v) = _t->isObsListHoleSizeImmutable(); break;
        case 464: *reinterpret_cast<double*>(_v) = _t->obsListCoverage(); break;
        case 465: *reinterpret_cast<bool*>(_v) = _t->isObsListCoverageImmutable(); break;
        case 466: *reinterpret_cast<QString*>(_v) = _t->colorSchemeFile(); break;
        case 467: *reinterpret_cast<bool*>(_v) = _t->isColorSchemeFileImmutable(); break;
        case 468: *reinterpret_cast<uint*>(_v) = _t->starColorMode(); break;
        case 469: *reinterpret_cast<bool*>(_v) = _t->isStarColorModeImmutable(); break;
        case 470: *reinterpret_cast<uint*>(_v) = _t->starColorIntensity(); break;
        case 471: *reinterpret_cast<bool*>(_v) = _t->isStarColorIntensityImmutable(); break;
        case 472: *reinterpret_cast<bool*>(_v) = _t->domeSlitInverted(); break;
        case 473: *reinterpret_cast<bool*>(_v) = _t->isDomeSlitInvertedImmutable(); break;
        case 474: *reinterpret_cast<QString*>(_v) = _t->angularRulerColor(); break;
        case 475: *reinterpret_cast<bool*>(_v) = _t->isAngularRulerColorImmutable(); break;
        case 476: *reinterpret_cast<QString*>(_v) = _t->boxBGColor(); break;
        case 477: *reinterpret_cast<bool*>(_v) = _t->isBoxBGColorImmutable(); break;
        case 478: *reinterpret_cast<QString*>(_v) = _t->boxGrabColor(); break;
        case 479: *reinterpret_cast<bool*>(_v) = _t->isBoxGrabColorImmutable(); break;
        case 480: *reinterpret_cast<QString*>(_v) = _t->boxTextColor(); break;
        case 481: *reinterpret_cast<bool*>(_v) = _t->isBoxTextColorImmutable(); break;
        case 482: *reinterpret_cast<QString*>(_v) = _t->cBoundColor(); break;
        case 483: *reinterpret_cast<bool*>(_v) = _t->isCBoundColorImmutable(); break;
        case 484: *reinterpret_cast<QString*>(_v) = _t->cBoundHighColor(); break;
        case 485: *reinterpret_cast<bool*>(_v) = _t->isCBoundHighColorImmutable(); break;
        case 486: *reinterpret_cast<QString*>(_v) = _t->cLineColor(); break;
        case 487: *reinterpret_cast<bool*>(_v) = _t->isCLineColorImmutable(); break;
        case 488: *reinterpret_cast<QString*>(_v) = _t->cNameColor(); break;
        case 489: *reinterpret_cast<bool*>(_v) = _t->isCNameColorImmutable(); break;
        case 490: *reinterpret_cast<QString*>(_v) = _t->compassColor(); break;
        case 491: *reinterpret_cast<bool*>(_v) = _t->isCompassColorImmutable(); break;
        case 492: *reinterpret_cast<QString*>(_v) = _t->eclipticColor(); break;
        case 493: *reinterpret_cast<bool*>(_v) = _t->isEclipticColorImmutable(); break;
        case 494: *reinterpret_cast<QString*>(_v) = _t->equatorColor(); break;
        case 495: *reinterpret_cast<bool*>(_v) = _t->isEquatorColorImmutable(); break;
        case 496: *reinterpret_cast<QString*>(_v) = _t->equatorialGridColor(); break;
        case 497: *reinterpret_cast<bool*>(_v) = _t->isEquatorialGridColorImmutable(); break;
        case 498: *reinterpret_cast<QString*>(_v) = _t->horizontalGridColor(); break;
        case 499: *reinterpret_cast<bool*>(_v) = _t->isHorizontalGridColorImmutable(); break;
        case 500: *reinterpret_cast<QString*>(_v) = _t->specialObjectColor(); break;
        case 501: *reinterpret_cast<bool*>(_v) = _t->isSpecialObjectColorImmutable(); break;
        case 502: *reinterpret_cast<QString*>(_v) = _t->horizonColor(); break;
        case 503: *reinterpret_cast<bool*>(_v) = _t->isHorizonColorImmutable(); break;
        case 504: *reinterpret_cast<QString*>(_v) = _t->localMeridianColor(); break;
        case 505: *reinterpret_cast<bool*>(_v) = _t->isLocalMeridianColorImmutable(); break;
        case 506: *reinterpret_cast<QString*>(_v) = _t->milkyWayWColor(); break;
        case 507: *reinterpret_cast<bool*>(_v) = _t->isMilkyWayWColorImmutable(); break;
        case 508: *reinterpret_cast<QString*>(_v) = _t->starNameColor(); break;
        case 509: *reinterpret_cast<bool*>(_v) = _t->isStarNameColorImmutable(); break;
        case 510: *reinterpret_cast<QString*>(_v) = _t->deepSkyNameColor(); break;
        case 511: *reinterpret_cast<bool*>(_v) = _t->isDeepSkyNameColorImmutable(); break;
        case 512: *reinterpret_cast<QString*>(_v) = _t->planetNameColor(); break;
        case 513: *reinterpret_cast<bool*>(_v) = _t->isPlanetNameColorImmutable(); break;
        case 514: *reinterpret_cast<QString*>(_v) = _t->planetTrailColor(); break;
        case 515: *reinterpret_cast<bool*>(_v) = _t->isPlanetTrailColorImmutable(); break;
        case 516: *reinterpret_cast<QString*>(_v) = _t->skyColor(); break;
        case 517: *reinterpret_cast<bool*>(_v) = _t->isSkyColorImmutable(); break;
        case 518: *reinterpret_cast<QString*>(_v) = _t->skyColorDaytime(); break;
        case 519: *reinterpret_cast<bool*>(_v) = _t->isSkyColorDaytimeImmutable(); break;
        case 520: *reinterpret_cast<QString*>(_v) = _t->artificialHorizonColor(); break;
        case 521: *reinterpret_cast<bool*>(_v) = _t->isArtificialHorizonColorImmutable(); break;
        case 522: *reinterpret_cast<QString*>(_v) = _t->telescopeTargetColor(); break;
        case 523: *reinterpret_cast<bool*>(_v) = _t->isTelescopeTargetColorImmutable(); break;
        case 524: *reinterpret_cast<QString*>(_v) = _t->visibleSatColor(); break;
        case 525: *reinterpret_cast<bool*>(_v) = _t->isVisibleSatColorImmutable(); break;
        case 526: *reinterpret_cast<QString*>(_v) = _t->satColor(); break;
        case 527: *reinterpret_cast<bool*>(_v) = _t->isSatColorImmutable(); break;
        case 528: *reinterpret_cast<QString*>(_v) = _t->satLabelColor(); break;
        case 529: *reinterpret_cast<bool*>(_v) = _t->isSatLabelColorImmutable(); break;
        case 530: *reinterpret_cast<QString*>(_v) = _t->supernovaColor(); break;
        case 531: *reinterpret_cast<bool*>(_v) = _t->isSupernovaColorImmutable(); break;
        case 532: *reinterpret_cast<QString*>(_v) = _t->asteroidColor(); break;
        case 533: *reinterpret_cast<bool*>(_v) = _t->isAsteroidColorImmutable(); break;
        case 534: *reinterpret_cast<QString*>(_v) = _t->userLabelColor(); break;
        case 535: *reinterpret_cast<bool*>(_v) = _t->isUserLabelColorImmutable(); break;
        case 536: *reinterpret_cast<QString*>(_v) = _t->rAGuideColor(); break;
        case 537: *reinterpret_cast<bool*>(_v) = _t->isRAGuideColorImmutable(); break;
        case 538: *reinterpret_cast<QString*>(_v) = _t->dEGuideColor(); break;
        case 539: *reinterpret_cast<bool*>(_v) = _t->isDEGuideColorImmutable(); break;
        case 540: *reinterpret_cast<QString*>(_v) = _t->solverFOVColor(); break;
        case 541: *reinterpret_cast<bool*>(_v) = _t->isSolverFOVColorImmutable(); break;
        case 542: *reinterpret_cast<bool*>(_v) = _t->xplanetIsInternal(); break;
        case 543: *reinterpret_cast<bool*>(_v) = _t->isXplanetIsInternalImmutable(); break;
        case 544: *reinterpret_cast<QString*>(_v) = _t->xplanetPath(); break;
        case 545: *reinterpret_cast<bool*>(_v) = _t->isXplanetPathImmutable(); break;
        case 546: *reinterpret_cast<bool*>(_v) = _t->xplanetUseFIFO(); break;
        case 547: *reinterpret_cast<bool*>(_v) = _t->isXplanetUseFIFOImmutable(); break;
        case 548: *reinterpret_cast<uint*>(_v) = _t->xplanetTimeout(); break;
        case 549: *reinterpret_cast<bool*>(_v) = _t->isXplanetTimeoutImmutable(); break;
        case 550: *reinterpret_cast<uint*>(_v) = _t->xplanetAnimationDelay(); break;
        case 551: *reinterpret_cast<bool*>(_v) = _t->isXplanetAnimationDelayImmutable(); break;
        case 552: *reinterpret_cast<uint*>(_v) = _t->xplanetWidth(); break;
        case 553: *reinterpret_cast<bool*>(_v) = _t->isXplanetWidthImmutable(); break;
        case 554: *reinterpret_cast<uint*>(_v) = _t->xplanetHeight(); break;
        case 555: *reinterpret_cast<bool*>(_v) = _t->isXplanetHeightImmutable(); break;
        case 556: *reinterpret_cast<bool*>(_v) = _t->xplanetLabel(); break;
        case 557: *reinterpret_cast<bool*>(_v) = _t->isXplanetLabelImmutable(); break;
        case 558: *reinterpret_cast<bool*>(_v) = _t->xplanetLabelLocalTime(); break;
        case 559: *reinterpret_cast<bool*>(_v) = _t->isXplanetLabelLocalTimeImmutable(); break;
        case 560: *reinterpret_cast<bool*>(_v) = _t->xplanetLabelGMT(); break;
        case 561: *reinterpret_cast<bool*>(_v) = _t->isXplanetLabelGMTImmutable(); break;
        case 562: *reinterpret_cast<QString*>(_v) = _t->xplanetLabelString(); break;
        case 563: *reinterpret_cast<bool*>(_v) = _t->isXplanetLabelStringImmutable(); break;
        case 564: *reinterpret_cast<QString*>(_v) = _t->xplanetFontSize(); break;
        case 565: *reinterpret_cast<bool*>(_v) = _t->isXplanetFontSizeImmutable(); break;
        case 566: *reinterpret_cast<QString*>(_v) = _t->xplanetColor(); break;
        case 567: *reinterpret_cast<bool*>(_v) = _t->isXplanetColorImmutable(); break;
        case 568: *reinterpret_cast<QString*>(_v) = _t->xplanetDateFormat(); break;
        case 569: *reinterpret_cast<bool*>(_v) = _t->isXplanetDateFormatImmutable(); break;
        case 570: *reinterpret_cast<bool*>(_v) = _t->xplanetLabelTL(); break;
        case 571: *reinterpret_cast<bool*>(_v) = _t->isXplanetLabelTLImmutable(); break;
        case 572: *reinterpret_cast<bool*>(_v) = _t->xplanetLabelTR(); break;
        case 573: *reinterpret_cast<bool*>(_v) = _t->isXplanetLabelTRImmutable(); break;
        case 574: *reinterpret_cast<bool*>(_v) = _t->xplanetLabelBR(); break;
        case 575: *reinterpret_cast<bool*>(_v) = _t->isXplanetLabelBRImmutable(); break;
        case 576: *reinterpret_cast<bool*>(_v) = _t->xplanetLabelBL(); break;
        case 577: *reinterpret_cast<bool*>(_v) = _t->isXplanetLabelBLImmutable(); break;
        case 578: *reinterpret_cast<QString*>(_v) = _t->xplanetGlare(); break;
        case 579: *reinterpret_cast<bool*>(_v) = _t->isXplanetGlareImmutable(); break;
        case 580: *reinterpret_cast<bool*>(_v) = _t->xplanetRandom(); break;
        case 581: *reinterpret_cast<bool*>(_v) = _t->isXplanetRandomImmutable(); break;
        case 582: *reinterpret_cast<bool*>(_v) = _t->xplanetLatLong(); break;
        case 583: *reinterpret_cast<bool*>(_v) = _t->isXplanetLatLongImmutable(); break;
        case 584: *reinterpret_cast<QString*>(_v) = _t->xplanetLatitude(); break;
        case 585: *reinterpret_cast<bool*>(_v) = _t->isXplanetLatitudeImmutable(); break;
        case 586: *reinterpret_cast<QString*>(_v) = _t->xplanetLongitude(); break;
        case 587: *reinterpret_cast<bool*>(_v) = _t->isXplanetLongitudeImmutable(); break;
        case 588: *reinterpret_cast<uint*>(_v) = _t->xplanetProjection(); break;
        case 589: *reinterpret_cast<bool*>(_v) = _t->isXplanetProjectionImmutable(); break;
        case 590: *reinterpret_cast<bool*>(_v) = _t->xplanetBackground(); break;
        case 591: *reinterpret_cast<bool*>(_v) = _t->isXplanetBackgroundImmutable(); break;
        case 592: *reinterpret_cast<bool*>(_v) = _t->xplanetBackgroundImage(); break;
        case 593: *reinterpret_cast<bool*>(_v) = _t->isXplanetBackgroundImageImmutable(); break;
        case 594: *reinterpret_cast<QString*>(_v) = _t->xplanetBackgroundImagePath(); break;
        case 595: *reinterpret_cast<bool*>(_v) = _t->isXplanetBackgroundImagePathImmutable(); break;
        case 596: *reinterpret_cast<bool*>(_v) = _t->xplanetBackgroundColor(); break;
        case 597: *reinterpret_cast<bool*>(_v) = _t->isXplanetBackgroundColorImmutable(); break;
        case 598: *reinterpret_cast<QString*>(_v) = _t->xplanetBackgroundColorValue(); break;
        case 599: *reinterpret_cast<bool*>(_v) = _t->isXplanetBackgroundColorValueImmutable(); break;
        case 600: *reinterpret_cast<QString*>(_v) = _t->xplanetMagnitude(); break;
        case 601: *reinterpret_cast<bool*>(_v) = _t->isXplanetMagnitudeImmutable(); break;
        case 602: *reinterpret_cast<bool*>(_v) = _t->xplanetArcFile(); break;
        case 603: *reinterpret_cast<bool*>(_v) = _t->isXplanetArcFileImmutable(); break;
        case 604: *reinterpret_cast<QString*>(_v) = _t->xplanetArcFilePath(); break;
        case 605: *reinterpret_cast<bool*>(_v) = _t->isXplanetArcFilePathImmutable(); break;
        case 606: *reinterpret_cast<bool*>(_v) = _t->xplanetConfigFile(); break;
        case 607: *reinterpret_cast<bool*>(_v) = _t->isXplanetConfigFileImmutable(); break;
        case 608: *reinterpret_cast<QString*>(_v) = _t->xplanetConfigFilePath(); break;
        case 609: *reinterpret_cast<bool*>(_v) = _t->isXplanetConfigFilePathImmutable(); break;
        case 610: *reinterpret_cast<bool*>(_v) = _t->xplanetFOV(); break;
        case 611: *reinterpret_cast<bool*>(_v) = _t->isXplanetFOVImmutable(); break;
        case 612: *reinterpret_cast<bool*>(_v) = _t->xplanetMarkerFile(); break;
        case 613: *reinterpret_cast<bool*>(_v) = _t->isXplanetMarkerFileImmutable(); break;
        case 614: *reinterpret_cast<QString*>(_v) = _t->xplanetMarkerFilePath(); break;
        case 615: *reinterpret_cast<bool*>(_v) = _t->isXplanetMarkerFilePathImmutable(); break;
        case 616: *reinterpret_cast<bool*>(_v) = _t->xplanetMarkerBounds(); break;
        case 617: *reinterpret_cast<bool*>(_v) = _t->isXplanetMarkerBoundsImmutable(); break;
        case 618: *reinterpret_cast<QString*>(_v) = _t->xplanetMarkerBoundsPath(); break;
        case 619: *reinterpret_cast<bool*>(_v) = _t->isXplanetMarkerBoundsPathImmutable(); break;
        case 620: *reinterpret_cast<bool*>(_v) = _t->xplanetStarmap(); break;
        case 621: *reinterpret_cast<bool*>(_v) = _t->isXplanetStarmapImmutable(); break;
        case 622: *reinterpret_cast<QString*>(_v) = _t->xplanetStarmapPath(); break;
        case 623: *reinterpret_cast<bool*>(_v) = _t->isXplanetStarmapPathImmutable(); break;
        case 624: *reinterpret_cast<QString*>(_v) = _t->xplanetQuality(); break;
        case 625: *reinterpret_cast<bool*>(_v) = _t->isXplanetQualityImmutable(); break;
        case 626: *reinterpret_cast<bool*>(_v) = _t->showSatellites(); break;
        case 627: *reinterpret_cast<bool*>(_v) = _t->isShowSatellitesImmutable(); break;
        case 628: *reinterpret_cast<bool*>(_v) = _t->showVisibleSatellites(); break;
        case 629: *reinterpret_cast<bool*>(_v) = _t->isShowVisibleSatellitesImmutable(); break;
        case 630: *reinterpret_cast<bool*>(_v) = _t->drawSatellitesLikeStars(); break;
        case 631: *reinterpret_cast<bool*>(_v) = _t->isDrawSatellitesLikeStarsImmutable(); break;
        case 632: *reinterpret_cast<bool*>(_v) = _t->showSatellitesLabels(); break;
        case 633: *reinterpret_cast<bool*>(_v) = _t->isShowSatellitesLabelsImmutable(); break;
        case 634: *reinterpret_cast<QStringList*>(_v) = _t->selectedSatellites(); break;
        case 635: *reinterpret_cast<bool*>(_v) = _t->isSelectedSatellitesImmutable(); break;
        case 636: *reinterpret_cast<bool*>(_v) = _t->kStarsFirstRun(); break;
        case 637: *reinterpret_cast<bool*>(_v) = _t->isKStarsFirstRunImmutable(); break;
        case 638: *reinterpret_cast<bool*>(_v) = _t->alwaysRecomputeCoordinates(); break;
        case 639: *reinterpret_cast<bool*>(_v) = _t->isAlwaysRecomputeCoordinatesImmutable(); break;
        case 640: *reinterpret_cast<double*>(_v) = _t->defaultDSSImageSize(); break;
        case 641: *reinterpret_cast<bool*>(_v) = _t->isDefaultDSSImageSizeImmutable(); break;
        case 642: *reinterpret_cast<double*>(_v) = _t->dSSPadding(); break;
        case 643: *reinterpret_cast<bool*>(_v) = _t->isDSSPaddingImmutable(); break;
        case 644: *reinterpret_cast<bool*>(_v) = _t->verboseLogging(); break;
        case 645: *reinterpret_cast<bool*>(_v) = _t->isVerboseLoggingImmutable(); break;
        case 646: *reinterpret_cast<bool*>(_v) = _t->regularLogging(); break;
        case 647: *reinterpret_cast<bool*>(_v) = _t->isRegularLoggingImmutable(); break;
        case 648: *reinterpret_cast<bool*>(_v) = _t->disableLogging(); break;
        case 649: *reinterpret_cast<bool*>(_v) = _t->isDisableLoggingImmutable(); break;
        case 650: *reinterpret_cast<bool*>(_v) = _t->logToDefault(); break;
        case 651: *reinterpret_cast<bool*>(_v) = _t->isLogToDefaultImmutable(); break;
        case 652: *reinterpret_cast<bool*>(_v) = _t->logToFile(); break;
        case 653: *reinterpret_cast<bool*>(_v) = _t->isLogToFileImmutable(); break;
        case 654: *reinterpret_cast<bool*>(_v) = _t->fITSLogging(); break;
        case 655: *reinterpret_cast<bool*>(_v) = _t->isFITSLoggingImmutable(); break;
        case 656: *reinterpret_cast<bool*>(_v) = _t->iNDILogging(); break;
        case 657: *reinterpret_cast<bool*>(_v) = _t->isINDILoggingImmutable(); break;
        case 658: *reinterpret_cast<bool*>(_v) = _t->captureLogging(); break;
        case 659: *reinterpret_cast<bool*>(_v) = _t->isCaptureLoggingImmutable(); break;
        case 660: *reinterpret_cast<bool*>(_v) = _t->focusLogging(); break;
        case 661: *reinterpret_cast<bool*>(_v) = _t->isFocusLoggingImmutable(); break;
        case 662: *reinterpret_cast<bool*>(_v) = _t->saveGuideImages(); break;
        case 663: *reinterpret_cast<bool*>(_v) = _t->isSaveGuideImagesImmutable(); break;
        case 664: *reinterpret_cast<bool*>(_v) = _t->saveAlignImages(); break;
        case 665: *reinterpret_cast<bool*>(_v) = _t->isSaveAlignImagesImmutable(); break;
        case 666: *reinterpret_cast<bool*>(_v) = _t->saveFailedAlignImages(); break;
        case 667: *reinterpret_cast<bool*>(_v) = _t->isSaveFailedAlignImagesImmutable(); break;
        case 668: *reinterpret_cast<bool*>(_v) = _t->dontSyncToRealTime(); break;
        case 669: *reinterpret_cast<bool*>(_v) = _t->isDontSyncToRealTimeImmutable(); break;
        case 670: *reinterpret_cast<bool*>(_v) = _t->guideLogging(); break;
        case 671: *reinterpret_cast<bool*>(_v) = _t->isGuideLoggingImmutable(); break;
        case 672: *reinterpret_cast<bool*>(_v) = _t->alignmentLogging(); break;
        case 673: *reinterpret_cast<bool*>(_v) = _t->isAlignmentLoggingImmutable(); break;
        case 674: *reinterpret_cast<bool*>(_v) = _t->mountLogging(); break;
        case 675: *reinterpret_cast<bool*>(_v) = _t->isMountLoggingImmutable(); break;
        case 676: *reinterpret_cast<bool*>(_v) = _t->observatoryLogging(); break;
        case 677: *reinterpret_cast<bool*>(_v) = _t->isObservatoryLoggingImmutable(); break;
        case 678: *reinterpret_cast<int*>(_v) = _t->imageDebayerEngine(); break;
        case 679: *reinterpret_cast<bool*>(_v) = _t->isImageDebayerEngineImmutable(); break;
        case 680: *reinterpret_cast<int*>(_v) = _t->imageDebayerAlgo(); break;
        case 681: *reinterpret_cast<bool*>(_v) = _t->isImageDebayerAlgoImmutable(); break;
        case 682: *reinterpret_cast<int*>(_v) = _t->stackDebayerEngine(); break;
        case 683: *reinterpret_cast<bool*>(_v) = _t->isStackDebayerEngineImmutable(); break;
        case 684: *reinterpret_cast<int*>(_v) = _t->stackDebayerAlgo(); break;
        case 685: *reinterpret_cast<bool*>(_v) = _t->isStackDebayerAlgoImmutable(); break;
        case 686: *reinterpret_cast<QString*>(_v) = _t->fITSWindowGeometry(); break;
        case 687: *reinterpret_cast<bool*>(_v) = _t->isFITSWindowGeometryImmutable(); break;
        case 688: *reinterpret_cast<bool*>(_v) = _t->useFITSViewer(); break;
        case 689: *reinterpret_cast<bool*>(_v) = _t->isUseFITSViewerImmutable(); break;
        case 690: *reinterpret_cast<bool*>(_v) = _t->singlePreviewFITS(); break;
        case 691: *reinterpret_cast<bool*>(_v) = _t->isSinglePreviewFITSImmutable(); break;
        case 692: *reinterpret_cast<bool*>(_v) = _t->singleWindowCapturedFITS(); break;
        case 693: *reinterpret_cast<bool*>(_v) = _t->isSingleWindowCapturedFITSImmutable(); break;
        case 694: *reinterpret_cast<bool*>(_v) = _t->singleWindowOpenedFITS(); break;
        case 695: *reinterpret_cast<bool*>(_v) = _t->isSingleWindowOpenedFITSImmutable(); break;
        case 696: *reinterpret_cast<bool*>(_v) = _t->focusFITSOnNewImage(); break;
        case 697: *reinterpret_cast<bool*>(_v) = _t->isFocusFITSOnNewImageImmutable(); break;
        case 698: *reinterpret_cast<bool*>(_v) = _t->independentWindowFITS(); break;
        case 699: *reinterpret_cast<bool*>(_v) = _t->isIndependentWindowFITSImmutable(); break;
        case 700: *reinterpret_cast<bool*>(_v) = _t->liveStackerOwnProcess(); break;
        case 701: *reinterpret_cast<bool*>(_v) = _t->isLiveStackerOwnProcessImmutable(); break;
        case 702: *reinterpret_cast<bool*>(_v) = _t->autoDebayer(); break;
        case 703: *reinterpret_cast<bool*>(_v) = _t->isAutoDebayerImmutable(); break;
        case 704: *reinterpret_cast<bool*>(_v) = _t->auto3DCube(); break;
        case 705: *reinterpret_cast<bool*>(_v) = _t->isAuto3DCubeImmutable(); break;
        case 706: *reinterpret_cast<bool*>(_v) = _t->autoHFR(); break;
        case 707: *reinterpret_cast<bool*>(_v) = _t->isAutoHFRImmutable(); break;
        case 708: *reinterpret_cast<bool*>(_v) = _t->quickHFR(); break;
        case 709: *reinterpret_cast<bool*>(_v) = _t->isQuickHFRImmutable(); break;
        case 710: *reinterpret_cast<bool*>(_v) = _t->stellarSolverPartition(); break;
        case 711: *reinterpret_cast<bool*>(_v) = _t->isStellarSolverPartitionImmutable(); break;
        case 712: *reinterpret_cast<bool*>(_v) = _t->autoWCS(); break;
        case 713: *reinterpret_cast<bool*>(_v) = _t->isAutoWCSImmutable(); break;
        case 714: *reinterpret_cast<bool*>(_v) = _t->limitedResourcesMode(); break;
        case 715: *reinterpret_cast<bool*>(_v) = _t->isLimitedResourcesModeImmutable(); break;
        case 716: *reinterpret_cast<bool*>(_v) = _t->nonLinearHistogram(); break;
        case 717: *reinterpret_cast<bool*>(_v) = _t->isNonLinearHistogramImmutable(); break;
        case 718: *reinterpret_cast<double*>(_v) = _t->hIPSOpacity(); break;
        case 719: *reinterpret_cast<bool*>(_v) = _t->isHIPSOpacityImmutable(); break;
        case 720: *reinterpret_cast<int*>(_v) = _t->hIPSOffsetX(); break;
        case 721: *reinterpret_cast<bool*>(_v) = _t->isHIPSOffsetXImmutable(); break;
        case 722: *reinterpret_cast<int*>(_v) = _t->hIPSOffsetY(); break;
        case 723: *reinterpret_cast<bool*>(_v) = _t->isHIPSOffsetYImmutable(); break;
        case 724: *reinterpret_cast<uint*>(_v) = _t->fitsSolverProfile(); break;
        case 725: *reinterpret_cast<bool*>(_v) = _t->isFitsSolverProfileImmutable(); break;
        case 726: *reinterpret_cast<uint*>(_v) = _t->fitsSolverModule(); break;
        case 727: *reinterpret_cast<bool*>(_v) = _t->isFitsSolverModuleImmutable(); break;
        case 728: *reinterpret_cast<QString*>(_v) = _t->fitsSolverProfileIndeces(); break;
        case 729: *reinterpret_cast<bool*>(_v) = _t->isFitsSolverProfileIndecesImmutable(); break;
        case 730: *reinterpret_cast<uint*>(_v) = _t->fitsCatalog(); break;
        case 731: *reinterpret_cast<bool*>(_v) = _t->isFitsCatalogImmutable(); break;
        case 732: *reinterpret_cast<bool*>(_v) = _t->fitsCatObjShowNames(); break;
        case 733: *reinterpret_cast<bool*>(_v) = _t->isFitsCatObjShowNamesImmutable(); break;
        case 734: *reinterpret_cast<bool*>(_v) = _t->fitsSolverUseScale(); break;
        case 735: *reinterpret_cast<bool*>(_v) = _t->isFitsSolverUseScaleImmutable(); break;
        case 736: *reinterpret_cast<bool*>(_v) = _t->fitsSolverUsePosition(); break;
        case 737: *reinterpret_cast<bool*>(_v) = _t->isFitsSolverUsePositionImmutable(); break;
        case 738: *reinterpret_cast<double*>(_v) = _t->fitsSolverScale(); break;
        case 739: *reinterpret_cast<bool*>(_v) = _t->isFitsSolverScaleImmutable(); break;
        case 740: *reinterpret_cast<uint*>(_v) = _t->fitsSolverImageScaleUnits(); break;
        case 741: *reinterpret_cast<bool*>(_v) = _t->isFitsSolverImageScaleUnitsImmutable(); break;
        case 742: *reinterpret_cast<double*>(_v) = _t->fitsSolverRadius(); break;
        case 743: *reinterpret_cast<bool*>(_v) = _t->isFitsSolverRadiusImmutable(); break;
        case 744: *reinterpret_cast<bool*>(_v) = _t->fitsLSHideGeneral(); break;
        case 745: *reinterpret_cast<bool*>(_v) = _t->isFitsLSHideGeneralImmutable(); break;
        case 746: *reinterpret_cast<bool*>(_v) = _t->fitsLSHideCalibration(); break;
        case 747: *reinterpret_cast<bool*>(_v) = _t->isFitsLSHideCalibrationImmutable(); break;
        case 748: *reinterpret_cast<bool*>(_v) = _t->fitsLSHideAlignment(); break;
        case 749: *reinterpret_cast<bool*>(_v) = _t->isFitsLSHideAlignmentImmutable(); break;
        case 750: *reinterpret_cast<bool*>(_v) = _t->fitsLSHideStacking(); break;
        case 751: *reinterpret_cast<bool*>(_v) = _t->isFitsLSHideStackingImmutable(); break;
        case 752: *reinterpret_cast<bool*>(_v) = _t->fitsLSHidePostProc(); break;
        case 753: *reinterpret_cast<bool*>(_v) = _t->isFitsLSHidePostProcImmutable(); break;
        case 754: *reinterpret_cast<bool*>(_v) = _t->fitsLSCalcSNR(); break;
        case 755: *reinterpret_cast<bool*>(_v) = _t->isFitsLSCalcSNRImmutable(); break;
        case 756: *reinterpret_cast<QString*>(_v) = _t->fitsLSMasterDark(); break;
        case 757: *reinterpret_cast<bool*>(_v) = _t->isFitsLSMasterDarkImmutable(); break;
        case 758: *reinterpret_cast<QString*>(_v) = _t->fitsLSMasterFlat(); break;
        case 759: *reinterpret_cast<bool*>(_v) = _t->isFitsLSMasterFlatImmutable(); break;
        case 760: *reinterpret_cast<bool*>(_v) = _t->fitsLSHotPixels(); break;
        case 761: *reinterpret_cast<bool*>(_v) = _t->isFitsLSHotPixelsImmutable(); break;
        case 762: *reinterpret_cast<bool*>(_v) = _t->fitsLSColdPixels(); break;
        case 763: *reinterpret_cast<bool*>(_v) = _t->isFitsLSColdPixelsImmutable(); break;
        case 764: *reinterpret_cast<uint*>(_v) = _t->fitsLSAlignMethod(); break;
        case 765: *reinterpret_cast<bool*>(_v) = _t->isFitsLSAlignMethodImmutable(); break;
        case 766: *reinterpret_cast<uint*>(_v) = _t->fitsLSNumInMem(); break;
        case 767: *reinterpret_cast<bool*>(_v) = _t->isFitsLSNumInMemImmutable(); break;
        case 768: *reinterpret_cast<uint*>(_v) = _t->fitsLSDownscale(); break;
        case 769: *reinterpret_cast<bool*>(_v) = _t->isFitsLSDownscaleImmutable(); break;
        case 770: *reinterpret_cast<uint*>(_v) = _t->fitsLSWeighting(); break;
        case 771: *reinterpret_cast<bool*>(_v) = _t->isFitsLSWeightingImmutable(); break;
        case 772: *reinterpret_cast<uint*>(_v) = _t->fitsLSNormalization(); break;
        case 773: *reinterpret_cast<bool*>(_v) = _t->isFitsLSNormalizationImmutable(); break;
        case 774: *reinterpret_cast<uint*>(_v) = _t->fitsLSStackingMethod(); break;
        case 775: *reinterpret_cast<bool*>(_v) = _t->isFitsLSStackingMethodImmutable(); break;
        case 776: *reinterpret_cast<double*>(_v) = _t->fitsLSLowSigma(); break;
        case 777: *reinterpret_cast<bool*>(_v) = _t->isFitsLSLowSigmaImmutable(); break;
        case 778: *reinterpret_cast<double*>(_v) = _t->fitsLSHighSigma(); break;
        case 779: *reinterpret_cast<bool*>(_v) = _t->isFitsLSHighSigmaImmutable(); break;
        case 780: *reinterpret_cast<double*>(_v) = _t->fitsLSWinsorCutoff(); break;
        case 781: *reinterpret_cast<bool*>(_v) = _t->isFitsLSWinsorCutoffImmutable(); break;
        case 782: *reinterpret_cast<uint*>(_v) = _t->fitsLSIterations(); break;
        case 783: *reinterpret_cast<bool*>(_v) = _t->isFitsLSIterationsImmutable(); break;
        case 784: *reinterpret_cast<double*>(_v) = _t->fitsLSKappa(); break;
        case 785: *reinterpret_cast<bool*>(_v) = _t->isFitsLSKappaImmutable(); break;
        case 786: *reinterpret_cast<double*>(_v) = _t->fitsLSAlpha(); break;
        case 787: *reinterpret_cast<bool*>(_v) = _t->isFitsLSAlphaImmutable(); break;
        case 788: *reinterpret_cast<double*>(_v) = _t->fitsLSSigma(); break;
        case 789: *reinterpret_cast<bool*>(_v) = _t->isFitsLSSigmaImmutable(); break;
        case 790: *reinterpret_cast<uint*>(_v) = _t->fitsPSFUpdate(); break;
        case 791: *reinterpret_cast<bool*>(_v) = _t->isFitsPSFUpdateImmutable(); break;
        case 792: *reinterpret_cast<bool*>(_v) = _t->fitsLSPostProc(); break;
        case 793: *reinterpret_cast<bool*>(_v) = _t->isFitsLSPostProcImmutable(); break;
        case 794: *reinterpret_cast<double*>(_v) = _t->fitsLSGradientAmt(); break;
        case 795: *reinterpret_cast<bool*>(_v) = _t->isFitsLSGradientAmtImmutable(); break;
        case 796: *reinterpret_cast<double*>(_v) = _t->fitsLSDeconvAmt(); break;
        case 797: *reinterpret_cast<bool*>(_v) = _t->isFitsLSDeconvAmtImmutable(); break;
        case 798: *reinterpret_cast<double*>(_v) = _t->fitsLSPSFSigma(); break;
        case 799: *reinterpret_cast<bool*>(_v) = _t->isFitsLSPSFSigmaImmutable(); break;
        case 800: *reinterpret_cast<double*>(_v) = _t->fitsLSDenoiseAmt(); break;
        case 801: *reinterpret_cast<bool*>(_v) = _t->isFitsLSDenoiseAmtImmutable(); break;
        case 802: *reinterpret_cast<double*>(_v) = _t->fitsLSSharpenAmt(); break;
        case 803: *reinterpret_cast<bool*>(_v) = _t->isFitsLSSharpenAmtImmutable(); break;
        case 804: *reinterpret_cast<uint*>(_v) = _t->fitsLSSharpenKernal(); break;
        case 805: *reinterpret_cast<bool*>(_v) = _t->isFitsLSSharpenKernalImmutable(); break;
        case 806: *reinterpret_cast<double*>(_v) = _t->fitsLSSharpenSigma(); break;
        case 807: *reinterpret_cast<bool*>(_v) = _t->isFitsLSSharpenSigmaImmutable(); break;
        case 808: *reinterpret_cast<QString*>(_v) = _t->fitsLSMWindowGeometry(); break;
        case 809: *reinterpret_cast<bool*>(_v) = _t->isFitsLSMWindowGeometryImmutable(); break;
        case 810: *reinterpret_cast<QStringList*>(_v) = _t->fitsLSMVisibleColumns(); break;
        case 811: *reinterpret_cast<bool*>(_v) = _t->isFitsLSMVisibleColumnsImmutable(); break;
        case 812: *reinterpret_cast<QList<int>*>(_v) = _t->fitsLSMColumnWidths(); break;
        case 813: *reinterpret_cast<bool*>(_v) = _t->isFitsLSMColumnWidthsImmutable(); break;
        case 814: *reinterpret_cast<int*>(_v) = _t->fitsLSMSortColumn(); break;
        case 815: *reinterpret_cast<bool*>(_v) = _t->isFitsLSMSortColumnImmutable(); break;
        case 816: *reinterpret_cast<int*>(_v) = _t->fitsLSMSortOrder(); break;
        case 817: *reinterpret_cast<bool*>(_v) = _t->isFitsLSMSortOrderImmutable(); break;
        case 818: *reinterpret_cast<bool*>(_v) = _t->fitsLSMHighlighting(); break;
        case 819: *reinterpret_cast<bool*>(_v) = _t->isFitsLSMHighlightingImmutable(); break;
        case 820: *reinterpret_cast<QString*>(_v) = _t->fitsLSWebcastTitle(); break;
        case 821: *reinterpret_cast<bool*>(_v) = _t->isFitsLSWebcastTitleImmutable(); break;
        case 822: *reinterpret_cast<QString*>(_v) = _t->fitsLSWebcastLogoL(); break;
        case 823: *reinterpret_cast<bool*>(_v) = _t->isFitsLSWebcastLogoLImmutable(); break;
        case 824: *reinterpret_cast<QString*>(_v) = _t->fitsLSWebcastLogoR(); break;
        case 825: *reinterpret_cast<bool*>(_v) = _t->isFitsLSWebcastLogoRImmutable(); break;
        case 826: *reinterpret_cast<uint*>(_v) = _t->fitsLSWebcastPort(); break;
        case 827: *reinterpret_cast<bool*>(_v) = _t->isFitsLSWebcastPortImmutable(); break;
        case 828: *reinterpret_cast<uint*>(_v) = _t->fitsLSWebcastThrottle(); break;
        case 829: *reinterpret_cast<bool*>(_v) = _t->isFitsLSWebcastThrottleImmutable(); break;
        case 830: *reinterpret_cast<uint*>(_v) = _t->bortleClass(); break;
        case 831: *reinterpret_cast<bool*>(_v) = _t->isBortleClassImmutable(); break;
        case 832: *reinterpret_cast<bool*>(_v) = _t->telescopeCheck(); break;
        case 833: *reinterpret_cast<bool*>(_v) = _t->isTelescopeCheckImmutable(); break;
        case 834: *reinterpret_cast<bool*>(_v) = _t->binocularsCheck(); break;
        case 835: *reinterpret_cast<bool*>(_v) = _t->isBinocularsCheckImmutable(); break;
        case 836: *reinterpret_cast<double*>(_v) = _t->binocularsAperture(); break;
        case 837: *reinterpret_cast<bool*>(_v) = _t->isBinocularsApertureImmutable(); break;
        case 838: *reinterpret_cast<uint*>(_v) = _t->scopeListIndex(); break;
        case 839: *reinterpret_cast<bool*>(_v) = _t->isScopeListIndexImmutable(); break;
        case 840: *reinterpret_cast<uint*>(_v) = _t->ekosWindowWidth(); break;
        case 841: *reinterpret_cast<bool*>(_v) = _t->isEkosWindowWidthImmutable(); break;
        case 842: *reinterpret_cast<uint*>(_v) = _t->ekosWindowHeight(); break;
        case 843: *reinterpret_cast<bool*>(_v) = _t->isEkosWindowHeightImmutable(); break;
        case 844: *reinterpret_cast<QString*>(_v) = _t->ekosGeometry(); break;
        case 845: *reinterpret_cast<bool*>(_v) = _t->isEkosGeometryImmutable(); break;
        case 846: *reinterpret_cast<bool*>(_v) = _t->ekosTopIcons(); break;
        case 847: *reinterpret_cast<bool*>(_v) = _t->isEkosTopIconsImmutable(); break;
        case 848: *reinterpret_cast<bool*>(_v) = _t->ekosLeftIcons(); break;
        case 849: *reinterpret_cast<bool*>(_v) = _t->isEkosLeftIconsImmutable(); break;
        case 850: *reinterpret_cast<bool*>(_v) = _t->independentWindowEkos(); break;
        case 851: *reinterpret_cast<bool*>(_v) = _t->isIndependentWindowEkosImmutable(); break;
        case 852: *reinterpret_cast<QString*>(_v) = _t->profile(); break;
        case 853: *reinterpret_cast<bool*>(_v) = _t->isProfileImmutable(); break;
        case 854: *reinterpret_cast<bool*>(_v) = _t->neverLoadConfig(); break;
        case 855: *reinterpret_cast<bool*>(_v) = _t->isNeverLoadConfigImmutable(); break;
        case 856: *reinterpret_cast<bool*>(_v) = _t->loadConfigOnConnection(); break;
        case 857: *reinterpret_cast<bool*>(_v) = _t->isLoadConfigOnConnectionImmutable(); break;
        case 858: *reinterpret_cast<bool*>(_v) = _t->loadDefaultConfig(); break;
        case 859: *reinterpret_cast<bool*>(_v) = _t->isLoadDefaultConfigImmutable(); break;
        case 860: *reinterpret_cast<bool*>(_v) = _t->autoLoadSerialAssistant(); break;
        case 861: *reinterpret_cast<bool*>(_v) = _t->isAutoLoadSerialAssistantImmutable(); break;
        case 862: *reinterpret_cast<bool*>(_v) = _t->rememberCredentials(); break;
        case 863: *reinterpret_cast<bool*>(_v) = _t->isRememberCredentialsImmutable(); break;
        case 864: *reinterpret_cast<bool*>(_v) = _t->autoStartEkosLive(); break;
        case 865: *reinterpret_cast<bool*>(_v) = _t->isAutoStartEkosLiveImmutable(); break;
        case 866: *reinterpret_cast<QString*>(_v) = _t->ekosLiveUsername(); break;
        case 867: *reinterpret_cast<bool*>(_v) = _t->isEkosLiveUsernameImmutable(); break;
        case 868: *reinterpret_cast<QString*>(_v) = _t->ekosLiveObservatory(); break;
        case 869: *reinterpret_cast<bool*>(_v) = _t->isEkosLiveObservatoryImmutable(); break;
        case 870: *reinterpret_cast<QString*>(_v) = _t->ekosLiveOfflineServer(); break;
        case 871: *reinterpret_cast<bool*>(_v) = _t->isEkosLiveOfflineServerImmutable(); break;
        case 872: *reinterpret_cast<QString*>(_v) = _t->ekosLiveOnlineServer(); break;
        case 873: *reinterpret_cast<bool*>(_v) = _t->isEkosLiveOnlineServerImmutable(); break;
        case 874: *reinterpret_cast<bool*>(_v) = _t->ekosLiveSound(); break;
        case 875: *reinterpret_cast<bool*>(_v) = _t->isEkosLiveSoundImmutable(); break;
        case 876: *reinterpret_cast<bool*>(_v) = _t->ekosLiveNotifications(); break;
        case 877: *reinterpret_cast<bool*>(_v) = _t->isEkosLiveNotificationsImmutable(); break;
        case 878: *reinterpret_cast<bool*>(_v) = _t->ekosLiveCloud(); break;
        case 879: *reinterpret_cast<bool*>(_v) = _t->isEkosLiveCloudImmutable(); break;
        case 880: *reinterpret_cast<double*>(_v) = _t->maxDarkTemperatureDiff(); break;
        case 881: *reinterpret_cast<bool*>(_v) = _t->isMaxDarkTemperatureDiffImmutable(); break;
        case 882: *reinterpret_cast<QStringList*>(_v) = _t->shutterfulCCDs(); break;
        case 883: *reinterpret_cast<bool*>(_v) = _t->isShutterfulCCDsImmutable(); break;
        case 884: *reinterpret_cast<QStringList*>(_v) = _t->shutterlessCCDs(); break;
        case 885: *reinterpret_cast<bool*>(_v) = _t->isShutterlessCCDsImmutable(); break;
        case 886: *reinterpret_cast<uint*>(_v) = _t->darkLibraryDuration(); break;
        case 887: *reinterpret_cast<bool*>(_v) = _t->isDarkLibraryDurationImmutable(); break;
        case 888: *reinterpret_cast<bool*>(_v) = _t->useGraphicalCountsDisplay(); break;
        case 889: *reinterpret_cast<bool*>(_v) = _t->isUseGraphicalCountsDisplayImmutable(); break;
        case 890: *reinterpret_cast<double*>(_v) = _t->minimumAltLimit(); break;
        case 891: *reinterpret_cast<bool*>(_v) = _t->isMinimumAltLimitImmutable(); break;
        case 892: *reinterpret_cast<double*>(_v) = _t->maximumAltLimit(); break;
        case 893: *reinterpret_cast<bool*>(_v) = _t->isMaximumAltLimitImmutable(); break;
        case 894: *reinterpret_cast<bool*>(_v) = _t->enableAltitudeLimits(); break;
        case 895: *reinterpret_cast<bool*>(_v) = _t->isEnableAltitudeLimitsImmutable(); break;
        case 896: *reinterpret_cast<bool*>(_v) = _t->enableAltitudeLimitsTrackingOnly(); break;
        case 897: *reinterpret_cast<bool*>(_v) = _t->isEnableAltitudeLimitsTrackingOnlyImmutable(); break;
        case 898: *reinterpret_cast<bool*>(_v) = _t->confirmBelowHorizon(); break;
        case 899: *reinterpret_cast<bool*>(_v) = _t->isConfirmBelowHorizonImmutable(); break;
        case 900: *reinterpret_cast<double*>(_v) = _t->meridianFlipOffsetDegrees(); break;
        case 901: *reinterpret_cast<bool*>(_v) = _t->isMeridianFlipOffsetDegreesImmutable(); break;
        case 902: *reinterpret_cast<double*>(_v) = _t->maximumHaLimit(); break;
        case 903: *reinterpret_cast<bool*>(_v) = _t->isMaximumHaLimitImmutable(); break;
        case 904: *reinterpret_cast<bool*>(_v) = _t->enableHaLimit(); break;
        case 905: *reinterpret_cast<bool*>(_v) = _t->isEnableHaLimitImmutable(); break;
        case 906: *reinterpret_cast<bool*>(_v) = _t->executeMeridianFlip(); break;
        case 907: *reinterpret_cast<bool*>(_v) = _t->isExecuteMeridianFlipImmutable(); break;
        case 908: *reinterpret_cast<bool*>(_v) = _t->leftRightReversed(); break;
        case 909: *reinterpret_cast<bool*>(_v) = _t->isLeftRightReversedImmutable(); break;
        case 910: *reinterpret_cast<bool*>(_v) = _t->upDownReversed(); break;
        case 911: *reinterpret_cast<bool*>(_v) = _t->isUpDownReversedImmutable(); break;
        case 912: *reinterpret_cast<bool*>(_v) = _t->parkEveryDay(); break;
        case 913: *reinterpret_cast<bool*>(_v) = _t->isParkEveryDayImmutable(); break;
        case 914: *reinterpret_cast<QString*>(_v) = _t->parkTime(); break;
        case 915: *reinterpret_cast<bool*>(_v) = _t->isParkTimeImmutable(); break;
        case 916: *reinterpret_cast<QString*>(_v) = _t->defaultObserver(); break;
        case 917: *reinterpret_cast<bool*>(_v) = _t->isDefaultObserverImmutable(); break;
        case 918: *reinterpret_cast<bool*>(_v) = _t->syncFOVPA(); break;
        case 919: *reinterpret_cast<bool*>(_v) = _t->isSyncFOVPAImmutable(); break;
        case 920: *reinterpret_cast<double*>(_v) = _t->pAMultiplier(); break;
        case 921: *reinterpret_cast<bool*>(_v) = _t->isPAMultiplierImmutable(); break;
        case 922: *reinterpret_cast<double*>(_v) = _t->pAOffset(); break;
        case 923: *reinterpret_cast<bool*>(_v) = _t->isPAOffsetImmutable(); break;
        case 924: *reinterpret_cast<uint*>(_v) = _t->pAPierSide(); break;
        case 925: *reinterpret_cast<bool*>(_v) = _t->isPAPierSideImmutable(); break;
        case 926: *reinterpret_cast<double*>(_v) = _t->guideDeviation(); break;
        case 927: *reinterpret_cast<bool*>(_v) = _t->isGuideDeviationImmutable(); break;
        case 928: *reinterpret_cast<uint*>(_v) = _t->guideDeviationReps(); break;
        case 929: *reinterpret_cast<bool*>(_v) = _t->isGuideDeviationRepsImmutable(); break;
        case 930: *reinterpret_cast<double*>(_v) = _t->startGuideDeviation(); break;
        case 931: *reinterpret_cast<bool*>(_v) = _t->isStartGuideDeviationImmutable(); break;
        case 932: *reinterpret_cast<uint*>(_v) = _t->guideDitherPerJobFrequency(); break;
        case 933: *reinterpret_cast<bool*>(_v) = _t->isGuideDitherPerJobFrequencyImmutable(); break;
        case 934: *reinterpret_cast<double*>(_v) = _t->hFRDeviation(); break;
        case 935: *reinterpret_cast<bool*>(_v) = _t->isHFRDeviationImmutable(); break;
        case 936: *reinterpret_cast<double*>(_v) = _t->maxFocusTemperatureDelta(); break;
        case 937: *reinterpret_cast<bool*>(_v) = _t->isMaxFocusTemperatureDeltaImmutable(); break;
        case 938: *reinterpret_cast<bool*>(_v) = _t->autoDark(); break;
        case 939: *reinterpret_cast<bool*>(_v) = _t->isAutoDarkImmutable(); break;
        case 940: *reinterpret_cast<bool*>(_v) = _t->enforceGuideDeviation(); break;
        case 941: *reinterpret_cast<bool*>(_v) = _t->isEnforceGuideDeviationImmutable(); break;
        case 942: *reinterpret_cast<bool*>(_v) = _t->enforceAutofocusHFR(); break;
        case 943: *reinterpret_cast<bool*>(_v) = _t->isEnforceAutofocusHFRImmutable(); break;
        case 944: *reinterpret_cast<bool*>(_v) = _t->enforceAutofocusOnTemperature(); break;
        case 945: *reinterpret_cast<bool*>(_v) = _t->isEnforceAutofocusOnTemperatureImmutable(); break;
        case 946: *reinterpret_cast<bool*>(_v) = _t->enforceRefocusEveryN(); break;
        case 947: *reinterpret_cast<bool*>(_v) = _t->isEnforceRefocusEveryNImmutable(); break;
        case 948: *reinterpret_cast<uint*>(_v) = _t->refocusEveryN(); break;
        case 949: *reinterpret_cast<bool*>(_v) = _t->isRefocusEveryNImmutable(); break;
        case 950: *reinterpret_cast<bool*>(_v) = _t->refocusAfterMeridianFlip(); break;
        case 951: *reinterpret_cast<bool*>(_v) = _t->isRefocusAfterMeridianFlipImmutable(); break;
        case 952: *reinterpret_cast<bool*>(_v) = _t->resetMountModelAfterMeridian(); break;
        case 953: *reinterpret_cast<bool*>(_v) = _t->isResetMountModelAfterMeridianImmutable(); break;
        case 954: *reinterpret_cast<bool*>(_v) = _t->forcedFlip(); break;
        case 955: *reinterpret_cast<bool*>(_v) = _t->isForcedFlipImmutable(); break;
        case 956: *reinterpret_cast<uint*>(_v) = _t->calibrationADUValue(); break;
        case 957: *reinterpret_cast<bool*>(_v) = _t->isCalibrationADUValueImmutable(); break;
        case 958: *reinterpret_cast<uint*>(_v) = _t->calibrationADUValueTolerance(); break;
        case 959: *reinterpret_cast<bool*>(_v) = _t->isCalibrationADUValueToleranceImmutable(); break;
        case 960: *reinterpret_cast<uint*>(_v) = _t->calibrationPreActionIndex(); break;
        case 961: *reinterpret_cast<bool*>(_v) = _t->isCalibrationPreActionIndexImmutable(); break;
        case 962: *reinterpret_cast<uint*>(_v) = _t->calibrationFlatDurationIndex(); break;
        case 963: *reinterpret_cast<bool*>(_v) = _t->isCalibrationFlatDurationIndexImmutable(); break;
        case 964: *reinterpret_cast<double*>(_v) = _t->calibrationWallAz(); break;
        case 965: *reinterpret_cast<bool*>(_v) = _t->isCalibrationWallAzImmutable(); break;
        case 966: *reinterpret_cast<double*>(_v) = _t->calibrationWallAlt(); break;
        case 967: *reinterpret_cast<bool*>(_v) = _t->isCalibrationWallAltImmutable(); break;
        case 968: *reinterpret_cast<double*>(_v) = _t->maxTemperatureDiff(); break;
        case 969: *reinterpret_cast<bool*>(_v) = _t->isMaxTemperatureDiffImmutable(); break;
        case 970: *reinterpret_cast<double*>(_v) = _t->maxStartGuiderDrift(); break;
        case 971: *reinterpret_cast<bool*>(_v) = _t->isMaxStartGuiderDriftImmutable(); break;
        case 972: *reinterpret_cast<bool*>(_v) = _t->enforceStartGuiderDrift(); break;
        case 973: *reinterpret_cast<bool*>(_v) = _t->isEnforceStartGuiderDriftImmutable(); break;
        case 974: *reinterpret_cast<double*>(_v) = _t->guidingSettle(); break;
        case 975: *reinterpret_cast<bool*>(_v) = _t->isGuidingSettleImmutable(); break;
        case 976: *reinterpret_cast<bool*>(_v) = _t->alwaysResetSequenceWhenStarting(); break;
        case 977: *reinterpret_cast<bool*>(_v) = _t->isAlwaysResetSequenceWhenStartingImmutable(); break;
        case 978: *reinterpret_cast<bool*>(_v) = _t->flatSyncFocus(); break;
        case 979: *reinterpret_cast<bool*>(_v) = _t->isFlatSyncFocusImmutable(); break;
        case 980: *reinterpret_cast<double*>(_v) = _t->hFRThresholdPercentage(); break;
        case 981: *reinterpret_cast<bool*>(_v) = _t->isHFRThresholdPercentageImmutable(); break;
        case 982: *reinterpret_cast<int*>(_v) = _t->hFRCheckAlgorithm(); break;
        case 983: *reinterpret_cast<bool*>(_v) = _t->isHFRCheckAlgorithmImmutable(); break;
        case 984: *reinterpret_cast<uint*>(_v) = _t->inSequenceCheckFrames(); break;
        case 985: *reinterpret_cast<bool*>(_v) = _t->isInSequenceCheckFramesImmutable(); break;
        case 986: *reinterpret_cast<bool*>(_v) = _t->autoStretch(); break;
        case 987: *reinterpret_cast<bool*>(_v) = _t->isAutoStretchImmutable(); break;
        case 988: *reinterpret_cast<uint*>(_v) = _t->stretchPreviewSampling(); break;
        case 989: *reinterpret_cast<bool*>(_v) = _t->isStretchPreviewSamplingImmutable(); break;
        case 990: *reinterpret_cast<uint*>(_v) = _t->clipping64KValue(); break;
        case 991: *reinterpret_cast<bool*>(_v) = _t->isClipping64KValueImmutable(); break;
        case 992: *reinterpret_cast<uint*>(_v) = _t->clipping256Value(); break;
        case 993: *reinterpret_cast<bool*>(_v) = _t->isClipping256ValueImmutable(); break;
        case 994: *reinterpret_cast<bool*>(_v) = _t->adaptiveSampling(); break;
        case 995: *reinterpret_cast<bool*>(_v) = _t->isAdaptiveSamplingImmutable(); break;
        case 996: *reinterpret_cast<bool*>(_v) = _t->useSummaryPreview(); break;
        case 997: *reinterpret_cast<bool*>(_v) = _t->isUseSummaryPreviewImmutable(); break;
        case 998: *reinterpret_cast<bool*>(_v) = _t->useDSLRImageViewer(); break;
        case 999: *reinterpret_cast<bool*>(_v) = _t->isUseDSLRImageViewerImmutable(); break;
        case 1000: *reinterpret_cast<bool*>(_v) = _t->forceDSLRPresets(); break;
        case 1001: *reinterpret_cast<bool*>(_v) = _t->isForceDSLRPresetsImmutable(); break;
        case 1002: *reinterpret_cast<QString*>(_v) = _t->captureDirectory(); break;
        case 1003: *reinterpret_cast<bool*>(_v) = _t->isCaptureDirectoryImmutable(); break;
        case 1004: *reinterpret_cast<QString*>(_v) = _t->placeholderFormat(); break;
        case 1005: *reinterpret_cast<bool*>(_v) = _t->isPlaceholderFormatImmutable(); break;
        case 1006: *reinterpret_cast<QString*>(_v) = _t->remoteCaptureDirectory(); break;
        case 1007: *reinterpret_cast<bool*>(_v) = _t->isRemoteCaptureDirectoryImmutable(); break;
        case 1008: *reinterpret_cast<uint*>(_v) = _t->manualCoverTimeout(); break;
        case 1009: *reinterpret_cast<bool*>(_v) = _t->isManualCoverTimeoutImmutable(); break;
        case 1010: *reinterpret_cast<uint*>(_v) = _t->captureOperationsTimeout(); break;
        case 1011: *reinterpret_cast<bool*>(_v) = _t->isCaptureOperationsTimeoutImmutable(); break;
        case 1012: *reinterpret_cast<uint*>(_v) = _t->minFlipDuration(); break;
        case 1013: *reinterpret_cast<bool*>(_v) = _t->isMinFlipDurationImmutable(); break;
        case 1014: *reinterpret_cast<bool*>(_v) = _t->capturePosition(); break;
        case 1015: *reinterpret_cast<bool*>(_v) = _t->isCapturePositionImmutable(); break;
        case 1016: *reinterpret_cast<uint*>(_v) = _t->captureTrainID(); break;
        case 1017: *reinterpret_cast<bool*>(_v) = _t->isCaptureTrainIDImmutable(); break;
        case 1018: *reinterpret_cast<bool*>(_v) = _t->captureCalibrationWall(); break;
        case 1019: *reinterpret_cast<bool*>(_v) = _t->isCaptureCalibrationWallImmutable(); break;
        case 1020: *reinterpret_cast<bool*>(_v) = _t->captureCalibrationParkMount(); break;
        case 1021: *reinterpret_cast<bool*>(_v) = _t->isCaptureCalibrationParkMountImmutable(); break;
        case 1022: *reinterpret_cast<bool*>(_v) = _t->captureCalibrationParkDome(); break;
        case 1023: *reinterpret_cast<bool*>(_v) = _t->isCaptureCalibrationParkDomeImmutable(); break;
        case 1024: *reinterpret_cast<bool*>(_v) = _t->captureCalibrationUseManual(); break;
        case 1025: *reinterpret_cast<bool*>(_v) = _t->isCaptureCalibrationUseManualImmutable(); break;
        case 1026: *reinterpret_cast<bool*>(_v) = _t->captureCalibrationUseADU(); break;
        case 1027: *reinterpret_cast<bool*>(_v) = _t->isCaptureCalibrationUseADUImmutable(); break;
        case 1028: *reinterpret_cast<double*>(_v) = _t->captureCalibrationADUValue(); break;
        case 1029: *reinterpret_cast<bool*>(_v) = _t->isCaptureCalibrationADUValueImmutable(); break;
        case 1030: *reinterpret_cast<double*>(_v) = _t->captureCalibrationADUTolerance(); break;
        case 1031: *reinterpret_cast<bool*>(_v) = _t->isCaptureCalibrationADUToleranceImmutable(); break;
        case 1032: *reinterpret_cast<bool*>(_v) = _t->captureCalibrationSkyFlats(); break;
        case 1033: *reinterpret_cast<bool*>(_v) = _t->isCaptureCalibrationSkyFlatsImmutable(); break;
        case 1034: *reinterpret_cast<uint*>(_v) = _t->absTicksSpin(); break;
        case 1035: *reinterpret_cast<bool*>(_v) = _t->isAbsTicksSpinImmutable(); break;
        case 1036: *reinterpret_cast<double*>(_v) = _t->focusExposure(); break;
        case 1037: *reinterpret_cast<bool*>(_v) = _t->isFocusExposureImmutable(); break;
        case 1038: *reinterpret_cast<QString*>(_v) = _t->focusBinning(); break;
        case 1039: *reinterpret_cast<bool*>(_v) = _t->isFocusBinningImmutable(); break;
        case 1040: *reinterpret_cast<double*>(_v) = _t->focusGain(); break;
        case 1041: *reinterpret_cast<bool*>(_v) = _t->isFocusGainImmutable(); break;
        case 1042: *reinterpret_cast<QString*>(_v) = _t->focusISO(); break;
        case 1043: *reinterpret_cast<bool*>(_v) = _t->isFocusISOImmutable(); break;
        case 1044: *reinterpret_cast<QString*>(_v) = _t->defaultFocusTemperatureSource(); break;
        case 1045: *reinterpret_cast<bool*>(_v) = _t->isDefaultFocusTemperatureSourceImmutable(); break;
        case 1046: *reinterpret_cast<QString*>(_v) = _t->focusFilter(); break;
        case 1047: *reinterpret_cast<bool*>(_v) = _t->isFocusFilterImmutable(); break;
        case 1048: *reinterpret_cast<bool*>(_v) = _t->useFocusDarkFrame(); break;
        case 1049: *reinterpret_cast<bool*>(_v) = _t->isUseFocusDarkFrameImmutable(); break;
        case 1050: *reinterpret_cast<bool*>(_v) = _t->focusSubFrame(); break;
        case 1051: *reinterpret_cast<bool*>(_v) = _t->isFocusSubFrameImmutable(); break;
        case 1052: *reinterpret_cast<uint*>(_v) = _t->focusBoxSize(); break;
        case 1053: *reinterpret_cast<bool*>(_v) = _t->isFocusBoxSizeImmutable(); break;
        case 1054: *reinterpret_cast<bool*>(_v) = _t->focusUseFullField(); break;
        case 1055: *reinterpret_cast<bool*>(_v) = _t->isFocusUseFullFieldImmutable(); break;
        case 1056: *reinterpret_cast<bool*>(_v) = _t->focusNoMaskRB(); break;
        case 1057: *reinterpret_cast<bool*>(_v) = _t->isFocusNoMaskRBImmutable(); break;
        case 1058: *reinterpret_cast<bool*>(_v) = _t->focusRingMaskRB(); break;
        case 1059: *reinterpret_cast<bool*>(_v) = _t->isFocusRingMaskRBImmutable(); break;
        case 1060: *reinterpret_cast<bool*>(_v) = _t->focusMosaicMaskRB(); break;
        case 1061: *reinterpret_cast<bool*>(_v) = _t->isFocusMosaicMaskRBImmutable(); break;
        case 1062: *reinterpret_cast<double*>(_v) = _t->focusFullFieldInnerRadius(); break;
        case 1063: *reinterpret_cast<bool*>(_v) = _t->isFocusFullFieldInnerRadiusImmutable(); break;
        case 1064: *reinterpret_cast<double*>(_v) = _t->focusFullFieldOuterRadius(); break;
        case 1065: *reinterpret_cast<bool*>(_v) = _t->isFocusFullFieldOuterRadiusImmutable(); break;
        case 1066: *reinterpret_cast<double*>(_v) = _t->focusMosaicTileWidth(); break;
        case 1067: *reinterpret_cast<bool*>(_v) = _t->isFocusMosaicTileWidthImmutable(); break;
        case 1068: *reinterpret_cast<uint*>(_v) = _t->focusMosaicSpace(); break;
        case 1069: *reinterpret_cast<bool*>(_v) = _t->isFocusMosaicSpaceImmutable(); break;
        case 1070: *reinterpret_cast<bool*>(_v) = _t->focusAutoStarEnabled(); break;
        case 1071: *reinterpret_cast<bool*>(_v) = _t->isFocusAutoStarEnabledImmutable(); break;
        case 1072: *reinterpret_cast<bool*>(_v) = _t->focusSuspendGuiding(); break;
        case 1073: *reinterpret_cast<bool*>(_v) = _t->isFocusSuspendGuidingImmutable(); break;
        case 1074: *reinterpret_cast<double*>(_v) = _t->focusGuideSettleTime(); break;
        case 1075: *reinterpret_cast<bool*>(_v) = _t->isFocusGuideSettleTimeImmutable(); break;
        case 1076: *reinterpret_cast<QString*>(_v) = _t->focusUnits(); break;
        case 1077: *reinterpret_cast<bool*>(_v) = _t->isFocusUnitsImmutable(); break;
        case 1078: *reinterpret_cast<bool*>(_v) = _t->focusAdaptive(); break;
        case 1079: *reinterpret_cast<bool*>(_v) = _t->isFocusAdaptiveImmutable(); break;
        case 1080: *reinterpret_cast<uint*>(_v) = _t->focusAdaptiveMinMove(); break;
        case 1081: *reinterpret_cast<bool*>(_v) = _t->isFocusAdaptiveMinMoveImmutable(); break;
        case 1082: *reinterpret_cast<bool*>(_v) = _t->focusAdaptStart(); break;
        case 1083: *reinterpret_cast<bool*>(_v) = _t->isFocusAdaptStartImmutable(); break;
        case 1084: *reinterpret_cast<uint*>(_v) = _t->focusAdaptiveMaxMove(); break;
        case 1085: *reinterpret_cast<bool*>(_v) = _t->isFocusAdaptiveMaxMoveImmutable(); break;
        case 1086: *reinterpret_cast<QString*>(_v) = _t->focusDetection(); break;
        case 1087: *reinterpret_cast<bool*>(_v) = _t->isFocusDetectionImmutable(); break;
        case 1088: *reinterpret_cast<QString*>(_v) = _t->focusSEPProfile(); break;
        case 1089: *reinterpret_cast<bool*>(_v) = _t->isFocusSEPProfileImmutable(); break;
        case 1090: *reinterpret_cast<QString*>(_v) = _t->focusAlgorithm(); break;
        case 1091: *reinterpret_cast<bool*>(_v) = _t->isFocusAlgorithmImmutable(); break;
        case 1092: *reinterpret_cast<QString*>(_v) = _t->focusCurveFit(); break;
        case 1093: *reinterpret_cast<bool*>(_v) = _t->isFocusCurveFitImmutable(); break;
        case 1094: *reinterpret_cast<QString*>(_v) = _t->focusStarMeasure(); break;
        case 1095: *reinterpret_cast<bool*>(_v) = _t->isFocusStarMeasureImmutable(); break;
        case 1096: *reinterpret_cast<QString*>(_v) = _t->focusStarPSF(); break;
        case 1097: *reinterpret_cast<bool*>(_v) = _t->isFocusStarPSFImmutable(); break;
        case 1098: *reinterpret_cast<bool*>(_v) = _t->focusUseWeights(); break;
        case 1099: *reinterpret_cast<bool*>(_v) = _t->isFocusUseWeightsImmutable(); break;
        case 1100: *reinterpret_cast<double*>(_v) = _t->focusR2Limit(); break;
        case 1101: *reinterpret_cast<bool*>(_v) = _t->isFocusR2LimitImmutable(); break;
        case 1102: *reinterpret_cast<bool*>(_v) = _t->focusRefineCurveFit(); break;
        case 1103: *reinterpret_cast<bool*>(_v) = _t->isFocusRefineCurveFitImmutable(); break;
        case 1104: *reinterpret_cast<uint*>(_v) = _t->focusFramesCount(); break;
        case 1105: *reinterpret_cast<bool*>(_v) = _t->isFocusFramesCountImmutable(); break;
        case 1106: *reinterpret_cast<uint*>(_v) = _t->focusHFRFramesCount(); break;
        case 1107: *reinterpret_cast<bool*>(_v) = _t->isFocusHFRFramesCountImmutable(); break;
        case 1108: *reinterpret_cast<int*>(_v) = _t->focusMultiRowAverage(); break;
        case 1109: *reinterpret_cast<bool*>(_v) = _t->isFocusMultiRowAverageImmutable(); break;
        case 1110: *reinterpret_cast<double*>(_v) = _t->focusGaussianSigma(); break;
        case 1111: *reinterpret_cast<bool*>(_v) = _t->isFocusGaussianSigmaImmutable(); break;
        case 1112: *reinterpret_cast<double*>(_v) = _t->focusThreshold(); break;
        case 1113: *reinterpret_cast<bool*>(_v) = _t->isFocusThresholdImmutable(); break;
        case 1114: *reinterpret_cast<bool*>(_v) = _t->focusDenoise(); break;
        case 1115: *reinterpret_cast<bool*>(_v) = _t->isFocusDenoiseImmutable(); break;
        case 1116: *reinterpret_cast<bool*>(_v) = _t->focusDonut(); break;
        case 1117: *reinterpret_cast<bool*>(_v) = _t->isFocusDonutImmutable(); break;
        case 1118: *reinterpret_cast<double*>(_v) = _t->focusTimeDilation(); break;
        case 1119: *reinterpret_cast<bool*>(_v) = _t->isFocusTimeDilationImmutable(); break;
        case 1120: *reinterpret_cast<double*>(_v) = _t->focusOutlierRejection(); break;
        case 1121: *reinterpret_cast<bool*>(_v) = _t->isFocusOutlierRejectionImmutable(); break;
        case 1122: *reinterpret_cast<bool*>(_v) = _t->focusScanStartPos(); break;
        case 1123: *reinterpret_cast<bool*>(_v) = _t->isFocusScanStartPosImmutable(); break;
        case 1124: *reinterpret_cast<bool*>(_v) = _t->focusScanAlwaysOn(); break;
        case 1125: *reinterpret_cast<bool*>(_v) = _t->isFocusScanAlwaysOnImmutable(); break;
        case 1126: *reinterpret_cast<uint*>(_v) = _t->focusScanDatapoints(); break;
        case 1127: *reinterpret_cast<bool*>(_v) = _t->isFocusScanDatapointsImmutable(); break;
        case 1128: *reinterpret_cast<double*>(_v) = _t->focusScanStepSizeFactor(); break;
        case 1129: *reinterpret_cast<bool*>(_v) = _t->isFocusScanStepSizeFactorImmutable(); break;
        case 1130: *reinterpret_cast<int*>(_v) = _t->focusGaussianKernelSize(); break;
        case 1131: *reinterpret_cast<bool*>(_v) = _t->isFocusGaussianKernelSizeImmutable(); break;
        case 1132: *reinterpret_cast<double*>(_v) = _t->focusTolerance(); break;
        case 1133: *reinterpret_cast<bool*>(_v) = _t->isFocusToleranceImmutable(); break;
        case 1134: *reinterpret_cast<QString*>(_v) = _t->focusWalk(); break;
        case 1135: *reinterpret_cast<bool*>(_v) = _t->isFocusWalkImmutable(); break;
        case 1136: *reinterpret_cast<double*>(_v) = _t->focusSettleTime(); break;
        case 1137: *reinterpret_cast<bool*>(_v) = _t->isFocusSettleTimeImmutable(); break;
        case 1138: *reinterpret_cast<uint*>(_v) = _t->focusTicks(); break;
        case 1139: *reinterpret_cast<bool*>(_v) = _t->isFocusTicksImmutable(); break;
        case 1140: *reinterpret_cast<double*>(_v) = _t->focusOutSteps(); break;
        case 1141: *reinterpret_cast<bool*>(_v) = _t->isFocusOutStepsImmutable(); break;
        case 1142: *reinterpret_cast<uint*>(_v) = _t->focusNumSteps(); break;
        case 1143: *reinterpret_cast<bool*>(_v) = _t->isFocusNumStepsImmutable(); break;
        case 1144: *reinterpret_cast<uint*>(_v) = _t->focusMaxTravel(); break;
        case 1145: *reinterpret_cast<bool*>(_v) = _t->isFocusMaxTravelImmutable(); break;
        case 1146: *reinterpret_cast<uint*>(_v) = _t->focusMaxSingleStep(); break;
        case 1147: *reinterpret_cast<bool*>(_v) = _t->isFocusMaxSingleStepImmutable(); break;
        case 1148: *reinterpret_cast<uint*>(_v) = _t->focusBacklash(); break;
        case 1149: *reinterpret_cast<bool*>(_v) = _t->isFocusBacklashImmutable(); break;
        case 1150: *reinterpret_cast<uint*>(_v) = _t->focusAFOverscan(); break;
        case 1151: *reinterpret_cast<bool*>(_v) = _t->isFocusAFOverscanImmutable(); break;
        case 1152: *reinterpret_cast<double*>(_v) = _t->focusOverscanDelay(); break;
        case 1153: *reinterpret_cast<bool*>(_v) = _t->isFocusOverscanDelayImmutable(); break;
        case 1154: *reinterpret_cast<uint*>(_v) = _t->focusCaptureTimeout(); break;
        case 1155: *reinterpret_cast<bool*>(_v) = _t->isFocusCaptureTimeoutImmutable(); break;
        case 1156: *reinterpret_cast<uint*>(_v) = _t->focusMotionTimeout(); break;
        case 1157: *reinterpret_cast<bool*>(_v) = _t->isFocusMotionTimeoutImmutable(); break;
        case 1158: *reinterpret_cast<QString*>(_v) = _t->focusCFZAlgorithm(); break;
        case 1159: *reinterpret_cast<bool*>(_v) = _t->isFocusCFZAlgorithmImmutable(); break;
        case 1160: *reinterpret_cast<double*>(_v) = _t->focusCFZTolerance(); break;
        case 1161: *reinterpret_cast<bool*>(_v) = _t->isFocusCFZToleranceImmutable(); break;
        case 1162: *reinterpret_cast<double*>(_v) = _t->focusCFZTau(); break;
        case 1163: *reinterpret_cast<bool*>(_v) = _t->isFocusCFZTauImmutable(); break;
        case 1164: *reinterpret_cast<bool*>(_v) = _t->focusCFZDisplayVCurve(); break;
        case 1165: *reinterpret_cast<bool*>(_v) = _t->isFocusCFZDisplayVCurveImmutable(); break;
        case 1166: *reinterpret_cast<double*>(_v) = _t->focusCFZWavelength(); break;
        case 1167: *reinterpret_cast<bool*>(_v) = _t->isFocusCFZWavelengthImmutable(); break;
        case 1168: *reinterpret_cast<uint*>(_v) = _t->focusCFZAperture(); break;
        case 1169: *reinterpret_cast<bool*>(_v) = _t->isFocusCFZApertureImmutable(); break;
        case 1170: *reinterpret_cast<double*>(_v) = _t->focusCFZFNumber(); break;
        case 1171: *reinterpret_cast<bool*>(_v) = _t->isFocusCFZFNumberImmutable(); break;
        case 1172: *reinterpret_cast<double*>(_v) = _t->focusCFZSeeing(); break;
        case 1173: *reinterpret_cast<bool*>(_v) = _t->isFocusCFZSeeingImmutable(); break;
        case 1174: *reinterpret_cast<double*>(_v) = _t->focusCFZStepSize(); break;
        case 1175: *reinterpret_cast<bool*>(_v) = _t->isFocusCFZStepSizeImmutable(); break;
        case 1176: *reinterpret_cast<bool*>(_v) = _t->focusAdvHelpOnlyChanges(); break;
        case 1177: *reinterpret_cast<bool*>(_v) = _t->isFocusAdvHelpOnlyChangesImmutable(); break;
        case 1178: *reinterpret_cast<bool*>(_v) = _t->focusAdvUpdateParams(); break;
        case 1179: *reinterpret_cast<bool*>(_v) = _t->isFocusAdvUpdateParamsImmutable(); break;
        case 1180: *reinterpret_cast<bool*>(_v) = _t->focusAdvFindStars(); break;
        case 1181: *reinterpret_cast<bool*>(_v) = _t->isFocusAdvFindStarsImmutable(); break;
        case 1182: *reinterpret_cast<bool*>(_v) = _t->focusAdvCourseAdj(); break;
        case 1183: *reinterpret_cast<bool*>(_v) = _t->isFocusAdvCourseAdjImmutable(); break;
        case 1184: *reinterpret_cast<bool*>(_v) = _t->focusAdvFineAdj(); break;
        case 1185: *reinterpret_cast<bool*>(_v) = _t->isFocusAdvFineAdjImmutable(); break;
        case 1186: *reinterpret_cast<QString*>(_v) = _t->focusSplitter(); break;
        case 1187: *reinterpret_cast<bool*>(_v) = _t->isFocusSplitterImmutable(); break;
        case 1188: *reinterpret_cast<QString*>(_v) = _t->rightLayout(); break;
        case 1189: *reinterpret_cast<bool*>(_v) = _t->isRightLayoutImmutable(); break;
        case 1190: *reinterpret_cast<bool*>(_v) = _t->adaptFocusBFO(); break;
        case 1191: *reinterpret_cast<bool*>(_v) = _t->isAdaptFocusBFOImmutable(); break;
        case 1192: *reinterpret_cast<QString*>(_v) = _t->abInsTileSelection(); break;
        case 1193: *reinterpret_cast<bool*>(_v) = _t->isAbInsTileSelectionImmutable(); break;
        case 1194: *reinterpret_cast<bool*>(_v) = _t->abInsShowLabels(); break;
        case 1195: *reinterpret_cast<bool*>(_v) = _t->isAbInsShowLabelsImmutable(); break;
        case 1196: *reinterpret_cast<bool*>(_v) = _t->abInsShowCFZ(); break;
        case 1197: *reinterpret_cast<bool*>(_v) = _t->isAbInsShowCFZImmutable(); break;
        case 1198: *reinterpret_cast<bool*>(_v) = _t->abInsOptCentres(); break;
        case 1199: *reinterpret_cast<bool*>(_v) = _t->isAbInsOptCentresImmutable(); break;
        case 1200: *reinterpret_cast<QString*>(_v) = _t->abInsHSplitter(); break;
        case 1201: *reinterpret_cast<bool*>(_v) = _t->isAbInsHSplitterImmutable(); break;
        case 1202: *reinterpret_cast<QString*>(_v) = _t->abInsVSplitter(); break;
        case 1203: *reinterpret_cast<bool*>(_v) = _t->isAbInsVSplitterImmutable(); break;
        case 1204: *reinterpret_cast<QString*>(_v) = _t->abInsSelection(); break;
        case 1205: *reinterpret_cast<bool*>(_v) = _t->isAbInsSelectionImmutable(); break;
        case 1206: *reinterpret_cast<QString*>(_v) = _t->abInsTheme(); break;
        case 1207: *reinterpret_cast<bool*>(_v) = _t->isAbInsThemeImmutable(); break;
        case 1208: *reinterpret_cast<bool*>(_v) = _t->abInsLabels(); break;
        case 1209: *reinterpret_cast<bool*>(_v) = _t->isAbInsLabelsImmutable(); break;
        case 1210: *reinterpret_cast<bool*>(_v) = _t->abInsSensor(); break;
        case 1211: *reinterpret_cast<bool*>(_v) = _t->isAbInsSensorImmutable(); break;
        case 1212: *reinterpret_cast<bool*>(_v) = _t->abInsPetzvalWire(); break;
        case 1213: *reinterpret_cast<bool*>(_v) = _t->isAbInsPetzvalWireImmutable(); break;
        case 1214: *reinterpret_cast<bool*>(_v) = _t->abInsPetzvalSurface(); break;
        case 1215: *reinterpret_cast<bool*>(_v) = _t->isAbInsPetzvalSurfaceImmutable(); break;
        case 1216: *reinterpret_cast<uint*>(_v) = _t->tiltPlateType(); break;
        case 1217: *reinterpret_cast<bool*>(_v) = _t->isTiltPlateTypeImmutable(); break;
        case 1218: *reinterpret_cast<double*>(_v) = _t->tiltRadius(); break;
        case 1219: *reinterpret_cast<bool*>(_v) = _t->isTiltRadiusImmutable(); break;
        case 1220: *reinterpret_cast<uint*>(_v) = _t->tiltThreadIndex(); break;
        case 1221: *reinterpret_cast<bool*>(_v) = _t->isTiltThreadIndexImmutable(); break;
        case 1222: *reinterpret_cast<double*>(_v) = _t->tiltScrewPitch(); break;
        case 1223: *reinterpret_cast<bool*>(_v) = _t->isTiltScrewPitchImmutable(); break;
        case 1224: *reinterpret_cast<double*>(_v) = _t->tiltRotation(); break;
        case 1225: *reinterpret_cast<bool*>(_v) = _t->isTiltRotationImmutable(); break;
        case 1226: *reinterpret_cast<uint*>(_v) = _t->tiltMode(); break;
        case 1227: *reinterpret_cast<bool*>(_v) = _t->isTiltModeImmutable(); break;
        case 1228: *reinterpret_cast<bool*>(_v) = _t->tiltPlatePresent(); break;
        case 1229: *reinterpret_cast<bool*>(_v) = _t->isTiltPlatePresentImmutable(); break;
        case 1230: *reinterpret_cast<uint*>(_v) = _t->focusSextractorType(); break;
        case 1231: *reinterpret_cast<bool*>(_v) = _t->isFocusSextractorTypeImmutable(); break;
        case 1232: *reinterpret_cast<uint*>(_v) = _t->focusOptionsProfile(); break;
        case 1233: *reinterpret_cast<bool*>(_v) = _t->isFocusOptionsProfileImmutable(); break;
        case 1234: *reinterpret_cast<uint*>(_v) = _t->hFRSextractorType(); break;
        case 1235: *reinterpret_cast<bool*>(_v) = _t->isHFRSextractorTypeImmutable(); break;
        case 1236: *reinterpret_cast<uint*>(_v) = _t->hFROptionsProfile(); break;
        case 1237: *reinterpret_cast<bool*>(_v) = _t->isHFROptionsProfileImmutable(); break;
        case 1238: *reinterpret_cast<uint*>(_v) = _t->guideSextractorType(); break;
        case 1239: *reinterpret_cast<bool*>(_v) = _t->isGuideSextractorTypeImmutable(); break;
        case 1240: *reinterpret_cast<uint*>(_v) = _t->guideOptionsProfile(); break;
        case 1241: *reinterpret_cast<bool*>(_v) = _t->isGuideOptionsProfileImmutable(); break;
        case 1242: *reinterpret_cast<uint*>(_v) = _t->solveSextractorType(); break;
        case 1243: *reinterpret_cast<bool*>(_v) = _t->isSolveSextractorTypeImmutable(); break;
        case 1244: *reinterpret_cast<uint*>(_v) = _t->solverMode(); break;
        case 1245: *reinterpret_cast<bool*>(_v) = _t->isSolverModeImmutable(); break;
        case 1246: *reinterpret_cast<uint*>(_v) = _t->solverType(); break;
        case 1247: *reinterpret_cast<bool*>(_v) = _t->isSolverTypeImmutable(); break;
        case 1248: *reinterpret_cast<uint*>(_v) = _t->solveOptionsProfile(); break;
        case 1249: *reinterpret_cast<bool*>(_v) = _t->isSolveOptionsProfileImmutable(); break;
        case 1250: *reinterpret_cast<uint*>(_v) = _t->loggerLevel(); break;
        case 1251: *reinterpret_cast<bool*>(_v) = _t->isLoggerLevelImmutable(); break;
        case 1252: *reinterpret_cast<bool*>(_v) = _t->astrometryLogToFile(); break;
        case 1253: *reinterpret_cast<bool*>(_v) = _t->isAstrometryLogToFileImmutable(); break;
        case 1254: *reinterpret_cast<QString*>(_v) = _t->astrometryLogFilepath(); break;
        case 1255: *reinterpret_cast<bool*>(_v) = _t->isAstrometryLogFilepathImmutable(); break;
        case 1256: *reinterpret_cast<QStringList*>(_v) = _t->astrometryIndexFolderList(); break;
        case 1257: *reinterpret_cast<bool*>(_v) = _t->isAstrometryIndexFolderListImmutable(); break;
        case 1258: *reinterpret_cast<double*>(_v) = _t->alignExposure(); break;
        case 1259: *reinterpret_cast<bool*>(_v) = _t->isAlignExposureImmutable(); break;
        case 1260: *reinterpret_cast<QString*>(_v) = _t->alignBinning(); break;
        case 1261: *reinterpret_cast<bool*>(_v) = _t->isAlignBinningImmutable(); break;
        case 1262: *reinterpret_cast<double*>(_v) = _t->alignGain(); break;
        case 1263: *reinterpret_cast<bool*>(_v) = _t->isAlignGainImmutable(); break;
        case 1264: *reinterpret_cast<double*>(_v) = _t->alignISO(); break;
        case 1265: *reinterpret_cast<bool*>(_v) = _t->isAlignISOImmutable(); break;
        case 1266: *reinterpret_cast<bool*>(_v) = _t->alignDarkFrame(); break;
        case 1267: *reinterpret_cast<bool*>(_v) = _t->isAlignDarkFrameImmutable(); break;
        case 1268: *reinterpret_cast<QString*>(_v) = _t->alignFilter(); break;
        case 1269: *reinterpret_cast<bool*>(_v) = _t->isAlignFilterImmutable(); break;
        case 1270: *reinterpret_cast<bool*>(_v) = _t->alignUseCurrentFilter(); break;
        case 1271: *reinterpret_cast<bool*>(_v) = _t->isAlignUseCurrentFilterImmutable(); break;
        case 1272: *reinterpret_cast<bool*>(_v) = _t->astrometryUseRotator(); break;
        case 1273: *reinterpret_cast<bool*>(_v) = _t->isAstrometryUseRotatorImmutable(); break;
        case 1274: *reinterpret_cast<double*>(_v) = _t->astrometryRotatorThreshold(); break;
        case 1275: *reinterpret_cast<bool*>(_v) = _t->isAstrometryRotatorThresholdImmutable(); break;
        case 1276: *reinterpret_cast<bool*>(_v) = _t->astrometryFlipRotationAllowed(); break;
        case 1277: *reinterpret_cast<bool*>(_v) = _t->isAstrometryFlipRotationAllowedImmutable(); break;
        case 1278: *reinterpret_cast<bool*>(_v) = _t->rotatorParityReversed(); break;
        case 1279: *reinterpret_cast<bool*>(_v) = _t->isRotatorParityReversedImmutable(); break;
        case 1280: *reinterpret_cast<bool*>(_v) = _t->astrometrySolverWCS(); break;
        case 1281: *reinterpret_cast<bool*>(_v) = _t->isAstrometrySolverWCSImmutable(); break;
        case 1282: *reinterpret_cast<bool*>(_v) = _t->astrometrySolverOverlay(); break;
        case 1283: *reinterpret_cast<bool*>(_v) = _t->isAstrometrySolverOverlayImmutable(); break;
        case 1284: *reinterpret_cast<bool*>(_v) = _t->astrometryDifferentialSlewing(); break;
        case 1285: *reinterpret_cast<bool*>(_v) = _t->isAstrometryDifferentialSlewingImmutable(); break;
        case 1286: *reinterpret_cast<uint*>(_v) = _t->alignAccuracyThreshold(); break;
        case 1287: *reinterpret_cast<bool*>(_v) = _t->isAlignAccuracyThresholdImmutable(); break;
        case 1288: *reinterpret_cast<uint*>(_v) = _t->alignSettlingTime(); break;
        case 1289: *reinterpret_cast<bool*>(_v) = _t->isAlignSettlingTimeImmutable(); break;
        case 1290: *reinterpret_cast<bool*>(_v) = _t->astrometryUseNoFITS2FITS(); break;
        case 1291: *reinterpret_cast<bool*>(_v) = _t->isAstrometryUseNoFITS2FITSImmutable(); break;
        case 1292: *reinterpret_cast<bool*>(_v) = _t->astrometryUseResort(); break;
        case 1293: *reinterpret_cast<bool*>(_v) = _t->isAstrometryUseResortImmutable(); break;
        case 1294: *reinterpret_cast<bool*>(_v) = _t->astrometryUseNoVerify(); break;
        case 1295: *reinterpret_cast<bool*>(_v) = _t->isAstrometryUseNoVerifyImmutable(); break;
        case 1296: *reinterpret_cast<bool*>(_v) = _t->astrometryUseImageScale(); break;
        case 1297: *reinterpret_cast<bool*>(_v) = _t->isAstrometryUseImageScaleImmutable(); break;
        case 1298: *reinterpret_cast<double*>(_v) = _t->astrometryImageScaleLow(); break;
        case 1299: *reinterpret_cast<bool*>(_v) = _t->isAstrometryImageScaleLowImmutable(); break;
        case 1300: *reinterpret_cast<double*>(_v) = _t->astrometryImageScaleHigh(); break;
        case 1301: *reinterpret_cast<bool*>(_v) = _t->isAstrometryImageScaleHighImmutable(); break;
        case 1302: *reinterpret_cast<bool*>(_v) = _t->astrometryAutoUpdateImageScale(); break;
        case 1303: *reinterpret_cast<bool*>(_v) = _t->isAstrometryAutoUpdateImageScaleImmutable(); break;
        case 1304: *reinterpret_cast<uint*>(_v) = _t->astrometryImageScaleUnits(); break;
        case 1305: *reinterpret_cast<bool*>(_v) = _t->isAstrometryImageScaleUnitsImmutable(); break;
        case 1306: *reinterpret_cast<bool*>(_v) = _t->astrometryUseDownsample(); break;
        case 1307: *reinterpret_cast<bool*>(_v) = _t->isAstrometryUseDownsampleImmutable(); break;
        case 1308: *reinterpret_cast<uint*>(_v) = _t->astrometryDownsample(); break;
        case 1309: *reinterpret_cast<bool*>(_v) = _t->isAstrometryDownsampleImmutable(); break;
        case 1310: *reinterpret_cast<bool*>(_v) = _t->astrometryAutoDownsample(); break;
        case 1311: *reinterpret_cast<bool*>(_v) = _t->isAstrometryAutoDownsampleImmutable(); break;
        case 1312: *reinterpret_cast<bool*>(_v) = _t->astrometryDynamicThreshold(); break;
        case 1313: *reinterpret_cast<bool*>(_v) = _t->isAstrometryDynamicThresholdImmutable(); break;
        case 1314: *reinterpret_cast<bool*>(_v) = _t->astrometryUsePosition(); break;
        case 1315: *reinterpret_cast<bool*>(_v) = _t->isAstrometryUsePositionImmutable(); break;
        case 1316: *reinterpret_cast<double*>(_v) = _t->astrometryPositionRA(); break;
        case 1317: *reinterpret_cast<bool*>(_v) = _t->isAstrometryPositionRAImmutable(); break;
        case 1318: *reinterpret_cast<double*>(_v) = _t->astrometryPositionDE(); break;
        case 1319: *reinterpret_cast<bool*>(_v) = _t->isAstrometryPositionDEImmutable(); break;
        case 1320: *reinterpret_cast<bool*>(_v) = _t->astrometryAutoUpdatePosition(); break;
        case 1321: *reinterpret_cast<bool*>(_v) = _t->isAstrometryAutoUpdatePositionImmutable(); break;
        case 1322: *reinterpret_cast<double*>(_v) = _t->astrometryRadius(); break;
        case 1323: *reinterpret_cast<bool*>(_v) = _t->isAstrometryRadiusImmutable(); break;
        case 1324: *reinterpret_cast<bool*>(_v) = _t->astrometryDetectParity(); break;
        case 1325: *reinterpret_cast<bool*>(_v) = _t->isAstrometryDetectParityImmutable(); break;
        case 1326: *reinterpret_cast<QString*>(_v) = _t->astrometryCustomOptions(); break;
        case 1327: *reinterpret_cast<bool*>(_v) = _t->isAstrometryCustomOptionsImmutable(); break;
        case 1328: *reinterpret_cast<QString*>(_v) = _t->astrometrySolverBinary(); break;
        case 1329: *reinterpret_cast<bool*>(_v) = _t->isAstrometrySolverBinaryImmutable(); break;
        case 1330: *reinterpret_cast<QString*>(_v) = _t->astrometryWCSInfo(); break;
        case 1331: *reinterpret_cast<bool*>(_v) = _t->isAstrometryWCSInfoImmutable(); break;
        case 1332: *reinterpret_cast<QString*>(_v) = _t->astrometryConfFile(); break;
        case 1333: *reinterpret_cast<bool*>(_v) = _t->isAstrometryConfFileImmutable(); break;
        case 1334: *reinterpret_cast<QString*>(_v) = _t->sextractorBinary(); break;
        case 1335: *reinterpret_cast<bool*>(_v) = _t->isSextractorBinaryImmutable(); break;
        case 1336: *reinterpret_cast<QString*>(_v) = _t->watneyBinary(); break;
        case 1337: *reinterpret_cast<bool*>(_v) = _t->isWatneyBinaryImmutable(); break;
        case 1338: *reinterpret_cast<QString*>(_v) = _t->astrometryAPIKey(); break;
        case 1339: *reinterpret_cast<bool*>(_v) = _t->isAstrometryAPIKeyImmutable(); break;
        case 1340: *reinterpret_cast<QString*>(_v) = _t->astrometryAPIURL(); break;
        case 1341: *reinterpret_cast<bool*>(_v) = _t->isAstrometryAPIURLImmutable(); break;
        case 1342: *reinterpret_cast<bool*>(_v) = _t->astrometryUseJPEG(); break;
        case 1343: *reinterpret_cast<bool*>(_v) = _t->isAstrometryUseJPEGImmutable(); break;
        case 1344: *reinterpret_cast<uint*>(_v) = _t->astrometryTimeout(); break;
        case 1345: *reinterpret_cast<bool*>(_v) = _t->isAstrometryTimeoutImmutable(); break;
        case 1346: *reinterpret_cast<QString*>(_v) = _t->pAHMountSpeed(); break;
        case 1347: *reinterpret_cast<bool*>(_v) = _t->isPAHMountSpeedImmutable(); break;
        case 1348: *reinterpret_cast<double*>(_v) = _t->pAHRotaion(); break;
        case 1349: *reinterpret_cast<bool*>(_v) = _t->isPAHRotaionImmutable(); break;
        case 1350: *reinterpret_cast<QString*>(_v) = _t->pAHRefreshAlgorithm(); break;
        case 1351: *reinterpret_cast<bool*>(_v) = _t->isPAHRefreshAlgorithmImmutable(); break;
        case 1352: *reinterpret_cast<QString*>(_v) = _t->pAHDirection(); break;
        case 1353: *reinterpret_cast<bool*>(_v) = _t->isPAHDirectionImmutable(); break;
        case 1354: *reinterpret_cast<bool*>(_v) = _t->pAHAutoPark(); break;
        case 1355: *reinterpret_cast<bool*>(_v) = _t->isPAHAutoParkImmutable(); break;
        case 1356: *reinterpret_cast<bool*>(_v) = _t->pAHManualSlew(); break;
        case 1357: *reinterpret_cast<bool*>(_v) = _t->isPAHManualSlewImmutable(); break;
        case 1358: *reinterpret_cast<double*>(_v) = _t->pAHExposure(); break;
        case 1359: *reinterpret_cast<bool*>(_v) = _t->isPAHExposureImmutable(); break;
        case 1360: *reinterpret_cast<bool*>(_v) = _t->pAHAutoPACCorrection(); break;
        case 1361: *reinterpret_cast<bool*>(_v) = _t->isPAHAutoPACCorrectionImmutable(); break;
        case 1362: *reinterpret_cast<bool*>(_v) = _t->pAHAutoChangeDirection(); break;
        case 1363: *reinterpret_cast<bool*>(_v) = _t->isPAHAutoChangeDirectionImmutable(); break;
        case 1364: *reinterpret_cast<double*>(_v) = _t->pAHSuccessThreshold(); break;
        case 1365: *reinterpret_cast<bool*>(_v) = _t->isPAHSuccessThresholdImmutable(); break;
        case 1366: *reinterpret_cast<uint*>(_v) = _t->pAHCorrectionTimeout(); break;
        case 1367: *reinterpret_cast<bool*>(_v) = _t->isPAHCorrectionTimeoutImmutable(); break;
        case 1368: *reinterpret_cast<double*>(_v) = _t->guideExposure(); break;
        case 1369: *reinterpret_cast<bool*>(_v) = _t->isGuideExposureImmutable(); break;
        case 1370: *reinterpret_cast<double*>(_v) = _t->guideDelay(); break;
        case 1371: *reinterpret_cast<bool*>(_v) = _t->isGuideDelayImmutable(); break;
        case 1372: *reinterpret_cast<uint*>(_v) = _t->guiderType(); break;
        case 1373: *reinterpret_cast<bool*>(_v) = _t->isGuiderTypeImmutable(); break;
        case 1374: *reinterpret_cast<uint*>(_v) = _t->guideAlgorithm(); break;
        case 1375: *reinterpret_cast<bool*>(_v) = _t->isGuideAlgorithmImmutable(); break;
        case 1376: *reinterpret_cast<uint*>(_v) = _t->rAGuidePulseAlgorithm(); break;
        case 1377: *reinterpret_cast<bool*>(_v) = _t->isRAGuidePulseAlgorithmImmutable(); break;
        case 1378: *reinterpret_cast<uint*>(_v) = _t->dECGuidePulseAlgorithm(); break;
        case 1379: *reinterpret_cast<bool*>(_v) = _t->isDECGuidePulseAlgorithmImmutable(); break;
        case 1380: *reinterpret_cast<QUrl*>(_v) = _t->aIGuiderWeightsFile(); break;
        case 1381: *reinterpret_cast<bool*>(_v) = _t->isAIGuiderWeightsFileImmutable(); break;
        case 1382: *reinterpret_cast<double*>(_v) = _t->aIPredictionGain(); break;
        case 1383: *reinterpret_cast<bool*>(_v) = _t->isAIPredictionGainImmutable(); break;
        case 1384: *reinterpret_cast<bool*>(_v) = _t->aIProportionalBackoff(); break;
        case 1385: *reinterpret_cast<bool*>(_v) = _t->isAIProportionalBackoffImmutable(); break;
        case 1386: *reinterpret_cast<bool*>(_v) = _t->aIPIDAutoTune(); break;
        case 1387: *reinterpret_cast<bool*>(_v) = _t->isAIPIDAutoTuneImmutable(); break;
        case 1388: *reinterpret_cast<bool*>(_v) = _t->aIShadowMode(); break;
        case 1389: *reinterpret_cast<bool*>(_v) = _t->isAIShadowModeImmutable(); break;
        case 1390: *reinterpret_cast<QString*>(_v) = _t->pHD2Host(); break;
        case 1391: *reinterpret_cast<bool*>(_v) = _t->isPHD2HostImmutable(); break;
        case 1392: *reinterpret_cast<uint*>(_v) = _t->pHD2Port(); break;
        case 1393: *reinterpret_cast<bool*>(_v) = _t->isPHD2PortImmutable(); break;
        case 1394: *reinterpret_cast<QString*>(_v) = _t->linGuiderHost(); break;
        case 1395: *reinterpret_cast<bool*>(_v) = _t->isLinGuiderHostImmutable(); break;
        case 1396: *reinterpret_cast<uint*>(_v) = _t->linGuiderPort(); break;
        case 1397: *reinterpret_cast<bool*>(_v) = _t->isLinGuiderPortImmutable(); break;
        case 1398: *reinterpret_cast<uint*>(_v) = _t->calibrationPulseDuration(); break;
        case 1399: *reinterpret_cast<bool*>(_v) = _t->isCalibrationPulseDurationImmutable(); break;
        case 1400: *reinterpret_cast<uint*>(_v) = _t->calibrationMaxMove(); break;
        case 1401: *reinterpret_cast<bool*>(_v) = _t->isCalibrationMaxMoveImmutable(); break;
        case 1402: *reinterpret_cast<QString*>(_v) = _t->guideSquareSize(); break;
        case 1403: *reinterpret_cast<bool*>(_v) = _t->isGuideSquareSizeImmutable(); break;
        case 1404: *reinterpret_cast<QString*>(_v) = _t->guideBinning(); break;
        case 1405: *reinterpret_cast<bool*>(_v) = _t->isGuideBinningImmutable(); break;
        case 1406: *reinterpret_cast<bool*>(_v) = _t->guideAutoStar(); break;
        case 1407: *reinterpret_cast<bool*>(_v) = _t->isGuideAutoStarImmutable(); break;
        case 1408: *reinterpret_cast<bool*>(_v) = _t->guideShowFrame(); break;
        case 1409: *reinterpret_cast<bool*>(_v) = _t->isGuideShowFrameImmutable(); break;
        case 1410: *reinterpret_cast<bool*>(_v) = _t->guideAutoSquareSizeEnabled(); break;
        case 1411: *reinterpret_cast<bool*>(_v) = _t->isGuideAutoSquareSizeEnabledImmutable(); break;
        case 1412: *reinterpret_cast<uint*>(_v) = _t->autoModeIterations(); break;
        case 1413: *reinterpret_cast<bool*>(_v) = _t->isAutoModeIterationsImmutable(); break;
        case 1414: *reinterpret_cast<uint*>(_v) = _t->guideLostStarTimeout(); break;
        case 1415: *reinterpret_cast<bool*>(_v) = _t->isGuideLostStarTimeoutImmutable(); break;
        case 1416: *reinterpret_cast<uint*>(_v) = _t->guideCalibrationTimeout(); break;
        case 1417: *reinterpret_cast<bool*>(_v) = _t->isGuideCalibrationTimeoutImmutable(); break;
        case 1418: *reinterpret_cast<double*>(_v) = _t->guideMaxDeltaRMS(); break;
        case 1419: *reinterpret_cast<bool*>(_v) = _t->isGuideMaxDeltaRMSImmutable(); break;
        case 1420: *reinterpret_cast<double*>(_v) = _t->guideMaxHFR(); break;
        case 1421: *reinterpret_cast<bool*>(_v) = _t->isGuideMaxHFRImmutable(); break;
        case 1422: *reinterpret_cast<uint*>(_v) = _t->minDetectionsSEPMultistar(); break;
        case 1423: *reinterpret_cast<bool*>(_v) = _t->isMinDetectionsSEPMultistarImmutable(); break;
        case 1424: *reinterpret_cast<uint*>(_v) = _t->maxMultistarReferenceStars(); break;
        case 1425: *reinterpret_cast<bool*>(_v) = _t->isMaxMultistarReferenceStarsImmutable(); break;
        case 1426: *reinterpret_cast<bool*>(_v) = _t->alwaysInventGuideStar(); break;
        case 1427: *reinterpret_cast<bool*>(_v) = _t->isAlwaysInventGuideStarImmutable(); break;
        case 1428: *reinterpret_cast<bool*>(_v) = _t->twoAxisEnabled(); break;
        case 1429: *reinterpret_cast<bool*>(_v) = _t->isTwoAxisEnabledImmutable(); break;
        case 1430: *reinterpret_cast<bool*>(_v) = _t->useGuideHead(); break;
        case 1431: *reinterpret_cast<bool*>(_v) = _t->isUseGuideHeadImmutable(); break;
        case 1432: *reinterpret_cast<bool*>(_v) = _t->saveGuideLog(); break;
        case 1433: *reinterpret_cast<bool*>(_v) = _t->isSaveGuideLogImmutable(); break;
        case 1434: *reinterpret_cast<bool*>(_v) = _t->guideDarkFrame(); break;
        case 1435: *reinterpret_cast<bool*>(_v) = _t->isGuideDarkFrameImmutable(); break;
        case 1436: *reinterpret_cast<bool*>(_v) = _t->guideSubframe(); break;
        case 1437: *reinterpret_cast<bool*>(_v) = _t->isGuideSubframeImmutable(); break;
        case 1438: *reinterpret_cast<double*>(_v) = _t->ditherPixels(); break;
        case 1439: *reinterpret_cast<bool*>(_v) = _t->isDitherPixelsImmutable(); break;
        case 1440: *reinterpret_cast<uint*>(_v) = _t->ditherFrames(); break;
        case 1441: *reinterpret_cast<bool*>(_v) = _t->isDitherFramesImmutable(); break;
        case 1442: *reinterpret_cast<uint*>(_v) = _t->ditherSettle(); break;
        case 1443: *reinterpret_cast<bool*>(_v) = _t->isDitherSettleImmutable(); break;
        case 1444: *reinterpret_cast<double*>(_v) = _t->ditherThreshold(); break;
        case 1445: *reinterpret_cast<bool*>(_v) = _t->isDitherThresholdImmutable(); break;
        case 1446: *reinterpret_cast<uint*>(_v) = _t->ditherTimeout(); break;
        case 1447: *reinterpret_cast<bool*>(_v) = _t->isDitherTimeoutImmutable(); break;
        case 1448: *reinterpret_cast<uint*>(_v) = _t->ditherMaxIterations(); break;
        case 1449: *reinterpret_cast<bool*>(_v) = _t->isDitherMaxIterationsImmutable(); break;
        case 1450: *reinterpret_cast<uint*>(_v) = _t->ditherNoGuidingPulse(); break;
        case 1451: *reinterpret_cast<bool*>(_v) = _t->isDitherNoGuidingPulseImmutable(); break;
        case 1452: *reinterpret_cast<bool*>(_v) = _t->ditherFailAbortsAutoGuide(); break;
        case 1453: *reinterpret_cast<bool*>(_v) = _t->isDitherFailAbortsAutoGuideImmutable(); break;
        case 1454: *reinterpret_cast<bool*>(_v) = _t->ditherWithOnePulse(); break;
        case 1455: *reinterpret_cast<bool*>(_v) = _t->isDitherWithOnePulseImmutable(); break;
        case 1456: *reinterpret_cast<bool*>(_v) = _t->ditherEnabled(); break;
        case 1457: *reinterpret_cast<bool*>(_v) = _t->isDitherEnabledImmutable(); break;
        case 1458: *reinterpret_cast<bool*>(_v) = _t->ditherNoGuiding(); break;
        case 1459: *reinterpret_cast<bool*>(_v) = _t->isDitherNoGuidingImmutable(); break;
        case 1460: *reinterpret_cast<bool*>(_v) = _t->rAGuideEnabled(); break;
        case 1461: *reinterpret_cast<bool*>(_v) = _t->isRAGuideEnabledImmutable(); break;
        case 1462: *reinterpret_cast<bool*>(_v) = _t->dECGuideEnabled(); break;
        case 1463: *reinterpret_cast<bool*>(_v) = _t->isDECGuideEnabledImmutable(); break;
        case 1464: *reinterpret_cast<bool*>(_v) = _t->northDECGuideEnabled(); break;
        case 1465: *reinterpret_cast<bool*>(_v) = _t->isNorthDECGuideEnabledImmutable(); break;
        case 1466: *reinterpret_cast<bool*>(_v) = _t->southDECGuideEnabled(); break;
        case 1467: *reinterpret_cast<bool*>(_v) = _t->isSouthDECGuideEnabledImmutable(); break;
        case 1468: *reinterpret_cast<bool*>(_v) = _t->eastRAGuideEnabled(); break;
        case 1469: *reinterpret_cast<bool*>(_v) = _t->isEastRAGuideEnabledImmutable(); break;
        case 1470: *reinterpret_cast<bool*>(_v) = _t->westRAGuideEnabled(); break;
        case 1471: *reinterpret_cast<bool*>(_v) = _t->isWestRAGuideEnabledImmutable(); break;
        case 1472: *reinterpret_cast<double*>(_v) = _t->rAProportionalGain(); break;
        case 1473: *reinterpret_cast<bool*>(_v) = _t->isRAProportionalGainImmutable(); break;
        case 1474: *reinterpret_cast<double*>(_v) = _t->dECProportionalGain(); break;
        case 1475: *reinterpret_cast<bool*>(_v) = _t->isDECProportionalGainImmutable(); break;
        case 1476: *reinterpret_cast<double*>(_v) = _t->rAIntegralGain(); break;
        case 1477: *reinterpret_cast<bool*>(_v) = _t->isRAIntegralGainImmutable(); break;
        case 1478: *reinterpret_cast<double*>(_v) = _t->dECIntegralGain(); break;
        case 1479: *reinterpret_cast<bool*>(_v) = _t->isDECIntegralGainImmutable(); break;
        case 1480: *reinterpret_cast<double*>(_v) = _t->rAMinimumPulseArcSec(); break;
        case 1481: *reinterpret_cast<bool*>(_v) = _t->isRAMinimumPulseArcSecImmutable(); break;
        case 1482: *reinterpret_cast<double*>(_v) = _t->dECMinimumPulseArcSec(); break;
        case 1483: *reinterpret_cast<bool*>(_v) = _t->isDECMinimumPulseArcSecImmutable(); break;
        case 1484: *reinterpret_cast<uint*>(_v) = _t->rAMaximumPulseArcSec(); break;
        case 1485: *reinterpret_cast<bool*>(_v) = _t->isRAMaximumPulseArcSecImmutable(); break;
        case 1486: *reinterpret_cast<uint*>(_v) = _t->dECMaximumPulseArcSec(); break;
        case 1487: *reinterpret_cast<bool*>(_v) = _t->isDECMaximumPulseArcSecImmutable(); break;
        case 1488: *reinterpret_cast<bool*>(_v) = _t->gPGEnabled(); break;
        case 1489: *reinterpret_cast<bool*>(_v) = _t->isGPGEnabledImmutable(); break;
        case 1490: *reinterpret_cast<bool*>(_v) = _t->gPGDarkGuiding(); break;
        case 1491: *reinterpret_cast<bool*>(_v) = _t->isGPGDarkGuidingImmutable(); break;
        case 1492: *reinterpret_cast<double*>(_v) = _t->gPGDarkGuidingInterval(); break;
        case 1493: *reinterpret_cast<bool*>(_v) = _t->isGPGDarkGuidingIntervalImmutable(); break;
        case 1494: *reinterpret_cast<bool*>(_v) = _t->aIDarkGuiding(); break;
        case 1495: *reinterpret_cast<bool*>(_v) = _t->isAIDarkGuidingImmutable(); break;
        case 1496: *reinterpret_cast<double*>(_v) = _t->aIDarkGuidingInterval(); break;
        case 1497: *reinterpret_cast<bool*>(_v) = _t->isAIDarkGuidingIntervalImmutable(); break;
        case 1498: *reinterpret_cast<double*>(_v) = _t->gPGcWeight(); break;
        case 1499: *reinterpret_cast<bool*>(_v) = _t->isGPGcWeightImmutable(); break;
        case 1500: *reinterpret_cast<uint*>(_v) = _t->gPGMinPeriodsForInference(); break;
        case 1501: *reinterpret_cast<bool*>(_v) = _t->isGPGMinPeriodsForInferenceImmutable(); break;
        case 1502: *reinterpret_cast<double*>(_v) = _t->gPGMinMove(); break;
        case 1503: *reinterpret_cast<bool*>(_v) = _t->isGPGMinMoveImmutable(); break;
        case 1504: *reinterpret_cast<uint*>(_v) = _t->gPGSE0KLengthScale(); break;
        case 1505: *reinterpret_cast<bool*>(_v) = _t->isGPGSE0KLengthScaleImmutable(); break;
        case 1506: *reinterpret_cast<double*>(_v) = _t->gPGSE0KSignalVariance(); break;
        case 1507: *reinterpret_cast<bool*>(_v) = _t->isGPGSE0KSignalVarianceImmutable(); break;
        case 1508: *reinterpret_cast<double*>(_v) = _t->gPGPKLengthScale(); break;
        case 1509: *reinterpret_cast<bool*>(_v) = _t->isGPGPKLengthScaleImmutable(); break;
        case 1510: *reinterpret_cast<double*>(_v) = _t->gPGPeriod(); break;
        case 1511: *reinterpret_cast<bool*>(_v) = _t->isGPGPeriodImmutable(); break;
        case 1512: *reinterpret_cast<double*>(_v) = _t->gPGPKSignalVariance(); break;
        case 1513: *reinterpret_cast<bool*>(_v) = _t->isGPGPKSignalVarianceImmutable(); break;
        case 1514: *reinterpret_cast<double*>(_v) = _t->gPGSE1KLengthScale(); break;
        case 1515: *reinterpret_cast<bool*>(_v) = _t->isGPGSE1KLengthScaleImmutable(); break;
        case 1516: *reinterpret_cast<double*>(_v) = _t->gPGSE1KSignalVariance(); break;
        case 1517: *reinterpret_cast<bool*>(_v) = _t->isGPGSE1KSignalVarianceImmutable(); break;
        case 1518: *reinterpret_cast<uint*>(_v) = _t->gPGMinPeriodsForPeriodEstimate(); break;
        case 1519: *reinterpret_cast<bool*>(_v) = _t->isGPGMinPeriodsForPeriodEstimateImmutable(); break;
        case 1520: *reinterpret_cast<uint*>(_v) = _t->gPGPointsForApproximation(); break;
        case 1521: *reinterpret_cast<bool*>(_v) = _t->isGPGPointsForApproximationImmutable(); break;
        case 1522: *reinterpret_cast<double*>(_v) = _t->gPGpWeight(); break;
        case 1523: *reinterpret_cast<bool*>(_v) = _t->isGPGpWeightImmutable(); break;
        case 1524: *reinterpret_cast<bool*>(_v) = _t->gPGEstimatePeriod(); break;
        case 1525: *reinterpret_cast<bool*>(_v) = _t->isGPGEstimatePeriodImmutable(); break;
        case 1526: *reinterpret_cast<uint*>(_v) = _t->guiderAccuracyThreshold(); break;
        case 1527: *reinterpret_cast<bool*>(_v) = _t->isGuiderAccuracyThresholdImmutable(); break;
        case 1528: *reinterpret_cast<bool*>(_v) = _t->rADisplayedOnGuideGraph(); break;
        case 1529: *reinterpret_cast<bool*>(_v) = _t->isRADisplayedOnGuideGraphImmutable(); break;
        case 1530: *reinterpret_cast<bool*>(_v) = _t->dEDisplayedOnGuideGraph(); break;
        case 1531: *reinterpret_cast<bool*>(_v) = _t->isDEDisplayedOnGuideGraphImmutable(); break;
        case 1532: *reinterpret_cast<bool*>(_v) = _t->rACorrDisplayedOnGuideGraph(); break;
        case 1533: *reinterpret_cast<bool*>(_v) = _t->isRACorrDisplayedOnGuideGraphImmutable(); break;
        case 1534: *reinterpret_cast<bool*>(_v) = _t->dECorrDisplayedOnGuideGraph(); break;
        case 1535: *reinterpret_cast<bool*>(_v) = _t->isDECorrDisplayedOnGuideGraphImmutable(); break;
        case 1536: *reinterpret_cast<bool*>(_v) = _t->sNRDisplayedOnGuideGraph(); break;
        case 1537: *reinterpret_cast<bool*>(_v) = _t->isSNRDisplayedOnGuideGraphImmutable(); break;
        case 1538: *reinterpret_cast<bool*>(_v) = _t->rMSDisplayedOnGuideGraph(); break;
        case 1539: *reinterpret_cast<bool*>(_v) = _t->isRMSDisplayedOnGuideGraphImmutable(); break;
        case 1540: *reinterpret_cast<double*>(_v) = _t->rAHysteresis(); break;
        case 1541: *reinterpret_cast<bool*>(_v) = _t->isRAHysteresisImmutable(); break;
        case 1542: *reinterpret_cast<double*>(_v) = _t->dECHysteresis(); break;
        case 1543: *reinterpret_cast<bool*>(_v) = _t->isDECHysteresisImmutable(); break;
        case 1544: *reinterpret_cast<uint*>(_v) = _t->schedulerAlgorithm(); break;
        case 1545: *reinterpret_cast<bool*>(_v) = _t->isSchedulerAlgorithmImmutable(); break;
        case 1546: *reinterpret_cast<bool*>(_v) = _t->schedulerLogging(); break;
        case 1547: *reinterpret_cast<bool*>(_v) = _t->isSchedulerLoggingImmutable(); break;
        case 1548: *reinterpret_cast<bool*>(_v) = _t->stopEkosAfterShutdown(); break;
        case 1549: *reinterpret_cast<bool*>(_v) = _t->isStopEkosAfterShutdownImmutable(); break;
        case 1550: *reinterpret_cast<bool*>(_v) = _t->shutdownScriptTerminatesINDI(); break;
        case 1551: *reinterpret_cast<bool*>(_v) = _t->isShutdownScriptTerminatesINDIImmutable(); break;
        case 1552: *reinterpret_cast<bool*>(_v) = _t->cameraWarmupEnabled(); break;
        case 1553: *reinterpret_cast<bool*>(_v) = _t->isCameraWarmupEnabledImmutable(); break;
        case 1554: *reinterpret_cast<uint*>(_v) = _t->cameraWarmupRamp(); break;
        case 1555: *reinterpret_cast<bool*>(_v) = _t->isCameraWarmupRampImmutable(); break;
        case 1556: *reinterpret_cast<bool*>(_v) = _t->preemptiveShutdown(); break;
        case 1557: *reinterpret_cast<bool*>(_v) = _t->isPreemptiveShutdownImmutable(); break;
        case 1558: *reinterpret_cast<bool*>(_v) = _t->resetMountModelOnAlignFail(); break;
        case 1559: *reinterpret_cast<bool*>(_v) = _t->isResetMountModelOnAlignFailImmutable(); break;
        case 1560: *reinterpret_cast<bool*>(_v) = _t->resetMountModelBeforeJob(); break;
        case 1561: *reinterpret_cast<bool*>(_v) = _t->isResetMountModelBeforeJobImmutable(); break;
        case 1562: *reinterpret_cast<bool*>(_v) = _t->resetGuideCalibration(); break;
        case 1563: *reinterpret_cast<bool*>(_v) = _t->isResetGuideCalibrationImmutable(); break;
        case 1564: *reinterpret_cast<bool*>(_v) = _t->forceAlignmentBeforeJob(); break;
        case 1565: *reinterpret_cast<bool*>(_v) = _t->isForceAlignmentBeforeJobImmutable(); break;
        case 1566: *reinterpret_cast<bool*>(_v) = _t->reuseGuideCalibration(); break;
        case 1567: *reinterpret_cast<bool*>(_v) = _t->isReuseGuideCalibrationImmutable(); break;
        case 1568: *reinterpret_cast<bool*>(_v) = _t->reverseDecOnPierSideChange(); break;
        case 1569: *reinterpret_cast<bool*>(_v) = _t->isReverseDecOnPierSideChangeImmutable(); break;
        case 1570: *reinterpret_cast<bool*>(_v) = _t->guideCalibrationBacklash(); break;
        case 1571: *reinterpret_cast<bool*>(_v) = _t->isGuideCalibrationBacklashImmutable(); break;
        case 1572: *reinterpret_cast<bool*>(_v) = _t->assumeDecOrthogonal(); break;
        case 1573: *reinterpret_cast<bool*>(_v) = _t->isAssumeDecOrthogonalImmutable(); break;
        case 1574: *reinterpret_cast<QString*>(_v) = _t->serializedCalibration(); break;
        case 1575: *reinterpret_cast<bool*>(_v) = _t->isSerializedCalibrationImmutable(); break;
        case 1576: *reinterpret_cast<bool*>(_v) = _t->realignAfterCalibrationFailure(); break;
        case 1577: *reinterpret_cast<bool*>(_v) = _t->isRealignAfterCalibrationFailureImmutable(); break;
        case 1578: *reinterpret_cast<double*>(_v) = _t->preemptiveShutdownTime(); break;
        case 1579: *reinterpret_cast<bool*>(_v) = _t->isPreemptiveShutdownTimeImmutable(); break;
        case 1580: *reinterpret_cast<bool*>(_v) = _t->rememberJobProgress(); break;
        case 1581: *reinterpret_cast<bool*>(_v) = _t->isRememberJobProgressImmutable(); break;
        case 1582: *reinterpret_cast<bool*>(_v) = _t->greedyScheduling(); break;
        case 1583: *reinterpret_cast<bool*>(_v) = _t->isGreedySchedulingImmutable(); break;
        case 1584: *reinterpret_cast<double*>(_v) = _t->leadTime(); break;
        case 1585: *reinterpret_cast<bool*>(_v) = _t->isLeadTimeImmutable(); break;
        case 1586: *reinterpret_cast<double*>(_v) = _t->preDawnTime(); break;
        case 1587: *reinterpret_cast<bool*>(_v) = _t->isPreDawnTimeImmutable(); break;
        case 1588: *reinterpret_cast<double*>(_v) = _t->dawnOffset(); break;
        case 1589: *reinterpret_cast<bool*>(_v) = _t->isDawnOffsetImmutable(); break;
        case 1590: *reinterpret_cast<double*>(_v) = _t->duskOffset(); break;
        case 1591: *reinterpret_cast<bool*>(_v) = _t->isDuskOffsetImmutable(); break;
        case 1592: *reinterpret_cast<double*>(_v) = _t->telescopeFocalLength(); break;
        case 1593: *reinterpret_cast<bool*>(_v) = _t->isTelescopeFocalLengthImmutable(); break;
        case 1594: *reinterpret_cast<double*>(_v) = _t->telescopeFocalReducer(); break;
        case 1595: *reinterpret_cast<bool*>(_v) = _t->isTelescopeFocalReducerImmutable(); break;
        case 1596: *reinterpret_cast<double*>(_v) = _t->cameraPixelWidth(); break;
        case 1597: *reinterpret_cast<bool*>(_v) = _t->isCameraPixelWidthImmutable(); break;
        case 1598: *reinterpret_cast<double*>(_v) = _t->cameraPixelHeight(); break;
        case 1599: *reinterpret_cast<bool*>(_v) = _t->isCameraPixelHeightImmutable(); break;
        case 1600: *reinterpret_cast<uint*>(_v) = _t->cameraWidth(); break;
        case 1601: *reinterpret_cast<bool*>(_v) = _t->isCameraWidthImmutable(); break;
        case 1602: *reinterpret_cast<uint*>(_v) = _t->cameraHeight(); break;
        case 1603: *reinterpret_cast<bool*>(_v) = _t->isCameraHeightImmutable(); break;
        case 1604: *reinterpret_cast<double*>(_v) = _t->cameraRotation(); break;
        case 1605: *reinterpret_cast<bool*>(_v) = _t->isCameraRotationImmutable(); break;
        case 1606: *reinterpret_cast<uint*>(_v) = _t->errorHandlingStrategy(); break;
        case 1607: *reinterpret_cast<bool*>(_v) = _t->isErrorHandlingStrategyImmutable(); break;
        case 1608: *reinterpret_cast<uint*>(_v) = _t->errorHandlingStrategyDelay(); break;
        case 1609: *reinterpret_cast<bool*>(_v) = _t->isErrorHandlingStrategyDelayImmutable(); break;
        case 1610: *reinterpret_cast<bool*>(_v) = _t->rescheduleErrors(); break;
        case 1611: *reinterpret_cast<bool*>(_v) = _t->isRescheduleErrorsImmutable(); break;
        case 1612: *reinterpret_cast<uint*>(_v) = _t->alignCheckFrequency(); break;
        case 1613: *reinterpret_cast<bool*>(_v) = _t->isAlignCheckFrequencyImmutable(); break;
        case 1614: *reinterpret_cast<double*>(_v) = _t->alignCheckThreshold(); break;
        case 1615: *reinterpret_cast<bool*>(_v) = _t->isAlignCheckThresholdImmutable(); break;
        case 1616: *reinterpret_cast<bool*>(_v) = _t->schedulerTrackStep(); break;
        case 1617: *reinterpret_cast<bool*>(_v) = _t->isSchedulerTrackStepImmutable(); break;
        case 1618: *reinterpret_cast<bool*>(_v) = _t->schedulerStartupEnabled(); break;
        case 1619: *reinterpret_cast<bool*>(_v) = _t->isSchedulerStartupEnabledImmutable(); break;
        case 1620: *reinterpret_cast<QString*>(_v) = _t->schedulerPreStartupScript(); break;
        case 1621: *reinterpret_cast<bool*>(_v) = _t->isSchedulerPreStartupScriptImmutable(); break;
        case 1622: *reinterpret_cast<QString*>(_v) = _t->schedulerPostStartupScript(); break;
        case 1623: *reinterpret_cast<bool*>(_v) = _t->isSchedulerPostStartupScriptImmutable(); break;
        case 1624: *reinterpret_cast<bool*>(_v) = _t->schedulerShutdownEnabled(); break;
        case 1625: *reinterpret_cast<bool*>(_v) = _t->isSchedulerShutdownEnabledImmutable(); break;
        case 1626: *reinterpret_cast<QString*>(_v) = _t->schedulerPreShutdownScript(); break;
        case 1627: *reinterpret_cast<bool*>(_v) = _t->isSchedulerPreShutdownScriptImmutable(); break;
        case 1628: *reinterpret_cast<QString*>(_v) = _t->schedulerPostShutdownScript(); break;
        case 1629: *reinterpret_cast<bool*>(_v) = _t->isSchedulerPostShutdownScriptImmutable(); break;
        case 1630: *reinterpret_cast<bool*>(_v) = _t->schedulerFocusStep(); break;
        case 1631: *reinterpret_cast<bool*>(_v) = _t->isSchedulerFocusStepImmutable(); break;
        case 1632: *reinterpret_cast<bool*>(_v) = _t->schedulerGuideStep(); break;
        case 1633: *reinterpret_cast<bool*>(_v) = _t->isSchedulerGuideStepImmutable(); break;
        case 1634: *reinterpret_cast<bool*>(_v) = _t->schedulerAlignStep(); break;
        case 1635: *reinterpret_cast<bool*>(_v) = _t->isSchedulerAlignStepImmutable(); break;
        case 1636: *reinterpret_cast<bool*>(_v) = _t->schedulerAltitude(); break;
        case 1637: *reinterpret_cast<bool*>(_v) = _t->isSchedulerAltitudeImmutable(); break;
        case 1638: *reinterpret_cast<double*>(_v) = _t->schedulerAltitudeValue(); break;
        case 1639: *reinterpret_cast<bool*>(_v) = _t->isSchedulerAltitudeValueImmutable(); break;
        case 1640: *reinterpret_cast<bool*>(_v) = _t->schedulerHorizon(); break;
        case 1641: *reinterpret_cast<bool*>(_v) = _t->isSchedulerHorizonImmutable(); break;
        case 1642: *reinterpret_cast<bool*>(_v) = _t->schedulerMoonSeparation(); break;
        case 1643: *reinterpret_cast<bool*>(_v) = _t->isSchedulerMoonSeparationImmutable(); break;
        case 1644: *reinterpret_cast<double*>(_v) = _t->schedulerMoonSeparationValue(); break;
        case 1645: *reinterpret_cast<bool*>(_v) = _t->isSchedulerMoonSeparationValueImmutable(); break;
        case 1646: *reinterpret_cast<bool*>(_v) = _t->schedulerMoonAltitude(); break;
        case 1647: *reinterpret_cast<bool*>(_v) = _t->isSchedulerMoonAltitudeImmutable(); break;
        case 1648: *reinterpret_cast<double*>(_v) = _t->schedulerMoonAltitudeMaxValue(); break;
        case 1649: *reinterpret_cast<bool*>(_v) = _t->isSchedulerMoonAltitudeMaxValueImmutable(); break;
        case 1650: *reinterpret_cast<bool*>(_v) = _t->schedulerWeather(); break;
        case 1651: *reinterpret_cast<bool*>(_v) = _t->isSchedulerWeatherImmutable(); break;
        case 1652: *reinterpret_cast<uint*>(_v) = _t->schedulerWeatherGracePeriod(); break;
        case 1653: *reinterpret_cast<bool*>(_v) = _t->isSchedulerWeatherGracePeriodImmutable(); break;
        case 1654: *reinterpret_cast<uint*>(_v) = _t->schedulerWeatherShutdownDelay(); break;
        case 1655: *reinterpret_cast<bool*>(_v) = _t->isSchedulerWeatherShutdownDelayImmutable(); break;
        case 1656: *reinterpret_cast<QString*>(_v) = _t->schedulerSafetyMonitorConnectionString(); break;
        case 1657: *reinterpret_cast<bool*>(_v) = _t->isSchedulerSafetyMonitorConnectionStringImmutable(); break;
        case 1658: *reinterpret_cast<bool*>(_v) = _t->schedulerTwilight(); break;
        case 1659: *reinterpret_cast<bool*>(_v) = _t->isSchedulerTwilightImmutable(); break;
        case 1660: *reinterpret_cast<bool*>(_v) = _t->schedulerCompleteSequences(); break;
        case 1661: *reinterpret_cast<bool*>(_v) = _t->isSchedulerCompleteSequencesImmutable(); break;
        case 1662: *reinterpret_cast<bool*>(_v) = _t->schedulerRepeatEverything(); break;
        case 1663: *reinterpret_cast<bool*>(_v) = _t->isSchedulerRepeatEverythingImmutable(); break;
        case 1664: *reinterpret_cast<bool*>(_v) = _t->schedulerRepeatSequences(); break;
        case 1665: *reinterpret_cast<bool*>(_v) = _t->isSchedulerRepeatSequencesImmutable(); break;
        case 1666: *reinterpret_cast<bool*>(_v) = _t->schedulerUntilTerminated(); break;
        case 1667: *reinterpret_cast<bool*>(_v) = _t->isSchedulerUntilTerminatedImmutable(); break;
        case 1668: *reinterpret_cast<bool*>(_v) = _t->schedulerUntil(); break;
        case 1669: *reinterpret_cast<bool*>(_v) = _t->isSchedulerUntilImmutable(); break;
        case 1670: *reinterpret_cast<QString*>(_v) = _t->schedulerUntilValue(); break;
        case 1671: *reinterpret_cast<bool*>(_v) = _t->isSchedulerUntilValueImmutable(); break;
        case 1672: *reinterpret_cast<uint*>(_v) = _t->schedulerExecutionSequencesLimit(); break;
        case 1673: *reinterpret_cast<bool*>(_v) = _t->isSchedulerExecutionSequencesLimitImmutable(); break;
        case 1674: *reinterpret_cast<bool*>(_v) = _t->analyzeRestartWithEkos(); break;
        case 1675: *reinterpret_cast<bool*>(_v) = _t->isAnalyzeRestartWithEkosImmutable(); break;
        case 1676: *reinterpret_cast<QString*>(_v) = _t->analyzeAlternativeDirectoryName(); break;
        case 1677: *reinterpret_cast<bool*>(_v) = _t->isAnalyzeAlternativeDirectoryNameImmutable(); break;
        case 1678: *reinterpret_cast<bool*>(_v) = _t->analyzeHFR(); break;
        case 1679: *reinterpret_cast<bool*>(_v) = _t->isAnalyzeHFRImmutable(); break;
        case 1680: *reinterpret_cast<bool*>(_v) = _t->analyzeNumCaptureStars(); break;
        case 1681: *reinterpret_cast<bool*>(_v) = _t->isAnalyzeNumCaptureStarsImmutable(); break;
        case 1682: *reinterpret_cast<bool*>(_v) = _t->analyzeMedian(); break;
        case 1683: *reinterpret_cast<bool*>(_v) = _t->isAnalyzeMedianImmutable(); break;
        case 1684: *reinterpret_cast<bool*>(_v) = _t->analyzeEccentricity(); break;
        case 1685: *reinterpret_cast<bool*>(_v) = _t->isAnalyzeEccentricityImmutable(); break;
        case 1686: *reinterpret_cast<bool*>(_v) = _t->analyzeTemperature(); break;
        case 1687: *reinterpret_cast<bool*>(_v) = _t->isAnalyzeTemperatureImmutable(); break;
        case 1688: *reinterpret_cast<bool*>(_v) = _t->focusPosition(); break;
        case 1689: *reinterpret_cast<bool*>(_v) = _t->isFocusPositionImmutable(); break;
        case 1690: *reinterpret_cast<bool*>(_v) = _t->analyzeNumStars(); break;
        case 1691: *reinterpret_cast<bool*>(_v) = _t->isAnalyzeNumStarsImmutable(); break;
        case 1692: *reinterpret_cast<bool*>(_v) = _t->analyzeSkyBg(); break;
        case 1693: *reinterpret_cast<bool*>(_v) = _t->isAnalyzeSkyBgImmutable(); break;
        case 1694: *reinterpret_cast<bool*>(_v) = _t->analyzeSNR(); break;
        case 1695: *reinterpret_cast<bool*>(_v) = _t->isAnalyzeSNRImmutable(); break;
        case 1696: *reinterpret_cast<bool*>(_v) = _t->analyzeRA(); break;
        case 1697: *reinterpret_cast<bool*>(_v) = _t->isAnalyzeRAImmutable(); break;
        case 1698: *reinterpret_cast<bool*>(_v) = _t->analyzeDEC(); break;
        case 1699: *reinterpret_cast<bool*>(_v) = _t->isAnalyzeDECImmutable(); break;
        case 1700: *reinterpret_cast<bool*>(_v) = _t->analyzeRAp(); break;
        case 1701: *reinterpret_cast<bool*>(_v) = _t->isAnalyzeRApImmutable(); break;
        case 1702: *reinterpret_cast<bool*>(_v) = _t->analyzeDECp(); break;
        case 1703: *reinterpret_cast<bool*>(_v) = _t->isAnalyzeDECpImmutable(); break;
        case 1704: *reinterpret_cast<bool*>(_v) = _t->analyzeDrift(); break;
        case 1705: *reinterpret_cast<bool*>(_v) = _t->isAnalyzeDriftImmutable(); break;
        case 1706: *reinterpret_cast<bool*>(_v) = _t->analyzeRMS(); break;
        case 1707: *reinterpret_cast<bool*>(_v) = _t->isAnalyzeRMSImmutable(); break;
        case 1708: *reinterpret_cast<bool*>(_v) = _t->analyzeTargetDistance(); break;
        case 1709: *reinterpret_cast<bool*>(_v) = _t->isAnalyzeTargetDistanceImmutable(); break;
        case 1710: *reinterpret_cast<bool*>(_v) = _t->analyzeRMSC(); break;
        case 1711: *reinterpret_cast<bool*>(_v) = _t->isAnalyzeRMSCImmutable(); break;
        case 1712: *reinterpret_cast<bool*>(_v) = _t->analyzeMountRA(); break;
        case 1713: *reinterpret_cast<bool*>(_v) = _t->isAnalyzeMountRAImmutable(); break;
        case 1714: *reinterpret_cast<bool*>(_v) = _t->analyzeMountDEC(); break;
        case 1715: *reinterpret_cast<bool*>(_v) = _t->isAnalyzeMountDECImmutable(); break;
        case 1716: *reinterpret_cast<bool*>(_v) = _t->analyzeMountHA(); break;
        case 1717: *reinterpret_cast<bool*>(_v) = _t->isAnalyzeMountHAImmutable(); break;
        case 1718: *reinterpret_cast<bool*>(_v) = _t->analyzeAz(); break;
        case 1719: *reinterpret_cast<bool*>(_v) = _t->isAnalyzeAzImmutable(); break;
        case 1720: *reinterpret_cast<bool*>(_v) = _t->analyzeAlt(); break;
        case 1721: *reinterpret_cast<bool*>(_v) = _t->isAnalyzeAltImmutable(); break;
        case 1722: *reinterpret_cast<bool*>(_v) = _t->analyzePierSide(); break;
        case 1723: *reinterpret_cast<bool*>(_v) = _t->isAnalyzePierSideImmutable(); break;
        case 1724: *reinterpret_cast<QString*>(_v) = _t->analyzeStatsYAxis(); break;
        case 1725: *reinterpret_cast<bool*>(_v) = _t->isAnalyzeStatsYAxisImmutable(); break;
        case 1726: *reinterpret_cast<QString*>(_v) = _t->lastServer(); break;
        case 1727: *reinterpret_cast<bool*>(_v) = _t->isLastServerImmutable(); break;
        case 1728: *reinterpret_cast<uint*>(_v) = _t->lastServerPort(); break;
        case 1729: *reinterpret_cast<bool*>(_v) = _t->isLastServerPortImmutable(); break;
        case 1730: *reinterpret_cast<uint*>(_v) = _t->lastWebManagerPort(); break;
        case 1731: *reinterpret_cast<bool*>(_v) = _t->isLastWebManagerPortImmutable(); break;
        case 1732: *reinterpret_cast<uint*>(_v) = _t->hIPSMemoryCache(); break;
        case 1733: *reinterpret_cast<bool*>(_v) = _t->isHIPSMemoryCacheImmutable(); break;
        case 1734: *reinterpret_cast<uint*>(_v) = _t->hIPSNetCache(); break;
        case 1735: *reinterpret_cast<bool*>(_v) = _t->isHIPSNetCacheImmutable(); break;
        case 1736: *reinterpret_cast<QString*>(_v) = _t->hIPSSource(); break;
        case 1737: *reinterpret_cast<bool*>(_v) = _t->isHIPSSourceImmutable(); break;
        case 1738: *reinterpret_cast<bool*>(_v) = _t->hIPSBiLinearInterpolation(); break;
        case 1739: *reinterpret_cast<bool*>(_v) = _t->isHIPSBiLinearInterpolationImmutable(); break;
        case 1740: *reinterpret_cast<bool*>(_v) = _t->hIPSShowGrid(); break;
        case 1741: *reinterpret_cast<bool*>(_v) = _t->isHIPSShowGridImmutable(); break;
        case 1742: *reinterpret_cast<bool*>(_v) = _t->hIPSPanning(); break;
        case 1743: *reinterpret_cast<bool*>(_v) = _t->isHIPSPanningImmutable(); break;
        case 1744: *reinterpret_cast<bool*>(_v) = _t->showHIPS(); break;
        case 1745: *reinterpret_cast<bool*>(_v) = _t->isShowHIPSImmutable(); break;
        case 1746: *reinterpret_cast<bool*>(_v) = _t->hIPSUseOfflineSource(); break;
        case 1747: *reinterpret_cast<bool*>(_v) = _t->isHIPSUseOfflineSourceImmutable(); break;
        case 1748: *reinterpret_cast<QString*>(_v) = _t->hIPSOfflinePath(); break;
        case 1749: *reinterpret_cast<bool*>(_v) = _t->isHIPSOfflinePathImmutable(); break;
        case 1750: *reinterpret_cast<QString*>(_v) = _t->terrainSource(); break;
        case 1751: *reinterpret_cast<bool*>(_v) = _t->isTerrainSourceImmutable(); break;
        case 1752: *reinterpret_cast<int*>(_v) = _t->terrainSourceCorrectAz(); break;
        case 1753: *reinterpret_cast<bool*>(_v) = _t->isTerrainSourceCorrectAzImmutable(); break;
        case 1754: *reinterpret_cast<int*>(_v) = _t->terrainSourceCorrectAlt(); break;
        case 1755: *reinterpret_cast<bool*>(_v) = _t->isTerrainSourceCorrectAltImmutable(); break;
        case 1756: *reinterpret_cast<int*>(_v) = _t->terrainDownsampling(); break;
        case 1757: *reinterpret_cast<bool*>(_v) = _t->isTerrainDownsamplingImmutable(); break;
        case 1758: *reinterpret_cast<bool*>(_v) = _t->terrainPanning(); break;
        case 1759: *reinterpret_cast<bool*>(_v) = _t->isTerrainPanningImmutable(); break;
        case 1760: *reinterpret_cast<bool*>(_v) = _t->showTerrain(); break;
        case 1761: *reinterpret_cast<bool*>(_v) = _t->isShowTerrainImmutable(); break;
        case 1762: *reinterpret_cast<bool*>(_v) = _t->terrainSkipSpeedup(); break;
        case 1763: *reinterpret_cast<bool*>(_v) = _t->isTerrainSkipSpeedupImmutable(); break;
        case 1764: *reinterpret_cast<bool*>(_v) = _t->terrainTransparencySpeedup(); break;
        case 1765: *reinterpret_cast<bool*>(_v) = _t->isTerrainTransparencySpeedupImmutable(); break;
        case 1766: *reinterpret_cast<bool*>(_v) = _t->terrainSmoothPixels(); break;
        case 1767: *reinterpret_cast<bool*>(_v) = _t->isTerrainSmoothPixelsImmutable(); break;
        case 1768: *reinterpret_cast<bool*>(_v) = _t->showImageOverlays(); break;
        case 1769: *reinterpret_cast<bool*>(_v) = _t->isShowImageOverlaysImmutable(); break;
        case 1770: *reinterpret_cast<bool*>(_v) = _t->showImageOverlaysBelowCatalogs(); break;
        case 1771: *reinterpret_cast<bool*>(_v) = _t->isShowImageOverlaysBelowCatalogsImmutable(); break;
        case 1772: *reinterpret_cast<bool*>(_v) = _t->showSelectedImageOverlay(); break;
        case 1773: *reinterpret_cast<bool*>(_v) = _t->isShowSelectedImageOverlayImmutable(); break;
        case 1774: *reinterpret_cast<int*>(_v) = _t->imageOverlayMaxDimension(); break;
        case 1775: *reinterpret_cast<bool*>(_v) = _t->isImageOverlayMaxDimensionImmutable(); break;
        case 1776: *reinterpret_cast<int*>(_v) = _t->imageOverlayTimeout(); break;
        case 1777: *reinterpret_cast<bool*>(_v) = _t->isImageOverlayTimeoutImmutable(); break;
        case 1778: *reinterpret_cast<double*>(_v) = _t->imageOverlayDefaultScale(); break;
        case 1779: *reinterpret_cast<bool*>(_v) = _t->isImageOverlayDefaultScaleImmutable(); break;
        case 1780: *reinterpret_cast<QString*>(_v) = _t->defaultObservatoryWeatherSource(); break;
        case 1781: *reinterpret_cast<bool*>(_v) = _t->isDefaultObservatoryWeatherSourceImmutable(); break;
        case 1782: *reinterpret_cast<bool*>(_v) = _t->warningActionsActive(); break;
        case 1783: *reinterpret_cast<bool*>(_v) = _t->isWarningActionsActiveImmutable(); break;
        case 1784: *reinterpret_cast<bool*>(_v) = _t->alertActionsActive(); break;
        case 1785: *reinterpret_cast<bool*>(_v) = _t->isAlertActionsActiveImmutable(); break;
        case 1786: *reinterpret_cast<bool*>(_v) = _t->weatherWarningCloseDome(); break;
        case 1787: *reinterpret_cast<bool*>(_v) = _t->isWeatherWarningCloseDomeImmutable(); break;
        case 1788: *reinterpret_cast<bool*>(_v) = _t->weatherWarningCloseShutter(); break;
        case 1789: *reinterpret_cast<bool*>(_v) = _t->isWeatherWarningCloseShutterImmutable(); break;
        case 1790: *reinterpret_cast<bool*>(_v) = _t->weatherWarningStopScheduler(); break;
        case 1791: *reinterpret_cast<bool*>(_v) = _t->isWeatherWarningStopSchedulerImmutable(); break;
        case 1792: *reinterpret_cast<uint*>(_v) = _t->weatherWarningDelay(); break;
        case 1793: *reinterpret_cast<bool*>(_v) = _t->isWeatherWarningDelayImmutable(); break;
        case 1794: *reinterpret_cast<bool*>(_v) = _t->weatherAlertCloseDome(); break;
        case 1795: *reinterpret_cast<bool*>(_v) = _t->isWeatherAlertCloseDomeImmutable(); break;
        case 1796: *reinterpret_cast<bool*>(_v) = _t->weatherAlertCloseShutter(); break;
        case 1797: *reinterpret_cast<bool*>(_v) = _t->isWeatherAlertCloseShutterImmutable(); break;
        case 1798: *reinterpret_cast<bool*>(_v) = _t->weatherAlertStopScheduler(); break;
        case 1799: *reinterpret_cast<bool*>(_v) = _t->isWeatherAlertStopSchedulerImmutable(); break;
        case 1800: *reinterpret_cast<uint*>(_v) = _t->weatherAlertDelay(); break;
        case 1801: *reinterpret_cast<bool*>(_v) = _t->isWeatherAlertDelayImmutable(); break;
        case 1802: *reinterpret_cast<bool*>(_v) = _t->observatoryStatusUseDome(); break;
        case 1803: *reinterpret_cast<bool*>(_v) = _t->isObservatoryStatusUseDomeImmutable(); break;
        case 1804: *reinterpret_cast<bool*>(_v) = _t->observatoryStatusUseShutter(); break;
        case 1805: *reinterpret_cast<bool*>(_v) = _t->isObservatoryStatusUseShutterImmutable(); break;
        case 1806: *reinterpret_cast<bool*>(_v) = _t->observatoryStatusUseWeather(); break;
        case 1807: *reinterpret_cast<bool*>(_v) = _t->isObservatoryStatusUseWeatherImmutable(); break;
        case 1808: *reinterpret_cast<bool*>(_v) = _t->weatherAutoScaleValues(); break;
        case 1809: *reinterpret_cast<bool*>(_v) = _t->isWeatherAutoScaleValuesImmutable(); break;
        case 1810: *reinterpret_cast<QString*>(_v) = _t->aSTAPExecutable(); break;
        case 1811: *reinterpret_cast<bool*>(_v) = _t->isASTAPExecutableImmutable(); break;
        case 1812: *reinterpret_cast<bool*>(_v) = _t->aSTAPDownSample(); break;
        case 1813: *reinterpret_cast<bool*>(_v) = _t->isASTAPDownSampleImmutable(); break;
        case 1814: *reinterpret_cast<double*>(_v) = _t->aSTAPDownSampleValue(); break;
        case 1815: *reinterpret_cast<bool*>(_v) = _t->isASTAPDownSampleValueImmutable(); break;
        case 1816: *reinterpret_cast<bool*>(_v) = _t->aSTAPSearchRadius(); break;
        case 1817: *reinterpret_cast<bool*>(_v) = _t->isASTAPSearchRadiusImmutable(); break;
        case 1818: *reinterpret_cast<double*>(_v) = _t->aSTAPSearchRadiusValue(); break;
        case 1819: *reinterpret_cast<bool*>(_v) = _t->isASTAPSearchRadiusValueImmutable(); break;
        case 1820: *reinterpret_cast<bool*>(_v) = _t->aSTAPUpdateFITS(); break;
        case 1821: *reinterpret_cast<bool*>(_v) = _t->isASTAPUpdateFITSImmutable(); break;
        case 1822: *reinterpret_cast<bool*>(_v) = _t->aSTAPLargeSearchWindow(); break;
        case 1823: *reinterpret_cast<bool*>(_v) = _t->isASTAPLargeSearchWindowImmutable(); break;
        case 1824: *reinterpret_cast<bool*>(_v) = _t->mosaicTransparencyAuto(); break;
        case 1825: *reinterpret_cast<bool*>(_v) = _t->isMosaicTransparencyAutoImmutable(); break;
        case 1826: *reinterpret_cast<double*>(_v) = _t->mosaicTransparencyLevel(); break;
        case 1827: *reinterpret_cast<bool*>(_v) = _t->isMosaicTransparencyLevelImmutable(); break;
        case 1828: *reinterpret_cast<bool*>(_v) = _t->mCPEnabled(); break;
        case 1829: *reinterpret_cast<bool*>(_v) = _t->isMCPEnabledImmutable(); break;
        case 1830: *reinterpret_cast<uint*>(_v) = _t->mCPPort(); break;
        case 1831: *reinterpret_cast<bool*>(_v) = _t->isMCPPortImmutable(); break;
        case 1832: *reinterpret_cast<bool*>(_v) = _t->mCPReadOnlyMode(); break;
        case 1833: *reinterpret_cast<bool*>(_v) = _t->isMCPReadOnlyModeImmutable(); break;
        case 1834: *reinterpret_cast<QStringList*>(_v) = _t->mCPDisabledTools(); break;
        case 1835: *reinterpret_cast<bool*>(_v) = _t->isMCPDisabledToolsImmutable(); break;
        default: break;
        }
    }
    if (_c == QMetaObject::WriteProperty) {
        void *_v = _a[0];
        switch (_id) {
        case 0: _t->setPositionTimeBox(*reinterpret_cast<QPoint*>(_v)); break;
        case 2: _t->setPositionFocusBox(*reinterpret_cast<QPoint*>(_v)); break;
        case 4: _t->setPositionGeoBox(*reinterpret_cast<QPoint*>(_v)); break;
        case 6: _t->setShadeTimeBox(*reinterpret_cast<bool*>(_v)); break;
        case 8: _t->setShadeFocusBox(*reinterpret_cast<bool*>(_v)); break;
        case 10: _t->setShadeGeoBox(*reinterpret_cast<bool*>(_v)); break;
        case 12: _t->setShowInfoBoxes(*reinterpret_cast<bool*>(_v)); break;
        case 14: _t->setShowTimeBox(*reinterpret_cast<bool*>(_v)); break;
        case 16: _t->setShowFocusBox(*reinterpret_cast<bool*>(_v)); break;
        case 18: _t->setShowGeoBox(*reinterpret_cast<bool*>(_v)); break;
        case 20: _t->setStickyTimeBox(*reinterpret_cast<int*>(_v)); break;
        case 22: _t->setStickyFocusBox(*reinterpret_cast<int*>(_v)); break;
        case 24: _t->setStickyGeoBox(*reinterpret_cast<int*>(_v)); break;
        case 26: _t->setShowStatusBar(*reinterpret_cast<bool*>(_v)); break;
        case 28: _t->setShowAltAzField(*reinterpret_cast<bool*>(_v)); break;
        case 30: _t->setShowRADecField(*reinterpret_cast<bool*>(_v)); break;
        case 32: _t->setShowJ2000RADecField(*reinterpret_cast<bool*>(_v)); break;
        case 34: _t->setShowSensorFOV(*reinterpret_cast<bool*>(_v)); break;
        case 36: _t->setWindowWidth(*reinterpret_cast<uint*>(_v)); break;
        case 38: _t->setWindowHeight(*reinterpret_cast<uint*>(_v)); break;
        case 40: _t->setKStarsGeometry(*reinterpret_cast<QString*>(_v)); break;
        case 42: _t->setRunStartupWizard(*reinterpret_cast<bool*>(_v)); break;
        case 44: _t->setCurrentTheme(*reinterpret_cast<QString*>(_v)); break;
        case 46: _t->setCatalogFile(*reinterpret_cast<QStringList*>(_v)); break;
        case 48: _t->setShowCatalog(*reinterpret_cast<QList<int>*>(_v)); break;
        case 50: _t->setShowCatalogNames(*reinterpret_cast<QStringList*>(_v)); break;
        case 52: _t->setResolveNamesOnline(*reinterpret_cast<bool*>(_v)); break;
        case 54: _t->setDSOCachePercentage(*reinterpret_cast<uint*>(_v)); break;
        case 56: _t->setDSOMinZoomFactor(*reinterpret_cast<uint*>(_v)); break;
        case 58: _t->setDSOCatalogFilename(*reinterpret_cast<QString*>(_v)); break;
        case 60: _t->setDSODefaultCatalogFilename(*reinterpret_cast<QString*>(_v)); break;
        case 62: _t->setINDIWindowWidth(*reinterpret_cast<uint*>(_v)); break;
        case 64: _t->setINDIWindowHeight(*reinterpret_cast<uint*>(_v)); break;
        case 66: _t->setINDIWindowGeometry(*reinterpret_cast<QString*>(_v)); break;
        case 68: _t->setUseGeographicUpdate(*reinterpret_cast<bool*>(_v)); break;
        case 70: _t->setUseTimeUpdate(*reinterpret_cast<bool*>(_v)); break;
        case 72: _t->setIndependentWindowINDI(*reinterpret_cast<bool*>(_v)); break;
        case 74: _t->setShowTargetCrosshair(*reinterpret_cast<bool*>(_v)); break;
        case 76: _t->setShowINDIMessages(*reinterpret_cast<bool*>(_v)); break;
        case 78: _t->setShowINDIwindowInitially(*reinterpret_cast<bool*>(_v)); break;
        case 80: _t->setMaxFocusFrameFiles(*reinterpret_cast<int*>(_v)); break;
        case 82: _t->setMessageNotificationINDI(*reinterpret_cast<bool*>(_v)); break;
        case 84: _t->setTimeSource(*reinterpret_cast<QString*>(_v)); break;
        case 86: _t->setLocationSource(*reinterpret_cast<QString*>(_v)); break;
        case 88: _t->setUseExternalSkyMap(*reinterpret_cast<bool*>(_v)); break;
        case 90: _t->setFitsDir(*reinterpret_cast<QString*>(_v)); break;
        case 92: _t->setServerTransferBufferSize(*reinterpret_cast<int*>(_v)); break;
        case 94: _t->setServerPortStart(*reinterpret_cast<int*>(_v)); break;
        case 96: _t->setServerPortEnd(*reinterpret_cast<int*>(_v)); break;
        case 98: _t->setIndiServer(*reinterpret_cast<QString*>(_v)); break;
        case 100: _t->setIndiServerIsInternal(*reinterpret_cast<bool*>(_v)); break;
        case 102: _t->setIndiDriversDir(*reinterpret_cast<QString*>(_v)); break;
        case 104: _t->setIndiDriversAreInternal(*reinterpret_cast<bool*>(_v)); break;
        case 106: _t->setStreamWindowWidth(*reinterpret_cast<uint*>(_v)); break;
        case 108: _t->setStreamWindowHeight(*reinterpret_cast<uint*>(_v)); break;
        case 110: _t->setINDIMountLogging(*reinterpret_cast<bool*>(_v)); break;
        case 112: _t->setINDIFocuserLogging(*reinterpret_cast<bool*>(_v)); break;
        case 114: _t->setINDICCDLogging(*reinterpret_cast<bool*>(_v)); break;
        case 116: _t->setINDIFilterWheelLogging(*reinterpret_cast<bool*>(_v)); break;
        case 118: _t->setINDIDomeLogging(*reinterpret_cast<bool*>(_v)); break;
        case 120: _t->setINDIDetectorLogging(*reinterpret_cast<bool*>(_v)); break;
        case 122: _t->setINDIWeatherLogging(*reinterpret_cast<bool*>(_v)); break;
        case 124: _t->setINDIAuxiliaryLogging(*reinterpret_cast<bool*>(_v)); break;
        case 126: _t->setINDIRotatorLogging(*reinterpret_cast<bool*>(_v)); break;
        case 128: _t->setINDIGPSLogging(*reinterpret_cast<bool*>(_v)); break;
        case 130: _t->setINDIAOLogging(*reinterpret_cast<bool*>(_v)); break;
        case 132: _t->setCityName(*reinterpret_cast<QString*>(_v)); break;
        case 134: _t->setProvinceName(*reinterpret_cast<QString*>(_v)); break;
        case 136: _t->setCountryName(*reinterpret_cast<QString*>(_v)); break;
        case 138: _t->setLongitude(*reinterpret_cast<double*>(_v)); break;
        case 140: _t->setLatitude(*reinterpret_cast<double*>(_v)); break;
        case 142: _t->setElevation(*reinterpret_cast<double*>(_v)); break;
        case 144: _t->setTimeZone(*reinterpret_cast<double*>(_v)); break;
        case 146: _t->setDST(*reinterpret_cast<QString*>(_v)); break;
        case 148: _t->setUseAnimatedSlewing(*reinterpret_cast<bool*>(_v)); break;
        case 150: _t->setLeftClickSelectsObject(*reinterpret_cast<bool*>(_v)); break;
        case 152: _t->setDefaultCursor(*reinterpret_cast<uint*>(_v)); break;
        case 154: _t->setFOVNames(*reinterpret_cast<QStringList*>(_v)); break;
        case 156: _t->setFadePlanetTrails(*reinterpret_cast<bool*>(_v)); break;
        case 158: _t->setFocusRA(*reinterpret_cast<double*>(_v)); break;
        case 160: _t->setFocusDec(*reinterpret_cast<double*>(_v)); break;
        case 162: _t->setFocusObject(*reinterpret_cast<QString*>(_v)); break;
        case 164: _t->setIsTracking(*reinterpret_cast<bool*>(_v)); break;
        case 166: _t->setHideOnSlew(*reinterpret_cast<bool*>(_v)); break;
        case 168: _t->setHideCBounds(*reinterpret_cast<bool*>(_v)); break;
        case 170: _t->setHideCLines(*reinterpret_cast<bool*>(_v)); break;
        case 172: _t->setSkyCulture(*reinterpret_cast<QString*>(_v)); break;
        case 174: _t->setHideCNames(*reinterpret_cast<bool*>(_v)); break;
        case 176: _t->setHideGrids(*reinterpret_cast<bool*>(_v)); break;
        case 178: _t->setHideMilkyWay(*reinterpret_cast<bool*>(_v)); break;
        case 180: _t->setHideOther(*reinterpret_cast<bool*>(_v)); break;
        case 182: _t->setHidePlanets(*reinterpret_cast<bool*>(_v)); break;
        case 184: _t->setHideStars(*reinterpret_cast<bool*>(_v)); break;
        case 186: _t->setHideLabels(*reinterpret_cast<bool*>(_v)); break;
        case 188: _t->setShowAsteroids(*reinterpret_cast<bool*>(_v)); break;
        case 190: _t->setShowAsteroidNames(*reinterpret_cast<bool*>(_v)); break;
        case 192: _t->setOrbitalElementsAutoUpdate(*reinterpret_cast<bool*>(_v)); break;
        case 194: _t->setShowComets(*reinterpret_cast<bool*>(_v)); break;
        case 196: _t->setShowCometComas(*reinterpret_cast<bool*>(_v)); break;
        case 198: _t->setShowCometNames(*reinterpret_cast<bool*>(_v)); break;
        case 200: _t->setShowSupernovae(*reinterpret_cast<bool*>(_v)); break;
        case 202: _t->setShowSupernovaNames(*reinterpret_cast<bool*>(_v)); break;
        case 204: _t->setMagnitudeLimitShowSupernovae(*reinterpret_cast<double*>(_v)); break;
        case 206: _t->setSupernovaDetectionAge(*reinterpret_cast<double*>(_v)); break;
        case 208: _t->setSupernovaDownloadUrl(*reinterpret_cast<QString*>(_v)); break;
        case 210: _t->setLimitSupernovaeByZoom(*reinterpret_cast<bool*>(_v)); break;
        case 212: _t->setSupernovaeHostOnly(*reinterpret_cast<bool*>(_v)); break;
        case 214: _t->setSupernovaeClassifiedOnly(*reinterpret_cast<bool*>(_v)); break;
        case 216: _t->setShowSupernovaAlerts(*reinterpret_cast<bool*>(_v)); break;
        case 218: _t->setMagnitudeLimitAlertSupernovae(*reinterpret_cast<double*>(_v)); break;
        case 220: _t->setShowCBounds(*reinterpret_cast<bool*>(_v)); break;
        case 222: _t->setShowHighlightedCBound(*reinterpret_cast<bool*>(_v)); break;
        case 224: _t->setShowCLines(*reinterpret_cast<bool*>(_v)); break;
        case 226: _t->setShowConstellationArt(*reinterpret_cast<bool*>(_v)); break;
        case 228: _t->setShowCNames(*reinterpret_cast<bool*>(_v)); break;
        case 230: _t->setShowDeepSky(*reinterpret_cast<bool*>(_v)); break;
        case 232: _t->setShowEcliptic(*reinterpret_cast<bool*>(_v)); break;
        case 234: _t->setShowEquator(*reinterpret_cast<bool*>(_v)); break;
        case 236: _t->setAutoSelectGrid(*reinterpret_cast<bool*>(_v)); break;
        case 238: _t->setShowEquatorialGrid(*reinterpret_cast<bool*>(_v)); break;
        case 240: _t->setShowHorizontalGrid(*reinterpret_cast<bool*>(_v)); break;
        case 242: _t->setShowLocalMeridian(*reinterpret_cast<bool*>(_v)); break;
        case 244: _t->setShowGround(*reinterpret_cast<bool*>(_v)); break;
        case 246: _t->setShowHorizon(*reinterpret_cast<bool*>(_v)); break;
        case 248: _t->setShowFlags(*reinterpret_cast<bool*>(_v)); break;
        case 250: _t->setSimulateDaytime(*reinterpret_cast<bool*>(_v)); break;
        case 252: _t->setShowOther(*reinterpret_cast<bool*>(_v)); break;
        case 254: _t->setShowMilkyWay(*reinterpret_cast<bool*>(_v)); break;
        case 256: _t->setFillMilkyWay(*reinterpret_cast<bool*>(_v)); break;
        case 258: _t->setShowSolarSystem(*reinterpret_cast<bool*>(_v)); break;
        case 260: _t->setShowPlanetImages(*reinterpret_cast<bool*>(_v)); break;
        case 262: _t->setShowPlanetNames(*reinterpret_cast<bool*>(_v)); break;
        case 264: _t->setShowSun(*reinterpret_cast<bool*>(_v)); break;
        case 266: _t->setSunScale(*reinterpret_cast<double*>(_v)); break;
        case 268: _t->setShowMoon(*reinterpret_cast<bool*>(_v)); break;
        case 270: _t->setMoonScale(*reinterpret_cast<double*>(_v)); break;
        case 272: _t->setShowMercury(*reinterpret_cast<bool*>(_v)); break;
        case 274: _t->setShowVenus(*reinterpret_cast<bool*>(_v)); break;
        case 276: _t->setShowMars(*reinterpret_cast<bool*>(_v)); break;
        case 278: _t->setShowJupiter(*reinterpret_cast<bool*>(_v)); break;
        case 280: _t->setShowSaturn(*reinterpret_cast<bool*>(_v)); break;
        case 282: _t->setShowUranus(*reinterpret_cast<bool*>(_v)); break;
        case 284: _t->setShowNeptune(*reinterpret_cast<bool*>(_v)); break;
        case 286: _t->setShowPluto(*reinterpret_cast<bool*>(_v)); break;
        case 288: _t->setShowStars(*reinterpret_cast<bool*>(_v)); break;
        case 290: _t->setShowStarMagnitudes(*reinterpret_cast<bool*>(_v)); break;
        case 292: _t->setShowStarsOverHIPS(*reinterpret_cast<bool*>(_v)); break;
        case 294: _t->setShowStarNames(*reinterpret_cast<bool*>(_v)); break;
        case 296: _t->setShowDeepSkyMagnitudes(*reinterpret_cast<bool*>(_v)); break;
        case 298: _t->setShowDeepSkyNames(*reinterpret_cast<bool*>(_v)); break;
        case 300: _t->setShowMosaicPanel(*reinterpret_cast<bool*>(_v)); break;
        case 302: _t->setSlewTimeScale(*reinterpret_cast<double*>(_v)); break;
        case 304: _t->setBoxBGMode(*reinterpret_cast<uint*>(_v)); break;
        case 306: _t->setProjection(*reinterpret_cast<uint*>(_v)); break;
        case 308: _t->setUseAbbrevConstellNames(*reinterpret_cast<bool*>(_v)); break;
        case 310: _t->setUseLatinConstellNames(*reinterpret_cast<bool*>(_v)); break;
        case 312: _t->setUseLocalConstellNames(*reinterpret_cast<bool*>(_v)); break;
        case 314: _t->setUseAltAz(*reinterpret_cast<bool*>(_v)); break;
        case 316: _t->setUseAutoLabel(*reinterpret_cast<bool*>(_v)); break;
        case 318: _t->setUseAutoTrail(*reinterpret_cast<bool*>(_v)); break;
        case 320: _t->setUseHoverLabel(*reinterpret_cast<bool*>(_v)); break;
        case 322: _t->setUseRefraction(*reinterpret_cast<bool*>(_v)); break;
        case 324: _t->setUseRelativistic(*reinterpret_cast<bool*>(_v)); break;
        case 326: _t->setUseAntialias(*reinterpret_cast<bool*>(_v)); break;
        case 328: _t->setZoomFactor(*reinterpret_cast<double*>(_v)); break;
        case 330: _t->setSkyRotation(*reinterpret_cast<double*>(_v)); break;
        case 332: _t->setMirrorSkyMap(*reinterpret_cast<bool*>(_v)); break;
        case 334: _t->setErectObserverCorrection(*reinterpret_cast<int*>(_v)); break;
        case 336: _t->setZoomScrollFactor(*reinterpret_cast<double*>(_v)); break;
        case 338: _t->setMagLimitAsteroid(*reinterpret_cast<double*>(_v)); break;
        case 340: _t->setMagLimitAsteroidDownload(*reinterpret_cast<double*>(_v)); break;
        case 342: _t->setAsteroidLabelDensity(*reinterpret_cast<double*>(_v)); break;
        case 344: _t->setMagLimitDrawDeepSky(*reinterpret_cast<double*>(_v)); break;
        case 346: _t->setMagLimitDrawDeepSkyZoomOut(*reinterpret_cast<double*>(_v)); break;
        case 348: _t->setShowUnknownMagObjects(*reinterpret_cast<bool*>(_v)); break;
        case 350: _t->setShowInlineImages(*reinterpret_cast<bool*>(_v)); break;
        case 352: _t->setStarDensity(*reinterpret_cast<int*>(_v)); break;
        case 354: _t->setMagLimitHideStar(*reinterpret_cast<double*>(_v)); break;
        case 356: _t->setStarLabelDensity(*reinterpret_cast<double*>(_v)); break;
        case 358: _t->setDeepSkyLabelDensity(*reinterpret_cast<double*>(_v)); break;
        case 360: _t->setDeepSkyLongLabels(*reinterpret_cast<bool*>(_v)); break;
        case 362: _t->setLabelFontScaling(*reinterpret_cast<int*>(_v)); break;
        case 364: _t->setMaxRadCometName(*reinterpret_cast<double*>(_v)); break;
        case 366: _t->setUseGL(*reinterpret_cast<bool*>(_v)); break;
        case 368: _t->setRunClock(*reinterpret_cast<bool*>(_v)); break;
        case 370: _t->setImagingPlannerAcceptOpenCluster(*reinterpret_cast<bool*>(_v)); break;
        case 372: _t->setImagingPlannerAcceptNebula(*reinterpret_cast<bool*>(_v)); break;
        case 374: _t->setImagingPlannerAcceptGlobularCluster(*reinterpret_cast<bool*>(_v)); break;
        case 376: _t->setImagingPlannerAcceptPlanetary(*reinterpret_cast<bool*>(_v)); break;
        case 378: _t->setImagingPlannerAcceptSupernovaRemnant(*reinterpret_cast<bool*>(_v)); break;
        case 380: _t->setImagingPlannerAcceptGalaxy(*reinterpret_cast<bool*>(_v)); break;
        case 382: _t->setImagingPlannerAcceptGalaxyCluster(*reinterpret_cast<bool*>(_v)); break;
        case 384: _t->setImagingPlannerAcceptDarkNebula(*reinterpret_cast<bool*>(_v)); break;
        case 386: _t->setImagingPlannerAcceptOther(*reinterpret_cast<bool*>(_v)); break;
        case 388: _t->setAstrobinAward(*reinterpret_cast<bool*>(_v)); break;
        case 390: _t->setAstrobinMinRadius(*reinterpret_cast<double*>(_v)); break;
        case 392: _t->setAstrobinMaxRadius(*reinterpret_cast<double*>(_v)); break;
        case 394: _t->setImagingPlannerUseArtificialHorizon(*reinterpret_cast<bool*>(_v)); break;
        case 396: _t->setImagingPlannerMinHours(*reinterpret_cast<double*>(_v)); break;
        case 398: _t->setImagingPlannerMinAltitude(*reinterpret_cast<double*>(_v)); break;
        case 400: _t->setImagingPlannerMinMoonSeparation(*reinterpret_cast<double*>(_v)); break;
        case 402: _t->setImagingPlannerMaxMoonAltitude(*reinterpret_cast<double*>(_v)); break;
        case 404: _t->setImagingPlannerShowPicked(*reinterpret_cast<bool*>(_v)); break;
        case 406: _t->setImagingPlannerShowNotPicked(*reinterpret_cast<bool*>(_v)); break;
        case 408: _t->setImagingPlannerDontCarePicked(*reinterpret_cast<bool*>(_v)); break;
        case 410: _t->setImagingPlannerShowKeyword(*reinterpret_cast<bool*>(_v)); break;
        case 412: _t->setImagingPlannerShowNotKeyword(*reinterpret_cast<bool*>(_v)); break;
        case 414: _t->setImagingPlannerDontCareKeyword(*reinterpret_cast<bool*>(_v)); break;
        case 416: _t->setImagingPlannerKeyword(*reinterpret_cast<QString*>(_v)); break;
        case 418: _t->setImagingPlannerShowImaged(*reinterpret_cast<bool*>(_v)); break;
        case 420: _t->setImagingPlannerShowNotImaged(*reinterpret_cast<bool*>(_v)); break;
        case 422: _t->setImagingPlannerDontCareImaged(*reinterpret_cast<bool*>(_v)); break;
        case 424: _t->setImagingPlannerShowAdded(*reinterpret_cast<bool*>(_v)); break;
        case 426: _t->setImagingPlannerShowNotAdded(*reinterpret_cast<bool*>(_v)); break;
        case 428: _t->setImagingPlannerDontCareAdded(*reinterpret_cast<bool*>(_v)); break;
        case 430: _t->setImagingPlannerShowIgnored(*reinterpret_cast<bool*>(_v)); break;
        case 432: _t->setImagingPlannerShowNotIgnored(*reinterpret_cast<bool*>(_v)); break;
        case 434: _t->setImagingPlannerDontCareIgnored(*reinterpret_cast<bool*>(_v)); break;
        case 436: _t->setImagingPlannerHideAstrobinDetails(*reinterpret_cast<bool*>(_v)); break;
        case 438: _t->setImagingPlannerHideFilters(*reinterpret_cast<bool*>(_v)); break;
        case 440: _t->setImagingPlannerHideImage(*reinterpret_cast<bool*>(_v)); break;
        case 442: _t->setImagingPlannerHideAltitudeGraph(*reinterpret_cast<bool*>(_v)); break;
        case 444: _t->setImagingPlannerCatalogPath(*reinterpret_cast<QString*>(_v)); break;
        case 446: _t->setImagingPlannerCenterOnSkyMap(*reinterpret_cast<bool*>(_v)); break;
        case 448: _t->setImagingPlannerIndependentWindow(*reinterpret_cast<bool*>(_v)); break;
        case 450: _t->setImagingPlannerStartSolvingImmediately(*reinterpret_cast<bool*>(_v)); break;
        case 452: _t->setObsListSymbol(*reinterpret_cast<bool*>(_v)); break;
        case 454: _t->setObsListText(*reinterpret_cast<bool*>(_v)); break;
        case 456: _t->setObsListPreferDSS(*reinterpret_cast<bool*>(_v)); break;
        case 458: _t->setObsListPreferSDSS(*reinterpret_cast<bool*>(_v)); break;
        case 460: _t->setObsListDemoteHole(*reinterpret_cast<bool*>(_v)); break;
        case 462: _t->setObsListHoleSize(*reinterpret_cast<double*>(_v)); break;
        case 464: _t->setObsListCoverage(*reinterpret_cast<double*>(_v)); break;
        case 466: _t->setColorSchemeFile(*reinterpret_cast<QString*>(_v)); break;
        case 468: _t->setStarColorMode(*reinterpret_cast<uint*>(_v)); break;
        case 470: _t->setStarColorIntensity(*reinterpret_cast<uint*>(_v)); break;
        case 472: _t->setDomeSlitInverted(*reinterpret_cast<bool*>(_v)); break;
        case 474: _t->setAngularRulerColor(*reinterpret_cast<QString*>(_v)); break;
        case 476: _t->setBoxBGColor(*reinterpret_cast<QString*>(_v)); break;
        case 478: _t->setBoxGrabColor(*reinterpret_cast<QString*>(_v)); break;
        case 480: _t->setBoxTextColor(*reinterpret_cast<QString*>(_v)); break;
        case 482: _t->setCBoundColor(*reinterpret_cast<QString*>(_v)); break;
        case 484: _t->setCBoundHighColor(*reinterpret_cast<QString*>(_v)); break;
        case 486: _t->setCLineColor(*reinterpret_cast<QString*>(_v)); break;
        case 488: _t->setCNameColor(*reinterpret_cast<QString*>(_v)); break;
        case 490: _t->setCompassColor(*reinterpret_cast<QString*>(_v)); break;
        case 492: _t->setEclipticColor(*reinterpret_cast<QString*>(_v)); break;
        case 494: _t->setEquatorColor(*reinterpret_cast<QString*>(_v)); break;
        case 496: _t->setEquatorialGridColor(*reinterpret_cast<QString*>(_v)); break;
        case 498: _t->setHorizontalGridColor(*reinterpret_cast<QString*>(_v)); break;
        case 500: _t->setSpecialObjectColor(*reinterpret_cast<QString*>(_v)); break;
        case 502: _t->setHorizonColor(*reinterpret_cast<QString*>(_v)); break;
        case 504: _t->setLocalMeridianColor(*reinterpret_cast<QString*>(_v)); break;
        case 506: _t->setMilkyWayWColor(*reinterpret_cast<QString*>(_v)); break;
        case 508: _t->setStarNameColor(*reinterpret_cast<QString*>(_v)); break;
        case 510: _t->setDeepSkyNameColor(*reinterpret_cast<QString*>(_v)); break;
        case 512: _t->setPlanetNameColor(*reinterpret_cast<QString*>(_v)); break;
        case 514: _t->setPlanetTrailColor(*reinterpret_cast<QString*>(_v)); break;
        case 516: _t->setSkyColor(*reinterpret_cast<QString*>(_v)); break;
        case 518: _t->setSkyColorDaytime(*reinterpret_cast<QString*>(_v)); break;
        case 520: _t->setArtificialHorizonColor(*reinterpret_cast<QString*>(_v)); break;
        case 522: _t->setTelescopeTargetColor(*reinterpret_cast<QString*>(_v)); break;
        case 524: _t->setVisibleSatColor(*reinterpret_cast<QString*>(_v)); break;
        case 526: _t->setSatColor(*reinterpret_cast<QString*>(_v)); break;
        case 528: _t->setSatLabelColor(*reinterpret_cast<QString*>(_v)); break;
        case 530: _t->setSupernovaColor(*reinterpret_cast<QString*>(_v)); break;
        case 532: _t->setAsteroidColor(*reinterpret_cast<QString*>(_v)); break;
        case 534: _t->setUserLabelColor(*reinterpret_cast<QString*>(_v)); break;
        case 536: _t->setRAGuideColor(*reinterpret_cast<QString*>(_v)); break;
        case 538: _t->setDEGuideColor(*reinterpret_cast<QString*>(_v)); break;
        case 540: _t->setSolverFOVColor(*reinterpret_cast<QString*>(_v)); break;
        case 542: _t->setXplanetIsInternal(*reinterpret_cast<bool*>(_v)); break;
        case 544: _t->setXplanetPath(*reinterpret_cast<QString*>(_v)); break;
        case 546: _t->setXplanetUseFIFO(*reinterpret_cast<bool*>(_v)); break;
        case 548: _t->setXplanetTimeout(*reinterpret_cast<uint*>(_v)); break;
        case 550: _t->setXplanetAnimationDelay(*reinterpret_cast<uint*>(_v)); break;
        case 552: _t->setXplanetWidth(*reinterpret_cast<uint*>(_v)); break;
        case 554: _t->setXplanetHeight(*reinterpret_cast<uint*>(_v)); break;
        case 556: _t->setXplanetLabel(*reinterpret_cast<bool*>(_v)); break;
        case 558: _t->setXplanetLabelLocalTime(*reinterpret_cast<bool*>(_v)); break;
        case 560: _t->setXplanetLabelGMT(*reinterpret_cast<bool*>(_v)); break;
        case 562: _t->setXplanetLabelString(*reinterpret_cast<QString*>(_v)); break;
        case 564: _t->setXplanetFontSize(*reinterpret_cast<QString*>(_v)); break;
        case 566: _t->setXplanetColor(*reinterpret_cast<QString*>(_v)); break;
        case 568: _t->setXplanetDateFormat(*reinterpret_cast<QString*>(_v)); break;
        case 570: _t->setXplanetLabelTL(*reinterpret_cast<bool*>(_v)); break;
        case 572: _t->setXplanetLabelTR(*reinterpret_cast<bool*>(_v)); break;
        case 574: _t->setXplanetLabelBR(*reinterpret_cast<bool*>(_v)); break;
        case 576: _t->setXplanetLabelBL(*reinterpret_cast<bool*>(_v)); break;
        case 578: _t->setXplanetGlare(*reinterpret_cast<QString*>(_v)); break;
        case 580: _t->setXplanetRandom(*reinterpret_cast<bool*>(_v)); break;
        case 582: _t->setXplanetLatLong(*reinterpret_cast<bool*>(_v)); break;
        case 584: _t->setXplanetLatitude(*reinterpret_cast<QString*>(_v)); break;
        case 586: _t->setXplanetLongitude(*reinterpret_cast<QString*>(_v)); break;
        case 588: _t->setXplanetProjection(*reinterpret_cast<uint*>(_v)); break;
        case 590: _t->setXplanetBackground(*reinterpret_cast<bool*>(_v)); break;
        case 592: _t->setXplanetBackgroundImage(*reinterpret_cast<bool*>(_v)); break;
        case 594: _t->setXplanetBackgroundImagePath(*reinterpret_cast<QString*>(_v)); break;
        case 596: _t->setXplanetBackgroundColor(*reinterpret_cast<bool*>(_v)); break;
        case 598: _t->setXplanetBackgroundColorValue(*reinterpret_cast<QString*>(_v)); break;
        case 600: _t->setXplanetMagnitude(*reinterpret_cast<QString*>(_v)); break;
        case 602: _t->setXplanetArcFile(*reinterpret_cast<bool*>(_v)); break;
        case 604: _t->setXplanetArcFilePath(*reinterpret_cast<QString*>(_v)); break;
        case 606: _t->setXplanetConfigFile(*reinterpret_cast<bool*>(_v)); break;
        case 608: _t->setXplanetConfigFilePath(*reinterpret_cast<QString*>(_v)); break;
        case 610: _t->setXplanetFOV(*reinterpret_cast<bool*>(_v)); break;
        case 612: _t->setXplanetMarkerFile(*reinterpret_cast<bool*>(_v)); break;
        case 614: _t->setXplanetMarkerFilePath(*reinterpret_cast<QString*>(_v)); break;
        case 616: _t->setXplanetMarkerBounds(*reinterpret_cast<bool*>(_v)); break;
        case 618: _t->setXplanetMarkerBoundsPath(*reinterpret_cast<QString*>(_v)); break;
        case 620: _t->setXplanetStarmap(*reinterpret_cast<bool*>(_v)); break;
        case 622: _t->setXplanetStarmapPath(*reinterpret_cast<QString*>(_v)); break;
        case 624: _t->setXplanetQuality(*reinterpret_cast<QString*>(_v)); break;
        case 626: _t->setShowSatellites(*reinterpret_cast<bool*>(_v)); break;
        case 628: _t->setShowVisibleSatellites(*reinterpret_cast<bool*>(_v)); break;
        case 630: _t->setDrawSatellitesLikeStars(*reinterpret_cast<bool*>(_v)); break;
        case 632: _t->setShowSatellitesLabels(*reinterpret_cast<bool*>(_v)); break;
        case 634: _t->setSelectedSatellites(*reinterpret_cast<QStringList*>(_v)); break;
        case 636: _t->setKStarsFirstRun(*reinterpret_cast<bool*>(_v)); break;
        case 638: _t->setAlwaysRecomputeCoordinates(*reinterpret_cast<bool*>(_v)); break;
        case 640: _t->setDefaultDSSImageSize(*reinterpret_cast<double*>(_v)); break;
        case 642: _t->setDSSPadding(*reinterpret_cast<double*>(_v)); break;
        case 644: _t->setVerboseLogging(*reinterpret_cast<bool*>(_v)); break;
        case 646: _t->setRegularLogging(*reinterpret_cast<bool*>(_v)); break;
        case 648: _t->setDisableLogging(*reinterpret_cast<bool*>(_v)); break;
        case 650: _t->setLogToDefault(*reinterpret_cast<bool*>(_v)); break;
        case 652: _t->setLogToFile(*reinterpret_cast<bool*>(_v)); break;
        case 654: _t->setFITSLogging(*reinterpret_cast<bool*>(_v)); break;
        case 656: _t->setINDILogging(*reinterpret_cast<bool*>(_v)); break;
        case 658: _t->setCaptureLogging(*reinterpret_cast<bool*>(_v)); break;
        case 660: _t->setFocusLogging(*reinterpret_cast<bool*>(_v)); break;
        case 662: _t->setSaveGuideImages(*reinterpret_cast<bool*>(_v)); break;
        case 664: _t->setSaveAlignImages(*reinterpret_cast<bool*>(_v)); break;
        case 666: _t->setSaveFailedAlignImages(*reinterpret_cast<bool*>(_v)); break;
        case 668: _t->setDontSyncToRealTime(*reinterpret_cast<bool*>(_v)); break;
        case 670: _t->setGuideLogging(*reinterpret_cast<bool*>(_v)); break;
        case 672: _t->setAlignmentLogging(*reinterpret_cast<bool*>(_v)); break;
        case 674: _t->setMountLogging(*reinterpret_cast<bool*>(_v)); break;
        case 676: _t->setObservatoryLogging(*reinterpret_cast<bool*>(_v)); break;
        case 678: _t->setImageDebayerEngine(*reinterpret_cast<int*>(_v)); break;
        case 680: _t->setImageDebayerAlgo(*reinterpret_cast<int*>(_v)); break;
        case 682: _t->setStackDebayerEngine(*reinterpret_cast<int*>(_v)); break;
        case 684: _t->setStackDebayerAlgo(*reinterpret_cast<int*>(_v)); break;
        case 686: _t->setFITSWindowGeometry(*reinterpret_cast<QString*>(_v)); break;
        case 688: _t->setUseFITSViewer(*reinterpret_cast<bool*>(_v)); break;
        case 690: _t->setSinglePreviewFITS(*reinterpret_cast<bool*>(_v)); break;
        case 692: _t->setSingleWindowCapturedFITS(*reinterpret_cast<bool*>(_v)); break;
        case 694: _t->setSingleWindowOpenedFITS(*reinterpret_cast<bool*>(_v)); break;
        case 696: _t->setFocusFITSOnNewImage(*reinterpret_cast<bool*>(_v)); break;
        case 698: _t->setIndependentWindowFITS(*reinterpret_cast<bool*>(_v)); break;
        case 700: _t->setLiveStackerOwnProcess(*reinterpret_cast<bool*>(_v)); break;
        case 702: _t->setAutoDebayer(*reinterpret_cast<bool*>(_v)); break;
        case 704: _t->setAuto3DCube(*reinterpret_cast<bool*>(_v)); break;
        case 706: _t->setAutoHFR(*reinterpret_cast<bool*>(_v)); break;
        case 708: _t->setQuickHFR(*reinterpret_cast<bool*>(_v)); break;
        case 710: _t->setStellarSolverPartition(*reinterpret_cast<bool*>(_v)); break;
        case 712: _t->setAutoWCS(*reinterpret_cast<bool*>(_v)); break;
        case 714: _t->setLimitedResourcesMode(*reinterpret_cast<bool*>(_v)); break;
        case 716: _t->setNonLinearHistogram(*reinterpret_cast<bool*>(_v)); break;
        case 718: _t->setHIPSOpacity(*reinterpret_cast<double*>(_v)); break;
        case 720: _t->setHIPSOffsetX(*reinterpret_cast<int*>(_v)); break;
        case 722: _t->setHIPSOffsetY(*reinterpret_cast<int*>(_v)); break;
        case 724: _t->setFitsSolverProfile(*reinterpret_cast<uint*>(_v)); break;
        case 726: _t->setFitsSolverModule(*reinterpret_cast<uint*>(_v)); break;
        case 728: _t->setFitsSolverProfileIndeces(*reinterpret_cast<QString*>(_v)); break;
        case 730: _t->setFitsCatalog(*reinterpret_cast<uint*>(_v)); break;
        case 732: _t->setFitsCatObjShowNames(*reinterpret_cast<bool*>(_v)); break;
        case 734: _t->setFitsSolverUseScale(*reinterpret_cast<bool*>(_v)); break;
        case 736: _t->setFitsSolverUsePosition(*reinterpret_cast<bool*>(_v)); break;
        case 738: _t->setFitsSolverScale(*reinterpret_cast<double*>(_v)); break;
        case 740: _t->setFitsSolverImageScaleUnits(*reinterpret_cast<uint*>(_v)); break;
        case 742: _t->setFitsSolverRadius(*reinterpret_cast<double*>(_v)); break;
        case 744: _t->setFitsLSHideGeneral(*reinterpret_cast<bool*>(_v)); break;
        case 746: _t->setFitsLSHideCalibration(*reinterpret_cast<bool*>(_v)); break;
        case 748: _t->setFitsLSHideAlignment(*reinterpret_cast<bool*>(_v)); break;
        case 750: _t->setFitsLSHideStacking(*reinterpret_cast<bool*>(_v)); break;
        case 752: _t->setFitsLSHidePostProc(*reinterpret_cast<bool*>(_v)); break;
        case 754: _t->setFitsLSCalcSNR(*reinterpret_cast<bool*>(_v)); break;
        case 756: _t->setFitsLSMasterDark(*reinterpret_cast<QString*>(_v)); break;
        case 758: _t->setFitsLSMasterFlat(*reinterpret_cast<QString*>(_v)); break;
        case 760: _t->setFitsLSHotPixels(*reinterpret_cast<bool*>(_v)); break;
        case 762: _t->setFitsLSColdPixels(*reinterpret_cast<bool*>(_v)); break;
        case 764: _t->setFitsLSAlignMethod(*reinterpret_cast<uint*>(_v)); break;
        case 766: _t->setFitsLSNumInMem(*reinterpret_cast<uint*>(_v)); break;
        case 768: _t->setFitsLSDownscale(*reinterpret_cast<uint*>(_v)); break;
        case 770: _t->setFitsLSWeighting(*reinterpret_cast<uint*>(_v)); break;
        case 772: _t->setFitsLSNormalization(*reinterpret_cast<uint*>(_v)); break;
        case 774: _t->setFitsLSStackingMethod(*reinterpret_cast<uint*>(_v)); break;
        case 776: _t->setFitsLSLowSigma(*reinterpret_cast<double*>(_v)); break;
        case 778: _t->setFitsLSHighSigma(*reinterpret_cast<double*>(_v)); break;
        case 780: _t->setFitsLSWinsorCutoff(*reinterpret_cast<double*>(_v)); break;
        case 782: _t->setFitsLSIterations(*reinterpret_cast<uint*>(_v)); break;
        case 784: _t->setFitsLSKappa(*reinterpret_cast<double*>(_v)); break;
        case 786: _t->setFitsLSAlpha(*reinterpret_cast<double*>(_v)); break;
        case 788: _t->setFitsLSSigma(*reinterpret_cast<double*>(_v)); break;
        case 790: _t->setFitsPSFUpdate(*reinterpret_cast<uint*>(_v)); break;
        case 792: _t->setFitsLSPostProc(*reinterpret_cast<bool*>(_v)); break;
        case 794: _t->setFitsLSGradientAmt(*reinterpret_cast<double*>(_v)); break;
        case 796: _t->setFitsLSDeconvAmt(*reinterpret_cast<double*>(_v)); break;
        case 798: _t->setFitsLSPSFSigma(*reinterpret_cast<double*>(_v)); break;
        case 800: _t->setFitsLSDenoiseAmt(*reinterpret_cast<double*>(_v)); break;
        case 802: _t->setFitsLSSharpenAmt(*reinterpret_cast<double*>(_v)); break;
        case 804: _t->setFitsLSSharpenKernal(*reinterpret_cast<uint*>(_v)); break;
        case 806: _t->setFitsLSSharpenSigma(*reinterpret_cast<double*>(_v)); break;
        case 808: _t->setFitsLSMWindowGeometry(*reinterpret_cast<QString*>(_v)); break;
        case 810: _t->setFitsLSMVisibleColumns(*reinterpret_cast<QStringList*>(_v)); break;
        case 812: _t->setFitsLSMColumnWidths(*reinterpret_cast<QList<int>*>(_v)); break;
        case 814: _t->setFitsLSMSortColumn(*reinterpret_cast<int*>(_v)); break;
        case 816: _t->setFitsLSMSortOrder(*reinterpret_cast<int*>(_v)); break;
        case 818: _t->setFitsLSMHighlighting(*reinterpret_cast<bool*>(_v)); break;
        case 820: _t->setFitsLSWebcastTitle(*reinterpret_cast<QString*>(_v)); break;
        case 822: _t->setFitsLSWebcastLogoL(*reinterpret_cast<QString*>(_v)); break;
        case 824: _t->setFitsLSWebcastLogoR(*reinterpret_cast<QString*>(_v)); break;
        case 826: _t->setFitsLSWebcastPort(*reinterpret_cast<uint*>(_v)); break;
        case 828: _t->setFitsLSWebcastThrottle(*reinterpret_cast<uint*>(_v)); break;
        case 830: _t->setBortleClass(*reinterpret_cast<uint*>(_v)); break;
        case 832: _t->setTelescopeCheck(*reinterpret_cast<bool*>(_v)); break;
        case 834: _t->setBinocularsCheck(*reinterpret_cast<bool*>(_v)); break;
        case 836: _t->setBinocularsAperture(*reinterpret_cast<double*>(_v)); break;
        case 838: _t->setScopeListIndex(*reinterpret_cast<uint*>(_v)); break;
        case 840: _t->setEkosWindowWidth(*reinterpret_cast<uint*>(_v)); break;
        case 842: _t->setEkosWindowHeight(*reinterpret_cast<uint*>(_v)); break;
        case 844: _t->setEkosGeometry(*reinterpret_cast<QString*>(_v)); break;
        case 846: _t->setEkosTopIcons(*reinterpret_cast<bool*>(_v)); break;
        case 848: _t->setEkosLeftIcons(*reinterpret_cast<bool*>(_v)); break;
        case 850: _t->setIndependentWindowEkos(*reinterpret_cast<bool*>(_v)); break;
        case 852: _t->setProfile(*reinterpret_cast<QString*>(_v)); break;
        case 854: _t->setNeverLoadConfig(*reinterpret_cast<bool*>(_v)); break;
        case 856: _t->setLoadConfigOnConnection(*reinterpret_cast<bool*>(_v)); break;
        case 858: _t->setLoadDefaultConfig(*reinterpret_cast<bool*>(_v)); break;
        case 860: _t->setAutoLoadSerialAssistant(*reinterpret_cast<bool*>(_v)); break;
        case 862: _t->setRememberCredentials(*reinterpret_cast<bool*>(_v)); break;
        case 864: _t->setAutoStartEkosLive(*reinterpret_cast<bool*>(_v)); break;
        case 866: _t->setEkosLiveUsername(*reinterpret_cast<QString*>(_v)); break;
        case 868: _t->setEkosLiveObservatory(*reinterpret_cast<QString*>(_v)); break;
        case 870: _t->setEkosLiveOfflineServer(*reinterpret_cast<QString*>(_v)); break;
        case 872: _t->setEkosLiveOnlineServer(*reinterpret_cast<QString*>(_v)); break;
        case 874: _t->setEkosLiveSound(*reinterpret_cast<bool*>(_v)); break;
        case 876: _t->setEkosLiveNotifications(*reinterpret_cast<bool*>(_v)); break;
        case 878: _t->setEkosLiveCloud(*reinterpret_cast<bool*>(_v)); break;
        case 880: _t->setMaxDarkTemperatureDiff(*reinterpret_cast<double*>(_v)); break;
        case 882: _t->setShutterfulCCDs(*reinterpret_cast<QStringList*>(_v)); break;
        case 884: _t->setShutterlessCCDs(*reinterpret_cast<QStringList*>(_v)); break;
        case 886: _t->setDarkLibraryDuration(*reinterpret_cast<uint*>(_v)); break;
        case 888: _t->setUseGraphicalCountsDisplay(*reinterpret_cast<bool*>(_v)); break;
        case 890: _t->setMinimumAltLimit(*reinterpret_cast<double*>(_v)); break;
        case 892: _t->setMaximumAltLimit(*reinterpret_cast<double*>(_v)); break;
        case 894: _t->setEnableAltitudeLimits(*reinterpret_cast<bool*>(_v)); break;
        case 896: _t->setEnableAltitudeLimitsTrackingOnly(*reinterpret_cast<bool*>(_v)); break;
        case 898: _t->setConfirmBelowHorizon(*reinterpret_cast<bool*>(_v)); break;
        case 900: _t->setMeridianFlipOffsetDegrees(*reinterpret_cast<double*>(_v)); break;
        case 902: _t->setMaximumHaLimit(*reinterpret_cast<double*>(_v)); break;
        case 904: _t->setEnableHaLimit(*reinterpret_cast<bool*>(_v)); break;
        case 906: _t->setExecuteMeridianFlip(*reinterpret_cast<bool*>(_v)); break;
        case 908: _t->setLeftRightReversed(*reinterpret_cast<bool*>(_v)); break;
        case 910: _t->setUpDownReversed(*reinterpret_cast<bool*>(_v)); break;
        case 912: _t->setParkEveryDay(*reinterpret_cast<bool*>(_v)); break;
        case 914: _t->setParkTime(*reinterpret_cast<QString*>(_v)); break;
        case 916: _t->setDefaultObserver(*reinterpret_cast<QString*>(_v)); break;
        case 918: _t->setSyncFOVPA(*reinterpret_cast<bool*>(_v)); break;
        case 920: _t->setPAMultiplier(*reinterpret_cast<double*>(_v)); break;
        case 922: _t->setPAOffset(*reinterpret_cast<double*>(_v)); break;
        case 924: _t->setPAPierSide(*reinterpret_cast<uint*>(_v)); break;
        case 926: _t->setGuideDeviation(*reinterpret_cast<double*>(_v)); break;
        case 928: _t->setGuideDeviationReps(*reinterpret_cast<uint*>(_v)); break;
        case 930: _t->setStartGuideDeviation(*reinterpret_cast<double*>(_v)); break;
        case 932: _t->setGuideDitherPerJobFrequency(*reinterpret_cast<uint*>(_v)); break;
        case 934: _t->setHFRDeviation(*reinterpret_cast<double*>(_v)); break;
        case 936: _t->setMaxFocusTemperatureDelta(*reinterpret_cast<double*>(_v)); break;
        case 938: _t->setAutoDark(*reinterpret_cast<bool*>(_v)); break;
        case 940: _t->setEnforceGuideDeviation(*reinterpret_cast<bool*>(_v)); break;
        case 942: _t->setEnforceAutofocusHFR(*reinterpret_cast<bool*>(_v)); break;
        case 944: _t->setEnforceAutofocusOnTemperature(*reinterpret_cast<bool*>(_v)); break;
        case 946: _t->setEnforceRefocusEveryN(*reinterpret_cast<bool*>(_v)); break;
        case 948: _t->setRefocusEveryN(*reinterpret_cast<uint*>(_v)); break;
        case 950: _t->setRefocusAfterMeridianFlip(*reinterpret_cast<bool*>(_v)); break;
        case 952: _t->setResetMountModelAfterMeridian(*reinterpret_cast<bool*>(_v)); break;
        case 954: _t->setForcedFlip(*reinterpret_cast<bool*>(_v)); break;
        case 956: _t->setCalibrationADUValue(*reinterpret_cast<uint*>(_v)); break;
        case 958: _t->setCalibrationADUValueTolerance(*reinterpret_cast<uint*>(_v)); break;
        case 960: _t->setCalibrationPreActionIndex(*reinterpret_cast<uint*>(_v)); break;
        case 962: _t->setCalibrationFlatDurationIndex(*reinterpret_cast<uint*>(_v)); break;
        case 964: _t->setCalibrationWallAz(*reinterpret_cast<double*>(_v)); break;
        case 966: _t->setCalibrationWallAlt(*reinterpret_cast<double*>(_v)); break;
        case 968: _t->setMaxTemperatureDiff(*reinterpret_cast<double*>(_v)); break;
        case 970: _t->setMaxStartGuiderDrift(*reinterpret_cast<double*>(_v)); break;
        case 972: _t->setEnforceStartGuiderDrift(*reinterpret_cast<bool*>(_v)); break;
        case 974: _t->setGuidingSettle(*reinterpret_cast<double*>(_v)); break;
        case 976: _t->setAlwaysResetSequenceWhenStarting(*reinterpret_cast<bool*>(_v)); break;
        case 978: _t->setFlatSyncFocus(*reinterpret_cast<bool*>(_v)); break;
        case 980: _t->setHFRThresholdPercentage(*reinterpret_cast<double*>(_v)); break;
        case 982: _t->setHFRCheckAlgorithm(*reinterpret_cast<int*>(_v)); break;
        case 984: _t->setInSequenceCheckFrames(*reinterpret_cast<uint*>(_v)); break;
        case 986: _t->setAutoStretch(*reinterpret_cast<bool*>(_v)); break;
        case 988: _t->setStretchPreviewSampling(*reinterpret_cast<uint*>(_v)); break;
        case 990: _t->setClipping64KValue(*reinterpret_cast<uint*>(_v)); break;
        case 992: _t->setClipping256Value(*reinterpret_cast<uint*>(_v)); break;
        case 994: _t->setAdaptiveSampling(*reinterpret_cast<bool*>(_v)); break;
        case 996: _t->setUseSummaryPreview(*reinterpret_cast<bool*>(_v)); break;
        case 998: _t->setUseDSLRImageViewer(*reinterpret_cast<bool*>(_v)); break;
        case 1000: _t->setForceDSLRPresets(*reinterpret_cast<bool*>(_v)); break;
        case 1002: _t->setCaptureDirectory(*reinterpret_cast<QString*>(_v)); break;
        case 1004: _t->setPlaceholderFormat(*reinterpret_cast<QString*>(_v)); break;
        case 1006: _t->setRemoteCaptureDirectory(*reinterpret_cast<QString*>(_v)); break;
        case 1008: _t->setManualCoverTimeout(*reinterpret_cast<uint*>(_v)); break;
        case 1010: _t->setCaptureOperationsTimeout(*reinterpret_cast<uint*>(_v)); break;
        case 1012: _t->setMinFlipDuration(*reinterpret_cast<uint*>(_v)); break;
        case 1014: _t->setCapturePosition(*reinterpret_cast<bool*>(_v)); break;
        case 1016: _t->setCaptureTrainID(*reinterpret_cast<uint*>(_v)); break;
        case 1018: _t->setCaptureCalibrationWall(*reinterpret_cast<bool*>(_v)); break;
        case 1020: _t->setCaptureCalibrationParkMount(*reinterpret_cast<bool*>(_v)); break;
        case 1022: _t->setCaptureCalibrationParkDome(*reinterpret_cast<bool*>(_v)); break;
        case 1024: _t->setCaptureCalibrationUseManual(*reinterpret_cast<bool*>(_v)); break;
        case 1026: _t->setCaptureCalibrationUseADU(*reinterpret_cast<bool*>(_v)); break;
        case 1028: _t->setCaptureCalibrationADUValue(*reinterpret_cast<double*>(_v)); break;
        case 1030: _t->setCaptureCalibrationADUTolerance(*reinterpret_cast<double*>(_v)); break;
        case 1032: _t->setCaptureCalibrationSkyFlats(*reinterpret_cast<bool*>(_v)); break;
        case 1034: _t->setAbsTicksSpin(*reinterpret_cast<uint*>(_v)); break;
        case 1036: _t->setFocusExposure(*reinterpret_cast<double*>(_v)); break;
        case 1038: _t->setFocusBinning(*reinterpret_cast<QString*>(_v)); break;
        case 1040: _t->setFocusGain(*reinterpret_cast<double*>(_v)); break;
        case 1042: _t->setFocusISO(*reinterpret_cast<QString*>(_v)); break;
        case 1044: _t->setDefaultFocusTemperatureSource(*reinterpret_cast<QString*>(_v)); break;
        case 1046: _t->setFocusFilter(*reinterpret_cast<QString*>(_v)); break;
        case 1048: _t->setUseFocusDarkFrame(*reinterpret_cast<bool*>(_v)); break;
        case 1050: _t->setFocusSubFrame(*reinterpret_cast<bool*>(_v)); break;
        case 1052: _t->setFocusBoxSize(*reinterpret_cast<uint*>(_v)); break;
        case 1054: _t->setFocusUseFullField(*reinterpret_cast<bool*>(_v)); break;
        case 1056: _t->setFocusNoMaskRB(*reinterpret_cast<bool*>(_v)); break;
        case 1058: _t->setFocusRingMaskRB(*reinterpret_cast<bool*>(_v)); break;
        case 1060: _t->setFocusMosaicMaskRB(*reinterpret_cast<bool*>(_v)); break;
        case 1062: _t->setFocusFullFieldInnerRadius(*reinterpret_cast<double*>(_v)); break;
        case 1064: _t->setFocusFullFieldOuterRadius(*reinterpret_cast<double*>(_v)); break;
        case 1066: _t->setFocusMosaicTileWidth(*reinterpret_cast<double*>(_v)); break;
        case 1068: _t->setFocusMosaicSpace(*reinterpret_cast<uint*>(_v)); break;
        case 1070: _t->setFocusAutoStarEnabled(*reinterpret_cast<bool*>(_v)); break;
        case 1072: _t->setFocusSuspendGuiding(*reinterpret_cast<bool*>(_v)); break;
        case 1074: _t->setFocusGuideSettleTime(*reinterpret_cast<double*>(_v)); break;
        case 1076: _t->setFocusUnits(*reinterpret_cast<QString*>(_v)); break;
        case 1078: _t->setFocusAdaptive(*reinterpret_cast<bool*>(_v)); break;
        case 1080: _t->setFocusAdaptiveMinMove(*reinterpret_cast<uint*>(_v)); break;
        case 1082: _t->setFocusAdaptStart(*reinterpret_cast<bool*>(_v)); break;
        case 1084: _t->setFocusAdaptiveMaxMove(*reinterpret_cast<uint*>(_v)); break;
        case 1086: _t->setFocusDetection(*reinterpret_cast<QString*>(_v)); break;
        case 1088: _t->setFocusSEPProfile(*reinterpret_cast<QString*>(_v)); break;
        case 1090: _t->setFocusAlgorithm(*reinterpret_cast<QString*>(_v)); break;
        case 1092: _t->setFocusCurveFit(*reinterpret_cast<QString*>(_v)); break;
        case 1094: _t->setFocusStarMeasure(*reinterpret_cast<QString*>(_v)); break;
        case 1096: _t->setFocusStarPSF(*reinterpret_cast<QString*>(_v)); break;
        case 1098: _t->setFocusUseWeights(*reinterpret_cast<bool*>(_v)); break;
        case 1100: _t->setFocusR2Limit(*reinterpret_cast<double*>(_v)); break;
        case 1102: _t->setFocusRefineCurveFit(*reinterpret_cast<bool*>(_v)); break;
        case 1104: _t->setFocusFramesCount(*reinterpret_cast<uint*>(_v)); break;
        case 1106: _t->setFocusHFRFramesCount(*reinterpret_cast<uint*>(_v)); break;
        case 1108: _t->setFocusMultiRowAverage(*reinterpret_cast<int*>(_v)); break;
        case 1110: _t->setFocusGaussianSigma(*reinterpret_cast<double*>(_v)); break;
        case 1112: _t->setFocusThreshold(*reinterpret_cast<double*>(_v)); break;
        case 1114: _t->setFocusDenoise(*reinterpret_cast<bool*>(_v)); break;
        case 1116: _t->setFocusDonut(*reinterpret_cast<bool*>(_v)); break;
        case 1118: _t->setFocusTimeDilation(*reinterpret_cast<double*>(_v)); break;
        case 1120: _t->setFocusOutlierRejection(*reinterpret_cast<double*>(_v)); break;
        case 1122: _t->setFocusScanStartPos(*reinterpret_cast<bool*>(_v)); break;
        case 1124: _t->setFocusScanAlwaysOn(*reinterpret_cast<bool*>(_v)); break;
        case 1126: _t->setFocusScanDatapoints(*reinterpret_cast<uint*>(_v)); break;
        case 1128: _t->setFocusScanStepSizeFactor(*reinterpret_cast<double*>(_v)); break;
        case 1130: _t->setFocusGaussianKernelSize(*reinterpret_cast<int*>(_v)); break;
        case 1132: _t->setFocusTolerance(*reinterpret_cast<double*>(_v)); break;
        case 1134: _t->setFocusWalk(*reinterpret_cast<QString*>(_v)); break;
        case 1136: _t->setFocusSettleTime(*reinterpret_cast<double*>(_v)); break;
        case 1138: _t->setFocusTicks(*reinterpret_cast<uint*>(_v)); break;
        case 1140: _t->setFocusOutSteps(*reinterpret_cast<double*>(_v)); break;
        case 1142: _t->setFocusNumSteps(*reinterpret_cast<uint*>(_v)); break;
        case 1144: _t->setFocusMaxTravel(*reinterpret_cast<uint*>(_v)); break;
        case 1146: _t->setFocusMaxSingleStep(*reinterpret_cast<uint*>(_v)); break;
        case 1148: _t->setFocusBacklash(*reinterpret_cast<uint*>(_v)); break;
        case 1150: _t->setFocusAFOverscan(*reinterpret_cast<uint*>(_v)); break;
        case 1152: _t->setFocusOverscanDelay(*reinterpret_cast<double*>(_v)); break;
        case 1154: _t->setFocusCaptureTimeout(*reinterpret_cast<uint*>(_v)); break;
        case 1156: _t->setFocusMotionTimeout(*reinterpret_cast<uint*>(_v)); break;
        case 1158: _t->setFocusCFZAlgorithm(*reinterpret_cast<QString*>(_v)); break;
        case 1160: _t->setFocusCFZTolerance(*reinterpret_cast<double*>(_v)); break;
        case 1162: _t->setFocusCFZTau(*reinterpret_cast<double*>(_v)); break;
        case 1164: _t->setFocusCFZDisplayVCurve(*reinterpret_cast<bool*>(_v)); break;
        case 1166: _t->setFocusCFZWavelength(*reinterpret_cast<double*>(_v)); break;
        case 1168: _t->setFocusCFZAperture(*reinterpret_cast<uint*>(_v)); break;
        case 1170: _t->setFocusCFZFNumber(*reinterpret_cast<double*>(_v)); break;
        case 1172: _t->setFocusCFZSeeing(*reinterpret_cast<double*>(_v)); break;
        case 1174: _t->setFocusCFZStepSize(*reinterpret_cast<double*>(_v)); break;
        case 1176: _t->setFocusAdvHelpOnlyChanges(*reinterpret_cast<bool*>(_v)); break;
        case 1178: _t->setFocusAdvUpdateParams(*reinterpret_cast<bool*>(_v)); break;
        case 1180: _t->setFocusAdvFindStars(*reinterpret_cast<bool*>(_v)); break;
        case 1182: _t->setFocusAdvCourseAdj(*reinterpret_cast<bool*>(_v)); break;
        case 1184: _t->setFocusAdvFineAdj(*reinterpret_cast<bool*>(_v)); break;
        case 1186: _t->setFocusSplitter(*reinterpret_cast<QString*>(_v)); break;
        case 1188: _t->setRightLayout(*reinterpret_cast<QString*>(_v)); break;
        case 1190: _t->setAdaptFocusBFO(*reinterpret_cast<bool*>(_v)); break;
        case 1192: _t->setAbInsTileSelection(*reinterpret_cast<QString*>(_v)); break;
        case 1194: _t->setAbInsShowLabels(*reinterpret_cast<bool*>(_v)); break;
        case 1196: _t->setAbInsShowCFZ(*reinterpret_cast<bool*>(_v)); break;
        case 1198: _t->setAbInsOptCentres(*reinterpret_cast<bool*>(_v)); break;
        case 1200: _t->setAbInsHSplitter(*reinterpret_cast<QString*>(_v)); break;
        case 1202: _t->setAbInsVSplitter(*reinterpret_cast<QString*>(_v)); break;
        case 1204: _t->setAbInsSelection(*reinterpret_cast<QString*>(_v)); break;
        case 1206: _t->setAbInsTheme(*reinterpret_cast<QString*>(_v)); break;
        case 1208: _t->setAbInsLabels(*reinterpret_cast<bool*>(_v)); break;
        case 1210: _t->setAbInsSensor(*reinterpret_cast<bool*>(_v)); break;
        case 1212: _t->setAbInsPetzvalWire(*reinterpret_cast<bool*>(_v)); break;
        case 1214: _t->setAbInsPetzvalSurface(*reinterpret_cast<bool*>(_v)); break;
        case 1216: _t->setTiltPlateType(*reinterpret_cast<uint*>(_v)); break;
        case 1218: _t->setTiltRadius(*reinterpret_cast<double*>(_v)); break;
        case 1220: _t->setTiltThreadIndex(*reinterpret_cast<uint*>(_v)); break;
        case 1222: _t->setTiltScrewPitch(*reinterpret_cast<double*>(_v)); break;
        case 1224: _t->setTiltRotation(*reinterpret_cast<double*>(_v)); break;
        case 1226: _t->setTiltMode(*reinterpret_cast<uint*>(_v)); break;
        case 1228: _t->setTiltPlatePresent(*reinterpret_cast<bool*>(_v)); break;
        case 1230: _t->setFocusSextractorType(*reinterpret_cast<uint*>(_v)); break;
        case 1232: _t->setFocusOptionsProfile(*reinterpret_cast<uint*>(_v)); break;
        case 1234: _t->setHFRSextractorType(*reinterpret_cast<uint*>(_v)); break;
        case 1236: _t->setHFROptionsProfile(*reinterpret_cast<uint*>(_v)); break;
        case 1238: _t->setGuideSextractorType(*reinterpret_cast<uint*>(_v)); break;
        case 1240: _t->setGuideOptionsProfile(*reinterpret_cast<uint*>(_v)); break;
        case 1242: _t->setSolveSextractorType(*reinterpret_cast<uint*>(_v)); break;
        case 1244: _t->setSolverMode(*reinterpret_cast<uint*>(_v)); break;
        case 1246: _t->setSolverType(*reinterpret_cast<uint*>(_v)); break;
        case 1248: _t->setSolveOptionsProfile(*reinterpret_cast<uint*>(_v)); break;
        case 1250: _t->setLoggerLevel(*reinterpret_cast<uint*>(_v)); break;
        case 1252: _t->setAstrometryLogToFile(*reinterpret_cast<bool*>(_v)); break;
        case 1254: _t->setAstrometryLogFilepath(*reinterpret_cast<QString*>(_v)); break;
        case 1256: _t->setAstrometryIndexFolderList(*reinterpret_cast<QStringList*>(_v)); break;
        case 1258: _t->setAlignExposure(*reinterpret_cast<double*>(_v)); break;
        case 1260: _t->setAlignBinning(*reinterpret_cast<QString*>(_v)); break;
        case 1262: _t->setAlignGain(*reinterpret_cast<double*>(_v)); break;
        case 1264: _t->setAlignISO(*reinterpret_cast<double*>(_v)); break;
        case 1266: _t->setAlignDarkFrame(*reinterpret_cast<bool*>(_v)); break;
        case 1268: _t->setAlignFilter(*reinterpret_cast<QString*>(_v)); break;
        case 1270: _t->setAlignUseCurrentFilter(*reinterpret_cast<bool*>(_v)); break;
        case 1272: _t->setAstrometryUseRotator(*reinterpret_cast<bool*>(_v)); break;
        case 1274: _t->setAstrometryRotatorThreshold(*reinterpret_cast<double*>(_v)); break;
        case 1276: _t->setAstrometryFlipRotationAllowed(*reinterpret_cast<bool*>(_v)); break;
        case 1278: _t->setRotatorParityReversed(*reinterpret_cast<bool*>(_v)); break;
        case 1280: _t->setAstrometrySolverWCS(*reinterpret_cast<bool*>(_v)); break;
        case 1282: _t->setAstrometrySolverOverlay(*reinterpret_cast<bool*>(_v)); break;
        case 1284: _t->setAstrometryDifferentialSlewing(*reinterpret_cast<bool*>(_v)); break;
        case 1286: _t->setAlignAccuracyThreshold(*reinterpret_cast<uint*>(_v)); break;
        case 1288: _t->setAlignSettlingTime(*reinterpret_cast<uint*>(_v)); break;
        case 1290: _t->setAstrometryUseNoFITS2FITS(*reinterpret_cast<bool*>(_v)); break;
        case 1292: _t->setAstrometryUseResort(*reinterpret_cast<bool*>(_v)); break;
        case 1294: _t->setAstrometryUseNoVerify(*reinterpret_cast<bool*>(_v)); break;
        case 1296: _t->setAstrometryUseImageScale(*reinterpret_cast<bool*>(_v)); break;
        case 1298: _t->setAstrometryImageScaleLow(*reinterpret_cast<double*>(_v)); break;
        case 1300: _t->setAstrometryImageScaleHigh(*reinterpret_cast<double*>(_v)); break;
        case 1302: _t->setAstrometryAutoUpdateImageScale(*reinterpret_cast<bool*>(_v)); break;
        case 1304: _t->setAstrometryImageScaleUnits(*reinterpret_cast<uint*>(_v)); break;
        case 1306: _t->setAstrometryUseDownsample(*reinterpret_cast<bool*>(_v)); break;
        case 1308: _t->setAstrometryDownsample(*reinterpret_cast<uint*>(_v)); break;
        case 1310: _t->setAstrometryAutoDownsample(*reinterpret_cast<bool*>(_v)); break;
        case 1312: _t->setAstrometryDynamicThreshold(*reinterpret_cast<bool*>(_v)); break;
        case 1314: _t->setAstrometryUsePosition(*reinterpret_cast<bool*>(_v)); break;
        case 1316: _t->setAstrometryPositionRA(*reinterpret_cast<double*>(_v)); break;
        case 1318: _t->setAstrometryPositionDE(*reinterpret_cast<double*>(_v)); break;
        case 1320: _t->setAstrometryAutoUpdatePosition(*reinterpret_cast<bool*>(_v)); break;
        case 1322: _t->setAstrometryRadius(*reinterpret_cast<double*>(_v)); break;
        case 1324: _t->setAstrometryDetectParity(*reinterpret_cast<bool*>(_v)); break;
        case 1326: _t->setAstrometryCustomOptions(*reinterpret_cast<QString*>(_v)); break;
        case 1328: _t->setAstrometrySolverBinary(*reinterpret_cast<QString*>(_v)); break;
        case 1330: _t->setAstrometryWCSInfo(*reinterpret_cast<QString*>(_v)); break;
        case 1332: _t->setAstrometryConfFile(*reinterpret_cast<QString*>(_v)); break;
        case 1334: _t->setSextractorBinary(*reinterpret_cast<QString*>(_v)); break;
        case 1336: _t->setWatneyBinary(*reinterpret_cast<QString*>(_v)); break;
        case 1338: _t->setAstrometryAPIKey(*reinterpret_cast<QString*>(_v)); break;
        case 1340: _t->setAstrometryAPIURL(*reinterpret_cast<QString*>(_v)); break;
        case 1342: _t->setAstrometryUseJPEG(*reinterpret_cast<bool*>(_v)); break;
        case 1344: _t->setAstrometryTimeout(*reinterpret_cast<uint*>(_v)); break;
        case 1346: _t->setPAHMountSpeed(*reinterpret_cast<QString*>(_v)); break;
        case 1348: _t->setPAHRotaion(*reinterpret_cast<double*>(_v)); break;
        case 1350: _t->setPAHRefreshAlgorithm(*reinterpret_cast<QString*>(_v)); break;
        case 1352: _t->setPAHDirection(*reinterpret_cast<QString*>(_v)); break;
        case 1354: _t->setPAHAutoPark(*reinterpret_cast<bool*>(_v)); break;
        case 1356: _t->setPAHManualSlew(*reinterpret_cast<bool*>(_v)); break;
        case 1358: _t->setPAHExposure(*reinterpret_cast<double*>(_v)); break;
        case 1360: _t->setPAHAutoPACCorrection(*reinterpret_cast<bool*>(_v)); break;
        case 1362: _t->setPAHAutoChangeDirection(*reinterpret_cast<bool*>(_v)); break;
        case 1364: _t->setPAHSuccessThreshold(*reinterpret_cast<double*>(_v)); break;
        case 1366: _t->setPAHCorrectionTimeout(*reinterpret_cast<uint*>(_v)); break;
        case 1368: _t->setGuideExposure(*reinterpret_cast<double*>(_v)); break;
        case 1370: _t->setGuideDelay(*reinterpret_cast<double*>(_v)); break;
        case 1372: _t->setGuiderType(*reinterpret_cast<uint*>(_v)); break;
        case 1374: _t->setGuideAlgorithm(*reinterpret_cast<uint*>(_v)); break;
        case 1376: _t->setRAGuidePulseAlgorithm(*reinterpret_cast<uint*>(_v)); break;
        case 1378: _t->setDECGuidePulseAlgorithm(*reinterpret_cast<uint*>(_v)); break;
        case 1380: _t->setAIGuiderWeightsFile(*reinterpret_cast<QUrl*>(_v)); break;
        case 1382: _t->setAIPredictionGain(*reinterpret_cast<double*>(_v)); break;
        case 1384: _t->setAIProportionalBackoff(*reinterpret_cast<bool*>(_v)); break;
        case 1386: _t->setAIPIDAutoTune(*reinterpret_cast<bool*>(_v)); break;
        case 1388: _t->setAIShadowMode(*reinterpret_cast<bool*>(_v)); break;
        case 1390: _t->setPHD2Host(*reinterpret_cast<QString*>(_v)); break;
        case 1392: _t->setPHD2Port(*reinterpret_cast<uint*>(_v)); break;
        case 1394: _t->setLinGuiderHost(*reinterpret_cast<QString*>(_v)); break;
        case 1396: _t->setLinGuiderPort(*reinterpret_cast<uint*>(_v)); break;
        case 1398: _t->setCalibrationPulseDuration(*reinterpret_cast<uint*>(_v)); break;
        case 1400: _t->setCalibrationMaxMove(*reinterpret_cast<uint*>(_v)); break;
        case 1402: _t->setGuideSquareSize(*reinterpret_cast<QString*>(_v)); break;
        case 1404: _t->setGuideBinning(*reinterpret_cast<QString*>(_v)); break;
        case 1406: _t->setGuideAutoStar(*reinterpret_cast<bool*>(_v)); break;
        case 1408: _t->setGuideShowFrame(*reinterpret_cast<bool*>(_v)); break;
        case 1410: _t->setGuideAutoSquareSizeEnabled(*reinterpret_cast<bool*>(_v)); break;
        case 1412: _t->setAutoModeIterations(*reinterpret_cast<uint*>(_v)); break;
        case 1414: _t->setGuideLostStarTimeout(*reinterpret_cast<uint*>(_v)); break;
        case 1416: _t->setGuideCalibrationTimeout(*reinterpret_cast<uint*>(_v)); break;
        case 1418: _t->setGuideMaxDeltaRMS(*reinterpret_cast<double*>(_v)); break;
        case 1420: _t->setGuideMaxHFR(*reinterpret_cast<double*>(_v)); break;
        case 1422: _t->setMinDetectionsSEPMultistar(*reinterpret_cast<uint*>(_v)); break;
        case 1424: _t->setMaxMultistarReferenceStars(*reinterpret_cast<uint*>(_v)); break;
        case 1426: _t->setAlwaysInventGuideStar(*reinterpret_cast<bool*>(_v)); break;
        case 1428: _t->setTwoAxisEnabled(*reinterpret_cast<bool*>(_v)); break;
        case 1430: _t->setUseGuideHead(*reinterpret_cast<bool*>(_v)); break;
        case 1432: _t->setSaveGuideLog(*reinterpret_cast<bool*>(_v)); break;
        case 1434: _t->setGuideDarkFrame(*reinterpret_cast<bool*>(_v)); break;
        case 1436: _t->setGuideSubframe(*reinterpret_cast<bool*>(_v)); break;
        case 1438: _t->setDitherPixels(*reinterpret_cast<double*>(_v)); break;
        case 1440: _t->setDitherFrames(*reinterpret_cast<uint*>(_v)); break;
        case 1442: _t->setDitherSettle(*reinterpret_cast<uint*>(_v)); break;
        case 1444: _t->setDitherThreshold(*reinterpret_cast<double*>(_v)); break;
        case 1446: _t->setDitherTimeout(*reinterpret_cast<uint*>(_v)); break;
        case 1448: _t->setDitherMaxIterations(*reinterpret_cast<uint*>(_v)); break;
        case 1450: _t->setDitherNoGuidingPulse(*reinterpret_cast<uint*>(_v)); break;
        case 1452: _t->setDitherFailAbortsAutoGuide(*reinterpret_cast<bool*>(_v)); break;
        case 1454: _t->setDitherWithOnePulse(*reinterpret_cast<bool*>(_v)); break;
        case 1456: _t->setDitherEnabled(*reinterpret_cast<bool*>(_v)); break;
        case 1458: _t->setDitherNoGuiding(*reinterpret_cast<bool*>(_v)); break;
        case 1460: _t->setRAGuideEnabled(*reinterpret_cast<bool*>(_v)); break;
        case 1462: _t->setDECGuideEnabled(*reinterpret_cast<bool*>(_v)); break;
        case 1464: _t->setNorthDECGuideEnabled(*reinterpret_cast<bool*>(_v)); break;
        case 1466: _t->setSouthDECGuideEnabled(*reinterpret_cast<bool*>(_v)); break;
        case 1468: _t->setEastRAGuideEnabled(*reinterpret_cast<bool*>(_v)); break;
        case 1470: _t->setWestRAGuideEnabled(*reinterpret_cast<bool*>(_v)); break;
        case 1472: _t->setRAProportionalGain(*reinterpret_cast<double*>(_v)); break;
        case 1474: _t->setDECProportionalGain(*reinterpret_cast<double*>(_v)); break;
        case 1476: _t->setRAIntegralGain(*reinterpret_cast<double*>(_v)); break;
        case 1478: _t->setDECIntegralGain(*reinterpret_cast<double*>(_v)); break;
        case 1480: _t->setRAMinimumPulseArcSec(*reinterpret_cast<double*>(_v)); break;
        case 1482: _t->setDECMinimumPulseArcSec(*reinterpret_cast<double*>(_v)); break;
        case 1484: _t->setRAMaximumPulseArcSec(*reinterpret_cast<uint*>(_v)); break;
        case 1486: _t->setDECMaximumPulseArcSec(*reinterpret_cast<uint*>(_v)); break;
        case 1488: _t->setGPGEnabled(*reinterpret_cast<bool*>(_v)); break;
        case 1490: _t->setGPGDarkGuiding(*reinterpret_cast<bool*>(_v)); break;
        case 1492: _t->setGPGDarkGuidingInterval(*reinterpret_cast<double*>(_v)); break;
        case 1494: _t->setAIDarkGuiding(*reinterpret_cast<bool*>(_v)); break;
        case 1496: _t->setAIDarkGuidingInterval(*reinterpret_cast<double*>(_v)); break;
        case 1498: _t->setGPGcWeight(*reinterpret_cast<double*>(_v)); break;
        case 1500: _t->setGPGMinPeriodsForInference(*reinterpret_cast<uint*>(_v)); break;
        case 1502: _t->setGPGMinMove(*reinterpret_cast<double*>(_v)); break;
        case 1504: _t->setGPGSE0KLengthScale(*reinterpret_cast<uint*>(_v)); break;
        case 1506: _t->setGPGSE0KSignalVariance(*reinterpret_cast<double*>(_v)); break;
        case 1508: _t->setGPGPKLengthScale(*reinterpret_cast<double*>(_v)); break;
        case 1510: _t->setGPGPeriod(*reinterpret_cast<double*>(_v)); break;
        case 1512: _t->setGPGPKSignalVariance(*reinterpret_cast<double*>(_v)); break;
        case 1514: _t->setGPGSE1KLengthScale(*reinterpret_cast<double*>(_v)); break;
        case 1516: _t->setGPGSE1KSignalVariance(*reinterpret_cast<double*>(_v)); break;
        case 1518: _t->setGPGMinPeriodsForPeriodEstimate(*reinterpret_cast<uint*>(_v)); break;
        case 1520: _t->setGPGPointsForApproximation(*reinterpret_cast<uint*>(_v)); break;
        case 1522: _t->setGPGpWeight(*reinterpret_cast<double*>(_v)); break;
        case 1524: _t->setGPGEstimatePeriod(*reinterpret_cast<bool*>(_v)); break;
        case 1526: _t->setGuiderAccuracyThreshold(*reinterpret_cast<uint*>(_v)); break;
        case 1528: _t->setRADisplayedOnGuideGraph(*reinterpret_cast<bool*>(_v)); break;
        case 1530: _t->setDEDisplayedOnGuideGraph(*reinterpret_cast<bool*>(_v)); break;
        case 1532: _t->setRACorrDisplayedOnGuideGraph(*reinterpret_cast<bool*>(_v)); break;
        case 1534: _t->setDECorrDisplayedOnGuideGraph(*reinterpret_cast<bool*>(_v)); break;
        case 1536: _t->setSNRDisplayedOnGuideGraph(*reinterpret_cast<bool*>(_v)); break;
        case 1538: _t->setRMSDisplayedOnGuideGraph(*reinterpret_cast<bool*>(_v)); break;
        case 1540: _t->setRAHysteresis(*reinterpret_cast<double*>(_v)); break;
        case 1542: _t->setDECHysteresis(*reinterpret_cast<double*>(_v)); break;
        case 1544: _t->setSchedulerAlgorithm(*reinterpret_cast<uint*>(_v)); break;
        case 1546: _t->setSchedulerLogging(*reinterpret_cast<bool*>(_v)); break;
        case 1548: _t->setStopEkosAfterShutdown(*reinterpret_cast<bool*>(_v)); break;
        case 1550: _t->setShutdownScriptTerminatesINDI(*reinterpret_cast<bool*>(_v)); break;
        case 1552: _t->setCameraWarmupEnabled(*reinterpret_cast<bool*>(_v)); break;
        case 1554: _t->setCameraWarmupRamp(*reinterpret_cast<uint*>(_v)); break;
        case 1556: _t->setPreemptiveShutdown(*reinterpret_cast<bool*>(_v)); break;
        case 1558: _t->setResetMountModelOnAlignFail(*reinterpret_cast<bool*>(_v)); break;
        case 1560: _t->setResetMountModelBeforeJob(*reinterpret_cast<bool*>(_v)); break;
        case 1562: _t->setResetGuideCalibration(*reinterpret_cast<bool*>(_v)); break;
        case 1564: _t->setForceAlignmentBeforeJob(*reinterpret_cast<bool*>(_v)); break;
        case 1566: _t->setReuseGuideCalibration(*reinterpret_cast<bool*>(_v)); break;
        case 1568: _t->setReverseDecOnPierSideChange(*reinterpret_cast<bool*>(_v)); break;
        case 1570: _t->setGuideCalibrationBacklash(*reinterpret_cast<bool*>(_v)); break;
        case 1572: _t->setAssumeDecOrthogonal(*reinterpret_cast<bool*>(_v)); break;
        case 1574: _t->setSerializedCalibration(*reinterpret_cast<QString*>(_v)); break;
        case 1576: _t->setRealignAfterCalibrationFailure(*reinterpret_cast<bool*>(_v)); break;
        case 1578: _t->setPreemptiveShutdownTime(*reinterpret_cast<double*>(_v)); break;
        case 1580: _t->setRememberJobProgress(*reinterpret_cast<bool*>(_v)); break;
        case 1582: _t->setGreedyScheduling(*reinterpret_cast<bool*>(_v)); break;
        case 1584: _t->setLeadTime(*reinterpret_cast<double*>(_v)); break;
        case 1586: _t->setPreDawnTime(*reinterpret_cast<double*>(_v)); break;
        case 1588: _t->setDawnOffset(*reinterpret_cast<double*>(_v)); break;
        case 1590: _t->setDuskOffset(*reinterpret_cast<double*>(_v)); break;
        case 1592: _t->setTelescopeFocalLength(*reinterpret_cast<double*>(_v)); break;
        case 1594: _t->setTelescopeFocalReducer(*reinterpret_cast<double*>(_v)); break;
        case 1596: _t->setCameraPixelWidth(*reinterpret_cast<double*>(_v)); break;
        case 1598: _t->setCameraPixelHeight(*reinterpret_cast<double*>(_v)); break;
        case 1600: _t->setCameraWidth(*reinterpret_cast<uint*>(_v)); break;
        case 1602: _t->setCameraHeight(*reinterpret_cast<uint*>(_v)); break;
        case 1604: _t->setCameraRotation(*reinterpret_cast<double*>(_v)); break;
        case 1606: _t->setErrorHandlingStrategy(*reinterpret_cast<uint*>(_v)); break;
        case 1608: _t->setErrorHandlingStrategyDelay(*reinterpret_cast<uint*>(_v)); break;
        case 1610: _t->setRescheduleErrors(*reinterpret_cast<bool*>(_v)); break;
        case 1612: _t->setAlignCheckFrequency(*reinterpret_cast<uint*>(_v)); break;
        case 1614: _t->setAlignCheckThreshold(*reinterpret_cast<double*>(_v)); break;
        case 1616: _t->setSchedulerTrackStep(*reinterpret_cast<bool*>(_v)); break;
        case 1618: _t->setSchedulerStartupEnabled(*reinterpret_cast<bool*>(_v)); break;
        case 1620: _t->setSchedulerPreStartupScript(*reinterpret_cast<QString*>(_v)); break;
        case 1622: _t->setSchedulerPostStartupScript(*reinterpret_cast<QString*>(_v)); break;
        case 1624: _t->setSchedulerShutdownEnabled(*reinterpret_cast<bool*>(_v)); break;
        case 1626: _t->setSchedulerPreShutdownScript(*reinterpret_cast<QString*>(_v)); break;
        case 1628: _t->setSchedulerPostShutdownScript(*reinterpret_cast<QString*>(_v)); break;
        case 1630: _t->setSchedulerFocusStep(*reinterpret_cast<bool*>(_v)); break;
        case 1632: _t->setSchedulerGuideStep(*reinterpret_cast<bool*>(_v)); break;
        case 1634: _t->setSchedulerAlignStep(*reinterpret_cast<bool*>(_v)); break;
        case 1636: _t->setSchedulerAltitude(*reinterpret_cast<bool*>(_v)); break;
        case 1638: _t->setSchedulerAltitudeValue(*reinterpret_cast<double*>(_v)); break;
        case 1640: _t->setSchedulerHorizon(*reinterpret_cast<bool*>(_v)); break;
        case 1642: _t->setSchedulerMoonSeparation(*reinterpret_cast<bool*>(_v)); break;
        case 1644: _t->setSchedulerMoonSeparationValue(*reinterpret_cast<double*>(_v)); break;
        case 1646: _t->setSchedulerMoonAltitude(*reinterpret_cast<bool*>(_v)); break;
        case 1648: _t->setSchedulerMoonAltitudeMaxValue(*reinterpret_cast<double*>(_v)); break;
        case 1650: _t->setSchedulerWeather(*reinterpret_cast<bool*>(_v)); break;
        case 1652: _t->setSchedulerWeatherGracePeriod(*reinterpret_cast<uint*>(_v)); break;
        case 1654: _t->setSchedulerWeatherShutdownDelay(*reinterpret_cast<uint*>(_v)); break;
        case 1656: _t->setSchedulerSafetyMonitorConnectionString(*reinterpret_cast<QString*>(_v)); break;
        case 1658: _t->setSchedulerTwilight(*reinterpret_cast<bool*>(_v)); break;
        case 1660: _t->setSchedulerCompleteSequences(*reinterpret_cast<bool*>(_v)); break;
        case 1662: _t->setSchedulerRepeatEverything(*reinterpret_cast<bool*>(_v)); break;
        case 1664: _t->setSchedulerRepeatSequences(*reinterpret_cast<bool*>(_v)); break;
        case 1666: _t->setSchedulerUntilTerminated(*reinterpret_cast<bool*>(_v)); break;
        case 1668: _t->setSchedulerUntil(*reinterpret_cast<bool*>(_v)); break;
        case 1670: _t->setSchedulerUntilValue(*reinterpret_cast<QString*>(_v)); break;
        case 1672: _t->setSchedulerExecutionSequencesLimit(*reinterpret_cast<uint*>(_v)); break;
        case 1674: _t->setAnalyzeRestartWithEkos(*reinterpret_cast<bool*>(_v)); break;
        case 1676: _t->setAnalyzeAlternativeDirectoryName(*reinterpret_cast<QString*>(_v)); break;
        case 1678: _t->setAnalyzeHFR(*reinterpret_cast<bool*>(_v)); break;
        case 1680: _t->setAnalyzeNumCaptureStars(*reinterpret_cast<bool*>(_v)); break;
        case 1682: _t->setAnalyzeMedian(*reinterpret_cast<bool*>(_v)); break;
        case 1684: _t->setAnalyzeEccentricity(*reinterpret_cast<bool*>(_v)); break;
        case 1686: _t->setAnalyzeTemperature(*reinterpret_cast<bool*>(_v)); break;
        case 1688: _t->setFocusPosition(*reinterpret_cast<bool*>(_v)); break;
        case 1690: _t->setAnalyzeNumStars(*reinterpret_cast<bool*>(_v)); break;
        case 1692: _t->setAnalyzeSkyBg(*reinterpret_cast<bool*>(_v)); break;
        case 1694: _t->setAnalyzeSNR(*reinterpret_cast<bool*>(_v)); break;
        case 1696: _t->setAnalyzeRA(*reinterpret_cast<bool*>(_v)); break;
        case 1698: _t->setAnalyzeDEC(*reinterpret_cast<bool*>(_v)); break;
        case 1700: _t->setAnalyzeRAp(*reinterpret_cast<bool*>(_v)); break;
        case 1702: _t->setAnalyzeDECp(*reinterpret_cast<bool*>(_v)); break;
        case 1704: _t->setAnalyzeDrift(*reinterpret_cast<bool*>(_v)); break;
        case 1706: _t->setAnalyzeRMS(*reinterpret_cast<bool*>(_v)); break;
        case 1708: _t->setAnalyzeTargetDistance(*reinterpret_cast<bool*>(_v)); break;
        case 1710: _t->setAnalyzeRMSC(*reinterpret_cast<bool*>(_v)); break;
        case 1712: _t->setAnalyzeMountRA(*reinterpret_cast<bool*>(_v)); break;
        case 1714: _t->setAnalyzeMountDEC(*reinterpret_cast<bool*>(_v)); break;
        case 1716: _t->setAnalyzeMountHA(*reinterpret_cast<bool*>(_v)); break;
        case 1718: _t->setAnalyzeAz(*reinterpret_cast<bool*>(_v)); break;
        case 1720: _t->setAnalyzeAlt(*reinterpret_cast<bool*>(_v)); break;
        case 1722: _t->setAnalyzePierSide(*reinterpret_cast<bool*>(_v)); break;
        case 1724: _t->setAnalyzeStatsYAxis(*reinterpret_cast<QString*>(_v)); break;
        case 1726: _t->setLastServer(*reinterpret_cast<QString*>(_v)); break;
        case 1728: _t->setLastServerPort(*reinterpret_cast<uint*>(_v)); break;
        case 1730: _t->setLastWebManagerPort(*reinterpret_cast<uint*>(_v)); break;
        case 1732: _t->setHIPSMemoryCache(*reinterpret_cast<uint*>(_v)); break;
        case 1734: _t->setHIPSNetCache(*reinterpret_cast<uint*>(_v)); break;
        case 1736: _t->setHIPSSource(*reinterpret_cast<QString*>(_v)); break;
        case 1738: _t->setHIPSBiLinearInterpolation(*reinterpret_cast<bool*>(_v)); break;
        case 1740: _t->setHIPSShowGrid(*reinterpret_cast<bool*>(_v)); break;
        case 1742: _t->setHIPSPanning(*reinterpret_cast<bool*>(_v)); break;
        case 1744: _t->setShowHIPS(*reinterpret_cast<bool*>(_v)); break;
        case 1746: _t->setHIPSUseOfflineSource(*reinterpret_cast<bool*>(_v)); break;
        case 1748: _t->setHIPSOfflinePath(*reinterpret_cast<QString*>(_v)); break;
        case 1750: _t->setTerrainSource(*reinterpret_cast<QString*>(_v)); break;
        case 1752: _t->setTerrainSourceCorrectAz(*reinterpret_cast<int*>(_v)); break;
        case 1754: _t->setTerrainSourceCorrectAlt(*reinterpret_cast<int*>(_v)); break;
        case 1756: _t->setTerrainDownsampling(*reinterpret_cast<int*>(_v)); break;
        case 1758: _t->setTerrainPanning(*reinterpret_cast<bool*>(_v)); break;
        case 1760: _t->setShowTerrain(*reinterpret_cast<bool*>(_v)); break;
        case 1762: _t->setTerrainSkipSpeedup(*reinterpret_cast<bool*>(_v)); break;
        case 1764: _t->setTerrainTransparencySpeedup(*reinterpret_cast<bool*>(_v)); break;
        case 1766: _t->setTerrainSmoothPixels(*reinterpret_cast<bool*>(_v)); break;
        case 1768: _t->setShowImageOverlays(*reinterpret_cast<bool*>(_v)); break;
        case 1770: _t->setShowImageOverlaysBelowCatalogs(*reinterpret_cast<bool*>(_v)); break;
        case 1772: _t->setShowSelectedImageOverlay(*reinterpret_cast<bool*>(_v)); break;
        case 1774: _t->setImageOverlayMaxDimension(*reinterpret_cast<int*>(_v)); break;
        case 1776: _t->setImageOverlayTimeout(*reinterpret_cast<int*>(_v)); break;
        case 1778: _t->setImageOverlayDefaultScale(*reinterpret_cast<double*>(_v)); break;
        case 1780: _t->setDefaultObservatoryWeatherSource(*reinterpret_cast<QString*>(_v)); break;
        case 1782: _t->setWarningActionsActive(*reinterpret_cast<bool*>(_v)); break;
        case 1784: _t->setAlertActionsActive(*reinterpret_cast<bool*>(_v)); break;
        case 1786: _t->setWeatherWarningCloseDome(*reinterpret_cast<bool*>(_v)); break;
        case 1788: _t->setWeatherWarningCloseShutter(*reinterpret_cast<bool*>(_v)); break;
        case 1790: _t->setWeatherWarningStopScheduler(*reinterpret_cast<bool*>(_v)); break;
        case 1792: _t->setWeatherWarningDelay(*reinterpret_cast<uint*>(_v)); break;
        case 1794: _t->setWeatherAlertCloseDome(*reinterpret_cast<bool*>(_v)); break;
        case 1796: _t->setWeatherAlertCloseShutter(*reinterpret_cast<bool*>(_v)); break;
        case 1798: _t->setWeatherAlertStopScheduler(*reinterpret_cast<bool*>(_v)); break;
        case 1800: _t->setWeatherAlertDelay(*reinterpret_cast<uint*>(_v)); break;
        case 1802: _t->setObservatoryStatusUseDome(*reinterpret_cast<bool*>(_v)); break;
        case 1804: _t->setObservatoryStatusUseShutter(*reinterpret_cast<bool*>(_v)); break;
        case 1806: _t->setObservatoryStatusUseWeather(*reinterpret_cast<bool*>(_v)); break;
        case 1808: _t->setWeatherAutoScaleValues(*reinterpret_cast<bool*>(_v)); break;
        case 1810: _t->setASTAPExecutable(*reinterpret_cast<QString*>(_v)); break;
        case 1812: _t->setASTAPDownSample(*reinterpret_cast<bool*>(_v)); break;
        case 1814: _t->setASTAPDownSampleValue(*reinterpret_cast<double*>(_v)); break;
        case 1816: _t->setASTAPSearchRadius(*reinterpret_cast<bool*>(_v)); break;
        case 1818: _t->setASTAPSearchRadiusValue(*reinterpret_cast<double*>(_v)); break;
        case 1820: _t->setASTAPUpdateFITS(*reinterpret_cast<bool*>(_v)); break;
        case 1822: _t->setASTAPLargeSearchWindow(*reinterpret_cast<bool*>(_v)); break;
        case 1824: _t->setMosaicTransparencyAuto(*reinterpret_cast<bool*>(_v)); break;
        case 1826: _t->setMosaicTransparencyLevel(*reinterpret_cast<double*>(_v)); break;
        case 1828: _t->setMCPEnabled(*reinterpret_cast<bool*>(_v)); break;
        case 1830: _t->setMCPPort(*reinterpret_cast<uint*>(_v)); break;
        case 1832: _t->setMCPReadOnlyMode(*reinterpret_cast<bool*>(_v)); break;
        case 1834: _t->setMCPDisabledTools(*reinterpret_cast<QStringList*>(_v)); break;
        default: break;
        }
    }
}

const QMetaObject *Options::metaObject() const
{
    return QObject::d_ptr->metaObject ? QObject::d_ptr->dynamicMetaObject() : &staticMetaObject;
}

void *Options::qt_metacast(const char *_clname)
{
    if (!_clname) return nullptr;
    if (!strcmp(_clname, qt_staticMetaObjectStaticContent<qt_meta_tag_ZN7OptionsE_t>.strings))
        return static_cast<void*>(this);
    return KConfigSkeleton::qt_metacast(_clname);
}

int Options::qt_metacall(QMetaObject::Call _c, int _id, void **_a)
{
    _id = KConfigSkeleton::qt_metacall(_c, _id, _a);
    if (_id < 0)
        return _id;
    if (_c == QMetaObject::InvokeMetaMethod) {
        if (_id < 918)
            qt_static_metacall(this, _c, _id, _a);
        _id -= 918;
    }
    if (_c == QMetaObject::RegisterMethodArgumentMetaType) {
        if (_id < 918)
            *reinterpret_cast<QMetaType *>(_a[0]) = QMetaType();
        _id -= 918;
    }
    if (_c == QMetaObject::ReadProperty || _c == QMetaObject::WriteProperty
            || _c == QMetaObject::ResetProperty || _c == QMetaObject::BindableProperty
            || _c == QMetaObject::RegisterPropertyMetaType) {
        qt_static_metacall(this, _c, _id, _a);
        _id -= 1836;
    }
    return _id;
}

// SIGNAL 0
void Options::PositionTimeBoxChanged()
{
    QMetaObject::activate(this, &staticMetaObject, 0, nullptr);
}

// SIGNAL 1
void Options::PositionFocusBoxChanged()
{
    QMetaObject::activate(this, &staticMetaObject, 1, nullptr);
}

// SIGNAL 2
void Options::PositionGeoBoxChanged()
{
    QMetaObject::activate(this, &staticMetaObject, 2, nullptr);
}

// SIGNAL 3
void Options::ShadeTimeBoxChanged()
{
    QMetaObject::activate(this, &staticMetaObject, 3, nullptr);
}

// SIGNAL 4
void Options::ShadeFocusBoxChanged()
{
    QMetaObject::activate(this, &staticMetaObject, 4, nullptr);
}

// SIGNAL 5
void Options::ShadeGeoBoxChanged()
{
    QMetaObject::activate(this, &staticMetaObject, 5, nullptr);
}

// SIGNAL 6
void Options::ShowInfoBoxesChanged()
{
    QMetaObject::activate(this, &staticMetaObject, 6, nullptr);
}

// SIGNAL 7
void Options::ShowTimeBoxChanged()
{
    QMetaObject::activate(this, &staticMetaObject, 7, nullptr);
}

// SIGNAL 8
void Options::ShowFocusBoxChanged()
{
    QMetaObject::activate(this, &staticMetaObject, 8, nullptr);
}

// SIGNAL 9
void Options::ShowGeoBoxChanged()
{
    QMetaObject::activate(this, &staticMetaObject, 9, nullptr);
}

// SIGNAL 10
void Options::StickyTimeBoxChanged()
{
    QMetaObject::activate(this, &staticMetaObject, 10, nullptr);
}

// SIGNAL 11
void Options::StickyFocusBoxChanged()
{
    QMetaObject::activate(this, &staticMetaObject, 11, nullptr);
}

// SIGNAL 12
void Options::StickyGeoBoxChanged()
{
    QMetaObject::activate(this, &staticMetaObject, 12, nullptr);
}

// SIGNAL 13
void Options::ShowStatusBarChanged()
{
    QMetaObject::activate(this, &staticMetaObject, 13, nullptr);
}

// SIGNAL 14
void Options::ShowAltAzFieldChanged()
{
    QMetaObject::activate(this, &staticMetaObject, 14, nullptr);
}

// SIGNAL 15
void Options::ShowRADecFieldChanged()
{
    QMetaObject::activate(this, &staticMetaObject, 15, nullptr);
}

// SIGNAL 16
void Options::ShowJ2000RADecFieldChanged()
{
    QMetaObject::activate(this, &staticMetaObject, 16, nullptr);
}

// SIGNAL 17
void Options::ShowSensorFOVChanged()
{
    QMetaObject::activate(this, &staticMetaObject, 17, nullptr);
}

// SIGNAL 18
void Options::WindowWidthChanged()
{
    QMetaObject::activate(this, &staticMetaObject, 18, nullptr);
}

// SIGNAL 19
void Options::WindowHeightChanged()
{
    QMetaObject::activate(this, &staticMetaObject, 19, nullptr);
}

// SIGNAL 20
void Options::KStarsGeometryChanged()
{
    QMetaObject::activate(this, &staticMetaObject, 20, nullptr);
}

// SIGNAL 21
void Options::RunStartupWizardChanged()
{
    QMetaObject::activate(this, &staticMetaObject, 21, nullptr);
}

// SIGNAL 22
void Options::CurrentThemeChanged()
{
    QMetaObject::activate(this, &staticMetaObject, 22, nullptr);
}

// SIGNAL 23
void Options::CatalogFileChanged()
{
    QMetaObject::activate(this, &staticMetaObject, 23, nullptr);
}

// SIGNAL 24
void Options::ShowCatalogChanged()
{
    QMetaObject::activate(this, &staticMetaObject, 24, nullptr);
}

// SIGNAL 25
void Options::ShowCatalogNamesChanged()
{
    QMetaObject::activate(this, &staticMetaObject, 25, nullptr);
}

// SIGNAL 26
void Options::ResolveNamesOnlineChanged()
{
    QMetaObject::activate(this, &staticMetaObject, 26, nullptr);
}

// SIGNAL 27
void Options::DSOCachePercentageChanged()
{
    QMetaObject::activate(this, &staticMetaObject, 27, nullptr);
}

// SIGNAL 28
void Options::DSOMinZoomFactorChanged()
{
    QMetaObject::activate(this, &staticMetaObject, 28, nullptr);
}

// SIGNAL 29
void Options::DSOCatalogFilenameChanged()
{
    QMetaObject::activate(this, &staticMetaObject, 29, nullptr);
}

// SIGNAL 30
void Options::DSODefaultCatalogFilenameChanged()
{
    QMetaObject::activate(this, &staticMetaObject, 30, nullptr);
}

// SIGNAL 31
void Options::INDIWindowWidthChanged()
{
    QMetaObject::activate(this, &staticMetaObject, 31, nullptr);
}

// SIGNAL 32
void Options::INDIWindowHeightChanged()
{
    QMetaObject::activate(this, &staticMetaObject, 32, nullptr);
}

// SIGNAL 33
void Options::INDIWindowGeometryChanged()
{
    QMetaObject::activate(this, &staticMetaObject, 33, nullptr);
}

// SIGNAL 34
void Options::useGeographicUpdateChanged()
{
    QMetaObject::activate(this, &staticMetaObject, 34, nullptr);
}

// SIGNAL 35
void Options::useTimeUpdateChanged()
{
    QMetaObject::activate(this, &staticMetaObject, 35, nullptr);
}

// SIGNAL 36
void Options::independentWindowINDIChanged()
{
    QMetaObject::activate(this, &staticMetaObject, 36, nullptr);
}

// SIGNAL 37
void Options::showTargetCrosshairChanged()
{
    QMetaObject::activate(this, &staticMetaObject, 37, nullptr);
}

// SIGNAL 38
void Options::showINDIMessagesChanged()
{
    QMetaObject::activate(this, &staticMetaObject, 38, nullptr);
}

// SIGNAL 39
void Options::showINDIwindowInitiallyChanged()
{
    QMetaObject::activate(this, &staticMetaObject, 39, nullptr);
}

// SIGNAL 40
void Options::maxFocusFrameFilesChanged()
{
    QMetaObject::activate(this, &staticMetaObject, 40, nullptr);
}

// SIGNAL 41
void Options::messageNotificationINDIChanged()
{
    QMetaObject::activate(this, &staticMetaObject, 41, nullptr);
}

// SIGNAL 42
void Options::timeSourceChanged()
{
    QMetaObject::activate(this, &staticMetaObject, 42, nullptr);
}

// SIGNAL 43
void Options::locationSourceChanged()
{
    QMetaObject::activate(this, &staticMetaObject, 43, nullptr);
}

// SIGNAL 44
void Options::useExternalSkyMapChanged()
{
    QMetaObject::activate(this, &staticMetaObject, 44, nullptr);
}

// SIGNAL 45
void Options::fitsDirChanged()
{
    QMetaObject::activate(this, &staticMetaObject, 45, nullptr);
}

// SIGNAL 46
void Options::serverTransferBufferSizeChanged()
{
    QMetaObject::activate(this, &staticMetaObject, 46, nullptr);
}

// SIGNAL 47
void Options::serverPortStartChanged()
{
    QMetaObject::activate(this, &staticMetaObject, 47, nullptr);
}

// SIGNAL 48
void Options::serverPortEndChanged()
{
    QMetaObject::activate(this, &staticMetaObject, 48, nullptr);
}

// SIGNAL 49
void Options::indiServerChanged()
{
    QMetaObject::activate(this, &staticMetaObject, 49, nullptr);
}

// SIGNAL 50
void Options::indiServerIsInternalChanged()
{
    QMetaObject::activate(this, &staticMetaObject, 50, nullptr);
}

// SIGNAL 51
void Options::indiDriversDirChanged()
{
    QMetaObject::activate(this, &staticMetaObject, 51, nullptr);
}

// SIGNAL 52
void Options::indiDriversAreInternalChanged()
{
    QMetaObject::activate(this, &staticMetaObject, 52, nullptr);
}

// SIGNAL 53
void Options::streamWindowWidthChanged()
{
    QMetaObject::activate(this, &staticMetaObject, 53, nullptr);
}

// SIGNAL 54
void Options::streamWindowHeightChanged()
{
    QMetaObject::activate(this, &staticMetaObject, 54, nullptr);
}

// SIGNAL 55
void Options::INDIMountLoggingChanged()
{
    QMetaObject::activate(this, &staticMetaObject, 55, nullptr);
}

// SIGNAL 56
void Options::INDIFocuserLoggingChanged()
{
    QMetaObject::activate(this, &staticMetaObject, 56, nullptr);
}

// SIGNAL 57
void Options::INDICCDLoggingChanged()
{
    QMetaObject::activate(this, &staticMetaObject, 57, nullptr);
}

// SIGNAL 58
void Options::INDIFilterWheelLoggingChanged()
{
    QMetaObject::activate(this, &staticMetaObject, 58, nullptr);
}

// SIGNAL 59
void Options::INDIDomeLoggingChanged()
{
    QMetaObject::activate(this, &staticMetaObject, 59, nullptr);
}

// SIGNAL 60
void Options::INDIDetectorLoggingChanged()
{
    QMetaObject::activate(this, &staticMetaObject, 60, nullptr);
}

// SIGNAL 61
void Options::INDIWeatherLoggingChanged()
{
    QMetaObject::activate(this, &staticMetaObject, 61, nullptr);
}

// SIGNAL 62
void Options::INDIAuxiliaryLoggingChanged()
{
    QMetaObject::activate(this, &staticMetaObject, 62, nullptr);
}

// SIGNAL 63
void Options::INDIRotatorLoggingChanged()
{
    QMetaObject::activate(this, &staticMetaObject, 63, nullptr);
}

// SIGNAL 64
void Options::INDIGPSLoggingChanged()
{
    QMetaObject::activate(this, &staticMetaObject, 64, nullptr);
}

// SIGNAL 65
void Options::INDIAOLoggingChanged()
{
    QMetaObject::activate(this, &staticMetaObject, 65, nullptr);
}

// SIGNAL 66
void Options::CityNameChanged()
{
    QMetaObject::activate(this, &staticMetaObject, 66, nullptr);
}

// SIGNAL 67
void Options::ProvinceNameChanged()
{
    QMetaObject::activate(this, &staticMetaObject, 67, nullptr);
}

// SIGNAL 68
void Options::CountryNameChanged()
{
    QMetaObject::activate(this, &staticMetaObject, 68, nullptr);
}

// SIGNAL 69
void Options::LongitudeChanged()
{
    QMetaObject::activate(this, &staticMetaObject, 69, nullptr);
}

// SIGNAL 70
void Options::LatitudeChanged()
{
    QMetaObject::activate(this, &staticMetaObject, 70, nullptr);
}

// SIGNAL 71
void Options::ElevationChanged()
{
    QMetaObject::activate(this, &staticMetaObject, 71, nullptr);
}

// SIGNAL 72
void Options::TimeZoneChanged()
{
    QMetaObject::activate(this, &staticMetaObject, 72, nullptr);
}

// SIGNAL 73
void Options::DSTChanged()
{
    QMetaObject::activate(this, &staticMetaObject, 73, nullptr);
}

// SIGNAL 74
void Options::UseAnimatedSlewingChanged()
{
    QMetaObject::activate(this, &staticMetaObject, 74, nullptr);
}

// SIGNAL 75
void Options::LeftClickSelectsObjectChanged()
{
    QMetaObject::activate(this, &staticMetaObject, 75, nullptr);
}

// SIGNAL 76
void Options::DefaultCursorChanged()
{
    QMetaObject::activate(this, &staticMetaObject, 76, nullptr);
}

// SIGNAL 77
void Options::FOVNamesChanged()
{
    QMetaObject::activate(this, &staticMetaObject, 77, nullptr);
}

// SIGNAL 78
void Options::FadePlanetTrailsChanged()
{
    QMetaObject::activate(this, &staticMetaObject, 78, nullptr);
}

// SIGNAL 79
void Options::FocusRAChanged()
{
    QMetaObject::activate(this, &staticMetaObject, 79, nullptr);
}

// SIGNAL 80
void Options::FocusDecChanged()
{
    QMetaObject::activate(this, &staticMetaObject, 80, nullptr);
}

// SIGNAL 81
void Options::FocusObjectChanged()
{
    QMetaObject::activate(this, &staticMetaObject, 81, nullptr);
}

// SIGNAL 82
void Options::IsTrackingChanged()
{
    QMetaObject::activate(this, &staticMetaObject, 82, nullptr);
}

// SIGNAL 83
void Options::HideOnSlewChanged()
{
    QMetaObject::activate(this, &staticMetaObject, 83, nullptr);
}

// SIGNAL 84
void Options::HideCBoundsChanged()
{
    QMetaObject::activate(this, &staticMetaObject, 84, nullptr);
}

// SIGNAL 85
void Options::HideCLinesChanged()
{
    QMetaObject::activate(this, &staticMetaObject, 85, nullptr);
}

// SIGNAL 86
void Options::SkyCultureChanged()
{
    QMetaObject::activate(this, &staticMetaObject, 86, nullptr);
}

// SIGNAL 87
void Options::HideCNamesChanged()
{
    QMetaObject::activate(this, &staticMetaObject, 87, nullptr);
}

// SIGNAL 88
void Options::HideGridsChanged()
{
    QMetaObject::activate(this, &staticMetaObject, 88, nullptr);
}

// SIGNAL 89
void Options::HideMilkyWayChanged()
{
    QMetaObject::activate(this, &staticMetaObject, 89, nullptr);
}

// SIGNAL 90
void Options::HideOtherChanged()
{
    QMetaObject::activate(this, &staticMetaObject, 90, nullptr);
}

// SIGNAL 91
void Options::HidePlanetsChanged()
{
    QMetaObject::activate(this, &staticMetaObject, 91, nullptr);
}

// SIGNAL 92
void Options::HideStarsChanged()
{
    QMetaObject::activate(this, &staticMetaObject, 92, nullptr);
}

// SIGNAL 93
void Options::HideLabelsChanged()
{
    QMetaObject::activate(this, &staticMetaObject, 93, nullptr);
}

// SIGNAL 94
void Options::ShowAsteroidsChanged()
{
    QMetaObject::activate(this, &staticMetaObject, 94, nullptr);
}

// SIGNAL 95
void Options::ShowAsteroidNamesChanged()
{
    QMetaObject::activate(this, &staticMetaObject, 95, nullptr);
}

// SIGNAL 96
void Options::OrbitalElementsAutoUpdateChanged()
{
    QMetaObject::activate(this, &staticMetaObject, 96, nullptr);
}

// SIGNAL 97
void Options::ShowCometsChanged()
{
    QMetaObject::activate(this, &staticMetaObject, 97, nullptr);
}

// SIGNAL 98
void Options::ShowCometComasChanged()
{
    QMetaObject::activate(this, &staticMetaObject, 98, nullptr);
}

// SIGNAL 99
void Options::ShowCometNamesChanged()
{
    QMetaObject::activate(this, &staticMetaObject, 99, nullptr);
}

// SIGNAL 100
void Options::ShowSupernovaeChanged()
{
    QMetaObject::activate(this, &staticMetaObject, 100, nullptr);
}

// SIGNAL 101
void Options::ShowSupernovaNamesChanged()
{
    QMetaObject::activate(this, &staticMetaObject, 101, nullptr);
}

// SIGNAL 102
void Options::MagnitudeLimitShowSupernovaeChanged()
{
    QMetaObject::activate(this, &staticMetaObject, 102, nullptr);
}

// SIGNAL 103
void Options::SupernovaDetectionAgeChanged()
{
    QMetaObject::activate(this, &staticMetaObject, 103, nullptr);
}

// SIGNAL 104
void Options::SupernovaDownloadUrlChanged()
{
    QMetaObject::activate(this, &staticMetaObject, 104, nullptr);
}

// SIGNAL 105
void Options::LimitSupernovaeByZoomChanged()
{
    QMetaObject::activate(this, &staticMetaObject, 105, nullptr);
}

// SIGNAL 106
void Options::SupernovaeHostOnlyChanged()
{
    QMetaObject::activate(this, &staticMetaObject, 106, nullptr);
}

// SIGNAL 107
void Options::SupernovaeClassifiedOnlyChanged()
{
    QMetaObject::activate(this, &staticMetaObject, 107, nullptr);
}

// SIGNAL 108
void Options::ShowSupernovaAlertsChanged()
{
    QMetaObject::activate(this, &staticMetaObject, 108, nullptr);
}

// SIGNAL 109
void Options::MagnitudeLimitAlertSupernovaeChanged()
{
    QMetaObject::activate(this, &staticMetaObject, 109, nullptr);
}

// SIGNAL 110
void Options::ShowCBoundsChanged()
{
    QMetaObject::activate(this, &staticMetaObject, 110, nullptr);
}

// SIGNAL 111
void Options::ShowHighlightedCBoundChanged()
{
    QMetaObject::activate(this, &staticMetaObject, 111, nullptr);
}

// SIGNAL 112
void Options::ShowCLinesChanged()
{
    QMetaObject::activate(this, &staticMetaObject, 112, nullptr);
}

// SIGNAL 113
void Options::ShowConstellationArtChanged()
{
    QMetaObject::activate(this, &staticMetaObject, 113, nullptr);
}

// SIGNAL 114
void Options::ShowCNamesChanged()
{
    QMetaObject::activate(this, &staticMetaObject, 114, nullptr);
}

// SIGNAL 115
void Options::ShowDeepSkyChanged()
{
    QMetaObject::activate(this, &staticMetaObject, 115, nullptr);
}

// SIGNAL 116
void Options::ShowEclipticChanged()
{
    QMetaObject::activate(this, &staticMetaObject, 116, nullptr);
}

// SIGNAL 117
void Options::ShowEquatorChanged()
{
    QMetaObject::activate(this, &staticMetaObject, 117, nullptr);
}

// SIGNAL 118
void Options::AutoSelectGridChanged()
{
    QMetaObject::activate(this, &staticMetaObject, 118, nullptr);
}

// SIGNAL 119
void Options::ShowEquatorialGridChanged()
{
    QMetaObject::activate(this, &staticMetaObject, 119, nullptr);
}

// SIGNAL 120
void Options::ShowHorizontalGridChanged()
{
    QMetaObject::activate(this, &staticMetaObject, 120, nullptr);
}

// SIGNAL 121
void Options::ShowLocalMeridianChanged()
{
    QMetaObject::activate(this, &staticMetaObject, 121, nullptr);
}

// SIGNAL 122
void Options::ShowGroundChanged()
{
    QMetaObject::activate(this, &staticMetaObject, 122, nullptr);
}

// SIGNAL 123
void Options::ShowHorizonChanged()
{
    QMetaObject::activate(this, &staticMetaObject, 123, nullptr);
}

// SIGNAL 124
void Options::ShowFlagsChanged()
{
    QMetaObject::activate(this, &staticMetaObject, 124, nullptr);
}

// SIGNAL 125
void Options::SimulateDaytimeChanged()
{
    QMetaObject::activate(this, &staticMetaObject, 125, nullptr);
}

// SIGNAL 126
void Options::ShowOtherChanged()
{
    QMetaObject::activate(this, &staticMetaObject, 126, nullptr);
}

// SIGNAL 127
void Options::ShowMilkyWayChanged()
{
    QMetaObject::activate(this, &staticMetaObject, 127, nullptr);
}

// SIGNAL 128
void Options::FillMilkyWayChanged()
{
    QMetaObject::activate(this, &staticMetaObject, 128, nullptr);
}

// SIGNAL 129
void Options::ShowSolarSystemChanged()
{
    QMetaObject::activate(this, &staticMetaObject, 129, nullptr);
}

// SIGNAL 130
void Options::ShowPlanetImagesChanged()
{
    QMetaObject::activate(this, &staticMetaObject, 130, nullptr);
}

// SIGNAL 131
void Options::ShowPlanetNamesChanged()
{
    QMetaObject::activate(this, &staticMetaObject, 131, nullptr);
}

// SIGNAL 132
void Options::ShowSunChanged()
{
    QMetaObject::activate(this, &staticMetaObject, 132, nullptr);
}

// SIGNAL 133
void Options::SunScaleChanged()
{
    QMetaObject::activate(this, &staticMetaObject, 133, nullptr);
}

// SIGNAL 134
void Options::ShowMoonChanged()
{
    QMetaObject::activate(this, &staticMetaObject, 134, nullptr);
}

// SIGNAL 135
void Options::MoonScaleChanged()
{
    QMetaObject::activate(this, &staticMetaObject, 135, nullptr);
}

// SIGNAL 136
void Options::ShowMercuryChanged()
{
    QMetaObject::activate(this, &staticMetaObject, 136, nullptr);
}

// SIGNAL 137
void Options::ShowVenusChanged()
{
    QMetaObject::activate(this, &staticMetaObject, 137, nullptr);
}

// SIGNAL 138
void Options::ShowMarsChanged()
{
    QMetaObject::activate(this, &staticMetaObject, 138, nullptr);
}

// SIGNAL 139
void Options::ShowJupiterChanged()
{
    QMetaObject::activate(this, &staticMetaObject, 139, nullptr);
}

// SIGNAL 140
void Options::ShowSaturnChanged()
{
    QMetaObject::activate(this, &staticMetaObject, 140, nullptr);
}

// SIGNAL 141
void Options::ShowUranusChanged()
{
    QMetaObject::activate(this, &staticMetaObject, 141, nullptr);
}

// SIGNAL 142
void Options::ShowNeptuneChanged()
{
    QMetaObject::activate(this, &staticMetaObject, 142, nullptr);
}

// SIGNAL 143
void Options::ShowPlutoChanged()
{
    QMetaObject::activate(this, &staticMetaObject, 143, nullptr);
}

// SIGNAL 144
void Options::ShowStarsChanged()
{
    QMetaObject::activate(this, &staticMetaObject, 144, nullptr);
}

// SIGNAL 145
void Options::ShowStarMagnitudesChanged()
{
    QMetaObject::activate(this, &staticMetaObject, 145, nullptr);
}

// SIGNAL 146
void Options::ShowStarsOverHIPSChanged()
{
    QMetaObject::activate(this, &staticMetaObject, 146, nullptr);
}

// SIGNAL 147
void Options::ShowStarNamesChanged()
{
    QMetaObject::activate(this, &staticMetaObject, 147, nullptr);
}

// SIGNAL 148
void Options::ShowDeepSkyMagnitudesChanged()
{
    QMetaObject::activate(this, &staticMetaObject, 148, nullptr);
}

// SIGNAL 149
void Options::ShowDeepSkyNamesChanged()
{
    QMetaObject::activate(this, &staticMetaObject, 149, nullptr);
}

// SIGNAL 150
void Options::ShowMosaicPanelChanged()
{
    QMetaObject::activate(this, &staticMetaObject, 150, nullptr);
}

// SIGNAL 151
void Options::SlewTimeScaleChanged()
{
    QMetaObject::activate(this, &staticMetaObject, 151, nullptr);
}

// SIGNAL 152
void Options::BoxBGModeChanged()
{
    QMetaObject::activate(this, &staticMetaObject, 152, nullptr);
}

// SIGNAL 153
void Options::ProjectionChanged()
{
    QMetaObject::activate(this, &staticMetaObject, 153, nullptr);
}

// SIGNAL 154
void Options::UseAbbrevConstellNamesChanged()
{
    QMetaObject::activate(this, &staticMetaObject, 154, nullptr);
}

// SIGNAL 155
void Options::UseLatinConstellNamesChanged()
{
    QMetaObject::activate(this, &staticMetaObject, 155, nullptr);
}

// SIGNAL 156
void Options::UseLocalConstellNamesChanged()
{
    QMetaObject::activate(this, &staticMetaObject, 156, nullptr);
}

// SIGNAL 157
void Options::UseAltAzChanged()
{
    QMetaObject::activate(this, &staticMetaObject, 157, nullptr);
}

// SIGNAL 158
void Options::UseAutoLabelChanged()
{
    QMetaObject::activate(this, &staticMetaObject, 158, nullptr);
}

// SIGNAL 159
void Options::UseAutoTrailChanged()
{
    QMetaObject::activate(this, &staticMetaObject, 159, nullptr);
}

// SIGNAL 160
void Options::UseHoverLabelChanged()
{
    QMetaObject::activate(this, &staticMetaObject, 160, nullptr);
}

// SIGNAL 161
void Options::UseRefractionChanged()
{
    QMetaObject::activate(this, &staticMetaObject, 161, nullptr);
}

// SIGNAL 162
void Options::UseRelativisticChanged()
{
    QMetaObject::activate(this, &staticMetaObject, 162, nullptr);
}

// SIGNAL 163
void Options::UseAntialiasChanged()
{
    QMetaObject::activate(this, &staticMetaObject, 163, nullptr);
}

// SIGNAL 164
void Options::ZoomFactorChanged()
{
    QMetaObject::activate(this, &staticMetaObject, 164, nullptr);
}

// SIGNAL 165
void Options::SkyRotationChanged()
{
    QMetaObject::activate(this, &staticMetaObject, 165, nullptr);
}

// SIGNAL 166
void Options::MirrorSkyMapChanged()
{
    QMetaObject::activate(this, &staticMetaObject, 166, nullptr);
}

// SIGNAL 167
void Options::ErectObserverCorrectionChanged()
{
    QMetaObject::activate(this, &staticMetaObject, 167, nullptr);
}

// SIGNAL 168
void Options::ZoomScrollFactorChanged()
{
    QMetaObject::activate(this, &staticMetaObject, 168, nullptr);
}

// SIGNAL 169
void Options::MagLimitAsteroidChanged()
{
    QMetaObject::activate(this, &staticMetaObject, 169, nullptr);
}

// SIGNAL 170
void Options::MagLimitAsteroidDownloadChanged()
{
    QMetaObject::activate(this, &staticMetaObject, 170, nullptr);
}

// SIGNAL 171
void Options::AsteroidLabelDensityChanged()
{
    QMetaObject::activate(this, &staticMetaObject, 171, nullptr);
}

// SIGNAL 172
void Options::MagLimitDrawDeepSkyChanged()
{
    QMetaObject::activate(this, &staticMetaObject, 172, nullptr);
}

// SIGNAL 173
void Options::MagLimitDrawDeepSkyZoomOutChanged()
{
    QMetaObject::activate(this, &staticMetaObject, 173, nullptr);
}

// SIGNAL 174
void Options::ShowUnknownMagObjectsChanged()
{
    QMetaObject::activate(this, &staticMetaObject, 174, nullptr);
}

// SIGNAL 175
void Options::ShowInlineImagesChanged()
{
    QMetaObject::activate(this, &staticMetaObject, 175, nullptr);
}

// SIGNAL 176
void Options::StarDensityChanged()
{
    QMetaObject::activate(this, &staticMetaObject, 176, nullptr);
}

// SIGNAL 177
void Options::MagLimitHideStarChanged()
{
    QMetaObject::activate(this, &staticMetaObject, 177, nullptr);
}

// SIGNAL 178
void Options::StarLabelDensityChanged()
{
    QMetaObject::activate(this, &staticMetaObject, 178, nullptr);
}

// SIGNAL 179
void Options::DeepSkyLabelDensityChanged()
{
    QMetaObject::activate(this, &staticMetaObject, 179, nullptr);
}

// SIGNAL 180
void Options::DeepSkyLongLabelsChanged()
{
    QMetaObject::activate(this, &staticMetaObject, 180, nullptr);
}

// SIGNAL 181
void Options::LabelFontScalingChanged()
{
    QMetaObject::activate(this, &staticMetaObject, 181, nullptr);
}

// SIGNAL 182
void Options::MaxRadCometNameChanged()
{
    QMetaObject::activate(this, &staticMetaObject, 182, nullptr);
}

// SIGNAL 183
void Options::UseGLChanged()
{
    QMetaObject::activate(this, &staticMetaObject, 183, nullptr);
}

// SIGNAL 184
void Options::RunClockChanged()
{
    QMetaObject::activate(this, &staticMetaObject, 184, nullptr);
}

// SIGNAL 185
void Options::ImagingPlannerAcceptOpenClusterChanged()
{
    QMetaObject::activate(this, &staticMetaObject, 185, nullptr);
}

// SIGNAL 186
void Options::ImagingPlannerAcceptNebulaChanged()
{
    QMetaObject::activate(this, &staticMetaObject, 186, nullptr);
}

// SIGNAL 187
void Options::ImagingPlannerAcceptGlobularClusterChanged()
{
    QMetaObject::activate(this, &staticMetaObject, 187, nullptr);
}

// SIGNAL 188
void Options::ImagingPlannerAcceptPlanetaryChanged()
{
    QMetaObject::activate(this, &staticMetaObject, 188, nullptr);
}

// SIGNAL 189
void Options::ImagingPlannerAcceptSupernovaRemnantChanged()
{
    QMetaObject::activate(this, &staticMetaObject, 189, nullptr);
}

// SIGNAL 190
void Options::ImagingPlannerAcceptGalaxyChanged()
{
    QMetaObject::activate(this, &staticMetaObject, 190, nullptr);
}

// SIGNAL 191
void Options::ImagingPlannerAcceptGalaxyClusterChanged()
{
    QMetaObject::activate(this, &staticMetaObject, 191, nullptr);
}

// SIGNAL 192
void Options::ImagingPlannerAcceptDarkNebulaChanged()
{
    QMetaObject::activate(this, &staticMetaObject, 192, nullptr);
}

// SIGNAL 193
void Options::ImagingPlannerAcceptOtherChanged()
{
    QMetaObject::activate(this, &staticMetaObject, 193, nullptr);
}

// SIGNAL 194
void Options::AstrobinAwardChanged()
{
    QMetaObject::activate(this, &staticMetaObject, 194, nullptr);
}

// SIGNAL 195
void Options::AstrobinMinRadiusChanged()
{
    QMetaObject::activate(this, &staticMetaObject, 195, nullptr);
}

// SIGNAL 196
void Options::AstrobinMaxRadiusChanged()
{
    QMetaObject::activate(this, &staticMetaObject, 196, nullptr);
}

// SIGNAL 197
void Options::ImagingPlannerUseArtificialHorizonChanged()
{
    QMetaObject::activate(this, &staticMetaObject, 197, nullptr);
}

// SIGNAL 198
void Options::ImagingPlannerMinHoursChanged()
{
    QMetaObject::activate(this, &staticMetaObject, 198, nullptr);
}

// SIGNAL 199
void Options::ImagingPlannerMinAltitudeChanged()
{
    QMetaObject::activate(this, &staticMetaObject, 199, nullptr);
}

// SIGNAL 200
void Options::ImagingPlannerMinMoonSeparationChanged()
{
    QMetaObject::activate(this, &staticMetaObject, 200, nullptr);
}

// SIGNAL 201
void Options::ImagingPlannerMaxMoonAltitudeChanged()
{
    QMetaObject::activate(this, &staticMetaObject, 201, nullptr);
}

// SIGNAL 202
void Options::ImagingPlannerShowPickedChanged()
{
    QMetaObject::activate(this, &staticMetaObject, 202, nullptr);
}

// SIGNAL 203
void Options::ImagingPlannerShowNotPickedChanged()
{
    QMetaObject::activate(this, &staticMetaObject, 203, nullptr);
}

// SIGNAL 204
void Options::ImagingPlannerDontCarePickedChanged()
{
    QMetaObject::activate(this, &staticMetaObject, 204, nullptr);
}

// SIGNAL 205
void Options::ImagingPlannerShowKeywordChanged()
{
    QMetaObject::activate(this, &staticMetaObject, 205, nullptr);
}

// SIGNAL 206
void Options::ImagingPlannerShowNotKeywordChanged()
{
    QMetaObject::activate(this, &staticMetaObject, 206, nullptr);
}

// SIGNAL 207
void Options::ImagingPlannerDontCareKeywordChanged()
{
    QMetaObject::activate(this, &staticMetaObject, 207, nullptr);
}

// SIGNAL 208
void Options::ImagingPlannerKeywordChanged()
{
    QMetaObject::activate(this, &staticMetaObject, 208, nullptr);
}

// SIGNAL 209
void Options::ImagingPlannerShowImagedChanged()
{
    QMetaObject::activate(this, &staticMetaObject, 209, nullptr);
}

// SIGNAL 210
void Options::ImagingPlannerShowNotImagedChanged()
{
    QMetaObject::activate(this, &staticMetaObject, 210, nullptr);
}

// SIGNAL 211
void Options::ImagingPlannerDontCareImagedChanged()
{
    QMetaObject::activate(this, &staticMetaObject, 211, nullptr);
}

// SIGNAL 212
void Options::ImagingPlannerShowAddedChanged()
{
    QMetaObject::activate(this, &staticMetaObject, 212, nullptr);
}

// SIGNAL 213
void Options::ImagingPlannerShowNotAddedChanged()
{
    QMetaObject::activate(this, &staticMetaObject, 213, nullptr);
}

// SIGNAL 214
void Options::ImagingPlannerDontCareAddedChanged()
{
    QMetaObject::activate(this, &staticMetaObject, 214, nullptr);
}

// SIGNAL 215
void Options::ImagingPlannerShowIgnoredChanged()
{
    QMetaObject::activate(this, &staticMetaObject, 215, nullptr);
}

// SIGNAL 216
void Options::ImagingPlannerShowNotIgnoredChanged()
{
    QMetaObject::activate(this, &staticMetaObject, 216, nullptr);
}

// SIGNAL 217
void Options::ImagingPlannerDontCareIgnoredChanged()
{
    QMetaObject::activate(this, &staticMetaObject, 217, nullptr);
}

// SIGNAL 218
void Options::ImagingPlannerHideAstrobinDetailsChanged()
{
    QMetaObject::activate(this, &staticMetaObject, 218, nullptr);
}

// SIGNAL 219
void Options::ImagingPlannerHideFiltersChanged()
{
    QMetaObject::activate(this, &staticMetaObject, 219, nullptr);
}

// SIGNAL 220
void Options::ImagingPlannerHideImageChanged()
{
    QMetaObject::activate(this, &staticMetaObject, 220, nullptr);
}

// SIGNAL 221
void Options::ImagingPlannerHideAltitudeGraphChanged()
{
    QMetaObject::activate(this, &staticMetaObject, 221, nullptr);
}

// SIGNAL 222
void Options::ImagingPlannerCatalogPathChanged()
{
    QMetaObject::activate(this, &staticMetaObject, 222, nullptr);
}

// SIGNAL 223
void Options::ImagingPlannerCenterOnSkyMapChanged()
{
    QMetaObject::activate(this, &staticMetaObject, 223, nullptr);
}

// SIGNAL 224
void Options::ImagingPlannerIndependentWindowChanged()
{
    QMetaObject::activate(this, &staticMetaObject, 224, nullptr);
}

// SIGNAL 225
void Options::ImagingPlannerStartSolvingImmediatelyChanged()
{
    QMetaObject::activate(this, &staticMetaObject, 225, nullptr);
}

// SIGNAL 226
void Options::ObsListSymbolChanged()
{
    QMetaObject::activate(this, &staticMetaObject, 226, nullptr);
}

// SIGNAL 227
void Options::ObsListTextChanged()
{
    QMetaObject::activate(this, &staticMetaObject, 227, nullptr);
}

// SIGNAL 228
void Options::ObsListPreferDSSChanged()
{
    QMetaObject::activate(this, &staticMetaObject, 228, nullptr);
}

// SIGNAL 229
void Options::ObsListPreferSDSSChanged()
{
    QMetaObject::activate(this, &staticMetaObject, 229, nullptr);
}

// SIGNAL 230
void Options::ObsListDemoteHoleChanged()
{
    QMetaObject::activate(this, &staticMetaObject, 230, nullptr);
}

// SIGNAL 231
void Options::ObsListHoleSizeChanged()
{
    QMetaObject::activate(this, &staticMetaObject, 231, nullptr);
}

// SIGNAL 232
void Options::ObsListCoverageChanged()
{
    QMetaObject::activate(this, &staticMetaObject, 232, nullptr);
}

// SIGNAL 233
void Options::ColorSchemeFileChanged()
{
    QMetaObject::activate(this, &staticMetaObject, 233, nullptr);
}

// SIGNAL 234
void Options::StarColorModeChanged()
{
    QMetaObject::activate(this, &staticMetaObject, 234, nullptr);
}

// SIGNAL 235
void Options::StarColorIntensityChanged()
{
    QMetaObject::activate(this, &staticMetaObject, 235, nullptr);
}

// SIGNAL 236
void Options::DomeSlitInvertedChanged()
{
    QMetaObject::activate(this, &staticMetaObject, 236, nullptr);
}

// SIGNAL 237
void Options::AngularRulerColorChanged()
{
    QMetaObject::activate(this, &staticMetaObject, 237, nullptr);
}

// SIGNAL 238
void Options::BoxBGColorChanged()
{
    QMetaObject::activate(this, &staticMetaObject, 238, nullptr);
}

// SIGNAL 239
void Options::BoxGrabColorChanged()
{
    QMetaObject::activate(this, &staticMetaObject, 239, nullptr);
}

// SIGNAL 240
void Options::BoxTextColorChanged()
{
    QMetaObject::activate(this, &staticMetaObject, 240, nullptr);
}

// SIGNAL 241
void Options::CBoundColorChanged()
{
    QMetaObject::activate(this, &staticMetaObject, 241, nullptr);
}

// SIGNAL 242
void Options::CBoundHighColorChanged()
{
    QMetaObject::activate(this, &staticMetaObject, 242, nullptr);
}

// SIGNAL 243
void Options::CLineColorChanged()
{
    QMetaObject::activate(this, &staticMetaObject, 243, nullptr);
}

// SIGNAL 244
void Options::CNameColorChanged()
{
    QMetaObject::activate(this, &staticMetaObject, 244, nullptr);
}

// SIGNAL 245
void Options::CompassColorChanged()
{
    QMetaObject::activate(this, &staticMetaObject, 245, nullptr);
}

// SIGNAL 246
void Options::EclipticColorChanged()
{
    QMetaObject::activate(this, &staticMetaObject, 246, nullptr);
}

// SIGNAL 247
void Options::EquatorColorChanged()
{
    QMetaObject::activate(this, &staticMetaObject, 247, nullptr);
}

// SIGNAL 248
void Options::EquatorialGridColorChanged()
{
    QMetaObject::activate(this, &staticMetaObject, 248, nullptr);
}

// SIGNAL 249
void Options::HorizontalGridColorChanged()
{
    QMetaObject::activate(this, &staticMetaObject, 249, nullptr);
}

// SIGNAL 250
void Options::SpecialObjectColorChanged()
{
    QMetaObject::activate(this, &staticMetaObject, 250, nullptr);
}

// SIGNAL 251
void Options::HorizonColorChanged()
{
    QMetaObject::activate(this, &staticMetaObject, 251, nullptr);
}

// SIGNAL 252
void Options::LocalMeridianColorChanged()
{
    QMetaObject::activate(this, &staticMetaObject, 252, nullptr);
}

// SIGNAL 253
void Options::MilkyWayWColorChanged()
{
    QMetaObject::activate(this, &staticMetaObject, 253, nullptr);
}

// SIGNAL 254
void Options::StarNameColorChanged()
{
    QMetaObject::activate(this, &staticMetaObject, 254, nullptr);
}

// SIGNAL 255
void Options::DeepSkyNameColorChanged()
{
    QMetaObject::activate(this, &staticMetaObject, 255, nullptr);
}

// SIGNAL 256
void Options::PlanetNameColorChanged()
{
    QMetaObject::activate(this, &staticMetaObject, 256, nullptr);
}

// SIGNAL 257
void Options::PlanetTrailColorChanged()
{
    QMetaObject::activate(this, &staticMetaObject, 257, nullptr);
}

// SIGNAL 258
void Options::SkyColorChanged()
{
    QMetaObject::activate(this, &staticMetaObject, 258, nullptr);
}

// SIGNAL 259
void Options::SkyColorDaytimeChanged()
{
    QMetaObject::activate(this, &staticMetaObject, 259, nullptr);
}

// SIGNAL 260
void Options::ArtificialHorizonColorChanged()
{
    QMetaObject::activate(this, &staticMetaObject, 260, nullptr);
}

// SIGNAL 261
void Options::TelescopeTargetColorChanged()
{
    QMetaObject::activate(this, &staticMetaObject, 261, nullptr);
}

// SIGNAL 262
void Options::VisibleSatColorChanged()
{
    QMetaObject::activate(this, &staticMetaObject, 262, nullptr);
}

// SIGNAL 263
void Options::SatColorChanged()
{
    QMetaObject::activate(this, &staticMetaObject, 263, nullptr);
}

// SIGNAL 264
void Options::SatLabelColorChanged()
{
    QMetaObject::activate(this, &staticMetaObject, 264, nullptr);
}

// SIGNAL 265
void Options::SupernovaColorChanged()
{
    QMetaObject::activate(this, &staticMetaObject, 265, nullptr);
}

// SIGNAL 266
void Options::AsteroidColorChanged()
{
    QMetaObject::activate(this, &staticMetaObject, 266, nullptr);
}

// SIGNAL 267
void Options::UserLabelColorChanged()
{
    QMetaObject::activate(this, &staticMetaObject, 267, nullptr);
}

// SIGNAL 268
void Options::RAGuideColorChanged()
{
    QMetaObject::activate(this, &staticMetaObject, 268, nullptr);
}

// SIGNAL 269
void Options::DEGuideColorChanged()
{
    QMetaObject::activate(this, &staticMetaObject, 269, nullptr);
}

// SIGNAL 270
void Options::SolverFOVColorChanged()
{
    QMetaObject::activate(this, &staticMetaObject, 270, nullptr);
}

// SIGNAL 271
void Options::xplanetIsInternalChanged()
{
    QMetaObject::activate(this, &staticMetaObject, 271, nullptr);
}

// SIGNAL 272
void Options::XplanetPathChanged()
{
    QMetaObject::activate(this, &staticMetaObject, 272, nullptr);
}

// SIGNAL 273
void Options::XplanetUseFIFOChanged()
{
    QMetaObject::activate(this, &staticMetaObject, 273, nullptr);
}

// SIGNAL 274
void Options::XplanetTimeoutChanged()
{
    QMetaObject::activate(this, &staticMetaObject, 274, nullptr);
}

// SIGNAL 275
void Options::XplanetAnimationDelayChanged()
{
    QMetaObject::activate(this, &staticMetaObject, 275, nullptr);
}

// SIGNAL 276
void Options::XplanetWidthChanged()
{
    QMetaObject::activate(this, &staticMetaObject, 276, nullptr);
}

// SIGNAL 277
void Options::XplanetHeightChanged()
{
    QMetaObject::activate(this, &staticMetaObject, 277, nullptr);
}

// SIGNAL 278
void Options::XplanetLabelChanged()
{
    QMetaObject::activate(this, &staticMetaObject, 278, nullptr);
}

// SIGNAL 279
void Options::XplanetLabelLocalTimeChanged()
{
    QMetaObject::activate(this, &staticMetaObject, 279, nullptr);
}

// SIGNAL 280
void Options::XplanetLabelGMTChanged()
{
    QMetaObject::activate(this, &staticMetaObject, 280, nullptr);
}

// SIGNAL 281
void Options::XplanetLabelStringChanged()
{
    QMetaObject::activate(this, &staticMetaObject, 281, nullptr);
}

// SIGNAL 282
void Options::XplanetFontSizeChanged()
{
    QMetaObject::activate(this, &staticMetaObject, 282, nullptr);
}

// SIGNAL 283
void Options::XplanetColorChanged()
{
    QMetaObject::activate(this, &staticMetaObject, 283, nullptr);
}

// SIGNAL 284
void Options::XplanetDateFormatChanged()
{
    QMetaObject::activate(this, &staticMetaObject, 284, nullptr);
}

// SIGNAL 285
void Options::XplanetLabelTLChanged()
{
    QMetaObject::activate(this, &staticMetaObject, 285, nullptr);
}

// SIGNAL 286
void Options::XplanetLabelTRChanged()
{
    QMetaObject::activate(this, &staticMetaObject, 286, nullptr);
}

// SIGNAL 287
void Options::XplanetLabelBRChanged()
{
    QMetaObject::activate(this, &staticMetaObject, 287, nullptr);
}

// SIGNAL 288
void Options::XplanetLabelBLChanged()
{
    QMetaObject::activate(this, &staticMetaObject, 288, nullptr);
}

// SIGNAL 289
void Options::XplanetGlareChanged()
{
    QMetaObject::activate(this, &staticMetaObject, 289, nullptr);
}

// SIGNAL 290
void Options::XplanetRandomChanged()
{
    QMetaObject::activate(this, &staticMetaObject, 290, nullptr);
}

// SIGNAL 291
void Options::XplanetLatLongChanged()
{
    QMetaObject::activate(this, &staticMetaObject, 291, nullptr);
}

// SIGNAL 292
void Options::XplanetLatitudeChanged()
{
    QMetaObject::activate(this, &staticMetaObject, 292, nullptr);
}

// SIGNAL 293
void Options::XplanetLongitudeChanged()
{
    QMetaObject::activate(this, &staticMetaObject, 293, nullptr);
}

// SIGNAL 294
void Options::XplanetProjectionChanged()
{
    QMetaObject::activate(this, &staticMetaObject, 294, nullptr);
}

// SIGNAL 295
void Options::XplanetBackgroundChanged()
{
    QMetaObject::activate(this, &staticMetaObject, 295, nullptr);
}

// SIGNAL 296
void Options::XplanetBackgroundImageChanged()
{
    QMetaObject::activate(this, &staticMetaObject, 296, nullptr);
}

// SIGNAL 297
void Options::XplanetBackgroundImagePathChanged()
{
    QMetaObject::activate(this, &staticMetaObject, 297, nullptr);
}

// SIGNAL 298
void Options::XplanetBackgroundColorChanged()
{
    QMetaObject::activate(this, &staticMetaObject, 298, nullptr);
}

// SIGNAL 299
void Options::XplanetBackgroundColorValueChanged()
{
    QMetaObject::activate(this, &staticMetaObject, 299, nullptr);
}

// SIGNAL 300
void Options::XplanetMagnitudeChanged()
{
    QMetaObject::activate(this, &staticMetaObject, 300, nullptr);
}

// SIGNAL 301
void Options::XplanetArcFileChanged()
{
    QMetaObject::activate(this, &staticMetaObject, 301, nullptr);
}

// SIGNAL 302
void Options::XplanetArcFilePathChanged()
{
    QMetaObject::activate(this, &staticMetaObject, 302, nullptr);
}

// SIGNAL 303
void Options::XplanetConfigFileChanged()
{
    QMetaObject::activate(this, &staticMetaObject, 303, nullptr);
}

// SIGNAL 304
void Options::XplanetConfigFilePathChanged()
{
    QMetaObject::activate(this, &staticMetaObject, 304, nullptr);
}

// SIGNAL 305
void Options::XplanetFOVChanged()
{
    QMetaObject::activate(this, &staticMetaObject, 305, nullptr);
}

// SIGNAL 306
void Options::XplanetMarkerFileChanged()
{
    QMetaObject::activate(this, &staticMetaObject, 306, nullptr);
}

// SIGNAL 307
void Options::XplanetMarkerFilePathChanged()
{
    QMetaObject::activate(this, &staticMetaObject, 307, nullptr);
}

// SIGNAL 308
void Options::XplanetMarkerBoundsChanged()
{
    QMetaObject::activate(this, &staticMetaObject, 308, nullptr);
}

// SIGNAL 309
void Options::XplanetMarkerBoundsPathChanged()
{
    QMetaObject::activate(this, &staticMetaObject, 309, nullptr);
}

// SIGNAL 310
void Options::XplanetStarmapChanged()
{
    QMetaObject::activate(this, &staticMetaObject, 310, nullptr);
}

// SIGNAL 311
void Options::XplanetStarmapPathChanged()
{
    QMetaObject::activate(this, &staticMetaObject, 311, nullptr);
}

// SIGNAL 312
void Options::XplanetQualityChanged()
{
    QMetaObject::activate(this, &staticMetaObject, 312, nullptr);
}

// SIGNAL 313
void Options::ShowSatellitesChanged()
{
    QMetaObject::activate(this, &staticMetaObject, 313, nullptr);
}

// SIGNAL 314
void Options::ShowVisibleSatellitesChanged()
{
    QMetaObject::activate(this, &staticMetaObject, 314, nullptr);
}

// SIGNAL 315
void Options::DrawSatellitesLikeStarsChanged()
{
    QMetaObject::activate(this, &staticMetaObject, 315, nullptr);
}

// SIGNAL 316
void Options::ShowSatellitesLabelsChanged()
{
    QMetaObject::activate(this, &staticMetaObject, 316, nullptr);
}

// SIGNAL 317
void Options::SelectedSatellitesChanged()
{
    QMetaObject::activate(this, &staticMetaObject, 317, nullptr);
}

// SIGNAL 318
void Options::KStarsFirstRunChanged()
{
    QMetaObject::activate(this, &staticMetaObject, 318, nullptr);
}

// SIGNAL 319
void Options::AlwaysRecomputeCoordinatesChanged()
{
    QMetaObject::activate(this, &staticMetaObject, 319, nullptr);
}

// SIGNAL 320
void Options::DefaultDSSImageSizeChanged()
{
    QMetaObject::activate(this, &staticMetaObject, 320, nullptr);
}

// SIGNAL 321
void Options::DSSPaddingChanged()
{
    QMetaObject::activate(this, &staticMetaObject, 321, nullptr);
}

// SIGNAL 322
void Options::VerboseLoggingChanged()
{
    QMetaObject::activate(this, &staticMetaObject, 322, nullptr);
}

// SIGNAL 323
void Options::RegularLoggingChanged()
{
    QMetaObject::activate(this, &staticMetaObject, 323, nullptr);
}

// SIGNAL 324
void Options::DisableLoggingChanged()
{
    QMetaObject::activate(this, &staticMetaObject, 324, nullptr);
}

// SIGNAL 325
void Options::LogToDefaultChanged()
{
    QMetaObject::activate(this, &staticMetaObject, 325, nullptr);
}

// SIGNAL 326
void Options::LogToFileChanged()
{
    QMetaObject::activate(this, &staticMetaObject, 326, nullptr);
}

// SIGNAL 327
void Options::FITSLoggingChanged()
{
    QMetaObject::activate(this, &staticMetaObject, 327, nullptr);
}

// SIGNAL 328
void Options::INDILoggingChanged()
{
    QMetaObject::activate(this, &staticMetaObject, 328, nullptr);
}

// SIGNAL 329
void Options::CaptureLoggingChanged()
{
    QMetaObject::activate(this, &staticMetaObject, 329, nullptr);
}

// SIGNAL 330
void Options::FocusLoggingChanged()
{
    QMetaObject::activate(this, &staticMetaObject, 330, nullptr);
}

// SIGNAL 331
void Options::SaveGuideImagesChanged()
{
    QMetaObject::activate(this, &staticMetaObject, 331, nullptr);
}

// SIGNAL 332
void Options::SaveAlignImagesChanged()
{
    QMetaObject::activate(this, &staticMetaObject, 332, nullptr);
}

// SIGNAL 333
void Options::SaveFailedAlignImagesChanged()
{
    QMetaObject::activate(this, &staticMetaObject, 333, nullptr);
}

// SIGNAL 334
void Options::DontSyncToRealTimeChanged()
{
    QMetaObject::activate(this, &staticMetaObject, 334, nullptr);
}

// SIGNAL 335
void Options::GuideLoggingChanged()
{
    QMetaObject::activate(this, &staticMetaObject, 335, nullptr);
}

// SIGNAL 336
void Options::AlignmentLoggingChanged()
{
    QMetaObject::activate(this, &staticMetaObject, 336, nullptr);
}

// SIGNAL 337
void Options::MountLoggingChanged()
{
    QMetaObject::activate(this, &staticMetaObject, 337, nullptr);
}

// SIGNAL 338
void Options::ObservatoryLoggingChanged()
{
    QMetaObject::activate(this, &staticMetaObject, 338, nullptr);
}

// SIGNAL 339
void Options::ImageDebayerEngineChanged()
{
    QMetaObject::activate(this, &staticMetaObject, 339, nullptr);
}

// SIGNAL 340
void Options::ImageDebayerAlgoChanged()
{
    QMetaObject::activate(this, &staticMetaObject, 340, nullptr);
}

// SIGNAL 341
void Options::StackDebayerEngineChanged()
{
    QMetaObject::activate(this, &staticMetaObject, 341, nullptr);
}

// SIGNAL 342
void Options::StackDebayerAlgoChanged()
{
    QMetaObject::activate(this, &staticMetaObject, 342, nullptr);
}

// SIGNAL 343
void Options::FITSWindowGeometryChanged()
{
    QMetaObject::activate(this, &staticMetaObject, 343, nullptr);
}

// SIGNAL 344
void Options::useFITSViewerChanged()
{
    QMetaObject::activate(this, &staticMetaObject, 344, nullptr);
}

// SIGNAL 345
void Options::singlePreviewFITSChanged()
{
    QMetaObject::activate(this, &staticMetaObject, 345, nullptr);
}

// SIGNAL 346
void Options::singleWindowCapturedFITSChanged()
{
    QMetaObject::activate(this, &staticMetaObject, 346, nullptr);
}

// SIGNAL 347
void Options::singleWindowOpenedFITSChanged()
{
    QMetaObject::activate(this, &staticMetaObject, 347, nullptr);
}

// SIGNAL 348
void Options::focusFITSOnNewImageChanged()
{
    QMetaObject::activate(this, &staticMetaObject, 348, nullptr);
}

// SIGNAL 349
void Options::independentWindowFITSChanged()
{
    QMetaObject::activate(this, &staticMetaObject, 349, nullptr);
}

// SIGNAL 350
void Options::liveStackerOwnProcessChanged()
{
    QMetaObject::activate(this, &staticMetaObject, 350, nullptr);
}

// SIGNAL 351
void Options::AutoDebayerChanged()
{
    QMetaObject::activate(this, &staticMetaObject, 351, nullptr);
}

// SIGNAL 352
void Options::Auto3DCubeChanged()
{
    QMetaObject::activate(this, &staticMetaObject, 352, nullptr);
}

// SIGNAL 353
void Options::AutoHFRChanged()
{
    QMetaObject::activate(this, &staticMetaObject, 353, nullptr);
}

// SIGNAL 354
void Options::QuickHFRChanged()
{
    QMetaObject::activate(this, &staticMetaObject, 354, nullptr);
}

// SIGNAL 355
void Options::StellarSolverPartitionChanged()
{
    QMetaObject::activate(this, &staticMetaObject, 355, nullptr);
}

// SIGNAL 356
void Options::AutoWCSChanged()
{
    QMetaObject::activate(this, &staticMetaObject, 356, nullptr);
}

// SIGNAL 357
void Options::LimitedResourcesModeChanged()
{
    QMetaObject::activate(this, &staticMetaObject, 357, nullptr);
}

// SIGNAL 358
void Options::NonLinearHistogramChanged()
{
    QMetaObject::activate(this, &staticMetaObject, 358, nullptr);
}

// SIGNAL 359
void Options::HIPSOpacityChanged()
{
    QMetaObject::activate(this, &staticMetaObject, 359, nullptr);
}

// SIGNAL 360
void Options::HIPSOffsetXChanged()
{
    QMetaObject::activate(this, &staticMetaObject, 360, nullptr);
}

// SIGNAL 361
void Options::HIPSOffsetYChanged()
{
    QMetaObject::activate(this, &staticMetaObject, 361, nullptr);
}

// SIGNAL 362
void Options::FitsSolverProfileChanged()
{
    QMetaObject::activate(this, &staticMetaObject, 362, nullptr);
}

// SIGNAL 363
void Options::FitsSolverModuleChanged()
{
    QMetaObject::activate(this, &staticMetaObject, 363, nullptr);
}

// SIGNAL 364
void Options::FitsSolverProfileIndecesChanged()
{
    QMetaObject::activate(this, &staticMetaObject, 364, nullptr);
}

// SIGNAL 365
void Options::FitsCatalogChanged()
{
    QMetaObject::activate(this, &staticMetaObject, 365, nullptr);
}

// SIGNAL 366
void Options::FitsCatObjShowNamesChanged()
{
    QMetaObject::activate(this, &staticMetaObject, 366, nullptr);
}

// SIGNAL 367
void Options::FitsSolverUseScaleChanged()
{
    QMetaObject::activate(this, &staticMetaObject, 367, nullptr);
}

// SIGNAL 368
void Options::FitsSolverUsePositionChanged()
{
    QMetaObject::activate(this, &staticMetaObject, 368, nullptr);
}

// SIGNAL 369
void Options::FitsSolverScaleChanged()
{
    QMetaObject::activate(this, &staticMetaObject, 369, nullptr);
}

// SIGNAL 370
void Options::FitsSolverImageScaleUnitsChanged()
{
    QMetaObject::activate(this, &staticMetaObject, 370, nullptr);
}

// SIGNAL 371
void Options::FitsSolverRadiusChanged()
{
    QMetaObject::activate(this, &staticMetaObject, 371, nullptr);
}

// SIGNAL 372
void Options::fitsLSHideGeneralChanged()
{
    QMetaObject::activate(this, &staticMetaObject, 372, nullptr);
}

// SIGNAL 373
void Options::fitsLSHideCalibrationChanged()
{
    QMetaObject::activate(this, &staticMetaObject, 373, nullptr);
}

// SIGNAL 374
void Options::fitsLSHideAlignmentChanged()
{
    QMetaObject::activate(this, &staticMetaObject, 374, nullptr);
}

// SIGNAL 375
void Options::fitsLSHideStackingChanged()
{
    QMetaObject::activate(this, &staticMetaObject, 375, nullptr);
}

// SIGNAL 376
void Options::fitsLSHidePostProcChanged()
{
    QMetaObject::activate(this, &staticMetaObject, 376, nullptr);
}

// SIGNAL 377
void Options::fitsLSCalcSNRChanged()
{
    QMetaObject::activate(this, &staticMetaObject, 377, nullptr);
}

// SIGNAL 378
void Options::fitsLSMasterDarkChanged()
{
    QMetaObject::activate(this, &staticMetaObject, 378, nullptr);
}

// SIGNAL 379
void Options::fitsLSMasterFlatChanged()
{
    QMetaObject::activate(this, &staticMetaObject, 379, nullptr);
}

// SIGNAL 380
void Options::fitsLSHotPixelsChanged()
{
    QMetaObject::activate(this, &staticMetaObject, 380, nullptr);
}

// SIGNAL 381
void Options::fitsLSColdPixelsChanged()
{
    QMetaObject::activate(this, &staticMetaObject, 381, nullptr);
}

// SIGNAL 382
void Options::fitsLSAlignMethodChanged()
{
    QMetaObject::activate(this, &staticMetaObject, 382, nullptr);
}

// SIGNAL 383
void Options::fitsLSNumInMemChanged()
{
    QMetaObject::activate(this, &staticMetaObject, 383, nullptr);
}

// SIGNAL 384
void Options::fitsLSDownscaleChanged()
{
    QMetaObject::activate(this, &staticMetaObject, 384, nullptr);
}

// SIGNAL 385
void Options::fitsLSWeightingChanged()
{
    QMetaObject::activate(this, &staticMetaObject, 385, nullptr);
}

// SIGNAL 386
void Options::fitsLSNormalizationChanged()
{
    QMetaObject::activate(this, &staticMetaObject, 386, nullptr);
}

// SIGNAL 387
void Options::fitsLSStackingMethodChanged()
{
    QMetaObject::activate(this, &staticMetaObject, 387, nullptr);
}

// SIGNAL 388
void Options::fitsLSLowSigmaChanged()
{
    QMetaObject::activate(this, &staticMetaObject, 388, nullptr);
}

// SIGNAL 389
void Options::fitsLSHighSigmaChanged()
{
    QMetaObject::activate(this, &staticMetaObject, 389, nullptr);
}

// SIGNAL 390
void Options::fitsLSWinsorCutoffChanged()
{
    QMetaObject::activate(this, &staticMetaObject, 390, nullptr);
}

// SIGNAL 391
void Options::fitsLSIterationsChanged()
{
    QMetaObject::activate(this, &staticMetaObject, 391, nullptr);
}

// SIGNAL 392
void Options::fitsLSKappaChanged()
{
    QMetaObject::activate(this, &staticMetaObject, 392, nullptr);
}

// SIGNAL 393
void Options::fitsLSAlphaChanged()
{
    QMetaObject::activate(this, &staticMetaObject, 393, nullptr);
}

// SIGNAL 394
void Options::fitsLSSigmaChanged()
{
    QMetaObject::activate(this, &staticMetaObject, 394, nullptr);
}

// SIGNAL 395
void Options::fitsPSFUpdateChanged()
{
    QMetaObject::activate(this, &staticMetaObject, 395, nullptr);
}

// SIGNAL 396
void Options::fitsLSPostProcChanged()
{
    QMetaObject::activate(this, &staticMetaObject, 396, nullptr);
}

// SIGNAL 397
void Options::fitsLSGradientAmtChanged()
{
    QMetaObject::activate(this, &staticMetaObject, 397, nullptr);
}

// SIGNAL 398
void Options::fitsLSDeconvAmtChanged()
{
    QMetaObject::activate(this, &staticMetaObject, 398, nullptr);
}

// SIGNAL 399
void Options::fitsLSPSFSigmaChanged()
{
    QMetaObject::activate(this, &staticMetaObject, 399, nullptr);
}

// SIGNAL 400
void Options::fitsLSDenoiseAmtChanged()
{
    QMetaObject::activate(this, &staticMetaObject, 400, nullptr);
}

// SIGNAL 401
void Options::fitsLSSharpenAmtChanged()
{
    QMetaObject::activate(this, &staticMetaObject, 401, nullptr);
}

// SIGNAL 402
void Options::fitsLSSharpenKernalChanged()
{
    QMetaObject::activate(this, &staticMetaObject, 402, nullptr);
}

// SIGNAL 403
void Options::fitsLSSharpenSigmaChanged()
{
    QMetaObject::activate(this, &staticMetaObject, 403, nullptr);
}

// SIGNAL 404
void Options::fitsLSMWindowGeometryChanged()
{
    QMetaObject::activate(this, &staticMetaObject, 404, nullptr);
}

// SIGNAL 405
void Options::fitsLSMVisibleColumnsChanged()
{
    QMetaObject::activate(this, &staticMetaObject, 405, nullptr);
}

// SIGNAL 406
void Options::fitsLSMColumnWidthsChanged()
{
    QMetaObject::activate(this, &staticMetaObject, 406, nullptr);
}

// SIGNAL 407
void Options::fitsLSMSortColumnChanged()
{
    QMetaObject::activate(this, &staticMetaObject, 407, nullptr);
}

// SIGNAL 408
void Options::fitsLSMSortOrderChanged()
{
    QMetaObject::activate(this, &staticMetaObject, 408, nullptr);
}

// SIGNAL 409
void Options::fitsLSMHighlightingChanged()
{
    QMetaObject::activate(this, &staticMetaObject, 409, nullptr);
}

// SIGNAL 410
void Options::fitsLSWebcastTitleChanged()
{
    QMetaObject::activate(this, &staticMetaObject, 410, nullptr);
}

// SIGNAL 411
void Options::fitsLSWebcastLogoLChanged()
{
    QMetaObject::activate(this, &staticMetaObject, 411, nullptr);
}

// SIGNAL 412
void Options::fitsLSWebcastLogoRChanged()
{
    QMetaObject::activate(this, &staticMetaObject, 412, nullptr);
}

// SIGNAL 413
void Options::fitsLSWebcastPortChanged()
{
    QMetaObject::activate(this, &staticMetaObject, 413, nullptr);
}

// SIGNAL 414
void Options::fitsLSWebcastThrottleChanged()
{
    QMetaObject::activate(this, &staticMetaObject, 414, nullptr);
}

// SIGNAL 415
void Options::BortleClassChanged()
{
    QMetaObject::activate(this, &staticMetaObject, 415, nullptr);
}

// SIGNAL 416
void Options::TelescopeCheckChanged()
{
    QMetaObject::activate(this, &staticMetaObject, 416, nullptr);
}

// SIGNAL 417
void Options::BinocularsCheckChanged()
{
    QMetaObject::activate(this, &staticMetaObject, 417, nullptr);
}

// SIGNAL 418
void Options::BinocularsApertureChanged()
{
    QMetaObject::activate(this, &staticMetaObject, 418, nullptr);
}

// SIGNAL 419
void Options::ScopeListIndexChanged()
{
    QMetaObject::activate(this, &staticMetaObject, 419, nullptr);
}

// SIGNAL 420
void Options::EkosWindowWidthChanged()
{
    QMetaObject::activate(this, &staticMetaObject, 420, nullptr);
}

// SIGNAL 421
void Options::EkosWindowHeightChanged()
{
    QMetaObject::activate(this, &staticMetaObject, 421, nullptr);
}

// SIGNAL 422
void Options::EkosGeometryChanged()
{
    QMetaObject::activate(this, &staticMetaObject, 422, nullptr);
}

// SIGNAL 423
void Options::EkosTopIconsChanged()
{
    QMetaObject::activate(this, &staticMetaObject, 423, nullptr);
}

// SIGNAL 424
void Options::EkosLeftIconsChanged()
{
    QMetaObject::activate(this, &staticMetaObject, 424, nullptr);
}

// SIGNAL 425
void Options::independentWindowEkosChanged()
{
    QMetaObject::activate(this, &staticMetaObject, 425, nullptr);
}

// SIGNAL 426
void Options::profileChanged()
{
    QMetaObject::activate(this, &staticMetaObject, 426, nullptr);
}

// SIGNAL 427
void Options::neverLoadConfigChanged()
{
    QMetaObject::activate(this, &staticMetaObject, 427, nullptr);
}

// SIGNAL 428
void Options::loadConfigOnConnectionChanged()
{
    QMetaObject::activate(this, &staticMetaObject, 428, nullptr);
}

// SIGNAL 429
void Options::loadDefaultConfigChanged()
{
    QMetaObject::activate(this, &staticMetaObject, 429, nullptr);
}

// SIGNAL 430
void Options::autoLoadSerialAssistantChanged()
{
    QMetaObject::activate(this, &staticMetaObject, 430, nullptr);
}

// SIGNAL 431
void Options::RememberCredentialsChanged()
{
    QMetaObject::activate(this, &staticMetaObject, 431, nullptr);
}

// SIGNAL 432
void Options::AutoStartEkosLiveChanged()
{
    QMetaObject::activate(this, &staticMetaObject, 432, nullptr);
}

// SIGNAL 433
void Options::EkosLiveUsernameChanged()
{
    QMetaObject::activate(this, &staticMetaObject, 433, nullptr);
}

// SIGNAL 434
void Options::EkosLiveObservatoryChanged()
{
    QMetaObject::activate(this, &staticMetaObject, 434, nullptr);
}

// SIGNAL 435
void Options::EkosLiveOfflineServerChanged()
{
    QMetaObject::activate(this, &staticMetaObject, 435, nullptr);
}

// SIGNAL 436
void Options::EkosLiveOnlineServerChanged()
{
    QMetaObject::activate(this, &staticMetaObject, 436, nullptr);
}

// SIGNAL 437
void Options::EkosLiveSoundChanged()
{
    QMetaObject::activate(this, &staticMetaObject, 437, nullptr);
}

// SIGNAL 438
void Options::EkosLiveNotificationsChanged()
{
    QMetaObject::activate(this, &staticMetaObject, 438, nullptr);
}

// SIGNAL 439
void Options::EkosLiveCloudChanged()
{
    QMetaObject::activate(this, &staticMetaObject, 439, nullptr);
}

// SIGNAL 440
void Options::MaxDarkTemperatureDiffChanged()
{
    QMetaObject::activate(this, &staticMetaObject, 440, nullptr);
}

// SIGNAL 441
void Options::shutterfulCCDsChanged()
{
    QMetaObject::activate(this, &staticMetaObject, 441, nullptr);
}

// SIGNAL 442
void Options::shutterlessCCDsChanged()
{
    QMetaObject::activate(this, &staticMetaObject, 442, nullptr);
}

// SIGNAL 443
void Options::DarkLibraryDurationChanged()
{
    QMetaObject::activate(this, &staticMetaObject, 443, nullptr);
}

// SIGNAL 444
void Options::UseGraphicalCountsDisplayChanged()
{
    QMetaObject::activate(this, &staticMetaObject, 444, nullptr);
}

// SIGNAL 445
void Options::MinimumAltLimitChanged()
{
    QMetaObject::activate(this, &staticMetaObject, 445, nullptr);
}

// SIGNAL 446
void Options::MaximumAltLimitChanged()
{
    QMetaObject::activate(this, &staticMetaObject, 446, nullptr);
}

// SIGNAL 447
void Options::EnableAltitudeLimitsChanged()
{
    QMetaObject::activate(this, &staticMetaObject, 447, nullptr);
}

// SIGNAL 448
void Options::EnableAltitudeLimitsTrackingOnlyChanged()
{
    QMetaObject::activate(this, &staticMetaObject, 448, nullptr);
}

// SIGNAL 449
void Options::ConfirmBelowHorizonChanged()
{
    QMetaObject::activate(this, &staticMetaObject, 449, nullptr);
}

// SIGNAL 450
void Options::MeridianFlipOffsetDegreesChanged()
{
    QMetaObject::activate(this, &staticMetaObject, 450, nullptr);
}

// SIGNAL 451
void Options::MaximumHaLimitChanged()
{
    QMetaObject::activate(this, &staticMetaObject, 451, nullptr);
}

// SIGNAL 452
void Options::EnableHaLimitChanged()
{
    QMetaObject::activate(this, &staticMetaObject, 452, nullptr);
}

// SIGNAL 453
void Options::ExecuteMeridianFlipChanged()
{
    QMetaObject::activate(this, &staticMetaObject, 453, nullptr);
}

// SIGNAL 454
void Options::LeftRightReversedChanged()
{
    QMetaObject::activate(this, &staticMetaObject, 454, nullptr);
}

// SIGNAL 455
void Options::UpDownReversedChanged()
{
    QMetaObject::activate(this, &staticMetaObject, 455, nullptr);
}

// SIGNAL 456
void Options::ParkEveryDayChanged()
{
    QMetaObject::activate(this, &staticMetaObject, 456, nullptr);
}

// SIGNAL 457
void Options::ParkTimeChanged()
{
    QMetaObject::activate(this, &staticMetaObject, 457, nullptr);
}

// SIGNAL 458
void Options::DefaultObserverChanged()
{
    QMetaObject::activate(this, &staticMetaObject, 458, nullptr);
}

// SIGNAL 459
void Options::SyncFOVPAChanged()
{
    QMetaObject::activate(this, &staticMetaObject, 459, nullptr);
}

// SIGNAL 460
void Options::PAMultiplierChanged()
{
    QMetaObject::activate(this, &staticMetaObject, 460, nullptr);
}

// SIGNAL 461
void Options::PAOffsetChanged()
{
    QMetaObject::activate(this, &staticMetaObject, 461, nullptr);
}

// SIGNAL 462
void Options::PAPierSideChanged()
{
    QMetaObject::activate(this, &staticMetaObject, 462, nullptr);
}

// SIGNAL 463
void Options::GuideDeviationChanged()
{
    QMetaObject::activate(this, &staticMetaObject, 463, nullptr);
}

// SIGNAL 464
void Options::GuideDeviationRepsChanged()
{
    QMetaObject::activate(this, &staticMetaObject, 464, nullptr);
}

// SIGNAL 465
void Options::StartGuideDeviationChanged()
{
    QMetaObject::activate(this, &staticMetaObject, 465, nullptr);
}

// SIGNAL 466
void Options::GuideDitherPerJobFrequencyChanged()
{
    QMetaObject::activate(this, &staticMetaObject, 466, nullptr);
}

// SIGNAL 467
void Options::HFRDeviationChanged()
{
    QMetaObject::activate(this, &staticMetaObject, 467, nullptr);
}

// SIGNAL 468
void Options::MaxFocusTemperatureDeltaChanged()
{
    QMetaObject::activate(this, &staticMetaObject, 468, nullptr);
}

// SIGNAL 469
void Options::AutoDarkChanged()
{
    QMetaObject::activate(this, &staticMetaObject, 469, nullptr);
}

// SIGNAL 470
void Options::EnforceGuideDeviationChanged()
{
    QMetaObject::activate(this, &staticMetaObject, 470, nullptr);
}

// SIGNAL 471
void Options::EnforceAutofocusHFRChanged()
{
    QMetaObject::activate(this, &staticMetaObject, 471, nullptr);
}

// SIGNAL 472
void Options::EnforceAutofocusOnTemperatureChanged()
{
    QMetaObject::activate(this, &staticMetaObject, 472, nullptr);
}

// SIGNAL 473
void Options::EnforceRefocusEveryNChanged()
{
    QMetaObject::activate(this, &staticMetaObject, 473, nullptr);
}

// SIGNAL 474
void Options::RefocusEveryNChanged()
{
    QMetaObject::activate(this, &staticMetaObject, 474, nullptr);
}

// SIGNAL 475
void Options::RefocusAfterMeridianFlipChanged()
{
    QMetaObject::activate(this, &staticMetaObject, 475, nullptr);
}

// SIGNAL 476
void Options::ResetMountModelAfterMeridianChanged()
{
    QMetaObject::activate(this, &staticMetaObject, 476, nullptr);
}

// SIGNAL 477
void Options::ForcedFlipChanged()
{
    QMetaObject::activate(this, &staticMetaObject, 477, nullptr);
}

// SIGNAL 478
void Options::CalibrationADUValueChanged()
{
    QMetaObject::activate(this, &staticMetaObject, 478, nullptr);
}

// SIGNAL 479
void Options::CalibrationADUValueToleranceChanged()
{
    QMetaObject::activate(this, &staticMetaObject, 479, nullptr);
}

// SIGNAL 480
void Options::CalibrationPreActionIndexChanged()
{
    QMetaObject::activate(this, &staticMetaObject, 480, nullptr);
}

// SIGNAL 481
void Options::CalibrationFlatDurationIndexChanged()
{
    QMetaObject::activate(this, &staticMetaObject, 481, nullptr);
}

// SIGNAL 482
void Options::CalibrationWallAzChanged()
{
    QMetaObject::activate(this, &staticMetaObject, 482, nullptr);
}

// SIGNAL 483
void Options::CalibrationWallAltChanged()
{
    QMetaObject::activate(this, &staticMetaObject, 483, nullptr);
}

// SIGNAL 484
void Options::MaxTemperatureDiffChanged()
{
    QMetaObject::activate(this, &staticMetaObject, 484, nullptr);
}

// SIGNAL 485
void Options::MaxStartGuiderDriftChanged()
{
    QMetaObject::activate(this, &staticMetaObject, 485, nullptr);
}

// SIGNAL 486
void Options::EnforceStartGuiderDriftChanged()
{
    QMetaObject::activate(this, &staticMetaObject, 486, nullptr);
}

// SIGNAL 487
void Options::GuidingSettleChanged()
{
    QMetaObject::activate(this, &staticMetaObject, 487, nullptr);
}

// SIGNAL 488
void Options::AlwaysResetSequenceWhenStartingChanged()
{
    QMetaObject::activate(this, &staticMetaObject, 488, nullptr);
}

// SIGNAL 489
void Options::FlatSyncFocusChanged()
{
    QMetaObject::activate(this, &staticMetaObject, 489, nullptr);
}

// SIGNAL 490
void Options::HFRThresholdPercentageChanged()
{
    QMetaObject::activate(this, &staticMetaObject, 490, nullptr);
}

// SIGNAL 491
void Options::HFRCheckAlgorithmChanged()
{
    QMetaObject::activate(this, &staticMetaObject, 491, nullptr);
}

// SIGNAL 492
void Options::InSequenceCheckFramesChanged()
{
    QMetaObject::activate(this, &staticMetaObject, 492, nullptr);
}

// SIGNAL 493
void Options::AutoStretchChanged()
{
    QMetaObject::activate(this, &staticMetaObject, 493, nullptr);
}

// SIGNAL 494
void Options::StretchPreviewSamplingChanged()
{
    QMetaObject::activate(this, &staticMetaObject, 494, nullptr);
}

// SIGNAL 495
void Options::Clipping64KValueChanged()
{
    QMetaObject::activate(this, &staticMetaObject, 495, nullptr);
}

// SIGNAL 496
void Options::Clipping256ValueChanged()
{
    QMetaObject::activate(this, &staticMetaObject, 496, nullptr);
}

// SIGNAL 497
void Options::AdaptiveSamplingChanged()
{
    QMetaObject::activate(this, &staticMetaObject, 497, nullptr);
}

// SIGNAL 498
void Options::useSummaryPreviewChanged()
{
    QMetaObject::activate(this, &staticMetaObject, 498, nullptr);
}

// SIGNAL 499
void Options::useDSLRImageViewerChanged()
{
    QMetaObject::activate(this, &staticMetaObject, 499, nullptr);
}

// SIGNAL 500
void Options::ForceDSLRPresetsChanged()
{
    QMetaObject::activate(this, &staticMetaObject, 500, nullptr);
}

// SIGNAL 501
void Options::CaptureDirectoryChanged()
{
    QMetaObject::activate(this, &staticMetaObject, 501, nullptr);
}

// SIGNAL 502
void Options::PlaceholderFormatChanged()
{
    QMetaObject::activate(this, &staticMetaObject, 502, nullptr);
}

// SIGNAL 503
void Options::RemoteCaptureDirectoryChanged()
{
    QMetaObject::activate(this, &staticMetaObject, 503, nullptr);
}

// SIGNAL 504
void Options::ManualCoverTimeoutChanged()
{
    QMetaObject::activate(this, &staticMetaObject, 504, nullptr);
}

// SIGNAL 505
void Options::CaptureOperationsTimeoutChanged()
{
    QMetaObject::activate(this, &staticMetaObject, 505, nullptr);
}

// SIGNAL 506
void Options::MinFlipDurationChanged()
{
    QMetaObject::activate(this, &staticMetaObject, 506, nullptr);
}

// SIGNAL 507
void Options::CapturePositionChanged()
{
    QMetaObject::activate(this, &staticMetaObject, 507, nullptr);
}

// SIGNAL 508
void Options::CaptureTrainIDChanged()
{
    QMetaObject::activate(this, &staticMetaObject, 508, nullptr);
}

// SIGNAL 509
void Options::CaptureCalibrationWallChanged()
{
    QMetaObject::activate(this, &staticMetaObject, 509, nullptr);
}

// SIGNAL 510
void Options::CaptureCalibrationParkMountChanged()
{
    QMetaObject::activate(this, &staticMetaObject, 510, nullptr);
}

// SIGNAL 511
void Options::CaptureCalibrationParkDomeChanged()
{
    QMetaObject::activate(this, &staticMetaObject, 511, nullptr);
}

// SIGNAL 512
void Options::CaptureCalibrationUseManualChanged()
{
    QMetaObject::activate(this, &staticMetaObject, 512, nullptr);
}

// SIGNAL 513
void Options::CaptureCalibrationUseADUChanged()
{
    QMetaObject::activate(this, &staticMetaObject, 513, nullptr);
}

// SIGNAL 514
void Options::CaptureCalibrationADUValueChanged()
{
    QMetaObject::activate(this, &staticMetaObject, 514, nullptr);
}

// SIGNAL 515
void Options::CaptureCalibrationADUToleranceChanged()
{
    QMetaObject::activate(this, &staticMetaObject, 515, nullptr);
}

// SIGNAL 516
void Options::CaptureCalibrationSkyFlatsChanged()
{
    QMetaObject::activate(this, &staticMetaObject, 516, nullptr);
}

// SIGNAL 517
void Options::AbsTicksSpinChanged()
{
    QMetaObject::activate(this, &staticMetaObject, 517, nullptr);
}

// SIGNAL 518
void Options::FocusExposureChanged()
{
    QMetaObject::activate(this, &staticMetaObject, 518, nullptr);
}

// SIGNAL 519
void Options::FocusBinningChanged()
{
    QMetaObject::activate(this, &staticMetaObject, 519, nullptr);
}

// SIGNAL 520
void Options::FocusGainChanged()
{
    QMetaObject::activate(this, &staticMetaObject, 520, nullptr);
}

// SIGNAL 521
void Options::FocusISOChanged()
{
    QMetaObject::activate(this, &staticMetaObject, 521, nullptr);
}

// SIGNAL 522
void Options::DefaultFocusTemperatureSourceChanged()
{
    QMetaObject::activate(this, &staticMetaObject, 522, nullptr);
}

// SIGNAL 523
void Options::FocusFilterChanged()
{
    QMetaObject::activate(this, &staticMetaObject, 523, nullptr);
}

// SIGNAL 524
void Options::UseFocusDarkFrameChanged()
{
    QMetaObject::activate(this, &staticMetaObject, 524, nullptr);
}

// SIGNAL 525
void Options::FocusSubFrameChanged()
{
    QMetaObject::activate(this, &staticMetaObject, 525, nullptr);
}

// SIGNAL 526
void Options::FocusBoxSizeChanged()
{
    QMetaObject::activate(this, &staticMetaObject, 526, nullptr);
}

// SIGNAL 527
void Options::FocusUseFullFieldChanged()
{
    QMetaObject::activate(this, &staticMetaObject, 527, nullptr);
}

// SIGNAL 528
void Options::FocusNoMaskRBChanged()
{
    QMetaObject::activate(this, &staticMetaObject, 528, nullptr);
}

// SIGNAL 529
void Options::focusRingMaskRBChanged()
{
    QMetaObject::activate(this, &staticMetaObject, 529, nullptr);
}

// SIGNAL 530
void Options::focusMosaicMaskRBChanged()
{
    QMetaObject::activate(this, &staticMetaObject, 530, nullptr);
}

// SIGNAL 531
void Options::FocusFullFieldInnerRadiusChanged()
{
    QMetaObject::activate(this, &staticMetaObject, 531, nullptr);
}

// SIGNAL 532
void Options::FocusFullFieldOuterRadiusChanged()
{
    QMetaObject::activate(this, &staticMetaObject, 532, nullptr);
}

// SIGNAL 533
void Options::FocusMosaicTileWidthChanged()
{
    QMetaObject::activate(this, &staticMetaObject, 533, nullptr);
}

// SIGNAL 534
void Options::focusMosaicSpaceChanged()
{
    QMetaObject::activate(this, &staticMetaObject, 534, nullptr);
}

// SIGNAL 535
void Options::FocusAutoStarEnabledChanged()
{
    QMetaObject::activate(this, &staticMetaObject, 535, nullptr);
}

// SIGNAL 536
void Options::FocusSuspendGuidingChanged()
{
    QMetaObject::activate(this, &staticMetaObject, 536, nullptr);
}

// SIGNAL 537
void Options::FocusGuideSettleTimeChanged()
{
    QMetaObject::activate(this, &staticMetaObject, 537, nullptr);
}

// SIGNAL 538
void Options::FocusUnitsChanged()
{
    QMetaObject::activate(this, &staticMetaObject, 538, nullptr);
}

// SIGNAL 539
void Options::FocusAdaptiveChanged()
{
    QMetaObject::activate(this, &staticMetaObject, 539, nullptr);
}

// SIGNAL 540
void Options::focusAdaptiveMinMoveChanged()
{
    QMetaObject::activate(this, &staticMetaObject, 540, nullptr);
}

// SIGNAL 541
void Options::FocusAdaptStartChanged()
{
    QMetaObject::activate(this, &staticMetaObject, 541, nullptr);
}

// SIGNAL 542
void Options::focusAdaptiveMaxMoveChanged()
{
    QMetaObject::activate(this, &staticMetaObject, 542, nullptr);
}

// SIGNAL 543
void Options::FocusDetectionChanged()
{
    QMetaObject::activate(this, &staticMetaObject, 543, nullptr);
}

// SIGNAL 544
void Options::FocusSEPProfileChanged()
{
    QMetaObject::activate(this, &staticMetaObject, 544, nullptr);
}

// SIGNAL 545
void Options::FocusAlgorithmChanged()
{
    QMetaObject::activate(this, &staticMetaObject, 545, nullptr);
}

// SIGNAL 546
void Options::FocusCurveFitChanged()
{
    QMetaObject::activate(this, &staticMetaObject, 546, nullptr);
}

// SIGNAL 547
void Options::FocusStarMeasureChanged()
{
    QMetaObject::activate(this, &staticMetaObject, 547, nullptr);
}

// SIGNAL 548
void Options::FocusStarPSFChanged()
{
    QMetaObject::activate(this, &staticMetaObject, 548, nullptr);
}

// SIGNAL 549
void Options::FocusUseWeightsChanged()
{
    QMetaObject::activate(this, &staticMetaObject, 549, nullptr);
}

// SIGNAL 550
void Options::FocusR2LimitChanged()
{
    QMetaObject::activate(this, &staticMetaObject, 550, nullptr);
}

// SIGNAL 551
void Options::FocusRefineCurveFitChanged()
{
    QMetaObject::activate(this, &staticMetaObject, 551, nullptr);
}

// SIGNAL 552
void Options::focusFramesCountChanged()
{
    QMetaObject::activate(this, &staticMetaObject, 552, nullptr);
}

// SIGNAL 553
void Options::focusHFRFramesCountChanged()
{
    QMetaObject::activate(this, &staticMetaObject, 553, nullptr);
}

// SIGNAL 554
void Options::FocusMultiRowAverageChanged()
{
    QMetaObject::activate(this, &staticMetaObject, 554, nullptr);
}

// SIGNAL 555
void Options::FocusGaussianSigmaChanged()
{
    QMetaObject::activate(this, &staticMetaObject, 555, nullptr);
}

// SIGNAL 556
void Options::FocusThresholdChanged()
{
    QMetaObject::activate(this, &staticMetaObject, 556, nullptr);
}

// SIGNAL 557
void Options::FocusDenoiseChanged()
{
    QMetaObject::activate(this, &staticMetaObject, 557, nullptr);
}

// SIGNAL 558
void Options::FocusDonutChanged()
{
    QMetaObject::activate(this, &staticMetaObject, 558, nullptr);
}

// SIGNAL 559
void Options::FocusTimeDilationChanged()
{
    QMetaObject::activate(this, &staticMetaObject, 559, nullptr);
}

// SIGNAL 560
void Options::focusOutlierRejectionChanged()
{
    QMetaObject::activate(this, &staticMetaObject, 560, nullptr);
}

// SIGNAL 561
void Options::focusScanStartPosChanged()
{
    QMetaObject::activate(this, &staticMetaObject, 561, nullptr);
}

// SIGNAL 562
void Options::focusScanAlwaysOnChanged()
{
    QMetaObject::activate(this, &staticMetaObject, 562, nullptr);
}

// SIGNAL 563
void Options::focusScanDatapointsChanged()
{
    QMetaObject::activate(this, &staticMetaObject, 563, nullptr);
}

// SIGNAL 564
void Options::focusScanStepSizeFactorChanged()
{
    QMetaObject::activate(this, &staticMetaObject, 564, nullptr);
}

// SIGNAL 565
void Options::FocusGaussianKernelSizeChanged()
{
    QMetaObject::activate(this, &staticMetaObject, 565, nullptr);
}

// SIGNAL 566
void Options::FocusToleranceChanged()
{
    QMetaObject::activate(this, &staticMetaObject, 566, nullptr);
}

// SIGNAL 567
void Options::FocusWalkChanged()
{
    QMetaObject::activate(this, &staticMetaObject, 567, nullptr);
}

// SIGNAL 568
void Options::FocusSettleTimeChanged()
{
    QMetaObject::activate(this, &staticMetaObject, 568, nullptr);
}

// SIGNAL 569
void Options::FocusTicksChanged()
{
    QMetaObject::activate(this, &staticMetaObject, 569, nullptr);
}

// SIGNAL 570
void Options::FocusOutStepsChanged()
{
    QMetaObject::activate(this, &staticMetaObject, 570, nullptr);
}

// SIGNAL 571
void Options::focusNumStepsChanged()
{
    QMetaObject::activate(this, &staticMetaObject, 571, nullptr);
}

// SIGNAL 572
void Options::FocusMaxTravelChanged()
{
    QMetaObject::activate(this, &staticMetaObject, 572, nullptr);
}

// SIGNAL 573
void Options::FocusMaxSingleStepChanged()
{
    QMetaObject::activate(this, &staticMetaObject, 573, nullptr);
}

// SIGNAL 574
void Options::FocusBacklashChanged()
{
    QMetaObject::activate(this, &staticMetaObject, 574, nullptr);
}

// SIGNAL 575
void Options::FocusAFOverscanChanged()
{
    QMetaObject::activate(this, &staticMetaObject, 575, nullptr);
}

// SIGNAL 576
void Options::FocusOverscanDelayChanged()
{
    QMetaObject::activate(this, &staticMetaObject, 576, nullptr);
}

// SIGNAL 577
void Options::FocusCaptureTimeoutChanged()
{
    QMetaObject::activate(this, &staticMetaObject, 577, nullptr);
}

// SIGNAL 578
void Options::FocusMotionTimeoutChanged()
{
    QMetaObject::activate(this, &staticMetaObject, 578, nullptr);
}

// SIGNAL 579
void Options::focusCFZAlgorithmChanged()
{
    QMetaObject::activate(this, &staticMetaObject, 579, nullptr);
}

// SIGNAL 580
void Options::focusCFZToleranceChanged()
{
    QMetaObject::activate(this, &staticMetaObject, 580, nullptr);
}

// SIGNAL 581
void Options::focusCFZTauChanged()
{
    QMetaObject::activate(this, &staticMetaObject, 581, nullptr);
}

// SIGNAL 582
void Options::focusCFZDisplayVCurveChanged()
{
    QMetaObject::activate(this, &staticMetaObject, 582, nullptr);
}

// SIGNAL 583
void Options::focusCFZWavelengthChanged()
{
    QMetaObject::activate(this, &staticMetaObject, 583, nullptr);
}

// SIGNAL 584
void Options::focusCFZApertureChanged()
{
    QMetaObject::activate(this, &staticMetaObject, 584, nullptr);
}

// SIGNAL 585
void Options::focusCFZFNumberChanged()
{
    QMetaObject::activate(this, &staticMetaObject, 585, nullptr);
}

// SIGNAL 586
void Options::focusCFZSeeingChanged()
{
    QMetaObject::activate(this, &staticMetaObject, 586, nullptr);
}

// SIGNAL 587
void Options::focusCFZStepSizeChanged()
{
    QMetaObject::activate(this, &staticMetaObject, 587, nullptr);
}

// SIGNAL 588
void Options::focusAdvHelpOnlyChangesChanged()
{
    QMetaObject::activate(this, &staticMetaObject, 588, nullptr);
}

// SIGNAL 589
void Options::focusAdvUpdateParamsChanged()
{
    QMetaObject::activate(this, &staticMetaObject, 589, nullptr);
}

// SIGNAL 590
void Options::focusAdvFindStarsChanged()
{
    QMetaObject::activate(this, &staticMetaObject, 590, nullptr);
}

// SIGNAL 591
void Options::focusAdvCourseAdjChanged()
{
    QMetaObject::activate(this, &staticMetaObject, 591, nullptr);
}

// SIGNAL 592
void Options::focusAdvFineAdjChanged()
{
    QMetaObject::activate(this, &staticMetaObject, 592, nullptr);
}

// SIGNAL 593
void Options::FocusSplitterChanged()
{
    QMetaObject::activate(this, &staticMetaObject, 593, nullptr);
}

// SIGNAL 594
void Options::rightLayoutChanged()
{
    QMetaObject::activate(this, &staticMetaObject, 594, nullptr);
}

// SIGNAL 595
void Options::adaptFocusBFOChanged()
{
    QMetaObject::activate(this, &staticMetaObject, 595, nullptr);
}

// SIGNAL 596
void Options::abInsTileSelectionChanged()
{
    QMetaObject::activate(this, &staticMetaObject, 596, nullptr);
}

// SIGNAL 597
void Options::abInsShowLabelsChanged()
{
    QMetaObject::activate(this, &staticMetaObject, 597, nullptr);
}

// SIGNAL 598
void Options::abInsShowCFZChanged()
{
    QMetaObject::activate(this, &staticMetaObject, 598, nullptr);
}

// SIGNAL 599
void Options::abInsOptCentresChanged()
{
    QMetaObject::activate(this, &staticMetaObject, 599, nullptr);
}

// SIGNAL 600
void Options::abInsHSplitterChanged()
{
    QMetaObject::activate(this, &staticMetaObject, 600, nullptr);
}

// SIGNAL 601
void Options::abInsVSplitterChanged()
{
    QMetaObject::activate(this, &staticMetaObject, 601, nullptr);
}

// SIGNAL 602
void Options::abInsSelectionChanged()
{
    QMetaObject::activate(this, &staticMetaObject, 602, nullptr);
}

// SIGNAL 603
void Options::abInsThemeChanged()
{
    QMetaObject::activate(this, &staticMetaObject, 603, nullptr);
}

// SIGNAL 604
void Options::abInsLabelsChanged()
{
    QMetaObject::activate(this, &staticMetaObject, 604, nullptr);
}

// SIGNAL 605
void Options::abInsSensorChanged()
{
    QMetaObject::activate(this, &staticMetaObject, 605, nullptr);
}

// SIGNAL 606
void Options::abInsPetzvalWireChanged()
{
    QMetaObject::activate(this, &staticMetaObject, 606, nullptr);
}

// SIGNAL 607
void Options::abInsPetzvalSurfaceChanged()
{
    QMetaObject::activate(this, &staticMetaObject, 607, nullptr);
}

// SIGNAL 608
void Options::tiltPlateTypeChanged()
{
    QMetaObject::activate(this, &staticMetaObject, 608, nullptr);
}

// SIGNAL 609
void Options::tiltRadiusChanged()
{
    QMetaObject::activate(this, &staticMetaObject, 609, nullptr);
}

// SIGNAL 610
void Options::tiltThreadIndexChanged()
{
    QMetaObject::activate(this, &staticMetaObject, 610, nullptr);
}

// SIGNAL 611
void Options::tiltScrewPitchChanged()
{
    QMetaObject::activate(this, &staticMetaObject, 611, nullptr);
}

// SIGNAL 612
void Options::tiltRotationChanged()
{
    QMetaObject::activate(this, &staticMetaObject, 612, nullptr);
}

// SIGNAL 613
void Options::tiltModeChanged()
{
    QMetaObject::activate(this, &staticMetaObject, 613, nullptr);
}

// SIGNAL 614
void Options::tiltPlatePresentChanged()
{
    QMetaObject::activate(this, &staticMetaObject, 614, nullptr);
}

// SIGNAL 615
void Options::FocusSextractorTypeChanged()
{
    QMetaObject::activate(this, &staticMetaObject, 615, nullptr);
}

// SIGNAL 616
void Options::FocusOptionsProfileChanged()
{
    QMetaObject::activate(this, &staticMetaObject, 616, nullptr);
}

// SIGNAL 617
void Options::HFRSextractorTypeChanged()
{
    QMetaObject::activate(this, &staticMetaObject, 617, nullptr);
}

// SIGNAL 618
void Options::HFROptionsProfileChanged()
{
    QMetaObject::activate(this, &staticMetaObject, 618, nullptr);
}

// SIGNAL 619
void Options::GuideSextractorTypeChanged()
{
    QMetaObject::activate(this, &staticMetaObject, 619, nullptr);
}

// SIGNAL 620
void Options::GuideOptionsProfileChanged()
{
    QMetaObject::activate(this, &staticMetaObject, 620, nullptr);
}

// SIGNAL 621
void Options::SolveSextractorTypeChanged()
{
    QMetaObject::activate(this, &staticMetaObject, 621, nullptr);
}

// SIGNAL 622
void Options::SolverModeChanged()
{
    QMetaObject::activate(this, &staticMetaObject, 622, nullptr);
}

// SIGNAL 623
void Options::SolverTypeChanged()
{
    QMetaObject::activate(this, &staticMetaObject, 623, nullptr);
}

// SIGNAL 624
void Options::SolveOptionsProfileChanged()
{
    QMetaObject::activate(this, &staticMetaObject, 624, nullptr);
}

// SIGNAL 625
void Options::LoggerLevelChanged()
{
    QMetaObject::activate(this, &staticMetaObject, 625, nullptr);
}

// SIGNAL 626
void Options::AstrometryLogToFileChanged()
{
    QMetaObject::activate(this, &staticMetaObject, 626, nullptr);
}

// SIGNAL 627
void Options::AstrometryLogFilepathChanged()
{
    QMetaObject::activate(this, &staticMetaObject, 627, nullptr);
}

// SIGNAL 628
void Options::AstrometryIndexFolderListChanged()
{
    QMetaObject::activate(this, &staticMetaObject, 628, nullptr);
}

// SIGNAL 629
void Options::AlignExposureChanged()
{
    QMetaObject::activate(this, &staticMetaObject, 629, nullptr);
}

// SIGNAL 630
void Options::AlignBinningChanged()
{
    QMetaObject::activate(this, &staticMetaObject, 630, nullptr);
}

// SIGNAL 631
void Options::AlignGainChanged()
{
    QMetaObject::activate(this, &staticMetaObject, 631, nullptr);
}

// SIGNAL 632
void Options::AlignISOChanged()
{
    QMetaObject::activate(this, &staticMetaObject, 632, nullptr);
}

// SIGNAL 633
void Options::AlignDarkFrameChanged()
{
    QMetaObject::activate(this, &staticMetaObject, 633, nullptr);
}

// SIGNAL 634
void Options::AlignFilterChanged()
{
    QMetaObject::activate(this, &staticMetaObject, 634, nullptr);
}

// SIGNAL 635
void Options::AlignUseCurrentFilterChanged()
{
    QMetaObject::activate(this, &staticMetaObject, 635, nullptr);
}

// SIGNAL 636
void Options::AstrometryUseRotatorChanged()
{
    QMetaObject::activate(this, &staticMetaObject, 636, nullptr);
}

// SIGNAL 637
void Options::AstrometryRotatorThresholdChanged()
{
    QMetaObject::activate(this, &staticMetaObject, 637, nullptr);
}

// SIGNAL 638
void Options::AstrometryFlipRotationAllowedChanged()
{
    QMetaObject::activate(this, &staticMetaObject, 638, nullptr);
}

// SIGNAL 639
void Options::RotatorParityReversedChanged()
{
    QMetaObject::activate(this, &staticMetaObject, 639, nullptr);
}

// SIGNAL 640
void Options::AstrometrySolverWCSChanged()
{
    QMetaObject::activate(this, &staticMetaObject, 640, nullptr);
}

// SIGNAL 641
void Options::AstrometrySolverOverlayChanged()
{
    QMetaObject::activate(this, &staticMetaObject, 641, nullptr);
}

// SIGNAL 642
void Options::AstrometryDifferentialSlewingChanged()
{
    QMetaObject::activate(this, &staticMetaObject, 642, nullptr);
}

// SIGNAL 643
void Options::AlignAccuracyThresholdChanged()
{
    QMetaObject::activate(this, &staticMetaObject, 643, nullptr);
}

// SIGNAL 644
void Options::AlignSettlingTimeChanged()
{
    QMetaObject::activate(this, &staticMetaObject, 644, nullptr);
}

// SIGNAL 645
void Options::AstrometryUseNoFITS2FITSChanged()
{
    QMetaObject::activate(this, &staticMetaObject, 645, nullptr);
}

// SIGNAL 646
void Options::AstrometryUseResortChanged()
{
    QMetaObject::activate(this, &staticMetaObject, 646, nullptr);
}

// SIGNAL 647
void Options::AstrometryUseNoVerifyChanged()
{
    QMetaObject::activate(this, &staticMetaObject, 647, nullptr);
}

// SIGNAL 648
void Options::AstrometryUseImageScaleChanged()
{
    QMetaObject::activate(this, &staticMetaObject, 648, nullptr);
}

// SIGNAL 649
void Options::AstrometryImageScaleLowChanged()
{
    QMetaObject::activate(this, &staticMetaObject, 649, nullptr);
}

// SIGNAL 650
void Options::AstrometryImageScaleHighChanged()
{
    QMetaObject::activate(this, &staticMetaObject, 650, nullptr);
}

// SIGNAL 651
void Options::AstrometryAutoUpdateImageScaleChanged()
{
    QMetaObject::activate(this, &staticMetaObject, 651, nullptr);
}

// SIGNAL 652
void Options::AstrometryImageScaleUnitsChanged()
{
    QMetaObject::activate(this, &staticMetaObject, 652, nullptr);
}

// SIGNAL 653
void Options::AstrometryUseDownsampleChanged()
{
    QMetaObject::activate(this, &staticMetaObject, 653, nullptr);
}

// SIGNAL 654
void Options::AstrometryDownsampleChanged()
{
    QMetaObject::activate(this, &staticMetaObject, 654, nullptr);
}

// SIGNAL 655
void Options::AstrometryAutoDownsampleChanged()
{
    QMetaObject::activate(this, &staticMetaObject, 655, nullptr);
}

// SIGNAL 656
void Options::AstrometryDynamicThresholdChanged()
{
    QMetaObject::activate(this, &staticMetaObject, 656, nullptr);
}

// SIGNAL 657
void Options::AstrometryUsePositionChanged()
{
    QMetaObject::activate(this, &staticMetaObject, 657, nullptr);
}

// SIGNAL 658
void Options::AstrometryPositionRAChanged()
{
    QMetaObject::activate(this, &staticMetaObject, 658, nullptr);
}

// SIGNAL 659
void Options::AstrometryPositionDEChanged()
{
    QMetaObject::activate(this, &staticMetaObject, 659, nullptr);
}

// SIGNAL 660
void Options::AstrometryAutoUpdatePositionChanged()
{
    QMetaObject::activate(this, &staticMetaObject, 660, nullptr);
}

// SIGNAL 661
void Options::AstrometryRadiusChanged()
{
    QMetaObject::activate(this, &staticMetaObject, 661, nullptr);
}

// SIGNAL 662
void Options::AstrometryDetectParityChanged()
{
    QMetaObject::activate(this, &staticMetaObject, 662, nullptr);
}

// SIGNAL 663
void Options::AstrometryCustomOptionsChanged()
{
    QMetaObject::activate(this, &staticMetaObject, 663, nullptr);
}

// SIGNAL 664
void Options::AstrometrySolverBinaryChanged()
{
    QMetaObject::activate(this, &staticMetaObject, 664, nullptr);
}

// SIGNAL 665
void Options::AstrometryWCSInfoChanged()
{
    QMetaObject::activate(this, &staticMetaObject, 665, nullptr);
}

// SIGNAL 666
void Options::AstrometryConfFileChanged()
{
    QMetaObject::activate(this, &staticMetaObject, 666, nullptr);
}

// SIGNAL 667
void Options::SextractorBinaryChanged()
{
    QMetaObject::activate(this, &staticMetaObject, 667, nullptr);
}

// SIGNAL 668
void Options::WatneyBinaryChanged()
{
    QMetaObject::activate(this, &staticMetaObject, 668, nullptr);
}

// SIGNAL 669
void Options::AstrometryAPIKeyChanged()
{
    QMetaObject::activate(this, &staticMetaObject, 669, nullptr);
}

// SIGNAL 670
void Options::AstrometryAPIURLChanged()
{
    QMetaObject::activate(this, &staticMetaObject, 670, nullptr);
}

// SIGNAL 671
void Options::AstrometryUseJPEGChanged()
{
    QMetaObject::activate(this, &staticMetaObject, 671, nullptr);
}

// SIGNAL 672
void Options::AstrometryTimeoutChanged()
{
    QMetaObject::activate(this, &staticMetaObject, 672, nullptr);
}

// SIGNAL 673
void Options::PAHMountSpeedChanged()
{
    QMetaObject::activate(this, &staticMetaObject, 673, nullptr);
}

// SIGNAL 674
void Options::PAHRotaionChanged()
{
    QMetaObject::activate(this, &staticMetaObject, 674, nullptr);
}

// SIGNAL 675
void Options::PAHRefreshAlgorithmChanged()
{
    QMetaObject::activate(this, &staticMetaObject, 675, nullptr);
}

// SIGNAL 676
void Options::PAHDirectionChanged()
{
    QMetaObject::activate(this, &staticMetaObject, 676, nullptr);
}

// SIGNAL 677
void Options::PAHAutoParkChanged()
{
    QMetaObject::activate(this, &staticMetaObject, 677, nullptr);
}

// SIGNAL 678
void Options::PAHManualSlewChanged()
{
    QMetaObject::activate(this, &staticMetaObject, 678, nullptr);
}

// SIGNAL 679
void Options::PAHExposureChanged()
{
    QMetaObject::activate(this, &staticMetaObject, 679, nullptr);
}

// SIGNAL 680
void Options::PAHAutoPACCorrectionChanged()
{
    QMetaObject::activate(this, &staticMetaObject, 680, nullptr);
}

// SIGNAL 681
void Options::PAHAutoChangeDirectionChanged()
{
    QMetaObject::activate(this, &staticMetaObject, 681, nullptr);
}

// SIGNAL 682
void Options::PAHSuccessThresholdChanged()
{
    QMetaObject::activate(this, &staticMetaObject, 682, nullptr);
}

// SIGNAL 683
void Options::PAHCorrectionTimeoutChanged()
{
    QMetaObject::activate(this, &staticMetaObject, 683, nullptr);
}

// SIGNAL 684
void Options::GuideExposureChanged()
{
    QMetaObject::activate(this, &staticMetaObject, 684, nullptr);
}

// SIGNAL 685
void Options::GuideDelayChanged()
{
    QMetaObject::activate(this, &staticMetaObject, 685, nullptr);
}

// SIGNAL 686
void Options::GuiderTypeChanged()
{
    QMetaObject::activate(this, &staticMetaObject, 686, nullptr);
}

// SIGNAL 687
void Options::GuideAlgorithmChanged()
{
    QMetaObject::activate(this, &staticMetaObject, 687, nullptr);
}

// SIGNAL 688
void Options::RAGuidePulseAlgorithmChanged()
{
    QMetaObject::activate(this, &staticMetaObject, 688, nullptr);
}

// SIGNAL 689
void Options::DECGuidePulseAlgorithmChanged()
{
    QMetaObject::activate(this, &staticMetaObject, 689, nullptr);
}

// SIGNAL 690
void Options::AIGuiderWeightsFileChanged()
{
    QMetaObject::activate(this, &staticMetaObject, 690, nullptr);
}

// SIGNAL 691
void Options::AIPredictionGainChanged()
{
    QMetaObject::activate(this, &staticMetaObject, 691, nullptr);
}

// SIGNAL 692
void Options::AIProportionalBackoffChanged()
{
    QMetaObject::activate(this, &staticMetaObject, 692, nullptr);
}

// SIGNAL 693
void Options::AIPIDAutoTuneChanged()
{
    QMetaObject::activate(this, &staticMetaObject, 693, nullptr);
}

// SIGNAL 694
void Options::AIShadowModeChanged()
{
    QMetaObject::activate(this, &staticMetaObject, 694, nullptr);
}

// SIGNAL 695
void Options::PHD2HostChanged()
{
    QMetaObject::activate(this, &staticMetaObject, 695, nullptr);
}

// SIGNAL 696
void Options::PHD2PortChanged()
{
    QMetaObject::activate(this, &staticMetaObject, 696, nullptr);
}

// SIGNAL 697
void Options::LinGuiderHostChanged()
{
    QMetaObject::activate(this, &staticMetaObject, 697, nullptr);
}

// SIGNAL 698
void Options::LinGuiderPortChanged()
{
    QMetaObject::activate(this, &staticMetaObject, 698, nullptr);
}

// SIGNAL 699
void Options::CalibrationPulseDurationChanged()
{
    QMetaObject::activate(this, &staticMetaObject, 699, nullptr);
}

// SIGNAL 700
void Options::CalibrationMaxMoveChanged()
{
    QMetaObject::activate(this, &staticMetaObject, 700, nullptr);
}

// SIGNAL 701
void Options::GuideSquareSizeChanged()
{
    QMetaObject::activate(this, &staticMetaObject, 701, nullptr);
}

// SIGNAL 702
void Options::GuideBinningChanged()
{
    QMetaObject::activate(this, &staticMetaObject, 702, nullptr);
}

// SIGNAL 703
void Options::GuideAutoStarChanged()
{
    QMetaObject::activate(this, &staticMetaObject, 703, nullptr);
}

// SIGNAL 704
void Options::guideShowFrameChanged()
{
    QMetaObject::activate(this, &staticMetaObject, 704, nullptr);
}

// SIGNAL 705
void Options::GuideAutoSquareSizeEnabledChanged()
{
    QMetaObject::activate(this, &staticMetaObject, 705, nullptr);
}

// SIGNAL 706
void Options::AutoModeIterationsChanged()
{
    QMetaObject::activate(this, &staticMetaObject, 706, nullptr);
}

// SIGNAL 707
void Options::GuideLostStarTimeoutChanged()
{
    QMetaObject::activate(this, &staticMetaObject, 707, nullptr);
}

// SIGNAL 708
void Options::GuideCalibrationTimeoutChanged()
{
    QMetaObject::activate(this, &staticMetaObject, 708, nullptr);
}

// SIGNAL 709
void Options::GuideMaxDeltaRMSChanged()
{
    QMetaObject::activate(this, &staticMetaObject, 709, nullptr);
}

// SIGNAL 710
void Options::GuideMaxHFRChanged()
{
    QMetaObject::activate(this, &staticMetaObject, 710, nullptr);
}

// SIGNAL 711
void Options::MinDetectionsSEPMultistarChanged()
{
    QMetaObject::activate(this, &staticMetaObject, 711, nullptr);
}

// SIGNAL 712
void Options::MaxMultistarReferenceStarsChanged()
{
    QMetaObject::activate(this, &staticMetaObject, 712, nullptr);
}

// SIGNAL 713
void Options::AlwaysInventGuideStarChanged()
{
    QMetaObject::activate(this, &staticMetaObject, 713, nullptr);
}

// SIGNAL 714
void Options::TwoAxisEnabledChanged()
{
    QMetaObject::activate(this, &staticMetaObject, 714, nullptr);
}

// SIGNAL 715
void Options::UseGuideHeadChanged()
{
    QMetaObject::activate(this, &staticMetaObject, 715, nullptr);
}

// SIGNAL 716
void Options::SaveGuideLogChanged()
{
    QMetaObject::activate(this, &staticMetaObject, 716, nullptr);
}

// SIGNAL 717
void Options::GuideDarkFrameChanged()
{
    QMetaObject::activate(this, &staticMetaObject, 717, nullptr);
}

// SIGNAL 718
void Options::GuideSubframeChanged()
{
    QMetaObject::activate(this, &staticMetaObject, 718, nullptr);
}

// SIGNAL 719
void Options::DitherPixelsChanged()
{
    QMetaObject::activate(this, &staticMetaObject, 719, nullptr);
}

// SIGNAL 720
void Options::DitherFramesChanged()
{
    QMetaObject::activate(this, &staticMetaObject, 720, nullptr);
}

// SIGNAL 721
void Options::DitherSettleChanged()
{
    QMetaObject::activate(this, &staticMetaObject, 721, nullptr);
}

// SIGNAL 722
void Options::DitherThresholdChanged()
{
    QMetaObject::activate(this, &staticMetaObject, 722, nullptr);
}

// SIGNAL 723
void Options::DitherTimeoutChanged()
{
    QMetaObject::activate(this, &staticMetaObject, 723, nullptr);
}

// SIGNAL 724
void Options::DitherMaxIterationsChanged()
{
    QMetaObject::activate(this, &staticMetaObject, 724, nullptr);
}

// SIGNAL 725
void Options::DitherNoGuidingPulseChanged()
{
    QMetaObject::activate(this, &staticMetaObject, 725, nullptr);
}

// SIGNAL 726
void Options::DitherFailAbortsAutoGuideChanged()
{
    QMetaObject::activate(this, &staticMetaObject, 726, nullptr);
}

// SIGNAL 727
void Options::DitherWithOnePulseChanged()
{
    QMetaObject::activate(this, &staticMetaObject, 727, nullptr);
}

// SIGNAL 728
void Options::DitherEnabledChanged()
{
    QMetaObject::activate(this, &staticMetaObject, 728, nullptr);
}

// SIGNAL 729
void Options::DitherNoGuidingChanged()
{
    QMetaObject::activate(this, &staticMetaObject, 729, nullptr);
}

// SIGNAL 730
void Options::RAGuideEnabledChanged()
{
    QMetaObject::activate(this, &staticMetaObject, 730, nullptr);
}

// SIGNAL 731
void Options::DECGuideEnabledChanged()
{
    QMetaObject::activate(this, &staticMetaObject, 731, nullptr);
}

// SIGNAL 732
void Options::NorthDECGuideEnabledChanged()
{
    QMetaObject::activate(this, &staticMetaObject, 732, nullptr);
}

// SIGNAL 733
void Options::SouthDECGuideEnabledChanged()
{
    QMetaObject::activate(this, &staticMetaObject, 733, nullptr);
}

// SIGNAL 734
void Options::EastRAGuideEnabledChanged()
{
    QMetaObject::activate(this, &staticMetaObject, 734, nullptr);
}

// SIGNAL 735
void Options::WestRAGuideEnabledChanged()
{
    QMetaObject::activate(this, &staticMetaObject, 735, nullptr);
}

// SIGNAL 736
void Options::RAProportionalGainChanged()
{
    QMetaObject::activate(this, &staticMetaObject, 736, nullptr);
}

// SIGNAL 737
void Options::DECProportionalGainChanged()
{
    QMetaObject::activate(this, &staticMetaObject, 737, nullptr);
}

// SIGNAL 738
void Options::RAIntegralGainChanged()
{
    QMetaObject::activate(this, &staticMetaObject, 738, nullptr);
}

// SIGNAL 739
void Options::DECIntegralGainChanged()
{
    QMetaObject::activate(this, &staticMetaObject, 739, nullptr);
}

// SIGNAL 740
void Options::RAMinimumPulseArcSecChanged()
{
    QMetaObject::activate(this, &staticMetaObject, 740, nullptr);
}

// SIGNAL 741
void Options::DECMinimumPulseArcSecChanged()
{
    QMetaObject::activate(this, &staticMetaObject, 741, nullptr);
}

// SIGNAL 742
void Options::RAMaximumPulseArcSecChanged()
{
    QMetaObject::activate(this, &staticMetaObject, 742, nullptr);
}

// SIGNAL 743
void Options::DECMaximumPulseArcSecChanged()
{
    QMetaObject::activate(this, &staticMetaObject, 743, nullptr);
}

// SIGNAL 744
void Options::GPGEnabledChanged()
{
    QMetaObject::activate(this, &staticMetaObject, 744, nullptr);
}

// SIGNAL 745
void Options::GPGDarkGuidingChanged()
{
    QMetaObject::activate(this, &staticMetaObject, 745, nullptr);
}

// SIGNAL 746
void Options::GPGDarkGuidingIntervalChanged()
{
    QMetaObject::activate(this, &staticMetaObject, 746, nullptr);
}

// SIGNAL 747
void Options::AIDarkGuidingChanged()
{
    QMetaObject::activate(this, &staticMetaObject, 747, nullptr);
}

// SIGNAL 748
void Options::AIDarkGuidingIntervalChanged()
{
    QMetaObject::activate(this, &staticMetaObject, 748, nullptr);
}

// SIGNAL 749
void Options::GPGcWeightChanged()
{
    QMetaObject::activate(this, &staticMetaObject, 749, nullptr);
}

// SIGNAL 750
void Options::GPGMinPeriodsForInferenceChanged()
{
    QMetaObject::activate(this, &staticMetaObject, 750, nullptr);
}

// SIGNAL 751
void Options::GPGMinMoveChanged()
{
    QMetaObject::activate(this, &staticMetaObject, 751, nullptr);
}

// SIGNAL 752
void Options::GPGSE0KLengthScaleChanged()
{
    QMetaObject::activate(this, &staticMetaObject, 752, nullptr);
}

// SIGNAL 753
void Options::GPGSE0KSignalVarianceChanged()
{
    QMetaObject::activate(this, &staticMetaObject, 753, nullptr);
}

// SIGNAL 754
void Options::GPGPKLengthScaleChanged()
{
    QMetaObject::activate(this, &staticMetaObject, 754, nullptr);
}

// SIGNAL 755
void Options::GPGPeriodChanged()
{
    QMetaObject::activate(this, &staticMetaObject, 755, nullptr);
}

// SIGNAL 756
void Options::GPGPKSignalVarianceChanged()
{
    QMetaObject::activate(this, &staticMetaObject, 756, nullptr);
}

// SIGNAL 757
void Options::GPGSE1KLengthScaleChanged()
{
    QMetaObject::activate(this, &staticMetaObject, 757, nullptr);
}

// SIGNAL 758
void Options::GPGSE1KSignalVarianceChanged()
{
    QMetaObject::activate(this, &staticMetaObject, 758, nullptr);
}

// SIGNAL 759
void Options::GPGMinPeriodsForPeriodEstimateChanged()
{
    QMetaObject::activate(this, &staticMetaObject, 759, nullptr);
}

// SIGNAL 760
void Options::GPGPointsForApproximationChanged()
{
    QMetaObject::activate(this, &staticMetaObject, 760, nullptr);
}

// SIGNAL 761
void Options::GPGpWeightChanged()
{
    QMetaObject::activate(this, &staticMetaObject, 761, nullptr);
}

// SIGNAL 762
void Options::GPGEstimatePeriodChanged()
{
    QMetaObject::activate(this, &staticMetaObject, 762, nullptr);
}

// SIGNAL 763
void Options::GuiderAccuracyThresholdChanged()
{
    QMetaObject::activate(this, &staticMetaObject, 763, nullptr);
}

// SIGNAL 764
void Options::RADisplayedOnGuideGraphChanged()
{
    QMetaObject::activate(this, &staticMetaObject, 764, nullptr);
}

// SIGNAL 765
void Options::DEDisplayedOnGuideGraphChanged()
{
    QMetaObject::activate(this, &staticMetaObject, 765, nullptr);
}

// SIGNAL 766
void Options::RACorrDisplayedOnGuideGraphChanged()
{
    QMetaObject::activate(this, &staticMetaObject, 766, nullptr);
}

// SIGNAL 767
void Options::DECorrDisplayedOnGuideGraphChanged()
{
    QMetaObject::activate(this, &staticMetaObject, 767, nullptr);
}

// SIGNAL 768
void Options::SNRDisplayedOnGuideGraphChanged()
{
    QMetaObject::activate(this, &staticMetaObject, 768, nullptr);
}

// SIGNAL 769
void Options::RMSDisplayedOnGuideGraphChanged()
{
    QMetaObject::activate(this, &staticMetaObject, 769, nullptr);
}

// SIGNAL 770
void Options::RAHysteresisChanged()
{
    QMetaObject::activate(this, &staticMetaObject, 770, nullptr);
}

// SIGNAL 771
void Options::DECHysteresisChanged()
{
    QMetaObject::activate(this, &staticMetaObject, 771, nullptr);
}

// SIGNAL 772
void Options::SchedulerAlgorithmChanged()
{
    QMetaObject::activate(this, &staticMetaObject, 772, nullptr);
}

// SIGNAL 773
void Options::SchedulerLoggingChanged()
{
    QMetaObject::activate(this, &staticMetaObject, 773, nullptr);
}

// SIGNAL 774
void Options::StopEkosAfterShutdownChanged()
{
    QMetaObject::activate(this, &staticMetaObject, 774, nullptr);
}

// SIGNAL 775
void Options::ShutdownScriptTerminatesINDIChanged()
{
    QMetaObject::activate(this, &staticMetaObject, 775, nullptr);
}

// SIGNAL 776
void Options::CameraWarmupEnabledChanged()
{
    QMetaObject::activate(this, &staticMetaObject, 776, nullptr);
}

// SIGNAL 777
void Options::CameraWarmupRampChanged()
{
    QMetaObject::activate(this, &staticMetaObject, 777, nullptr);
}

// SIGNAL 778
void Options::PreemptiveShutdownChanged()
{
    QMetaObject::activate(this, &staticMetaObject, 778, nullptr);
}

// SIGNAL 779
void Options::ResetMountModelOnAlignFailChanged()
{
    QMetaObject::activate(this, &staticMetaObject, 779, nullptr);
}

// SIGNAL 780
void Options::ResetMountModelBeforeJobChanged()
{
    QMetaObject::activate(this, &staticMetaObject, 780, nullptr);
}

// SIGNAL 781
void Options::ResetGuideCalibrationChanged()
{
    QMetaObject::activate(this, &staticMetaObject, 781, nullptr);
}

// SIGNAL 782
void Options::ForceAlignmentBeforeJobChanged()
{
    QMetaObject::activate(this, &staticMetaObject, 782, nullptr);
}

// SIGNAL 783
void Options::ReuseGuideCalibrationChanged()
{
    QMetaObject::activate(this, &staticMetaObject, 783, nullptr);
}

// SIGNAL 784
void Options::ReverseDecOnPierSideChangeChanged()
{
    QMetaObject::activate(this, &staticMetaObject, 784, nullptr);
}

// SIGNAL 785
void Options::GuideCalibrationBacklashChanged()
{
    QMetaObject::activate(this, &staticMetaObject, 785, nullptr);
}

// SIGNAL 786
void Options::AssumeDecOrthogonalChanged()
{
    QMetaObject::activate(this, &staticMetaObject, 786, nullptr);
}

// SIGNAL 787
void Options::SerializedCalibrationChanged()
{
    QMetaObject::activate(this, &staticMetaObject, 787, nullptr);
}

// SIGNAL 788
void Options::RealignAfterCalibrationFailureChanged()
{
    QMetaObject::activate(this, &staticMetaObject, 788, nullptr);
}

// SIGNAL 789
void Options::PreemptiveShutdownTimeChanged()
{
    QMetaObject::activate(this, &staticMetaObject, 789, nullptr);
}

// SIGNAL 790
void Options::RememberJobProgressChanged()
{
    QMetaObject::activate(this, &staticMetaObject, 790, nullptr);
}

// SIGNAL 791
void Options::GreedySchedulingChanged()
{
    QMetaObject::activate(this, &staticMetaObject, 791, nullptr);
}

// SIGNAL 792
void Options::LeadTimeChanged()
{
    QMetaObject::activate(this, &staticMetaObject, 792, nullptr);
}

// SIGNAL 793
void Options::PreDawnTimeChanged()
{
    QMetaObject::activate(this, &staticMetaObject, 793, nullptr);
}

// SIGNAL 794
void Options::DawnOffsetChanged()
{
    QMetaObject::activate(this, &staticMetaObject, 794, nullptr);
}

// SIGNAL 795
void Options::DuskOffsetChanged()
{
    QMetaObject::activate(this, &staticMetaObject, 795, nullptr);
}

// SIGNAL 796
void Options::TelescopeFocalLengthChanged()
{
    QMetaObject::activate(this, &staticMetaObject, 796, nullptr);
}

// SIGNAL 797
void Options::TelescopeFocalReducerChanged()
{
    QMetaObject::activate(this, &staticMetaObject, 797, nullptr);
}

// SIGNAL 798
void Options::CameraPixelWidthChanged()
{
    QMetaObject::activate(this, &staticMetaObject, 798, nullptr);
}

// SIGNAL 799
void Options::CameraPixelHeightChanged()
{
    QMetaObject::activate(this, &staticMetaObject, 799, nullptr);
}

// SIGNAL 800
void Options::CameraWidthChanged()
{
    QMetaObject::activate(this, &staticMetaObject, 800, nullptr);
}

// SIGNAL 801
void Options::CameraHeightChanged()
{
    QMetaObject::activate(this, &staticMetaObject, 801, nullptr);
}

// SIGNAL 802
void Options::CameraRotationChanged()
{
    QMetaObject::activate(this, &staticMetaObject, 802, nullptr);
}

// SIGNAL 803
void Options::ErrorHandlingStrategyChanged()
{
    QMetaObject::activate(this, &staticMetaObject, 803, nullptr);
}

// SIGNAL 804
void Options::ErrorHandlingStrategyDelayChanged()
{
    QMetaObject::activate(this, &staticMetaObject, 804, nullptr);
}

// SIGNAL 805
void Options::RescheduleErrorsChanged()
{
    QMetaObject::activate(this, &staticMetaObject, 805, nullptr);
}

// SIGNAL 806
void Options::AlignCheckFrequencyChanged()
{
    QMetaObject::activate(this, &staticMetaObject, 806, nullptr);
}

// SIGNAL 807
void Options::AlignCheckThresholdChanged()
{
    QMetaObject::activate(this, &staticMetaObject, 807, nullptr);
}

// SIGNAL 808
void Options::SchedulerTrackStepChanged()
{
    QMetaObject::activate(this, &staticMetaObject, 808, nullptr);
}

// SIGNAL 809
void Options::SchedulerStartupEnabledChanged()
{
    QMetaObject::activate(this, &staticMetaObject, 809, nullptr);
}

// SIGNAL 810
void Options::SchedulerPreStartupScriptChanged()
{
    QMetaObject::activate(this, &staticMetaObject, 810, nullptr);
}

// SIGNAL 811
void Options::SchedulerPostStartupScriptChanged()
{
    QMetaObject::activate(this, &staticMetaObject, 811, nullptr);
}

// SIGNAL 812
void Options::SchedulerShutdownEnabledChanged()
{
    QMetaObject::activate(this, &staticMetaObject, 812, nullptr);
}

// SIGNAL 813
void Options::SchedulerPreShutdownScriptChanged()
{
    QMetaObject::activate(this, &staticMetaObject, 813, nullptr);
}

// SIGNAL 814
void Options::SchedulerPostShutdownScriptChanged()
{
    QMetaObject::activate(this, &staticMetaObject, 814, nullptr);
}

// SIGNAL 815
void Options::SchedulerFocusStepChanged()
{
    QMetaObject::activate(this, &staticMetaObject, 815, nullptr);
}

// SIGNAL 816
void Options::SchedulerGuideStepChanged()
{
    QMetaObject::activate(this, &staticMetaObject, 816, nullptr);
}

// SIGNAL 817
void Options::SchedulerAlignStepChanged()
{
    QMetaObject::activate(this, &staticMetaObject, 817, nullptr);
}

// SIGNAL 818
void Options::SchedulerAltitudeChanged()
{
    QMetaObject::activate(this, &staticMetaObject, 818, nullptr);
}

// SIGNAL 819
void Options::SchedulerAltitudeValueChanged()
{
    QMetaObject::activate(this, &staticMetaObject, 819, nullptr);
}

// SIGNAL 820
void Options::SchedulerHorizonChanged()
{
    QMetaObject::activate(this, &staticMetaObject, 820, nullptr);
}

// SIGNAL 821
void Options::SchedulerMoonSeparationChanged()
{
    QMetaObject::activate(this, &staticMetaObject, 821, nullptr);
}

// SIGNAL 822
void Options::SchedulerMoonSeparationValueChanged()
{
    QMetaObject::activate(this, &staticMetaObject, 822, nullptr);
}

// SIGNAL 823
void Options::SchedulerMoonAltitudeChanged()
{
    QMetaObject::activate(this, &staticMetaObject, 823, nullptr);
}

// SIGNAL 824
void Options::SchedulerMoonAltitudeMaxValueChanged()
{
    QMetaObject::activate(this, &staticMetaObject, 824, nullptr);
}

// SIGNAL 825
void Options::SchedulerWeatherChanged()
{
    QMetaObject::activate(this, &staticMetaObject, 825, nullptr);
}

// SIGNAL 826
void Options::SchedulerWeatherGracePeriodChanged()
{
    QMetaObject::activate(this, &staticMetaObject, 826, nullptr);
}

// SIGNAL 827
void Options::SchedulerWeatherShutdownDelayChanged()
{
    QMetaObject::activate(this, &staticMetaObject, 827, nullptr);
}

// SIGNAL 828
void Options::SchedulerSafetyMonitorConnectionStringChanged()
{
    QMetaObject::activate(this, &staticMetaObject, 828, nullptr);
}

// SIGNAL 829
void Options::SchedulerTwilightChanged()
{
    QMetaObject::activate(this, &staticMetaObject, 829, nullptr);
}

// SIGNAL 830
void Options::SchedulerCompleteSequencesChanged()
{
    QMetaObject::activate(this, &staticMetaObject, 830, nullptr);
}

// SIGNAL 831
void Options::SchedulerRepeatEverythingChanged()
{
    QMetaObject::activate(this, &staticMetaObject, 831, nullptr);
}

// SIGNAL 832
void Options::SchedulerRepeatSequencesChanged()
{
    QMetaObject::activate(this, &staticMetaObject, 832, nullptr);
}

// SIGNAL 833
void Options::SchedulerUntilTerminatedChanged()
{
    QMetaObject::activate(this, &staticMetaObject, 833, nullptr);
}

// SIGNAL 834
void Options::SchedulerUntilChanged()
{
    QMetaObject::activate(this, &staticMetaObject, 834, nullptr);
}

// SIGNAL 835
void Options::SchedulerUntilValueChanged()
{
    QMetaObject::activate(this, &staticMetaObject, 835, nullptr);
}

// SIGNAL 836
void Options::SchedulerExecutionSequencesLimitChanged()
{
    QMetaObject::activate(this, &staticMetaObject, 836, nullptr);
}

// SIGNAL 837
void Options::AnalyzeRestartWithEkosChanged()
{
    QMetaObject::activate(this, &staticMetaObject, 837, nullptr);
}

// SIGNAL 838
void Options::AnalyzeAlternativeDirectoryNameChanged()
{
    QMetaObject::activate(this, &staticMetaObject, 838, nullptr);
}

// SIGNAL 839
void Options::AnalyzeHFRChanged()
{
    QMetaObject::activate(this, &staticMetaObject, 839, nullptr);
}

// SIGNAL 840
void Options::AnalyzeNumCaptureStarsChanged()
{
    QMetaObject::activate(this, &staticMetaObject, 840, nullptr);
}

// SIGNAL 841
void Options::AnalyzeMedianChanged()
{
    QMetaObject::activate(this, &staticMetaObject, 841, nullptr);
}

// SIGNAL 842
void Options::AnalyzeEccentricityChanged()
{
    QMetaObject::activate(this, &staticMetaObject, 842, nullptr);
}

// SIGNAL 843
void Options::AnalyzeTemperatureChanged()
{
    QMetaObject::activate(this, &staticMetaObject, 843, nullptr);
}

// SIGNAL 844
void Options::FocusPositionChanged()
{
    QMetaObject::activate(this, &staticMetaObject, 844, nullptr);
}

// SIGNAL 845
void Options::AnalyzeNumStarsChanged()
{
    QMetaObject::activate(this, &staticMetaObject, 845, nullptr);
}

// SIGNAL 846
void Options::AnalyzeSkyBgChanged()
{
    QMetaObject::activate(this, &staticMetaObject, 846, nullptr);
}

// SIGNAL 847
void Options::AnalyzeSNRChanged()
{
    QMetaObject::activate(this, &staticMetaObject, 847, nullptr);
}

// SIGNAL 848
void Options::AnalyzeRAChanged()
{
    QMetaObject::activate(this, &staticMetaObject, 848, nullptr);
}

// SIGNAL 849
void Options::AnalyzeDECChanged()
{
    QMetaObject::activate(this, &staticMetaObject, 849, nullptr);
}

// SIGNAL 850
void Options::AnalyzeRApChanged()
{
    QMetaObject::activate(this, &staticMetaObject, 850, nullptr);
}

// SIGNAL 851
void Options::AnalyzeDECpChanged()
{
    QMetaObject::activate(this, &staticMetaObject, 851, nullptr);
}

// SIGNAL 852
void Options::AnalyzeDriftChanged()
{
    QMetaObject::activate(this, &staticMetaObject, 852, nullptr);
}

// SIGNAL 853
void Options::AnalyzeRMSChanged()
{
    QMetaObject::activate(this, &staticMetaObject, 853, nullptr);
}

// SIGNAL 854
void Options::AnalyzeTargetDistanceChanged()
{
    QMetaObject::activate(this, &staticMetaObject, 854, nullptr);
}

// SIGNAL 855
void Options::AnalyzeRMSCChanged()
{
    QMetaObject::activate(this, &staticMetaObject, 855, nullptr);
}

// SIGNAL 856
void Options::AnalyzeMountRAChanged()
{
    QMetaObject::activate(this, &staticMetaObject, 856, nullptr);
}

// SIGNAL 857
void Options::AnalyzeMountDECChanged()
{
    QMetaObject::activate(this, &staticMetaObject, 857, nullptr);
}

// SIGNAL 858
void Options::AnalyzeMountHAChanged()
{
    QMetaObject::activate(this, &staticMetaObject, 858, nullptr);
}

// SIGNAL 859
void Options::AnalyzeAzChanged()
{
    QMetaObject::activate(this, &staticMetaObject, 859, nullptr);
}

// SIGNAL 860
void Options::AnalyzeAltChanged()
{
    QMetaObject::activate(this, &staticMetaObject, 860, nullptr);
}

// SIGNAL 861
void Options::AnalyzePierSideChanged()
{
    QMetaObject::activate(this, &staticMetaObject, 861, nullptr);
}

// SIGNAL 862
void Options::AnalyzeStatsYAxisChanged()
{
    QMetaObject::activate(this, &staticMetaObject, 862, nullptr);
}

// SIGNAL 863
void Options::LastServerChanged()
{
    QMetaObject::activate(this, &staticMetaObject, 863, nullptr);
}

// SIGNAL 864
void Options::LastServerPortChanged()
{
    QMetaObject::activate(this, &staticMetaObject, 864, nullptr);
}

// SIGNAL 865
void Options::LastWebManagerPortChanged()
{
    QMetaObject::activate(this, &staticMetaObject, 865, nullptr);
}

// SIGNAL 866
void Options::HIPSMemoryCacheChanged()
{
    QMetaObject::activate(this, &staticMetaObject, 866, nullptr);
}

// SIGNAL 867
void Options::HIPSNetCacheChanged()
{
    QMetaObject::activate(this, &staticMetaObject, 867, nullptr);
}

// SIGNAL 868
void Options::HIPSSourceChanged()
{
    QMetaObject::activate(this, &staticMetaObject, 868, nullptr);
}

// SIGNAL 869
void Options::HIPSBiLinearInterpolationChanged()
{
    QMetaObject::activate(this, &staticMetaObject, 869, nullptr);
}

// SIGNAL 870
void Options::HIPSShowGridChanged()
{
    QMetaObject::activate(this, &staticMetaObject, 870, nullptr);
}

// SIGNAL 871
void Options::HIPSPanningChanged()
{
    QMetaObject::activate(this, &staticMetaObject, 871, nullptr);
}

// SIGNAL 872
void Options::ShowHIPSChanged()
{
    QMetaObject::activate(this, &staticMetaObject, 872, nullptr);
}

// SIGNAL 873
void Options::HIPSUseOfflineSourceChanged()
{
    QMetaObject::activate(this, &staticMetaObject, 873, nullptr);
}

// SIGNAL 874
void Options::HIPSOfflinePathChanged()
{
    QMetaObject::activate(this, &staticMetaObject, 874, nullptr);
}

// SIGNAL 875
void Options::TerrainSourceChanged()
{
    QMetaObject::activate(this, &staticMetaObject, 875, nullptr);
}

// SIGNAL 876
void Options::TerrainSourceCorrectAzChanged()
{
    QMetaObject::activate(this, &staticMetaObject, 876, nullptr);
}

// SIGNAL 877
void Options::TerrainSourceCorrectAltChanged()
{
    QMetaObject::activate(this, &staticMetaObject, 877, nullptr);
}

// SIGNAL 878
void Options::TerrainDownsamplingChanged()
{
    QMetaObject::activate(this, &staticMetaObject, 878, nullptr);
}

// SIGNAL 879
void Options::TerrainPanningChanged()
{
    QMetaObject::activate(this, &staticMetaObject, 879, nullptr);
}

// SIGNAL 880
void Options::ShowTerrainChanged()
{
    QMetaObject::activate(this, &staticMetaObject, 880, nullptr);
}

// SIGNAL 881
void Options::TerrainSkipSpeedupChanged()
{
    QMetaObject::activate(this, &staticMetaObject, 881, nullptr);
}

// SIGNAL 882
void Options::TerrainTransparencySpeedupChanged()
{
    QMetaObject::activate(this, &staticMetaObject, 882, nullptr);
}

// SIGNAL 883
void Options::TerrainSmoothPixelsChanged()
{
    QMetaObject::activate(this, &staticMetaObject, 883, nullptr);
}

// SIGNAL 884
void Options::ShowImageOverlaysChanged()
{
    QMetaObject::activate(this, &staticMetaObject, 884, nullptr);
}

// SIGNAL 885
void Options::ShowImageOverlaysBelowCatalogsChanged()
{
    QMetaObject::activate(this, &staticMetaObject, 885, nullptr);
}

// SIGNAL 886
void Options::ShowSelectedImageOverlayChanged()
{
    QMetaObject::activate(this, &staticMetaObject, 886, nullptr);
}

// SIGNAL 887
void Options::ImageOverlayMaxDimensionChanged()
{
    QMetaObject::activate(this, &staticMetaObject, 887, nullptr);
}

// SIGNAL 888
void Options::ImageOverlayTimeoutChanged()
{
    QMetaObject::activate(this, &staticMetaObject, 888, nullptr);
}

// SIGNAL 889
void Options::ImageOverlayDefaultScaleChanged()
{
    QMetaObject::activate(this, &staticMetaObject, 889, nullptr);
}

// SIGNAL 890
void Options::DefaultObservatoryWeatherSourceChanged()
{
    QMetaObject::activate(this, &staticMetaObject, 890, nullptr);
}

// SIGNAL 891
void Options::warningActionsActiveChanged()
{
    QMetaObject::activate(this, &staticMetaObject, 891, nullptr);
}

// SIGNAL 892
void Options::alertActionsActiveChanged()
{
    QMetaObject::activate(this, &staticMetaObject, 892, nullptr);
}

// SIGNAL 893
void Options::weatherWarningCloseDomeChanged()
{
    QMetaObject::activate(this, &staticMetaObject, 893, nullptr);
}

// SIGNAL 894
void Options::weatherWarningCloseShutterChanged()
{
    QMetaObject::activate(this, &staticMetaObject, 894, nullptr);
}

// SIGNAL 895
void Options::weatherWarningStopSchedulerChanged()
{
    QMetaObject::activate(this, &staticMetaObject, 895, nullptr);
}

// SIGNAL 896
void Options::weatherWarningDelayChanged()
{
    QMetaObject::activate(this, &staticMetaObject, 896, nullptr);
}

// SIGNAL 897
void Options::weatherAlertCloseDomeChanged()
{
    QMetaObject::activate(this, &staticMetaObject, 897, nullptr);
}

// SIGNAL 898
void Options::weatherAlertCloseShutterChanged()
{
    QMetaObject::activate(this, &staticMetaObject, 898, nullptr);
}

// SIGNAL 899
void Options::weatherAlertStopSchedulerChanged()
{
    QMetaObject::activate(this, &staticMetaObject, 899, nullptr);
}

// SIGNAL 900
void Options::weatherAlertDelayChanged()
{
    QMetaObject::activate(this, &staticMetaObject, 900, nullptr);
}

// SIGNAL 901
void Options::observatoryStatusUseDomeChanged()
{
    QMetaObject::activate(this, &staticMetaObject, 901, nullptr);
}

// SIGNAL 902
void Options::observatoryStatusUseShutterChanged()
{
    QMetaObject::activate(this, &staticMetaObject, 902, nullptr);
}

// SIGNAL 903
void Options::observatoryStatusUseWeatherChanged()
{
    QMetaObject::activate(this, &staticMetaObject, 903, nullptr);
}

// SIGNAL 904
void Options::weatherAutoScaleValuesChanged()
{
    QMetaObject::activate(this, &staticMetaObject, 904, nullptr);
}

// SIGNAL 905
void Options::ASTAPExecutableChanged()
{
    QMetaObject::activate(this, &staticMetaObject, 905, nullptr);
}

// SIGNAL 906
void Options::ASTAPDownSampleChanged()
{
    QMetaObject::activate(this, &staticMetaObject, 906, nullptr);
}

// SIGNAL 907
void Options::ASTAPDownSampleValueChanged()
{
    QMetaObject::activate(this, &staticMetaObject, 907, nullptr);
}

// SIGNAL 908
void Options::ASTAPSearchRadiusChanged()
{
    QMetaObject::activate(this, &staticMetaObject, 908, nullptr);
}

// SIGNAL 909
void Options::ASTAPSearchRadiusValueChanged()
{
    QMetaObject::activate(this, &staticMetaObject, 909, nullptr);
}

// SIGNAL 910
void Options::ASTAPUpdateFITSChanged()
{
    QMetaObject::activate(this, &staticMetaObject, 910, nullptr);
}

// SIGNAL 911
void Options::ASTAPLargeSearchWindowChanged()
{
    QMetaObject::activate(this, &staticMetaObject, 911, nullptr);
}

// SIGNAL 912
void Options::MosaicTransparencyAutoChanged()
{
    QMetaObject::activate(this, &staticMetaObject, 912, nullptr);
}

// SIGNAL 913
void Options::MosaicTransparencyLevelChanged()
{
    QMetaObject::activate(this, &staticMetaObject, 913, nullptr);
}

// SIGNAL 914
void Options::MCPEnabledChanged()
{
    QMetaObject::activate(this, &staticMetaObject, 914, nullptr);
}

// SIGNAL 915
void Options::MCPPortChanged()
{
    QMetaObject::activate(this, &staticMetaObject, 915, nullptr);
}

// SIGNAL 916
void Options::MCPReadOnlyModeChanged()
{
    QMetaObject::activate(this, &staticMetaObject, 916, nullptr);
}

// SIGNAL 917
void Options::MCPDisabledToolsChanged()
{
    QMetaObject::activate(this, &staticMetaObject, 917, nullptr);
}
QT_WARNING_POP
