// This file is generated by kconfig_compiler_kf6 from kstars.kcfg.
// All changes you do to this file will be lost.

#include "Options.h"

#include <qglobal.h>
#include <QFile>

class OptionsHelper
{
  public:
    OptionsHelper() noexcept : q(nullptr) {}
    ~OptionsHelper() noexcept { delete q; q = nullptr; }
    OptionsHelper(const OptionsHelper&) = delete;
    OptionsHelper& operator=(const OptionsHelper&) = delete;
    Options *q;
};
Q_GLOBAL_STATIC(OptionsHelper, s_globalOptions)
Options *Options::self()
{
  if (!s_globalOptions()->q) {
    new Options;
    s_globalOptions()->q->read();
  }

  return s_globalOptions()->q;
}

Options::Options( )
  : KConfigSkeleton( QStringLiteral( "kstarsrc" ) )
{
  Q_ASSERT(!s_globalOptions()->q);
  s_globalOptions()->q = this;
  KConfigCompilerSignallingItem::NotifyFunction notifyFunction = static_cast<KConfigCompilerSignallingItem::NotifyFunction>(&Options::itemChanged);

  setCurrentGroup( QStringLiteral( "GUI" ) );

  KConfigCompilerSignallingItem  *itemPositionTimeBox;
  KConfigSkeleton::ItemPoint  *innerItemPositionTimeBox;
  innerItemPositionTimeBox = new KConfigSkeleton::ItemPoint( currentGroup(), QStringLiteral( "PositionTimeBox" ), mPositionTimeBox, QPoint(0,0) );
  itemPositionTimeBox = new KConfigCompilerSignallingItem(innerItemPositionTimeBox, this, notifyFunction, signalPositionTimeBoxChanged);
  addItem( itemPositionTimeBox, QStringLiteral( "PositionTimeBox" ) );
  KConfigCompilerSignallingItem  *itemPositionFocusBox;
  KConfigSkeleton::ItemPoint  *innerItemPositionFocusBox;
  innerItemPositionFocusBox = new KConfigSkeleton::ItemPoint( currentGroup(), QStringLiteral( "PositionFocusBox" ), mPositionFocusBox, QPoint(600,0) );
  itemPositionFocusBox = new KConfigCompilerSignallingItem(innerItemPositionFocusBox, this, notifyFunction, signalPositionFocusBoxChanged);
  addItem( itemPositionFocusBox, QStringLiteral( "PositionFocusBox" ) );
  KConfigCompilerSignallingItem  *itemPositionGeoBox;
  KConfigSkeleton::ItemPoint  *innerItemPositionGeoBox;
  innerItemPositionGeoBox = new KConfigSkeleton::ItemPoint( currentGroup(), QStringLiteral( "PositionGeoBox" ), mPositionGeoBox, QPoint(0,600) );
  itemPositionGeoBox = new KConfigCompilerSignallingItem(innerItemPositionGeoBox, this, notifyFunction, signalPositionGeoBoxChanged);
  addItem( itemPositionGeoBox, QStringLiteral( "PositionGeoBox" ) );
  KConfigCompilerSignallingItem  *itemShadeTimeBox;
  KConfigSkeleton::ItemBool  *innerItemShadeTimeBox;
  innerItemShadeTimeBox = new KConfigSkeleton::ItemBool( currentGroup(), QStringLiteral( "ShadeTimeBox" ), mShadeTimeBox, true );
  itemShadeTimeBox = new KConfigCompilerSignallingItem(innerItemShadeTimeBox, this, notifyFunction, signalShadeTimeBoxChanged);
  addItem( itemShadeTimeBox, QStringLiteral( "ShadeTimeBox" ) );
  KConfigCompilerSignallingItem  *itemShadeFocusBox;
  KConfigSkeleton::ItemBool  *innerItemShadeFocusBox;
  innerItemShadeFocusBox = new KConfigSkeleton::ItemBool( currentGroup(), QStringLiteral( "ShadeFocusBox" ), mShadeFocusBox, true );
  itemShadeFocusBox = new KConfigCompilerSignallingItem(innerItemShadeFocusBox, this, notifyFunction, signalShadeFocusBoxChanged);
  addItem( itemShadeFocusBox, QStringLiteral( "ShadeFocusBox" ) );
  KConfigCompilerSignallingItem  *itemShadeGeoBox;
  KConfigSkeleton::ItemBool  *innerItemShadeGeoBox;
  innerItemShadeGeoBox = new KConfigSkeleton::ItemBool( currentGroup(), QStringLiteral( "ShadeGeoBox" ), mShadeGeoBox, true );
  itemShadeGeoBox = new KConfigCompilerSignallingItem(innerItemShadeGeoBox, this, notifyFunction, signalShadeGeoBoxChanged);
  addItem( itemShadeGeoBox, QStringLiteral( "ShadeGeoBox" ) );
  KConfigCompilerSignallingItem  *itemShowInfoBoxes;
  KConfigSkeleton::ItemBool  *innerItemShowInfoBoxes;
  innerItemShowInfoBoxes = new KConfigSkeleton::ItemBool( currentGroup(), QStringLiteral( "ShowInfoBoxes" ), mShowInfoBoxes, true );
  itemShowInfoBoxes = new KConfigCompilerSignallingItem(innerItemShowInfoBoxes, this, notifyFunction, signalShowInfoBoxesChanged);
  addItem( itemShowInfoBoxes, QStringLiteral( "ShowInfoBoxes" ) );
  KConfigCompilerSignallingItem  *itemShowTimeBox;
  KConfigSkeleton::ItemBool  *innerItemShowTimeBox;
  innerItemShowTimeBox = new KConfigSkeleton::ItemBool( currentGroup(), QStringLiteral( "ShowTimeBox" ), mShowTimeBox, true );
  itemShowTimeBox = new KConfigCompilerSignallingItem(innerItemShowTimeBox, this, notifyFunction, signalShowTimeBoxChanged);
  addItem( itemShowTimeBox, QStringLiteral( "ShowTimeBox" ) );
  KConfigCompilerSignallingItem  *itemShowFocusBox;
  KConfigSkeleton::ItemBool  *innerItemShowFocusBox;
  innerItemShowFocusBox = new KConfigSkeleton::ItemBool( currentGroup(), QStringLiteral( "ShowFocusBox" ), mShowFocusBox, true );
  itemShowFocusBox = new KConfigCompilerSignallingItem(innerItemShowFocusBox, this, notifyFunction, signalShowFocusBoxChanged);
  addItem( itemShowFocusBox, QStringLiteral( "ShowFocusBox" ) );
  KConfigCompilerSignallingItem  *itemShowGeoBox;
  KConfigSkeleton::ItemBool  *innerItemShowGeoBox;
  innerItemShowGeoBox = new KConfigSkeleton::ItemBool( currentGroup(), QStringLiteral( "ShowGeoBox" ), mShowGeoBox, true );
  itemShowGeoBox = new KConfigCompilerSignallingItem(innerItemShowGeoBox, this, notifyFunction, signalShowGeoBoxChanged);
  addItem( itemShowGeoBox, QStringLiteral( "ShowGeoBox" ) );
  KConfigCompilerSignallingItem  *itemStickyTimeBox;
  KConfigSkeleton::ItemInt  *innerItemStickyTimeBox;
  innerItemStickyTimeBox = new KConfigSkeleton::ItemInt( currentGroup(), QStringLiteral( "StickyTimeBox" ), mStickyTimeBox, 0 );
  itemStickyTimeBox = new KConfigCompilerSignallingItem(innerItemStickyTimeBox, this, notifyFunction, signalStickyTimeBoxChanged);
  innerItemStickyTimeBox->setMinValue(0);
  innerItemStickyTimeBox->setMaxValue(3);
  addItem( itemStickyTimeBox, QStringLiteral( "StickyTimeBox" ) );
  KConfigCompilerSignallingItem  *itemStickyFocusBox;
  KConfigSkeleton::ItemInt  *innerItemStickyFocusBox;
  innerItemStickyFocusBox = new KConfigSkeleton::ItemInt( currentGroup(), QStringLiteral( "StickyFocusBox" ), mStickyFocusBox, 1 );
  itemStickyFocusBox = new KConfigCompilerSignallingItem(innerItemStickyFocusBox, this, notifyFunction, signalStickyFocusBoxChanged);
  innerItemStickyFocusBox->setMinValue(0);
  innerItemStickyFocusBox->setMaxValue(3);
  addItem( itemStickyFocusBox, QStringLiteral( "StickyFocusBox" ) );
  KConfigCompilerSignallingItem  *itemStickyGeoBox;
  KConfigSkeleton::ItemInt  *innerItemStickyGeoBox;
  innerItemStickyGeoBox = new KConfigSkeleton::ItemInt( currentGroup(), QStringLiteral( "StickyGeoBox" ), mStickyGeoBox, 2 );
  itemStickyGeoBox = new KConfigCompilerSignallingItem(innerItemStickyGeoBox, this, notifyFunction, signalStickyGeoBoxChanged);
  innerItemStickyGeoBox->setMinValue(0);
  innerItemStickyGeoBox->setMaxValue(3);
  addItem( itemStickyGeoBox, QStringLiteral( "StickyGeoBox" ) );
  KConfigCompilerSignallingItem  *itemShowStatusBar;
  KConfigSkeleton::ItemBool  *innerItemShowStatusBar;
  innerItemShowStatusBar = new KConfigSkeleton::ItemBool( currentGroup(), QStringLiteral( "ShowStatusBar" ), mShowStatusBar, true );
  itemShowStatusBar = new KConfigCompilerSignallingItem(innerItemShowStatusBar, this, notifyFunction, signalShowStatusBarChanged);
  addItem( itemShowStatusBar, QStringLiteral( "ShowStatusBar" ) );
  KConfigCompilerSignallingItem  *itemShowAltAzField;
  KConfigSkeleton::ItemBool  *innerItemShowAltAzField;
  innerItemShowAltAzField = new KConfigSkeleton::ItemBool( currentGroup(), QStringLiteral( "ShowAltAzField" ), mShowAltAzField, true );
  itemShowAltAzField = new KConfigCompilerSignallingItem(innerItemShowAltAzField, this, notifyFunction, signalShowAltAzFieldChanged);
  addItem( itemShowAltAzField, QStringLiteral( "ShowAltAzField" ) );
  KConfigCompilerSignallingItem  *itemShowRADecField;
  KConfigSkeleton::ItemBool  *innerItemShowRADecField;
  innerItemShowRADecField = new KConfigSkeleton::ItemBool( currentGroup(), QStringLiteral( "ShowRADecField" ), mShowRADecField, true );
  itemShowRADecField = new KConfigCompilerSignallingItem(innerItemShowRADecField, this, notifyFunction, signalShowRADecFieldChanged);
  addItem( itemShowRADecField, QStringLiteral( "ShowRADecField" ) );
  KConfigCompilerSignallingItem  *itemShowJ2000RADecField;
  KConfigSkeleton::ItemBool  *innerItemShowJ2000RADecField;
  innerItemShowJ2000RADecField = new KConfigSkeleton::ItemBool( currentGroup(), QStringLiteral( "ShowJ2000RADecField" ), mShowJ2000RADecField, false );
  itemShowJ2000RADecField = new KConfigCompilerSignallingItem(innerItemShowJ2000RADecField, this, notifyFunction, signalShowJ2000RADecFieldChanged);
  addItem( itemShowJ2000RADecField, QStringLiteral( "ShowJ2000RADecField" ) );
  KConfigCompilerSignallingItem  *itemShowSensorFOV;
  KConfigSkeleton::ItemBool  *innerItemShowSensorFOV;
  innerItemShowSensorFOV = new KConfigSkeleton::ItemBool( currentGroup(), QStringLiteral( "ShowSensorFOV" ), mShowSensorFOV, true );
  itemShowSensorFOV = new KConfigCompilerSignallingItem(innerItemShowSensorFOV, this, notifyFunction, signalShowSensorFOVChanged);
  addItem( itemShowSensorFOV, QStringLiteral( "ShowSensorFOV" ) );
  KConfigCompilerSignallingItem  *itemWindowWidth;
  KConfigSkeleton::ItemUInt  *innerItemWindowWidth;
  innerItemWindowWidth = new KConfigSkeleton::ItemUInt( currentGroup(), QStringLiteral( "WindowWidth" ), mWindowWidth, 1024 );
  itemWindowWidth = new KConfigCompilerSignallingItem(innerItemWindowWidth, this, notifyFunction, signalWindowWidthChanged);
  addItem( itemWindowWidth, QStringLiteral( "WindowWidth" ) );
  KConfigCompilerSignallingItem  *itemWindowHeight;
  KConfigSkeleton::ItemUInt  *innerItemWindowHeight;
  innerItemWindowHeight = new KConfigSkeleton::ItemUInt( currentGroup(), QStringLiteral( "WindowHeight" ), mWindowHeight, 768 );
  itemWindowHeight = new KConfigCompilerSignallingItem(innerItemWindowHeight, this, notifyFunction, signalWindowHeightChanged);
  addItem( itemWindowHeight, QStringLiteral( "WindowHeight" ) );
  KConfigCompilerSignallingItem  *itemKStarsGeometry;
  KConfigSkeleton::ItemString  *innerItemKStarsGeometry;
  innerItemKStarsGeometry = new KConfigSkeleton::ItemString( currentGroup(), QStringLiteral( "KStarsGeometry" ), mKStarsGeometry );
  itemKStarsGeometry = new KConfigCompilerSignallingItem(innerItemKStarsGeometry, this, notifyFunction, signalKStarsGeometryChanged);
  addItem( itemKStarsGeometry, QStringLiteral( "KStarsGeometry" ) );
  KConfigCompilerSignallingItem  *itemRunStartupWizard;
  KConfigSkeleton::ItemBool  *innerItemRunStartupWizard;
  innerItemRunStartupWizard = new KConfigSkeleton::ItemBool( currentGroup(), QStringLiteral( "RunStartupWizard" ), mRunStartupWizard, true );
  itemRunStartupWizard = new KConfigCompilerSignallingItem(innerItemRunStartupWizard, this, notifyFunction, signalRunStartupWizardChanged);
  addItem( itemRunStartupWizard, QStringLiteral( "RunStartupWizard" ) );
  KConfigCompilerSignallingItem  *itemCurrentTheme;
  KConfigSkeleton::ItemString  *innerItemCurrentTheme;
  innerItemCurrentTheme = new KConfigSkeleton::ItemString( currentGroup(), QStringLiteral( "CurrentTheme" ), mCurrentTheme, QStringLiteral( "Default" ) );
  itemCurrentTheme = new KConfigCompilerSignallingItem(innerItemCurrentTheme, this, notifyFunction, signalCurrentThemeChanged);
  addItem( itemCurrentTheme, QStringLiteral( "CurrentTheme" ) );

  setCurrentGroup( QStringLiteral( "Catalogs" ) );

  KConfigCompilerSignallingItem  *itemCatalogFile;
  KConfigSkeleton::ItemStringList  *innerItemCatalogFile;
  innerItemCatalogFile = new KConfigSkeleton::ItemStringList( currentGroup(), QStringLiteral( "CatalogFile" ), mCatalogFile );
  itemCatalogFile = new KConfigCompilerSignallingItem(innerItemCatalogFile, this, notifyFunction, signalCatalogFileChanged);
  addItem( itemCatalogFile, QStringLiteral( "CatalogFile" ) );
  QList<int> defaultShowCatalog;

  KConfigCompilerSignallingItem  *itemShowCatalog;
  KConfigSkeleton::ItemIntList  *innerItemShowCatalog;
  innerItemShowCatalog = new KConfigSkeleton::ItemIntList( currentGroup(), QStringLiteral( "ShowCatalog" ), mShowCatalog, defaultShowCatalog );
  itemShowCatalog = new KConfigCompilerSignallingItem(innerItemShowCatalog, this, notifyFunction, signalShowCatalogChanged);
  addItem( itemShowCatalog, QStringLiteral( "ShowCatalog" ) );
  KConfigCompilerSignallingItem  *itemShowCatalogNames;
  KConfigSkeleton::ItemStringList  *innerItemShowCatalogNames;
  innerItemShowCatalogNames = new KConfigSkeleton::ItemStringList( currentGroup(), QStringLiteral( "ShowCatalogNames" ), mShowCatalogNames );
  itemShowCatalogNames = new KConfigCompilerSignallingItem(innerItemShowCatalogNames, this, notifyFunction, signalShowCatalogNamesChanged);
  addItem( itemShowCatalogNames, QStringLiteral( "ShowCatalogNames" ) );
  KConfigCompilerSignallingItem  *itemResolveNamesOnline;
  KConfigSkeleton::ItemBool  *innerItemResolveNamesOnline;
  innerItemResolveNamesOnline = new KConfigSkeleton::ItemBool( currentGroup(), QStringLiteral( "ResolveNamesOnline" ), mResolveNamesOnline, true );
  itemResolveNamesOnline = new KConfigCompilerSignallingItem(innerItemResolveNamesOnline, this, notifyFunction, signalResolveNamesOnlineChanged);
  addItem( itemResolveNamesOnline, QStringLiteral( "ResolveNamesOnline" ) );
  KConfigCompilerSignallingItem  *itemDSOCachePercentage;
  KConfigSkeleton::ItemUInt  *innerItemDSOCachePercentage;
  innerItemDSOCachePercentage = new KConfigSkeleton::ItemUInt( currentGroup(), QStringLiteral( "DSOCachePercentage" ), mDSOCachePercentage, 100 );
  itemDSOCachePercentage = new KConfigCompilerSignallingItem(innerItemDSOCachePercentage, this, notifyFunction, signalDSOCachePercentageChanged);
  innerItemDSOCachePercentage->setMinValue(5);
  innerItemDSOCachePercentage->setMaxValue(100);
  addItem( itemDSOCachePercentage, QStringLiteral( "DSOCachePercentage" ) );
  KConfigCompilerSignallingItem  *itemDSOMinZoomFactor;
  KConfigSkeleton::ItemUInt  *innerItemDSOMinZoomFactor;
  innerItemDSOMinZoomFactor = new KConfigSkeleton::ItemUInt( currentGroup(), QStringLiteral( "DSOMinZoomFactor" ), mDSOMinZoomFactor, 400 );
  itemDSOMinZoomFactor = new KConfigCompilerSignallingItem(innerItemDSOMinZoomFactor, this, notifyFunction, signalDSOMinZoomFactorChanged);
  innerItemDSOMinZoomFactor->setMinValue(250);
  innerItemDSOMinZoomFactor->setMaxValue(4000);
  addItem( itemDSOMinZoomFactor, QStringLiteral( "DSOMinZoomFactor" ) );
  KConfigCompilerSignallingItem  *itemDSOCatalogFilename;
  KConfigSkeleton::ItemString  *innerItemDSOCatalogFilename;
  innerItemDSOCatalogFilename = new KConfigSkeleton::ItemString( currentGroup(), QStringLiteral( "DSOCatalogFilename" ), mDSOCatalogFilename, QStringLiteral( "dso_main.kscat" ) );
  itemDSOCatalogFilename = new KConfigCompilerSignallingItem(innerItemDSOCatalogFilename, this, notifyFunction, signalDSOCatalogFilenameChanged);
  addItem( itemDSOCatalogFilename, QStringLiteral( "DSOCatalogFilename" ) );
  KConfigCompilerSignallingItem  *itemDSODefaultCatalogFilename;
  KConfigSkeleton::ItemString  *innerItemDSODefaultCatalogFilename;
  innerItemDSODefaultCatalogFilename = new KConfigSkeleton::ItemString( currentGroup(), QStringLiteral( "DSODefaultCatalogFilename" ), mDSODefaultCatalogFilename, QStringLiteral( "OpenNGC.kscat" ) );
  itemDSODefaultCatalogFilename = new KConfigCompilerSignallingItem(innerItemDSODefaultCatalogFilename, this, notifyFunction, signalDSODefaultCatalogFilenameChanged);
  addItem( itemDSODefaultCatalogFilename, QStringLiteral( "DSODefaultCatalogFilename" ) );

  setCurrentGroup( QStringLiteral( "indi" ) );

  KConfigCompilerSignallingItem  *itemINDIWindowWidth;
  KConfigSkeleton::ItemUInt  *innerItemINDIWindowWidth;
  innerItemINDIWindowWidth = new KConfigSkeleton::ItemUInt( currentGroup(), QStringLiteral( "INDIWindowWidth" ), mINDIWindowWidth, 800 );
  itemINDIWindowWidth = new KConfigCompilerSignallingItem(innerItemINDIWindowWidth, this, notifyFunction, signalINDIWindowWidthChanged);
  addItem( itemINDIWindowWidth, QStringLiteral( "INDIWindowWidth" ) );
  KConfigCompilerSignallingItem  *itemINDIWindowHeight;
  KConfigSkeleton::ItemUInt  *innerItemINDIWindowHeight;
  innerItemINDIWindowHeight = new KConfigSkeleton::ItemUInt( currentGroup(), QStringLiteral( "INDIWindowHeight" ), mINDIWindowHeight, 600 );
  itemINDIWindowHeight = new KConfigCompilerSignallingItem(innerItemINDIWindowHeight, this, notifyFunction, signalINDIWindowHeightChanged);
  addItem( itemINDIWindowHeight, QStringLiteral( "INDIWindowHeight" ) );
  KConfigCompilerSignallingItem  *itemINDIWindowGeometry;
  KConfigSkeleton::ItemString  *innerItemINDIWindowGeometry;
  innerItemINDIWindowGeometry = new KConfigSkeleton::ItemString( currentGroup(), QStringLiteral( "INDIWindowGeometry" ), mINDIWindowGeometry );
  itemINDIWindowGeometry = new KConfigCompilerSignallingItem(innerItemINDIWindowGeometry, this, notifyFunction, signalINDIWindowGeometryChanged);
  addItem( itemINDIWindowGeometry, QStringLiteral( "INDIWindowGeometry" ) );
  KConfigCompilerSignallingItem  *itemUseGeographicUpdate;
  KConfigSkeleton::ItemBool  *innerItemUseGeographicUpdate;
  innerItemUseGeographicUpdate = new KConfigSkeleton::ItemBool( currentGroup(), QStringLiteral( "useGeographicUpdate" ), mUseGeographicUpdate, true );
  itemUseGeographicUpdate = new KConfigCompilerSignallingItem(innerItemUseGeographicUpdate, this, notifyFunction, signalUseGeographicUpdateChanged);
  addItem( itemUseGeographicUpdate, QStringLiteral( "useGeographicUpdate" ) );
  KConfigCompilerSignallingItem  *itemUseTimeUpdate;
  KConfigSkeleton::ItemBool  *innerItemUseTimeUpdate;
  innerItemUseTimeUpdate = new KConfigSkeleton::ItemBool( currentGroup(), QStringLiteral( "useTimeUpdate" ), mUseTimeUpdate, true );
  itemUseTimeUpdate = new KConfigCompilerSignallingItem(innerItemUseTimeUpdate, this, notifyFunction, signalUseTimeUpdateChanged);
  addItem( itemUseTimeUpdate, QStringLiteral( "useTimeUpdate" ) );
  KConfigCompilerSignallingItem  *itemIndependentWindowINDI;
  KConfigSkeleton::ItemBool  *innerItemIndependentWindowINDI;
  innerItemIndependentWindowINDI = new KConfigSkeleton::ItemBool( currentGroup(), QStringLiteral( "independentWindowINDI" ), mIndependentWindowINDI, false );
  itemIndependentWindowINDI = new KConfigCompilerSignallingItem(innerItemIndependentWindowINDI, this, notifyFunction, signalIndependentWindowINDIChanged);
  addItem( itemIndependentWindowINDI, QStringLiteral( "independentWindowINDI" ) );
  KConfigCompilerSignallingItem  *itemShowTargetCrosshair;
  KConfigSkeleton::ItemBool  *innerItemShowTargetCrosshair;
  innerItemShowTargetCrosshair = new KConfigSkeleton::ItemBool( currentGroup(), QStringLiteral( "showTargetCrosshair" ), mShowTargetCrosshair, true );
  itemShowTargetCrosshair = new KConfigCompilerSignallingItem(innerItemShowTargetCrosshair, this, notifyFunction, signalShowTargetCrosshairChanged);
  addItem( itemShowTargetCrosshair, QStringLiteral( "showTargetCrosshair" ) );
  KConfigCompilerSignallingItem  *itemShowINDIMessages;
  KConfigSkeleton::ItemBool  *innerItemShowINDIMessages;
  innerItemShowINDIMessages = new KConfigSkeleton::ItemBool( currentGroup(), QStringLiteral( "showINDIMessages" ), mShowINDIMessages, true );
  itemShowINDIMessages = new KConfigCompilerSignallingItem(innerItemShowINDIMessages, this, notifyFunction, signalShowINDIMessagesChanged);
  addItem( itemShowINDIMessages, QStringLiteral( "showINDIMessages" ) );
  KConfigCompilerSignallingItem  *itemShowINDIwindowInitially;
  KConfigSkeleton::ItemBool  *innerItemShowINDIwindowInitially;
  innerItemShowINDIwindowInitially = new KConfigSkeleton::ItemBool( currentGroup(), QStringLiteral( "showINDIwindowInitially" ), mShowINDIwindowInitially, true );
  itemShowINDIwindowInitially = new KConfigCompilerSignallingItem(innerItemShowINDIwindowInitially, this, notifyFunction, signalShowINDIwindowInitiallyChanged);
  addItem( itemShowINDIwindowInitially, QStringLiteral( "showINDIwindowInitially" ) );
  KConfigCompilerSignallingItem  *itemMaxFocusFrameFiles;
  KConfigSkeleton::ItemInt  *innerItemMaxFocusFrameFiles;
  innerItemMaxFocusFrameFiles = new KConfigSkeleton::ItemInt( currentGroup(), QStringLiteral( "maxFocusFrameFiles" ), mMaxFocusFrameFiles, 0 );
  itemMaxFocusFrameFiles = new KConfigCompilerSignallingItem(innerItemMaxFocusFrameFiles, this, notifyFunction, signalMaxFocusFrameFilesChanged);
  addItem( itemMaxFocusFrameFiles, QStringLiteral( "maxFocusFrameFiles" ) );
  KConfigCompilerSignallingItem  *itemMessageNotificationINDI;
  KConfigSkeleton::ItemBool  *innerItemMessageNotificationINDI;
  innerItemMessageNotificationINDI = new KConfigSkeleton::ItemBool( currentGroup(), QStringLiteral( "messageNotificationINDI" ), mMessageNotificationINDI, true );
  itemMessageNotificationINDI = new KConfigCompilerSignallingItem(innerItemMessageNotificationINDI, this, notifyFunction, signalMessageNotificationINDIChanged);
  addItem( itemMessageNotificationINDI, QStringLiteral( "messageNotificationINDI" ) );
  KConfigCompilerSignallingItem  *itemTimeSource;
  KConfigSkeleton::ItemString  *innerItemTimeSource;
  innerItemTimeSource = new KConfigSkeleton::ItemString( currentGroup(), QStringLiteral( "timeSource" ), mTimeSource, QStringLiteral( "KStars" ) );
  itemTimeSource = new KConfigCompilerSignallingItem(innerItemTimeSource, this, notifyFunction, signalTimeSourceChanged);
  addItem( itemTimeSource, QStringLiteral( "timeSource" ) );
  KConfigCompilerSignallingItem  *itemLocationSource;
  KConfigSkeleton::ItemString  *innerItemLocationSource;
  innerItemLocationSource = new KConfigSkeleton::ItemString( currentGroup(), QStringLiteral( "locationSource" ), mLocationSource, QStringLiteral( "KStars" ) );
  itemLocationSource = new KConfigCompilerSignallingItem(innerItemLocationSource, this, notifyFunction, signalLocationSourceChanged);
  addItem( itemLocationSource, QStringLiteral( "locationSource" ) );
  KConfigCompilerSignallingItem  *itemUseExternalSkyMap;
  KConfigSkeleton::ItemBool  *innerItemUseExternalSkyMap;
  innerItemUseExternalSkyMap = new KConfigSkeleton::ItemBool( currentGroup(), QStringLiteral( "useExternalSkyMap" ), mUseExternalSkyMap, false );
  itemUseExternalSkyMap = new KConfigCompilerSignallingItem(innerItemUseExternalSkyMap, this, notifyFunction, signalUseExternalSkyMapChanged);
  addItem( itemUseExternalSkyMap, QStringLiteral( "useExternalSkyMap" ) );
  KConfigCompilerSignallingItem  *itemFitsDir;
  KConfigSkeleton::ItemString  *innerItemFitsDir;
  innerItemFitsDir = new KConfigSkeleton::ItemString( currentGroup(), QStringLiteral( "fitsDir" ), mFitsDir, KSUtils::getDefaultPath("fitsDir") );
  itemFitsDir = new KConfigCompilerSignallingItem(innerItemFitsDir, this, notifyFunction, signalFitsDirChanged);
  addItem( itemFitsDir, QStringLiteral( "fitsDir" ) );
  KConfigCompilerSignallingItem  *itemServerTransferBufferSize;
  KConfigSkeleton::ItemInt  *innerItemServerTransferBufferSize;
  innerItemServerTransferBufferSize = new KConfigSkeleton::ItemInt( currentGroup(), QStringLiteral( "serverTransferBufferSize" ), mServerTransferBufferSize, 1024 );
  itemServerTransferBufferSize = new KConfigCompilerSignallingItem(innerItemServerTransferBufferSize, this, notifyFunction, signalServerTransferBufferSizeChanged);
  addItem( itemServerTransferBufferSize, QStringLiteral( "serverTransferBufferSize" ) );
  KConfigCompilerSignallingItem  *itemServerPortStart;
  KConfigSkeleton::ItemInt  *innerItemServerPortStart;
  innerItemServerPortStart = new KConfigSkeleton::ItemInt( currentGroup(), QStringLiteral( "serverPortStart" ), mServerPortStart, 7624 );
  itemServerPortStart = new KConfigCompilerSignallingItem(innerItemServerPortStart, this, notifyFunction, signalServerPortStartChanged);
  addItem( itemServerPortStart, QStringLiteral( "serverPortStart" ) );
  KConfigCompilerSignallingItem  *itemServerPortEnd;
  KConfigSkeleton::ItemInt  *innerItemServerPortEnd;
  innerItemServerPortEnd = new KConfigSkeleton::ItemInt( currentGroup(), QStringLiteral( "serverPortEnd" ), mServerPortEnd, 8623 );
  itemServerPortEnd = new KConfigCompilerSignallingItem(innerItemServerPortEnd, this, notifyFunction, signalServerPortEndChanged);
  addItem( itemServerPortEnd, QStringLiteral( "serverPortEnd" ) );
  KConfigCompilerSignallingItem  *itemIndiServer;
  KConfigSkeleton::ItemString  *innerItemIndiServer;
  innerItemIndiServer = new KConfigSkeleton::ItemString( currentGroup(), QStringLiteral( "indiServer" ), mIndiServer, KSUtils::getDefaultPath("indiServer") );
  itemIndiServer = new KConfigCompilerSignallingItem(innerItemIndiServer, this, notifyFunction, signalIndiServerChanged);
  addItem( itemIndiServer, QStringLiteral( "indiServer" ) );
  KConfigCompilerSignallingItem  *itemIndiServerIsInternal;
  KConfigSkeleton::ItemBool  *innerItemIndiServerIsInternal;
  innerItemIndiServerIsInternal = new KConfigSkeleton::ItemBool( currentGroup(), QStringLiteral( "indiServerIsInternal" ), mIndiServerIsInternal, false );
  itemIndiServerIsInternal = new KConfigCompilerSignallingItem(innerItemIndiServerIsInternal, this, notifyFunction, signalIndiServerIsInternalChanged);
  addItem( itemIndiServerIsInternal, QStringLiteral( "indiServerIsInternal" ) );
  KConfigCompilerSignallingItem  *itemIndiDriversDir;
  KConfigSkeleton::ItemString  *innerItemIndiDriversDir;
  innerItemIndiDriversDir = new KConfigSkeleton::ItemString( currentGroup(), QStringLiteral( "indiDriversDir" ), mIndiDriversDir, KSUtils::getDefaultPath("indiDriversDir") );
  itemIndiDriversDir = new KConfigCompilerSignallingItem(innerItemIndiDriversDir, this, notifyFunction, signalIndiDriversDirChanged);
  addItem( itemIndiDriversDir, QStringLiteral( "indiDriversDir" ) );
  KConfigCompilerSignallingItem  *itemIndiDriversAreInternal;
  KConfigSkeleton::ItemBool  *innerItemIndiDriversAreInternal;
  innerItemIndiDriversAreInternal = new KConfigSkeleton::ItemBool( currentGroup(), QStringLiteral( "indiDriversAreInternal" ), mIndiDriversAreInternal, false );
  itemIndiDriversAreInternal = new KConfigCompilerSignallingItem(innerItemIndiDriversAreInternal, this, notifyFunction, signalIndiDriversAreInternalChanged);
  addItem( itemIndiDriversAreInternal, QStringLiteral( "indiDriversAreInternal" ) );
  KConfigCompilerSignallingItem  *itemStreamWindowWidth;
  KConfigSkeleton::ItemUInt  *innerItemStreamWindowWidth;
  innerItemStreamWindowWidth = new KConfigSkeleton::ItemUInt( currentGroup(), QStringLiteral( "streamWindowWidth" ), mStreamWindowWidth, 320 );
  itemStreamWindowWidth = new KConfigCompilerSignallingItem(innerItemStreamWindowWidth, this, notifyFunction, signalStreamWindowWidthChanged);
  addItem( itemStreamWindowWidth, QStringLiteral( "streamWindowWidth" ) );
  KConfigCompilerSignallingItem  *itemStreamWindowHeight;
  KConfigSkeleton::ItemUInt  *innerItemStreamWindowHeight;
  innerItemStreamWindowHeight = new KConfigSkeleton::ItemUInt( currentGroup(), QStringLiteral( "streamWindowHeight" ), mStreamWindowHeight, 240 );
  itemStreamWindowHeight = new KConfigCompilerSignallingItem(innerItemStreamWindowHeight, this, notifyFunction, signalStreamWindowHeightChanged);
  addItem( itemStreamWindowHeight, QStringLiteral( "streamWindowHeight" ) );
  KConfigCompilerSignallingItem  *itemINDIMountLogging;
  KConfigSkeleton::ItemBool  *innerItemINDIMountLogging;
  innerItemINDIMountLogging = new KConfigSkeleton::ItemBool( currentGroup(), QStringLiteral( "INDIMountLogging" ), mINDIMountLogging, false );
  itemINDIMountLogging = new KConfigCompilerSignallingItem(innerItemINDIMountLogging, this, notifyFunction, signalINDIMountLoggingChanged);
  addItem( itemINDIMountLogging, QStringLiteral( "INDIMountLogging" ) );
  KConfigCompilerSignallingItem  *itemINDIFocuserLogging;
  KConfigSkeleton::ItemBool  *innerItemINDIFocuserLogging;
  innerItemINDIFocuserLogging = new KConfigSkeleton::ItemBool( currentGroup(), QStringLiteral( "INDIFocuserLogging" ), mINDIFocuserLogging, false );
  itemINDIFocuserLogging = new KConfigCompilerSignallingItem(innerItemINDIFocuserLogging, this, notifyFunction, signalINDIFocuserLoggingChanged);
  addItem( itemINDIFocuserLogging, QStringLiteral( "INDIFocuserLogging" ) );
  KConfigCompilerSignallingItem  *itemINDICCDLogging;
  KConfigSkeleton::ItemBool  *innerItemINDICCDLogging;
  innerItemINDICCDLogging = new KConfigSkeleton::ItemBool( currentGroup(), QStringLiteral( "INDICCDLogging" ), mINDICCDLogging, false );
  itemINDICCDLogging = new KConfigCompilerSignallingItem(innerItemINDICCDLogging, this, notifyFunction, signalINDICCDLoggingChanged);
  addItem( itemINDICCDLogging, QStringLiteral( "INDICCDLogging" ) );
  KConfigCompilerSignallingItem  *itemINDIFilterWheelLogging;
  KConfigSkeleton::ItemBool  *innerItemINDIFilterWheelLogging;
  innerItemINDIFilterWheelLogging = new KConfigSkeleton::ItemBool( currentGroup(), QStringLiteral( "INDIFilterWheelLogging" ), mINDIFilterWheelLogging, false );
  itemINDIFilterWheelLogging = new KConfigCompilerSignallingItem(innerItemINDIFilterWheelLogging, this, notifyFunction, signalINDIFilterWheelLoggingChanged);
  addItem( itemINDIFilterWheelLogging, QStringLiteral( "INDIFilterWheelLogging" ) );
  KConfigCompilerSignallingItem  *itemINDIDomeLogging;
  KConfigSkeleton::ItemBool  *innerItemINDIDomeLogging;
  innerItemINDIDomeLogging = new KConfigSkeleton::ItemBool( currentGroup(), QStringLiteral( "INDIDomeLogging" ), mINDIDomeLogging, false );
  itemINDIDomeLogging = new KConfigCompilerSignallingItem(innerItemINDIDomeLogging, this, notifyFunction, signalINDIDomeLoggingChanged);
  addItem( itemINDIDomeLogging, QStringLiteral( "INDIDomeLogging" ) );
  KConfigCompilerSignallingItem  *itemINDIDetectorLogging;
  KConfigSkeleton::ItemBool  *innerItemINDIDetectorLogging;
  innerItemINDIDetectorLogging = new KConfigSkeleton::ItemBool( currentGroup(), QStringLiteral( "INDIDetectorLogging" ), mINDIDetectorLogging, false );
  itemINDIDetectorLogging = new KConfigCompilerSignallingItem(innerItemINDIDetectorLogging, this, notifyFunction, signalINDIDetectorLoggingChanged);
  addItem( itemINDIDetectorLogging, QStringLiteral( "INDIDetectorLogging" ) );
  KConfigCompilerSignallingItem  *itemINDIWeatherLogging;
  KConfigSkeleton::ItemBool  *innerItemINDIWeatherLogging;
  innerItemINDIWeatherLogging = new KConfigSkeleton::ItemBool( currentGroup(), QStringLiteral( "INDIWeatherLogging" ), mINDIWeatherLogging, false );
  itemINDIWeatherLogging = new KConfigCompilerSignallingItem(innerItemINDIWeatherLogging, this, notifyFunction, signalINDIWeatherLoggingChanged);
  addItem( itemINDIWeatherLogging, QStringLiteral( "INDIWeatherLogging" ) );
  KConfigCompilerSignallingItem  *itemINDIAuxiliaryLogging;
  KConfigSkeleton::ItemBool  *innerItemINDIAuxiliaryLogging;
  innerItemINDIAuxiliaryLogging = new KConfigSkeleton::ItemBool( currentGroup(), QStringLiteral( "INDIAuxiliaryLogging" ), mINDIAuxiliaryLogging, false );
  itemINDIAuxiliaryLogging = new KConfigCompilerSignallingItem(innerItemINDIAuxiliaryLogging, this, notifyFunction, signalINDIAuxiliaryLoggingChanged);
  addItem( itemINDIAuxiliaryLogging, QStringLiteral( "INDIAuxiliaryLogging" ) );
  KConfigCompilerSignallingItem  *itemINDIRotatorLogging;
  KConfigSkeleton::ItemBool  *innerItemINDIRotatorLogging;
  innerItemINDIRotatorLogging = new KConfigSkeleton::ItemBool( currentGroup(), QStringLiteral( "INDIRotatorLogging" ), mINDIRotatorLogging, false );
  itemINDIRotatorLogging = new KConfigCompilerSignallingItem(innerItemINDIRotatorLogging, this, notifyFunction, signalINDIRotatorLoggingChanged);
  addItem( itemINDIRotatorLogging, QStringLiteral( "INDIRotatorLogging" ) );
  KConfigCompilerSignallingItem  *itemINDIGPSLogging;
  KConfigSkeleton::ItemBool  *innerItemINDIGPSLogging;
  innerItemINDIGPSLogging = new KConfigSkeleton::ItemBool( currentGroup(), QStringLiteral( "INDIGPSLogging" ), mINDIGPSLogging, false );
  itemINDIGPSLogging = new KConfigCompilerSignallingItem(innerItemINDIGPSLogging, this, notifyFunction, signalINDIGPSLoggingChanged);
  addItem( itemINDIGPSLogging, QStringLiteral( "INDIGPSLogging" ) );
  KConfigCompilerSignallingItem  *itemINDIAOLogging;
  KConfigSkeleton::ItemBool  *innerItemINDIAOLogging;
  innerItemINDIAOLogging = new KConfigSkeleton::ItemBool( currentGroup(), QStringLiteral( "INDIAOLogging" ), mINDIAOLogging, false );
  itemINDIAOLogging = new KConfigCompilerSignallingItem(innerItemINDIAOLogging, this, notifyFunction, signalINDIAOLoggingChanged);
  addItem( itemINDIAOLogging, QStringLiteral( "INDIAOLogging" ) );

  setCurrentGroup( QStringLiteral( "Location" ) );

  KConfigCompilerSignallingItem  *itemCityName;
  KConfigSkeleton::ItemString  *innerItemCityName;
  innerItemCityName = new KConfigSkeleton::ItemString( currentGroup(), QStringLiteral( "CityName" ), mCityName, QStringLiteral( "Greenwich" ) );
  itemCityName = new KConfigCompilerSignallingItem(innerItemCityName, this, notifyFunction, signalCityNameChanged);
  addItem( itemCityName, QStringLiteral( "CityName" ) );
  KConfigCompilerSignallingItem  *itemProvinceName;
  KConfigSkeleton::ItemString  *innerItemProvinceName;
  innerItemProvinceName = new KConfigSkeleton::ItemString( currentGroup(), QStringLiteral( "ProvinceName" ), mProvinceName );
  itemProvinceName = new KConfigCompilerSignallingItem(innerItemProvinceName, this, notifyFunction, signalProvinceNameChanged);
  addItem( itemProvinceName, QStringLiteral( "ProvinceName" ) );
  KConfigCompilerSignallingItem  *itemCountryName;
  KConfigSkeleton::ItemString  *innerItemCountryName;
  innerItemCountryName = new KConfigSkeleton::ItemString( currentGroup(), QStringLiteral( "CountryName" ), mCountryName, QStringLiteral( "United Kingdom" ) );
  itemCountryName = new KConfigCompilerSignallingItem(innerItemCountryName, this, notifyFunction, signalCountryNameChanged);
  addItem( itemCountryName, QStringLiteral( "CountryName" ) );
  KConfigCompilerSignallingItem  *itemLongitude;
  KConfigSkeleton::ItemDouble  *innerItemLongitude;
  innerItemLongitude = new KConfigSkeleton::ItemDouble( currentGroup(), QStringLiteral( "Longitude" ), mLongitude, 0.0 );
  itemLongitude = new KConfigCompilerSignallingItem(innerItemLongitude, this, notifyFunction, signalLongitudeChanged);
  addItem( itemLongitude, QStringLiteral( "Longitude" ) );
  KConfigCompilerSignallingItem  *itemLatitude;
  KConfigSkeleton::ItemDouble  *innerItemLatitude;
  innerItemLatitude = new KConfigSkeleton::ItemDouble( currentGroup(), QStringLiteral( "Latitude" ), mLatitude, 51.468 );
  itemLatitude = new KConfigCompilerSignallingItem(innerItemLatitude, this, notifyFunction, signalLatitudeChanged);
  addItem( itemLatitude, QStringLiteral( "Latitude" ) );
  KConfigCompilerSignallingItem  *itemElevation;
  KConfigSkeleton::ItemDouble  *innerItemElevation;
  innerItemElevation = new KConfigSkeleton::ItemDouble( currentGroup(), QStringLiteral( "Elevation" ), mElevation, -10.0 );
  itemElevation = new KConfigCompilerSignallingItem(innerItemElevation, this, notifyFunction, signalElevationChanged);
  addItem( itemElevation, QStringLiteral( "Elevation" ) );
  KConfigCompilerSignallingItem  *itemTimeZone;
  KConfigSkeleton::ItemDouble  *innerItemTimeZone;
  innerItemTimeZone = new KConfigSkeleton::ItemDouble( currentGroup(), QStringLiteral( "TimeZone" ), mTimeZone, 0.0 );
  itemTimeZone = new KConfigCompilerSignallingItem(innerItemTimeZone, this, notifyFunction, signalTimeZoneChanged);
  addItem( itemTimeZone, QStringLiteral( "TimeZone" ) );
  KConfigCompilerSignallingItem  *itemDST;
  KConfigSkeleton::ItemString  *innerItemDST;
  innerItemDST = new KConfigSkeleton::ItemString( currentGroup(), QStringLiteral( "DST" ), mDST, QStringLiteral( "--" ) );
  itemDST = new KConfigCompilerSignallingItem(innerItemDST, this, notifyFunction, signalDSTChanged);
  addItem( itemDST, QStringLiteral( "DST" ) );

  setCurrentGroup( QStringLiteral( "View" ) );

  KConfigCompilerSignallingItem  *itemUseAnimatedSlewing;
  KConfigSkeleton::ItemBool  *innerItemUseAnimatedSlewing;
  innerItemUseAnimatedSlewing = new KConfigSkeleton::ItemBool( currentGroup(), QStringLiteral( "UseAnimatedSlewing" ), mUseAnimatedSlewing, true );
  itemUseAnimatedSlewing = new KConfigCompilerSignallingItem(innerItemUseAnimatedSlewing, this, notifyFunction, signalUseAnimatedSlewingChanged);
  addItem( itemUseAnimatedSlewing, QStringLiteral( "UseAnimatedSlewing" ) );
  KConfigCompilerSignallingItem  *itemLeftClickSelectsObject;
  KConfigSkeleton::ItemBool  *innerItemLeftClickSelectsObject;
  innerItemLeftClickSelectsObject = new KConfigSkeleton::ItemBool( currentGroup(), QStringLiteral( "LeftClickSelectsObject" ), mLeftClickSelectsObject, false );
  itemLeftClickSelectsObject = new KConfigCompilerSignallingItem(innerItemLeftClickSelectsObject, this, notifyFunction, signalLeftClickSelectsObjectChanged);
  addItem( itemLeftClickSelectsObject, QStringLiteral( "LeftClickSelectsObject" ) );
  KConfigCompilerSignallingItem  *itemDefaultCursor;
  KConfigSkeleton::ItemUInt  *innerItemDefaultCursor;
  innerItemDefaultCursor = new KConfigSkeleton::ItemUInt( currentGroup(), QStringLiteral( "DefaultCursor" ), mDefaultCursor, 1 );
  itemDefaultCursor = new KConfigCompilerSignallingItem(innerItemDefaultCursor, this, notifyFunction, signalDefaultCursorChanged);
  addItem( itemDefaultCursor, QStringLiteral( "DefaultCursor" ) );
  QStringList defaultFOVNames;
  defaultFOVNames.append( QString::fromUtf8( "Telrad" ) );

  KConfigCompilerSignallingItem  *itemFOVNames;
  KConfigSkeleton::ItemStringList  *innerItemFOVNames;
  innerItemFOVNames = new KConfigSkeleton::ItemStringList( currentGroup(), QStringLiteral( "FOVNames" ), mFOVNames, defaultFOVNames );
  itemFOVNames = new KConfigCompilerSignallingItem(innerItemFOVNames, this, notifyFunction, signalFOVNamesChanged);
  addItem( itemFOVNames, QStringLiteral( "FOVNames" ) );
  KConfigCompilerSignallingItem  *itemFadePlanetTrails;
  KConfigSkeleton::ItemBool  *innerItemFadePlanetTrails;
  innerItemFadePlanetTrails = new KConfigSkeleton::ItemBool( currentGroup(), QStringLiteral( "FadePlanetTrails" ), mFadePlanetTrails, true );
  itemFadePlanetTrails = new KConfigCompilerSignallingItem(innerItemFadePlanetTrails, this, notifyFunction, signalFadePlanetTrailsChanged);
  addItem( itemFadePlanetTrails, QStringLiteral( "FadePlanetTrails" ) );
  KConfigCompilerSignallingItem  *itemFocusRA;
  KConfigSkeleton::ItemDouble  *innerItemFocusRA;
  innerItemFocusRA = new KConfigSkeleton::ItemDouble( currentGroup(), QStringLiteral( "FocusRA" ), mFocusRA, 180.0 );
  itemFocusRA = new KConfigCompilerSignallingItem(innerItemFocusRA, this, notifyFunction, signalFocusRAChanged);
  addItem( itemFocusRA, QStringLiteral( "FocusRA" ) );
  KConfigCompilerSignallingItem  *itemFocusDec;
  KConfigSkeleton::ItemDouble  *innerItemFocusDec;
  innerItemFocusDec = new KConfigSkeleton::ItemDouble( currentGroup(), QStringLiteral( "FocusDec" ), mFocusDec, 45.0 );
  itemFocusDec = new KConfigCompilerSignallingItem(innerItemFocusDec, this, notifyFunction, signalFocusDecChanged);
  addItem( itemFocusDec, QStringLiteral( "FocusDec" ) );
  KConfigCompilerSignallingItem  *itemFocusObject;
  KConfigSkeleton::ItemString  *innerItemFocusObject;
  innerItemFocusObject = new KConfigSkeleton::ItemString( currentGroup(), QStringLiteral( "FocusObject" ), mFocusObject, QStringLiteral( "nothing" ) );
  itemFocusObject = new KConfigCompilerSignallingItem(innerItemFocusObject, this, notifyFunction, signalFocusObjectChanged);
  addItem( itemFocusObject, QStringLiteral( "FocusObject" ) );
  KConfigCompilerSignallingItem  *itemIsTracking;
  KConfigSkeleton::ItemBool  *innerItemIsTracking;
  innerItemIsTracking = new KConfigSkeleton::ItemBool( currentGroup(), QStringLiteral( "IsTracking" ), mIsTracking, false );
  itemIsTracking = new KConfigCompilerSignallingItem(innerItemIsTracking, this, notifyFunction, signalIsTrackingChanged);
  addItem( itemIsTracking, QStringLiteral( "IsTracking" ) );
  KConfigCompilerSignallingItem  *itemHideOnSlew;
  KConfigSkeleton::ItemBool  *innerItemHideOnSlew;
  innerItemHideOnSlew = new KConfigSkeleton::ItemBool( currentGroup(), QStringLiteral( "HideOnSlew" ), mHideOnSlew, true );
  itemHideOnSlew = new KConfigCompilerSignallingItem(innerItemHideOnSlew, this, notifyFunction, signalHideOnSlewChanged);
  addItem( itemHideOnSlew, QStringLiteral( "HideOnSlew" ) );
  KConfigCompilerSignallingItem  *itemHideCBounds;
  KConfigSkeleton::ItemBool  *innerItemHideCBounds;
  innerItemHideCBounds = new KConfigSkeleton::ItemBool( currentGroup(), QStringLiteral( "HideCBounds" ), mHideCBounds, true );
  itemHideCBounds = new KConfigCompilerSignallingItem(innerItemHideCBounds, this, notifyFunction, signalHideCBoundsChanged);
  addItem( itemHideCBounds, QStringLiteral( "HideCBounds" ) );
  KConfigCompilerSignallingItem  *itemHideCLines;
  KConfigSkeleton::ItemBool  *innerItemHideCLines;
  innerItemHideCLines = new KConfigSkeleton::ItemBool( currentGroup(), QStringLiteral( "HideCLines" ), mHideCLines, false );
  itemHideCLines = new KConfigCompilerSignallingItem(innerItemHideCLines, this, notifyFunction, signalHideCLinesChanged);
  addItem( itemHideCLines, QStringLiteral( "HideCLines" ) );
  KConfigCompilerSignallingItem  *itemSkyCulture;
  KConfigSkeleton::ItemString  *innerItemSkyCulture;
  innerItemSkyCulture = new KConfigSkeleton::ItemString( currentGroup(), QStringLiteral( "SkyCulture" ), mSkyCulture, QStringLiteral( "Western" ) );
  itemSkyCulture = new KConfigCompilerSignallingItem(innerItemSkyCulture, this, notifyFunction, signalSkyCultureChanged);
  addItem( itemSkyCulture, QStringLiteral( "SkyCulture" ) );
  KConfigCompilerSignallingItem  *itemHideCNames;
  KConfigSkeleton::ItemBool  *innerItemHideCNames;
  innerItemHideCNames = new KConfigSkeleton::ItemBool( currentGroup(), QStringLiteral( "HideCNames" ), mHideCNames, false );
  itemHideCNames = new KConfigCompilerSignallingItem(innerItemHideCNames, this, notifyFunction, signalHideCNamesChanged);
  addItem( itemHideCNames, QStringLiteral( "HideCNames" ) );
  KConfigCompilerSignallingItem  *itemHideGrids;
  KConfigSkeleton::ItemBool  *innerItemHideGrids;
  innerItemHideGrids = new KConfigSkeleton::ItemBool( currentGroup(), QStringLiteral( "HideGrids" ), mHideGrids, true );
  itemHideGrids = new KConfigCompilerSignallingItem(innerItemHideGrids, this, notifyFunction, signalHideGridsChanged);
  addItem( itemHideGrids, QStringLiteral( "HideGrids" ) );
  KConfigCompilerSignallingItem  *itemHideMilkyWay;
  KConfigSkeleton::ItemBool  *innerItemHideMilkyWay;
  innerItemHideMilkyWay = new KConfigSkeleton::ItemBool( currentGroup(), QStringLiteral( "HideMilkyWay" ), mHideMilkyWay, true );
  itemHideMilkyWay = new KConfigCompilerSignallingItem(innerItemHideMilkyWay, this, notifyFunction, signalHideMilkyWayChanged);
  addItem( itemHideMilkyWay, QStringLiteral( "HideMilkyWay" ) );
  KConfigCompilerSignallingItem  *itemHideOther;
  KConfigSkeleton::ItemBool  *innerItemHideOther;
  innerItemHideOther = new KConfigSkeleton::ItemBool( currentGroup(), QStringLiteral( "HideOther" ), mHideOther, true );
  itemHideOther = new KConfigCompilerSignallingItem(innerItemHideOther, this, notifyFunction, signalHideOtherChanged);
  addItem( itemHideOther, QStringLiteral( "HideOther" ) );
  KConfigCompilerSignallingItem  *itemHidePlanets;
  KConfigSkeleton::ItemBool  *innerItemHidePlanets;
  innerItemHidePlanets = new KConfigSkeleton::ItemBool( currentGroup(), QStringLiteral( "HidePlanets" ), mHidePlanets, false );
  itemHidePlanets = new KConfigCompilerSignallingItem(innerItemHidePlanets, this, notifyFunction, signalHidePlanetsChanged);
  addItem( itemHidePlanets, QStringLiteral( "HidePlanets" ) );
  KConfigCompilerSignallingItem  *itemHideStars;
  KConfigSkeleton::ItemBool  *innerItemHideStars;
  innerItemHideStars = new KConfigSkeleton::ItemBool( currentGroup(), QStringLiteral( "HideStars" ), mHideStars, true );
  itemHideStars = new KConfigCompilerSignallingItem(innerItemHideStars, this, notifyFunction, signalHideStarsChanged);
  addItem( itemHideStars, QStringLiteral( "HideStars" ) );
  KConfigCompilerSignallingItem  *itemHideLabels;
  KConfigSkeleton::ItemBool  *innerItemHideLabels;
  innerItemHideLabels = new KConfigSkeleton::ItemBool( currentGroup(), QStringLiteral( "HideLabels" ), mHideLabels, true );
  itemHideLabels = new KConfigCompilerSignallingItem(innerItemHideLabels, this, notifyFunction, signalHideLabelsChanged);
  addItem( itemHideLabels, QStringLiteral( "HideLabels" ) );
  KConfigCompilerSignallingItem  *itemShowAsteroids;
  KConfigSkeleton::ItemBool  *innerItemShowAsteroids;
  innerItemShowAsteroids = new KConfigSkeleton::ItemBool( currentGroup(), QStringLiteral( "ShowAsteroids" ), mShowAsteroids, true );
  itemShowAsteroids = new KConfigCompilerSignallingItem(innerItemShowAsteroids, this, notifyFunction, signalShowAsteroidsChanged);
  addItem( itemShowAsteroids, QStringLiteral( "ShowAsteroids" ) );
  KConfigCompilerSignallingItem  *itemShowAsteroidNames;
  KConfigSkeleton::ItemBool  *innerItemShowAsteroidNames;
  innerItemShowAsteroidNames = new KConfigSkeleton::ItemBool( currentGroup(), QStringLiteral( "ShowAsteroidNames" ), mShowAsteroidNames, false );
  itemShowAsteroidNames = new KConfigCompilerSignallingItem(innerItemShowAsteroidNames, this, notifyFunction, signalShowAsteroidNamesChanged);
  addItem( itemShowAsteroidNames, QStringLiteral( "ShowAsteroidNames" ) );
  KConfigCompilerSignallingItem  *itemOrbitalElementsAutoUpdate;
  KConfigSkeleton::ItemBool  *innerItemOrbitalElementsAutoUpdate;
  innerItemOrbitalElementsAutoUpdate = new KConfigSkeleton::ItemBool( currentGroup(), QStringLiteral( "OrbitalElementsAutoUpdate" ), mOrbitalElementsAutoUpdate, true );
  itemOrbitalElementsAutoUpdate = new KConfigCompilerSignallingItem(innerItemOrbitalElementsAutoUpdate, this, notifyFunction, signalOrbitalElementsAutoUpdateChanged);
  addItem( itemOrbitalElementsAutoUpdate, QStringLiteral( "OrbitalElementsAutoUpdate" ) );
  KConfigCompilerSignallingItem  *itemShowComets;
  KConfigSkeleton::ItemBool  *innerItemShowComets;
  innerItemShowComets = new KConfigSkeleton::ItemBool( currentGroup(), QStringLiteral( "ShowComets" ), mShowComets, true );
  itemShowComets = new KConfigCompilerSignallingItem(innerItemShowComets, this, notifyFunction, signalShowCometsChanged);
  addItem( itemShowComets, QStringLiteral( "ShowComets" ) );
  KConfigCompilerSignallingItem  *itemShowCometComas;
  KConfigSkeleton::ItemBool  *innerItemShowCometComas;
  innerItemShowCometComas = new KConfigSkeleton::ItemBool( currentGroup(), QStringLiteral( "ShowCometComas" ), mShowCometComas, true );
  itemShowCometComas = new KConfigCompilerSignallingItem(innerItemShowCometComas, this, notifyFunction, signalShowCometComasChanged);
  addItem( itemShowCometComas, QStringLiteral( "ShowCometComas" ) );
  KConfigCompilerSignallingItem  *itemShowCometNames;
  KConfigSkeleton::ItemBool  *innerItemShowCometNames;
  innerItemShowCometNames = new KConfigSkeleton::ItemBool( currentGroup(), QStringLiteral( "ShowCometNames" ), mShowCometNames, false );
  itemShowCometNames = new KConfigCompilerSignallingItem(innerItemShowCometNames, this, notifyFunction, signalShowCometNamesChanged);
  addItem( itemShowCometNames, QStringLiteral( "ShowCometNames" ) );
  KConfigCompilerSignallingItem  *itemShowSupernovae;
  KConfigSkeleton::ItemBool  *innerItemShowSupernovae;
  innerItemShowSupernovae = new KConfigSkeleton::ItemBool( currentGroup(), QStringLiteral( "ShowSupernovae" ), mShowSupernovae, true );
  itemShowSupernovae = new KConfigCompilerSignallingItem(innerItemShowSupernovae, this, notifyFunction, signalShowSupernovaeChanged);
  addItem( itemShowSupernovae, QStringLiteral( "ShowSupernovae" ) );
  KConfigCompilerSignallingItem  *itemShowSupernovaNames;
  KConfigSkeleton::ItemBool  *innerItemShowSupernovaNames;
  innerItemShowSupernovaNames = new KConfigSkeleton::ItemBool( currentGroup(), QStringLiteral( "ShowSupernovaNames" ), mShowSupernovaNames, true );
  itemShowSupernovaNames = new KConfigCompilerSignallingItem(innerItemShowSupernovaNames, this, notifyFunction, signalShowSupernovaNamesChanged);
  addItem( itemShowSupernovaNames, QStringLiteral( "ShowSupernovaNames" ) );
  KConfigCompilerSignallingItem  *itemMagnitudeLimitShowSupernovae;
  KConfigSkeleton::ItemDouble  *innerItemMagnitudeLimitShowSupernovae;
  innerItemMagnitudeLimitShowSupernovae = new KConfigSkeleton::ItemDouble( currentGroup(), QStringLiteral( "MagnitudeLimitShowSupernovae" ), mMagnitudeLimitShowSupernovae, 19 );
  itemMagnitudeLimitShowSupernovae = new KConfigCompilerSignallingItem(innerItemMagnitudeLimitShowSupernovae, this, notifyFunction, signalMagnitudeLimitShowSupernovaeChanged);
  addItem( itemMagnitudeLimitShowSupernovae, QStringLiteral( "MagnitudeLimitShowSupernovae" ) );
  KConfigCompilerSignallingItem  *itemSupernovaDetectionAge;
  KConfigSkeleton::ItemDouble  *innerItemSupernovaDetectionAge;
  innerItemSupernovaDetectionAge = new KConfigSkeleton::ItemDouble( currentGroup(), QStringLiteral( "SupernovaDetectionAge" ), mSupernovaDetectionAge, 60 );
  itemSupernovaDetectionAge = new KConfigCompilerSignallingItem(innerItemSupernovaDetectionAge, this, notifyFunction, signalSupernovaDetectionAgeChanged);
  addItem( itemSupernovaDetectionAge, QStringLiteral( "SupernovaDetectionAge" ) );
  KConfigCompilerSignallingItem  *itemSupernovaDownloadUrl;
  KConfigSkeleton::ItemString  *innerItemSupernovaDownloadUrl;
  innerItemSupernovaDownloadUrl = new KConfigSkeleton::ItemString( currentGroup(), QStringLiteral( "SupernovaDownloadUrl" ), mSupernovaDownloadUrl, QStringLiteral( "http://kstars.bluedynamics.net:8000/tns/files/tns-daily.csv" ) );
  itemSupernovaDownloadUrl = new KConfigCompilerSignallingItem(innerItemSupernovaDownloadUrl, this, notifyFunction, signalSupernovaDownloadUrlChanged);
  addItem( itemSupernovaDownloadUrl, QStringLiteral( "SupernovaDownloadUrl" ) );
  KConfigCompilerSignallingItem  *itemLimitSupernovaeByZoom;
  KConfigSkeleton::ItemBool  *innerItemLimitSupernovaeByZoom;
  innerItemLimitSupernovaeByZoom = new KConfigSkeleton::ItemBool( currentGroup(), QStringLiteral( "LimitSupernovaeByZoom" ), mLimitSupernovaeByZoom, false );
  itemLimitSupernovaeByZoom = new KConfigCompilerSignallingItem(innerItemLimitSupernovaeByZoom, this, notifyFunction, signalLimitSupernovaeByZoomChanged);
  addItem( itemLimitSupernovaeByZoom, QStringLiteral( "LimitSupernovaeByZoom" ) );
  KConfigCompilerSignallingItem  *itemSupernovaeHostOnly;
  KConfigSkeleton::ItemBool  *innerItemSupernovaeHostOnly;
  innerItemSupernovaeHostOnly = new KConfigSkeleton::ItemBool( currentGroup(), QStringLiteral( "SupernovaeHostOnly" ), mSupernovaeHostOnly, true );
  itemSupernovaeHostOnly = new KConfigCompilerSignallingItem(innerItemSupernovaeHostOnly, this, notifyFunction, signalSupernovaeHostOnlyChanged);
  addItem( itemSupernovaeHostOnly, QStringLiteral( "SupernovaeHostOnly" ) );
  KConfigCompilerSignallingItem  *itemSupernovaeClassifiedOnly;
  KConfigSkeleton::ItemBool  *innerItemSupernovaeClassifiedOnly;
  innerItemSupernovaeClassifiedOnly = new KConfigSkeleton::ItemBool( currentGroup(), QStringLiteral( "SupernovaeClassifiedOnly" ), mSupernovaeClassifiedOnly, true );
  itemSupernovaeClassifiedOnly = new KConfigCompilerSignallingItem(innerItemSupernovaeClassifiedOnly, this, notifyFunction, signalSupernovaeClassifiedOnlyChanged);
  addItem( itemSupernovaeClassifiedOnly, QStringLiteral( "SupernovaeClassifiedOnly" ) );
  KConfigCompilerSignallingItem  *itemShowSupernovaAlerts;
  KConfigSkeleton::ItemBool  *innerItemShowSupernovaAlerts;
  innerItemShowSupernovaAlerts = new KConfigSkeleton::ItemBool( currentGroup(), QStringLiteral( "ShowSupernovaAlerts" ), mShowSupernovaAlerts, true );
  itemShowSupernovaAlerts = new KConfigCompilerSignallingItem(innerItemShowSupernovaAlerts, this, notifyFunction, signalShowSupernovaAlertsChanged);
  addItem( itemShowSupernovaAlerts, QStringLiteral( "ShowSupernovaAlerts" ) );
  KConfigCompilerSignallingItem  *itemMagnitudeLimitAlertSupernovae;
  KConfigSkeleton::ItemDouble  *innerItemMagnitudeLimitAlertSupernovae;
  innerItemMagnitudeLimitAlertSupernovae = new KConfigSkeleton::ItemDouble( currentGroup(), QStringLiteral( "MagnitudeLimitAlertSupernovae" ), mMagnitudeLimitAlertSupernovae, 13 );
  itemMagnitudeLimitAlertSupernovae = new KConfigCompilerSignallingItem(innerItemMagnitudeLimitAlertSupernovae, this, notifyFunction, signalMagnitudeLimitAlertSupernovaeChanged);
  addItem( itemMagnitudeLimitAlertSupernovae, QStringLiteral( "MagnitudeLimitAlertSupernovae" ) );
  KConfigCompilerSignallingItem  *itemShowCBounds;
  KConfigSkeleton::ItemBool  *innerItemShowCBounds;
  innerItemShowCBounds = new KConfigSkeleton::ItemBool( currentGroup(), QStringLiteral( "ShowCBounds" ), mShowCBounds, false );
  itemShowCBounds = new KConfigCompilerSignallingItem(innerItemShowCBounds, this, notifyFunction, signalShowCBoundsChanged);
  addItem( itemShowCBounds, QStringLiteral( "ShowCBounds" ) );
  KConfigCompilerSignallingItem  *itemShowHighlightedCBound;
  KConfigSkeleton::ItemBool  *innerItemShowHighlightedCBound;
  innerItemShowHighlightedCBound = new KConfigSkeleton::ItemBool( currentGroup(), QStringLiteral( "ShowHighlightedCBound" ), mShowHighlightedCBound, false );
  itemShowHighlightedCBound = new KConfigCompilerSignallingItem(innerItemShowHighlightedCBound, this, notifyFunction, signalShowHighlightedCBoundChanged);
  addItem( itemShowHighlightedCBound, QStringLiteral( "ShowHighlightedCBound" ) );
  KConfigCompilerSignallingItem  *itemShowCLines;
  KConfigSkeleton::ItemBool  *innerItemShowCLines;
  innerItemShowCLines = new KConfigSkeleton::ItemBool( currentGroup(), QStringLiteral( "ShowCLines" ), mShowCLines, false );
  itemShowCLines = new KConfigCompilerSignallingItem(innerItemShowCLines, this, notifyFunction, signalShowCLinesChanged);
  addItem( itemShowCLines, QStringLiteral( "ShowCLines" ) );
  KConfigCompilerSignallingItem  *itemShowConstellationArt;
  KConfigSkeleton::ItemBool  *innerItemShowConstellationArt;
  innerItemShowConstellationArt = new KConfigSkeleton::ItemBool( currentGroup(), QStringLiteral( "ShowConstellationArt" ), mShowConstellationArt, false );
  itemShowConstellationArt = new KConfigCompilerSignallingItem(innerItemShowConstellationArt, this, notifyFunction, signalShowConstellationArtChanged);
  addItem( itemShowConstellationArt, QStringLiteral( "ShowConstellationArt" ) );
  KConfigCompilerSignallingItem  *itemShowCNames;
  KConfigSkeleton::ItemBool  *innerItemShowCNames;
  innerItemShowCNames = new KConfigSkeleton::ItemBool( currentGroup(), QStringLiteral( "ShowCNames" ), mShowCNames, false );
  itemShowCNames = new KConfigCompilerSignallingItem(innerItemShowCNames, this, notifyFunction, signalShowCNamesChanged);
  addItem( itemShowCNames, QStringLiteral( "ShowCNames" ) );
  KConfigCompilerSignallingItem  *itemShowDeepSky;
  KConfigSkeleton::ItemBool  *innerItemShowDeepSky;
  innerItemShowDeepSky = new KConfigSkeleton::ItemBool( currentGroup(), QStringLiteral( "ShowDeepSky" ), mShowDeepSky, true );
  itemShowDeepSky = new KConfigCompilerSignallingItem(innerItemShowDeepSky, this, notifyFunction, signalShowDeepSkyChanged);
  addItem( itemShowDeepSky, QStringLiteral( "ShowDeepSky" ) );
  KConfigCompilerSignallingItem  *itemShowEcliptic;
  KConfigSkeleton::ItemBool  *innerItemShowEcliptic;
  innerItemShowEcliptic = new KConfigSkeleton::ItemBool( currentGroup(), QStringLiteral( "ShowEcliptic" ), mShowEcliptic, false );
  itemShowEcliptic = new KConfigCompilerSignallingItem(innerItemShowEcliptic, this, notifyFunction, signalShowEclipticChanged);
  addItem( itemShowEcliptic, QStringLiteral( "ShowEcliptic" ) );
  KConfigCompilerSignallingItem  *itemShowEquator;
  KConfigSkeleton::ItemBool  *innerItemShowEquator;
  innerItemShowEquator = new KConfigSkeleton::ItemBool( currentGroup(), QStringLiteral( "ShowEquator" ), mShowEquator, false );
  itemShowEquator = new KConfigCompilerSignallingItem(innerItemShowEquator, this, notifyFunction, signalShowEquatorChanged);
  addItem( itemShowEquator, QStringLiteral( "ShowEquator" ) );
  KConfigCompilerSignallingItem  *itemAutoSelectGrid;
  KConfigSkeleton::ItemBool  *innerItemAutoSelectGrid;
  innerItemAutoSelectGrid = new KConfigSkeleton::ItemBool( currentGroup(), QStringLiteral( "AutoSelectGrid" ), mAutoSelectGrid, true );
  itemAutoSelectGrid = new KConfigCompilerSignallingItem(innerItemAutoSelectGrid, this, notifyFunction, signalAutoSelectGridChanged);
  addItem( itemAutoSelectGrid, QStringLiteral( "AutoSelectGrid" ) );
  KConfigCompilerSignallingItem  *itemShowEquatorialGrid;
  KConfigSkeleton::ItemBool  *innerItemShowEquatorialGrid;
  innerItemShowEquatorialGrid = new KConfigSkeleton::ItemBool( currentGroup(), QStringLiteral( "ShowEquatorialGrid" ), mShowEquatorialGrid, false );
  itemShowEquatorialGrid = new KConfigCompilerSignallingItem(innerItemShowEquatorialGrid, this, notifyFunction, signalShowEquatorialGridChanged);
  addItem( itemShowEquatorialGrid, QStringLiteral( "ShowEquatorialGrid" ) );
  KConfigCompilerSignallingItem  *itemShowHorizontalGrid;
  KConfigSkeleton::ItemBool  *innerItemShowHorizontalGrid;
  innerItemShowHorizontalGrid = new KConfigSkeleton::ItemBool( currentGroup(), QStringLiteral( "ShowHorizontalGrid" ), mShowHorizontalGrid, false );
  itemShowHorizontalGrid = new KConfigCompilerSignallingItem(innerItemShowHorizontalGrid, this, notifyFunction, signalShowHorizontalGridChanged);
  addItem( itemShowHorizontalGrid, QStringLiteral( "ShowHorizontalGrid" ) );
  KConfigCompilerSignallingItem  *itemShowLocalMeridian;
  KConfigSkeleton::ItemBool  *innerItemShowLocalMeridian;
  innerItemShowLocalMeridian = new KConfigSkeleton::ItemBool( currentGroup(), QStringLiteral( "ShowLocalMeridian" ), mShowLocalMeridian, false );
  itemShowLocalMeridian = new KConfigCompilerSignallingItem(innerItemShowLocalMeridian, this, notifyFunction, signalShowLocalMeridianChanged);
  addItem( itemShowLocalMeridian, QStringLiteral( "ShowLocalMeridian" ) );
  KConfigCompilerSignallingItem  *itemShowGround;
  KConfigSkeleton::ItemBool  *innerItemShowGround;
  innerItemShowGround = new KConfigSkeleton::ItemBool( currentGroup(), QStringLiteral( "ShowGround" ), mShowGround, true );
  itemShowGround = new KConfigCompilerSignallingItem(innerItemShowGround, this, notifyFunction, signalShowGroundChanged);
  addItem( itemShowGround, QStringLiteral( "ShowGround" ) );
  KConfigCompilerSignallingItem  *itemShowHorizon;
  KConfigSkeleton::ItemBool  *innerItemShowHorizon;
  innerItemShowHorizon = new KConfigSkeleton::ItemBool( currentGroup(), QStringLiteral( "ShowHorizon" ), mShowHorizon, true );
  itemShowHorizon = new KConfigCompilerSignallingItem(innerItemShowHorizon, this, notifyFunction, signalShowHorizonChanged);
  addItem( itemShowHorizon, QStringLiteral( "ShowHorizon" ) );
  KConfigCompilerSignallingItem  *itemShowFlags;
  KConfigSkeleton::ItemBool  *innerItemShowFlags;
  innerItemShowFlags = new KConfigSkeleton::ItemBool( currentGroup(), QStringLiteral( "ShowFlags" ), mShowFlags, true );
  itemShowFlags = new KConfigCompilerSignallingItem(innerItemShowFlags, this, notifyFunction, signalShowFlagsChanged);
  addItem( itemShowFlags, QStringLiteral( "ShowFlags" ) );
  KConfigCompilerSignallingItem  *itemSimulateDaytime;
  KConfigSkeleton::ItemBool  *innerItemSimulateDaytime;
  innerItemSimulateDaytime = new KConfigSkeleton::ItemBool( currentGroup(), QStringLiteral( "SimulateDaytime" ), mSimulateDaytime, true );
  itemSimulateDaytime = new KConfigCompilerSignallingItem(innerItemSimulateDaytime, this, notifyFunction, signalSimulateDaytimeChanged);
  addItem( itemSimulateDaytime, QStringLiteral( "SimulateDaytime" ) );
  KConfigCompilerSignallingItem  *itemShowOther;
  KConfigSkeleton::ItemBool  *innerItemShowOther;
  innerItemShowOther = new KConfigSkeleton::ItemBool( currentGroup(), QStringLiteral( "ShowOther" ), mShowOther, true );
  itemShowOther = new KConfigCompilerSignallingItem(innerItemShowOther, this, notifyFunction, signalShowOtherChanged);
  addItem( itemShowOther, QStringLiteral( "ShowOther" ) );
  KConfigCompilerSignallingItem  *itemShowMilkyWay;
  KConfigSkeleton::ItemBool  *innerItemShowMilkyWay;
  innerItemShowMilkyWay = new KConfigSkeleton::ItemBool( currentGroup(), QStringLiteral( "ShowMilkyWay" ), mShowMilkyWay, true );
  itemShowMilkyWay = new KConfigCompilerSignallingItem(innerItemShowMilkyWay, this, notifyFunction, signalShowMilkyWayChanged);
  addItem( itemShowMilkyWay, QStringLiteral( "ShowMilkyWay" ) );
  KConfigCompilerSignallingItem  *itemFillMilkyWay;
  KConfigSkeleton::ItemBool  *innerItemFillMilkyWay;
  innerItemFillMilkyWay = new KConfigSkeleton::ItemBool( currentGroup(), QStringLiteral( "FillMilkyWay" ), mFillMilkyWay, true );
  itemFillMilkyWay = new KConfigCompilerSignallingItem(innerItemFillMilkyWay, this, notifyFunction, signalFillMilkyWayChanged);
  addItem( itemFillMilkyWay, QStringLiteral( "FillMilkyWay" ) );
  KConfigCompilerSignallingItem  *itemShowSolarSystem;
  KConfigSkeleton::ItemBool  *innerItemShowSolarSystem;
  innerItemShowSolarSystem = new KConfigSkeleton::ItemBool( currentGroup(), QStringLiteral( "ShowSolarSystem" ), mShowSolarSystem, true );
  itemShowSolarSystem = new KConfigCompilerSignallingItem(innerItemShowSolarSystem, this, notifyFunction, signalShowSolarSystemChanged);
  addItem( itemShowSolarSystem, QStringLiteral( "ShowSolarSystem" ) );
  KConfigCompilerSignallingItem  *itemShowPlanetImages;
  KConfigSkeleton::ItemBool  *innerItemShowPlanetImages;
  innerItemShowPlanetImages = new KConfigSkeleton::ItemBool( currentGroup(), QStringLiteral( "ShowPlanetImages" ), mShowPlanetImages, true );
  itemShowPlanetImages = new KConfigCompilerSignallingItem(innerItemShowPlanetImages, this, notifyFunction, signalShowPlanetImagesChanged);
  addItem( itemShowPlanetImages, QStringLiteral( "ShowPlanetImages" ) );
  KConfigCompilerSignallingItem  *itemShowPlanetNames;
  KConfigSkeleton::ItemBool  *innerItemShowPlanetNames;
  innerItemShowPlanetNames = new KConfigSkeleton::ItemBool( currentGroup(), QStringLiteral( "ShowPlanetNames" ), mShowPlanetNames, true );
  itemShowPlanetNames = new KConfigCompilerSignallingItem(innerItemShowPlanetNames, this, notifyFunction, signalShowPlanetNamesChanged);
  addItem( itemShowPlanetNames, QStringLiteral( "ShowPlanetNames" ) );
  KConfigCompilerSignallingItem  *itemShowSun;
  KConfigSkeleton::ItemBool  *innerItemShowSun;
  innerItemShowSun = new KConfigSkeleton::ItemBool( currentGroup(), QStringLiteral( "ShowSun" ), mShowSun, true );
  itemShowSun = new KConfigCompilerSignallingItem(innerItemShowSun, this, notifyFunction, signalShowSunChanged);
  addItem( itemShowSun, QStringLiteral( "ShowSun" ) );
  KConfigCompilerSignallingItem  *itemSunScale;
  KConfigSkeleton::ItemDouble  *innerItemSunScale;
  innerItemSunScale = new KConfigSkeleton::ItemDouble( currentGroup(), QStringLiteral( "SunScale" ), mSunScale, 1.0 );
  itemSunScale = new KConfigCompilerSignallingItem(innerItemSunScale, this, notifyFunction, signalSunScaleChanged);
  addItem( itemSunScale, QStringLiteral( "SunScale" ) );
  KConfigCompilerSignallingItem  *itemShowMoon;
  KConfigSkeleton::ItemBool  *innerItemShowMoon;
  innerItemShowMoon = new KConfigSkeleton::ItemBool( currentGroup(), QStringLiteral( "ShowMoon" ), mShowMoon, true );
  itemShowMoon = new KConfigCompilerSignallingItem(innerItemShowMoon, this, notifyFunction, signalShowMoonChanged);
  addItem( itemShowMoon, QStringLiteral( "ShowMoon" ) );
  KConfigCompilerSignallingItem  *itemMoonScale;
  KConfigSkeleton::ItemDouble  *innerItemMoonScale;
  innerItemMoonScale = new KConfigSkeleton::ItemDouble( currentGroup(), QStringLiteral( "MoonScale" ), mMoonScale, 1.0 );
  itemMoonScale = new KConfigCompilerSignallingItem(innerItemMoonScale, this, notifyFunction, signalMoonScaleChanged);
  addItem( itemMoonScale, QStringLiteral( "MoonScale" ) );
  KConfigCompilerSignallingItem  *itemShowMercury;
  KConfigSkeleton::ItemBool  *innerItemShowMercury;
  innerItemShowMercury = new KConfigSkeleton::ItemBool( currentGroup(), QStringLiteral( "ShowMercury" ), mShowMercury, true );
  itemShowMercury = new KConfigCompilerSignallingItem(innerItemShowMercury, this, notifyFunction, signalShowMercuryChanged);
  addItem( itemShowMercury, QStringLiteral( "ShowMercury" ) );
  KConfigCompilerSignallingItem  *itemShowVenus;
  KConfigSkeleton::ItemBool  *innerItemShowVenus;
  innerItemShowVenus = new KConfigSkeleton::ItemBool( currentGroup(), QStringLiteral( "ShowVenus" ), mShowVenus, true );
  itemShowVenus = new KConfigCompilerSignallingItem(innerItemShowVenus, this, notifyFunction, signalShowVenusChanged);
  addItem( itemShowVenus, QStringLiteral( "ShowVenus" ) );
  KConfigCompilerSignallingItem  *itemShowMars;
  KConfigSkeleton::ItemBool  *innerItemShowMars;
  innerItemShowMars = new KConfigSkeleton::ItemBool( currentGroup(), QStringLiteral( "ShowMars" ), mShowMars, true );
  itemShowMars = new KConfigCompilerSignallingItem(innerItemShowMars, this, notifyFunction, signalShowMarsChanged);
  addItem( itemShowMars, QStringLiteral( "ShowMars" ) );
  KConfigCompilerSignallingItem  *itemShowJupiter;
  KConfigSkeleton::ItemBool  *innerItemShowJupiter;
  innerItemShowJupiter = new KConfigSkeleton::ItemBool( currentGroup(), QStringLiteral( "ShowJupiter" ), mShowJupiter, true );
  itemShowJupiter = new KConfigCompilerSignallingItem(innerItemShowJupiter, this, notifyFunction, signalShowJupiterChanged);
  addItem( itemShowJupiter, QStringLiteral( "ShowJupiter" ) );
  KConfigCompilerSignallingItem  *itemShowSaturn;
  KConfigSkeleton::ItemBool  *innerItemShowSaturn;
  innerItemShowSaturn = new KConfigSkeleton::ItemBool( currentGroup(), QStringLiteral( "ShowSaturn" ), mShowSaturn, true );
  itemShowSaturn = new KConfigCompilerSignallingItem(innerItemShowSaturn, this, notifyFunction, signalShowSaturnChanged);
  addItem( itemShowSaturn, QStringLiteral( "ShowSaturn" ) );
  KConfigCompilerSignallingItem  *itemShowUranus;
  KConfigSkeleton::ItemBool  *innerItemShowUranus;
  innerItemShowUranus = new KConfigSkeleton::ItemBool( currentGroup(), QStringLiteral( "ShowUranus" ), mShowUranus, true );
  itemShowUranus = new KConfigCompilerSignallingItem(innerItemShowUranus, this, notifyFunction, signalShowUranusChanged);
  addItem( itemShowUranus, QStringLiteral( "ShowUranus" ) );
  KConfigCompilerSignallingItem  *itemShowNeptune;
  KConfigSkeleton::ItemBool  *innerItemShowNeptune;
  innerItemShowNeptune = new KConfigSkeleton::ItemBool( currentGroup(), QStringLiteral( "ShowNeptune" ), mShowNeptune, true );
  itemShowNeptune = new KConfigCompilerSignallingItem(innerItemShowNeptune, this, notifyFunction, signalShowNeptuneChanged);
  addItem( itemShowNeptune, QStringLiteral( "ShowNeptune" ) );
  KConfigCompilerSignallingItem  *itemShowPluto;
  KConfigSkeleton::ItemBool  *innerItemShowPluto;
  innerItemShowPluto = new KConfigSkeleton::ItemBool( currentGroup(), QStringLiteral( "ShowPluto" ), mShowPluto, true );
  itemShowPluto = new KConfigCompilerSignallingItem(innerItemShowPluto, this, notifyFunction, signalShowPlutoChanged);
  addItem( itemShowPluto, QStringLiteral( "ShowPluto" ) );
  KConfigCompilerSignallingItem  *itemShowStars;
  KConfigSkeleton::ItemBool  *innerItemShowStars;
  innerItemShowStars = new KConfigSkeleton::ItemBool( currentGroup(), QStringLiteral( "ShowStars" ), mShowStars, true );
  itemShowStars = new KConfigCompilerSignallingItem(innerItemShowStars, this, notifyFunction, signalShowStarsChanged);
  addItem( itemShowStars, QStringLiteral( "ShowStars" ) );
  KConfigCompilerSignallingItem  *itemShowStarMagnitudes;
  KConfigSkeleton::ItemBool  *innerItemShowStarMagnitudes;
  innerItemShowStarMagnitudes = new KConfigSkeleton::ItemBool( currentGroup(), QStringLiteral( "ShowStarMagnitudes" ), mShowStarMagnitudes, false );
  itemShowStarMagnitudes = new KConfigCompilerSignallingItem(innerItemShowStarMagnitudes, this, notifyFunction, signalShowStarMagnitudesChanged);
  addItem( itemShowStarMagnitudes, QStringLiteral( "ShowStarMagnitudes" ) );
  KConfigCompilerSignallingItem  *itemShowStarsOverHIPS;
  KConfigSkeleton::ItemBool  *innerItemShowStarsOverHIPS;
  innerItemShowStarsOverHIPS = new KConfigSkeleton::ItemBool( currentGroup(), QStringLiteral( "ShowStarsOverHIPS" ), mShowStarsOverHIPS, true );
  itemShowStarsOverHIPS = new KConfigCompilerSignallingItem(innerItemShowStarsOverHIPS, this, notifyFunction, signalShowStarsOverHIPSChanged);
  addItem( itemShowStarsOverHIPS, QStringLiteral( "ShowStarsOverHIPS" ) );
  KConfigCompilerSignallingItem  *itemShowStarNames;
  KConfigSkeleton::ItemBool  *innerItemShowStarNames;
  innerItemShowStarNames = new KConfigSkeleton::ItemBool( currentGroup(), QStringLiteral( "ShowStarNames" ), mShowStarNames, true );
  itemShowStarNames = new KConfigCompilerSignallingItem(innerItemShowStarNames, this, notifyFunction, signalShowStarNamesChanged);
  addItem( itemShowStarNames, QStringLiteral( "ShowStarNames" ) );
  KConfigCompilerSignallingItem  *itemShowDeepSkyMagnitudes;
  KConfigSkeleton::ItemBool  *innerItemShowDeepSkyMagnitudes;
  innerItemShowDeepSkyMagnitudes = new KConfigSkeleton::ItemBool( currentGroup(), QStringLiteral( "ShowDeepSkyMagnitudes" ), mShowDeepSkyMagnitudes, false );
  itemShowDeepSkyMagnitudes = new KConfigCompilerSignallingItem(innerItemShowDeepSkyMagnitudes, this, notifyFunction, signalShowDeepSkyMagnitudesChanged);
  addItem( itemShowDeepSkyMagnitudes, QStringLiteral( "ShowDeepSkyMagnitudes" ) );
  KConfigCompilerSignallingItem  *itemShowDeepSkyNames;
  KConfigSkeleton::ItemBool  *innerItemShowDeepSkyNames;
  innerItemShowDeepSkyNames = new KConfigSkeleton::ItemBool( currentGroup(), QStringLiteral( "ShowDeepSkyNames" ), mShowDeepSkyNames, true );
  itemShowDeepSkyNames = new KConfigCompilerSignallingItem(innerItemShowDeepSkyNames, this, notifyFunction, signalShowDeepSkyNamesChanged);
  addItem( itemShowDeepSkyNames, QStringLiteral( "ShowDeepSkyNames" ) );
  KConfigCompilerSignallingItem  *itemShowMosaicPanel;
  KConfigSkeleton::ItemBool  *innerItemShowMosaicPanel;
  innerItemShowMosaicPanel = new KConfigSkeleton::ItemBool( currentGroup(), QStringLiteral( "ShowMosaicPanel" ), mShowMosaicPanel, false );
  itemShowMosaicPanel = new KConfigCompilerSignallingItem(innerItemShowMosaicPanel, this, notifyFunction, signalShowMosaicPanelChanged);
  addItem( itemShowMosaicPanel, QStringLiteral( "ShowMosaicPanel" ) );
  KConfigCompilerSignallingItem  *itemSlewTimeScale;
  KConfigSkeleton::ItemDouble  *innerItemSlewTimeScale;
  innerItemSlewTimeScale = new KConfigSkeleton::ItemDouble( currentGroup(), QStringLiteral( "SlewTimeScale" ), mSlewTimeScale, 60 );
  itemSlewTimeScale = new KConfigCompilerSignallingItem(innerItemSlewTimeScale, this, notifyFunction, signalSlewTimeScaleChanged);
  addItem( itemSlewTimeScale, QStringLiteral( "SlewTimeScale" ) );
  KConfigCompilerSignallingItem  *itemBoxBGMode;
  KConfigSkeleton::ItemUInt  *innerItemBoxBGMode;
  innerItemBoxBGMode = new KConfigSkeleton::ItemUInt( currentGroup(), QStringLiteral( "BoxBGMode" ), mBoxBGMode, 1 );
  itemBoxBGMode = new KConfigCompilerSignallingItem(innerItemBoxBGMode, this, notifyFunction, signalBoxBGModeChanged);
  addItem( itemBoxBGMode, QStringLiteral( "BoxBGMode" ) );
  KConfigCompilerSignallingItem  *itemProjection;
  KConfigSkeleton::ItemUInt  *innerItemProjection;
  innerItemProjection = new KConfigSkeleton::ItemUInt( currentGroup(), QStringLiteral( "Projection" ), mProjection, 0 );
  itemProjection = new KConfigCompilerSignallingItem(innerItemProjection, this, notifyFunction, signalProjectionChanged);
  addItem( itemProjection, QStringLiteral( "Projection" ) );
  KConfigCompilerSignallingItem  *itemUseAbbrevConstellNames;
  KConfigSkeleton::ItemBool  *innerItemUseAbbrevConstellNames;
  innerItemUseAbbrevConstellNames = new KConfigSkeleton::ItemBool( currentGroup(), QStringLiteral( "UseAbbrevConstellNames" ), mUseAbbrevConstellNames, false );
  itemUseAbbrevConstellNames = new KConfigCompilerSignallingItem(innerItemUseAbbrevConstellNames, this, notifyFunction, signalUseAbbrevConstellNamesChanged);
  addItem( itemUseAbbrevConstellNames, QStringLiteral( "UseAbbrevConstellNames" ) );
  KConfigCompilerSignallingItem  *itemUseLatinConstellNames;
  KConfigSkeleton::ItemBool  *innerItemUseLatinConstellNames;
  innerItemUseLatinConstellNames = new KConfigSkeleton::ItemBool( currentGroup(), QStringLiteral( "UseLatinConstellNames" ), mUseLatinConstellNames, false );
  itemUseLatinConstellNames = new KConfigCompilerSignallingItem(innerItemUseLatinConstellNames, this, notifyFunction, signalUseLatinConstellNamesChanged);
  addItem( itemUseLatinConstellNames, QStringLiteral( "UseLatinConstellNames" ) );
  KConfigCompilerSignallingItem  *itemUseLocalConstellNames;
  KConfigSkeleton::ItemBool  *innerItemUseLocalConstellNames;
  innerItemUseLocalConstellNames = new KConfigSkeleton::ItemBool( currentGroup(), QStringLiteral( "UseLocalConstellNames" ), mUseLocalConstellNames, true );
  itemUseLocalConstellNames = new KConfigCompilerSignallingItem(innerItemUseLocalConstellNames, this, notifyFunction, signalUseLocalConstellNamesChanged);
  addItem( itemUseLocalConstellNames, QStringLiteral( "UseLocalConstellNames" ) );
  KConfigCompilerSignallingItem  *itemUseAltAz;
  KConfigSkeleton::ItemBool  *innerItemUseAltAz;
  innerItemUseAltAz = new KConfigSkeleton::ItemBool( currentGroup(), QStringLiteral( "UseAltAz" ), mUseAltAz, true );
  itemUseAltAz = new KConfigCompilerSignallingItem(innerItemUseAltAz, this, notifyFunction, signalUseAltAzChanged);
  addItem( itemUseAltAz, QStringLiteral( "UseAltAz" ) );
  KConfigCompilerSignallingItem  *itemUseAutoLabel;
  KConfigSkeleton::ItemBool  *innerItemUseAutoLabel;
  innerItemUseAutoLabel = new KConfigSkeleton::ItemBool( currentGroup(), QStringLiteral( "UseAutoLabel" ), mUseAutoLabel, true );
  itemUseAutoLabel = new KConfigCompilerSignallingItem(innerItemUseAutoLabel, this, notifyFunction, signalUseAutoLabelChanged);
  addItem( itemUseAutoLabel, QStringLiteral( "UseAutoLabel" ) );
  KConfigCompilerSignallingItem  *itemUseAutoTrail;
  KConfigSkeleton::ItemBool  *innerItemUseAutoTrail;
  innerItemUseAutoTrail = new KConfigSkeleton::ItemBool( currentGroup(), QStringLiteral( "UseAutoTrail" ), mUseAutoTrail, true );
  itemUseAutoTrail = new KConfigCompilerSignallingItem(innerItemUseAutoTrail, this, notifyFunction, signalUseAutoTrailChanged);
  addItem( itemUseAutoTrail, QStringLiteral( "UseAutoTrail" ) );
  KConfigCompilerSignallingItem  *itemUseHoverLabel;
  KConfigSkeleton::ItemBool  *innerItemUseHoverLabel;
  innerItemUseHoverLabel = new KConfigSkeleton::ItemBool( currentGroup(), QStringLiteral( "UseHoverLabel" ), mUseHoverLabel, true );
  itemUseHoverLabel = new KConfigCompilerSignallingItem(innerItemUseHoverLabel, this, notifyFunction, signalUseHoverLabelChanged);
  addItem( itemUseHoverLabel, QStringLiteral( "UseHoverLabel" ) );
  KConfigCompilerSignallingItem  *itemUseRefraction;
  KConfigSkeleton::ItemBool  *innerItemUseRefraction;
  innerItemUseRefraction = new KConfigSkeleton::ItemBool( currentGroup(), QStringLiteral( "UseRefraction" ), mUseRefraction, true );
  itemUseRefraction = new KConfigCompilerSignallingItem(innerItemUseRefraction, this, notifyFunction, signalUseRefractionChanged);
  addItem( itemUseRefraction, QStringLiteral( "UseRefraction" ) );
  KConfigCompilerSignallingItem  *itemUseRelativistic;
  KConfigSkeleton::ItemBool  *innerItemUseRelativistic;
  innerItemUseRelativistic = new KConfigSkeleton::ItemBool( currentGroup(), QStringLiteral( "UseRelativistic" ), mUseRelativistic, false );
  itemUseRelativistic = new KConfigCompilerSignallingItem(innerItemUseRelativistic, this, notifyFunction, signalUseRelativisticChanged);
  addItem( itemUseRelativistic, QStringLiteral( "UseRelativistic" ) );
  KConfigCompilerSignallingItem  *itemUseAntialias;
  KConfigSkeleton::ItemBool  *innerItemUseAntialias;
  innerItemUseAntialias = new KConfigSkeleton::ItemBool( currentGroup(), QStringLiteral( "UseAntialias" ), mUseAntialias, true );
  itemUseAntialias = new KConfigCompilerSignallingItem(innerItemUseAntialias, this, notifyFunction, signalUseAntialiasChanged);
  addItem( itemUseAntialias, QStringLiteral( "UseAntialias" ) );
  KConfigCompilerSignallingItem  *itemZoomFactor;
  KConfigSkeleton::ItemDouble  *innerItemZoomFactor;
  innerItemZoomFactor = new KConfigSkeleton::ItemDouble( currentGroup(), QStringLiteral( "ZoomFactor" ), mZoomFactor, 250. );
  itemZoomFactor = new KConfigCompilerSignallingItem(innerItemZoomFactor, this, notifyFunction, signalZoomFactorChanged);
  innerItemZoomFactor->setMinValue(250.);
  innerItemZoomFactor->setMaxValue(5000000.);
  addItem( itemZoomFactor, QStringLiteral( "ZoomFactor" ) );
  KConfigCompilerSignallingItem  *itemSkyRotation;
  KConfigSkeleton::ItemDouble  *innerItemSkyRotation;
  innerItemSkyRotation = new KConfigSkeleton::ItemDouble( currentGroup(), QStringLiteral( "SkyRotation" ), mSkyRotation, 0. );
  itemSkyRotation = new KConfigCompilerSignallingItem(innerItemSkyRotation, this, notifyFunction, signalSkyRotationChanged);
  innerItemSkyRotation->setMinValue(0.);
  innerItemSkyRotation->setMaxValue(359.9999);
  addItem( itemSkyRotation, QStringLiteral( "SkyRotation" ) );
  KConfigCompilerSignallingItem  *itemMirrorSkyMap;
  KConfigSkeleton::ItemBool  *innerItemMirrorSkyMap;
  innerItemMirrorSkyMap = new KConfigSkeleton::ItemBool( currentGroup(), QStringLiteral( "MirrorSkyMap" ), mMirrorSkyMap, false );
  itemMirrorSkyMap = new KConfigCompilerSignallingItem(innerItemMirrorSkyMap, this, notifyFunction, signalMirrorSkyMapChanged);
  addItem( itemMirrorSkyMap, QStringLiteral( "MirrorSkyMap" ) );
  QList<KConfigSkeleton::ItemEnum::Choice> valuesErectObserverCorrection;
  {
    KConfigSkeleton::ItemEnum::Choice choice;
    choice.name = QStringLiteral("Off");
    valuesErectObserverCorrection.append( choice );
  }
  {
    KConfigSkeleton::ItemEnum::Choice choice;
    choice.name = QStringLiteral("Left");
    valuesErectObserverCorrection.append( choice );
  }
  {
    KConfigSkeleton::ItemEnum::Choice choice;
    choice.name = QStringLiteral("Right");
    valuesErectObserverCorrection.append( choice );
  }
  KConfigCompilerSignallingItem  *itemErectObserverCorrection;
  KConfigSkeleton::ItemEnum  *innerItemErectObserverCorrection;
  innerItemErectObserverCorrection = new KConfigSkeleton::ItemEnum( currentGroup(), QStringLiteral( "ErectObserverCorrection" ), mErectObserverCorrection, valuesErectObserverCorrection, 0 );
  itemErectObserverCorrection = new KConfigCompilerSignallingItem(innerItemErectObserverCorrection, this, notifyFunction, signalErectObserverCorrectionChanged);
  addItem( itemErectObserverCorrection, QStringLiteral( "ErectObserverCorrection" ) );
  KConfigCompilerSignallingItem  *itemZoomScrollFactor;
  KConfigSkeleton::ItemDouble  *innerItemZoomScrollFactor;
  innerItemZoomScrollFactor = new KConfigSkeleton::ItemDouble( currentGroup(), QStringLiteral( "ZoomScrollFactor" ), mZoomScrollFactor, 0.2 );
  itemZoomScrollFactor = new KConfigCompilerSignallingItem(innerItemZoomScrollFactor, this, notifyFunction, signalZoomScrollFactorChanged);
  innerItemZoomScrollFactor->setMinValue(0.01);
  innerItemZoomScrollFactor->setMaxValue(1.0);
  addItem( itemZoomScrollFactor, QStringLiteral( "ZoomScrollFactor" ) );
  KConfigCompilerSignallingItem  *itemMagLimitAsteroid;
  KConfigSkeleton::ItemDouble  *innerItemMagLimitAsteroid;
  innerItemMagLimitAsteroid = new KConfigSkeleton::ItemDouble( currentGroup(), QStringLiteral( "MagLimitAsteroid" ), mMagLimitAsteroid, 15.0 );
  itemMagLimitAsteroid = new KConfigCompilerSignallingItem(innerItemMagLimitAsteroid, this, notifyFunction, signalMagLimitAsteroidChanged);
  addItem( itemMagLimitAsteroid, QStringLiteral( "MagLimitAsteroid" ) );
  KConfigCompilerSignallingItem  *itemMagLimitAsteroidDownload;
  KConfigSkeleton::ItemDouble  *innerItemMagLimitAsteroidDownload;
  innerItemMagLimitAsteroidDownload = new KConfigSkeleton::ItemDouble( currentGroup(), QStringLiteral( "MagLimitAsteroidDownload" ), mMagLimitAsteroidDownload, 12.000 );
  itemMagLimitAsteroidDownload = new KConfigCompilerSignallingItem(innerItemMagLimitAsteroidDownload, this, notifyFunction, signalMagLimitAsteroidDownloadChanged);
  addItem( itemMagLimitAsteroidDownload, QStringLiteral( "MagLimitAsteroidDownload" ) );
  KConfigCompilerSignallingItem  *itemAsteroidLabelDensity;
  KConfigSkeleton::ItemDouble  *innerItemAsteroidLabelDensity;
  innerItemAsteroidLabelDensity = new KConfigSkeleton::ItemDouble( currentGroup(), QStringLiteral( "AsteroidLabelDensity" ), mAsteroidLabelDensity, 4.0 );
  itemAsteroidLabelDensity = new KConfigCompilerSignallingItem(innerItemAsteroidLabelDensity, this, notifyFunction, signalAsteroidLabelDensityChanged);
  addItem( itemAsteroidLabelDensity, QStringLiteral( "AsteroidLabelDensity" ) );
  KConfigCompilerSignallingItem  *itemMagLimitDrawDeepSky;
  KConfigSkeleton::ItemDouble  *innerItemMagLimitDrawDeepSky;
  innerItemMagLimitDrawDeepSky = new KConfigSkeleton::ItemDouble( currentGroup(), QStringLiteral( "MagLimitDrawDeepSky" ), mMagLimitDrawDeepSky, 36.0 );
  itemMagLimitDrawDeepSky = new KConfigCompilerSignallingItem(innerItemMagLimitDrawDeepSky, this, notifyFunction, signalMagLimitDrawDeepSkyChanged);
  addItem( itemMagLimitDrawDeepSky, QStringLiteral( "MagLimitDrawDeepSky" ) );
  KConfigCompilerSignallingItem  *itemMagLimitDrawDeepSkyZoomOut;
  KConfigSkeleton::ItemDouble  *innerItemMagLimitDrawDeepSkyZoomOut;
  innerItemMagLimitDrawDeepSkyZoomOut = new KConfigSkeleton::ItemDouble( currentGroup(), QStringLiteral( "MagLimitDrawDeepSkyZoomOut" ), mMagLimitDrawDeepSkyZoomOut, 1.0 );
  itemMagLimitDrawDeepSkyZoomOut = new KConfigCompilerSignallingItem(innerItemMagLimitDrawDeepSkyZoomOut, this, notifyFunction, signalMagLimitDrawDeepSkyZoomOutChanged);
  addItem( itemMagLimitDrawDeepSkyZoomOut, QStringLiteral( "MagLimitDrawDeepSkyZoomOut" ) );
  KConfigCompilerSignallingItem  *itemShowUnknownMagObjects;
  KConfigSkeleton::ItemBool  *innerItemShowUnknownMagObjects;
  innerItemShowUnknownMagObjects = new KConfigSkeleton::ItemBool( currentGroup(), QStringLiteral( "ShowUnknownMagObjects" ), mShowUnknownMagObjects, true );
  itemShowUnknownMagObjects = new KConfigCompilerSignallingItem(innerItemShowUnknownMagObjects, this, notifyFunction, signalShowUnknownMagObjectsChanged);
  addItem( itemShowUnknownMagObjects, QStringLiteral( "ShowUnknownMagObjects" ) );
  KConfigCompilerSignallingItem  *itemShowInlineImages;
  KConfigSkeleton::ItemBool  *innerItemShowInlineImages;
  innerItemShowInlineImages = new KConfigSkeleton::ItemBool( currentGroup(), QStringLiteral( "ShowInlineImages" ), mShowInlineImages, true );
  itemShowInlineImages = new KConfigCompilerSignallingItem(innerItemShowInlineImages, this, notifyFunction, signalShowInlineImagesChanged);
  addItem( itemShowInlineImages, QStringLiteral( "ShowInlineImages" ) );
  KConfigCompilerSignallingItem  *itemStarDensity;
  KConfigSkeleton::ItemInt  *innerItemStarDensity;
  innerItemStarDensity = new KConfigSkeleton::ItemInt( currentGroup(), QStringLiteral( "StarDensity" ), mStarDensity, 5 );
  itemStarDensity = new KConfigCompilerSignallingItem(innerItemStarDensity, this, notifyFunction, signalStarDensityChanged);
  addItem( itemStarDensity, QStringLiteral( "StarDensity" ) );
  KConfigCompilerSignallingItem  *itemMagLimitHideStar;
  KConfigSkeleton::ItemDouble  *innerItemMagLimitHideStar;
  innerItemMagLimitHideStar = new KConfigSkeleton::ItemDouble( currentGroup(), QStringLiteral( "MagLimitHideStar" ), mMagLimitHideStar, 5.0 );
  itemMagLimitHideStar = new KConfigCompilerSignallingItem(innerItemMagLimitHideStar, this, notifyFunction, signalMagLimitHideStarChanged);
  addItem( itemMagLimitHideStar, QStringLiteral( "MagLimitHideStar" ) );
  KConfigCompilerSignallingItem  *itemStarLabelDensity;
  KConfigSkeleton::ItemDouble  *innerItemStarLabelDensity;
  innerItemStarLabelDensity = new KConfigSkeleton::ItemDouble( currentGroup(), QStringLiteral( "StarLabelDensity" ), mStarLabelDensity, 2.0 );
  itemStarLabelDensity = new KConfigCompilerSignallingItem(innerItemStarLabelDensity, this, notifyFunction, signalStarLabelDensityChanged);
  addItem( itemStarLabelDensity, QStringLiteral( "StarLabelDensity" ) );
  KConfigCompilerSignallingItem  *itemDeepSkyLabelDensity;
  KConfigSkeleton::ItemDouble  *innerItemDeepSkyLabelDensity;
  innerItemDeepSkyLabelDensity = new KConfigSkeleton::ItemDouble( currentGroup(), QStringLiteral( "DeepSkyLabelDensity" ), mDeepSkyLabelDensity, 5.0 );
  itemDeepSkyLabelDensity = new KConfigCompilerSignallingItem(innerItemDeepSkyLabelDensity, this, notifyFunction, signalDeepSkyLabelDensityChanged);
  addItem( itemDeepSkyLabelDensity, QStringLiteral( "DeepSkyLabelDensity" ) );
  KConfigCompilerSignallingItem  *itemDeepSkyLongLabels;
  KConfigSkeleton::ItemBool  *innerItemDeepSkyLongLabels;
  innerItemDeepSkyLongLabels = new KConfigSkeleton::ItemBool( currentGroup(), QStringLiteral( "DeepSkyLongLabels" ), mDeepSkyLongLabels, false );
  itemDeepSkyLongLabels = new KConfigCompilerSignallingItem(innerItemDeepSkyLongLabels, this, notifyFunction, signalDeepSkyLongLabelsChanged);
  addItem( itemDeepSkyLongLabels, QStringLiteral( "DeepSkyLongLabels" ) );
  KConfigCompilerSignallingItem  *itemLabelFontScaling;
  KConfigSkeleton::ItemInt  *innerItemLabelFontScaling;
  innerItemLabelFontScaling = new KConfigSkeleton::ItemInt( currentGroup(), QStringLiteral( "LabelFontScaling" ), mLabelFontScaling, 0 );
  itemLabelFontScaling = new KConfigCompilerSignallingItem(innerItemLabelFontScaling, this, notifyFunction, signalLabelFontScalingChanged);
  addItem( itemLabelFontScaling, QStringLiteral( "LabelFontScaling" ) );
  KConfigCompilerSignallingItem  *itemMaxRadCometName;
  KConfigSkeleton::ItemDouble  *innerItemMaxRadCometName;
  innerItemMaxRadCometName = new KConfigSkeleton::ItemDouble( currentGroup(), QStringLiteral( "MaxRadCometName" ), mMaxRadCometName, 1.0 );
  itemMaxRadCometName = new KConfigCompilerSignallingItem(innerItemMaxRadCometName, this, notifyFunction, signalMaxRadCometNameChanged);
  addItem( itemMaxRadCometName, QStringLiteral( "MaxRadCometName" ) );
  KConfigCompilerSignallingItem  *itemUseGL;
  KConfigSkeleton::ItemBool  *innerItemUseGL;
  innerItemUseGL = new KConfigSkeleton::ItemBool( currentGroup(), QStringLiteral( "UseGL" ), mUseGL, false );
  itemUseGL = new KConfigCompilerSignallingItem(innerItemUseGL, this, notifyFunction, signalUseGLChanged);
  addItem( itemUseGL, QStringLiteral( "UseGL" ) );
  KConfigCompilerSignallingItem  *itemRunClock;
  KConfigSkeleton::ItemBool  *innerItemRunClock;
  innerItemRunClock = new KConfigSkeleton::ItemBool( currentGroup(), QStringLiteral( "RunClock" ), mRunClock, true );
  itemRunClock = new KConfigCompilerSignallingItem(innerItemRunClock, this, notifyFunction, signalRunClockChanged);
  addItem( itemRunClock, QStringLiteral( "RunClock" ) );

  setCurrentGroup( QStringLiteral( "ImagingPlanner" ) );

  KConfigCompilerSignallingItem  *itemImagingPlannerAcceptOpenCluster;
  KConfigSkeleton::ItemBool  *innerItemImagingPlannerAcceptOpenCluster;
  innerItemImagingPlannerAcceptOpenCluster = new KConfigSkeleton::ItemBool( currentGroup(), QStringLiteral( "ImagingPlannerAcceptOpenCluster" ), mImagingPlannerAcceptOpenCluster, true );
  itemImagingPlannerAcceptOpenCluster = new KConfigCompilerSignallingItem(innerItemImagingPlannerAcceptOpenCluster, this, notifyFunction, signalImagingPlannerAcceptOpenClusterChanged);
  addItem( itemImagingPlannerAcceptOpenCluster, QStringLiteral( "ImagingPlannerAcceptOpenCluster" ) );
  KConfigCompilerSignallingItem  *itemImagingPlannerAcceptNebula;
  KConfigSkeleton::ItemBool  *innerItemImagingPlannerAcceptNebula;
  innerItemImagingPlannerAcceptNebula = new KConfigSkeleton::ItemBool( currentGroup(), QStringLiteral( "ImagingPlannerAcceptNebula" ), mImagingPlannerAcceptNebula, true );
  itemImagingPlannerAcceptNebula = new KConfigCompilerSignallingItem(innerItemImagingPlannerAcceptNebula, this, notifyFunction, signalImagingPlannerAcceptNebulaChanged);
  addItem( itemImagingPlannerAcceptNebula, QStringLiteral( "ImagingPlannerAcceptNebula" ) );
  KConfigCompilerSignallingItem  *itemImagingPlannerAcceptGlobularCluster;
  KConfigSkeleton::ItemBool  *innerItemImagingPlannerAcceptGlobularCluster;
  innerItemImagingPlannerAcceptGlobularCluster = new KConfigSkeleton::ItemBool( currentGroup(), QStringLiteral( "ImagingPlannerAcceptGlobularCluster" ), mImagingPlannerAcceptGlobularCluster, true );
  itemImagingPlannerAcceptGlobularCluster = new KConfigCompilerSignallingItem(innerItemImagingPlannerAcceptGlobularCluster, this, notifyFunction, signalImagingPlannerAcceptGlobularClusterChanged);
  addItem( itemImagingPlannerAcceptGlobularCluster, QStringLiteral( "ImagingPlannerAcceptGlobularCluster" ) );
  KConfigCompilerSignallingItem  *itemImagingPlannerAcceptPlanetary;
  KConfigSkeleton::ItemBool  *innerItemImagingPlannerAcceptPlanetary;
  innerItemImagingPlannerAcceptPlanetary = new KConfigSkeleton::ItemBool( currentGroup(), QStringLiteral( "ImagingPlannerAcceptPlanetary" ), mImagingPlannerAcceptPlanetary, true );
  itemImagingPlannerAcceptPlanetary = new KConfigCompilerSignallingItem(innerItemImagingPlannerAcceptPlanetary, this, notifyFunction, signalImagingPlannerAcceptPlanetaryChanged);
  addItem( itemImagingPlannerAcceptPlanetary, QStringLiteral( "ImagingPlannerAcceptPlanetary" ) );
  KConfigCompilerSignallingItem  *itemImagingPlannerAcceptSupernovaRemnant;
  KConfigSkeleton::ItemBool  *innerItemImagingPlannerAcceptSupernovaRemnant;
  innerItemImagingPlannerAcceptSupernovaRemnant = new KConfigSkeleton::ItemBool( currentGroup(), QStringLiteral( "ImagingPlannerAcceptSupernovaRemnant" ), mImagingPlannerAcceptSupernovaRemnant, true );
  itemImagingPlannerAcceptSupernovaRemnant = new KConfigCompilerSignallingItem(innerItemImagingPlannerAcceptSupernovaRemnant, this, notifyFunction, signalImagingPlannerAcceptSupernovaRemnantChanged);
  addItem( itemImagingPlannerAcceptSupernovaRemnant, QStringLiteral( "ImagingPlannerAcceptSupernovaRemnant" ) );
  KConfigCompilerSignallingItem  *itemImagingPlannerAcceptGalaxy;
  KConfigSkeleton::ItemBool  *innerItemImagingPlannerAcceptGalaxy;
  innerItemImagingPlannerAcceptGalaxy = new KConfigSkeleton::ItemBool( currentGroup(), QStringLiteral( "ImagingPlannerAcceptGalaxy" ), mImagingPlannerAcceptGalaxy, true );
  itemImagingPlannerAcceptGalaxy = new KConfigCompilerSignallingItem(innerItemImagingPlannerAcceptGalaxy, this, notifyFunction, signalImagingPlannerAcceptGalaxyChanged);
  addItem( itemImagingPlannerAcceptGalaxy, QStringLiteral( "ImagingPlannerAcceptGalaxy" ) );
  KConfigCompilerSignallingItem  *itemImagingPlannerAcceptGalaxyCluster;
  KConfigSkeleton::ItemBool  *innerItemImagingPlannerAcceptGalaxyCluster;
  innerItemImagingPlannerAcceptGalaxyCluster = new KConfigSkeleton::ItemBool( currentGroup(), QStringLiteral( "ImagingPlannerAcceptGalaxyCluster" ), mImagingPlannerAcceptGalaxyCluster, true );
  itemImagingPlannerAcceptGalaxyCluster = new KConfigCompilerSignallingItem(innerItemImagingPlannerAcceptGalaxyCluster, this, notifyFunction, signalImagingPlannerAcceptGalaxyClusterChanged);
  addItem( itemImagingPlannerAcceptGalaxyCluster, QStringLiteral( "ImagingPlannerAcceptGalaxyCluster" ) );
  KConfigCompilerSignallingItem  *itemImagingPlannerAcceptDarkNebula;
  KConfigSkeleton::ItemBool  *innerItemImagingPlannerAcceptDarkNebula;
  innerItemImagingPlannerAcceptDarkNebula = new KConfigSkeleton::ItemBool( currentGroup(), QStringLiteral( "ImagingPlannerAcceptDarkNebula" ), mImagingPlannerAcceptDarkNebula, true );
  itemImagingPlannerAcceptDarkNebula = new KConfigCompilerSignallingItem(innerItemImagingPlannerAcceptDarkNebula, this, notifyFunction, signalImagingPlannerAcceptDarkNebulaChanged);
  addItem( itemImagingPlannerAcceptDarkNebula, QStringLiteral( "ImagingPlannerAcceptDarkNebula" ) );
  KConfigCompilerSignallingItem  *itemImagingPlannerAcceptOther;
  KConfigSkeleton::ItemBool  *innerItemImagingPlannerAcceptOther;
  innerItemImagingPlannerAcceptOther = new KConfigSkeleton::ItemBool( currentGroup(), QStringLiteral( "ImagingPlannerAcceptOther" ), mImagingPlannerAcceptOther, true );
  itemImagingPlannerAcceptOther = new KConfigCompilerSignallingItem(innerItemImagingPlannerAcceptOther, this, notifyFunction, signalImagingPlannerAcceptOtherChanged);
  addItem( itemImagingPlannerAcceptOther, QStringLiteral( "ImagingPlannerAcceptOther" ) );
  KConfigCompilerSignallingItem  *itemAstrobinAward;
  KConfigSkeleton::ItemBool  *innerItemAstrobinAward;
  innerItemAstrobinAward = new KConfigSkeleton::ItemBool( currentGroup(), QStringLiteral( "AstrobinAward" ), mAstrobinAward, false );
  itemAstrobinAward = new KConfigCompilerSignallingItem(innerItemAstrobinAward, this, notifyFunction, signalAstrobinAwardChanged);
  addItem( itemAstrobinAward, QStringLiteral( "AstrobinAward" ) );
  KConfigCompilerSignallingItem  *itemAstrobinMinRadius;
  KConfigSkeleton::ItemDouble  *innerItemAstrobinMinRadius;
  innerItemAstrobinMinRadius = new KConfigSkeleton::ItemDouble( currentGroup(), QStringLiteral( "AstrobinMinRadius" ), mAstrobinMinRadius, 0.01 );
  itemAstrobinMinRadius = new KConfigCompilerSignallingItem(innerItemAstrobinMinRadius, this, notifyFunction, signalAstrobinMinRadiusChanged);
  addItem( itemAstrobinMinRadius, QStringLiteral( "AstrobinMinRadius" ) );
  KConfigCompilerSignallingItem  *itemAstrobinMaxRadius;
  KConfigSkeleton::ItemDouble  *innerItemAstrobinMaxRadius;
  innerItemAstrobinMaxRadius = new KConfigSkeleton::ItemDouble( currentGroup(), QStringLiteral( "AstrobinMaxRadius" ), mAstrobinMaxRadius, 30.0 );
  itemAstrobinMaxRadius = new KConfigCompilerSignallingItem(innerItemAstrobinMaxRadius, this, notifyFunction, signalAstrobinMaxRadiusChanged);
  addItem( itemAstrobinMaxRadius, QStringLiteral( "AstrobinMaxRadius" ) );
  KConfigCompilerSignallingItem  *itemImagingPlannerUseArtificialHorizon;
  KConfigSkeleton::ItemBool  *innerItemImagingPlannerUseArtificialHorizon;
  innerItemImagingPlannerUseArtificialHorizon = new KConfigSkeleton::ItemBool( currentGroup(), QStringLiteral( "ImagingPlannerUseArtificialHorizon" ), mImagingPlannerUseArtificialHorizon, true );
  itemImagingPlannerUseArtificialHorizon = new KConfigCompilerSignallingItem(innerItemImagingPlannerUseArtificialHorizon, this, notifyFunction, signalImagingPlannerUseArtificialHorizonChanged);
  addItem( itemImagingPlannerUseArtificialHorizon, QStringLiteral( "ImagingPlannerUseArtificialHorizon" ) );
  KConfigCompilerSignallingItem  *itemImagingPlannerMinHours;
  KConfigSkeleton::ItemDouble  *innerItemImagingPlannerMinHours;
  innerItemImagingPlannerMinHours = new KConfigSkeleton::ItemDouble( currentGroup(), QStringLiteral( "ImagingPlannerMinHours" ), mImagingPlannerMinHours, 0.0 );
  itemImagingPlannerMinHours = new KConfigCompilerSignallingItem(innerItemImagingPlannerMinHours, this, notifyFunction, signalImagingPlannerMinHoursChanged);
  addItem( itemImagingPlannerMinHours, QStringLiteral( "ImagingPlannerMinHours" ) );
  KConfigCompilerSignallingItem  *itemImagingPlannerMinAltitude;
  KConfigSkeleton::ItemDouble  *innerItemImagingPlannerMinAltitude;
  innerItemImagingPlannerMinAltitude = new KConfigSkeleton::ItemDouble( currentGroup(), QStringLiteral( "ImagingPlannerMinAltitude" ), mImagingPlannerMinAltitude, 30.0 );
  itemImagingPlannerMinAltitude = new KConfigCompilerSignallingItem(innerItemImagingPlannerMinAltitude, this, notifyFunction, signalImagingPlannerMinAltitudeChanged);
  addItem( itemImagingPlannerMinAltitude, QStringLiteral( "ImagingPlannerMinAltitude" ) );
  KConfigCompilerSignallingItem  *itemImagingPlannerMinMoonSeparation;
  KConfigSkeleton::ItemDouble  *innerItemImagingPlannerMinMoonSeparation;
  innerItemImagingPlannerMinMoonSeparation = new KConfigSkeleton::ItemDouble( currentGroup(), QStringLiteral( "ImagingPlannerMinMoonSeparation" ), mImagingPlannerMinMoonSeparation, 30.0 );
  itemImagingPlannerMinMoonSeparation = new KConfigCompilerSignallingItem(innerItemImagingPlannerMinMoonSeparation, this, notifyFunction, signalImagingPlannerMinMoonSeparationChanged);
  addItem( itemImagingPlannerMinMoonSeparation, QStringLiteral( "ImagingPlannerMinMoonSeparation" ) );
  KConfigCompilerSignallingItem  *itemImagingPlannerMaxMoonAltitude;
  KConfigSkeleton::ItemDouble  *innerItemImagingPlannerMaxMoonAltitude;
  innerItemImagingPlannerMaxMoonAltitude = new KConfigSkeleton::ItemDouble( currentGroup(), QStringLiteral( "ImagingPlannerMaxMoonAltitude" ), mImagingPlannerMaxMoonAltitude, 90.0 );
  itemImagingPlannerMaxMoonAltitude = new KConfigCompilerSignallingItem(innerItemImagingPlannerMaxMoonAltitude, this, notifyFunction, signalImagingPlannerMaxMoonAltitudeChanged);
  addItem( itemImagingPlannerMaxMoonAltitude, QStringLiteral( "ImagingPlannerMaxMoonAltitude" ) );
  KConfigCompilerSignallingItem  *itemImagingPlannerShowPicked;
  KConfigSkeleton::ItemBool  *innerItemImagingPlannerShowPicked;
  innerItemImagingPlannerShowPicked = new KConfigSkeleton::ItemBool( currentGroup(), QStringLiteral( "ImagingPlannerShowPicked" ), mImagingPlannerShowPicked, false );
  itemImagingPlannerShowPicked = new KConfigCompilerSignallingItem(innerItemImagingPlannerShowPicked, this, notifyFunction, signalImagingPlannerShowPickedChanged);
  addItem( itemImagingPlannerShowPicked, QStringLiteral( "ImagingPlannerShowPicked" ) );
  KConfigCompilerSignallingItem  *itemImagingPlannerShowNotPicked;
  KConfigSkeleton::ItemBool  *innerItemImagingPlannerShowNotPicked;
  innerItemImagingPlannerShowNotPicked = new KConfigSkeleton::ItemBool( currentGroup(), QStringLiteral( "ImagingPlannerShowNotPicked" ), mImagingPlannerShowNotPicked, false );
  itemImagingPlannerShowNotPicked = new KConfigCompilerSignallingItem(innerItemImagingPlannerShowNotPicked, this, notifyFunction, signalImagingPlannerShowNotPickedChanged);
  addItem( itemImagingPlannerShowNotPicked, QStringLiteral( "ImagingPlannerShowNotPicked" ) );
  KConfigCompilerSignallingItem  *itemImagingPlannerDontCarePicked;
  KConfigSkeleton::ItemBool  *innerItemImagingPlannerDontCarePicked;
  innerItemImagingPlannerDontCarePicked = new KConfigSkeleton::ItemBool( currentGroup(), QStringLiteral( "ImagingPlannerDontCarePicked" ), mImagingPlannerDontCarePicked, true );
  itemImagingPlannerDontCarePicked = new KConfigCompilerSignallingItem(innerItemImagingPlannerDontCarePicked, this, notifyFunction, signalImagingPlannerDontCarePickedChanged);
  addItem( itemImagingPlannerDontCarePicked, QStringLiteral( "ImagingPlannerDontCarePicked" ) );
  KConfigCompilerSignallingItem  *itemImagingPlannerShowKeyword;
  KConfigSkeleton::ItemBool  *innerItemImagingPlannerShowKeyword;
  innerItemImagingPlannerShowKeyword = new KConfigSkeleton::ItemBool( currentGroup(), QStringLiteral( "ImagingPlannerShowKeyword" ), mImagingPlannerShowKeyword, false );
  itemImagingPlannerShowKeyword = new KConfigCompilerSignallingItem(innerItemImagingPlannerShowKeyword, this, notifyFunction, signalImagingPlannerShowKeywordChanged);
  addItem( itemImagingPlannerShowKeyword, QStringLiteral( "ImagingPlannerShowKeyword" ) );
  KConfigCompilerSignallingItem  *itemImagingPlannerShowNotKeyword;
  KConfigSkeleton::ItemBool  *innerItemImagingPlannerShowNotKeyword;
  innerItemImagingPlannerShowNotKeyword = new KConfigSkeleton::ItemBool( currentGroup(), QStringLiteral( "ImagingPlannerShowNotKeyword" ), mImagingPlannerShowNotKeyword, false );
  itemImagingPlannerShowNotKeyword = new KConfigCompilerSignallingItem(innerItemImagingPlannerShowNotKeyword, this, notifyFunction, signalImagingPlannerShowNotKeywordChanged);
  addItem( itemImagingPlannerShowNotKeyword, QStringLiteral( "ImagingPlannerShowNotKeyword" ) );
  KConfigCompilerSignallingItem  *itemImagingPlannerDontCareKeyword;
  KConfigSkeleton::ItemBool  *innerItemImagingPlannerDontCareKeyword;
  innerItemImagingPlannerDontCareKeyword = new KConfigSkeleton::ItemBool( currentGroup(), QStringLiteral( "ImagingPlannerDontCareKeyword" ), mImagingPlannerDontCareKeyword, true );
  itemImagingPlannerDontCareKeyword = new KConfigCompilerSignallingItem(innerItemImagingPlannerDontCareKeyword, this, notifyFunction, signalImagingPlannerDontCareKeywordChanged);
  addItem( itemImagingPlannerDontCareKeyword, QStringLiteral( "ImagingPlannerDontCareKeyword" ) );
  KConfigCompilerSignallingItem  *itemImagingPlannerKeyword;
  KConfigSkeleton::ItemString  *innerItemImagingPlannerKeyword;
  innerItemImagingPlannerKeyword = new KConfigSkeleton::ItemString( currentGroup(), QStringLiteral( "ImagingPlannerKeyword" ), mImagingPlannerKeyword );
  itemImagingPlannerKeyword = new KConfigCompilerSignallingItem(innerItemImagingPlannerKeyword, this, notifyFunction, signalImagingPlannerKeywordChanged);
  addItem( itemImagingPlannerKeyword, QStringLiteral( "ImagingPlannerKeyword" ) );
  KConfigCompilerSignallingItem  *itemImagingPlannerShowImaged;
  KConfigSkeleton::ItemBool  *innerItemImagingPlannerShowImaged;
  innerItemImagingPlannerShowImaged = new KConfigSkeleton::ItemBool( currentGroup(), QStringLiteral( "ImagingPlannerShowImaged" ), mImagingPlannerShowImaged, false );
  itemImagingPlannerShowImaged = new KConfigCompilerSignallingItem(innerItemImagingPlannerShowImaged, this, notifyFunction, signalImagingPlannerShowImagedChanged);
  addItem( itemImagingPlannerShowImaged, QStringLiteral( "ImagingPlannerShowImaged" ) );
  KConfigCompilerSignallingItem  *itemImagingPlannerShowNotImaged;
  KConfigSkeleton::ItemBool  *innerItemImagingPlannerShowNotImaged;
  innerItemImagingPlannerShowNotImaged = new KConfigSkeleton::ItemBool( currentGroup(), QStringLiteral( "ImagingPlannerShowNotImaged" ), mImagingPlannerShowNotImaged, false );
  itemImagingPlannerShowNotImaged = new KConfigCompilerSignallingItem(innerItemImagingPlannerShowNotImaged, this, notifyFunction, signalImagingPlannerShowNotImagedChanged);
  addItem( itemImagingPlannerShowNotImaged, QStringLiteral( "ImagingPlannerShowNotImaged" ) );
  KConfigCompilerSignallingItem  *itemImagingPlannerDontCareImaged;
  KConfigSkeleton::ItemBool  *innerItemImagingPlannerDontCareImaged;
  innerItemImagingPlannerDontCareImaged = new KConfigSkeleton::ItemBool( currentGroup(), QStringLiteral( "ImagingPlannerDontCareImaged" ), mImagingPlannerDontCareImaged, true );
  itemImagingPlannerDontCareImaged = new KConfigCompilerSignallingItem(innerItemImagingPlannerDontCareImaged, this, notifyFunction, signalImagingPlannerDontCareImagedChanged);
  addItem( itemImagingPlannerDontCareImaged, QStringLiteral( "ImagingPlannerDontCareImaged" ) );
  KConfigCompilerSignallingItem  *itemImagingPlannerShowAdded;
  KConfigSkeleton::ItemBool  *innerItemImagingPlannerShowAdded;
  innerItemImagingPlannerShowAdded = new KConfigSkeleton::ItemBool( currentGroup(), QStringLiteral( "ImagingPlannerShowAdded" ), mImagingPlannerShowAdded, false );
  itemImagingPlannerShowAdded = new KConfigCompilerSignallingItem(innerItemImagingPlannerShowAdded, this, notifyFunction, signalImagingPlannerShowAddedChanged);
  addItem( itemImagingPlannerShowAdded, QStringLiteral( "ImagingPlannerShowAdded" ) );
  KConfigCompilerSignallingItem  *itemImagingPlannerShowNotAdded;
  KConfigSkeleton::ItemBool  *innerItemImagingPlannerShowNotAdded;
  innerItemImagingPlannerShowNotAdded = new KConfigSkeleton::ItemBool( currentGroup(), QStringLiteral( "ImagingPlannerShowNotAdded" ), mImagingPlannerShowNotAdded, false );
  itemImagingPlannerShowNotAdded = new KConfigCompilerSignallingItem(innerItemImagingPlannerShowNotAdded, this, notifyFunction, signalImagingPlannerShowNotAddedChanged);
  addItem( itemImagingPlannerShowNotAdded, QStringLiteral( "ImagingPlannerShowNotAdded" ) );
  KConfigCompilerSignallingItem  *itemImagingPlannerDontCareAdded;
  KConfigSkeleton::ItemBool  *innerItemImagingPlannerDontCareAdded;
  innerItemImagingPlannerDontCareAdded = new KConfigSkeleton::ItemBool( currentGroup(), QStringLiteral( "ImagingPlannerDontCareAdded" ), mImagingPlannerDontCareAdded, true );
  itemImagingPlannerDontCareAdded = new KConfigCompilerSignallingItem(innerItemImagingPlannerDontCareAdded, this, notifyFunction, signalImagingPlannerDontCareAddedChanged);
  addItem( itemImagingPlannerDontCareAdded, QStringLiteral( "ImagingPlannerDontCareAdded" ) );
  KConfigCompilerSignallingItem  *itemImagingPlannerShowIgnored;
  KConfigSkeleton::ItemBool  *innerItemImagingPlannerShowIgnored;
  innerItemImagingPlannerShowIgnored = new KConfigSkeleton::ItemBool( currentGroup(), QStringLiteral( "ImagingPlannerShowIgnored" ), mImagingPlannerShowIgnored, false );
  itemImagingPlannerShowIgnored = new KConfigCompilerSignallingItem(innerItemImagingPlannerShowIgnored, this, notifyFunction, signalImagingPlannerShowIgnoredChanged);
  addItem( itemImagingPlannerShowIgnored, QStringLiteral( "ImagingPlannerShowIgnored" ) );
  KConfigCompilerSignallingItem  *itemImagingPlannerShowNotIgnored;
  KConfigSkeleton::ItemBool  *innerItemImagingPlannerShowNotIgnored;
  innerItemImagingPlannerShowNotIgnored = new KConfigSkeleton::ItemBool( currentGroup(), QStringLiteral( "ImagingPlannerShowNotIgnored" ), mImagingPlannerShowNotIgnored, true );
  itemImagingPlannerShowNotIgnored = new KConfigCompilerSignallingItem(innerItemImagingPlannerShowNotIgnored, this, notifyFunction, signalImagingPlannerShowNotIgnoredChanged);
  addItem( itemImagingPlannerShowNotIgnored, QStringLiteral( "ImagingPlannerShowNotIgnored" ) );
  KConfigCompilerSignallingItem  *itemImagingPlannerDontCareIgnored;
  KConfigSkeleton::ItemBool  *innerItemImagingPlannerDontCareIgnored;
  innerItemImagingPlannerDontCareIgnored = new KConfigSkeleton::ItemBool( currentGroup(), QStringLiteral( "ImagingPlannerDontCareIgnored" ), mImagingPlannerDontCareIgnored, false );
  itemImagingPlannerDontCareIgnored = new KConfigCompilerSignallingItem(innerItemImagingPlannerDontCareIgnored, this, notifyFunction, signalImagingPlannerDontCareIgnoredChanged);
  addItem( itemImagingPlannerDontCareIgnored, QStringLiteral( "ImagingPlannerDontCareIgnored" ) );
  KConfigCompilerSignallingItem  *itemImagingPlannerHideAstrobinDetails;
  KConfigSkeleton::ItemBool  *innerItemImagingPlannerHideAstrobinDetails;
  innerItemImagingPlannerHideAstrobinDetails = new KConfigSkeleton::ItemBool( currentGroup(), QStringLiteral( "ImagingPlannerHideAstrobinDetails" ), mImagingPlannerHideAstrobinDetails, true );
  itemImagingPlannerHideAstrobinDetails = new KConfigCompilerSignallingItem(innerItemImagingPlannerHideAstrobinDetails, this, notifyFunction, signalImagingPlannerHideAstrobinDetailsChanged);
  addItem( itemImagingPlannerHideAstrobinDetails, QStringLiteral( "ImagingPlannerHideAstrobinDetails" ) );
  KConfigCompilerSignallingItem  *itemImagingPlannerHideFilters;
  KConfigSkeleton::ItemBool  *innerItemImagingPlannerHideFilters;
  innerItemImagingPlannerHideFilters = new KConfigSkeleton::ItemBool( currentGroup(), QStringLiteral( "ImagingPlannerHideFilters" ), mImagingPlannerHideFilters, true );
  itemImagingPlannerHideFilters = new KConfigCompilerSignallingItem(innerItemImagingPlannerHideFilters, this, notifyFunction, signalImagingPlannerHideFiltersChanged);
  addItem( itemImagingPlannerHideFilters, QStringLiteral( "ImagingPlannerHideFilters" ) );
  KConfigCompilerSignallingItem  *itemImagingPlannerHideImage;
  KConfigSkeleton::ItemBool  *innerItemImagingPlannerHideImage;
  innerItemImagingPlannerHideImage = new KConfigSkeleton::ItemBool( currentGroup(), QStringLiteral( "ImagingPlannerHideImage" ), mImagingPlannerHideImage, false );
  itemImagingPlannerHideImage = new KConfigCompilerSignallingItem(innerItemImagingPlannerHideImage, this, notifyFunction, signalImagingPlannerHideImageChanged);
  addItem( itemImagingPlannerHideImage, QStringLiteral( "ImagingPlannerHideImage" ) );
  KConfigCompilerSignallingItem  *itemImagingPlannerHideAltitudeGraph;
  KConfigSkeleton::ItemBool  *innerItemImagingPlannerHideAltitudeGraph;
  innerItemImagingPlannerHideAltitudeGraph = new KConfigSkeleton::ItemBool( currentGroup(), QStringLiteral( "ImagingPlannerHideAltitudeGraph" ), mImagingPlannerHideAltitudeGraph, false );
  itemImagingPlannerHideAltitudeGraph = new KConfigCompilerSignallingItem(innerItemImagingPlannerHideAltitudeGraph, this, notifyFunction, signalImagingPlannerHideAltitudeGraphChanged);
  addItem( itemImagingPlannerHideAltitudeGraph, QStringLiteral( "ImagingPlannerHideAltitudeGraph" ) );
  KConfigCompilerSignallingItem  *itemImagingPlannerCatalogPath;
  KConfigSkeleton::ItemString  *innerItemImagingPlannerCatalogPath;
  innerItemImagingPlannerCatalogPath = new KConfigSkeleton::ItemString( currentGroup(), QStringLiteral( "ImagingPlannerCatalogPath" ), mImagingPlannerCatalogPath );
  itemImagingPlannerCatalogPath = new KConfigCompilerSignallingItem(innerItemImagingPlannerCatalogPath, this, notifyFunction, signalImagingPlannerCatalogPathChanged);
  addItem( itemImagingPlannerCatalogPath, QStringLiteral( "ImagingPlannerCatalogPath" ) );
  KConfigCompilerSignallingItem  *itemImagingPlannerCenterOnSkyMap;
  KConfigSkeleton::ItemBool  *innerItemImagingPlannerCenterOnSkyMap;
  innerItemImagingPlannerCenterOnSkyMap = new KConfigSkeleton::ItemBool( currentGroup(), QStringLiteral( "ImagingPlannerCenterOnSkyMap" ), mImagingPlannerCenterOnSkyMap, false );
  itemImagingPlannerCenterOnSkyMap = new KConfigCompilerSignallingItem(innerItemImagingPlannerCenterOnSkyMap, this, notifyFunction, signalImagingPlannerCenterOnSkyMapChanged);
  addItem( itemImagingPlannerCenterOnSkyMap, QStringLiteral( "ImagingPlannerCenterOnSkyMap" ) );
  KConfigCompilerSignallingItem  *itemImagingPlannerIndependentWindow;
  KConfigSkeleton::ItemBool  *innerItemImagingPlannerIndependentWindow;
  innerItemImagingPlannerIndependentWindow = new KConfigSkeleton::ItemBool( currentGroup(), QStringLiteral( "ImagingPlannerIndependentWindow" ), mImagingPlannerIndependentWindow, true );
  itemImagingPlannerIndependentWindow = new KConfigCompilerSignallingItem(innerItemImagingPlannerIndependentWindow, this, notifyFunction, signalImagingPlannerIndependentWindowChanged);
  addItem( itemImagingPlannerIndependentWindow, QStringLiteral( "ImagingPlannerIndependentWindow" ) );
  KConfigCompilerSignallingItem  *itemImagingPlannerStartSolvingImmediately;
  KConfigSkeleton::ItemBool  *innerItemImagingPlannerStartSolvingImmediately;
  innerItemImagingPlannerStartSolvingImmediately = new KConfigSkeleton::ItemBool( currentGroup(), QStringLiteral( "ImagingPlannerStartSolvingImmediately" ), mImagingPlannerStartSolvingImmediately, false );
  itemImagingPlannerStartSolvingImmediately = new KConfigCompilerSignallingItem(innerItemImagingPlannerStartSolvingImmediately, this, notifyFunction, signalImagingPlannerStartSolvingImmediatelyChanged);
  addItem( itemImagingPlannerStartSolvingImmediately, QStringLiteral( "ImagingPlannerStartSolvingImmediately" ) );

  setCurrentGroup( QStringLiteral( "ObservingList" ) );

  KConfigCompilerSignallingItem  *itemObsListSymbol;
  KConfigSkeleton::ItemBool  *innerItemObsListSymbol;
  innerItemObsListSymbol = new KConfigSkeleton::ItemBool( currentGroup(), QStringLiteral( "ObsListSymbol" ), mObsListSymbol, true );
  itemObsListSymbol = new KConfigCompilerSignallingItem(innerItemObsListSymbol, this, notifyFunction, signalObsListSymbolChanged);
  addItem( itemObsListSymbol, QStringLiteral( "ObsListSymbol" ) );
  KConfigCompilerSignallingItem  *itemObsListText;
  KConfigSkeleton::ItemBool  *innerItemObsListText;
  innerItemObsListText = new KConfigSkeleton::ItemBool( currentGroup(), QStringLiteral( "ObsListText" ), mObsListText, false );
  itemObsListText = new KConfigCompilerSignallingItem(innerItemObsListText, this, notifyFunction, signalObsListTextChanged);
  addItem( itemObsListText, QStringLiteral( "ObsListText" ) );
  KConfigCompilerSignallingItem  *itemObsListPreferDSS;
  KConfigSkeleton::ItemBool  *innerItemObsListPreferDSS;
  innerItemObsListPreferDSS = new KConfigSkeleton::ItemBool( currentGroup(), QStringLiteral( "ObsListPreferDSS" ), mObsListPreferDSS, true );
  itemObsListPreferDSS = new KConfigCompilerSignallingItem(innerItemObsListPreferDSS, this, notifyFunction, signalObsListPreferDSSChanged);
  addItem( itemObsListPreferDSS, QStringLiteral( "ObsListPreferDSS" ) );
  KConfigCompilerSignallingItem  *itemObsListPreferSDSS;
  KConfigSkeleton::ItemBool  *innerItemObsListPreferSDSS;
  innerItemObsListPreferSDSS = new KConfigSkeleton::ItemBool( currentGroup(), QStringLiteral( "ObsListPreferSDSS" ), mObsListPreferSDSS, false );
  itemObsListPreferSDSS = new KConfigCompilerSignallingItem(innerItemObsListPreferSDSS, this, notifyFunction, signalObsListPreferSDSSChanged);
  addItem( itemObsListPreferSDSS, QStringLiteral( "ObsListPreferSDSS" ) );
  KConfigCompilerSignallingItem  *itemObsListDemoteHole;
  KConfigSkeleton::ItemBool  *innerItemObsListDemoteHole;
  innerItemObsListDemoteHole = new KConfigSkeleton::ItemBool( currentGroup(), QStringLiteral( "ObsListDemoteHole" ), mObsListDemoteHole, false );
  itemObsListDemoteHole = new KConfigCompilerSignallingItem(innerItemObsListDemoteHole, this, notifyFunction, signalObsListDemoteHoleChanged);
  addItem( itemObsListDemoteHole, QStringLiteral( "ObsListDemoteHole" ) );
  KConfigCompilerSignallingItem  *itemObsListHoleSize;
  KConfigSkeleton::ItemDouble  *innerItemObsListHoleSize;
  innerItemObsListHoleSize = new KConfigSkeleton::ItemDouble( currentGroup(), QStringLiteral( "ObsListHoleSize" ), mObsListHoleSize, 15.00 );
  itemObsListHoleSize = new KConfigCompilerSignallingItem(innerItemObsListHoleSize, this, notifyFunction, signalObsListHoleSizeChanged);
  addItem( itemObsListHoleSize, QStringLiteral( "ObsListHoleSize" ) );
  KConfigCompilerSignallingItem  *itemObsListCoverage;
  KConfigSkeleton::ItemDouble  *innerItemObsListCoverage;
  innerItemObsListCoverage = new KConfigSkeleton::ItemDouble( currentGroup(), QStringLiteral( "ObsListCoverage" ), mObsListCoverage, 40.00 );
  itemObsListCoverage = new KConfigCompilerSignallingItem(innerItemObsListCoverage, this, notifyFunction, signalObsListCoverageChanged);
  addItem( itemObsListCoverage, QStringLiteral( "ObsListCoverage" ) );

  setCurrentGroup( QStringLiteral( "Colors" ) );

  KConfigCompilerSignallingItem  *itemColorSchemeFile;
  KConfigSkeleton::ItemString  *innerItemColorSchemeFile;
  innerItemColorSchemeFile = new KConfigSkeleton::ItemString( currentGroup(), QStringLiteral( "ColorSchemeFile" ), mColorSchemeFile, QStringLiteral( "moonless-night.colors" ) );
  itemColorSchemeFile = new KConfigCompilerSignallingItem(innerItemColorSchemeFile, this, notifyFunction, signalColorSchemeFileChanged);
  addItem( itemColorSchemeFile, QStringLiteral( "ColorSchemeFile" ) );
  KConfigCompilerSignallingItem  *itemStarColorMode;
  KConfigSkeleton::ItemUInt  *innerItemStarColorMode;
  innerItemStarColorMode = new KConfigSkeleton::ItemUInt( currentGroup(), QStringLiteral( "StarColorMode" ), mStarColorMode, 0 );
  itemStarColorMode = new KConfigCompilerSignallingItem(innerItemStarColorMode, this, notifyFunction, signalStarColorModeChanged);
  innerItemStarColorMode->setMaxValue(4);
  addItem( itemStarColorMode, QStringLiteral( "StarColorMode" ) );
  KConfigCompilerSignallingItem  *itemStarColorIntensity;
  KConfigSkeleton::ItemUInt  *innerItemStarColorIntensity;
  innerItemStarColorIntensity = new KConfigSkeleton::ItemUInt( currentGroup(), QStringLiteral( "StarColorIntensity" ), mStarColorIntensity, 6 );
  itemStarColorIntensity = new KConfigCompilerSignallingItem(innerItemStarColorIntensity, this, notifyFunction, signalStarColorIntensityChanged);
  innerItemStarColorIntensity->setMaxValue(10);
  addItem( itemStarColorIntensity, QStringLiteral( "StarColorIntensity" ) );
  KConfigCompilerSignallingItem  *itemDomeSlitInverted;
  KConfigSkeleton::ItemBool  *innerItemDomeSlitInverted;
  innerItemDomeSlitInverted = new KConfigSkeleton::ItemBool( currentGroup(), QStringLiteral( "DomeSlitInverted" ), mDomeSlitInverted, false );
  itemDomeSlitInverted = new KConfigCompilerSignallingItem(innerItemDomeSlitInverted, this, notifyFunction, signalDomeSlitInvertedChanged);
  addItem( itemDomeSlitInverted, QStringLiteral( "DomeSlitInverted" ) );
  KConfigCompilerSignallingItem  *itemAngularRulerColor;
  KConfigSkeleton::ItemString  *innerItemAngularRulerColor;
  innerItemAngularRulerColor = new KConfigSkeleton::ItemString( currentGroup(), QStringLiteral( "AngularRulerColor" ), mAngularRulerColor, QStringLiteral( "#FFF" ) );
  itemAngularRulerColor = new KConfigCompilerSignallingItem(innerItemAngularRulerColor, this, notifyFunction, signalAngularRulerColorChanged);
  addItem( itemAngularRulerColor, QStringLiteral( "AngularRulerColor" ) );
  KConfigCompilerSignallingItem  *itemBoxBGColor;
  KConfigSkeleton::ItemString  *innerItemBoxBGColor;
  innerItemBoxBGColor = new KConfigSkeleton::ItemString( currentGroup(), QStringLiteral( "BoxBGColor" ), mBoxBGColor, QStringLiteral( "#000" ) );
  itemBoxBGColor = new KConfigCompilerSignallingItem(innerItemBoxBGColor, this, notifyFunction, signalBoxBGColorChanged);
  addItem( itemBoxBGColor, QStringLiteral( "BoxBGColor" ) );
  KConfigCompilerSignallingItem  *itemBoxGrabColor;
  KConfigSkeleton::ItemString  *innerItemBoxGrabColor;
  innerItemBoxGrabColor = new KConfigSkeleton::ItemString( currentGroup(), QStringLiteral( "BoxGrabColor" ), mBoxGrabColor, QStringLiteral( "#F00" ) );
  itemBoxGrabColor = new KConfigCompilerSignallingItem(innerItemBoxGrabColor, this, notifyFunction, signalBoxGrabColorChanged);
  addItem( itemBoxGrabColor, QStringLiteral( "BoxGrabColor" ) );
  KConfigCompilerSignallingItem  *itemBoxTextColor;
  KConfigSkeleton::ItemString  *innerItemBoxTextColor;
  innerItemBoxTextColor = new KConfigSkeleton::ItemString( currentGroup(), QStringLiteral( "BoxTextColor" ), mBoxTextColor, QStringLiteral( "#FFF" ) );
  itemBoxTextColor = new KConfigCompilerSignallingItem(innerItemBoxTextColor, this, notifyFunction, signalBoxTextColorChanged);
  addItem( itemBoxTextColor, QStringLiteral( "BoxTextColor" ) );
  KConfigCompilerSignallingItem  *itemCBoundColor;
  KConfigSkeleton::ItemString  *innerItemCBoundColor;
  innerItemCBoundColor = new KConfigSkeleton::ItemString( currentGroup(), QStringLiteral( "CBoundColor" ), mCBoundColor, QStringLiteral( "#222" ) );
  itemCBoundColor = new KConfigCompilerSignallingItem(innerItemCBoundColor, this, notifyFunction, signalCBoundColorChanged);
  addItem( itemCBoundColor, QStringLiteral( "CBoundColor" ) );
  KConfigCompilerSignallingItem  *itemCBoundHighColor;
  KConfigSkeleton::ItemString  *innerItemCBoundHighColor;
  innerItemCBoundHighColor = new KConfigSkeleton::ItemString( currentGroup(), QStringLiteral( "CBoundHighColor" ), mCBoundHighColor, QStringLiteral( "#222" ) );
  itemCBoundHighColor = new KConfigCompilerSignallingItem(innerItemCBoundHighColor, this, notifyFunction, signalCBoundHighColorChanged);
  addItem( itemCBoundHighColor, QStringLiteral( "CBoundHighColor" ) );
  KConfigCompilerSignallingItem  *itemCLineColor;
  KConfigSkeleton::ItemString  *innerItemCLineColor;
  innerItemCLineColor = new KConfigSkeleton::ItemString( currentGroup(), QStringLiteral( "CLineColor" ), mCLineColor, QStringLiteral( "#555" ) );
  itemCLineColor = new KConfigCompilerSignallingItem(innerItemCLineColor, this, notifyFunction, signalCLineColorChanged);
  addItem( itemCLineColor, QStringLiteral( "CLineColor" ) );
  KConfigCompilerSignallingItem  *itemCNameColor;
  KConfigSkeleton::ItemString  *innerItemCNameColor;
  innerItemCNameColor = new KConfigSkeleton::ItemString( currentGroup(), QStringLiteral( "CNameColor" ), mCNameColor, QStringLiteral( "#AA7" ) );
  itemCNameColor = new KConfigCompilerSignallingItem(innerItemCNameColor, this, notifyFunction, signalCNameColorChanged);
  addItem( itemCNameColor, QStringLiteral( "CNameColor" ) );
  KConfigCompilerSignallingItem  *itemCompassColor;
  KConfigSkeleton::ItemString  *innerItemCompassColor;
  innerItemCompassColor = new KConfigSkeleton::ItemString( currentGroup(), QStringLiteral( "CompassColor" ), mCompassColor, QStringLiteral( "#002" ) );
  itemCompassColor = new KConfigCompilerSignallingItem(innerItemCompassColor, this, notifyFunction, signalCompassColorChanged);
  addItem( itemCompassColor, QStringLiteral( "CompassColor" ) );
  KConfigCompilerSignallingItem  *itemEclipticColor;
  KConfigSkeleton::ItemString  *innerItemEclipticColor;
  innerItemEclipticColor = new KConfigSkeleton::ItemString( currentGroup(), QStringLiteral( "EclipticColor" ), mEclipticColor, QStringLiteral( "#663" ) );
  itemEclipticColor = new KConfigCompilerSignallingItem(innerItemEclipticColor, this, notifyFunction, signalEclipticColorChanged);
  addItem( itemEclipticColor, QStringLiteral( "EclipticColor" ) );
  KConfigCompilerSignallingItem  *itemEquatorColor;
  KConfigSkeleton::ItemString  *innerItemEquatorColor;
  innerItemEquatorColor = new KConfigSkeleton::ItemString( currentGroup(), QStringLiteral( "EquatorColor" ), mEquatorColor, QStringLiteral( "#FFF" ) );
  itemEquatorColor = new KConfigCompilerSignallingItem(innerItemEquatorColor, this, notifyFunction, signalEquatorColorChanged);
  addItem( itemEquatorColor, QStringLiteral( "EquatorColor" ) );
  KConfigCompilerSignallingItem  *itemEquatorialGridColor;
  KConfigSkeleton::ItemString  *innerItemEquatorialGridColor;
  innerItemEquatorialGridColor = new KConfigSkeleton::ItemString( currentGroup(), QStringLiteral( "EquatorialGridColor" ), mEquatorialGridColor, QStringLiteral( "#456" ) );
  itemEquatorialGridColor = new KConfigCompilerSignallingItem(innerItemEquatorialGridColor, this, notifyFunction, signalEquatorialGridColorChanged);
  addItem( itemEquatorialGridColor, QStringLiteral( "EquatorialGridColor" ) );
  KConfigCompilerSignallingItem  *itemHorizontalGridColor;
  KConfigSkeleton::ItemString  *innerItemHorizontalGridColor;
  innerItemHorizontalGridColor = new KConfigSkeleton::ItemString( currentGroup(), QStringLiteral( "HorizontalGridColor" ), mHorizontalGridColor, QStringLiteral( "#5A3" ) );
  itemHorizontalGridColor = new KConfigCompilerSignallingItem(innerItemHorizontalGridColor, this, notifyFunction, signalHorizontalGridColorChanged);
  addItem( itemHorizontalGridColor, QStringLiteral( "HorizontalGridColor" ) );
  KConfigCompilerSignallingItem  *itemSpecialObjectColor;
  KConfigSkeleton::ItemString  *innerItemSpecialObjectColor;
  innerItemSpecialObjectColor = new KConfigSkeleton::ItemString( currentGroup(), QStringLiteral( "SpecialObjectColor" ), mSpecialObjectColor, QStringLiteral( "#A00" ) );
  itemSpecialObjectColor = new KConfigCompilerSignallingItem(innerItemSpecialObjectColor, this, notifyFunction, signalSpecialObjectColorChanged);
  addItem( itemSpecialObjectColor, QStringLiteral( "SpecialObjectColor" ) );
  KConfigCompilerSignallingItem  *itemHorizonColor;
  KConfigSkeleton::ItemString  *innerItemHorizonColor;
  innerItemHorizonColor = new KConfigSkeleton::ItemString( currentGroup(), QStringLiteral( "HorizonColor" ), mHorizonColor, QStringLiteral( "#5A3" ) );
  itemHorizonColor = new KConfigCompilerSignallingItem(innerItemHorizonColor, this, notifyFunction, signalHorizonColorChanged);
  addItem( itemHorizonColor, QStringLiteral( "HorizonColor" ) );
  KConfigCompilerSignallingItem  *itemLocalMeridianColor;
  KConfigSkeleton::ItemString  *innerItemLocalMeridianColor;
  innerItemLocalMeridianColor = new KConfigSkeleton::ItemString( currentGroup(), QStringLiteral( "LocalMeridianColor" ), mLocalMeridianColor, QStringLiteral( "#0059b3" ) );
  itemLocalMeridianColor = new KConfigCompilerSignallingItem(innerItemLocalMeridianColor, this, notifyFunction, signalLocalMeridianColorChanged);
  addItem( itemLocalMeridianColor, QStringLiteral( "LocalMeridianColor" ) );
  KConfigCompilerSignallingItem  *itemMilkyWayWColor;
  KConfigSkeleton::ItemString  *innerItemMilkyWayWColor;
  innerItemMilkyWayWColor = new KConfigSkeleton::ItemString( currentGroup(), QStringLiteral( "MilkyWayWColor" ), mMilkyWayWColor, QStringLiteral( "#123" ) );
  itemMilkyWayWColor = new KConfigCompilerSignallingItem(innerItemMilkyWayWColor, this, notifyFunction, signalMilkyWayWColorChanged);
  addItem( itemMilkyWayWColor, QStringLiteral( "MilkyWayWColor" ) );
  KConfigCompilerSignallingItem  *itemStarNameColor;
  KConfigSkeleton::ItemString  *innerItemStarNameColor;
  innerItemStarNameColor = new KConfigSkeleton::ItemString( currentGroup(), QStringLiteral( "StarNameColor" ), mStarNameColor, QStringLiteral( "#7AA" ) );
  itemStarNameColor = new KConfigCompilerSignallingItem(innerItemStarNameColor, this, notifyFunction, signalStarNameColorChanged);
  addItem( itemStarNameColor, QStringLiteral( "StarNameColor" ) );
  KConfigCompilerSignallingItem  *itemDeepSkyNameColor;
  KConfigSkeleton::ItemString  *innerItemDeepSkyNameColor;
  innerItemDeepSkyNameColor = new KConfigSkeleton::ItemString( currentGroup(), QStringLiteral( "DeepSkyNameColor" ), mDeepSkyNameColor, QStringLiteral( "#7AA" ) );
  itemDeepSkyNameColor = new KConfigCompilerSignallingItem(innerItemDeepSkyNameColor, this, notifyFunction, signalDeepSkyNameColorChanged);
  addItem( itemDeepSkyNameColor, QStringLiteral( "DeepSkyNameColor" ) );
  KConfigCompilerSignallingItem  *itemPlanetNameColor;
  KConfigSkeleton::ItemString  *innerItemPlanetNameColor;
  innerItemPlanetNameColor = new KConfigSkeleton::ItemString( currentGroup(), QStringLiteral( "PlanetNameColor" ), mPlanetNameColor, QStringLiteral( "#439" ) );
  itemPlanetNameColor = new KConfigCompilerSignallingItem(innerItemPlanetNameColor, this, notifyFunction, signalPlanetNameColorChanged);
  addItem( itemPlanetNameColor, QStringLiteral( "PlanetNameColor" ) );
  KConfigCompilerSignallingItem  *itemPlanetTrailColor;
  KConfigSkeleton::ItemString  *innerItemPlanetTrailColor;
  innerItemPlanetTrailColor = new KConfigSkeleton::ItemString( currentGroup(), QStringLiteral( "PlanetTrailColor" ), mPlanetTrailColor, QStringLiteral( "#963" ) );
  itemPlanetTrailColor = new KConfigCompilerSignallingItem(innerItemPlanetTrailColor, this, notifyFunction, signalPlanetTrailColorChanged);
  addItem( itemPlanetTrailColor, QStringLiteral( "PlanetTrailColor" ) );
  KConfigCompilerSignallingItem  *itemSkyColor;
  KConfigSkeleton::ItemString  *innerItemSkyColor;
  innerItemSkyColor = new KConfigSkeleton::ItemString( currentGroup(), QStringLiteral( "SkyColor" ), mSkyColor, QStringLiteral( "#002" ) );
  itemSkyColor = new KConfigCompilerSignallingItem(innerItemSkyColor, this, notifyFunction, signalSkyColorChanged);
  addItem( itemSkyColor, QStringLiteral( "SkyColor" ) );
  KConfigCompilerSignallingItem  *itemSkyColorDaytime;
  KConfigSkeleton::ItemString  *innerItemSkyColorDaytime;
  innerItemSkyColorDaytime = new KConfigSkeleton::ItemString( currentGroup(), QStringLiteral( "SkyColorDaytime" ), mSkyColorDaytime, QStringLiteral( "#002" ) );
  itemSkyColorDaytime = new KConfigCompilerSignallingItem(innerItemSkyColorDaytime, this, notifyFunction, signalSkyColorDaytimeChanged);
  addItem( itemSkyColorDaytime, QStringLiteral( "SkyColorDaytime" ) );
  KConfigCompilerSignallingItem  *itemArtificialHorizonColor;
  KConfigSkeleton::ItemString  *innerItemArtificialHorizonColor;
  innerItemArtificialHorizonColor = new KConfigSkeleton::ItemString( currentGroup(), QStringLiteral( "ArtificialHorizonColor" ), mArtificialHorizonColor, QStringLiteral( "#C82828" ) );
  itemArtificialHorizonColor = new KConfigCompilerSignallingItem(innerItemArtificialHorizonColor, this, notifyFunction, signalArtificialHorizonColorChanged);
  addItem( itemArtificialHorizonColor, QStringLiteral( "ArtificialHorizonColor" ) );
  KConfigCompilerSignallingItem  *itemTelescopeTargetColor;
  KConfigSkeleton::ItemString  *innerItemTelescopeTargetColor;
  innerItemTelescopeTargetColor = new KConfigSkeleton::ItemString( currentGroup(), QStringLiteral( "TelescopeTargetColor" ), mTelescopeTargetColor, QStringLiteral( "#8B8" ) );
  itemTelescopeTargetColor = new KConfigCompilerSignallingItem(innerItemTelescopeTargetColor, this, notifyFunction, signalTelescopeTargetColorChanged);
  addItem( itemTelescopeTargetColor, QStringLiteral( "TelescopeTargetColor" ) );
  KConfigCompilerSignallingItem  *itemVisibleSatColor;
  KConfigSkeleton::ItemString  *innerItemVisibleSatColor;
  innerItemVisibleSatColor = new KConfigSkeleton::ItemString( currentGroup(), QStringLiteral( "VisibleSatColor" ), mVisibleSatColor, QStringLiteral( "#00FF00" ) );
  itemVisibleSatColor = new KConfigCompilerSignallingItem(innerItemVisibleSatColor, this, notifyFunction, signalVisibleSatColorChanged);
  addItem( itemVisibleSatColor, QStringLiteral( "VisibleSatColor" ) );
  KConfigCompilerSignallingItem  *itemSatColor;
  KConfigSkeleton::ItemString  *innerItemSatColor;
  innerItemSatColor = new KConfigSkeleton::ItemString( currentGroup(), QStringLiteral( "SatColor" ), mSatColor, QStringLiteral( "#FF0000" ) );
  itemSatColor = new KConfigCompilerSignallingItem(innerItemSatColor, this, notifyFunction, signalSatColorChanged);
  addItem( itemSatColor, QStringLiteral( "SatColor" ) );
  KConfigCompilerSignallingItem  *itemSatLabelColor;
  KConfigSkeleton::ItemString  *innerItemSatLabelColor;
  innerItemSatLabelColor = new KConfigSkeleton::ItemString( currentGroup(), QStringLiteral( "SatLabelColor" ), mSatLabelColor, QStringLiteral( "#640000" ) );
  itemSatLabelColor = new KConfigCompilerSignallingItem(innerItemSatLabelColor, this, notifyFunction, signalSatLabelColorChanged);
  addItem( itemSatLabelColor, QStringLiteral( "SatLabelColor" ) );
  KConfigCompilerSignallingItem  *itemSupernovaColor;
  KConfigSkeleton::ItemString  *innerItemSupernovaColor;
  innerItemSupernovaColor = new KConfigSkeleton::ItemString( currentGroup(), QStringLiteral( "SupernovaColor" ), mSupernovaColor, QStringLiteral( "#FFA500" ) );
  itemSupernovaColor = new KConfigCompilerSignallingItem(innerItemSupernovaColor, this, notifyFunction, signalSupernovaColorChanged);
  addItem( itemSupernovaColor, QStringLiteral( "SupernovaColor" ) );
  KConfigCompilerSignallingItem  *itemAsteroidColor;
  KConfigSkeleton::ItemString  *innerItemAsteroidColor;
  innerItemAsteroidColor = new KConfigSkeleton::ItemString( currentGroup(), QStringLiteral( "AsteroidColor" ), mAsteroidColor, QStringLiteral( "#F1C232" ) );
  itemAsteroidColor = new KConfigCompilerSignallingItem(innerItemAsteroidColor, this, notifyFunction, signalAsteroidColorChanged);
  addItem( itemAsteroidColor, QStringLiteral( "AsteroidColor" ) );
  KConfigCompilerSignallingItem  *itemUserLabelColor;
  KConfigSkeleton::ItemString  *innerItemUserLabelColor;
  innerItemUserLabelColor = new KConfigSkeleton::ItemString( currentGroup(), QStringLiteral( "UserLabelColor" ), mUserLabelColor, QStringLiteral( "#439" ) );
  itemUserLabelColor = new KConfigCompilerSignallingItem(innerItemUserLabelColor, this, notifyFunction, signalUserLabelColorChanged);
  addItem( itemUserLabelColor, QStringLiteral( "UserLabelColor" ) );
  KConfigCompilerSignallingItem  *itemRAGuideColor;
  KConfigSkeleton::ItemString  *innerItemRAGuideColor;
  innerItemRAGuideColor = new KConfigSkeleton::ItemString( currentGroup(), QStringLiteral( "RAGuideColor" ), mRAGuideColor, QStringLiteral( "#00FF00" ) );
  itemRAGuideColor = new KConfigCompilerSignallingItem(innerItemRAGuideColor, this, notifyFunction, signalRAGuideColorChanged);
  addItem( itemRAGuideColor, QStringLiteral( "RAGuideColor" ) );
  KConfigCompilerSignallingItem  *itemDEGuideColor;
  KConfigSkeleton::ItemString  *innerItemDEGuideColor;
  innerItemDEGuideColor = new KConfigSkeleton::ItemString( currentGroup(), QStringLiteral( "DEGuideColor" ), mDEGuideColor, QStringLiteral( "#00A5FF" ) );
  itemDEGuideColor = new KConfigCompilerSignallingItem(innerItemDEGuideColor, this, notifyFunction, signalDEGuideColorChanged);
  addItem( itemDEGuideColor, QStringLiteral( "DEGuideColor" ) );
  KConfigCompilerSignallingItem  *itemSolverFOVColor;
  KConfigSkeleton::ItemString  *innerItemSolverFOVColor;
  innerItemSolverFOVColor = new KConfigSkeleton::ItemString( currentGroup(), QStringLiteral( "SolverFOVColor" ), mSolverFOVColor, QStringLiteral( "#FFFF00" ) );
  itemSolverFOVColor = new KConfigCompilerSignallingItem(innerItemSolverFOVColor, this, notifyFunction, signalSolverFOVColorChanged);
  addItem( itemSolverFOVColor, QStringLiteral( "SolverFOVColor" ) );

  setCurrentGroup( QStringLiteral( "Xplanet" ) );

  KConfigCompilerSignallingItem  *itemXplanetIsInternal;
  KConfigSkeleton::ItemBool  *innerItemXplanetIsInternal;
  innerItemXplanetIsInternal = new KConfigSkeleton::ItemBool( currentGroup(), QStringLiteral( "xplanetIsInternal" ), mXplanetIsInternal, false );
  itemXplanetIsInternal = new KConfigCompilerSignallingItem(innerItemXplanetIsInternal, this, notifyFunction, signalXplanetIsInternalChanged);
  addItem( itemXplanetIsInternal, QStringLiteral( "xplanetIsInternal" ) );
  KConfigCompilerSignallingItem  *itemXplanetPath;
  KConfigSkeleton::ItemString  *innerItemXplanetPath;
  innerItemXplanetPath = new KConfigSkeleton::ItemString( currentGroup(), QStringLiteral( "XplanetPath" ), mXplanetPath, KSUtils::getDefaultPath("XplanetPath") );
  itemXplanetPath = new KConfigCompilerSignallingItem(innerItemXplanetPath, this, notifyFunction, signalXplanetPathChanged);
  addItem( itemXplanetPath, QStringLiteral( "XplanetPath" ) );
  KConfigCompilerSignallingItem  *itemXplanetUseFIFO;
  KConfigSkeleton::ItemBool  *innerItemXplanetUseFIFO;
  innerItemXplanetUseFIFO = new KConfigSkeleton::ItemBool( currentGroup(), QStringLiteral( "XplanetUseFIFO" ), mXplanetUseFIFO, true );
  itemXplanetUseFIFO = new KConfigCompilerSignallingItem(innerItemXplanetUseFIFO, this, notifyFunction, signalXplanetUseFIFOChanged);
  addItem( itemXplanetUseFIFO, QStringLiteral( "XplanetUseFIFO" ) );
  KConfigCompilerSignallingItem  *itemXplanetTimeout;
  KConfigSkeleton::ItemUInt  *innerItemXplanetTimeout;
  innerItemXplanetTimeout = new KConfigSkeleton::ItemUInt( currentGroup(), QStringLiteral( "XplanetTimeout" ), mXplanetTimeout, 1000 );
  itemXplanetTimeout = new KConfigCompilerSignallingItem(innerItemXplanetTimeout, this, notifyFunction, signalXplanetTimeoutChanged);
  addItem( itemXplanetTimeout, QStringLiteral( "XplanetTimeout" ) );
  KConfigCompilerSignallingItem  *itemXplanetAnimationDelay;
  KConfigSkeleton::ItemUInt  *innerItemXplanetAnimationDelay;
  innerItemXplanetAnimationDelay = new KConfigSkeleton::ItemUInt( currentGroup(), QStringLiteral( "XplanetAnimationDelay" ), mXplanetAnimationDelay, 100 );
  itemXplanetAnimationDelay = new KConfigCompilerSignallingItem(innerItemXplanetAnimationDelay, this, notifyFunction, signalXplanetAnimationDelayChanged);
  addItem( itemXplanetAnimationDelay, QStringLiteral( "XplanetAnimationDelay" ) );
  KConfigCompilerSignallingItem  *itemXplanetWidth;
  KConfigSkeleton::ItemUInt  *innerItemXplanetWidth;
  innerItemXplanetWidth = new KConfigSkeleton::ItemUInt( currentGroup(), QStringLiteral( "XplanetWidth" ), mXplanetWidth, 640 );
  itemXplanetWidth = new KConfigCompilerSignallingItem(innerItemXplanetWidth, this, notifyFunction, signalXplanetWidthChanged);
  addItem( itemXplanetWidth, QStringLiteral( "XplanetWidth" ) );
  KConfigCompilerSignallingItem  *itemXplanetHeight;
  KConfigSkeleton::ItemUInt  *innerItemXplanetHeight;
  innerItemXplanetHeight = new KConfigSkeleton::ItemUInt( currentGroup(), QStringLiteral( "XplanetHeight" ), mXplanetHeight, 480 );
  itemXplanetHeight = new KConfigCompilerSignallingItem(innerItemXplanetHeight, this, notifyFunction, signalXplanetHeightChanged);
  addItem( itemXplanetHeight, QStringLiteral( "XplanetHeight" ) );
  KConfigCompilerSignallingItem  *itemXplanetLabel;
  KConfigSkeleton::ItemBool  *innerItemXplanetLabel;
  innerItemXplanetLabel = new KConfigSkeleton::ItemBool( currentGroup(), QStringLiteral( "XplanetLabel" ), mXplanetLabel, false );
  itemXplanetLabel = new KConfigCompilerSignallingItem(innerItemXplanetLabel, this, notifyFunction, signalXplanetLabelChanged);
  addItem( itemXplanetLabel, QStringLiteral( "XplanetLabel" ) );
  KConfigCompilerSignallingItem  *itemXplanetLabelLocalTime;
  KConfigSkeleton::ItemBool  *innerItemXplanetLabelLocalTime;
  innerItemXplanetLabelLocalTime = new KConfigSkeleton::ItemBool( currentGroup(), QStringLiteral( "XplanetLabelLocalTime" ), mXplanetLabelLocalTime, true );
  itemXplanetLabelLocalTime = new KConfigCompilerSignallingItem(innerItemXplanetLabelLocalTime, this, notifyFunction, signalXplanetLabelLocalTimeChanged);
  addItem( itemXplanetLabelLocalTime, QStringLiteral( "XplanetLabelLocalTime" ) );
  KConfigCompilerSignallingItem  *itemXplanetLabelGMT;
  KConfigSkeleton::ItemBool  *innerItemXplanetLabelGMT;
  innerItemXplanetLabelGMT = new KConfigSkeleton::ItemBool( currentGroup(), QStringLiteral( "XplanetLabelGMT" ), mXplanetLabelGMT, false );
  itemXplanetLabelGMT = new KConfigCompilerSignallingItem(innerItemXplanetLabelGMT, this, notifyFunction, signalXplanetLabelGMTChanged);
  addItem( itemXplanetLabelGMT, QStringLiteral( "XplanetLabelGMT" ) );
  KConfigCompilerSignallingItem  *itemXplanetLabelString;
  KConfigSkeleton::ItemString  *innerItemXplanetLabelString;
  innerItemXplanetLabelString = new KConfigSkeleton::ItemString( currentGroup(), QStringLiteral( "XplanetLabelString" ), mXplanetLabelString );
  itemXplanetLabelString = new KConfigCompilerSignallingItem(innerItemXplanetLabelString, this, notifyFunction, signalXplanetLabelStringChanged);
  addItem( itemXplanetLabelString, QStringLiteral( "XplanetLabelString" ) );
  KConfigCompilerSignallingItem  *itemXplanetFontSize;
  KConfigSkeleton::ItemString  *innerItemXplanetFontSize;
  innerItemXplanetFontSize = new KConfigSkeleton::ItemString( currentGroup(), QStringLiteral( "XplanetFontSize" ), mXplanetFontSize, QStringLiteral( "12" ) );
  itemXplanetFontSize = new KConfigCompilerSignallingItem(innerItemXplanetFontSize, this, notifyFunction, signalXplanetFontSizeChanged);
  addItem( itemXplanetFontSize, QStringLiteral( "XplanetFontSize" ) );
  KConfigCompilerSignallingItem  *itemXplanetColor;
  KConfigSkeleton::ItemString  *innerItemXplanetColor;
  innerItemXplanetColor = new KConfigSkeleton::ItemString( currentGroup(), QStringLiteral( "XplanetColor" ), mXplanetColor, QStringLiteral( "#F00" ) );
  itemXplanetColor = new KConfigCompilerSignallingItem(innerItemXplanetColor, this, notifyFunction, signalXplanetColorChanged);
  addItem( itemXplanetColor, QStringLiteral( "XplanetColor" ) );
  KConfigCompilerSignallingItem  *itemXplanetDateFormat;
  KConfigSkeleton::ItemString  *innerItemXplanetDateFormat;
  innerItemXplanetDateFormat = new KConfigSkeleton::ItemString( currentGroup(), QStringLiteral( "XplanetDateFormat" ), mXplanetDateFormat, QStringLiteral( "%c %Z" ) );
  itemXplanetDateFormat = new KConfigCompilerSignallingItem(innerItemXplanetDateFormat, this, notifyFunction, signalXplanetDateFormatChanged);
  addItem( itemXplanetDateFormat, QStringLiteral( "XplanetDateFormat" ) );
  KConfigCompilerSignallingItem  *itemXplanetLabelTL;
  KConfigSkeleton::ItemBool  *innerItemXplanetLabelTL;
  innerItemXplanetLabelTL = new KConfigSkeleton::ItemBool( currentGroup(), QStringLiteral( "XplanetLabelTL" ), mXplanetLabelTL, false );
  itemXplanetLabelTL = new KConfigCompilerSignallingItem(innerItemXplanetLabelTL, this, notifyFunction, signalXplanetLabelTLChanged);
  addItem( itemXplanetLabelTL, QStringLiteral( "XplanetLabelTL" ) );
  KConfigCompilerSignallingItem  *itemXplanetLabelTR;
  KConfigSkeleton::ItemBool  *innerItemXplanetLabelTR;
  innerItemXplanetLabelTR = new KConfigSkeleton::ItemBool( currentGroup(), QStringLiteral( "XplanetLabelTR" ), mXplanetLabelTR, true );
  itemXplanetLabelTR = new KConfigCompilerSignallingItem(innerItemXplanetLabelTR, this, notifyFunction, signalXplanetLabelTRChanged);
  addItem( itemXplanetLabelTR, QStringLiteral( "XplanetLabelTR" ) );
  KConfigCompilerSignallingItem  *itemXplanetLabelBR;
  KConfigSkeleton::ItemBool  *innerItemXplanetLabelBR;
  innerItemXplanetLabelBR = new KConfigSkeleton::ItemBool( currentGroup(), QStringLiteral( "XplanetLabelBR" ), mXplanetLabelBR, false );
  itemXplanetLabelBR = new KConfigCompilerSignallingItem(innerItemXplanetLabelBR, this, notifyFunction, signalXplanetLabelBRChanged);
  addItem( itemXplanetLabelBR, QStringLiteral( "XplanetLabelBR" ) );
  KConfigCompilerSignallingItem  *itemXplanetLabelBL;
  KConfigSkeleton::ItemBool  *innerItemXplanetLabelBL;
  innerItemXplanetLabelBL = new KConfigSkeleton::ItemBool( currentGroup(), QStringLiteral( "XplanetLabelBL" ), mXplanetLabelBL, false );
  itemXplanetLabelBL = new KConfigCompilerSignallingItem(innerItemXplanetLabelBL, this, notifyFunction, signalXplanetLabelBLChanged);
  addItem( itemXplanetLabelBL, QStringLiteral( "XplanetLabelBL" ) );
  KConfigCompilerSignallingItem  *itemXplanetGlare;
  KConfigSkeleton::ItemString  *innerItemXplanetGlare;
  innerItemXplanetGlare = new KConfigSkeleton::ItemString( currentGroup(), QStringLiteral( "XplanetGlare" ), mXplanetGlare, QStringLiteral( "28" ) );
  itemXplanetGlare = new KConfigCompilerSignallingItem(innerItemXplanetGlare, this, notifyFunction, signalXplanetGlareChanged);
  addItem( itemXplanetGlare, QStringLiteral( "XplanetGlare" ) );
  KConfigCompilerSignallingItem  *itemXplanetRandom;
  KConfigSkeleton::ItemBool  *innerItemXplanetRandom;
  innerItemXplanetRandom = new KConfigSkeleton::ItemBool( currentGroup(), QStringLiteral( "XplanetRandom" ), mXplanetRandom, false );
  itemXplanetRandom = new KConfigCompilerSignallingItem(innerItemXplanetRandom, this, notifyFunction, signalXplanetRandomChanged);
  addItem( itemXplanetRandom, QStringLiteral( "XplanetRandom" ) );
  KConfigCompilerSignallingItem  *itemXplanetLatLong;
  KConfigSkeleton::ItemBool  *innerItemXplanetLatLong;
  innerItemXplanetLatLong = new KConfigSkeleton::ItemBool( currentGroup(), QStringLiteral( "XplanetLatLong" ), mXplanetLatLong, true );
  itemXplanetLatLong = new KConfigCompilerSignallingItem(innerItemXplanetLatLong, this, notifyFunction, signalXplanetLatLongChanged);
  addItem( itemXplanetLatLong, QStringLiteral( "XplanetLatLong" ) );
  KConfigCompilerSignallingItem  *itemXplanetLatitude;
  KConfigSkeleton::ItemString  *innerItemXplanetLatitude;
  innerItemXplanetLatitude = new KConfigSkeleton::ItemString( currentGroup(), QStringLiteral( "XplanetLatitude" ), mXplanetLatitude, QStringLiteral( "0" ) );
  itemXplanetLatitude = new KConfigCompilerSignallingItem(innerItemXplanetLatitude, this, notifyFunction, signalXplanetLatitudeChanged);
  addItem( itemXplanetLatitude, QStringLiteral( "XplanetLatitude" ) );
  KConfigCompilerSignallingItem  *itemXplanetLongitude;
  KConfigSkeleton::ItemString  *innerItemXplanetLongitude;
  innerItemXplanetLongitude = new KConfigSkeleton::ItemString( currentGroup(), QStringLiteral( "XplanetLongitude" ), mXplanetLongitude, QStringLiteral( "0" ) );
  itemXplanetLongitude = new KConfigCompilerSignallingItem(innerItemXplanetLongitude, this, notifyFunction, signalXplanetLongitudeChanged);
  addItem( itemXplanetLongitude, QStringLiteral( "XplanetLongitude" ) );
  KConfigCompilerSignallingItem  *itemXplanetProjection;
  KConfigSkeleton::ItemUInt  *innerItemXplanetProjection;
  innerItemXplanetProjection = new KConfigSkeleton::ItemUInt( currentGroup(), QStringLiteral( "XplanetProjection" ), mXplanetProjection, 0 );
  itemXplanetProjection = new KConfigCompilerSignallingItem(innerItemXplanetProjection, this, notifyFunction, signalXplanetProjectionChanged);
  addItem( itemXplanetProjection, QStringLiteral( "XplanetProjection" ) );
  KConfigCompilerSignallingItem  *itemXplanetBackground;
  KConfigSkeleton::ItemBool  *innerItemXplanetBackground;
  innerItemXplanetBackground = new KConfigSkeleton::ItemBool( currentGroup(), QStringLiteral( "XplanetBackground" ), mXplanetBackground, false );
  itemXplanetBackground = new KConfigCompilerSignallingItem(innerItemXplanetBackground, this, notifyFunction, signalXplanetBackgroundChanged);
  addItem( itemXplanetBackground, QStringLiteral( "XplanetBackground" ) );
  KConfigCompilerSignallingItem  *itemXplanetBackgroundImage;
  KConfigSkeleton::ItemBool  *innerItemXplanetBackgroundImage;
  innerItemXplanetBackgroundImage = new KConfigSkeleton::ItemBool( currentGroup(), QStringLiteral( "XplanetBackgroundImage" ), mXplanetBackgroundImage, false );
  itemXplanetBackgroundImage = new KConfigCompilerSignallingItem(innerItemXplanetBackgroundImage, this, notifyFunction, signalXplanetBackgroundImageChanged);
  addItem( itemXplanetBackgroundImage, QStringLiteral( "XplanetBackgroundImage" ) );
  KConfigCompilerSignallingItem  *itemXplanetBackgroundImagePath;
  KConfigSkeleton::ItemString  *innerItemXplanetBackgroundImagePath;
  innerItemXplanetBackgroundImagePath = new KConfigSkeleton::ItemString( currentGroup(), QStringLiteral( "XplanetBackgroundImagePath" ), mXplanetBackgroundImagePath );
  itemXplanetBackgroundImagePath = new KConfigCompilerSignallingItem(innerItemXplanetBackgroundImagePath, this, notifyFunction, signalXplanetBackgroundImagePathChanged);
  addItem( itemXplanetBackgroundImagePath, QStringLiteral( "XplanetBackgroundImagePath" ) );
  KConfigCompilerSignallingItem  *itemXplanetBackgroundColor;
  KConfigSkeleton::ItemBool  *innerItemXplanetBackgroundColor;
  innerItemXplanetBackgroundColor = new KConfigSkeleton::ItemBool( currentGroup(), QStringLiteral( "XplanetBackgroundColor" ), mXplanetBackgroundColor, true );
  itemXplanetBackgroundColor = new KConfigCompilerSignallingItem(innerItemXplanetBackgroundColor, this, notifyFunction, signalXplanetBackgroundColorChanged);
  addItem( itemXplanetBackgroundColor, QStringLiteral( "XplanetBackgroundColor" ) );
  KConfigCompilerSignallingItem  *itemXplanetBackgroundColorValue;
  KConfigSkeleton::ItemString  *innerItemXplanetBackgroundColorValue;
  innerItemXplanetBackgroundColorValue = new KConfigSkeleton::ItemString( currentGroup(), QStringLiteral( "XplanetBackgroundColorValue" ), mXplanetBackgroundColorValue, QStringLiteral( "#000" ) );
  itemXplanetBackgroundColorValue = new KConfigCompilerSignallingItem(innerItemXplanetBackgroundColorValue, this, notifyFunction, signalXplanetBackgroundColorValueChanged);
  addItem( itemXplanetBackgroundColorValue, QStringLiteral( "XplanetBackgroundColorValue" ) );
  KConfigCompilerSignallingItem  *itemXplanetMagnitude;
  KConfigSkeleton::ItemString  *innerItemXplanetMagnitude;
  innerItemXplanetMagnitude = new KConfigSkeleton::ItemString( currentGroup(), QStringLiteral( "XplanetMagnitude" ), mXplanetMagnitude, QStringLiteral( "10" ) );
  itemXplanetMagnitude = new KConfigCompilerSignallingItem(innerItemXplanetMagnitude, this, notifyFunction, signalXplanetMagnitudeChanged);
  addItem( itemXplanetMagnitude, QStringLiteral( "XplanetMagnitude" ) );
  KConfigCompilerSignallingItem  *itemXplanetArcFile;
  KConfigSkeleton::ItemBool  *innerItemXplanetArcFile;
  innerItemXplanetArcFile = new KConfigSkeleton::ItemBool( currentGroup(), QStringLiteral( "XplanetArcFile" ), mXplanetArcFile, false );
  itemXplanetArcFile = new KConfigCompilerSignallingItem(innerItemXplanetArcFile, this, notifyFunction, signalXplanetArcFileChanged);
  addItem( itemXplanetArcFile, QStringLiteral( "XplanetArcFile" ) );
  KConfigCompilerSignallingItem  *itemXplanetArcFilePath;
  KConfigSkeleton::ItemString  *innerItemXplanetArcFilePath;
  innerItemXplanetArcFilePath = new KConfigSkeleton::ItemString( currentGroup(), QStringLiteral( "XplanetArcFilePath" ), mXplanetArcFilePath );
  itemXplanetArcFilePath = new KConfigCompilerSignallingItem(innerItemXplanetArcFilePath, this, notifyFunction, signalXplanetArcFilePathChanged);
  addItem( itemXplanetArcFilePath, QStringLiteral( "XplanetArcFilePath" ) );
  KConfigCompilerSignallingItem  *itemXplanetConfigFile;
  KConfigSkeleton::ItemBool  *innerItemXplanetConfigFile;
  innerItemXplanetConfigFile = new KConfigSkeleton::ItemBool( currentGroup(), QStringLiteral( "XplanetConfigFile" ), mXplanetConfigFile, false );
  itemXplanetConfigFile = new KConfigCompilerSignallingItem(innerItemXplanetConfigFile, this, notifyFunction, signalXplanetConfigFileChanged);
  addItem( itemXplanetConfigFile, QStringLiteral( "XplanetConfigFile" ) );
  KConfigCompilerSignallingItem  *itemXplanetConfigFilePath;
  KConfigSkeleton::ItemString  *innerItemXplanetConfigFilePath;
  innerItemXplanetConfigFilePath = new KConfigSkeleton::ItemString( currentGroup(), QStringLiteral( "XplanetConfigFilePath" ), mXplanetConfigFilePath );
  itemXplanetConfigFilePath = new KConfigCompilerSignallingItem(innerItemXplanetConfigFilePath, this, notifyFunction, signalXplanetConfigFilePathChanged);
  addItem( itemXplanetConfigFilePath, QStringLiteral( "XplanetConfigFilePath" ) );
  KConfigCompilerSignallingItem  *itemXplanetFOV;
  KConfigSkeleton::ItemBool  *innerItemXplanetFOV;
  innerItemXplanetFOV = new KConfigSkeleton::ItemBool( currentGroup(), QStringLiteral( "XplanetFOV" ), mXplanetFOV, false );
  itemXplanetFOV = new KConfigCompilerSignallingItem(innerItemXplanetFOV, this, notifyFunction, signalXplanetFOVChanged);
  addItem( itemXplanetFOV, QStringLiteral( "XplanetFOV" ) );
  KConfigCompilerSignallingItem  *itemXplanetMarkerFile;
  KConfigSkeleton::ItemBool  *innerItemXplanetMarkerFile;
  innerItemXplanetMarkerFile = new KConfigSkeleton::ItemBool( currentGroup(), QStringLiteral( "XplanetMarkerFile" ), mXplanetMarkerFile, false );
  itemXplanetMarkerFile = new KConfigCompilerSignallingItem(innerItemXplanetMarkerFile, this, notifyFunction, signalXplanetMarkerFileChanged);
  addItem( itemXplanetMarkerFile, QStringLiteral( "XplanetMarkerFile" ) );
  KConfigCompilerSignallingItem  *itemXplanetMarkerFilePath;
  KConfigSkeleton::ItemString  *innerItemXplanetMarkerFilePath;
  innerItemXplanetMarkerFilePath = new KConfigSkeleton::ItemString( currentGroup(), QStringLiteral( "XplanetMarkerFilePath" ), mXplanetMarkerFilePath );
  itemXplanetMarkerFilePath = new KConfigCompilerSignallingItem(innerItemXplanetMarkerFilePath, this, notifyFunction, signalXplanetMarkerFilePathChanged);
  addItem( itemXplanetMarkerFilePath, QStringLiteral( "XplanetMarkerFilePath" ) );
  KConfigCompilerSignallingItem  *itemXplanetMarkerBounds;
  KConfigSkeleton::ItemBool  *innerItemXplanetMarkerBounds;
  innerItemXplanetMarkerBounds = new KConfigSkeleton::ItemBool( currentGroup(), QStringLiteral( "XplanetMarkerBounds" ), mXplanetMarkerBounds, false );
  itemXplanetMarkerBounds = new KConfigCompilerSignallingItem(innerItemXplanetMarkerBounds, this, notifyFunction, signalXplanetMarkerBoundsChanged);
  addItem( itemXplanetMarkerBounds, QStringLiteral( "XplanetMarkerBounds" ) );
  KConfigCompilerSignallingItem  *itemXplanetMarkerBoundsPath;
  KConfigSkeleton::ItemString  *innerItemXplanetMarkerBoundsPath;
  innerItemXplanetMarkerBoundsPath = new KConfigSkeleton::ItemString( currentGroup(), QStringLiteral( "XplanetMarkerBoundsPath" ), mXplanetMarkerBoundsPath );
  itemXplanetMarkerBoundsPath = new KConfigCompilerSignallingItem(innerItemXplanetMarkerBoundsPath, this, notifyFunction, signalXplanetMarkerBoundsPathChanged);
  addItem( itemXplanetMarkerBoundsPath, QStringLiteral( "XplanetMarkerBoundsPath" ) );
  KConfigCompilerSignallingItem  *itemXplanetStarmap;
  KConfigSkeleton::ItemBool  *innerItemXplanetStarmap;
  innerItemXplanetStarmap = new KConfigSkeleton::ItemBool( currentGroup(), QStringLiteral( "XplanetStarmap" ), mXplanetStarmap, false );
  itemXplanetStarmap = new KConfigCompilerSignallingItem(innerItemXplanetStarmap, this, notifyFunction, signalXplanetStarmapChanged);
  addItem( itemXplanetStarmap, QStringLiteral( "XplanetStarmap" ) );
  KConfigCompilerSignallingItem  *itemXplanetStarmapPath;
  KConfigSkeleton::ItemString  *innerItemXplanetStarmapPath;
  innerItemXplanetStarmapPath = new KConfigSkeleton::ItemString( currentGroup(), QStringLiteral( "XplanetStarmapPath" ), mXplanetStarmapPath );
  itemXplanetStarmapPath = new KConfigCompilerSignallingItem(innerItemXplanetStarmapPath, this, notifyFunction, signalXplanetStarmapPathChanged);
  addItem( itemXplanetStarmapPath, QStringLiteral( "XplanetStarmapPath" ) );
  KConfigCompilerSignallingItem  *itemXplanetQuality;
  KConfigSkeleton::ItemString  *innerItemXplanetQuality;
  innerItemXplanetQuality = new KConfigSkeleton::ItemString( currentGroup(), QStringLiteral( "XplanetQuality" ), mXplanetQuality, QStringLiteral( "80" ) );
  itemXplanetQuality = new KConfigCompilerSignallingItem(innerItemXplanetQuality, this, notifyFunction, signalXplanetQualityChanged);
  addItem( itemXplanetQuality, QStringLiteral( "XplanetQuality" ) );

  setCurrentGroup( QStringLiteral( "Satellites" ) );

  KConfigCompilerSignallingItem  *itemShowSatellites;
  KConfigSkeleton::ItemBool  *innerItemShowSatellites;
  innerItemShowSatellites = new KConfigSkeleton::ItemBool( currentGroup(), QStringLiteral( "ShowSatellites" ), mShowSatellites, false );
  itemShowSatellites = new KConfigCompilerSignallingItem(innerItemShowSatellites, this, notifyFunction, signalShowSatellitesChanged);
  addItem( itemShowSatellites, QStringLiteral( "ShowSatellites" ) );
  KConfigCompilerSignallingItem  *itemShowVisibleSatellites;
  KConfigSkeleton::ItemBool  *innerItemShowVisibleSatellites;
  innerItemShowVisibleSatellites = new KConfigSkeleton::ItemBool( currentGroup(), QStringLiteral( "ShowVisibleSatellites" ), mShowVisibleSatellites, false );
  itemShowVisibleSatellites = new KConfigCompilerSignallingItem(innerItemShowVisibleSatellites, this, notifyFunction, signalShowVisibleSatellitesChanged);
  addItem( itemShowVisibleSatellites, QStringLiteral( "ShowVisibleSatellites" ) );
  KConfigCompilerSignallingItem  *itemDrawSatellitesLikeStars;
  KConfigSkeleton::ItemBool  *innerItemDrawSatellitesLikeStars;
  innerItemDrawSatellitesLikeStars = new KConfigSkeleton::ItemBool( currentGroup(), QStringLiteral( "DrawSatellitesLikeStars" ), mDrawSatellitesLikeStars, false );
  itemDrawSatellitesLikeStars = new KConfigCompilerSignallingItem(innerItemDrawSatellitesLikeStars, this, notifyFunction, signalDrawSatellitesLikeStarsChanged);
  addItem( itemDrawSatellitesLikeStars, QStringLiteral( "DrawSatellitesLikeStars" ) );
  KConfigCompilerSignallingItem  *itemShowSatellitesLabels;
  KConfigSkeleton::ItemBool  *innerItemShowSatellitesLabels;
  innerItemShowSatellitesLabels = new KConfigSkeleton::ItemBool( currentGroup(), QStringLiteral( "ShowSatellitesLabels" ), mShowSatellitesLabels, false );
  itemShowSatellitesLabels = new KConfigCompilerSignallingItem(innerItemShowSatellitesLabels, this, notifyFunction, signalShowSatellitesLabelsChanged);
  addItem( itemShowSatellitesLabels, QStringLiteral( "ShowSatellitesLabels" ) );
  KConfigCompilerSignallingItem  *itemSelectedSatellites;
  KConfigSkeleton::ItemStringList  *innerItemSelectedSatellites;
  innerItemSelectedSatellites = new KConfigSkeleton::ItemStringList( currentGroup(), QStringLiteral( "SelectedSatellites" ), mSelectedSatellites );
  itemSelectedSatellites = new KConfigCompilerSignallingItem(innerItemSelectedSatellites, this, notifyFunction, signalSelectedSatellitesChanged);
  addItem( itemSelectedSatellites, QStringLiteral( "SelectedSatellites" ) );

  setCurrentGroup( QStringLiteral( "General" ) );

  KConfigCompilerSignallingItem  *itemKStarsFirstRun;
  KConfigSkeleton::ItemBool  *innerItemKStarsFirstRun;
  innerItemKStarsFirstRun = new KConfigSkeleton::ItemBool( currentGroup(), QStringLiteral( "KStarsFirstRun" ), mKStarsFirstRun, true );
  itemKStarsFirstRun = new KConfigCompilerSignallingItem(innerItemKStarsFirstRun, this, notifyFunction, signalKStarsFirstRunChanged);
  addItem( itemKStarsFirstRun, QStringLiteral( "KStarsFirstRun" ) );
  KConfigCompilerSignallingItem  *itemAlwaysRecomputeCoordinates;
  KConfigSkeleton::ItemBool  *innerItemAlwaysRecomputeCoordinates;
  innerItemAlwaysRecomputeCoordinates = new KConfigSkeleton::ItemBool( currentGroup(), QStringLiteral( "AlwaysRecomputeCoordinates" ), mAlwaysRecomputeCoordinates, false );
  itemAlwaysRecomputeCoordinates = new KConfigCompilerSignallingItem(innerItemAlwaysRecomputeCoordinates, this, notifyFunction, signalAlwaysRecomputeCoordinatesChanged);
  addItem( itemAlwaysRecomputeCoordinates, QStringLiteral( "AlwaysRecomputeCoordinates" ) );
  KConfigCompilerSignallingItem  *itemDefaultDSSImageSize;
  KConfigSkeleton::ItemDouble  *innerItemDefaultDSSImageSize;
  innerItemDefaultDSSImageSize = new KConfigSkeleton::ItemDouble( currentGroup(), QStringLiteral( "DefaultDSSImageSize" ), mDefaultDSSImageSize, 15.0 );
  itemDefaultDSSImageSize = new KConfigCompilerSignallingItem(innerItemDefaultDSSImageSize, this, notifyFunction, signalDefaultDSSImageSizeChanged);
  addItem( itemDefaultDSSImageSize, QStringLiteral( "DefaultDSSImageSize" ) );
  KConfigCompilerSignallingItem  *itemDSSPadding;
  KConfigSkeleton::ItemDouble  *innerItemDSSPadding;
  innerItemDSSPadding = new KConfigSkeleton::ItemDouble( currentGroup(), QStringLiteral( "DSSPadding" ), mDSSPadding, 10.0 );
  itemDSSPadding = new KConfigCompilerSignallingItem(innerItemDSSPadding, this, notifyFunction, signalDSSPaddingChanged);
  addItem( itemDSSPadding, QStringLiteral( "DSSPadding" ) );
  KConfigCompilerSignallingItem  *itemVerboseLogging;
  KConfigSkeleton::ItemBool  *innerItemVerboseLogging;
  innerItemVerboseLogging = new KConfigSkeleton::ItemBool( currentGroup(), QStringLiteral( "VerboseLogging" ), mVerboseLogging, false );
  itemVerboseLogging = new KConfigCompilerSignallingItem(innerItemVerboseLogging, this, notifyFunction, signalVerboseLoggingChanged);
  addItem( itemVerboseLogging, QStringLiteral( "VerboseLogging" ) );
  KConfigCompilerSignallingItem  *itemRegularLogging;
  KConfigSkeleton::ItemBool  *innerItemRegularLogging;
  innerItemRegularLogging = new KConfigSkeleton::ItemBool( currentGroup(), QStringLiteral( "RegularLogging" ), mRegularLogging, true );
  itemRegularLogging = new KConfigCompilerSignallingItem(innerItemRegularLogging, this, notifyFunction, signalRegularLoggingChanged);
  addItem( itemRegularLogging, QStringLiteral( "RegularLogging" ) );
  KConfigCompilerSignallingItem  *itemDisableLogging;
  KConfigSkeleton::ItemBool  *innerItemDisableLogging;
  innerItemDisableLogging = new KConfigSkeleton::ItemBool( currentGroup(), QStringLiteral( "DisableLogging" ), mDisableLogging, false );
  itemDisableLogging = new KConfigCompilerSignallingItem(innerItemDisableLogging, this, notifyFunction, signalDisableLoggingChanged);
  addItem( itemDisableLogging, QStringLiteral( "DisableLogging" ) );
  KConfigCompilerSignallingItem  *itemLogToDefault;
  KConfigSkeleton::ItemBool  *innerItemLogToDefault;
  innerItemLogToDefault = new KConfigSkeleton::ItemBool( currentGroup(), QStringLiteral( "LogToDefault" ), mLogToDefault, true );
  itemLogToDefault = new KConfigCompilerSignallingItem(innerItemLogToDefault, this, notifyFunction, signalLogToDefaultChanged);
  addItem( itemLogToDefault, QStringLiteral( "LogToDefault" ) );
  KConfigCompilerSignallingItem  *itemLogToFile;
  KConfigSkeleton::ItemBool  *innerItemLogToFile;
  innerItemLogToFile = new KConfigSkeleton::ItemBool( currentGroup(), QStringLiteral( "LogToFile" ), mLogToFile, false );
  itemLogToFile = new KConfigCompilerSignallingItem(innerItemLogToFile, this, notifyFunction, signalLogToFileChanged);
  addItem( itemLogToFile, QStringLiteral( "LogToFile" ) );
  KConfigCompilerSignallingItem  *itemFITSLogging;
  KConfigSkeleton::ItemBool  *innerItemFITSLogging;
  innerItemFITSLogging = new KConfigSkeleton::ItemBool( currentGroup(), QStringLiteral( "FITSLogging" ), mFITSLogging, false );
  itemFITSLogging = new KConfigCompilerSignallingItem(innerItemFITSLogging, this, notifyFunction, signalFITSLoggingChanged);
  addItem( itemFITSLogging, QStringLiteral( "FITSLogging" ) );
  KConfigCompilerSignallingItem  *itemINDILogging;
  KConfigSkeleton::ItemBool  *innerItemINDILogging;
  innerItemINDILogging = new KConfigSkeleton::ItemBool( currentGroup(), QStringLiteral( "INDILogging" ), mINDILogging, false );
  itemINDILogging = new KConfigCompilerSignallingItem(innerItemINDILogging, this, notifyFunction, signalINDILoggingChanged);
  addItem( itemINDILogging, QStringLiteral( "INDILogging" ) );
  KConfigCompilerSignallingItem  *itemCaptureLogging;
  KConfigSkeleton::ItemBool  *innerItemCaptureLogging;
  innerItemCaptureLogging = new KConfigSkeleton::ItemBool( currentGroup(), QStringLiteral( "CaptureLogging" ), mCaptureLogging, false );
  itemCaptureLogging = new KConfigCompilerSignallingItem(innerItemCaptureLogging, this, notifyFunction, signalCaptureLoggingChanged);
  addItem( itemCaptureLogging, QStringLiteral( "CaptureLogging" ) );
  KConfigCompilerSignallingItem  *itemFocusLogging;
  KConfigSkeleton::ItemBool  *innerItemFocusLogging;
  innerItemFocusLogging = new KConfigSkeleton::ItemBool( currentGroup(), QStringLiteral( "FocusLogging" ), mFocusLogging, false );
  itemFocusLogging = new KConfigCompilerSignallingItem(innerItemFocusLogging, this, notifyFunction, signalFocusLoggingChanged);
  addItem( itemFocusLogging, QStringLiteral( "FocusLogging" ) );
  KConfigCompilerSignallingItem  *itemSaveGuideImages;
  KConfigSkeleton::ItemBool  *innerItemSaveGuideImages;
  innerItemSaveGuideImages = new KConfigSkeleton::ItemBool( currentGroup(), QStringLiteral( "SaveGuideImages" ), mSaveGuideImages, false );
  itemSaveGuideImages = new KConfigCompilerSignallingItem(innerItemSaveGuideImages, this, notifyFunction, signalSaveGuideImagesChanged);
  addItem( itemSaveGuideImages, QStringLiteral( "SaveGuideImages" ) );
  KConfigCompilerSignallingItem  *itemSaveAlignImages;
  KConfigSkeleton::ItemBool  *innerItemSaveAlignImages;
  innerItemSaveAlignImages = new KConfigSkeleton::ItemBool( currentGroup(), QStringLiteral( "SaveAlignImages" ), mSaveAlignImages, false );
  itemSaveAlignImages = new KConfigCompilerSignallingItem(innerItemSaveAlignImages, this, notifyFunction, signalSaveAlignImagesChanged);
  addItem( itemSaveAlignImages, QStringLiteral( "SaveAlignImages" ) );
  KConfigCompilerSignallingItem  *itemSaveFailedAlignImages;
  KConfigSkeleton::ItemBool  *innerItemSaveFailedAlignImages;
  innerItemSaveFailedAlignImages = new KConfigSkeleton::ItemBool( currentGroup(), QStringLiteral( "SaveFailedAlignImages" ), mSaveFailedAlignImages, false );
  itemSaveFailedAlignImages = new KConfigCompilerSignallingItem(innerItemSaveFailedAlignImages, this, notifyFunction, signalSaveFailedAlignImagesChanged);
  addItem( itemSaveFailedAlignImages, QStringLiteral( "SaveFailedAlignImages" ) );
  KConfigCompilerSignallingItem  *itemDontSyncToRealTime;
  KConfigSkeleton::ItemBool  *innerItemDontSyncToRealTime;
  innerItemDontSyncToRealTime = new KConfigSkeleton::ItemBool( currentGroup(), QStringLiteral( "DontSyncToRealTime" ), mDontSyncToRealTime, false );
  itemDontSyncToRealTime = new KConfigCompilerSignallingItem(innerItemDontSyncToRealTime, this, notifyFunction, signalDontSyncToRealTimeChanged);
  addItem( itemDontSyncToRealTime, QStringLiteral( "DontSyncToRealTime" ) );
  KConfigCompilerSignallingItem  *itemGuideLogging;
  KConfigSkeleton::ItemBool  *innerItemGuideLogging;
  innerItemGuideLogging = new KConfigSkeleton::ItemBool( currentGroup(), QStringLiteral( "GuideLogging" ), mGuideLogging, false );
  itemGuideLogging = new KConfigCompilerSignallingItem(innerItemGuideLogging, this, notifyFunction, signalGuideLoggingChanged);
  addItem( itemGuideLogging, QStringLiteral( "GuideLogging" ) );
  KConfigCompilerSignallingItem  *itemAlignmentLogging;
  KConfigSkeleton::ItemBool  *innerItemAlignmentLogging;
  innerItemAlignmentLogging = new KConfigSkeleton::ItemBool( currentGroup(), QStringLiteral( "AlignmentLogging" ), mAlignmentLogging, false );
  itemAlignmentLogging = new KConfigCompilerSignallingItem(innerItemAlignmentLogging, this, notifyFunction, signalAlignmentLoggingChanged);
  addItem( itemAlignmentLogging, QStringLiteral( "AlignmentLogging" ) );
  KConfigCompilerSignallingItem  *itemMountLogging;
  KConfigSkeleton::ItemBool  *innerItemMountLogging;
  innerItemMountLogging = new KConfigSkeleton::ItemBool( currentGroup(), QStringLiteral( "MountLogging" ), mMountLogging, false );
  itemMountLogging = new KConfigCompilerSignallingItem(innerItemMountLogging, this, notifyFunction, signalMountLoggingChanged);
  addItem( itemMountLogging, QStringLiteral( "MountLogging" ) );
  KConfigCompilerSignallingItem  *itemObservatoryLogging;
  KConfigSkeleton::ItemBool  *innerItemObservatoryLogging;
  innerItemObservatoryLogging = new KConfigSkeleton::ItemBool( currentGroup(), QStringLiteral( "ObservatoryLogging" ), mObservatoryLogging, false );
  itemObservatoryLogging = new KConfigCompilerSignallingItem(innerItemObservatoryLogging, this, notifyFunction, signalObservatoryLoggingChanged);
  addItem( itemObservatoryLogging, QStringLiteral( "ObservatoryLogging" ) );
  KConfigCompilerSignallingItem  *itemImageDebayerEngine;
  KConfigSkeleton::ItemInt  *innerItemImageDebayerEngine;
  innerItemImageDebayerEngine = new KConfigSkeleton::ItemInt( currentGroup(), QStringLiteral( "ImageDebayerEngine" ), mImageDebayerEngine, 1 );
  itemImageDebayerEngine = new KConfigCompilerSignallingItem(innerItemImageDebayerEngine, this, notifyFunction, signalImageDebayerEngineChanged);
  addItem( itemImageDebayerEngine, QStringLiteral( "ImageDebayerEngine" ) );
  KConfigCompilerSignallingItem  *itemImageDebayerAlgo;
  KConfigSkeleton::ItemInt  *innerItemImageDebayerAlgo;
  innerItemImageDebayerAlgo = new KConfigSkeleton::ItemInt( currentGroup(), QStringLiteral( "ImageDebayerAlgo" ), mImageDebayerAlgo, 2 );
  itemImageDebayerAlgo = new KConfigCompilerSignallingItem(innerItemImageDebayerAlgo, this, notifyFunction, signalImageDebayerAlgoChanged);
  addItem( itemImageDebayerAlgo, QStringLiteral( "ImageDebayerAlgo" ) );
  KConfigCompilerSignallingItem  *itemStackDebayerEngine;
  KConfigSkeleton::ItemInt  *innerItemStackDebayerEngine;
  innerItemStackDebayerEngine = new KConfigSkeleton::ItemInt( currentGroup(), QStringLiteral( "StackDebayerEngine" ), mStackDebayerEngine, 1 );
  itemStackDebayerEngine = new KConfigCompilerSignallingItem(innerItemStackDebayerEngine, this, notifyFunction, signalStackDebayerEngineChanged);
  addItem( itemStackDebayerEngine, QStringLiteral( "StackDebayerEngine" ) );
  KConfigCompilerSignallingItem  *itemStackDebayerAlgo;
  KConfigSkeleton::ItemInt  *innerItemStackDebayerAlgo;
  innerItemStackDebayerAlgo = new KConfigSkeleton::ItemInt( currentGroup(), QStringLiteral( "StackDebayerAlgo" ), mStackDebayerAlgo, 2 );
  itemStackDebayerAlgo = new KConfigCompilerSignallingItem(innerItemStackDebayerAlgo, this, notifyFunction, signalStackDebayerAlgoChanged);
  addItem( itemStackDebayerAlgo, QStringLiteral( "StackDebayerAlgo" ) );

  setCurrentGroup( QStringLiteral( "FITSViewer" ) );

  KConfigCompilerSignallingItem  *itemFITSWindowGeometry;
  KConfigSkeleton::ItemString  *innerItemFITSWindowGeometry;
  innerItemFITSWindowGeometry = new KConfigSkeleton::ItemString( currentGroup(), QStringLiteral( "FITSWindowGeometry" ), mFITSWindowGeometry );
  itemFITSWindowGeometry = new KConfigCompilerSignallingItem(innerItemFITSWindowGeometry, this, notifyFunction, signalFITSWindowGeometryChanged);
  addItem( itemFITSWindowGeometry, QStringLiteral( "FITSWindowGeometry" ) );
  KConfigCompilerSignallingItem  *itemUseFITSViewer;
  KConfigSkeleton::ItemBool  *innerItemUseFITSViewer;
  innerItemUseFITSViewer = new KConfigSkeleton::ItemBool( currentGroup(), QStringLiteral( "useFITSViewer" ), mUseFITSViewer, true );
  itemUseFITSViewer = new KConfigCompilerSignallingItem(innerItemUseFITSViewer, this, notifyFunction, signalUseFITSViewerChanged);
  addItem( itemUseFITSViewer, QStringLiteral( "useFITSViewer" ) );
  KConfigCompilerSignallingItem  *itemSinglePreviewFITS;
  KConfigSkeleton::ItemBool  *innerItemSinglePreviewFITS;
  innerItemSinglePreviewFITS = new KConfigSkeleton::ItemBool( currentGroup(), QStringLiteral( "singlePreviewFITS" ), mSinglePreviewFITS, true );
  itemSinglePreviewFITS = new KConfigCompilerSignallingItem(innerItemSinglePreviewFITS, this, notifyFunction, signalSinglePreviewFITSChanged);
  addItem( itemSinglePreviewFITS, QStringLiteral( "singlePreviewFITS" ) );
  KConfigCompilerSignallingItem  *itemSingleWindowCapturedFITS;
  KConfigSkeleton::ItemBool  *innerItemSingleWindowCapturedFITS;
  innerItemSingleWindowCapturedFITS = new KConfigSkeleton::ItemBool( currentGroup(), QStringLiteral( "singleWindowCapturedFITS" ), mSingleWindowCapturedFITS, false );
  itemSingleWindowCapturedFITS = new KConfigCompilerSignallingItem(innerItemSingleWindowCapturedFITS, this, notifyFunction, signalSingleWindowCapturedFITSChanged);
  addItem( itemSingleWindowCapturedFITS, QStringLiteral( "singleWindowCapturedFITS" ) );
  KConfigCompilerSignallingItem  *itemSingleWindowOpenedFITS;
  KConfigSkeleton::ItemBool  *innerItemSingleWindowOpenedFITS;
  innerItemSingleWindowOpenedFITS = new KConfigSkeleton::ItemBool( currentGroup(), QStringLiteral( "singleWindowOpenedFITS" ), mSingleWindowOpenedFITS, true );
  itemSingleWindowOpenedFITS = new KConfigCompilerSignallingItem(innerItemSingleWindowOpenedFITS, this, notifyFunction, signalSingleWindowOpenedFITSChanged);
  addItem( itemSingleWindowOpenedFITS, QStringLiteral( "singleWindowOpenedFITS" ) );
  KConfigCompilerSignallingItem  *itemFocusFITSOnNewImage;
  KConfigSkeleton::ItemBool  *innerItemFocusFITSOnNewImage;
  innerItemFocusFITSOnNewImage = new KConfigSkeleton::ItemBool( currentGroup(), QStringLiteral( "focusFITSOnNewImage" ), mFocusFITSOnNewImage, true );
  itemFocusFITSOnNewImage = new KConfigCompilerSignallingItem(innerItemFocusFITSOnNewImage, this, notifyFunction, signalFocusFITSOnNewImageChanged);
  addItem( itemFocusFITSOnNewImage, QStringLiteral( "focusFITSOnNewImage" ) );
  KConfigCompilerSignallingItem  *itemIndependentWindowFITS;
  KConfigSkeleton::ItemBool  *innerItemIndependentWindowFITS;
  innerItemIndependentWindowFITS = new KConfigSkeleton::ItemBool( currentGroup(), QStringLiteral( "independentWindowFITS" ), mIndependentWindowFITS, false );
  itemIndependentWindowFITS = new KConfigCompilerSignallingItem(innerItemIndependentWindowFITS, this, notifyFunction, signalIndependentWindowFITSChanged);
  addItem( itemIndependentWindowFITS, QStringLiteral( "independentWindowFITS" ) );
  KConfigCompilerSignallingItem  *itemLiveStackerOwnProcess;
  KConfigSkeleton::ItemBool  *innerItemLiveStackerOwnProcess;
  innerItemLiveStackerOwnProcess = new KConfigSkeleton::ItemBool( currentGroup(), QStringLiteral( "liveStackerOwnProcess" ), mLiveStackerOwnProcess, false );
  itemLiveStackerOwnProcess = new KConfigCompilerSignallingItem(innerItemLiveStackerOwnProcess, this, notifyFunction, signalLiveStackerOwnProcessChanged);
  addItem( itemLiveStackerOwnProcess, QStringLiteral( "liveStackerOwnProcess" ) );
  KConfigCompilerSignallingItem  *itemAutoDebayer;
  KConfigSkeleton::ItemBool  *innerItemAutoDebayer;
  innerItemAutoDebayer = new KConfigSkeleton::ItemBool( currentGroup(), QStringLiteral( "AutoDebayer" ), mAutoDebayer, !KSUtils::isHardwareLimited() );
  itemAutoDebayer = new KConfigCompilerSignallingItem(innerItemAutoDebayer, this, notifyFunction, signalAutoDebayerChanged);
  addItem( itemAutoDebayer, QStringLiteral( "AutoDebayer" ) );
  KConfigCompilerSignallingItem  *itemAuto3DCube;
  KConfigSkeleton::ItemBool  *innerItemAuto3DCube;
  innerItemAuto3DCube = new KConfigSkeleton::ItemBool( currentGroup(), QStringLiteral( "Auto3DCube" ), mAuto3DCube, !KSUtils::isHardwareLimited() );
  itemAuto3DCube = new KConfigCompilerSignallingItem(innerItemAuto3DCube, this, notifyFunction, signalAuto3DCubeChanged);
  addItem( itemAuto3DCube, QStringLiteral( "Auto3DCube" ) );
  KConfigCompilerSignallingItem  *itemAutoHFR;
  KConfigSkeleton::ItemBool  *innerItemAutoHFR;
  innerItemAutoHFR = new KConfigSkeleton::ItemBool( currentGroup(), QStringLiteral( "AutoHFR" ), mAutoHFR, false );
  itemAutoHFR = new KConfigCompilerSignallingItem(innerItemAutoHFR, this, notifyFunction, signalAutoHFRChanged);
  addItem( itemAutoHFR, QStringLiteral( "AutoHFR" ) );
  KConfigCompilerSignallingItem  *itemQuickHFR;
  KConfigSkeleton::ItemBool  *innerItemQuickHFR;
  innerItemQuickHFR = new KConfigSkeleton::ItemBool( currentGroup(), QStringLiteral( "QuickHFR" ), mQuickHFR, true );
  itemQuickHFR = new KConfigCompilerSignallingItem(innerItemQuickHFR, this, notifyFunction, signalQuickHFRChanged);
  addItem( itemQuickHFR, QStringLiteral( "QuickHFR" ) );
  KConfigCompilerSignallingItem  *itemStellarSolverPartition;
  KConfigSkeleton::ItemBool  *innerItemStellarSolverPartition;
  innerItemStellarSolverPartition = new KConfigSkeleton::ItemBool( currentGroup(), QStringLiteral( "StellarSolverPartition" ), mStellarSolverPartition, false );
  itemStellarSolverPartition = new KConfigCompilerSignallingItem(innerItemStellarSolverPartition, this, notifyFunction, signalStellarSolverPartitionChanged);
  addItem( itemStellarSolverPartition, QStringLiteral( "StellarSolverPartition" ) );
  KConfigCompilerSignallingItem  *itemAutoWCS;
  KConfigSkeleton::ItemBool  *innerItemAutoWCS;
  innerItemAutoWCS = new KConfigSkeleton::ItemBool( currentGroup(), QStringLiteral( "AutoWCS" ), mAutoWCS, !KSUtils::isHardwareLimited() );
  itemAutoWCS = new KConfigCompilerSignallingItem(innerItemAutoWCS, this, notifyFunction, signalAutoWCSChanged);
  addItem( itemAutoWCS, QStringLiteral( "AutoWCS" ) );
  KConfigCompilerSignallingItem  *itemLimitedResourcesMode;
  KConfigSkeleton::ItemBool  *innerItemLimitedResourcesMode;
  innerItemLimitedResourcesMode = new KConfigSkeleton::ItemBool( currentGroup(), QStringLiteral( "LimitedResourcesMode" ), mLimitedResourcesMode, KSUtils::isHardwareLimited() );
  itemLimitedResourcesMode = new KConfigCompilerSignallingItem(innerItemLimitedResourcesMode, this, notifyFunction, signalLimitedResourcesModeChanged);
  addItem( itemLimitedResourcesMode, QStringLiteral( "LimitedResourcesMode" ) );
  KConfigCompilerSignallingItem  *itemNonLinearHistogram;
  KConfigSkeleton::ItemBool  *innerItemNonLinearHistogram;
  innerItemNonLinearHistogram = new KConfigSkeleton::ItemBool( currentGroup(), QStringLiteral( "NonLinearHistogram" ), mNonLinearHistogram, true );
  itemNonLinearHistogram = new KConfigCompilerSignallingItem(innerItemNonLinearHistogram, this, notifyFunction, signalNonLinearHistogramChanged);
  addItem( itemNonLinearHistogram, QStringLiteral( "NonLinearHistogram" ) );
  KConfigCompilerSignallingItem  *itemHIPSOpacity;
  KConfigSkeleton::ItemDouble  *innerItemHIPSOpacity;
  innerItemHIPSOpacity = new KConfigSkeleton::ItemDouble( currentGroup(), QStringLiteral( "HIPSOpacity" ), mHIPSOpacity, 0.5 );
  itemHIPSOpacity = new KConfigCompilerSignallingItem(innerItemHIPSOpacity, this, notifyFunction, signalHIPSOpacityChanged);
  addItem( itemHIPSOpacity, QStringLiteral( "HIPSOpacity" ) );
  KConfigCompilerSignallingItem  *itemHIPSOffsetX;
  KConfigSkeleton::ItemInt  *innerItemHIPSOffsetX;
  innerItemHIPSOffsetX = new KConfigSkeleton::ItemInt( currentGroup(), QStringLiteral( "HIPSOffsetX" ), mHIPSOffsetX, 0 );
  itemHIPSOffsetX = new KConfigCompilerSignallingItem(innerItemHIPSOffsetX, this, notifyFunction, signalHIPSOffsetXChanged);
  addItem( itemHIPSOffsetX, QStringLiteral( "HIPSOffsetX" ) );
  KConfigCompilerSignallingItem  *itemHIPSOffsetY;
  KConfigSkeleton::ItemInt  *innerItemHIPSOffsetY;
  innerItemHIPSOffsetY = new KConfigSkeleton::ItemInt( currentGroup(), QStringLiteral( "HIPSOffsetY" ), mHIPSOffsetY, 0 );
  itemHIPSOffsetY = new KConfigCompilerSignallingItem(innerItemHIPSOffsetY, this, notifyFunction, signalHIPSOffsetYChanged);
  addItem( itemHIPSOffsetY, QStringLiteral( "HIPSOffsetY" ) );
  KConfigCompilerSignallingItem  *itemFitsSolverProfile;
  KConfigSkeleton::ItemUInt  *innerItemFitsSolverProfile;
  innerItemFitsSolverProfile = new KConfigSkeleton::ItemUInt( currentGroup(), QStringLiteral( "FitsSolverProfile" ), mFitsSolverProfile, 0 );
  itemFitsSolverProfile = new KConfigCompilerSignallingItem(innerItemFitsSolverProfile, this, notifyFunction, signalFitsSolverProfileChanged);
  addItem( itemFitsSolverProfile, QStringLiteral( "FitsSolverProfile" ) );
  KConfigCompilerSignallingItem  *itemFitsSolverModule;
  KConfigSkeleton::ItemUInt  *innerItemFitsSolverModule;
  innerItemFitsSolverModule = new KConfigSkeleton::ItemUInt( currentGroup(), QStringLiteral( "FitsSolverModule" ), mFitsSolverModule, 0 );
  itemFitsSolverModule = new KConfigCompilerSignallingItem(innerItemFitsSolverModule, this, notifyFunction, signalFitsSolverModuleChanged);
  addItem( itemFitsSolverModule, QStringLiteral( "FitsSolverModule" ) );
  KConfigCompilerSignallingItem  *itemFitsSolverProfileIndeces;
  KConfigSkeleton::ItemString  *innerItemFitsSolverProfileIndeces;
  innerItemFitsSolverProfileIndeces = new KConfigSkeleton::ItemString( currentGroup(), QStringLiteral( "FitsSolverProfileIndeces" ), mFitsSolverProfileIndeces );
  itemFitsSolverProfileIndeces = new KConfigCompilerSignallingItem(innerItemFitsSolverProfileIndeces, this, notifyFunction, signalFitsSolverProfileIndecesChanged);
  addItem( itemFitsSolverProfileIndeces, QStringLiteral( "FitsSolverProfileIndeces" ) );
  KConfigCompilerSignallingItem  *itemFitsCatalog;
  KConfigSkeleton::ItemUInt  *innerItemFitsCatalog;
  innerItemFitsCatalog = new KConfigSkeleton::ItemUInt( currentGroup(), QStringLiteral( "FitsCatalog" ), mFitsCatalog, 0 );
  itemFitsCatalog = new KConfigCompilerSignallingItem(innerItemFitsCatalog, this, notifyFunction, signalFitsCatalogChanged);
  addItem( itemFitsCatalog, QStringLiteral( "FitsCatalog" ) );
  KConfigCompilerSignallingItem  *itemFitsCatObjShowNames;
  KConfigSkeleton::ItemBool  *innerItemFitsCatObjShowNames;
  innerItemFitsCatObjShowNames = new KConfigSkeleton::ItemBool( currentGroup(), QStringLiteral( "FitsCatObjShowNames" ), mFitsCatObjShowNames, true );
  itemFitsCatObjShowNames = new KConfigCompilerSignallingItem(innerItemFitsCatObjShowNames, this, notifyFunction, signalFitsCatObjShowNamesChanged);
  addItem( itemFitsCatObjShowNames, QStringLiteral( "FitsCatObjShowNames" ) );
  KConfigCompilerSignallingItem  *itemFitsSolverUseScale;
  KConfigSkeleton::ItemBool  *innerItemFitsSolverUseScale;
  innerItemFitsSolverUseScale = new KConfigSkeleton::ItemBool( currentGroup(), QStringLiteral( "FitsSolverUseScale" ), mFitsSolverUseScale, false );
  itemFitsSolverUseScale = new KConfigCompilerSignallingItem(innerItemFitsSolverUseScale, this, notifyFunction, signalFitsSolverUseScaleChanged);
  addItem( itemFitsSolverUseScale, QStringLiteral( "FitsSolverUseScale" ) );
  KConfigCompilerSignallingItem  *itemFitsSolverUsePosition;
  KConfigSkeleton::ItemBool  *innerItemFitsSolverUsePosition;
  innerItemFitsSolverUsePosition = new KConfigSkeleton::ItemBool( currentGroup(), QStringLiteral( "FitsSolverUsePosition" ), mFitsSolverUsePosition, false );
  itemFitsSolverUsePosition = new KConfigCompilerSignallingItem(innerItemFitsSolverUsePosition, this, notifyFunction, signalFitsSolverUsePositionChanged);
  addItem( itemFitsSolverUsePosition, QStringLiteral( "FitsSolverUsePosition" ) );
  KConfigCompilerSignallingItem  *itemFitsSolverScale;
  KConfigSkeleton::ItemDouble  *innerItemFitsSolverScale;
  innerItemFitsSolverScale = new KConfigSkeleton::ItemDouble( currentGroup(), QStringLiteral( "FitsSolverScale" ), mFitsSolverScale, 1.0 );
  itemFitsSolverScale = new KConfigCompilerSignallingItem(innerItemFitsSolverScale, this, notifyFunction, signalFitsSolverScaleChanged);
  addItem( itemFitsSolverScale, QStringLiteral( "FitsSolverScale" ) );
  KConfigCompilerSignallingItem  *itemFitsSolverImageScaleUnits;
  KConfigSkeleton::ItemUInt  *innerItemFitsSolverImageScaleUnits;
  innerItemFitsSolverImageScaleUnits = new KConfigSkeleton::ItemUInt( currentGroup(), QStringLiteral( "FitsSolverImageScaleUnits" ), mFitsSolverImageScaleUnits, 2 );
  itemFitsSolverImageScaleUnits = new KConfigCompilerSignallingItem(innerItemFitsSolverImageScaleUnits, this, notifyFunction, signalFitsSolverImageScaleUnitsChanged);
  addItem( itemFitsSolverImageScaleUnits, QStringLiteral( "FitsSolverImageScaleUnits" ) );
  KConfigCompilerSignallingItem  *itemFitsSolverRadius;
  KConfigSkeleton::ItemDouble  *innerItemFitsSolverRadius;
  innerItemFitsSolverRadius = new KConfigSkeleton::ItemDouble( currentGroup(), QStringLiteral( "FitsSolverRadius" ), mFitsSolverRadius, 30 );
  itemFitsSolverRadius = new KConfigCompilerSignallingItem(innerItemFitsSolverRadius, this, notifyFunction, signalFitsSolverRadiusChanged);
  addItem( itemFitsSolverRadius, QStringLiteral( "FitsSolverRadius" ) );
  KConfigCompilerSignallingItem  *itemFitsLSHideGeneral;
  KConfigSkeleton::ItemBool  *innerItemFitsLSHideGeneral;
  innerItemFitsLSHideGeneral = new KConfigSkeleton::ItemBool( currentGroup(), QStringLiteral( "fitsLSHideGeneral" ), mFitsLSHideGeneral, false );
  itemFitsLSHideGeneral = new KConfigCompilerSignallingItem(innerItemFitsLSHideGeneral, this, notifyFunction, signalFitsLSHideGeneralChanged);
  addItem( itemFitsLSHideGeneral, QStringLiteral( "fitsLSHideGeneral" ) );
  KConfigCompilerSignallingItem  *itemFitsLSHideCalibration;
  KConfigSkeleton::ItemBool  *innerItemFitsLSHideCalibration;
  innerItemFitsLSHideCalibration = new KConfigSkeleton::ItemBool( currentGroup(), QStringLiteral( "fitsLSHideCalibration" ), mFitsLSHideCalibration, true );
  itemFitsLSHideCalibration = new KConfigCompilerSignallingItem(innerItemFitsLSHideCalibration, this, notifyFunction, signalFitsLSHideCalibrationChanged);
  addItem( itemFitsLSHideCalibration, QStringLiteral( "fitsLSHideCalibration" ) );
  KConfigCompilerSignallingItem  *itemFitsLSHideAlignment;
  KConfigSkeleton::ItemBool  *innerItemFitsLSHideAlignment;
  innerItemFitsLSHideAlignment = new KConfigSkeleton::ItemBool( currentGroup(), QStringLiteral( "fitsLSHideAlignment" ), mFitsLSHideAlignment, true );
  itemFitsLSHideAlignment = new KConfigCompilerSignallingItem(innerItemFitsLSHideAlignment, this, notifyFunction, signalFitsLSHideAlignmentChanged);
  addItem( itemFitsLSHideAlignment, QStringLiteral( "fitsLSHideAlignment" ) );
  KConfigCompilerSignallingItem  *itemFitsLSHideStacking;
  KConfigSkeleton::ItemBool  *innerItemFitsLSHideStacking;
  innerItemFitsLSHideStacking = new KConfigSkeleton::ItemBool( currentGroup(), QStringLiteral( "fitsLSHideStacking" ), mFitsLSHideStacking, true );
  itemFitsLSHideStacking = new KConfigCompilerSignallingItem(innerItemFitsLSHideStacking, this, notifyFunction, signalFitsLSHideStackingChanged);
  addItem( itemFitsLSHideStacking, QStringLiteral( "fitsLSHideStacking" ) );
  KConfigCompilerSignallingItem  *itemFitsLSHidePostProc;
  KConfigSkeleton::ItemBool  *innerItemFitsLSHidePostProc;
  innerItemFitsLSHidePostProc = new KConfigSkeleton::ItemBool( currentGroup(), QStringLiteral( "fitsLSHidePostProc" ), mFitsLSHidePostProc, true );
  itemFitsLSHidePostProc = new KConfigCompilerSignallingItem(innerItemFitsLSHidePostProc, this, notifyFunction, signalFitsLSHidePostProcChanged);
  addItem( itemFitsLSHidePostProc, QStringLiteral( "fitsLSHidePostProc" ) );
  KConfigCompilerSignallingItem  *itemFitsLSCalcSNR;
  KConfigSkeleton::ItemBool  *innerItemFitsLSCalcSNR;
  innerItemFitsLSCalcSNR = new KConfigSkeleton::ItemBool( currentGroup(), QStringLiteral( "fitsLSCalcSNR" ), mFitsLSCalcSNR, true );
  itemFitsLSCalcSNR = new KConfigCompilerSignallingItem(innerItemFitsLSCalcSNR, this, notifyFunction, signalFitsLSCalcSNRChanged);
  addItem( itemFitsLSCalcSNR, QStringLiteral( "fitsLSCalcSNR" ) );
  KConfigCompilerSignallingItem  *itemFitsLSMasterDark;
  KConfigSkeleton::ItemString  *innerItemFitsLSMasterDark;
  innerItemFitsLSMasterDark = new KConfigSkeleton::ItemString( currentGroup(), QStringLiteral( "fitsLSMasterDark" ), mFitsLSMasterDark );
  itemFitsLSMasterDark = new KConfigCompilerSignallingItem(innerItemFitsLSMasterDark, this, notifyFunction, signalFitsLSMasterDarkChanged);
  addItem( itemFitsLSMasterDark, QStringLiteral( "fitsLSMasterDark" ) );
  KConfigCompilerSignallingItem  *itemFitsLSMasterFlat;
  KConfigSkeleton::ItemString  *innerItemFitsLSMasterFlat;
  innerItemFitsLSMasterFlat = new KConfigSkeleton::ItemString( currentGroup(), QStringLiteral( "fitsLSMasterFlat" ), mFitsLSMasterFlat );
  itemFitsLSMasterFlat = new KConfigCompilerSignallingItem(innerItemFitsLSMasterFlat, this, notifyFunction, signalFitsLSMasterFlatChanged);
  addItem( itemFitsLSMasterFlat, QStringLiteral( "fitsLSMasterFlat" ) );
  KConfigCompilerSignallingItem  *itemFitsLSHotPixels;
  KConfigSkeleton::ItemBool  *innerItemFitsLSHotPixels;
  innerItemFitsLSHotPixels = new KConfigSkeleton::ItemBool( currentGroup(), QStringLiteral( "fitsLSHotPixels" ), mFitsLSHotPixels, false );
  itemFitsLSHotPixels = new KConfigCompilerSignallingItem(innerItemFitsLSHotPixels, this, notifyFunction, signalFitsLSHotPixelsChanged);
  addItem( itemFitsLSHotPixels, QStringLiteral( "fitsLSHotPixels" ) );
  KConfigCompilerSignallingItem  *itemFitsLSColdPixels;
  KConfigSkeleton::ItemBool  *innerItemFitsLSColdPixels;
  innerItemFitsLSColdPixels = new KConfigSkeleton::ItemBool( currentGroup(), QStringLiteral( "fitsLSColdPixels" ), mFitsLSColdPixels, false );
  itemFitsLSColdPixels = new KConfigCompilerSignallingItem(innerItemFitsLSColdPixels, this, notifyFunction, signalFitsLSColdPixelsChanged);
  addItem( itemFitsLSColdPixels, QStringLiteral( "fitsLSColdPixels" ) );
  KConfigCompilerSignallingItem  *itemFitsLSAlignMethod;
  KConfigSkeleton::ItemUInt  *innerItemFitsLSAlignMethod;
  innerItemFitsLSAlignMethod = new KConfigSkeleton::ItemUInt( currentGroup(), QStringLiteral( "fitsLSAlignMethod" ), mFitsLSAlignMethod, 0 );
  itemFitsLSAlignMethod = new KConfigCompilerSignallingItem(innerItemFitsLSAlignMethod, this, notifyFunction, signalFitsLSAlignMethodChanged);
  addItem( itemFitsLSAlignMethod, QStringLiteral( "fitsLSAlignMethod" ) );
  KConfigCompilerSignallingItem  *itemFitsLSNumInMem;
  KConfigSkeleton::ItemUInt  *innerItemFitsLSNumInMem;
  innerItemFitsLSNumInMem = new KConfigSkeleton::ItemUInt( currentGroup(), QStringLiteral( "fitsLSNumInMem" ), mFitsLSNumInMem, 5 );
  itemFitsLSNumInMem = new KConfigCompilerSignallingItem(innerItemFitsLSNumInMem, this, notifyFunction, signalFitsLSNumInMemChanged);
  addItem( itemFitsLSNumInMem, QStringLiteral( "fitsLSNumInMem" ) );
  KConfigCompilerSignallingItem  *itemFitsLSDownscale;
  KConfigSkeleton::ItemUInt  *innerItemFitsLSDownscale;
  innerItemFitsLSDownscale = new KConfigSkeleton::ItemUInt( currentGroup(), QStringLiteral( "fitsLSDownscale" ), mFitsLSDownscale, 1 );
  itemFitsLSDownscale = new KConfigCompilerSignallingItem(innerItemFitsLSDownscale, this, notifyFunction, signalFitsLSDownscaleChanged);
  addItem( itemFitsLSDownscale, QStringLiteral( "fitsLSDownscale" ) );
  KConfigCompilerSignallingItem  *itemFitsLSWeighting;
  KConfigSkeleton::ItemUInt  *innerItemFitsLSWeighting;
  innerItemFitsLSWeighting = new KConfigSkeleton::ItemUInt( currentGroup(), QStringLiteral( "fitsLSWeighting" ), mFitsLSWeighting, 0 );
  itemFitsLSWeighting = new KConfigCompilerSignallingItem(innerItemFitsLSWeighting, this, notifyFunction, signalFitsLSWeightingChanged);
  addItem( itemFitsLSWeighting, QStringLiteral( "fitsLSWeighting" ) );
  KConfigCompilerSignallingItem  *itemFitsLSNormalization;
  KConfigSkeleton::ItemUInt  *innerItemFitsLSNormalization;
  innerItemFitsLSNormalization = new KConfigSkeleton::ItemUInt( currentGroup(), QStringLiteral( "fitsLSNormalization" ), mFitsLSNormalization, 0 );
  itemFitsLSNormalization = new KConfigCompilerSignallingItem(innerItemFitsLSNormalization, this, notifyFunction, signalFitsLSNormalizationChanged);
  addItem( itemFitsLSNormalization, QStringLiteral( "fitsLSNormalization" ) );
  KConfigCompilerSignallingItem  *itemFitsLSStackingMethod;
  KConfigSkeleton::ItemUInt  *innerItemFitsLSStackingMethod;
  innerItemFitsLSStackingMethod = new KConfigSkeleton::ItemUInt( currentGroup(), QStringLiteral( "fitsLSStackingMethod" ), mFitsLSStackingMethod, 0 );
  itemFitsLSStackingMethod = new KConfigCompilerSignallingItem(innerItemFitsLSStackingMethod, this, notifyFunction, signalFitsLSStackingMethodChanged);
  addItem( itemFitsLSStackingMethod, QStringLiteral( "fitsLSStackingMethod" ) );
  KConfigCompilerSignallingItem  *itemFitsLSLowSigma;
  KConfigSkeleton::ItemDouble  *innerItemFitsLSLowSigma;
  innerItemFitsLSLowSigma = new KConfigSkeleton::ItemDouble( currentGroup(), QStringLiteral( "fitsLSLowSigma" ), mFitsLSLowSigma, 3.0 );
  itemFitsLSLowSigma = new KConfigCompilerSignallingItem(innerItemFitsLSLowSigma, this, notifyFunction, signalFitsLSLowSigmaChanged);
  addItem( itemFitsLSLowSigma, QStringLiteral( "fitsLSLowSigma" ) );
  KConfigCompilerSignallingItem  *itemFitsLSHighSigma;
  KConfigSkeleton::ItemDouble  *innerItemFitsLSHighSigma;
  innerItemFitsLSHighSigma = new KConfigSkeleton::ItemDouble( currentGroup(), QStringLiteral( "fitsLSHighSigma" ), mFitsLSHighSigma, 3.0 );
  itemFitsLSHighSigma = new KConfigCompilerSignallingItem(innerItemFitsLSHighSigma, this, notifyFunction, signalFitsLSHighSigmaChanged);
  addItem( itemFitsLSHighSigma, QStringLiteral( "fitsLSHighSigma" ) );
  KConfigCompilerSignallingItem  *itemFitsLSWinsorCutoff;
  KConfigSkeleton::ItemDouble  *innerItemFitsLSWinsorCutoff;
  innerItemFitsLSWinsorCutoff = new KConfigSkeleton::ItemDouble( currentGroup(), QStringLiteral( "fitsLSWinsorCutoff" ), mFitsLSWinsorCutoff, 3.0 );
  itemFitsLSWinsorCutoff = new KConfigCompilerSignallingItem(innerItemFitsLSWinsorCutoff, this, notifyFunction, signalFitsLSWinsorCutoffChanged);
  addItem( itemFitsLSWinsorCutoff, QStringLiteral( "fitsLSWinsorCutoff" ) );
  KConfigCompilerSignallingItem  *itemFitsLSIterations;
  KConfigSkeleton::ItemUInt  *innerItemFitsLSIterations;
  innerItemFitsLSIterations = new KConfigSkeleton::ItemUInt( currentGroup(), QStringLiteral( "fitsLSIterations" ), mFitsLSIterations, 3 );
  itemFitsLSIterations = new KConfigCompilerSignallingItem(innerItemFitsLSIterations, this, notifyFunction, signalFitsLSIterationsChanged);
  addItem( itemFitsLSIterations, QStringLiteral( "fitsLSIterations" ) );
  KConfigCompilerSignallingItem  *itemFitsLSKappa;
  KConfigSkeleton::ItemDouble  *innerItemFitsLSKappa;
  innerItemFitsLSKappa = new KConfigSkeleton::ItemDouble( currentGroup(), QStringLiteral( "fitsLSKappa" ), mFitsLSKappa, 1.5 );
  itemFitsLSKappa = new KConfigCompilerSignallingItem(innerItemFitsLSKappa, this, notifyFunction, signalFitsLSKappaChanged);
  addItem( itemFitsLSKappa, QStringLiteral( "fitsLSKappa" ) );
  KConfigCompilerSignallingItem  *itemFitsLSAlpha;
  KConfigSkeleton::ItemDouble  *innerItemFitsLSAlpha;
  innerItemFitsLSAlpha = new KConfigSkeleton::ItemDouble( currentGroup(), QStringLiteral( "fitsLSAlpha" ), mFitsLSAlpha, 0.9 );
  itemFitsLSAlpha = new KConfigCompilerSignallingItem(innerItemFitsLSAlpha, this, notifyFunction, signalFitsLSAlphaChanged);
  addItem( itemFitsLSAlpha, QStringLiteral( "fitsLSAlpha" ) );
  KConfigCompilerSignallingItem  *itemFitsLSSigma;
  KConfigSkeleton::ItemDouble  *innerItemFitsLSSigma;
  innerItemFitsLSSigma = new KConfigSkeleton::ItemDouble( currentGroup(), QStringLiteral( "fitsLSSigma" ), mFitsLSSigma, 0.9 );
  itemFitsLSSigma = new KConfigCompilerSignallingItem(innerItemFitsLSSigma, this, notifyFunction, signalFitsLSSigmaChanged);
  addItem( itemFitsLSSigma, QStringLiteral( "fitsLSSigma" ) );
  KConfigCompilerSignallingItem  *itemFitsPSFUpdate;
  KConfigSkeleton::ItemUInt  *innerItemFitsPSFUpdate;
  innerItemFitsPSFUpdate = new KConfigSkeleton::ItemUInt( currentGroup(), QStringLiteral( "fitsPSFUpdate" ), mFitsPSFUpdate, 0 );
  itemFitsPSFUpdate = new KConfigCompilerSignallingItem(innerItemFitsPSFUpdate, this, notifyFunction, signalFitsPSFUpdateChanged);
  addItem( itemFitsPSFUpdate, QStringLiteral( "fitsPSFUpdate" ) );
  KConfigCompilerSignallingItem  *itemFitsLSPostProc;
  KConfigSkeleton::ItemBool  *innerItemFitsLSPostProc;
  innerItemFitsLSPostProc = new KConfigSkeleton::ItemBool( currentGroup(), QStringLiteral( "fitsLSPostProc" ), mFitsLSPostProc, false );
  itemFitsLSPostProc = new KConfigCompilerSignallingItem(innerItemFitsLSPostProc, this, notifyFunction, signalFitsLSPostProcChanged);
  addItem( itemFitsLSPostProc, QStringLiteral( "fitsLSPostProc" ) );
  KConfigCompilerSignallingItem  *itemFitsLSGradientAmt;
  KConfigSkeleton::ItemDouble  *innerItemFitsLSGradientAmt;
  innerItemFitsLSGradientAmt = new KConfigSkeleton::ItemDouble( currentGroup(), QStringLiteral( "fitsLSGradientAmt" ), mFitsLSGradientAmt, 0.0 );
  itemFitsLSGradientAmt = new KConfigCompilerSignallingItem(innerItemFitsLSGradientAmt, this, notifyFunction, signalFitsLSGradientAmtChanged);
  addItem( itemFitsLSGradientAmt, QStringLiteral( "fitsLSGradientAmt" ) );
  KConfigCompilerSignallingItem  *itemFitsLSDeconvAmt;
  KConfigSkeleton::ItemDouble  *innerItemFitsLSDeconvAmt;
  innerItemFitsLSDeconvAmt = new KConfigSkeleton::ItemDouble( currentGroup(), QStringLiteral( "fitsLSDeconvAmt" ), mFitsLSDeconvAmt, 0.0 );
  itemFitsLSDeconvAmt = new KConfigCompilerSignallingItem(innerItemFitsLSDeconvAmt, this, notifyFunction, signalFitsLSDeconvAmtChanged);
  addItem( itemFitsLSDeconvAmt, QStringLiteral( "fitsLSDeconvAmt" ) );
  KConfigCompilerSignallingItem  *itemFitsLSPSFSigma;
  KConfigSkeleton::ItemDouble  *innerItemFitsLSPSFSigma;
  innerItemFitsLSPSFSigma = new KConfigSkeleton::ItemDouble( currentGroup(), QStringLiteral( "fitsLSPSFSigma" ), mFitsLSPSFSigma, 1.0 );
  itemFitsLSPSFSigma = new KConfigCompilerSignallingItem(innerItemFitsLSPSFSigma, this, notifyFunction, signalFitsLSPSFSigmaChanged);
  addItem( itemFitsLSPSFSigma, QStringLiteral( "fitsLSPSFSigma" ) );
  KConfigCompilerSignallingItem  *itemFitsLSDenoiseAmt;
  KConfigSkeleton::ItemDouble  *innerItemFitsLSDenoiseAmt;
  innerItemFitsLSDenoiseAmt = new KConfigSkeleton::ItemDouble( currentGroup(), QStringLiteral( "fitsLSDenoiseAmt" ), mFitsLSDenoiseAmt, 0.0 );
  itemFitsLSDenoiseAmt = new KConfigCompilerSignallingItem(innerItemFitsLSDenoiseAmt, this, notifyFunction, signalFitsLSDenoiseAmtChanged);
  addItem( itemFitsLSDenoiseAmt, QStringLiteral( "fitsLSDenoiseAmt" ) );
  KConfigCompilerSignallingItem  *itemFitsLSSharpenAmt;
  KConfigSkeleton::ItemDouble  *innerItemFitsLSSharpenAmt;
  innerItemFitsLSSharpenAmt = new KConfigSkeleton::ItemDouble( currentGroup(), QStringLiteral( "fitsLSSharpenAmt" ), mFitsLSSharpenAmt, 0.0 );
  itemFitsLSSharpenAmt = new KConfigCompilerSignallingItem(innerItemFitsLSSharpenAmt, this, notifyFunction, signalFitsLSSharpenAmtChanged);
  addItem( itemFitsLSSharpenAmt, QStringLiteral( "fitsLSSharpenAmt" ) );
  KConfigCompilerSignallingItem  *itemFitsLSSharpenKernal;
  KConfigSkeleton::ItemUInt  *innerItemFitsLSSharpenKernal;
  innerItemFitsLSSharpenKernal = new KConfigSkeleton::ItemUInt( currentGroup(), QStringLiteral( "fitsLSSharpenKernal" ), mFitsLSSharpenKernal, 3 );
  itemFitsLSSharpenKernal = new KConfigCompilerSignallingItem(innerItemFitsLSSharpenKernal, this, notifyFunction, signalFitsLSSharpenKernalChanged);
  addItem( itemFitsLSSharpenKernal, QStringLiteral( "fitsLSSharpenKernal" ) );
  KConfigCompilerSignallingItem  *itemFitsLSSharpenSigma;
  KConfigSkeleton::ItemDouble  *innerItemFitsLSSharpenSigma;
  innerItemFitsLSSharpenSigma = new KConfigSkeleton::ItemDouble( currentGroup(), QStringLiteral( "fitsLSSharpenSigma" ), mFitsLSSharpenSigma, 5.0 );
  itemFitsLSSharpenSigma = new KConfigCompilerSignallingItem(innerItemFitsLSSharpenSigma, this, notifyFunction, signalFitsLSSharpenSigmaChanged);
  addItem( itemFitsLSSharpenSigma, QStringLiteral( "fitsLSSharpenSigma" ) );
  KConfigCompilerSignallingItem  *itemFitsLSMWindowGeometry;
  KConfigSkeleton::ItemString  *innerItemFitsLSMWindowGeometry;
  innerItemFitsLSMWindowGeometry = new KConfigSkeleton::ItemString( currentGroup(), QStringLiteral( "fitsLSMWindowGeometry" ), mFitsLSMWindowGeometry );
  itemFitsLSMWindowGeometry = new KConfigCompilerSignallingItem(innerItemFitsLSMWindowGeometry, this, notifyFunction, signalFitsLSMWindowGeometryChanged);
  addItem( itemFitsLSMWindowGeometry, QStringLiteral( "fitsLSMWindowGeometry" ) );
  QStringList defaultfitsLSMVisibleColumns;
  defaultfitsLSMVisibleColumns.append( QString::fromUtf8( "ID" ) );
  defaultfitsLSMVisibleColumns.append( QString::fromUtf8( "Filename" ) );
  defaultfitsLSMVisibleColumns.append( QString::fromUtf8( "Channel(s)" ) );
  defaultfitsLSMVisibleColumns.append( QString::fromUtf8( "Overall\nStatus" ) );
  defaultfitsLSMVisibleColumns.append( QString::fromUtf8( "Load Wait\nTime(s)" ) );
  defaultfitsLSMVisibleColumns.append( QString::fromUtf8( "Loading\nStatus" ) );
  defaultfitsLSMVisibleColumns.append( QString::fromUtf8( "Loading\nTime(s)" ) );
  defaultfitsLSMVisibleColumns.append( QString::fromUtf8( "SNR" ) );
  defaultfitsLSMVisibleColumns.append( QString::fromUtf8( "Plate Solve\nStatus" ) );
  defaultfitsLSMVisibleColumns.append( QString::fromUtf8( "Plate Solve\nTime(s)" ) );
  defaultfitsLSMVisibleColumns.append( QString::fromUtf8( "HFR" ) );
  defaultfitsLSMVisibleColumns.append( QString::fromUtf8( "Num Stars" ) );
  defaultfitsLSMVisibleColumns.append( QString::fromUtf8( "Stack Wait\nTime(s)" ) );
  defaultfitsLSMVisibleColumns.append( QString::fromUtf8( "Calibration\nStatus" ) );
  defaultfitsLSMVisibleColumns.append( QString::fromUtf8( "Calibration\nTime" ) );
  defaultfitsLSMVisibleColumns.append( QString::fromUtf8( "Alignment\nStatus" ) );
  defaultfitsLSMVisibleColumns.append( QString::fromUtf8( "Alignment\nTime" ) );
  defaultfitsLSMVisibleColumns.append( QString::fromUtf8( "Δx" ) );
  defaultfitsLSMVisibleColumns.append( QString::fromUtf8( "Δy" ) );
  defaultfitsLSMVisibleColumns.append( QString::fromUtf8( "Rot(°)" ) );
  defaultfitsLSMVisibleColumns.append( QString::fromUtf8( "Stacking\nStatus" ) );
  defaultfitsLSMVisibleColumns.append( QString::fromUtf8( "Stacking\nTime" ) );
  defaultfitsLSMVisibleColumns.append( QString::fromUtf8( "Stacking\nWeight" ) );

  KConfigCompilerSignallingItem  *itemFitsLSMVisibleColumns;
  KConfigSkeleton::ItemStringList  *innerItemFitsLSMVisibleColumns;
  innerItemFitsLSMVisibleColumns = new KConfigSkeleton::ItemStringList( currentGroup(), QStringLiteral( "fitsLSMVisibleColumns" ), mFitsLSMVisibleColumns, defaultfitsLSMVisibleColumns );
  itemFitsLSMVisibleColumns = new KConfigCompilerSignallingItem(innerItemFitsLSMVisibleColumns, this, notifyFunction, signalFitsLSMVisibleColumnsChanged);
  addItem( itemFitsLSMVisibleColumns, QStringLiteral( "fitsLSMVisibleColumns" ) );
  QList<int> defaultfitsLSMColumnWidths;
  defaultfitsLSMColumnWidths.append( 80 );
  defaultfitsLSMColumnWidths.append( 120 );
  defaultfitsLSMColumnWidths.append( 80 );
  defaultfitsLSMColumnWidths.append( 80 );
  defaultfitsLSMColumnWidths.append( 80 );
  defaultfitsLSMColumnWidths.append( 80 );
  defaultfitsLSMColumnWidths.append( 80 );
  defaultfitsLSMColumnWidths.append( 80 );
  defaultfitsLSMColumnWidths.append( 80 );
  defaultfitsLSMColumnWidths.append( 80 );
  defaultfitsLSMColumnWidths.append( 80 );
  defaultfitsLSMColumnWidths.append( 80 );
  defaultfitsLSMColumnWidths.append( 80 );
  defaultfitsLSMColumnWidths.append( 80 );
  defaultfitsLSMColumnWidths.append( 80 );
  defaultfitsLSMColumnWidths.append( 80 );
  defaultfitsLSMColumnWidths.append( 80 );
  defaultfitsLSMColumnWidths.append( 80 );
  defaultfitsLSMColumnWidths.append( 80 );
  defaultfitsLSMColumnWidths.append( 80 );
  defaultfitsLSMColumnWidths.append( 80 );
  defaultfitsLSMColumnWidths.append( 80 );
  defaultfitsLSMColumnWidths.append( 80 );

  KConfigCompilerSignallingItem  *itemFitsLSMColumnWidths;
  KConfigSkeleton::ItemIntList  *innerItemFitsLSMColumnWidths;
  innerItemFitsLSMColumnWidths = new KConfigSkeleton::ItemIntList( currentGroup(), QStringLiteral( "fitsLSMColumnWidths" ), mFitsLSMColumnWidths, defaultfitsLSMColumnWidths );
  itemFitsLSMColumnWidths = new KConfigCompilerSignallingItem(innerItemFitsLSMColumnWidths, this, notifyFunction, signalFitsLSMColumnWidthsChanged);
  addItem( itemFitsLSMColumnWidths, QStringLiteral( "fitsLSMColumnWidths" ) );
  KConfigCompilerSignallingItem  *itemFitsLSMSortColumn;
  KConfigSkeleton::ItemInt  *innerItemFitsLSMSortColumn;
  innerItemFitsLSMSortColumn = new KConfigSkeleton::ItemInt( currentGroup(), QStringLiteral( "fitsLSMSortColumn" ), mFitsLSMSortColumn, 0 );
  itemFitsLSMSortColumn = new KConfigCompilerSignallingItem(innerItemFitsLSMSortColumn, this, notifyFunction, signalFitsLSMSortColumnChanged);
  addItem( itemFitsLSMSortColumn, QStringLiteral( "fitsLSMSortColumn" ) );
  KConfigCompilerSignallingItem  *itemFitsLSMSortOrder;
  KConfigSkeleton::ItemInt  *innerItemFitsLSMSortOrder;
  innerItemFitsLSMSortOrder = new KConfigSkeleton::ItemInt( currentGroup(), QStringLiteral( "fitsLSMSortOrder" ), mFitsLSMSortOrder, 0 );
  itemFitsLSMSortOrder = new KConfigCompilerSignallingItem(innerItemFitsLSMSortOrder, this, notifyFunction, signalFitsLSMSortOrderChanged);
  addItem( itemFitsLSMSortOrder, QStringLiteral( "fitsLSMSortOrder" ) );
  KConfigCompilerSignallingItem  *itemFitsLSMHighlighting;
  KConfigSkeleton::ItemBool  *innerItemFitsLSMHighlighting;
  innerItemFitsLSMHighlighting = new KConfigSkeleton::ItemBool( currentGroup(), QStringLiteral( "fitsLSMHighlighting" ), mFitsLSMHighlighting, true );
  itemFitsLSMHighlighting = new KConfigCompilerSignallingItem(innerItemFitsLSMHighlighting, this, notifyFunction, signalFitsLSMHighlightingChanged);
  addItem( itemFitsLSMHighlighting, QStringLiteral( "fitsLSMHighlighting" ) );
  KConfigCompilerSignallingItem  *itemFitsLSWebcastTitle;
  KConfigSkeleton::ItemString  *innerItemFitsLSWebcastTitle;
  innerItemFitsLSWebcastTitle = new KConfigSkeleton::ItemString( currentGroup(), QStringLiteral( "fitsLSWebcastTitle" ), mFitsLSWebcastTitle, QStringLiteral( "My LiveStack Webcast" ) );
  itemFitsLSWebcastTitle = new KConfigCompilerSignallingItem(innerItemFitsLSWebcastTitle, this, notifyFunction, signalFitsLSWebcastTitleChanged);
  addItem( itemFitsLSWebcastTitle, QStringLiteral( "fitsLSWebcastTitle" ) );
  KConfigCompilerSignallingItem  *itemFitsLSWebcastLogoL;
  KConfigSkeleton::ItemString  *innerItemFitsLSWebcastLogoL;
  innerItemFitsLSWebcastLogoL = new KConfigSkeleton::ItemString( currentGroup(), QStringLiteral( "fitsLSWebcastLogoL" ), mFitsLSWebcastLogoL );
  itemFitsLSWebcastLogoL = new KConfigCompilerSignallingItem(innerItemFitsLSWebcastLogoL, this, notifyFunction, signalFitsLSWebcastLogoLChanged);
  addItem( itemFitsLSWebcastLogoL, QStringLiteral( "fitsLSWebcastLogoL" ) );
  KConfigCompilerSignallingItem  *itemFitsLSWebcastLogoR;
  KConfigSkeleton::ItemString  *innerItemFitsLSWebcastLogoR;
  innerItemFitsLSWebcastLogoR = new KConfigSkeleton::ItemString( currentGroup(), QStringLiteral( "fitsLSWebcastLogoR" ), mFitsLSWebcastLogoR );
  itemFitsLSWebcastLogoR = new KConfigCompilerSignallingItem(innerItemFitsLSWebcastLogoR, this, notifyFunction, signalFitsLSWebcastLogoRChanged);
  addItem( itemFitsLSWebcastLogoR, QStringLiteral( "fitsLSWebcastLogoR" ) );
  KConfigCompilerSignallingItem  *itemFitsLSWebcastPort;
  KConfigSkeleton::ItemUInt  *innerItemFitsLSWebcastPort;
  innerItemFitsLSWebcastPort = new KConfigSkeleton::ItemUInt( currentGroup(), QStringLiteral( "fitsLSWebcastPort" ), mFitsLSWebcastPort, 8080 );
  itemFitsLSWebcastPort = new KConfigCompilerSignallingItem(innerItemFitsLSWebcastPort, this, notifyFunction, signalFitsLSWebcastPortChanged);
  addItem( itemFitsLSWebcastPort, QStringLiteral( "fitsLSWebcastPort" ) );
  KConfigCompilerSignallingItem  *itemFitsLSWebcastThrottle;
  KConfigSkeleton::ItemUInt  *innerItemFitsLSWebcastThrottle;
  innerItemFitsLSWebcastThrottle = new KConfigSkeleton::ItemUInt( currentGroup(), QStringLiteral( "fitsLSWebcastThrottle" ), mFitsLSWebcastThrottle, 5000 );
  itemFitsLSWebcastThrottle = new KConfigCompilerSignallingItem(innerItemFitsLSWebcastThrottle, this, notifyFunction, signalFitsLSWebcastThrottleChanged);
  addItem( itemFitsLSWebcastThrottle, QStringLiteral( "fitsLSWebcastThrottle" ) );

  setCurrentGroup( QStringLiteral( "WISettings" ) );

  KConfigCompilerSignallingItem  *itemBortleClass;
  KConfigSkeleton::ItemUInt  *innerItemBortleClass;
  innerItemBortleClass = new KConfigSkeleton::ItemUInt( currentGroup(), QStringLiteral( "BortleClass" ), mBortleClass, 4 );
  itemBortleClass = new KConfigCompilerSignallingItem(innerItemBortleClass, this, notifyFunction, signalBortleClassChanged);
  addItem( itemBortleClass, QStringLiteral( "BortleClass" ) );
  KConfigCompilerSignallingItem  *itemTelescopeCheck;
  KConfigSkeleton::ItemBool  *innerItemTelescopeCheck;
  innerItemTelescopeCheck = new KConfigSkeleton::ItemBool( currentGroup(), QStringLiteral( "TelescopeCheck" ), mTelescopeCheck, false );
  itemTelescopeCheck = new KConfigCompilerSignallingItem(innerItemTelescopeCheck, this, notifyFunction, signalTelescopeCheckChanged);
  addItem( itemTelescopeCheck, QStringLiteral( "TelescopeCheck" ) );
  KConfigCompilerSignallingItem  *itemBinocularsCheck;
  KConfigSkeleton::ItemBool  *innerItemBinocularsCheck;
  innerItemBinocularsCheck = new KConfigSkeleton::ItemBool( currentGroup(), QStringLiteral( "BinocularsCheck" ), mBinocularsCheck, false );
  itemBinocularsCheck = new KConfigCompilerSignallingItem(innerItemBinocularsCheck, this, notifyFunction, signalBinocularsCheckChanged);
  addItem( itemBinocularsCheck, QStringLiteral( "BinocularsCheck" ) );
  KConfigCompilerSignallingItem  *itemBinocularsAperture;
  KConfigSkeleton::ItemDouble  *innerItemBinocularsAperture;
  innerItemBinocularsAperture = new KConfigSkeleton::ItemDouble( currentGroup(), QStringLiteral( "BinocularsAperture" ), mBinocularsAperture, 40.0 );
  itemBinocularsAperture = new KConfigCompilerSignallingItem(innerItemBinocularsAperture, this, notifyFunction, signalBinocularsApertureChanged);
  addItem( itemBinocularsAperture, QStringLiteral( "BinocularsAperture" ) );
  KConfigCompilerSignallingItem  *itemScopeListIndex;
  KConfigSkeleton::ItemUInt  *innerItemScopeListIndex;
  innerItemScopeListIndex = new KConfigSkeleton::ItemUInt( currentGroup(), QStringLiteral( "ScopeListIndex" ), mScopeListIndex, 0 );
  itemScopeListIndex = new KConfigCompilerSignallingItem(innerItemScopeListIndex, this, notifyFunction, signalScopeListIndexChanged);
  addItem( itemScopeListIndex, QStringLiteral( "ScopeListIndex" ) );

  setCurrentGroup( QStringLiteral( "Ekos" ) );

  KConfigCompilerSignallingItem  *itemEkosWindowWidth;
  KConfigSkeleton::ItemUInt  *innerItemEkosWindowWidth;
  innerItemEkosWindowWidth = new KConfigSkeleton::ItemUInt( currentGroup(), QStringLiteral( "EkosWindowWidth" ), mEkosWindowWidth, 600 );
  itemEkosWindowWidth = new KConfigCompilerSignallingItem(innerItemEkosWindowWidth, this, notifyFunction, signalEkosWindowWidthChanged);
  addItem( itemEkosWindowWidth, QStringLiteral( "EkosWindowWidth" ) );
  KConfigCompilerSignallingItem  *itemEkosWindowHeight;
  KConfigSkeleton::ItemUInt  *innerItemEkosWindowHeight;
  innerItemEkosWindowHeight = new KConfigSkeleton::ItemUInt( currentGroup(), QStringLiteral( "EkosWindowHeight" ), mEkosWindowHeight, 600 );
  itemEkosWindowHeight = new KConfigCompilerSignallingItem(innerItemEkosWindowHeight, this, notifyFunction, signalEkosWindowHeightChanged);
  addItem( itemEkosWindowHeight, QStringLiteral( "EkosWindowHeight" ) );
  KConfigCompilerSignallingItem  *itemEkosGeometry;
  KConfigSkeleton::ItemString  *innerItemEkosGeometry;
  innerItemEkosGeometry = new KConfigSkeleton::ItemString( currentGroup(), QStringLiteral( "EkosGeometry" ), mEkosGeometry );
  itemEkosGeometry = new KConfigCompilerSignallingItem(innerItemEkosGeometry, this, notifyFunction, signalEkosGeometryChanged);
  addItem( itemEkosGeometry, QStringLiteral( "EkosGeometry" ) );
  KConfigCompilerSignallingItem  *itemEkosTopIcons;
  KConfigSkeleton::ItemBool  *innerItemEkosTopIcons;
  innerItemEkosTopIcons = new KConfigSkeleton::ItemBool( currentGroup(), QStringLiteral( "EkosTopIcons" ), mEkosTopIcons, true );
  itemEkosTopIcons = new KConfigCompilerSignallingItem(innerItemEkosTopIcons, this, notifyFunction, signalEkosTopIconsChanged);
  addItem( itemEkosTopIcons, QStringLiteral( "EkosTopIcons" ) );
  KConfigCompilerSignallingItem  *itemEkosLeftIcons;
  KConfigSkeleton::ItemBool  *innerItemEkosLeftIcons;
  innerItemEkosLeftIcons = new KConfigSkeleton::ItemBool( currentGroup(), QStringLiteral( "EkosLeftIcons" ), mEkosLeftIcons, false );
  itemEkosLeftIcons = new KConfigCompilerSignallingItem(innerItemEkosLeftIcons, this, notifyFunction, signalEkosLeftIconsChanged);
  addItem( itemEkosLeftIcons, QStringLiteral( "EkosLeftIcons" ) );
  KConfigCompilerSignallingItem  *itemIndependentWindowEkos;
  KConfigSkeleton::ItemBool  *innerItemIndependentWindowEkos;
  innerItemIndependentWindowEkos = new KConfigSkeleton::ItemBool( currentGroup(), QStringLiteral( "independentWindowEkos" ), mIndependentWindowEkos, false );
  itemIndependentWindowEkos = new KConfigCompilerSignallingItem(innerItemIndependentWindowEkos, this, notifyFunction, signalIndependentWindowEkosChanged);
  addItem( itemIndependentWindowEkos, QStringLiteral( "independentWindowEkos" ) );
  KConfigCompilerSignallingItem  *itemProfile;
  KConfigSkeleton::ItemString  *innerItemProfile;
  innerItemProfile = new KConfigSkeleton::ItemString( currentGroup(), QStringLiteral( "profile" ), mProfile, QStringLiteral( "Simulators" ) );
  itemProfile = new KConfigCompilerSignallingItem(innerItemProfile, this, notifyFunction, signalProfileChanged);
  addItem( itemProfile, QStringLiteral( "profile" ) );
  KConfigCompilerSignallingItem  *itemNeverLoadConfig;
  KConfigSkeleton::ItemBool  *innerItemNeverLoadConfig;
  innerItemNeverLoadConfig = new KConfigSkeleton::ItemBool( currentGroup(), QStringLiteral( "neverLoadConfig" ), mNeverLoadConfig, false );
  itemNeverLoadConfig = new KConfigCompilerSignallingItem(innerItemNeverLoadConfig, this, notifyFunction, signalNeverLoadConfigChanged);
  addItem( itemNeverLoadConfig, QStringLiteral( "neverLoadConfig" ) );
  KConfigCompilerSignallingItem  *itemLoadConfigOnConnection;
  KConfigSkeleton::ItemBool  *innerItemLoadConfigOnConnection;
  innerItemLoadConfigOnConnection = new KConfigSkeleton::ItemBool( currentGroup(), QStringLiteral( "loadConfigOnConnection" ), mLoadConfigOnConnection, true );
  itemLoadConfigOnConnection = new KConfigCompilerSignallingItem(innerItemLoadConfigOnConnection, this, notifyFunction, signalLoadConfigOnConnectionChanged);
  addItem( itemLoadConfigOnConnection, QStringLiteral( "loadConfigOnConnection" ) );
  KConfigCompilerSignallingItem  *itemLoadDefaultConfig;
  KConfigSkeleton::ItemBool  *innerItemLoadDefaultConfig;
  innerItemLoadDefaultConfig = new KConfigSkeleton::ItemBool( currentGroup(), QStringLiteral( "loadDefaultConfig" ), mLoadDefaultConfig, false );
  itemLoadDefaultConfig = new KConfigCompilerSignallingItem(innerItemLoadDefaultConfig, this, notifyFunction, signalLoadDefaultConfigChanged);
  addItem( itemLoadDefaultConfig, QStringLiteral( "loadDefaultConfig" ) );
  KConfigCompilerSignallingItem  *itemAutoLoadSerialAssistant;
  KConfigSkeleton::ItemBool  *innerItemAutoLoadSerialAssistant;
  innerItemAutoLoadSerialAssistant = new KConfigSkeleton::ItemBool( currentGroup(), QStringLiteral( "autoLoadSerialAssistant" ), mAutoLoadSerialAssistant, true );
  itemAutoLoadSerialAssistant = new KConfigCompilerSignallingItem(innerItemAutoLoadSerialAssistant, this, notifyFunction, signalAutoLoadSerialAssistantChanged);
  addItem( itemAutoLoadSerialAssistant, QStringLiteral( "autoLoadSerialAssistant" ) );

  setCurrentGroup( QStringLiteral( "EkosLive" ) );

  KConfigCompilerSignallingItem  *itemRememberCredentials;
  KConfigSkeleton::ItemBool  *innerItemRememberCredentials;
  innerItemRememberCredentials = new KConfigSkeleton::ItemBool( currentGroup(), QStringLiteral( "RememberCredentials" ), mRememberCredentials, true );
  itemRememberCredentials = new KConfigCompilerSignallingItem(innerItemRememberCredentials, this, notifyFunction, signalRememberCredentialsChanged);
  addItem( itemRememberCredentials, QStringLiteral( "RememberCredentials" ) );
  KConfigCompilerSignallingItem  *itemAutoStartEkosLive;
  KConfigSkeleton::ItemBool  *innerItemAutoStartEkosLive;
  innerItemAutoStartEkosLive = new KConfigSkeleton::ItemBool( currentGroup(), QStringLiteral( "AutoStartEkosLive" ), mAutoStartEkosLive, true );
  itemAutoStartEkosLive = new KConfigCompilerSignallingItem(innerItemAutoStartEkosLive, this, notifyFunction, signalAutoStartEkosLiveChanged);
  addItem( itemAutoStartEkosLive, QStringLiteral( "AutoStartEkosLive" ) );
  KConfigCompilerSignallingItem  *itemEkosLiveUsername;
  KConfigSkeleton::ItemString  *innerItemEkosLiveUsername;
  innerItemEkosLiveUsername = new KConfigSkeleton::ItemString( currentGroup(), QStringLiteral( "EkosLiveUsername" ), mEkosLiveUsername );
  itemEkosLiveUsername = new KConfigCompilerSignallingItem(innerItemEkosLiveUsername, this, notifyFunction, signalEkosLiveUsernameChanged);
  addItem( itemEkosLiveUsername, QStringLiteral( "EkosLiveUsername" ) );
  KConfigCompilerSignallingItem  *itemEkosLiveObservatory;
  KConfigSkeleton::ItemString  *innerItemEkosLiveObservatory;
  innerItemEkosLiveObservatory = new KConfigSkeleton::ItemString( currentGroup(), QStringLiteral( "EkosLiveObservatory" ), mEkosLiveObservatory, QStringLiteral( "Home Observatory" ) );
  itemEkosLiveObservatory = new KConfigCompilerSignallingItem(innerItemEkosLiveObservatory, this, notifyFunction, signalEkosLiveObservatoryChanged);
  addItem( itemEkosLiveObservatory, QStringLiteral( "EkosLiveObservatory" ) );
  KConfigCompilerSignallingItem  *itemEkosLiveOfflineServer;
  KConfigSkeleton::ItemString  *innerItemEkosLiveOfflineServer;
  innerItemEkosLiveOfflineServer = new KConfigSkeleton::ItemString( currentGroup(), QStringLiteral( "EkosLiveOfflineServer" ), mEkosLiveOfflineServer, QStringLiteral( "http://localhost:3000" ) );
  itemEkosLiveOfflineServer = new KConfigCompilerSignallingItem(innerItemEkosLiveOfflineServer, this, notifyFunction, signalEkosLiveOfflineServerChanged);
  addItem( itemEkosLiveOfflineServer, QStringLiteral( "EkosLiveOfflineServer" ) );
  KConfigCompilerSignallingItem  *itemEkosLiveOnlineServer;
  KConfigSkeleton::ItemString  *innerItemEkosLiveOnlineServer;
  innerItemEkosLiveOnlineServer = new KConfigSkeleton::ItemString( currentGroup(), QStringLiteral( "EkosLiveOnlineServer" ), mEkosLiveOnlineServer, QStringLiteral( "https://ekoslive.com" ) );
  itemEkosLiveOnlineServer = new KConfigCompilerSignallingItem(innerItemEkosLiveOnlineServer, this, notifyFunction, signalEkosLiveOnlineServerChanged);
  addItem( itemEkosLiveOnlineServer, QStringLiteral( "EkosLiveOnlineServer" ) );
  KConfigCompilerSignallingItem  *itemEkosLiveSound;
  KConfigSkeleton::ItemBool  *innerItemEkosLiveSound;
  innerItemEkosLiveSound = new KConfigSkeleton::ItemBool( currentGroup(), QStringLiteral( "EkosLiveSound" ), mEkosLiveSound, true );
  itemEkosLiveSound = new KConfigCompilerSignallingItem(innerItemEkosLiveSound, this, notifyFunction, signalEkosLiveSoundChanged);
  addItem( itemEkosLiveSound, QStringLiteral( "EkosLiveSound" ) );
  KConfigCompilerSignallingItem  *itemEkosLiveNotifications;
  KConfigSkeleton::ItemBool  *innerItemEkosLiveNotifications;
  innerItemEkosLiveNotifications = new KConfigSkeleton::ItemBool( currentGroup(), QStringLiteral( "EkosLiveNotifications" ), mEkosLiveNotifications, true );
  itemEkosLiveNotifications = new KConfigCompilerSignallingItem(innerItemEkosLiveNotifications, this, notifyFunction, signalEkosLiveNotificationsChanged);
  addItem( itemEkosLiveNotifications, QStringLiteral( "EkosLiveNotifications" ) );
  KConfigCompilerSignallingItem  *itemEkosLiveCloud;
  KConfigSkeleton::ItemBool  *innerItemEkosLiveCloud;
  innerItemEkosLiveCloud = new KConfigSkeleton::ItemBool( currentGroup(), QStringLiteral( "EkosLiveCloud" ), mEkosLiveCloud, false );
  itemEkosLiveCloud = new KConfigCompilerSignallingItem(innerItemEkosLiveCloud, this, notifyFunction, signalEkosLiveCloudChanged);
  addItem( itemEkosLiveCloud, QStringLiteral( "EkosLiveCloud" ) );

  setCurrentGroup( QStringLiteral( "DarkLibrary" ) );

  KConfigCompilerSignallingItem  *itemMaxDarkTemperatureDiff;
  KConfigSkeleton::ItemDouble  *innerItemMaxDarkTemperatureDiff;
  innerItemMaxDarkTemperatureDiff = new KConfigSkeleton::ItemDouble( currentGroup(), QStringLiteral( "MaxDarkTemperatureDiff" ), mMaxDarkTemperatureDiff, 1 );
  itemMaxDarkTemperatureDiff = new KConfigCompilerSignallingItem(innerItemMaxDarkTemperatureDiff, this, notifyFunction, signalMaxDarkTemperatureDiffChanged);
  addItem( itemMaxDarkTemperatureDiff, QStringLiteral( "MaxDarkTemperatureDiff" ) );
  KConfigCompilerSignallingItem  *itemShutterfulCCDs;
  KConfigSkeleton::ItemStringList  *innerItemShutterfulCCDs;
  innerItemShutterfulCCDs = new KConfigSkeleton::ItemStringList( currentGroup(), QStringLiteral( "shutterfulCCDs" ), mShutterfulCCDs );
  itemShutterfulCCDs = new KConfigCompilerSignallingItem(innerItemShutterfulCCDs, this, notifyFunction, signalShutterfulCCDsChanged);
  addItem( itemShutterfulCCDs, QStringLiteral( "shutterfulCCDs" ) );
  KConfigCompilerSignallingItem  *itemShutterlessCCDs;
  KConfigSkeleton::ItemStringList  *innerItemShutterlessCCDs;
  innerItemShutterlessCCDs = new KConfigSkeleton::ItemStringList( currentGroup(), QStringLiteral( "shutterlessCCDs" ), mShutterlessCCDs );
  itemShutterlessCCDs = new KConfigCompilerSignallingItem(innerItemShutterlessCCDs, this, notifyFunction, signalShutterlessCCDsChanged);
  addItem( itemShutterlessCCDs, QStringLiteral( "shutterlessCCDs" ) );
  KConfigCompilerSignallingItem  *itemDarkLibraryDuration;
  KConfigSkeleton::ItemUInt  *innerItemDarkLibraryDuration;
  innerItemDarkLibraryDuration = new KConfigSkeleton::ItemUInt( currentGroup(), QStringLiteral( "DarkLibraryDuration" ), mDarkLibraryDuration, 30 );
  itemDarkLibraryDuration = new KConfigCompilerSignallingItem(innerItemDarkLibraryDuration, this, notifyFunction, signalDarkLibraryDurationChanged);
  addItem( itemDarkLibraryDuration, QStringLiteral( "DarkLibraryDuration" ) );

  setCurrentGroup( QStringLiteral( "Manager" ) );

  KConfigCompilerSignallingItem  *itemUseGraphicalCountsDisplay;
  KConfigSkeleton::ItemBool  *innerItemUseGraphicalCountsDisplay;
  innerItemUseGraphicalCountsDisplay = new KConfigSkeleton::ItemBool( currentGroup(), QStringLiteral( "UseGraphicalCountsDisplay" ), mUseGraphicalCountsDisplay, true );
  itemUseGraphicalCountsDisplay = new KConfigCompilerSignallingItem(innerItemUseGraphicalCountsDisplay, this, notifyFunction, signalUseGraphicalCountsDisplayChanged);
  addItem( itemUseGraphicalCountsDisplay, QStringLiteral( "UseGraphicalCountsDisplay" ) );

  setCurrentGroup( QStringLiteral( "Mount" ) );

  KConfigCompilerSignallingItem  *itemMinimumAltLimit;
  KConfigSkeleton::ItemDouble  *innerItemMinimumAltLimit;
  innerItemMinimumAltLimit = new KConfigSkeleton::ItemDouble( currentGroup(), QStringLiteral( "MinimumAltLimit" ), mMinimumAltLimit, 0 );
  itemMinimumAltLimit = new KConfigCompilerSignallingItem(innerItemMinimumAltLimit, this, notifyFunction, signalMinimumAltLimitChanged);
  addItem( itemMinimumAltLimit, QStringLiteral( "MinimumAltLimit" ) );
  KConfigCompilerSignallingItem  *itemMaximumAltLimit;
  KConfigSkeleton::ItemDouble  *innerItemMaximumAltLimit;
  innerItemMaximumAltLimit = new KConfigSkeleton::ItemDouble( currentGroup(), QStringLiteral( "MaximumAltLimit" ), mMaximumAltLimit, 90.0 );
  itemMaximumAltLimit = new KConfigCompilerSignallingItem(innerItemMaximumAltLimit, this, notifyFunction, signalMaximumAltLimitChanged);
  addItem( itemMaximumAltLimit, QStringLiteral( "MaximumAltLimit" ) );
  KConfigCompilerSignallingItem  *itemEnableAltitudeLimits;
  KConfigSkeleton::ItemBool  *innerItemEnableAltitudeLimits;
  innerItemEnableAltitudeLimits = new KConfigSkeleton::ItemBool( currentGroup(), QStringLiteral( "EnableAltitudeLimits" ), mEnableAltitudeLimits, false );
  itemEnableAltitudeLimits = new KConfigCompilerSignallingItem(innerItemEnableAltitudeLimits, this, notifyFunction, signalEnableAltitudeLimitsChanged);
  addItem( itemEnableAltitudeLimits, QStringLiteral( "EnableAltitudeLimits" ) );
  KConfigCompilerSignallingItem  *itemEnableAltitudeLimitsTrackingOnly;
  KConfigSkeleton::ItemBool  *innerItemEnableAltitudeLimitsTrackingOnly;
  innerItemEnableAltitudeLimitsTrackingOnly = new KConfigSkeleton::ItemBool( currentGroup(), QStringLiteral( "EnableAltitudeLimitsTrackingOnly" ), mEnableAltitudeLimitsTrackingOnly, false );
  itemEnableAltitudeLimitsTrackingOnly = new KConfigCompilerSignallingItem(innerItemEnableAltitudeLimitsTrackingOnly, this, notifyFunction, signalEnableAltitudeLimitsTrackingOnlyChanged);
  addItem( itemEnableAltitudeLimitsTrackingOnly, QStringLiteral( "EnableAltitudeLimitsTrackingOnly" ) );
  KConfigCompilerSignallingItem  *itemConfirmBelowHorizon;
  KConfigSkeleton::ItemBool  *innerItemConfirmBelowHorizon;
  innerItemConfirmBelowHorizon = new KConfigSkeleton::ItemBool( currentGroup(), QStringLiteral( "ConfirmBelowHorizon" ), mConfirmBelowHorizon, true );
  itemConfirmBelowHorizon = new KConfigCompilerSignallingItem(innerItemConfirmBelowHorizon, this, notifyFunction, signalConfirmBelowHorizonChanged);
  addItem( itemConfirmBelowHorizon, QStringLiteral( "ConfirmBelowHorizon" ) );
  KConfigCompilerSignallingItem  *itemMeridianFlipOffsetDegrees;
  KConfigSkeleton::ItemDouble  *innerItemMeridianFlipOffsetDegrees;
  innerItemMeridianFlipOffsetDegrees = new KConfigSkeleton::ItemDouble( currentGroup(), QStringLiteral( "MeridianFlipOffsetDegrees" ), mMeridianFlipOffsetDegrees, 5 );
  itemMeridianFlipOffsetDegrees = new KConfigCompilerSignallingItem(innerItemMeridianFlipOffsetDegrees, this, notifyFunction, signalMeridianFlipOffsetDegreesChanged);
  addItem( itemMeridianFlipOffsetDegrees, QStringLiteral( "MeridianFlipOffsetDegrees" ) );
  KConfigCompilerSignallingItem  *itemMaximumHaLimit;
  KConfigSkeleton::ItemDouble  *innerItemMaximumHaLimit;
  innerItemMaximumHaLimit = new KConfigSkeleton::ItemDouble( currentGroup(), QStringLiteral( "MaximumHaLimit" ), mMaximumHaLimit, 90.0 );
  itemMaximumHaLimit = new KConfigCompilerSignallingItem(innerItemMaximumHaLimit, this, notifyFunction, signalMaximumHaLimitChanged);
  addItem( itemMaximumHaLimit, QStringLiteral( "MaximumHaLimit" ) );
  KConfigCompilerSignallingItem  *itemEnableHaLimit;
  KConfigSkeleton::ItemBool  *innerItemEnableHaLimit;
  innerItemEnableHaLimit = new KConfigSkeleton::ItemBool( currentGroup(), QStringLiteral( "EnableHaLimit" ), mEnableHaLimit, false );
  itemEnableHaLimit = new KConfigCompilerSignallingItem(innerItemEnableHaLimit, this, notifyFunction, signalEnableHaLimitChanged);
  addItem( itemEnableHaLimit, QStringLiteral( "EnableHaLimit" ) );
  KConfigCompilerSignallingItem  *itemExecuteMeridianFlip;
  KConfigSkeleton::ItemBool  *innerItemExecuteMeridianFlip;
  innerItemExecuteMeridianFlip = new KConfigSkeleton::ItemBool( currentGroup(), QStringLiteral( "ExecuteMeridianFlip" ), mExecuteMeridianFlip, false );
  itemExecuteMeridianFlip = new KConfigCompilerSignallingItem(innerItemExecuteMeridianFlip, this, notifyFunction, signalExecuteMeridianFlipChanged);
  addItem( itemExecuteMeridianFlip, QStringLiteral( "ExecuteMeridianFlip" ) );
  KConfigCompilerSignallingItem  *itemLeftRightReversed;
  KConfigSkeleton::ItemBool  *innerItemLeftRightReversed;
  innerItemLeftRightReversed = new KConfigSkeleton::ItemBool( currentGroup(), QStringLiteral( "LeftRightReversed" ), mLeftRightReversed, false );
  itemLeftRightReversed = new KConfigCompilerSignallingItem(innerItemLeftRightReversed, this, notifyFunction, signalLeftRightReversedChanged);
  addItem( itemLeftRightReversed, QStringLiteral( "LeftRightReversed" ) );
  KConfigCompilerSignallingItem  *itemUpDownReversed;
  KConfigSkeleton::ItemBool  *innerItemUpDownReversed;
  innerItemUpDownReversed = new KConfigSkeleton::ItemBool( currentGroup(), QStringLiteral( "UpDownReversed" ), mUpDownReversed, false );
  itemUpDownReversed = new KConfigCompilerSignallingItem(innerItemUpDownReversed, this, notifyFunction, signalUpDownReversedChanged);
  addItem( itemUpDownReversed, QStringLiteral( "UpDownReversed" ) );
  KConfigCompilerSignallingItem  *itemParkEveryDay;
  KConfigSkeleton::ItemBool  *innerItemParkEveryDay;
  innerItemParkEveryDay = new KConfigSkeleton::ItemBool( currentGroup(), QStringLiteral( "ParkEveryDay" ), mParkEveryDay, false );
  itemParkEveryDay = new KConfigCompilerSignallingItem(innerItemParkEveryDay, this, notifyFunction, signalParkEveryDayChanged);
  addItem( itemParkEveryDay, QStringLiteral( "ParkEveryDay" ) );
  KConfigCompilerSignallingItem  *itemParkTime;
  KConfigSkeleton::ItemString  *innerItemParkTime;
  innerItemParkTime = new KConfigSkeleton::ItemString( currentGroup(), QStringLiteral( "ParkTime" ), mParkTime, QStringLiteral( "3:00 AM" ) );
  itemParkTime = new KConfigCompilerSignallingItem(innerItemParkTime, this, notifyFunction, signalParkTimeChanged);
  addItem( itemParkTime, QStringLiteral( "ParkTime" ) );

  setCurrentGroup( QStringLiteral( "Capture" ) );

  KConfigCompilerSignallingItem  *itemDefaultObserver;
  KConfigSkeleton::ItemString  *innerItemDefaultObserver;
  innerItemDefaultObserver = new KConfigSkeleton::ItemString( currentGroup(), QStringLiteral( "DefaultObserver" ), mDefaultObserver );
  itemDefaultObserver = new KConfigCompilerSignallingItem(innerItemDefaultObserver, this, notifyFunction, signalDefaultObserverChanged);
  addItem( itemDefaultObserver, QStringLiteral( "DefaultObserver" ) );
  KConfigCompilerSignallingItem  *itemSyncFOVPA;
  KConfigSkeleton::ItemBool  *innerItemSyncFOVPA;
  innerItemSyncFOVPA = new KConfigSkeleton::ItemBool( currentGroup(), QStringLiteral( "SyncFOVPA" ), mSyncFOVPA, false );
  itemSyncFOVPA = new KConfigCompilerSignallingItem(innerItemSyncFOVPA, this, notifyFunction, signalSyncFOVPAChanged);
  addItem( itemSyncFOVPA, QStringLiteral( "SyncFOVPA" ) );
  KConfigCompilerSignallingItem  *itemPAMultiplier;
  KConfigSkeleton::ItemDouble  *innerItemPAMultiplier;
  innerItemPAMultiplier = new KConfigSkeleton::ItemDouble( currentGroup(), QStringLiteral( "PAMultiplier" ), mPAMultiplier, 1 );
  itemPAMultiplier = new KConfigCompilerSignallingItem(innerItemPAMultiplier, this, notifyFunction, signalPAMultiplierChanged);
  addItem( itemPAMultiplier, QStringLiteral( "PAMultiplier" ) );
  KConfigCompilerSignallingItem  *itemPAOffset;
  KConfigSkeleton::ItemDouble  *innerItemPAOffset;
  innerItemPAOffset = new KConfigSkeleton::ItemDouble( currentGroup(), QStringLiteral( "PAOffset" ), mPAOffset, 0 );
  itemPAOffset = new KConfigCompilerSignallingItem(innerItemPAOffset, this, notifyFunction, signalPAOffsetChanged);
  addItem( itemPAOffset, QStringLiteral( "PAOffset" ) );
  KConfigCompilerSignallingItem  *itemPAPierSide;
  KConfigSkeleton::ItemUInt  *innerItemPAPierSide;
  innerItemPAPierSide = new KConfigSkeleton::ItemUInt( currentGroup(), QStringLiteral( "PAPierSide" ), mPAPierSide );
  itemPAPierSide = new KConfigCompilerSignallingItem(innerItemPAPierSide, this, notifyFunction, signalPAPierSideChanged);
  addItem( itemPAPierSide, QStringLiteral( "PAPierSide" ) );
  KConfigCompilerSignallingItem  *itemGuideDeviation;
  KConfigSkeleton::ItemDouble  *innerItemGuideDeviation;
  innerItemGuideDeviation = new KConfigSkeleton::ItemDouble( currentGroup(), QStringLiteral( "GuideDeviation" ), mGuideDeviation, 2 );
  itemGuideDeviation = new KConfigCompilerSignallingItem(innerItemGuideDeviation, this, notifyFunction, signalGuideDeviationChanged);
  addItem( itemGuideDeviation, QStringLiteral( "GuideDeviation" ) );
  KConfigCompilerSignallingItem  *itemGuideDeviationReps;
  KConfigSkeleton::ItemUInt  *innerItemGuideDeviationReps;
  innerItemGuideDeviationReps = new KConfigSkeleton::ItemUInt( currentGroup(), QStringLiteral( "GuideDeviationReps" ), mGuideDeviationReps, 3 );
  itemGuideDeviationReps = new KConfigCompilerSignallingItem(innerItemGuideDeviationReps, this, notifyFunction, signalGuideDeviationRepsChanged);
  addItem( itemGuideDeviationReps, QStringLiteral( "GuideDeviationReps" ) );
  KConfigCompilerSignallingItem  *itemStartGuideDeviation;
  KConfigSkeleton::ItemDouble  *innerItemStartGuideDeviation;
  innerItemStartGuideDeviation = new KConfigSkeleton::ItemDouble( currentGroup(), QStringLiteral( "StartGuideDeviation" ), mStartGuideDeviation, 2 );
  itemStartGuideDeviation = new KConfigCompilerSignallingItem(innerItemStartGuideDeviation, this, notifyFunction, signalStartGuideDeviationChanged);
  addItem( itemStartGuideDeviation, QStringLiteral( "StartGuideDeviation" ) );
  KConfigCompilerSignallingItem  *itemGuideDitherPerJobFrequency;
  KConfigSkeleton::ItemUInt  *innerItemGuideDitherPerJobFrequency;
  innerItemGuideDitherPerJobFrequency = new KConfigSkeleton::ItemUInt( currentGroup(), QStringLiteral( "GuideDitherPerJobFrequency" ), mGuideDitherPerJobFrequency, 0 );
  itemGuideDitherPerJobFrequency = new KConfigCompilerSignallingItem(innerItemGuideDitherPerJobFrequency, this, notifyFunction, signalGuideDitherPerJobFrequencyChanged);
  addItem( itemGuideDitherPerJobFrequency, QStringLiteral( "GuideDitherPerJobFrequency" ) );
  KConfigCompilerSignallingItem  *itemHFRDeviation;
  KConfigSkeleton::ItemDouble  *innerItemHFRDeviation;
  innerItemHFRDeviation = new KConfigSkeleton::ItemDouble( currentGroup(), QStringLiteral( "HFRDeviation" ), mHFRDeviation, 0.5 );
  itemHFRDeviation = new KConfigCompilerSignallingItem(innerItemHFRDeviation, this, notifyFunction, signalHFRDeviationChanged);
  addItem( itemHFRDeviation, QStringLiteral( "HFRDeviation" ) );
  KConfigCompilerSignallingItem  *itemMaxFocusTemperatureDelta;
  KConfigSkeleton::ItemDouble  *innerItemMaxFocusTemperatureDelta;
  innerItemMaxFocusTemperatureDelta = new KConfigSkeleton::ItemDouble( currentGroup(), QStringLiteral( "MaxFocusTemperatureDelta" ), mMaxFocusTemperatureDelta, 1 );
  itemMaxFocusTemperatureDelta = new KConfigCompilerSignallingItem(innerItemMaxFocusTemperatureDelta, this, notifyFunction, signalMaxFocusTemperatureDeltaChanged);
  addItem( itemMaxFocusTemperatureDelta, QStringLiteral( "MaxFocusTemperatureDelta" ) );
  KConfigCompilerSignallingItem  *itemAutoDark;
  KConfigSkeleton::ItemBool  *innerItemAutoDark;
  innerItemAutoDark = new KConfigSkeleton::ItemBool( currentGroup(), QStringLiteral( "AutoDark" ), mAutoDark, false );
  itemAutoDark = new KConfigCompilerSignallingItem(innerItemAutoDark, this, notifyFunction, signalAutoDarkChanged);
  addItem( itemAutoDark, QStringLiteral( "AutoDark" ) );
  KConfigCompilerSignallingItem  *itemEnforceGuideDeviation;
  KConfigSkeleton::ItemBool  *innerItemEnforceGuideDeviation;
  innerItemEnforceGuideDeviation = new KConfigSkeleton::ItemBool( currentGroup(), QStringLiteral( "EnforceGuideDeviation" ), mEnforceGuideDeviation, false );
  itemEnforceGuideDeviation = new KConfigCompilerSignallingItem(innerItemEnforceGuideDeviation, this, notifyFunction, signalEnforceGuideDeviationChanged);
  addItem( itemEnforceGuideDeviation, QStringLiteral( "EnforceGuideDeviation" ) );
  KConfigCompilerSignallingItem  *itemEnforceAutofocusHFR;
  KConfigSkeleton::ItemBool  *innerItemEnforceAutofocusHFR;
  innerItemEnforceAutofocusHFR = new KConfigSkeleton::ItemBool( currentGroup(), QStringLiteral( "EnforceAutofocusHFR" ), mEnforceAutofocusHFR, false );
  itemEnforceAutofocusHFR = new KConfigCompilerSignallingItem(innerItemEnforceAutofocusHFR, this, notifyFunction, signalEnforceAutofocusHFRChanged);
  addItem( itemEnforceAutofocusHFR, QStringLiteral( "EnforceAutofocusHFR" ) );
  KConfigCompilerSignallingItem  *itemEnforceAutofocusOnTemperature;
  KConfigSkeleton::ItemBool  *innerItemEnforceAutofocusOnTemperature;
  innerItemEnforceAutofocusOnTemperature = new KConfigSkeleton::ItemBool( currentGroup(), QStringLiteral( "EnforceAutofocusOnTemperature" ), mEnforceAutofocusOnTemperature, false );
  itemEnforceAutofocusOnTemperature = new KConfigCompilerSignallingItem(innerItemEnforceAutofocusOnTemperature, this, notifyFunction, signalEnforceAutofocusOnTemperatureChanged);
  addItem( itemEnforceAutofocusOnTemperature, QStringLiteral( "EnforceAutofocusOnTemperature" ) );
  KConfigCompilerSignallingItem  *itemEnforceRefocusEveryN;
  KConfigSkeleton::ItemBool  *innerItemEnforceRefocusEveryN;
  innerItemEnforceRefocusEveryN = new KConfigSkeleton::ItemBool( currentGroup(), QStringLiteral( "EnforceRefocusEveryN" ), mEnforceRefocusEveryN, false );
  itemEnforceRefocusEveryN = new KConfigCompilerSignallingItem(innerItemEnforceRefocusEveryN, this, notifyFunction, signalEnforceRefocusEveryNChanged);
  addItem( itemEnforceRefocusEveryN, QStringLiteral( "EnforceRefocusEveryN" ) );
  KConfigCompilerSignallingItem  *itemRefocusEveryN;
  KConfigSkeleton::ItemUInt  *innerItemRefocusEveryN;
  innerItemRefocusEveryN = new KConfigSkeleton::ItemUInt( currentGroup(), QStringLiteral( "RefocusEveryN" ), mRefocusEveryN, 60 );
  itemRefocusEveryN = new KConfigCompilerSignallingItem(innerItemRefocusEveryN, this, notifyFunction, signalRefocusEveryNChanged);
  addItem( itemRefocusEveryN, QStringLiteral( "RefocusEveryN" ) );
  KConfigCompilerSignallingItem  *itemRefocusAfterMeridianFlip;
  KConfigSkeleton::ItemBool  *innerItemRefocusAfterMeridianFlip;
  innerItemRefocusAfterMeridianFlip = new KConfigSkeleton::ItemBool( currentGroup(), QStringLiteral( "RefocusAfterMeridianFlip" ), mRefocusAfterMeridianFlip, false );
  itemRefocusAfterMeridianFlip = new KConfigCompilerSignallingItem(innerItemRefocusAfterMeridianFlip, this, notifyFunction, signalRefocusAfterMeridianFlipChanged);
  addItem( itemRefocusAfterMeridianFlip, QStringLiteral( "RefocusAfterMeridianFlip" ) );
  KConfigCompilerSignallingItem  *itemResetMountModelAfterMeridian;
  KConfigSkeleton::ItemBool  *innerItemResetMountModelAfterMeridian;
  innerItemResetMountModelAfterMeridian = new KConfigSkeleton::ItemBool( currentGroup(), QStringLiteral( "ResetMountModelAfterMeridian" ), mResetMountModelAfterMeridian, true );
  itemResetMountModelAfterMeridian = new KConfigCompilerSignallingItem(innerItemResetMountModelAfterMeridian, this, notifyFunction, signalResetMountModelAfterMeridianChanged);
  addItem( itemResetMountModelAfterMeridian, QStringLiteral( "ResetMountModelAfterMeridian" ) );
  KConfigCompilerSignallingItem  *itemForcedFlip;
  KConfigSkeleton::ItemBool  *innerItemForcedFlip;
  innerItemForcedFlip = new KConfigSkeleton::ItemBool( currentGroup(), QStringLiteral( "ForcedFlip" ), mForcedFlip, false );
  itemForcedFlip = new KConfigCompilerSignallingItem(innerItemForcedFlip, this, notifyFunction, signalForcedFlipChanged);
  addItem( itemForcedFlip, QStringLiteral( "ForcedFlip" ) );
  KConfigCompilerSignallingItem  *itemCalibrationADUValue;
  KConfigSkeleton::ItemUInt  *innerItemCalibrationADUValue;
  innerItemCalibrationADUValue = new KConfigSkeleton::ItemUInt( currentGroup(), QStringLiteral( "CalibrationADUValue" ), mCalibrationADUValue, 0 );
  itemCalibrationADUValue = new KConfigCompilerSignallingItem(innerItemCalibrationADUValue, this, notifyFunction, signalCalibrationADUValueChanged);
  addItem( itemCalibrationADUValue, QStringLiteral( "CalibrationADUValue" ) );
  KConfigCompilerSignallingItem  *itemCalibrationADUValueTolerance;
  KConfigSkeleton::ItemUInt  *innerItemCalibrationADUValueTolerance;
  innerItemCalibrationADUValueTolerance = new KConfigSkeleton::ItemUInt( currentGroup(), QStringLiteral( "CalibrationADUValueTolerance" ), mCalibrationADUValueTolerance, 1000 );
  itemCalibrationADUValueTolerance = new KConfigCompilerSignallingItem(innerItemCalibrationADUValueTolerance, this, notifyFunction, signalCalibrationADUValueToleranceChanged);
  addItem( itemCalibrationADUValueTolerance, QStringLiteral( "CalibrationADUValueTolerance" ) );
  KConfigCompilerSignallingItem  *itemCalibrationPreActionIndex;
  KConfigSkeleton::ItemUInt  *innerItemCalibrationPreActionIndex;
  innerItemCalibrationPreActionIndex = new KConfigSkeleton::ItemUInt( currentGroup(), QStringLiteral( "CalibrationPreActionIndex" ), mCalibrationPreActionIndex, 0 );
  itemCalibrationPreActionIndex = new KConfigCompilerSignallingItem(innerItemCalibrationPreActionIndex, this, notifyFunction, signalCalibrationPreActionIndexChanged);
  addItem( itemCalibrationPreActionIndex, QStringLiteral( "CalibrationPreActionIndex" ) );
  KConfigCompilerSignallingItem  *itemCalibrationFlatDurationIndex;
  KConfigSkeleton::ItemUInt  *innerItemCalibrationFlatDurationIndex;
  innerItemCalibrationFlatDurationIndex = new KConfigSkeleton::ItemUInt( currentGroup(), QStringLiteral( "CalibrationFlatDurationIndex" ), mCalibrationFlatDurationIndex, 0 );
  itemCalibrationFlatDurationIndex = new KConfigCompilerSignallingItem(innerItemCalibrationFlatDurationIndex, this, notifyFunction, signalCalibrationFlatDurationIndexChanged);
  addItem( itemCalibrationFlatDurationIndex, QStringLiteral( "CalibrationFlatDurationIndex" ) );
  KConfigCompilerSignallingItem  *itemCalibrationWallAz;
  KConfigSkeleton::ItemDouble  *innerItemCalibrationWallAz;
  innerItemCalibrationWallAz = new KConfigSkeleton::ItemDouble( currentGroup(), QStringLiteral( "CalibrationWallAz" ), mCalibrationWallAz, 0 );
  itemCalibrationWallAz = new KConfigCompilerSignallingItem(innerItemCalibrationWallAz, this, notifyFunction, signalCalibrationWallAzChanged);
  addItem( itemCalibrationWallAz, QStringLiteral( "CalibrationWallAz" ) );
  KConfigCompilerSignallingItem  *itemCalibrationWallAlt;
  KConfigSkeleton::ItemDouble  *innerItemCalibrationWallAlt;
  innerItemCalibrationWallAlt = new KConfigSkeleton::ItemDouble( currentGroup(), QStringLiteral( "CalibrationWallAlt" ), mCalibrationWallAlt, 0 );
  itemCalibrationWallAlt = new KConfigCompilerSignallingItem(innerItemCalibrationWallAlt, this, notifyFunction, signalCalibrationWallAltChanged);
  addItem( itemCalibrationWallAlt, QStringLiteral( "CalibrationWallAlt" ) );
  KConfigCompilerSignallingItem  *itemMaxTemperatureDiff;
  KConfigSkeleton::ItemDouble  *innerItemMaxTemperatureDiff;
  innerItemMaxTemperatureDiff = new KConfigSkeleton::ItemDouble( currentGroup(), QStringLiteral( "MaxTemperatureDiff" ), mMaxTemperatureDiff, 1 );
  itemMaxTemperatureDiff = new KConfigCompilerSignallingItem(innerItemMaxTemperatureDiff, this, notifyFunction, signalMaxTemperatureDiffChanged);
  addItem( itemMaxTemperatureDiff, QStringLiteral( "MaxTemperatureDiff" ) );
  KConfigCompilerSignallingItem  *itemMaxStartGuiderDrift;
  KConfigSkeleton::ItemDouble  *innerItemMaxStartGuiderDrift;
  innerItemMaxStartGuiderDrift = new KConfigSkeleton::ItemDouble( currentGroup(), QStringLiteral( "MaxStartGuiderDrift" ), mMaxStartGuiderDrift, 2 );
  itemMaxStartGuiderDrift = new KConfigCompilerSignallingItem(innerItemMaxStartGuiderDrift, this, notifyFunction, signalMaxStartGuiderDriftChanged);
  addItem( itemMaxStartGuiderDrift, QStringLiteral( "MaxStartGuiderDrift" ) );
  KConfigCompilerSignallingItem  *itemEnforceStartGuiderDrift;
  KConfigSkeleton::ItemBool  *innerItemEnforceStartGuiderDrift;
  innerItemEnforceStartGuiderDrift = new KConfigSkeleton::ItemBool( currentGroup(), QStringLiteral( "EnforceStartGuiderDrift" ), mEnforceStartGuiderDrift, false );
  itemEnforceStartGuiderDrift = new KConfigCompilerSignallingItem(innerItemEnforceStartGuiderDrift, this, notifyFunction, signalEnforceStartGuiderDriftChanged);
  addItem( itemEnforceStartGuiderDrift, QStringLiteral( "EnforceStartGuiderDrift" ) );
  KConfigCompilerSignallingItem  *itemGuidingSettle;
  KConfigSkeleton::ItemDouble  *innerItemGuidingSettle;
  innerItemGuidingSettle = new KConfigSkeleton::ItemDouble( currentGroup(), QStringLiteral( "GuidingSettle" ), mGuidingSettle, 0 );
  itemGuidingSettle = new KConfigCompilerSignallingItem(innerItemGuidingSettle, this, notifyFunction, signalGuidingSettleChanged);
  addItem( itemGuidingSettle, QStringLiteral( "GuidingSettle" ) );
  KConfigCompilerSignallingItem  *itemAlwaysResetSequenceWhenStarting;
  KConfigSkeleton::ItemBool  *innerItemAlwaysResetSequenceWhenStarting;
  innerItemAlwaysResetSequenceWhenStarting = new KConfigSkeleton::ItemBool( currentGroup(), QStringLiteral( "AlwaysResetSequenceWhenStarting" ), mAlwaysResetSequenceWhenStarting, false );
  itemAlwaysResetSequenceWhenStarting = new KConfigCompilerSignallingItem(innerItemAlwaysResetSequenceWhenStarting, this, notifyFunction, signalAlwaysResetSequenceWhenStartingChanged);
  addItem( itemAlwaysResetSequenceWhenStarting, QStringLiteral( "AlwaysResetSequenceWhenStarting" ) );
  KConfigCompilerSignallingItem  *itemFlatSyncFocus;
  KConfigSkeleton::ItemBool  *innerItemFlatSyncFocus;
  innerItemFlatSyncFocus = new KConfigSkeleton::ItemBool( currentGroup(), QStringLiteral( "FlatSyncFocus" ), mFlatSyncFocus, false );
  itemFlatSyncFocus = new KConfigCompilerSignallingItem(innerItemFlatSyncFocus, this, notifyFunction, signalFlatSyncFocusChanged);
  addItem( itemFlatSyncFocus, QStringLiteral( "FlatSyncFocus" ) );
  KConfigCompilerSignallingItem  *itemHFRThresholdPercentage;
  KConfigSkeleton::ItemDouble  *innerItemHFRThresholdPercentage;
  innerItemHFRThresholdPercentage = new KConfigSkeleton::ItemDouble( currentGroup(), QStringLiteral( "HFRThresholdPercentage" ), mHFRThresholdPercentage, 10 );
  itemHFRThresholdPercentage = new KConfigCompilerSignallingItem(innerItemHFRThresholdPercentage, this, notifyFunction, signalHFRThresholdPercentageChanged);
  addItem( itemHFRThresholdPercentage, QStringLiteral( "HFRThresholdPercentage" ) );
  KConfigCompilerSignallingItem  *itemHFRCheckAlgorithm;
  KConfigSkeleton::ItemInt  *innerItemHFRCheckAlgorithm;
  innerItemHFRCheckAlgorithm = new KConfigSkeleton::ItemInt( currentGroup(), QStringLiteral( "HFRCheckAlgorithm" ), mHFRCheckAlgorithm, 0 );
  itemHFRCheckAlgorithm = new KConfigCompilerSignallingItem(innerItemHFRCheckAlgorithm, this, notifyFunction, signalHFRCheckAlgorithmChanged);
  addItem( itemHFRCheckAlgorithm, QStringLiteral( "HFRCheckAlgorithm" ) );
  KConfigCompilerSignallingItem  *itemInSequenceCheckFrames;
  KConfigSkeleton::ItemUInt  *innerItemInSequenceCheckFrames;
  innerItemInSequenceCheckFrames = new KConfigSkeleton::ItemUInt( currentGroup(), QStringLiteral( "InSequenceCheckFrames" ), mInSequenceCheckFrames, 1 );
  itemInSequenceCheckFrames = new KConfigCompilerSignallingItem(innerItemInSequenceCheckFrames, this, notifyFunction, signalInSequenceCheckFramesChanged);
  addItem( itemInSequenceCheckFrames, QStringLiteral( "InSequenceCheckFrames" ) );
  KConfigCompilerSignallingItem  *itemAutoStretch;
  KConfigSkeleton::ItemBool  *innerItemAutoStretch;
  innerItemAutoStretch = new KConfigSkeleton::ItemBool( currentGroup(), QStringLiteral( "AutoStretch" ), mAutoStretch, true );
  itemAutoStretch = new KConfigCompilerSignallingItem(innerItemAutoStretch, this, notifyFunction, signalAutoStretchChanged);
  addItem( itemAutoStretch, QStringLiteral( "AutoStretch" ) );
  KConfigCompilerSignallingItem  *itemStretchPreviewSampling;
  KConfigSkeleton::ItemUInt  *innerItemStretchPreviewSampling;
  innerItemStretchPreviewSampling = new KConfigSkeleton::ItemUInt( currentGroup(), QStringLiteral( "StretchPreviewSampling" ), mStretchPreviewSampling, 4 );
  itemStretchPreviewSampling = new KConfigCompilerSignallingItem(innerItemStretchPreviewSampling, this, notifyFunction, signalStretchPreviewSamplingChanged);
  addItem( itemStretchPreviewSampling, QStringLiteral( "StretchPreviewSampling" ) );
  KConfigCompilerSignallingItem  *itemClipping64KValue;
  KConfigSkeleton::ItemUInt  *innerItemClipping64KValue;
  innerItemClipping64KValue = new KConfigSkeleton::ItemUInt( currentGroup(), QStringLiteral( "Clipping64KValue" ), mClipping64KValue, 60000 );
  itemClipping64KValue = new KConfigCompilerSignallingItem(innerItemClipping64KValue, this, notifyFunction, signalClipping64KValueChanged);
  addItem( itemClipping64KValue, QStringLiteral( "Clipping64KValue" ) );
  KConfigCompilerSignallingItem  *itemClipping256Value;
  KConfigSkeleton::ItemUInt  *innerItemClipping256Value;
  innerItemClipping256Value = new KConfigSkeleton::ItemUInt( currentGroup(), QStringLiteral( "Clipping256Value" ), mClipping256Value, 250 );
  itemClipping256Value = new KConfigCompilerSignallingItem(innerItemClipping256Value, this, notifyFunction, signalClipping256ValueChanged);
  addItem( itemClipping256Value, QStringLiteral( "Clipping256Value" ) );
  KConfigCompilerSignallingItem  *itemAdaptiveSampling;
  KConfigSkeleton::ItemBool  *innerItemAdaptiveSampling;
  innerItemAdaptiveSampling = new KConfigSkeleton::ItemBool( currentGroup(), QStringLiteral( "AdaptiveSampling" ), mAdaptiveSampling, true );
  itemAdaptiveSampling = new KConfigCompilerSignallingItem(innerItemAdaptiveSampling, this, notifyFunction, signalAdaptiveSamplingChanged);
  addItem( itemAdaptiveSampling, QStringLiteral( "AdaptiveSampling" ) );
  KConfigCompilerSignallingItem  *itemUseSummaryPreview;
  KConfigSkeleton::ItemBool  *innerItemUseSummaryPreview;
  innerItemUseSummaryPreview = new KConfigSkeleton::ItemBool( currentGroup(), QStringLiteral( "useSummaryPreview" ), mUseSummaryPreview, !KSUtils::isHardwareLimited() );
  itemUseSummaryPreview = new KConfigCompilerSignallingItem(innerItemUseSummaryPreview, this, notifyFunction, signalUseSummaryPreviewChanged);
  addItem( itemUseSummaryPreview, QStringLiteral( "useSummaryPreview" ) );
  KConfigCompilerSignallingItem  *itemUseDSLRImageViewer;
  KConfigSkeleton::ItemBool  *innerItemUseDSLRImageViewer;
  innerItemUseDSLRImageViewer = new KConfigSkeleton::ItemBool( currentGroup(), QStringLiteral( "useDSLRImageViewer" ), mUseDSLRImageViewer, !KSUtils::isHardwareLimited() );
  itemUseDSLRImageViewer = new KConfigCompilerSignallingItem(innerItemUseDSLRImageViewer, this, notifyFunction, signalUseDSLRImageViewerChanged);
  addItem( itemUseDSLRImageViewer, QStringLiteral( "useDSLRImageViewer" ) );
  KConfigCompilerSignallingItem  *itemForceDSLRPresets;
  KConfigSkeleton::ItemBool  *innerItemForceDSLRPresets;
  innerItemForceDSLRPresets = new KConfigSkeleton::ItemBool( currentGroup(), QStringLiteral( "ForceDSLRPresets" ), mForceDSLRPresets, true );
  itemForceDSLRPresets = new KConfigCompilerSignallingItem(innerItemForceDSLRPresets, this, notifyFunction, signalForceDSLRPresetsChanged);
  addItem( itemForceDSLRPresets, QStringLiteral( "ForceDSLRPresets" ) );
  KConfigCompilerSignallingItem  *itemCaptureDirectory;
  KConfigSkeleton::ItemString  *innerItemCaptureDirectory;
  innerItemCaptureDirectory = new KConfigSkeleton::ItemString( currentGroup(), QStringLiteral( "CaptureDirectory" ), mCaptureDirectory );
  itemCaptureDirectory = new KConfigCompilerSignallingItem(innerItemCaptureDirectory, this, notifyFunction, signalCaptureDirectoryChanged);
  addItem( itemCaptureDirectory, QStringLiteral( "CaptureDirectory" ) );
  KConfigCompilerSignallingItem  *itemPlaceholderFormat;
  KConfigSkeleton::ItemString  *innerItemPlaceholderFormat;
  innerItemPlaceholderFormat = new KConfigSkeleton::ItemString( currentGroup(), QStringLiteral( "PlaceholderFormat" ), mPlaceholderFormat, KSUtils::getDefaultPath("PlaceholderFormat") );
  itemPlaceholderFormat = new KConfigCompilerSignallingItem(innerItemPlaceholderFormat, this, notifyFunction, signalPlaceholderFormatChanged);
  addItem( itemPlaceholderFormat, QStringLiteral( "PlaceholderFormat" ) );
  KConfigCompilerSignallingItem  *itemRemoteCaptureDirectory;
  KConfigSkeleton::ItemString  *innerItemRemoteCaptureDirectory;
  innerItemRemoteCaptureDirectory = new KConfigSkeleton::ItemString( currentGroup(), QStringLiteral( "RemoteCaptureDirectory" ), mRemoteCaptureDirectory );
  itemRemoteCaptureDirectory = new KConfigCompilerSignallingItem(innerItemRemoteCaptureDirectory, this, notifyFunction, signalRemoteCaptureDirectoryChanged);
  addItem( itemRemoteCaptureDirectory, QStringLiteral( "RemoteCaptureDirectory" ) );
  KConfigCompilerSignallingItem  *itemManualCoverTimeout;
  KConfigSkeleton::ItemUInt  *innerItemManualCoverTimeout;
  innerItemManualCoverTimeout = new KConfigSkeleton::ItemUInt( currentGroup(), QStringLiteral( "ManualCoverTimeout" ), mManualCoverTimeout, 60 );
  itemManualCoverTimeout = new KConfigCompilerSignallingItem(innerItemManualCoverTimeout, this, notifyFunction, signalManualCoverTimeoutChanged);
  addItem( itemManualCoverTimeout, QStringLiteral( "ManualCoverTimeout" ) );
  KConfigCompilerSignallingItem  *itemCaptureOperationsTimeout;
  KConfigSkeleton::ItemUInt  *innerItemCaptureOperationsTimeout;
  innerItemCaptureOperationsTimeout = new KConfigSkeleton::ItemUInt( currentGroup(), QStringLiteral( "CaptureOperationsTimeout" ), mCaptureOperationsTimeout, 300 );
  itemCaptureOperationsTimeout = new KConfigCompilerSignallingItem(innerItemCaptureOperationsTimeout, this, notifyFunction, signalCaptureOperationsTimeoutChanged);
  addItem( itemCaptureOperationsTimeout, QStringLiteral( "CaptureOperationsTimeout" ) );
  KConfigCompilerSignallingItem  *itemMinFlipDuration;
  KConfigSkeleton::ItemUInt  *innerItemMinFlipDuration;
  innerItemMinFlipDuration = new KConfigSkeleton::ItemUInt( currentGroup(), QStringLiteral( "MinFlipDuration" ), mMinFlipDuration, 20 );
  itemMinFlipDuration = new KConfigCompilerSignallingItem(innerItemMinFlipDuration, this, notifyFunction, signalMinFlipDurationChanged);
  addItem( itemMinFlipDuration, QStringLiteral( "MinFlipDuration" ) );
  KConfigCompilerSignallingItem  *itemCapturePosition;
  KConfigSkeleton::ItemBool  *innerItemCapturePosition;
  innerItemCapturePosition = new KConfigSkeleton::ItemBool( currentGroup(), QStringLiteral( "CapturePosition" ), mCapturePosition, false );
  itemCapturePosition = new KConfigCompilerSignallingItem(innerItemCapturePosition, this, notifyFunction, signalCapturePositionChanged);
  addItem( itemCapturePosition, QStringLiteral( "CapturePosition" ) );
  KConfigCompilerSignallingItem  *itemCaptureTrainID;
  KConfigSkeleton::ItemUInt  *innerItemCaptureTrainID;
  innerItemCaptureTrainID = new KConfigSkeleton::ItemUInt( currentGroup(), QStringLiteral( "CaptureTrainID" ), mCaptureTrainID );
  itemCaptureTrainID = new KConfigCompilerSignallingItem(innerItemCaptureTrainID, this, notifyFunction, signalCaptureTrainIDChanged);
  addItem( itemCaptureTrainID, QStringLiteral( "CaptureTrainID" ) );
  KConfigCompilerSignallingItem  *itemCaptureCalibrationWall;
  KConfigSkeleton::ItemBool  *innerItemCaptureCalibrationWall;
  innerItemCaptureCalibrationWall = new KConfigSkeleton::ItemBool( currentGroup(), QStringLiteral( "CaptureCalibrationWall" ), mCaptureCalibrationWall, false );
  itemCaptureCalibrationWall = new KConfigCompilerSignallingItem(innerItemCaptureCalibrationWall, this, notifyFunction, signalCaptureCalibrationWallChanged);
  addItem( itemCaptureCalibrationWall, QStringLiteral( "CaptureCalibrationWall" ) );
  KConfigCompilerSignallingItem  *itemCaptureCalibrationParkMount;
  KConfigSkeleton::ItemBool  *innerItemCaptureCalibrationParkMount;
  innerItemCaptureCalibrationParkMount = new KConfigSkeleton::ItemBool( currentGroup(), QStringLiteral( "CaptureCalibrationParkMount" ), mCaptureCalibrationParkMount, false );
  itemCaptureCalibrationParkMount = new KConfigCompilerSignallingItem(innerItemCaptureCalibrationParkMount, this, notifyFunction, signalCaptureCalibrationParkMountChanged);
  addItem( itemCaptureCalibrationParkMount, QStringLiteral( "CaptureCalibrationParkMount" ) );
  KConfigCompilerSignallingItem  *itemCaptureCalibrationParkDome;
  KConfigSkeleton::ItemBool  *innerItemCaptureCalibrationParkDome;
  innerItemCaptureCalibrationParkDome = new KConfigSkeleton::ItemBool( currentGroup(), QStringLiteral( "CaptureCalibrationParkDome" ), mCaptureCalibrationParkDome, false );
  itemCaptureCalibrationParkDome = new KConfigCompilerSignallingItem(innerItemCaptureCalibrationParkDome, this, notifyFunction, signalCaptureCalibrationParkDomeChanged);
  addItem( itemCaptureCalibrationParkDome, QStringLiteral( "CaptureCalibrationParkDome" ) );
  KConfigCompilerSignallingItem  *itemCaptureCalibrationUseManual;
  KConfigSkeleton::ItemBool  *innerItemCaptureCalibrationUseManual;
  innerItemCaptureCalibrationUseManual = new KConfigSkeleton::ItemBool( currentGroup(), QStringLiteral( "CaptureCalibrationUseManual" ), mCaptureCalibrationUseManual, false );
  itemCaptureCalibrationUseManual = new KConfigCompilerSignallingItem(innerItemCaptureCalibrationUseManual, this, notifyFunction, signalCaptureCalibrationUseManualChanged);
  addItem( itemCaptureCalibrationUseManual, QStringLiteral( "CaptureCalibrationUseManual" ) );
  KConfigCompilerSignallingItem  *itemCaptureCalibrationUseADU;
  KConfigSkeleton::ItemBool  *innerItemCaptureCalibrationUseADU;
  innerItemCaptureCalibrationUseADU = new KConfigSkeleton::ItemBool( currentGroup(), QStringLiteral( "CaptureCalibrationUseADU" ), mCaptureCalibrationUseADU, false );
  itemCaptureCalibrationUseADU = new KConfigCompilerSignallingItem(innerItemCaptureCalibrationUseADU, this, notifyFunction, signalCaptureCalibrationUseADUChanged);
  addItem( itemCaptureCalibrationUseADU, QStringLiteral( "CaptureCalibrationUseADU" ) );
  KConfigCompilerSignallingItem  *itemCaptureCalibrationADUValue;
  KConfigSkeleton::ItemDouble  *innerItemCaptureCalibrationADUValue;
  innerItemCaptureCalibrationADUValue = new KConfigSkeleton::ItemDouble( currentGroup(), QStringLiteral( "CaptureCalibrationADUValue" ), mCaptureCalibrationADUValue, 0 );
  itemCaptureCalibrationADUValue = new KConfigCompilerSignallingItem(innerItemCaptureCalibrationADUValue, this, notifyFunction, signalCaptureCalibrationADUValueChanged);
  addItem( itemCaptureCalibrationADUValue, QStringLiteral( "CaptureCalibrationADUValue" ) );
  KConfigCompilerSignallingItem  *itemCaptureCalibrationADUTolerance;
  KConfigSkeleton::ItemDouble  *innerItemCaptureCalibrationADUTolerance;
  innerItemCaptureCalibrationADUTolerance = new KConfigSkeleton::ItemDouble( currentGroup(), QStringLiteral( "CaptureCalibrationADUTolerance" ), mCaptureCalibrationADUTolerance, 1000 );
  itemCaptureCalibrationADUTolerance = new KConfigCompilerSignallingItem(innerItemCaptureCalibrationADUTolerance, this, notifyFunction, signalCaptureCalibrationADUToleranceChanged);
  addItem( itemCaptureCalibrationADUTolerance, QStringLiteral( "CaptureCalibrationADUTolerance" ) );
  KConfigCompilerSignallingItem  *itemCaptureCalibrationSkyFlats;
  KConfigSkeleton::ItemBool  *innerItemCaptureCalibrationSkyFlats;
  innerItemCaptureCalibrationSkyFlats = new KConfigSkeleton::ItemBool( currentGroup(), QStringLiteral( "CaptureCalibrationSkyFlats" ), mCaptureCalibrationSkyFlats, false );
  itemCaptureCalibrationSkyFlats = new KConfigCompilerSignallingItem(innerItemCaptureCalibrationSkyFlats, this, notifyFunction, signalCaptureCalibrationSkyFlatsChanged);
  addItem( itemCaptureCalibrationSkyFlats, QStringLiteral( "CaptureCalibrationSkyFlats" ) );

  setCurrentGroup( QStringLiteral( "Focus" ) );

  KConfigCompilerSignallingItem  *itemAbsTicksSpin;
  KConfigSkeleton::ItemUInt  *innerItemAbsTicksSpin;
  innerItemAbsTicksSpin = new KConfigSkeleton::ItemUInt( currentGroup(), QStringLiteral( "AbsTicksSpin" ), mAbsTicksSpin, 0 );
  itemAbsTicksSpin = new KConfigCompilerSignallingItem(innerItemAbsTicksSpin, this, notifyFunction, signalAbsTicksSpinChanged);
  addItem( itemAbsTicksSpin, QStringLiteral( "AbsTicksSpin" ) );
  KConfigCompilerSignallingItem  *itemFocusExposure;
  KConfigSkeleton::ItemDouble  *innerItemFocusExposure;
  innerItemFocusExposure = new KConfigSkeleton::ItemDouble( currentGroup(), QStringLiteral( "FocusExposure" ), mFocusExposure, 2.0 );
  itemFocusExposure = new KConfigCompilerSignallingItem(innerItemFocusExposure, this, notifyFunction, signalFocusExposureChanged);
  addItem( itemFocusExposure, QStringLiteral( "FocusExposure" ) );
  KConfigCompilerSignallingItem  *itemFocusBinning;
  KConfigSkeleton::ItemString  *innerItemFocusBinning;
  innerItemFocusBinning = new KConfigSkeleton::ItemString( currentGroup(), QStringLiteral( "FocusBinning" ), mFocusBinning, QStringLiteral( "1x1" ) );
  itemFocusBinning = new KConfigCompilerSignallingItem(innerItemFocusBinning, this, notifyFunction, signalFocusBinningChanged);
  addItem( itemFocusBinning, QStringLiteral( "FocusBinning" ) );
  KConfigCompilerSignallingItem  *itemFocusGain;
  KConfigSkeleton::ItemDouble  *innerItemFocusGain;
  innerItemFocusGain = new KConfigSkeleton::ItemDouble( currentGroup(), QStringLiteral( "FocusGain" ), mFocusGain, 0 );
  itemFocusGain = new KConfigCompilerSignallingItem(innerItemFocusGain, this, notifyFunction, signalFocusGainChanged);
  addItem( itemFocusGain, QStringLiteral( "FocusGain" ) );
  KConfigCompilerSignallingItem  *itemFocusISO;
  KConfigSkeleton::ItemString  *innerItemFocusISO;
  innerItemFocusISO = new KConfigSkeleton::ItemString( currentGroup(), QStringLiteral( "FocusISO" ), mFocusISO );
  itemFocusISO = new KConfigCompilerSignallingItem(innerItemFocusISO, this, notifyFunction, signalFocusISOChanged);
  addItem( itemFocusISO, QStringLiteral( "FocusISO" ) );
  KConfigCompilerSignallingItem  *itemDefaultFocusTemperatureSource;
  KConfigSkeleton::ItemString  *innerItemDefaultFocusTemperatureSource;
  innerItemDefaultFocusTemperatureSource = new KConfigSkeleton::ItemString( currentGroup(), QStringLiteral( "DefaultFocusTemperatureSource" ), mDefaultFocusTemperatureSource );
  itemDefaultFocusTemperatureSource = new KConfigCompilerSignallingItem(innerItemDefaultFocusTemperatureSource, this, notifyFunction, signalDefaultFocusTemperatureSourceChanged);
  addItem( itemDefaultFocusTemperatureSource, QStringLiteral( "DefaultFocusTemperatureSource" ) );
  KConfigCompilerSignallingItem  *itemFocusFilter;
  KConfigSkeleton::ItemString  *innerItemFocusFilter;
  innerItemFocusFilter = new KConfigSkeleton::ItemString( currentGroup(), QStringLiteral( "FocusFilter" ), mFocusFilter );
  itemFocusFilter = new KConfigCompilerSignallingItem(innerItemFocusFilter, this, notifyFunction, signalFocusFilterChanged);
  addItem( itemFocusFilter, QStringLiteral( "FocusFilter" ) );
  KConfigCompilerSignallingItem  *itemUseFocusDarkFrame;
  KConfigSkeleton::ItemBool  *innerItemUseFocusDarkFrame;
  innerItemUseFocusDarkFrame = new KConfigSkeleton::ItemBool( currentGroup(), QStringLiteral( "UseFocusDarkFrame" ), mUseFocusDarkFrame, false );
  itemUseFocusDarkFrame = new KConfigCompilerSignallingItem(innerItemUseFocusDarkFrame, this, notifyFunction, signalUseFocusDarkFrameChanged);
  addItem( itemUseFocusDarkFrame, QStringLiteral( "UseFocusDarkFrame" ) );
  KConfigCompilerSignallingItem  *itemFocusSubFrame;
  KConfigSkeleton::ItemBool  *innerItemFocusSubFrame;
  innerItemFocusSubFrame = new KConfigSkeleton::ItemBool( currentGroup(), QStringLiteral( "FocusSubFrame" ), mFocusSubFrame, false );
  itemFocusSubFrame = new KConfigCompilerSignallingItem(innerItemFocusSubFrame, this, notifyFunction, signalFocusSubFrameChanged);
  addItem( itemFocusSubFrame, QStringLiteral( "FocusSubFrame" ) );
  KConfigCompilerSignallingItem  *itemFocusBoxSize;
  KConfigSkeleton::ItemUInt  *innerItemFocusBoxSize;
  innerItemFocusBoxSize = new KConfigSkeleton::ItemUInt( currentGroup(), QStringLiteral( "FocusBoxSize" ), mFocusBoxSize, 64 );
  itemFocusBoxSize = new KConfigCompilerSignallingItem(innerItemFocusBoxSize, this, notifyFunction, signalFocusBoxSizeChanged);
  addItem( itemFocusBoxSize, QStringLiteral( "FocusBoxSize" ) );
  KConfigCompilerSignallingItem  *itemFocusUseFullField;
  KConfigSkeleton::ItemBool  *innerItemFocusUseFullField;
  innerItemFocusUseFullField = new KConfigSkeleton::ItemBool( currentGroup(), QStringLiteral( "FocusUseFullField" ), mFocusUseFullField, true );
  itemFocusUseFullField = new KConfigCompilerSignallingItem(innerItemFocusUseFullField, this, notifyFunction, signalFocusUseFullFieldChanged);
  addItem( itemFocusUseFullField, QStringLiteral( "FocusUseFullField" ) );
  KConfigCompilerSignallingItem  *itemFocusNoMaskRB;
  KConfigSkeleton::ItemBool  *innerItemFocusNoMaskRB;
  innerItemFocusNoMaskRB = new KConfigSkeleton::ItemBool( currentGroup(), QStringLiteral( "FocusNoMaskRB" ), mFocusNoMaskRB, true );
  itemFocusNoMaskRB = new KConfigCompilerSignallingItem(innerItemFocusNoMaskRB, this, notifyFunction, signalFocusNoMaskRBChanged);
  addItem( itemFocusNoMaskRB, QStringLiteral( "FocusNoMaskRB" ) );
  KConfigCompilerSignallingItem  *itemFocusRingMaskRB;
  KConfigSkeleton::ItemBool  *innerItemFocusRingMaskRB;
  innerItemFocusRingMaskRB = new KConfigSkeleton::ItemBool( currentGroup(), QStringLiteral( "focusRingMaskRB" ), mFocusRingMaskRB, false );
  itemFocusRingMaskRB = new KConfigCompilerSignallingItem(innerItemFocusRingMaskRB, this, notifyFunction, signalFocusRingMaskRBChanged);
  addItem( itemFocusRingMaskRB, QStringLiteral( "focusRingMaskRB" ) );
  KConfigCompilerSignallingItem  *itemFocusMosaicMaskRB;
  KConfigSkeleton::ItemBool  *innerItemFocusMosaicMaskRB;
  innerItemFocusMosaicMaskRB = new KConfigSkeleton::ItemBool( currentGroup(), QStringLiteral( "focusMosaicMaskRB" ), mFocusMosaicMaskRB, false );
  itemFocusMosaicMaskRB = new KConfigCompilerSignallingItem(innerItemFocusMosaicMaskRB, this, notifyFunction, signalFocusMosaicMaskRBChanged);
  addItem( itemFocusMosaicMaskRB, QStringLiteral( "focusMosaicMaskRB" ) );
  KConfigCompilerSignallingItem  *itemFocusFullFieldInnerRadius;
  KConfigSkeleton::ItemDouble  *innerItemFocusFullFieldInnerRadius;
  innerItemFocusFullFieldInnerRadius = new KConfigSkeleton::ItemDouble( currentGroup(), QStringLiteral( "FocusFullFieldInnerRadius" ), mFocusFullFieldInnerRadius, 0.0 );
  itemFocusFullFieldInnerRadius = new KConfigCompilerSignallingItem(innerItemFocusFullFieldInnerRadius, this, notifyFunction, signalFocusFullFieldInnerRadiusChanged);
  addItem( itemFocusFullFieldInnerRadius, QStringLiteral( "FocusFullFieldInnerRadius" ) );
  KConfigCompilerSignallingItem  *itemFocusFullFieldOuterRadius;
  KConfigSkeleton::ItemDouble  *innerItemFocusFullFieldOuterRadius;
  innerItemFocusFullFieldOuterRadius = new KConfigSkeleton::ItemDouble( currentGroup(), QStringLiteral( "FocusFullFieldOuterRadius" ), mFocusFullFieldOuterRadius, 100.0 );
  itemFocusFullFieldOuterRadius = new KConfigCompilerSignallingItem(innerItemFocusFullFieldOuterRadius, this, notifyFunction, signalFocusFullFieldOuterRadiusChanged);
  addItem( itemFocusFullFieldOuterRadius, QStringLiteral( "FocusFullFieldOuterRadius" ) );
  KConfigCompilerSignallingItem  *itemFocusMosaicTileWidth;
  KConfigSkeleton::ItemDouble  *innerItemFocusMosaicTileWidth;
  innerItemFocusMosaicTileWidth = new KConfigSkeleton::ItemDouble( currentGroup(), QStringLiteral( "FocusMosaicTileWidth" ), mFocusMosaicTileWidth, 25.0 );
  itemFocusMosaicTileWidth = new KConfigCompilerSignallingItem(innerItemFocusMosaicTileWidth, this, notifyFunction, signalFocusMosaicTileWidthChanged);
  addItem( itemFocusMosaicTileWidth, QStringLiteral( "FocusMosaicTileWidth" ) );
  KConfigCompilerSignallingItem  *itemFocusMosaicSpace;
  KConfigSkeleton::ItemUInt  *innerItemFocusMosaicSpace;
  innerItemFocusMosaicSpace = new KConfigSkeleton::ItemUInt( currentGroup(), QStringLiteral( "focusMosaicSpace" ), mFocusMosaicSpace, 5 );
  itemFocusMosaicSpace = new KConfigCompilerSignallingItem(innerItemFocusMosaicSpace, this, notifyFunction, signalFocusMosaicSpaceChanged);
  addItem( itemFocusMosaicSpace, QStringLiteral( "focusMosaicSpace" ) );
  KConfigCompilerSignallingItem  *itemFocusAutoStarEnabled;
  KConfigSkeleton::ItemBool  *innerItemFocusAutoStarEnabled;
  innerItemFocusAutoStarEnabled = new KConfigSkeleton::ItemBool( currentGroup(), QStringLiteral( "FocusAutoStarEnabled" ), mFocusAutoStarEnabled, false );
  itemFocusAutoStarEnabled = new KConfigCompilerSignallingItem(innerItemFocusAutoStarEnabled, this, notifyFunction, signalFocusAutoStarEnabledChanged);
  addItem( itemFocusAutoStarEnabled, QStringLiteral( "FocusAutoStarEnabled" ) );
  KConfigCompilerSignallingItem  *itemFocusSuspendGuiding;
  KConfigSkeleton::ItemBool  *innerItemFocusSuspendGuiding;
  innerItemFocusSuspendGuiding = new KConfigSkeleton::ItemBool( currentGroup(), QStringLiteral( "FocusSuspendGuiding" ), mFocusSuspendGuiding, true );
  itemFocusSuspendGuiding = new KConfigCompilerSignallingItem(innerItemFocusSuspendGuiding, this, notifyFunction, signalFocusSuspendGuidingChanged);
  addItem( itemFocusSuspendGuiding, QStringLiteral( "FocusSuspendGuiding" ) );
  KConfigCompilerSignallingItem  *itemFocusGuideSettleTime;
  KConfigSkeleton::ItemDouble  *innerItemFocusGuideSettleTime;
  innerItemFocusGuideSettleTime = new KConfigSkeleton::ItemDouble( currentGroup(), QStringLiteral( "FocusGuideSettleTime" ), mFocusGuideSettleTime, 0 );
  itemFocusGuideSettleTime = new KConfigCompilerSignallingItem(innerItemFocusGuideSettleTime, this, notifyFunction, signalFocusGuideSettleTimeChanged);
  addItem( itemFocusGuideSettleTime, QStringLiteral( "FocusGuideSettleTime" ) );
  KConfigCompilerSignallingItem  *itemFocusUnits;
  KConfigSkeleton::ItemString  *innerItemFocusUnits;
  innerItemFocusUnits = new KConfigSkeleton::ItemString( currentGroup(), QStringLiteral( "FocusUnits" ), mFocusUnits, QStringLiteral( "Pixels" ) );
  itemFocusUnits = new KConfigCompilerSignallingItem(innerItemFocusUnits, this, notifyFunction, signalFocusUnitsChanged);
  addItem( itemFocusUnits, QStringLiteral( "FocusUnits" ) );
  KConfigCompilerSignallingItem  *itemFocusAdaptive;
  KConfigSkeleton::ItemBool  *innerItemFocusAdaptive;
  innerItemFocusAdaptive = new KConfigSkeleton::ItemBool( currentGroup(), QStringLiteral( "FocusAdaptive" ), mFocusAdaptive, false );
  itemFocusAdaptive = new KConfigCompilerSignallingItem(innerItemFocusAdaptive, this, notifyFunction, signalFocusAdaptiveChanged);
  addItem( itemFocusAdaptive, QStringLiteral( "FocusAdaptive" ) );
  KConfigCompilerSignallingItem  *itemFocusAdaptiveMinMove;
  KConfigSkeleton::ItemUInt  *innerItemFocusAdaptiveMinMove;
  innerItemFocusAdaptiveMinMove = new KConfigSkeleton::ItemUInt( currentGroup(), QStringLiteral( "focusAdaptiveMinMove" ), mFocusAdaptiveMinMove, 1 );
  itemFocusAdaptiveMinMove = new KConfigCompilerSignallingItem(innerItemFocusAdaptiveMinMove, this, notifyFunction, signalFocusAdaptiveMinMoveChanged);
  addItem( itemFocusAdaptiveMinMove, QStringLiteral( "focusAdaptiveMinMove" ) );
  KConfigCompilerSignallingItem  *itemFocusAdaptStart;
  KConfigSkeleton::ItemBool  *innerItemFocusAdaptStart;
  innerItemFocusAdaptStart = new KConfigSkeleton::ItemBool( currentGroup(), QStringLiteral( "FocusAdaptStart" ), mFocusAdaptStart, false );
  itemFocusAdaptStart = new KConfigCompilerSignallingItem(innerItemFocusAdaptStart, this, notifyFunction, signalFocusAdaptStartChanged);
  addItem( itemFocusAdaptStart, QStringLiteral( "FocusAdaptStart" ) );
  KConfigCompilerSignallingItem  *itemFocusAdaptiveMaxMove;
  KConfigSkeleton::ItemUInt  *innerItemFocusAdaptiveMaxMove;
  innerItemFocusAdaptiveMaxMove = new KConfigSkeleton::ItemUInt( currentGroup(), QStringLiteral( "focusAdaptiveMaxMove" ), mFocusAdaptiveMaxMove, 1000 );
  itemFocusAdaptiveMaxMove = new KConfigCompilerSignallingItem(innerItemFocusAdaptiveMaxMove, this, notifyFunction, signalFocusAdaptiveMaxMoveChanged);
  addItem( itemFocusAdaptiveMaxMove, QStringLiteral( "focusAdaptiveMaxMove" ) );
  KConfigCompilerSignallingItem  *itemFocusDetection;
  KConfigSkeleton::ItemString  *innerItemFocusDetection;
  innerItemFocusDetection = new KConfigSkeleton::ItemString( currentGroup(), QStringLiteral( "FocusDetection" ), mFocusDetection, QStringLiteral( "SEP" ) );
  itemFocusDetection = new KConfigCompilerSignallingItem(innerItemFocusDetection, this, notifyFunction, signalFocusDetectionChanged);
  addItem( itemFocusDetection, QStringLiteral( "FocusDetection" ) );
  KConfigCompilerSignallingItem  *itemFocusSEPProfile;
  KConfigSkeleton::ItemString  *innerItemFocusSEPProfile;
  innerItemFocusSEPProfile = new KConfigSkeleton::ItemString( currentGroup(), QStringLiteral( "FocusSEPProfile" ), mFocusSEPProfile );
  itemFocusSEPProfile = new KConfigCompilerSignallingItem(innerItemFocusSEPProfile, this, notifyFunction, signalFocusSEPProfileChanged);
  addItem( itemFocusSEPProfile, QStringLiteral( "FocusSEPProfile" ) );
  KConfigCompilerSignallingItem  *itemFocusAlgorithm;
  KConfigSkeleton::ItemString  *innerItemFocusAlgorithm;
  innerItemFocusAlgorithm = new KConfigSkeleton::ItemString( currentGroup(), QStringLiteral( "FocusAlgorithm" ), mFocusAlgorithm, QStringLiteral( "Linear 1 Pass" ) );
  itemFocusAlgorithm = new KConfigCompilerSignallingItem(innerItemFocusAlgorithm, this, notifyFunction, signalFocusAlgorithmChanged);
  addItem( itemFocusAlgorithm, QStringLiteral( "FocusAlgorithm" ) );
  KConfigCompilerSignallingItem  *itemFocusCurveFit;
  KConfigSkeleton::ItemString  *innerItemFocusCurveFit;
  innerItemFocusCurveFit = new KConfigSkeleton::ItemString( currentGroup(), QStringLiteral( "FocusCurveFit" ), mFocusCurveFit, QStringLiteral( "Hyperbola" ) );
  itemFocusCurveFit = new KConfigCompilerSignallingItem(innerItemFocusCurveFit, this, notifyFunction, signalFocusCurveFitChanged);
  addItem( itemFocusCurveFit, QStringLiteral( "FocusCurveFit" ) );
  KConfigCompilerSignallingItem  *itemFocusStarMeasure;
  KConfigSkeleton::ItemString  *innerItemFocusStarMeasure;
  innerItemFocusStarMeasure = new KConfigSkeleton::ItemString( currentGroup(), QStringLiteral( "FocusStarMeasure" ), mFocusStarMeasure, QStringLiteral( "HFR" ) );
  itemFocusStarMeasure = new KConfigCompilerSignallingItem(innerItemFocusStarMeasure, this, notifyFunction, signalFocusStarMeasureChanged);
  addItem( itemFocusStarMeasure, QStringLiteral( "FocusStarMeasure" ) );
  KConfigCompilerSignallingItem  *itemFocusStarPSF;
  KConfigSkeleton::ItemString  *innerItemFocusStarPSF;
  innerItemFocusStarPSF = new KConfigSkeleton::ItemString( currentGroup(), QStringLiteral( "FocusStarPSF" ), mFocusStarPSF, QStringLiteral( "Gaussian" ) );
  itemFocusStarPSF = new KConfigCompilerSignallingItem(innerItemFocusStarPSF, this, notifyFunction, signalFocusStarPSFChanged);
  addItem( itemFocusStarPSF, QStringLiteral( "FocusStarPSF" ) );
  KConfigCompilerSignallingItem  *itemFocusUseWeights;
  KConfigSkeleton::ItemBool  *innerItemFocusUseWeights;
  innerItemFocusUseWeights = new KConfigSkeleton::ItemBool( currentGroup(), QStringLiteral( "FocusUseWeights" ), mFocusUseWeights, true );
  itemFocusUseWeights = new KConfigCompilerSignallingItem(innerItemFocusUseWeights, this, notifyFunction, signalFocusUseWeightsChanged);
  addItem( itemFocusUseWeights, QStringLiteral( "FocusUseWeights" ) );
  KConfigCompilerSignallingItem  *itemFocusR2Limit;
  KConfigSkeleton::ItemDouble  *innerItemFocusR2Limit;
  innerItemFocusR2Limit = new KConfigSkeleton::ItemDouble( currentGroup(), QStringLiteral( "FocusR2Limit" ), mFocusR2Limit, 0.8 );
  itemFocusR2Limit = new KConfigCompilerSignallingItem(innerItemFocusR2Limit, this, notifyFunction, signalFocusR2LimitChanged);
  addItem( itemFocusR2Limit, QStringLiteral( "FocusR2Limit" ) );
  KConfigCompilerSignallingItem  *itemFocusRefineCurveFit;
  KConfigSkeleton::ItemBool  *innerItemFocusRefineCurveFit;
  innerItemFocusRefineCurveFit = new KConfigSkeleton::ItemBool( currentGroup(), QStringLiteral( "FocusRefineCurveFit" ), mFocusRefineCurveFit, false );
  itemFocusRefineCurveFit = new KConfigCompilerSignallingItem(innerItemFocusRefineCurveFit, this, notifyFunction, signalFocusRefineCurveFitChanged);
  addItem( itemFocusRefineCurveFit, QStringLiteral( "FocusRefineCurveFit" ) );
  KConfigCompilerSignallingItem  *itemFocusFramesCount;
  KConfigSkeleton::ItemUInt  *innerItemFocusFramesCount;
  innerItemFocusFramesCount = new KConfigSkeleton::ItemUInt( currentGroup(), QStringLiteral( "focusFramesCount" ), mFocusFramesCount, 1 );
  itemFocusFramesCount = new KConfigCompilerSignallingItem(innerItemFocusFramesCount, this, notifyFunction, signalFocusFramesCountChanged);
  addItem( itemFocusFramesCount, QStringLiteral( "focusFramesCount" ) );
  KConfigCompilerSignallingItem  *itemFocusHFRFramesCount;
  KConfigSkeleton::ItemUInt  *innerItemFocusHFRFramesCount;
  innerItemFocusHFRFramesCount = new KConfigSkeleton::ItemUInt( currentGroup(), QStringLiteral( "focusHFRFramesCount" ), mFocusHFRFramesCount, 1 );
  itemFocusHFRFramesCount = new KConfigCompilerSignallingItem(innerItemFocusHFRFramesCount, this, notifyFunction, signalFocusHFRFramesCountChanged);
  addItem( itemFocusHFRFramesCount, QStringLiteral( "focusHFRFramesCount" ) );
  KConfigCompilerSignallingItem  *itemFocusMultiRowAverage;
  KConfigSkeleton::ItemInt  *innerItemFocusMultiRowAverage;
  innerItemFocusMultiRowAverage = new KConfigSkeleton::ItemInt( currentGroup(), QStringLiteral( "FocusMultiRowAverage" ), mFocusMultiRowAverage, 3 );
  itemFocusMultiRowAverage = new KConfigCompilerSignallingItem(innerItemFocusMultiRowAverage, this, notifyFunction, signalFocusMultiRowAverageChanged);
  addItem( itemFocusMultiRowAverage, QStringLiteral( "FocusMultiRowAverage" ) );
  KConfigCompilerSignallingItem  *itemFocusGaussianSigma;
  KConfigSkeleton::ItemDouble  *innerItemFocusGaussianSigma;
  innerItemFocusGaussianSigma = new KConfigSkeleton::ItemDouble( currentGroup(), QStringLiteral( "FocusGaussianSigma" ), mFocusGaussianSigma, 1.5 );
  itemFocusGaussianSigma = new KConfigCompilerSignallingItem(innerItemFocusGaussianSigma, this, notifyFunction, signalFocusGaussianSigmaChanged);
  addItem( itemFocusGaussianSigma, QStringLiteral( "FocusGaussianSigma" ) );
  KConfigCompilerSignallingItem  *itemFocusThreshold;
  KConfigSkeleton::ItemDouble  *innerItemFocusThreshold;
  innerItemFocusThreshold = new KConfigSkeleton::ItemDouble( currentGroup(), QStringLiteral( "FocusThreshold" ), mFocusThreshold, 150 );
  itemFocusThreshold = new KConfigCompilerSignallingItem(innerItemFocusThreshold, this, notifyFunction, signalFocusThresholdChanged);
  addItem( itemFocusThreshold, QStringLiteral( "FocusThreshold" ) );
  KConfigCompilerSignallingItem  *itemFocusDenoise;
  KConfigSkeleton::ItemBool  *innerItemFocusDenoise;
  innerItemFocusDenoise = new KConfigSkeleton::ItemBool( currentGroup(), QStringLiteral( "FocusDenoise" ), mFocusDenoise, false );
  itemFocusDenoise = new KConfigCompilerSignallingItem(innerItemFocusDenoise, this, notifyFunction, signalFocusDenoiseChanged);
  addItem( itemFocusDenoise, QStringLiteral( "FocusDenoise" ) );
  KConfigCompilerSignallingItem  *itemFocusDonut;
  KConfigSkeleton::ItemBool  *innerItemFocusDonut;
  innerItemFocusDonut = new KConfigSkeleton::ItemBool( currentGroup(), QStringLiteral( "FocusDonut" ), mFocusDonut, false );
  itemFocusDonut = new KConfigCompilerSignallingItem(innerItemFocusDonut, this, notifyFunction, signalFocusDonutChanged);
  addItem( itemFocusDonut, QStringLiteral( "FocusDonut" ) );
  KConfigCompilerSignallingItem  *itemFocusTimeDilation;
  KConfigSkeleton::ItemDouble  *innerItemFocusTimeDilation;
  innerItemFocusTimeDilation = new KConfigSkeleton::ItemDouble( currentGroup(), QStringLiteral( "FocusTimeDilation" ), mFocusTimeDilation, 1.0 );
  itemFocusTimeDilation = new KConfigCompilerSignallingItem(innerItemFocusTimeDilation, this, notifyFunction, signalFocusTimeDilationChanged);
  addItem( itemFocusTimeDilation, QStringLiteral( "FocusTimeDilation" ) );
  KConfigCompilerSignallingItem  *itemFocusOutlierRejection;
  KConfigSkeleton::ItemDouble  *innerItemFocusOutlierRejection;
  innerItemFocusOutlierRejection = new KConfigSkeleton::ItemDouble( currentGroup(), QStringLiteral( "focusOutlierRejection" ), mFocusOutlierRejection, 1.0 );
  itemFocusOutlierRejection = new KConfigCompilerSignallingItem(innerItemFocusOutlierRejection, this, notifyFunction, signalFocusOutlierRejectionChanged);
  addItem( itemFocusOutlierRejection, QStringLiteral( "focusOutlierRejection" ) );
  KConfigCompilerSignallingItem  *itemFocusScanStartPos;
  KConfigSkeleton::ItemBool  *innerItemFocusScanStartPos;
  innerItemFocusScanStartPos = new KConfigSkeleton::ItemBool( currentGroup(), QStringLiteral( "focusScanStartPos" ), mFocusScanStartPos, false );
  itemFocusScanStartPos = new KConfigCompilerSignallingItem(innerItemFocusScanStartPos, this, notifyFunction, signalFocusScanStartPosChanged);
  addItem( itemFocusScanStartPos, QStringLiteral( "focusScanStartPos" ) );
  KConfigCompilerSignallingItem  *itemFocusScanAlwaysOn;
  KConfigSkeleton::ItemBool  *innerItemFocusScanAlwaysOn;
  innerItemFocusScanAlwaysOn = new KConfigSkeleton::ItemBool( currentGroup(), QStringLiteral( "focusScanAlwaysOn" ), mFocusScanAlwaysOn, true );
  itemFocusScanAlwaysOn = new KConfigCompilerSignallingItem(innerItemFocusScanAlwaysOn, this, notifyFunction, signalFocusScanAlwaysOnChanged);
  addItem( itemFocusScanAlwaysOn, QStringLiteral( "focusScanAlwaysOn" ) );
  KConfigCompilerSignallingItem  *itemFocusScanDatapoints;
  KConfigSkeleton::ItemUInt  *innerItemFocusScanDatapoints;
  innerItemFocusScanDatapoints = new KConfigSkeleton::ItemUInt( currentGroup(), QStringLiteral( "focusScanDatapoints" ), mFocusScanDatapoints, 5 );
  itemFocusScanDatapoints = new KConfigCompilerSignallingItem(innerItemFocusScanDatapoints, this, notifyFunction, signalFocusScanDatapointsChanged);
  addItem( itemFocusScanDatapoints, QStringLiteral( "focusScanDatapoints" ) );
  KConfigCompilerSignallingItem  *itemFocusScanStepSizeFactor;
  KConfigSkeleton::ItemDouble  *innerItemFocusScanStepSizeFactor;
  innerItemFocusScanStepSizeFactor = new KConfigSkeleton::ItemDouble( currentGroup(), QStringLiteral( "focusScanStepSizeFactor" ), mFocusScanStepSizeFactor, 1.0 );
  itemFocusScanStepSizeFactor = new KConfigCompilerSignallingItem(innerItemFocusScanStepSizeFactor, this, notifyFunction, signalFocusScanStepSizeFactorChanged);
  addItem( itemFocusScanStepSizeFactor, QStringLiteral( "focusScanStepSizeFactor" ) );
  KConfigCompilerSignallingItem  *itemFocusGaussianKernelSize;
  KConfigSkeleton::ItemInt  *innerItemFocusGaussianKernelSize;
  innerItemFocusGaussianKernelSize = new KConfigSkeleton::ItemInt( currentGroup(), QStringLiteral( "FocusGaussianKernelSize" ), mFocusGaussianKernelSize, 5 );
  itemFocusGaussianKernelSize = new KConfigCompilerSignallingItem(innerItemFocusGaussianKernelSize, this, notifyFunction, signalFocusGaussianKernelSizeChanged);
  addItem( itemFocusGaussianKernelSize, QStringLiteral( "FocusGaussianKernelSize" ) );
  KConfigCompilerSignallingItem  *itemFocusTolerance;
  KConfigSkeleton::ItemDouble  *innerItemFocusTolerance;
  innerItemFocusTolerance = new KConfigSkeleton::ItemDouble( currentGroup(), QStringLiteral( "FocusTolerance" ), mFocusTolerance, 1 );
  itemFocusTolerance = new KConfigCompilerSignallingItem(innerItemFocusTolerance, this, notifyFunction, signalFocusToleranceChanged);
  addItem( itemFocusTolerance, QStringLiteral( "FocusTolerance" ) );
  KConfigCompilerSignallingItem  *itemFocusWalk;
  KConfigSkeleton::ItemString  *innerItemFocusWalk;
  innerItemFocusWalk = new KConfigSkeleton::ItemString( currentGroup(), QStringLiteral( "FocusWalk" ), mFocusWalk, QStringLiteral( "Fixed Steps" ) );
  itemFocusWalk = new KConfigCompilerSignallingItem(innerItemFocusWalk, this, notifyFunction, signalFocusWalkChanged);
  addItem( itemFocusWalk, QStringLiteral( "FocusWalk" ) );
  KConfigCompilerSignallingItem  *itemFocusSettleTime;
  KConfigSkeleton::ItemDouble  *innerItemFocusSettleTime;
  innerItemFocusSettleTime = new KConfigSkeleton::ItemDouble( currentGroup(), QStringLiteral( "FocusSettleTime" ), mFocusSettleTime, 1.0 );
  itemFocusSettleTime = new KConfigCompilerSignallingItem(innerItemFocusSettleTime, this, notifyFunction, signalFocusSettleTimeChanged);
  addItem( itemFocusSettleTime, QStringLiteral( "FocusSettleTime" ) );
  KConfigCompilerSignallingItem  *itemFocusTicks;
  KConfigSkeleton::ItemUInt  *innerItemFocusTicks;
  innerItemFocusTicks = new KConfigSkeleton::ItemUInt( currentGroup(), QStringLiteral( "FocusTicks" ), mFocusTicks, 250 );
  itemFocusTicks = new KConfigCompilerSignallingItem(innerItemFocusTicks, this, notifyFunction, signalFocusTicksChanged);
  addItem( itemFocusTicks, QStringLiteral( "FocusTicks" ) );
  KConfigCompilerSignallingItem  *itemFocusOutSteps;
  KConfigSkeleton::ItemDouble  *innerItemFocusOutSteps;
  innerItemFocusOutSteps = new KConfigSkeleton::ItemDouble( currentGroup(), QStringLiteral( "FocusOutSteps" ), mFocusOutSteps, 5 );
  itemFocusOutSteps = new KConfigCompilerSignallingItem(innerItemFocusOutSteps, this, notifyFunction, signalFocusOutStepsChanged);
  addItem( itemFocusOutSteps, QStringLiteral( "FocusOutSteps" ) );
  KConfigCompilerSignallingItem  *itemFocusNumSteps;
  KConfigSkeleton::ItemUInt  *innerItemFocusNumSteps;
  innerItemFocusNumSteps = new KConfigSkeleton::ItemUInt( currentGroup(), QStringLiteral( "focusNumSteps" ), mFocusNumSteps, 11 );
  itemFocusNumSteps = new KConfigCompilerSignallingItem(innerItemFocusNumSteps, this, notifyFunction, signalFocusNumStepsChanged);
  addItem( itemFocusNumSteps, QStringLiteral( "focusNumSteps" ) );
  KConfigCompilerSignallingItem  *itemFocusMaxTravel;
  KConfigSkeleton::ItemUInt  *innerItemFocusMaxTravel;
  innerItemFocusMaxTravel = new KConfigSkeleton::ItemUInt( currentGroup(), QStringLiteral( "FocusMaxTravel" ), mFocusMaxTravel, 10000 );
  itemFocusMaxTravel = new KConfigCompilerSignallingItem(innerItemFocusMaxTravel, this, notifyFunction, signalFocusMaxTravelChanged);
  addItem( itemFocusMaxTravel, QStringLiteral( "FocusMaxTravel" ) );
  KConfigCompilerSignallingItem  *itemFocusMaxSingleStep;
  KConfigSkeleton::ItemUInt  *innerItemFocusMaxSingleStep;
  innerItemFocusMaxSingleStep = new KConfigSkeleton::ItemUInt( currentGroup(), QStringLiteral( "FocusMaxSingleStep" ), mFocusMaxSingleStep, 100000 );
  itemFocusMaxSingleStep = new KConfigCompilerSignallingItem(innerItemFocusMaxSingleStep, this, notifyFunction, signalFocusMaxSingleStepChanged);
  addItem( itemFocusMaxSingleStep, QStringLiteral( "FocusMaxSingleStep" ) );
  KConfigCompilerSignallingItem  *itemFocusBacklash;
  KConfigSkeleton::ItemUInt  *innerItemFocusBacklash;
  innerItemFocusBacklash = new KConfigSkeleton::ItemUInt( currentGroup(), QStringLiteral( "FocusBacklash" ), mFocusBacklash, 0 );
  itemFocusBacklash = new KConfigCompilerSignallingItem(innerItemFocusBacklash, this, notifyFunction, signalFocusBacklashChanged);
  addItem( itemFocusBacklash, QStringLiteral( "FocusBacklash" ) );
  KConfigCompilerSignallingItem  *itemFocusAFOverscan;
  KConfigSkeleton::ItemUInt  *innerItemFocusAFOverscan;
  innerItemFocusAFOverscan = new KConfigSkeleton::ItemUInt( currentGroup(), QStringLiteral( "FocusAFOverscan" ), mFocusAFOverscan, 100 );
  itemFocusAFOverscan = new KConfigCompilerSignallingItem(innerItemFocusAFOverscan, this, notifyFunction, signalFocusAFOverscanChanged);
  addItem( itemFocusAFOverscan, QStringLiteral( "FocusAFOverscan" ) );
  KConfigCompilerSignallingItem  *itemFocusOverscanDelay;
  KConfigSkeleton::ItemDouble  *innerItemFocusOverscanDelay;
  innerItemFocusOverscanDelay = new KConfigSkeleton::ItemDouble( currentGroup(), QStringLiteral( "FocusOverscanDelay" ), mFocusOverscanDelay, 0.0 );
  itemFocusOverscanDelay = new KConfigCompilerSignallingItem(innerItemFocusOverscanDelay, this, notifyFunction, signalFocusOverscanDelayChanged);
  addItem( itemFocusOverscanDelay, QStringLiteral( "FocusOverscanDelay" ) );
  KConfigCompilerSignallingItem  *itemFocusCaptureTimeout;
  KConfigSkeleton::ItemUInt  *innerItemFocusCaptureTimeout;
  innerItemFocusCaptureTimeout = new KConfigSkeleton::ItemUInt( currentGroup(), QStringLiteral( "FocusCaptureTimeout" ), mFocusCaptureTimeout, 30 );
  itemFocusCaptureTimeout = new KConfigCompilerSignallingItem(innerItemFocusCaptureTimeout, this, notifyFunction, signalFocusCaptureTimeoutChanged);
  addItem( itemFocusCaptureTimeout, QStringLiteral( "FocusCaptureTimeout" ) );
  KConfigCompilerSignallingItem  *itemFocusMotionTimeout;
  KConfigSkeleton::ItemUInt  *innerItemFocusMotionTimeout;
  innerItemFocusMotionTimeout = new KConfigSkeleton::ItemUInt( currentGroup(), QStringLiteral( "FocusMotionTimeout" ), mFocusMotionTimeout, 30 );
  itemFocusMotionTimeout = new KConfigCompilerSignallingItem(innerItemFocusMotionTimeout, this, notifyFunction, signalFocusMotionTimeoutChanged);
  addItem( itemFocusMotionTimeout, QStringLiteral( "FocusMotionTimeout" ) );
  KConfigCompilerSignallingItem  *itemFocusCFZAlgorithm;
  KConfigSkeleton::ItemString  *innerItemFocusCFZAlgorithm;
  innerItemFocusCFZAlgorithm = new KConfigSkeleton::ItemString( currentGroup(), QStringLiteral( "focusCFZAlgorithm" ), mFocusCFZAlgorithm, QStringLiteral( "Classic" ) );
  itemFocusCFZAlgorithm = new KConfigCompilerSignallingItem(innerItemFocusCFZAlgorithm, this, notifyFunction, signalFocusCFZAlgorithmChanged);
  addItem( itemFocusCFZAlgorithm, QStringLiteral( "focusCFZAlgorithm" ) );
  KConfigCompilerSignallingItem  *itemFocusCFZTolerance;
  KConfigSkeleton::ItemDouble  *innerItemFocusCFZTolerance;
  innerItemFocusCFZTolerance = new KConfigSkeleton::ItemDouble( currentGroup(), QStringLiteral( "focusCFZTolerance" ), mFocusCFZTolerance, 0.33 );
  itemFocusCFZTolerance = new KConfigCompilerSignallingItem(innerItemFocusCFZTolerance, this, notifyFunction, signalFocusCFZToleranceChanged);
  addItem( itemFocusCFZTolerance, QStringLiteral( "focusCFZTolerance" ) );
  KConfigCompilerSignallingItem  *itemFocusCFZTau;
  KConfigSkeleton::ItemDouble  *innerItemFocusCFZTau;
  innerItemFocusCFZTau = new KConfigSkeleton::ItemDouble( currentGroup(), QStringLiteral( "focusCFZTau" ), mFocusCFZTau, 3.0 );
  itemFocusCFZTau = new KConfigCompilerSignallingItem(innerItemFocusCFZTau, this, notifyFunction, signalFocusCFZTauChanged);
  addItem( itemFocusCFZTau, QStringLiteral( "focusCFZTau" ) );
  KConfigCompilerSignallingItem  *itemFocusCFZDisplayVCurve;
  KConfigSkeleton::ItemBool  *innerItemFocusCFZDisplayVCurve;
  innerItemFocusCFZDisplayVCurve = new KConfigSkeleton::ItemBool( currentGroup(), QStringLiteral( "focusCFZDisplayVCurve" ), mFocusCFZDisplayVCurve, true );
  itemFocusCFZDisplayVCurve = new KConfigCompilerSignallingItem(innerItemFocusCFZDisplayVCurve, this, notifyFunction, signalFocusCFZDisplayVCurveChanged);
  addItem( itemFocusCFZDisplayVCurve, QStringLiteral( "focusCFZDisplayVCurve" ) );
  KConfigCompilerSignallingItem  *itemFocusCFZWavelength;
  KConfigSkeleton::ItemDouble  *innerItemFocusCFZWavelength;
  innerItemFocusCFZWavelength = new KConfigSkeleton::ItemDouble( currentGroup(), QStringLiteral( "focusCFZWavelength" ), mFocusCFZWavelength, 550.0 );
  itemFocusCFZWavelength = new KConfigCompilerSignallingItem(innerItemFocusCFZWavelength, this, notifyFunction, signalFocusCFZWavelengthChanged);
  addItem( itemFocusCFZWavelength, QStringLiteral( "focusCFZWavelength" ) );
  KConfigCompilerSignallingItem  *itemFocusCFZAperture;
  KConfigSkeleton::ItemUInt  *innerItemFocusCFZAperture;
  innerItemFocusCFZAperture = new KConfigSkeleton::ItemUInt( currentGroup(), QStringLiteral( "focusCFZAperture" ), mFocusCFZAperture, 100 );
  itemFocusCFZAperture = new KConfigCompilerSignallingItem(innerItemFocusCFZAperture, this, notifyFunction, signalFocusCFZApertureChanged);
  addItem( itemFocusCFZAperture, QStringLiteral( "focusCFZAperture" ) );
  KConfigCompilerSignallingItem  *itemFocusCFZFNumber;
  KConfigSkeleton::ItemDouble  *innerItemFocusCFZFNumber;
  innerItemFocusCFZFNumber = new KConfigSkeleton::ItemDouble( currentGroup(), QStringLiteral( "focusCFZFNumber" ), mFocusCFZFNumber, 5.5 );
  itemFocusCFZFNumber = new KConfigCompilerSignallingItem(innerItemFocusCFZFNumber, this, notifyFunction, signalFocusCFZFNumberChanged);
  addItem( itemFocusCFZFNumber, QStringLiteral( "focusCFZFNumber" ) );
  KConfigCompilerSignallingItem  *itemFocusCFZSeeing;
  KConfigSkeleton::ItemDouble  *innerItemFocusCFZSeeing;
  innerItemFocusCFZSeeing = new KConfigSkeleton::ItemDouble( currentGroup(), QStringLiteral( "focusCFZSeeing" ), mFocusCFZSeeing, 3.0 );
  itemFocusCFZSeeing = new KConfigCompilerSignallingItem(innerItemFocusCFZSeeing, this, notifyFunction, signalFocusCFZSeeingChanged);
  addItem( itemFocusCFZSeeing, QStringLiteral( "focusCFZSeeing" ) );
  KConfigCompilerSignallingItem  *itemFocusCFZStepSize;
  KConfigSkeleton::ItemDouble  *innerItemFocusCFZStepSize;
  innerItemFocusCFZStepSize = new KConfigSkeleton::ItemDouble( currentGroup(), QStringLiteral( "focusCFZStepSize" ), mFocusCFZStepSize, 5.0 );
  itemFocusCFZStepSize = new KConfigCompilerSignallingItem(innerItemFocusCFZStepSize, this, notifyFunction, signalFocusCFZStepSizeChanged);
  addItem( itemFocusCFZStepSize, QStringLiteral( "focusCFZStepSize" ) );
  KConfigCompilerSignallingItem  *itemFocusAdvHelpOnlyChanges;
  KConfigSkeleton::ItemBool  *innerItemFocusAdvHelpOnlyChanges;
  innerItemFocusAdvHelpOnlyChanges = new KConfigSkeleton::ItemBool( currentGroup(), QStringLiteral( "focusAdvHelpOnlyChanges" ), mFocusAdvHelpOnlyChanges, true );
  itemFocusAdvHelpOnlyChanges = new KConfigCompilerSignallingItem(innerItemFocusAdvHelpOnlyChanges, this, notifyFunction, signalFocusAdvHelpOnlyChangesChanged);
  addItem( itemFocusAdvHelpOnlyChanges, QStringLiteral( "focusAdvHelpOnlyChanges" ) );
  KConfigCompilerSignallingItem  *itemFocusAdvUpdateParams;
  KConfigSkeleton::ItemBool  *innerItemFocusAdvUpdateParams;
  innerItemFocusAdvUpdateParams = new KConfigSkeleton::ItemBool( currentGroup(), QStringLiteral( "focusAdvUpdateParams" ), mFocusAdvUpdateParams, true );
  itemFocusAdvUpdateParams = new KConfigCompilerSignallingItem(innerItemFocusAdvUpdateParams, this, notifyFunction, signalFocusAdvUpdateParamsChanged);
  addItem( itemFocusAdvUpdateParams, QStringLiteral( "focusAdvUpdateParams" ) );
  KConfigCompilerSignallingItem  *itemFocusAdvFindStars;
  KConfigSkeleton::ItemBool  *innerItemFocusAdvFindStars;
  innerItemFocusAdvFindStars = new KConfigSkeleton::ItemBool( currentGroup(), QStringLiteral( "focusAdvFindStars" ), mFocusAdvFindStars, true );
  itemFocusAdvFindStars = new KConfigCompilerSignallingItem(innerItemFocusAdvFindStars, this, notifyFunction, signalFocusAdvFindStarsChanged);
  addItem( itemFocusAdvFindStars, QStringLiteral( "focusAdvFindStars" ) );
  KConfigCompilerSignallingItem  *itemFocusAdvCourseAdj;
  KConfigSkeleton::ItemBool  *innerItemFocusAdvCourseAdj;
  innerItemFocusAdvCourseAdj = new KConfigSkeleton::ItemBool( currentGroup(), QStringLiteral( "focusAdvCourseAdj" ), mFocusAdvCourseAdj, true );
  itemFocusAdvCourseAdj = new KConfigCompilerSignallingItem(innerItemFocusAdvCourseAdj, this, notifyFunction, signalFocusAdvCourseAdjChanged);
  addItem( itemFocusAdvCourseAdj, QStringLiteral( "focusAdvCourseAdj" ) );
  KConfigCompilerSignallingItem  *itemFocusAdvFineAdj;
  KConfigSkeleton::ItemBool  *innerItemFocusAdvFineAdj;
  innerItemFocusAdvFineAdj = new KConfigSkeleton::ItemBool( currentGroup(), QStringLiteral( "focusAdvFineAdj" ), mFocusAdvFineAdj, true );
  itemFocusAdvFineAdj = new KConfigCompilerSignallingItem(innerItemFocusAdvFineAdj, this, notifyFunction, signalFocusAdvFineAdjChanged);
  addItem( itemFocusAdvFineAdj, QStringLiteral( "focusAdvFineAdj" ) );
  KConfigCompilerSignallingItem  *itemFocusSplitter;
  KConfigSkeleton::ItemString  *innerItemFocusSplitter;
  innerItemFocusSplitter = new KConfigSkeleton::ItemString( currentGroup(), QStringLiteral( "FocusSplitter" ), mFocusSplitter );
  itemFocusSplitter = new KConfigCompilerSignallingItem(innerItemFocusSplitter, this, notifyFunction, signalFocusSplitterChanged);
  addItem( itemFocusSplitter, QStringLiteral( "FocusSplitter" ) );
  KConfigCompilerSignallingItem  *itemRightLayout;
  KConfigSkeleton::ItemString  *innerItemRightLayout;
  innerItemRightLayout = new KConfigSkeleton::ItemString( currentGroup(), QStringLiteral( "rightLayout" ), mRightLayout );
  itemRightLayout = new KConfigCompilerSignallingItem(innerItemRightLayout, this, notifyFunction, signalRightLayoutChanged);
  addItem( itemRightLayout, QStringLiteral( "rightLayout" ) );
  KConfigCompilerSignallingItem  *itemAdaptFocusBFO;
  KConfigSkeleton::ItemBool  *innerItemAdaptFocusBFO;
  innerItemAdaptFocusBFO = new KConfigSkeleton::ItemBool( currentGroup(), QStringLiteral( "adaptFocusBFO" ), mAdaptFocusBFO, false );
  itemAdaptFocusBFO = new KConfigCompilerSignallingItem(innerItemAdaptFocusBFO, this, notifyFunction, signalAdaptFocusBFOChanged);
  addItem( itemAdaptFocusBFO, QStringLiteral( "adaptFocusBFO" ) );
  KConfigCompilerSignallingItem  *itemAbInsTileSelection;
  KConfigSkeleton::ItemString  *innerItemAbInsTileSelection;
  innerItemAbInsTileSelection = new KConfigSkeleton::ItemString( currentGroup(), QStringLiteral( "abInsTileSelection" ), mAbInsTileSelection, QStringLiteral( "Centre and outer corners" ) );
  itemAbInsTileSelection = new KConfigCompilerSignallingItem(innerItemAbInsTileSelection, this, notifyFunction, signalAbInsTileSelectionChanged);
  addItem( itemAbInsTileSelection, QStringLiteral( "abInsTileSelection" ) );
  KConfigCompilerSignallingItem  *itemAbInsShowLabels;
  KConfigSkeleton::ItemBool  *innerItemAbInsShowLabels;
  innerItemAbInsShowLabels = new KConfigSkeleton::ItemBool( currentGroup(), QStringLiteral( "abInsShowLabels" ), mAbInsShowLabels, false );
  itemAbInsShowLabels = new KConfigCompilerSignallingItem(innerItemAbInsShowLabels, this, notifyFunction, signalAbInsShowLabelsChanged);
  addItem( itemAbInsShowLabels, QStringLiteral( "abInsShowLabels" ) );
  KConfigCompilerSignallingItem  *itemAbInsShowCFZ;
  KConfigSkeleton::ItemBool  *innerItemAbInsShowCFZ;
  innerItemAbInsShowCFZ = new KConfigSkeleton::ItemBool( currentGroup(), QStringLiteral( "abInsShowCFZ" ), mAbInsShowCFZ, false );
  itemAbInsShowCFZ = new KConfigCompilerSignallingItem(innerItemAbInsShowCFZ, this, notifyFunction, signalAbInsShowCFZChanged);
  addItem( itemAbInsShowCFZ, QStringLiteral( "abInsShowCFZ" ) );
  KConfigCompilerSignallingItem  *itemAbInsOptCentres;
  KConfigSkeleton::ItemBool  *innerItemAbInsOptCentres;
  innerItemAbInsOptCentres = new KConfigSkeleton::ItemBool( currentGroup(), QStringLiteral( "abInsOptCentres" ), mAbInsOptCentres, false );
  itemAbInsOptCentres = new KConfigCompilerSignallingItem(innerItemAbInsOptCentres, this, notifyFunction, signalAbInsOptCentresChanged);
  addItem( itemAbInsOptCentres, QStringLiteral( "abInsOptCentres" ) );
  KConfigCompilerSignallingItem  *itemAbInsHSplitter;
  KConfigSkeleton::ItemString  *innerItemAbInsHSplitter;
  innerItemAbInsHSplitter = new KConfigSkeleton::ItemString( currentGroup(), QStringLiteral( "abInsHSplitter" ), mAbInsHSplitter );
  itemAbInsHSplitter = new KConfigCompilerSignallingItem(innerItemAbInsHSplitter, this, notifyFunction, signalAbInsHSplitterChanged);
  addItem( itemAbInsHSplitter, QStringLiteral( "abInsHSplitter" ) );
  KConfigCompilerSignallingItem  *itemAbInsVSplitter;
  KConfigSkeleton::ItemString  *innerItemAbInsVSplitter;
  innerItemAbInsVSplitter = new KConfigSkeleton::ItemString( currentGroup(), QStringLiteral( "abInsVSplitter" ), mAbInsVSplitter );
  itemAbInsVSplitter = new KConfigCompilerSignallingItem(innerItemAbInsVSplitter, this, notifyFunction, signalAbInsVSplitterChanged);
  addItem( itemAbInsVSplitter, QStringLiteral( "abInsVSplitter" ) );
  KConfigCompilerSignallingItem  *itemAbInsSelection;
  KConfigSkeleton::ItemString  *innerItemAbInsSelection;
  innerItemAbInsSelection = new KConfigSkeleton::ItemString( currentGroup(), QStringLiteral( "abInsSelection" ), mAbInsSelection, QStringLiteral( "None" ) );
  itemAbInsSelection = new KConfigCompilerSignallingItem(innerItemAbInsSelection, this, notifyFunction, signalAbInsSelectionChanged);
  addItem( itemAbInsSelection, QStringLiteral( "abInsSelection" ) );
  KConfigCompilerSignallingItem  *itemAbInsTheme;
  KConfigSkeleton::ItemString  *innerItemAbInsTheme;
  innerItemAbInsTheme = new KConfigSkeleton::ItemString( currentGroup(), QStringLiteral( "abInsTheme" ), mAbInsTheme, QStringLiteral( "Primary Colors" ) );
  itemAbInsTheme = new KConfigCompilerSignallingItem(innerItemAbInsTheme, this, notifyFunction, signalAbInsThemeChanged);
  addItem( itemAbInsTheme, QStringLiteral( "abInsTheme" ) );
  KConfigCompilerSignallingItem  *itemAbInsLabels;
  KConfigSkeleton::ItemBool  *innerItemAbInsLabels;
  innerItemAbInsLabels = new KConfigSkeleton::ItemBool( currentGroup(), QStringLiteral( "abInsLabels" ), mAbInsLabels, true );
  itemAbInsLabels = new KConfigCompilerSignallingItem(innerItemAbInsLabels, this, notifyFunction, signalAbInsLabelsChanged);
  addItem( itemAbInsLabels, QStringLiteral( "abInsLabels" ) );
  KConfigCompilerSignallingItem  *itemAbInsSensor;
  KConfigSkeleton::ItemBool  *innerItemAbInsSensor;
  innerItemAbInsSensor = new KConfigSkeleton::ItemBool( currentGroup(), QStringLiteral( "abInsSensor" ), mAbInsSensor, true );
  itemAbInsSensor = new KConfigCompilerSignallingItem(innerItemAbInsSensor, this, notifyFunction, signalAbInsSensorChanged);
  addItem( itemAbInsSensor, QStringLiteral( "abInsSensor" ) );
  KConfigCompilerSignallingItem  *itemAbInsPetzvalWire;
  KConfigSkeleton::ItemBool  *innerItemAbInsPetzvalWire;
  innerItemAbInsPetzvalWire = new KConfigSkeleton::ItemBool( currentGroup(), QStringLiteral( "abInsPetzvalWire" ), mAbInsPetzvalWire, true );
  itemAbInsPetzvalWire = new KConfigCompilerSignallingItem(innerItemAbInsPetzvalWire, this, notifyFunction, signalAbInsPetzvalWireChanged);
  addItem( itemAbInsPetzvalWire, QStringLiteral( "abInsPetzvalWire" ) );
  KConfigCompilerSignallingItem  *itemAbInsPetzvalSurface;
  KConfigSkeleton::ItemBool  *innerItemAbInsPetzvalSurface;
  innerItemAbInsPetzvalSurface = new KConfigSkeleton::ItemBool( currentGroup(), QStringLiteral( "abInsPetzvalSurface" ), mAbInsPetzvalSurface, false );
  itemAbInsPetzvalSurface = new KConfigCompilerSignallingItem(innerItemAbInsPetzvalSurface, this, notifyFunction, signalAbInsPetzvalSurfaceChanged);
  addItem( itemAbInsPetzvalSurface, QStringLiteral( "abInsPetzvalSurface" ) );
  KConfigCompilerSignallingItem  *itemTiltPlateType;
  KConfigSkeleton::ItemUInt  *innerItemTiltPlateType;
  innerItemTiltPlateType = new KConfigSkeleton::ItemUInt( currentGroup(), QStringLiteral( "tiltPlateType" ), mTiltPlateType, 0 );
  itemTiltPlateType = new KConfigCompilerSignallingItem(innerItemTiltPlateType, this, notifyFunction, signalTiltPlateTypeChanged);
  addItem( itemTiltPlateType, QStringLiteral( "tiltPlateType" ) );
  KConfigCompilerSignallingItem  *itemTiltRadius;
  KConfigSkeleton::ItemDouble  *innerItemTiltRadius;
  innerItemTiltRadius = new KConfigSkeleton::ItemDouble( currentGroup(), QStringLiteral( "tiltRadius" ), mTiltRadius, 64.0 );
  itemTiltRadius = new KConfigCompilerSignallingItem(innerItemTiltRadius, this, notifyFunction, signalTiltRadiusChanged);
  addItem( itemTiltRadius, QStringLiteral( "tiltRadius" ) );
  KConfigCompilerSignallingItem  *itemTiltThreadIndex;
  KConfigSkeleton::ItemUInt  *innerItemTiltThreadIndex;
  innerItemTiltThreadIndex = new KConfigSkeleton::ItemUInt( currentGroup(), QStringLiteral( "tiltThreadIndex" ), mTiltThreadIndex, 8 );
  itemTiltThreadIndex = new KConfigCompilerSignallingItem(innerItemTiltThreadIndex, this, notifyFunction, signalTiltThreadIndexChanged);
  addItem( itemTiltThreadIndex, QStringLiteral( "tiltThreadIndex" ) );
  KConfigCompilerSignallingItem  *itemTiltScrewPitch;
  KConfigSkeleton::ItemDouble  *innerItemTiltScrewPitch;
  innerItemTiltScrewPitch = new KConfigSkeleton::ItemDouble( currentGroup(), QStringLiteral( "tiltScrewPitch" ), mTiltScrewPitch, 0.5 );
  itemTiltScrewPitch = new KConfigCompilerSignallingItem(innerItemTiltScrewPitch, this, notifyFunction, signalTiltScrewPitchChanged);
  addItem( itemTiltScrewPitch, QStringLiteral( "tiltScrewPitch" ) );
  KConfigCompilerSignallingItem  *itemTiltRotation;
  KConfigSkeleton::ItemDouble  *innerItemTiltRotation;
  innerItemTiltRotation = new KConfigSkeleton::ItemDouble( currentGroup(), QStringLiteral( "tiltRotation" ), mTiltRotation, 0.0 );
  itemTiltRotation = new KConfigCompilerSignallingItem(innerItemTiltRotation, this, notifyFunction, signalTiltRotationChanged);
  addItem( itemTiltRotation, QStringLiteral( "tiltRotation" ) );
  KConfigCompilerSignallingItem  *itemTiltMode;
  KConfigSkeleton::ItemUInt  *innerItemTiltMode;
  innerItemTiltMode = new KConfigSkeleton::ItemUInt( currentGroup(), QStringLiteral( "tiltMode" ), mTiltMode, 0 );
  itemTiltMode = new KConfigCompilerSignallingItem(innerItemTiltMode, this, notifyFunction, signalTiltModeChanged);
  addItem( itemTiltMode, QStringLiteral( "tiltMode" ) );
  KConfigCompilerSignallingItem  *itemTiltPlatePresent;
  KConfigSkeleton::ItemBool  *innerItemTiltPlatePresent;
  innerItemTiltPlatePresent = new KConfigSkeleton::ItemBool( currentGroup(), QStringLiteral( "tiltPlatePresent" ), mTiltPlatePresent, false );
  itemTiltPlatePresent = new KConfigCompilerSignallingItem(innerItemTiltPlatePresent, this, notifyFunction, signalTiltPlatePresentChanged);
  addItem( itemTiltPlatePresent, QStringLiteral( "tiltPlatePresent" ) );

  setCurrentGroup( QStringLiteral( "StellarSolver" ) );

  KConfigCompilerSignallingItem  *itemFocusSextractorType;
  KConfigSkeleton::ItemUInt  *innerItemFocusSextractorType;
  innerItemFocusSextractorType = new KConfigSkeleton::ItemUInt( currentGroup(), QStringLiteral( "FocusSextractorType" ), mFocusSextractorType, 0 );
  itemFocusSextractorType = new KConfigCompilerSignallingItem(innerItemFocusSextractorType, this, notifyFunction, signalFocusSextractorTypeChanged);
  addItem( itemFocusSextractorType, QStringLiteral( "FocusSextractorType" ) );
  KConfigCompilerSignallingItem  *itemFocusOptionsProfile;
  KConfigSkeleton::ItemUInt  *innerItemFocusOptionsProfile;
  innerItemFocusOptionsProfile = new KConfigSkeleton::ItemUInt( currentGroup(), QStringLiteral( "FocusOptionsProfile" ), mFocusOptionsProfile, 0 );
  itemFocusOptionsProfile = new KConfigCompilerSignallingItem(innerItemFocusOptionsProfile, this, notifyFunction, signalFocusOptionsProfileChanged);
  addItem( itemFocusOptionsProfile, QStringLiteral( "FocusOptionsProfile" ) );
  KConfigCompilerSignallingItem  *itemHFRSextractorType;
  KConfigSkeleton::ItemUInt  *innerItemHFRSextractorType;
  innerItemHFRSextractorType = new KConfigSkeleton::ItemUInt( currentGroup(), QStringLiteral( "HFRSextractorType" ), mHFRSextractorType, 0 );
  itemHFRSextractorType = new KConfigCompilerSignallingItem(innerItemHFRSextractorType, this, notifyFunction, signalHFRSextractorTypeChanged);
  addItem( itemHFRSextractorType, QStringLiteral( "HFRSextractorType" ) );
  KConfigCompilerSignallingItem  *itemHFROptionsProfile;
  KConfigSkeleton::ItemUInt  *innerItemHFROptionsProfile;
  innerItemHFROptionsProfile = new KConfigSkeleton::ItemUInt( currentGroup(), QStringLiteral( "HFROptionsProfile" ), mHFROptionsProfile, 0 );
  itemHFROptionsProfile = new KConfigCompilerSignallingItem(innerItemHFROptionsProfile, this, notifyFunction, signalHFROptionsProfileChanged);
  addItem( itemHFROptionsProfile, QStringLiteral( "HFROptionsProfile" ) );
  KConfigCompilerSignallingItem  *itemGuideSextractorType;
  KConfigSkeleton::ItemUInt  *innerItemGuideSextractorType;
  innerItemGuideSextractorType = new KConfigSkeleton::ItemUInt( currentGroup(), QStringLiteral( "GuideSextractorType" ), mGuideSextractorType, 0 );
  itemGuideSextractorType = new KConfigCompilerSignallingItem(innerItemGuideSextractorType, this, notifyFunction, signalGuideSextractorTypeChanged);
  addItem( itemGuideSextractorType, QStringLiteral( "GuideSextractorType" ) );
  KConfigCompilerSignallingItem  *itemGuideOptionsProfile;
  KConfigSkeleton::ItemUInt  *innerItemGuideOptionsProfile;
  innerItemGuideOptionsProfile = new KConfigSkeleton::ItemUInt( currentGroup(), QStringLiteral( "GuideOptionsProfile" ), mGuideOptionsProfile, 0 );
  itemGuideOptionsProfile = new KConfigCompilerSignallingItem(innerItemGuideOptionsProfile, this, notifyFunction, signalGuideOptionsProfileChanged);
  addItem( itemGuideOptionsProfile, QStringLiteral( "GuideOptionsProfile" ) );
  KConfigCompilerSignallingItem  *itemSolveSextractorType;
  KConfigSkeleton::ItemUInt  *innerItemSolveSextractorType;
  innerItemSolveSextractorType = new KConfigSkeleton::ItemUInt( currentGroup(), QStringLiteral( "SolveSextractorType" ), mSolveSextractorType, 0 );
  itemSolveSextractorType = new KConfigCompilerSignallingItem(innerItemSolveSextractorType, this, notifyFunction, signalSolveSextractorTypeChanged);
  addItem( itemSolveSextractorType, QStringLiteral( "SolveSextractorType" ) );
  KConfigCompilerSignallingItem  *itemSolverMode;
  KConfigSkeleton::ItemUInt  *innerItemSolverMode;
  innerItemSolverMode = new KConfigSkeleton::ItemUInt( currentGroup(), QStringLiteral( "SolverMode" ), mSolverMode, 0 );
  itemSolverMode = new KConfigCompilerSignallingItem(innerItemSolverMode, this, notifyFunction, signalSolverModeChanged);
  addItem( itemSolverMode, QStringLiteral( "SolverMode" ) );
  KConfigCompilerSignallingItem  *itemSolverType;
  KConfigSkeleton::ItemUInt  *innerItemSolverType;
  innerItemSolverType = new KConfigSkeleton::ItemUInt( currentGroup(), QStringLiteral( "SolverType" ), mSolverType, 0 );
  itemSolverType = new KConfigCompilerSignallingItem(innerItemSolverType, this, notifyFunction, signalSolverTypeChanged);
  addItem( itemSolverType, QStringLiteral( "SolverType" ) );
  KConfigCompilerSignallingItem  *itemSolveOptionsProfile;
  KConfigSkeleton::ItemUInt  *innerItemSolveOptionsProfile;
  innerItemSolveOptionsProfile = new KConfigSkeleton::ItemUInt( currentGroup(), QStringLiteral( "SolveOptionsProfile" ), mSolveOptionsProfile, 0 );
  itemSolveOptionsProfile = new KConfigCompilerSignallingItem(innerItemSolveOptionsProfile, this, notifyFunction, signalSolveOptionsProfileChanged);
  addItem( itemSolveOptionsProfile, QStringLiteral( "SolveOptionsProfile" ) );
  KConfigCompilerSignallingItem  *itemLoggerLevel;
  KConfigSkeleton::ItemUInt  *innerItemLoggerLevel;
  innerItemLoggerLevel = new KConfigSkeleton::ItemUInt( currentGroup(), QStringLiteral( "LoggerLevel" ), mLoggerLevel, 0 );
  itemLoggerLevel = new KConfigCompilerSignallingItem(innerItemLoggerLevel, this, notifyFunction, signalLoggerLevelChanged);
  addItem( itemLoggerLevel, QStringLiteral( "LoggerLevel" ) );
  KConfigCompilerSignallingItem  *itemAstrometryLogToFile;
  KConfigSkeleton::ItemBool  *innerItemAstrometryLogToFile;
  innerItemAstrometryLogToFile = new KConfigSkeleton::ItemBool( currentGroup(), QStringLiteral( "AstrometryLogToFile" ), mAstrometryLogToFile, true );
  itemAstrometryLogToFile = new KConfigCompilerSignallingItem(innerItemAstrometryLogToFile, this, notifyFunction, signalAstrometryLogToFileChanged);
  addItem( itemAstrometryLogToFile, QStringLiteral( "AstrometryLogToFile" ) );
  KConfigCompilerSignallingItem  *itemAstrometryLogFilepath;
  KConfigSkeleton::ItemString  *innerItemAstrometryLogFilepath;
  innerItemAstrometryLogFilepath = new KConfigSkeleton::ItemString( currentGroup(), QStringLiteral( "AstrometryLogFilepath" ), mAstrometryLogFilepath, KSUtils::getDefaultPath("AstrometryLogFilepath") );
  itemAstrometryLogFilepath = new KConfigCompilerSignallingItem(innerItemAstrometryLogFilepath, this, notifyFunction, signalAstrometryLogFilepathChanged);
  addItem( itemAstrometryLogFilepath, QStringLiteral( "AstrometryLogFilepath" ) );
  KConfigCompilerSignallingItem  *itemAstrometryIndexFolderList;
  KConfigSkeleton::ItemStringList  *innerItemAstrometryIndexFolderList;
  innerItemAstrometryIndexFolderList = new KConfigSkeleton::ItemStringList( currentGroup(), QStringLiteral( "AstrometryIndexFolderList" ), mAstrometryIndexFolderList, KSUtils::getAstrometryDefaultIndexFolderPaths() );
  itemAstrometryIndexFolderList = new KConfigCompilerSignallingItem(innerItemAstrometryIndexFolderList, this, notifyFunction, signalAstrometryIndexFolderListChanged);
  addItem( itemAstrometryIndexFolderList, QStringLiteral( "AstrometryIndexFolderList" ) );

  setCurrentGroup( QStringLiteral( "Align" ) );

  KConfigCompilerSignallingItem  *itemAlignExposure;
  KConfigSkeleton::ItemDouble  *innerItemAlignExposure;
  innerItemAlignExposure = new KConfigSkeleton::ItemDouble( currentGroup(), QStringLiteral( "AlignExposure" ), mAlignExposure, 5 );
  itemAlignExposure = new KConfigCompilerSignallingItem(innerItemAlignExposure, this, notifyFunction, signalAlignExposureChanged);
  addItem( itemAlignExposure, QStringLiteral( "AlignExposure" ) );
  KConfigCompilerSignallingItem  *itemAlignBinning;
  KConfigSkeleton::ItemString  *innerItemAlignBinning;
  innerItemAlignBinning = new KConfigSkeleton::ItemString( currentGroup(), QStringLiteral( "AlignBinning" ), mAlignBinning, QStringLiteral( "2x2" ) );
  itemAlignBinning = new KConfigCompilerSignallingItem(innerItemAlignBinning, this, notifyFunction, signalAlignBinningChanged);
  addItem( itemAlignBinning, QStringLiteral( "AlignBinning" ) );
  KConfigCompilerSignallingItem  *itemAlignGain;
  KConfigSkeleton::ItemDouble  *innerItemAlignGain;
  innerItemAlignGain = new KConfigSkeleton::ItemDouble( currentGroup(), QStringLiteral( "AlignGain" ), mAlignGain, 0 );
  itemAlignGain = new KConfigCompilerSignallingItem(innerItemAlignGain, this, notifyFunction, signalAlignGainChanged);
  addItem( itemAlignGain, QStringLiteral( "AlignGain" ) );
  KConfigCompilerSignallingItem  *itemAlignISO;
  KConfigSkeleton::ItemDouble  *innerItemAlignISO;
  innerItemAlignISO = new KConfigSkeleton::ItemDouble( currentGroup(), QStringLiteral( "AlignISO" ), mAlignISO, 0 );
  itemAlignISO = new KConfigCompilerSignallingItem(innerItemAlignISO, this, notifyFunction, signalAlignISOChanged);
  addItem( itemAlignISO, QStringLiteral( "AlignISO" ) );
  KConfigCompilerSignallingItem  *itemAlignDarkFrame;
  KConfigSkeleton::ItemBool  *innerItemAlignDarkFrame;
  innerItemAlignDarkFrame = new KConfigSkeleton::ItemBool( currentGroup(), QStringLiteral( "AlignDarkFrame" ), mAlignDarkFrame, false );
  itemAlignDarkFrame = new KConfigCompilerSignallingItem(innerItemAlignDarkFrame, this, notifyFunction, signalAlignDarkFrameChanged);
  addItem( itemAlignDarkFrame, QStringLiteral( "AlignDarkFrame" ) );
  KConfigCompilerSignallingItem  *itemAlignFilter;
  KConfigSkeleton::ItemString  *innerItemAlignFilter;
  innerItemAlignFilter = new KConfigSkeleton::ItemString( currentGroup(), QStringLiteral( "AlignFilter" ), mAlignFilter );
  itemAlignFilter = new KConfigCompilerSignallingItem(innerItemAlignFilter, this, notifyFunction, signalAlignFilterChanged);
  addItem( itemAlignFilter, QStringLiteral( "AlignFilter" ) );
  KConfigCompilerSignallingItem  *itemAlignUseCurrentFilter;
  KConfigSkeleton::ItemBool  *innerItemAlignUseCurrentFilter;
  innerItemAlignUseCurrentFilter = new KConfigSkeleton::ItemBool( currentGroup(), QStringLiteral( "AlignUseCurrentFilter" ), mAlignUseCurrentFilter, false );
  itemAlignUseCurrentFilter = new KConfigCompilerSignallingItem(innerItemAlignUseCurrentFilter, this, notifyFunction, signalAlignUseCurrentFilterChanged);
  addItem( itemAlignUseCurrentFilter, QStringLiteral( "AlignUseCurrentFilter" ) );
  KConfigCompilerSignallingItem  *itemAstrometryUseRotator;
  KConfigSkeleton::ItemBool  *innerItemAstrometryUseRotator;
  innerItemAstrometryUseRotator = new KConfigSkeleton::ItemBool( currentGroup(), QStringLiteral( "AstrometryUseRotator" ), mAstrometryUseRotator, true );
  itemAstrometryUseRotator = new KConfigCompilerSignallingItem(innerItemAstrometryUseRotator, this, notifyFunction, signalAstrometryUseRotatorChanged);
  addItem( itemAstrometryUseRotator, QStringLiteral( "AstrometryUseRotator" ) );
  KConfigCompilerSignallingItem  *itemAstrometryRotatorThreshold;
  KConfigSkeleton::ItemDouble  *innerItemAstrometryRotatorThreshold;
  innerItemAstrometryRotatorThreshold = new KConfigSkeleton::ItemDouble( currentGroup(), QStringLiteral( "AstrometryRotatorThreshold" ), mAstrometryRotatorThreshold, 30 );
  itemAstrometryRotatorThreshold = new KConfigCompilerSignallingItem(innerItemAstrometryRotatorThreshold, this, notifyFunction, signalAstrometryRotatorThresholdChanged);
  addItem( itemAstrometryRotatorThreshold, QStringLiteral( "AstrometryRotatorThreshold" ) );
  KConfigCompilerSignallingItem  *itemAstrometryFlipRotationAllowed;
  KConfigSkeleton::ItemBool  *innerItemAstrometryFlipRotationAllowed;
  innerItemAstrometryFlipRotationAllowed = new KConfigSkeleton::ItemBool( currentGroup(), QStringLiteral( "AstrometryFlipRotationAllowed" ), mAstrometryFlipRotationAllowed, true );
  itemAstrometryFlipRotationAllowed = new KConfigCompilerSignallingItem(innerItemAstrometryFlipRotationAllowed, this, notifyFunction, signalAstrometryFlipRotationAllowedChanged);
  addItem( itemAstrometryFlipRotationAllowed, QStringLiteral( "AstrometryFlipRotationAllowed" ) );
  KConfigCompilerSignallingItem  *itemRotatorParityReversed;
  KConfigSkeleton::ItemBool  *innerItemRotatorParityReversed;
  innerItemRotatorParityReversed = new KConfigSkeleton::ItemBool( currentGroup(), QStringLiteral( "RotatorParityReversed" ), mRotatorParityReversed, false );
  itemRotatorParityReversed = new KConfigCompilerSignallingItem(innerItemRotatorParityReversed, this, notifyFunction, signalRotatorParityReversedChanged);
  addItem( itemRotatorParityReversed, QStringLiteral( "RotatorParityReversed" ) );
  KConfigCompilerSignallingItem  *itemAstrometrySolverWCS;
  KConfigSkeleton::ItemBool  *innerItemAstrometrySolverWCS;
  innerItemAstrometrySolverWCS = new KConfigSkeleton::ItemBool( currentGroup(), QStringLiteral( "AstrometrySolverWCS" ), mAstrometrySolverWCS, true );
  itemAstrometrySolverWCS = new KConfigCompilerSignallingItem(innerItemAstrometrySolverWCS, this, notifyFunction, signalAstrometrySolverWCSChanged);
  addItem( itemAstrometrySolverWCS, QStringLiteral( "AstrometrySolverWCS" ) );
  KConfigCompilerSignallingItem  *itemAstrometrySolverOverlay;
  KConfigSkeleton::ItemBool  *innerItemAstrometrySolverOverlay;
  innerItemAstrometrySolverOverlay = new KConfigSkeleton::ItemBool( currentGroup(), QStringLiteral( "AstrometrySolverOverlay" ), mAstrometrySolverOverlay, false );
  itemAstrometrySolverOverlay = new KConfigCompilerSignallingItem(innerItemAstrometrySolverOverlay, this, notifyFunction, signalAstrometrySolverOverlayChanged);
  addItem( itemAstrometrySolverOverlay, QStringLiteral( "AstrometrySolverOverlay" ) );
  KConfigCompilerSignallingItem  *itemAstrometryDifferentialSlewing;
  KConfigSkeleton::ItemBool  *innerItemAstrometryDifferentialSlewing;
  innerItemAstrometryDifferentialSlewing = new KConfigSkeleton::ItemBool( currentGroup(), QStringLiteral( "AstrometryDifferentialSlewing" ), mAstrometryDifferentialSlewing, false );
  itemAstrometryDifferentialSlewing = new KConfigCompilerSignallingItem(innerItemAstrometryDifferentialSlewing, this, notifyFunction, signalAstrometryDifferentialSlewingChanged);
  addItem( itemAstrometryDifferentialSlewing, QStringLiteral( "AstrometryDifferentialSlewing" ) );
  KConfigCompilerSignallingItem  *itemAlignAccuracyThreshold;
  KConfigSkeleton::ItemUInt  *innerItemAlignAccuracyThreshold;
  innerItemAlignAccuracyThreshold = new KConfigSkeleton::ItemUInt( currentGroup(), QStringLiteral( "AlignAccuracyThreshold" ), mAlignAccuracyThreshold, 30 );
  itemAlignAccuracyThreshold = new KConfigCompilerSignallingItem(innerItemAlignAccuracyThreshold, this, notifyFunction, signalAlignAccuracyThresholdChanged);
  addItem( itemAlignAccuracyThreshold, QStringLiteral( "AlignAccuracyThreshold" ) );
  KConfigCompilerSignallingItem  *itemAlignSettlingTime;
  KConfigSkeleton::ItemUInt  *innerItemAlignSettlingTime;
  innerItemAlignSettlingTime = new KConfigSkeleton::ItemUInt( currentGroup(), QStringLiteral( "AlignSettlingTime" ), mAlignSettlingTime, 1500 );
  itemAlignSettlingTime = new KConfigCompilerSignallingItem(innerItemAlignSettlingTime, this, notifyFunction, signalAlignSettlingTimeChanged);
  addItem( itemAlignSettlingTime, QStringLiteral( "AlignSettlingTime" ) );
  KConfigCompilerSignallingItem  *itemAstrometryUseNoFITS2FITS;
  KConfigSkeleton::ItemBool  *innerItemAstrometryUseNoFITS2FITS;
  innerItemAstrometryUseNoFITS2FITS = new KConfigSkeleton::ItemBool( currentGroup(), QStringLiteral( "AstrometryUseNoFITS2FITS" ), mAstrometryUseNoFITS2FITS, false );
  itemAstrometryUseNoFITS2FITS = new KConfigCompilerSignallingItem(innerItemAstrometryUseNoFITS2FITS, this, notifyFunction, signalAstrometryUseNoFITS2FITSChanged);
  addItem( itemAstrometryUseNoFITS2FITS, QStringLiteral( "AstrometryUseNoFITS2FITS" ) );
  KConfigCompilerSignallingItem  *itemAstrometryUseResort;
  KConfigSkeleton::ItemBool  *innerItemAstrometryUseResort;
  innerItemAstrometryUseResort = new KConfigSkeleton::ItemBool( currentGroup(), QStringLiteral( "AstrometryUseResort" ), mAstrometryUseResort, true );
  itemAstrometryUseResort = new KConfigCompilerSignallingItem(innerItemAstrometryUseResort, this, notifyFunction, signalAstrometryUseResortChanged);
  addItem( itemAstrometryUseResort, QStringLiteral( "AstrometryUseResort" ) );
  KConfigCompilerSignallingItem  *itemAstrometryUseNoVerify;
  KConfigSkeleton::ItemBool  *innerItemAstrometryUseNoVerify;
  innerItemAstrometryUseNoVerify = new KConfigSkeleton::ItemBool( currentGroup(), QStringLiteral( "AstrometryUseNoVerify" ), mAstrometryUseNoVerify, true );
  itemAstrometryUseNoVerify = new KConfigCompilerSignallingItem(innerItemAstrometryUseNoVerify, this, notifyFunction, signalAstrometryUseNoVerifyChanged);
  addItem( itemAstrometryUseNoVerify, QStringLiteral( "AstrometryUseNoVerify" ) );
  KConfigCompilerSignallingItem  *itemAstrometryUseImageScale;
  KConfigSkeleton::ItemBool  *innerItemAstrometryUseImageScale;
  innerItemAstrometryUseImageScale = new KConfigSkeleton::ItemBool( currentGroup(), QStringLiteral( "AstrometryUseImageScale" ), mAstrometryUseImageScale, true );
  itemAstrometryUseImageScale = new KConfigCompilerSignallingItem(innerItemAstrometryUseImageScale, this, notifyFunction, signalAstrometryUseImageScaleChanged);
  addItem( itemAstrometryUseImageScale, QStringLiteral( "AstrometryUseImageScale" ) );
  KConfigCompilerSignallingItem  *itemAstrometryImageScaleLow;
  KConfigSkeleton::ItemDouble  *innerItemAstrometryImageScaleLow;
  innerItemAstrometryImageScaleLow = new KConfigSkeleton::ItemDouble( currentGroup(), QStringLiteral( "AstrometryImageScaleLow" ), mAstrometryImageScaleLow );
  itemAstrometryImageScaleLow = new KConfigCompilerSignallingItem(innerItemAstrometryImageScaleLow, this, notifyFunction, signalAstrometryImageScaleLowChanged);
  addItem( itemAstrometryImageScaleLow, QStringLiteral( "AstrometryImageScaleLow" ) );
  KConfigCompilerSignallingItem  *itemAstrometryImageScaleHigh;
  KConfigSkeleton::ItemDouble  *innerItemAstrometryImageScaleHigh;
  innerItemAstrometryImageScaleHigh = new KConfigSkeleton::ItemDouble( currentGroup(), QStringLiteral( "AstrometryImageScaleHigh" ), mAstrometryImageScaleHigh );
  itemAstrometryImageScaleHigh = new KConfigCompilerSignallingItem(innerItemAstrometryImageScaleHigh, this, notifyFunction, signalAstrometryImageScaleHighChanged);
  addItem( itemAstrometryImageScaleHigh, QStringLiteral( "AstrometryImageScaleHigh" ) );
  KConfigCompilerSignallingItem  *itemAstrometryAutoUpdateImageScale;
  KConfigSkeleton::ItemBool  *innerItemAstrometryAutoUpdateImageScale;
  innerItemAstrometryAutoUpdateImageScale = new KConfigSkeleton::ItemBool( currentGroup(), QStringLiteral( "AstrometryAutoUpdateImageScale" ), mAstrometryAutoUpdateImageScale, true );
  itemAstrometryAutoUpdateImageScale = new KConfigCompilerSignallingItem(innerItemAstrometryAutoUpdateImageScale, this, notifyFunction, signalAstrometryAutoUpdateImageScaleChanged);
  addItem( itemAstrometryAutoUpdateImageScale, QStringLiteral( "AstrometryAutoUpdateImageScale" ) );
  KConfigCompilerSignallingItem  *itemAstrometryImageScaleUnits;
  KConfigSkeleton::ItemUInt  *innerItemAstrometryImageScaleUnits;
  innerItemAstrometryImageScaleUnits = new KConfigSkeleton::ItemUInt( currentGroup(), QStringLiteral( "AstrometryImageScaleUnits" ), mAstrometryImageScaleUnits, 1 );
  itemAstrometryImageScaleUnits = new KConfigCompilerSignallingItem(innerItemAstrometryImageScaleUnits, this, notifyFunction, signalAstrometryImageScaleUnitsChanged);
  addItem( itemAstrometryImageScaleUnits, QStringLiteral( "AstrometryImageScaleUnits" ) );
  KConfigCompilerSignallingItem  *itemAstrometryUseDownsample;
  KConfigSkeleton::ItemBool  *innerItemAstrometryUseDownsample;
  innerItemAstrometryUseDownsample = new KConfigSkeleton::ItemBool( currentGroup(), QStringLiteral( "AstrometryUseDownsample" ), mAstrometryUseDownsample, true );
  itemAstrometryUseDownsample = new KConfigCompilerSignallingItem(innerItemAstrometryUseDownsample, this, notifyFunction, signalAstrometryUseDownsampleChanged);
  addItem( itemAstrometryUseDownsample, QStringLiteral( "AstrometryUseDownsample" ) );
  KConfigCompilerSignallingItem  *itemAstrometryDownsample;
  KConfigSkeleton::ItemUInt  *innerItemAstrometryDownsample;
  innerItemAstrometryDownsample = new KConfigSkeleton::ItemUInt( currentGroup(), QStringLiteral( "AstrometryDownsample" ), mAstrometryDownsample, 2 );
  itemAstrometryDownsample = new KConfigCompilerSignallingItem(innerItemAstrometryDownsample, this, notifyFunction, signalAstrometryDownsampleChanged);
  addItem( itemAstrometryDownsample, QStringLiteral( "AstrometryDownsample" ) );
  KConfigCompilerSignallingItem  *itemAstrometryAutoDownsample;
  KConfigSkeleton::ItemBool  *innerItemAstrometryAutoDownsample;
  innerItemAstrometryAutoDownsample = new KConfigSkeleton::ItemBool( currentGroup(), QStringLiteral( "AstrometryAutoDownsample" ), mAstrometryAutoDownsample, true );
  itemAstrometryAutoDownsample = new KConfigCompilerSignallingItem(innerItemAstrometryAutoDownsample, this, notifyFunction, signalAstrometryAutoDownsampleChanged);
  addItem( itemAstrometryAutoDownsample, QStringLiteral( "AstrometryAutoDownsample" ) );
  KConfigCompilerSignallingItem  *itemAstrometryDynamicThreshold;
  KConfigSkeleton::ItemBool  *innerItemAstrometryDynamicThreshold;
  innerItemAstrometryDynamicThreshold = new KConfigSkeleton::ItemBool( currentGroup(), QStringLiteral( "AstrometryDynamicThreshold" ), mAstrometryDynamicThreshold, false );
  itemAstrometryDynamicThreshold = new KConfigCompilerSignallingItem(innerItemAstrometryDynamicThreshold, this, notifyFunction, signalAstrometryDynamicThresholdChanged);
  addItem( itemAstrometryDynamicThreshold, QStringLiteral( "AstrometryDynamicThreshold" ) );
  KConfigCompilerSignallingItem  *itemAstrometryUsePosition;
  KConfigSkeleton::ItemBool  *innerItemAstrometryUsePosition;
  innerItemAstrometryUsePosition = new KConfigSkeleton::ItemBool( currentGroup(), QStringLiteral( "AstrometryUsePosition" ), mAstrometryUsePosition, true );
  itemAstrometryUsePosition = new KConfigCompilerSignallingItem(innerItemAstrometryUsePosition, this, notifyFunction, signalAstrometryUsePositionChanged);
  addItem( itemAstrometryUsePosition, QStringLiteral( "AstrometryUsePosition" ) );
  KConfigCompilerSignallingItem  *itemAstrometryPositionRA;
  KConfigSkeleton::ItemDouble  *innerItemAstrometryPositionRA;
  innerItemAstrometryPositionRA = new KConfigSkeleton::ItemDouble( currentGroup(), QStringLiteral( "AstrometryPositionRA" ), mAstrometryPositionRA );
  itemAstrometryPositionRA = new KConfigCompilerSignallingItem(innerItemAstrometryPositionRA, this, notifyFunction, signalAstrometryPositionRAChanged);
  addItem( itemAstrometryPositionRA, QStringLiteral( "AstrometryPositionRA" ) );
  KConfigCompilerSignallingItem  *itemAstrometryPositionDE;
  KConfigSkeleton::ItemDouble  *innerItemAstrometryPositionDE;
  innerItemAstrometryPositionDE = new KConfigSkeleton::ItemDouble( currentGroup(), QStringLiteral( "AstrometryPositionDE" ), mAstrometryPositionDE );
  itemAstrometryPositionDE = new KConfigCompilerSignallingItem(innerItemAstrometryPositionDE, this, notifyFunction, signalAstrometryPositionDEChanged);
  addItem( itemAstrometryPositionDE, QStringLiteral( "AstrometryPositionDE" ) );
  KConfigCompilerSignallingItem  *itemAstrometryAutoUpdatePosition;
  KConfigSkeleton::ItemBool  *innerItemAstrometryAutoUpdatePosition;
  innerItemAstrometryAutoUpdatePosition = new KConfigSkeleton::ItemBool( currentGroup(), QStringLiteral( "AstrometryAutoUpdatePosition" ), mAstrometryAutoUpdatePosition, true );
  itemAstrometryAutoUpdatePosition = new KConfigCompilerSignallingItem(innerItemAstrometryAutoUpdatePosition, this, notifyFunction, signalAstrometryAutoUpdatePositionChanged);
  addItem( itemAstrometryAutoUpdatePosition, QStringLiteral( "AstrometryAutoUpdatePosition" ) );
  KConfigCompilerSignallingItem  *itemAstrometryRadius;
  KConfigSkeleton::ItemDouble  *innerItemAstrometryRadius;
  innerItemAstrometryRadius = new KConfigSkeleton::ItemDouble( currentGroup(), QStringLiteral( "AstrometryRadius" ), mAstrometryRadius, 30 );
  itemAstrometryRadius = new KConfigCompilerSignallingItem(innerItemAstrometryRadius, this, notifyFunction, signalAstrometryRadiusChanged);
  addItem( itemAstrometryRadius, QStringLiteral( "AstrometryRadius" ) );
  KConfigCompilerSignallingItem  *itemAstrometryDetectParity;
  KConfigSkeleton::ItemBool  *innerItemAstrometryDetectParity;
  innerItemAstrometryDetectParity = new KConfigSkeleton::ItemBool( currentGroup(), QStringLiteral( "AstrometryDetectParity" ), mAstrometryDetectParity, false );
  itemAstrometryDetectParity = new KConfigCompilerSignallingItem(innerItemAstrometryDetectParity, this, notifyFunction, signalAstrometryDetectParityChanged);
  addItem( itemAstrometryDetectParity, QStringLiteral( "AstrometryDetectParity" ) );
  KConfigCompilerSignallingItem  *itemAstrometryCustomOptions;
  KConfigSkeleton::ItemString  *innerItemAstrometryCustomOptions;
  innerItemAstrometryCustomOptions = new KConfigSkeleton::ItemString( currentGroup(), QStringLiteral( "AstrometryCustomOptions" ), mAstrometryCustomOptions );
  itemAstrometryCustomOptions = new KConfigCompilerSignallingItem(innerItemAstrometryCustomOptions, this, notifyFunction, signalAstrometryCustomOptionsChanged);
  addItem( itemAstrometryCustomOptions, QStringLiteral( "AstrometryCustomOptions" ) );
  KConfigCompilerSignallingItem  *itemAstrometrySolverBinary;
  KConfigSkeleton::ItemString  *innerItemAstrometrySolverBinary;
  innerItemAstrometrySolverBinary = new KConfigSkeleton::ItemString( currentGroup(), QStringLiteral( "AstrometrySolverBinary" ), mAstrometrySolverBinary, KSUtils::getDefaultPath("AstrometrySolverBinary") );
  itemAstrometrySolverBinary = new KConfigCompilerSignallingItem(innerItemAstrometrySolverBinary, this, notifyFunction, signalAstrometrySolverBinaryChanged);
  addItem( itemAstrometrySolverBinary, QStringLiteral( "AstrometrySolverBinary" ) );
  KConfigCompilerSignallingItem  *itemAstrometryWCSInfo;
  KConfigSkeleton::ItemString  *innerItemAstrometryWCSInfo;
  innerItemAstrometryWCSInfo = new KConfigSkeleton::ItemString( currentGroup(), QStringLiteral( "AstrometryWCSInfo" ), mAstrometryWCSInfo, KSUtils::getDefaultPath("AstrometryWCSInfo") );
  itemAstrometryWCSInfo = new KConfigCompilerSignallingItem(innerItemAstrometryWCSInfo, this, notifyFunction, signalAstrometryWCSInfoChanged);
  addItem( itemAstrometryWCSInfo, QStringLiteral( "AstrometryWCSInfo" ) );
  KConfigCompilerSignallingItem  *itemAstrometryConfFile;
  KConfigSkeleton::ItemString  *innerItemAstrometryConfFile;
  innerItemAstrometryConfFile = new KConfigSkeleton::ItemString( currentGroup(), QStringLiteral( "AstrometryConfFile" ), mAstrometryConfFile, KSUtils::getDefaultPath("AstrometryConfFile") );
  itemAstrometryConfFile = new KConfigCompilerSignallingItem(innerItemAstrometryConfFile, this, notifyFunction, signalAstrometryConfFileChanged);
  addItem( itemAstrometryConfFile, QStringLiteral( "AstrometryConfFile" ) );
  KConfigCompilerSignallingItem  *itemSextractorBinary;
  KConfigSkeleton::ItemString  *innerItemSextractorBinary;
  innerItemSextractorBinary = new KConfigSkeleton::ItemString( currentGroup(), QStringLiteral( "SextractorBinary" ), mSextractorBinary, KSUtils::getDefaultPath("SextractorBinary") );
  itemSextractorBinary = new KConfigCompilerSignallingItem(innerItemSextractorBinary, this, notifyFunction, signalSextractorBinaryChanged);
  addItem( itemSextractorBinary, QStringLiteral( "SextractorBinary" ) );
  KConfigCompilerSignallingItem  *itemWatneyBinary;
  KConfigSkeleton::ItemString  *innerItemWatneyBinary;
  innerItemWatneyBinary = new KConfigSkeleton::ItemString( currentGroup(), QStringLiteral( "WatneyBinary" ), mWatneyBinary, KSUtils::getDefaultPath("WatneyBinary") );
  itemWatneyBinary = new KConfigCompilerSignallingItem(innerItemWatneyBinary, this, notifyFunction, signalWatneyBinaryChanged);
  addItem( itemWatneyBinary, QStringLiteral( "WatneyBinary" ) );
  KConfigCompilerSignallingItem  *itemAstrometryAPIKey;
  KConfigSkeleton::ItemString  *innerItemAstrometryAPIKey;
  innerItemAstrometryAPIKey = new KConfigSkeleton::ItemString( currentGroup(), QStringLiteral( "AstrometryAPIKey" ), mAstrometryAPIKey, QStringLiteral( "iczikaqstszeptgs" ) );
  itemAstrometryAPIKey = new KConfigCompilerSignallingItem(innerItemAstrometryAPIKey, this, notifyFunction, signalAstrometryAPIKeyChanged);
  addItem( itemAstrometryAPIKey, QStringLiteral( "AstrometryAPIKey" ) );
  KConfigCompilerSignallingItem  *itemAstrometryAPIURL;
  KConfigSkeleton::ItemString  *innerItemAstrometryAPIURL;
  innerItemAstrometryAPIURL = new KConfigSkeleton::ItemString( currentGroup(), QStringLiteral( "AstrometryAPIURL" ), mAstrometryAPIURL, QStringLiteral( "http://nova.astrometry.net" ) );
  itemAstrometryAPIURL = new KConfigCompilerSignallingItem(innerItemAstrometryAPIURL, this, notifyFunction, signalAstrometryAPIURLChanged);
  addItem( itemAstrometryAPIURL, QStringLiteral( "AstrometryAPIURL" ) );
  KConfigCompilerSignallingItem  *itemAstrometryUseJPEG;
  KConfigSkeleton::ItemBool  *innerItemAstrometryUseJPEG;
  innerItemAstrometryUseJPEG = new KConfigSkeleton::ItemBool( currentGroup(), QStringLiteral( "AstrometryUseJPEG" ), mAstrometryUseJPEG, true );
  itemAstrometryUseJPEG = new KConfigCompilerSignallingItem(innerItemAstrometryUseJPEG, this, notifyFunction, signalAstrometryUseJPEGChanged);
  addItem( itemAstrometryUseJPEG, QStringLiteral( "AstrometryUseJPEG" ) );
  KConfigCompilerSignallingItem  *itemAstrometryTimeout;
  KConfigSkeleton::ItemUInt  *innerItemAstrometryTimeout;
  innerItemAstrometryTimeout = new KConfigSkeleton::ItemUInt( currentGroup(), QStringLiteral( "AstrometryTimeout" ), mAstrometryTimeout, 180 );
  itemAstrometryTimeout = new KConfigCompilerSignallingItem(innerItemAstrometryTimeout, this, notifyFunction, signalAstrometryTimeoutChanged);
  addItem( itemAstrometryTimeout, QStringLiteral( "AstrometryTimeout" ) );
  KConfigCompilerSignallingItem  *itemPAHMountSpeed;
  KConfigSkeleton::ItemString  *innerItemPAHMountSpeed;
  innerItemPAHMountSpeed = new KConfigSkeleton::ItemString( currentGroup(), QStringLiteral( "PAHMountSpeed" ), mPAHMountSpeed );
  itemPAHMountSpeed = new KConfigCompilerSignallingItem(innerItemPAHMountSpeed, this, notifyFunction, signalPAHMountSpeedChanged);
  addItem( itemPAHMountSpeed, QStringLiteral( "PAHMountSpeed" ) );
  KConfigCompilerSignallingItem  *itemPAHRotaion;
  KConfigSkeleton::ItemDouble  *innerItemPAHRotaion;
  innerItemPAHRotaion = new KConfigSkeleton::ItemDouble( currentGroup(), QStringLiteral( "PAHRotaion" ), mPAHRotaion, 30.0 );
  itemPAHRotaion = new KConfigCompilerSignallingItem(innerItemPAHRotaion, this, notifyFunction, signalPAHRotaionChanged);
  addItem( itemPAHRotaion, QStringLiteral( "PAHRotaion" ) );
  KConfigCompilerSignallingItem  *itemPAHRefreshAlgorithm;
  KConfigSkeleton::ItemString  *innerItemPAHRefreshAlgorithm;
  innerItemPAHRefreshAlgorithm = new KConfigSkeleton::ItemString( currentGroup(), QStringLiteral( "PAHRefreshAlgorithm" ), mPAHRefreshAlgorithm );
  itemPAHRefreshAlgorithm = new KConfigCompilerSignallingItem(innerItemPAHRefreshAlgorithm, this, notifyFunction, signalPAHRefreshAlgorithmChanged);
  addItem( itemPAHRefreshAlgorithm, QStringLiteral( "PAHRefreshAlgorithm" ) );
  KConfigCompilerSignallingItem  *itemPAHDirection;
  KConfigSkeleton::ItemString  *innerItemPAHDirection;
  innerItemPAHDirection = new KConfigSkeleton::ItemString( currentGroup(), QStringLiteral( "PAHDirection" ), mPAHDirection );
  itemPAHDirection = new KConfigCompilerSignallingItem(innerItemPAHDirection, this, notifyFunction, signalPAHDirectionChanged);
  addItem( itemPAHDirection, QStringLiteral( "PAHDirection" ) );
  KConfigCompilerSignallingItem  *itemPAHAutoPark;
  KConfigSkeleton::ItemBool  *innerItemPAHAutoPark;
  innerItemPAHAutoPark = new KConfigSkeleton::ItemBool( currentGroup(), QStringLiteral( "PAHAutoPark" ), mPAHAutoPark, false );
  itemPAHAutoPark = new KConfigCompilerSignallingItem(innerItemPAHAutoPark, this, notifyFunction, signalPAHAutoParkChanged);
  addItem( itemPAHAutoPark, QStringLiteral( "PAHAutoPark" ) );
  KConfigCompilerSignallingItem  *itemPAHManualSlew;
  KConfigSkeleton::ItemBool  *innerItemPAHManualSlew;
  innerItemPAHManualSlew = new KConfigSkeleton::ItemBool( currentGroup(), QStringLiteral( "PAHManualSlew" ), mPAHManualSlew, false );
  itemPAHManualSlew = new KConfigCompilerSignallingItem(innerItemPAHManualSlew, this, notifyFunction, signalPAHManualSlewChanged);
  addItem( itemPAHManualSlew, QStringLiteral( "PAHManualSlew" ) );
  KConfigCompilerSignallingItem  *itemPAHExposure;
  KConfigSkeleton::ItemDouble  *innerItemPAHExposure;
  innerItemPAHExposure = new KConfigSkeleton::ItemDouble( currentGroup(), QStringLiteral( "PAHExposure" ), mPAHExposure, 2 );
  itemPAHExposure = new KConfigCompilerSignallingItem(innerItemPAHExposure, this, notifyFunction, signalPAHExposureChanged);
  addItem( itemPAHExposure, QStringLiteral( "PAHExposure" ) );
  KConfigCompilerSignallingItem  *itemPAHAutoPACCorrection;
  KConfigSkeleton::ItemBool  *innerItemPAHAutoPACCorrection;
  innerItemPAHAutoPACCorrection = new KConfigSkeleton::ItemBool( currentGroup(), QStringLiteral( "PAHAutoPACCorrection" ), mPAHAutoPACCorrection, true );
  itemPAHAutoPACCorrection = new KConfigCompilerSignallingItem(innerItemPAHAutoPACCorrection, this, notifyFunction, signalPAHAutoPACCorrectionChanged);
  addItem( itemPAHAutoPACCorrection, QStringLiteral( "PAHAutoPACCorrection" ) );
  KConfigCompilerSignallingItem  *itemPAHAutoChangeDirection;
  KConfigSkeleton::ItemBool  *innerItemPAHAutoChangeDirection;
  innerItemPAHAutoChangeDirection = new KConfigSkeleton::ItemBool( currentGroup(), QStringLiteral( "PAHAutoChangeDirection" ), mPAHAutoChangeDirection, true );
  itemPAHAutoChangeDirection = new KConfigCompilerSignallingItem(innerItemPAHAutoChangeDirection, this, notifyFunction, signalPAHAutoChangeDirectionChanged);
  addItem( itemPAHAutoChangeDirection, QStringLiteral( "PAHAutoChangeDirection" ) );
  KConfigCompilerSignallingItem  *itemPAHSuccessThreshold;
  KConfigSkeleton::ItemDouble  *innerItemPAHSuccessThreshold;
  innerItemPAHSuccessThreshold = new KConfigSkeleton::ItemDouble( currentGroup(), QStringLiteral( "PAHSuccessThreshold" ), mPAHSuccessThreshold, 30.0 );
  itemPAHSuccessThreshold = new KConfigCompilerSignallingItem(innerItemPAHSuccessThreshold, this, notifyFunction, signalPAHSuccessThresholdChanged);
  addItem( itemPAHSuccessThreshold, QStringLiteral( "PAHSuccessThreshold" ) );
  KConfigCompilerSignallingItem  *itemPAHCorrectionTimeout;
  KConfigSkeleton::ItemUInt  *innerItemPAHCorrectionTimeout;
  innerItemPAHCorrectionTimeout = new KConfigSkeleton::ItemUInt( currentGroup(), QStringLiteral( "PAHCorrectionTimeout" ), mPAHCorrectionTimeout, 300 );
  itemPAHCorrectionTimeout = new KConfigCompilerSignallingItem(innerItemPAHCorrectionTimeout, this, notifyFunction, signalPAHCorrectionTimeoutChanged);
  addItem( itemPAHCorrectionTimeout, QStringLiteral( "PAHCorrectionTimeout" ) );

  setCurrentGroup( QStringLiteral( "Guide" ) );

  KConfigCompilerSignallingItem  *itemGuideExposure;
  KConfigSkeleton::ItemDouble  *innerItemGuideExposure;
  innerItemGuideExposure = new KConfigSkeleton::ItemDouble( currentGroup(), QStringLiteral( "GuideExposure" ), mGuideExposure, 2 );
  itemGuideExposure = new KConfigCompilerSignallingItem(innerItemGuideExposure, this, notifyFunction, signalGuideExposureChanged);
  addItem( itemGuideExposure, QStringLiteral( "GuideExposure" ) );
  KConfigCompilerSignallingItem  *itemGuideDelay;
  KConfigSkeleton::ItemDouble  *innerItemGuideDelay;
  innerItemGuideDelay = new KConfigSkeleton::ItemDouble( currentGroup(), QStringLiteral( "GuideDelay" ), mGuideDelay, 0 );
  itemGuideDelay = new KConfigCompilerSignallingItem(innerItemGuideDelay, this, notifyFunction, signalGuideDelayChanged);
  addItem( itemGuideDelay, QStringLiteral( "GuideDelay" ) );
  KConfigCompilerSignallingItem  *itemGuiderType;
  KConfigSkeleton::ItemUInt  *innerItemGuiderType;
  innerItemGuiderType = new KConfigSkeleton::ItemUInt( currentGroup(), QStringLiteral( "GuiderType" ), mGuiderType, 0 );
  itemGuiderType = new KConfigCompilerSignallingItem(innerItemGuiderType, this, notifyFunction, signalGuiderTypeChanged);
  addItem( itemGuiderType, QStringLiteral( "GuiderType" ) );
  KConfigCompilerSignallingItem  *itemGuideAlgorithm;
  KConfigSkeleton::ItemUInt  *innerItemGuideAlgorithm;
  innerItemGuideAlgorithm = new KConfigSkeleton::ItemUInt( currentGroup(), QStringLiteral( "GuideAlgorithm" ), mGuideAlgorithm, 5 );
  itemGuideAlgorithm = new KConfigCompilerSignallingItem(innerItemGuideAlgorithm, this, notifyFunction, signalGuideAlgorithmChanged);
  addItem( itemGuideAlgorithm, QStringLiteral( "GuideAlgorithm" ) );
  KConfigCompilerSignallingItem  *itemRAGuidePulseAlgorithm;
  KConfigSkeleton::ItemUInt  *innerItemRAGuidePulseAlgorithm;
  innerItemRAGuidePulseAlgorithm = new KConfigSkeleton::ItemUInt( currentGroup(), QStringLiteral( "RAGuidePulseAlgorithm" ), mRAGuidePulseAlgorithm, 0 );
  itemRAGuidePulseAlgorithm = new KConfigCompilerSignallingItem(innerItemRAGuidePulseAlgorithm, this, notifyFunction, signalRAGuidePulseAlgorithmChanged);
  addItem( itemRAGuidePulseAlgorithm, QStringLiteral( "RAGuidePulseAlgorithm" ) );
  KConfigCompilerSignallingItem  *itemDECGuidePulseAlgorithm;
  KConfigSkeleton::ItemUInt  *innerItemDECGuidePulseAlgorithm;
  innerItemDECGuidePulseAlgorithm = new KConfigSkeleton::ItemUInt( currentGroup(), QStringLiteral( "DECGuidePulseAlgorithm" ), mDECGuidePulseAlgorithm, 0 );
  itemDECGuidePulseAlgorithm = new KConfigCompilerSignallingItem(innerItemDECGuidePulseAlgorithm, this, notifyFunction, signalDECGuidePulseAlgorithmChanged);
  addItem( itemDECGuidePulseAlgorithm, QStringLiteral( "DECGuidePulseAlgorithm" ) );
  KConfigCompilerSignallingItem  *itemAIGuiderWeightsFile;
  KConfigSkeleton::ItemUrl  *innerItemAIGuiderWeightsFile;
  innerItemAIGuiderWeightsFile = new KConfigSkeleton::ItemUrl( currentGroup(), QStringLiteral( "AIGuiderWeightsFile" ), mAIGuiderWeightsFile );
  itemAIGuiderWeightsFile = new KConfigCompilerSignallingItem(innerItemAIGuiderWeightsFile, this, notifyFunction, signalAIGuiderWeightsFileChanged);
  addItem( itemAIGuiderWeightsFile, QStringLiteral( "AIGuiderWeightsFile" ) );
  KConfigCompilerSignallingItem  *itemAIPredictionGain;
  KConfigSkeleton::ItemDouble  *innerItemAIPredictionGain;
  innerItemAIPredictionGain = new KConfigSkeleton::ItemDouble( currentGroup(), QStringLiteral( "AIPredictionGain" ), mAIPredictionGain, 0.5 );
  itemAIPredictionGain = new KConfigCompilerSignallingItem(innerItemAIPredictionGain, this, notifyFunction, signalAIPredictionGainChanged);
  innerItemAIPredictionGain->setMinValue(0.0);
  innerItemAIPredictionGain->setMaxValue(1.0);
  addItem( itemAIPredictionGain, QStringLiteral( "AIPredictionGain" ) );
  KConfigCompilerSignallingItem  *itemAIProportionalBackoff;
  KConfigSkeleton::ItemBool  *innerItemAIProportionalBackoff;
  innerItemAIProportionalBackoff = new KConfigSkeleton::ItemBool( currentGroup(), QStringLiteral( "AIProportionalBackoff" ), mAIProportionalBackoff, false );
  itemAIProportionalBackoff = new KConfigCompilerSignallingItem(innerItemAIProportionalBackoff, this, notifyFunction, signalAIProportionalBackoffChanged);
  addItem( itemAIProportionalBackoff, QStringLiteral( "AIProportionalBackoff" ) );
  KConfigCompilerSignallingItem  *itemAIPIDAutoTune;
  KConfigSkeleton::ItemBool  *innerItemAIPIDAutoTune;
  innerItemAIPIDAutoTune = new KConfigSkeleton::ItemBool( currentGroup(), QStringLiteral( "AIPIDAutoTune" ), mAIPIDAutoTune, true );
  itemAIPIDAutoTune = new KConfigCompilerSignallingItem(innerItemAIPIDAutoTune, this, notifyFunction, signalAIPIDAutoTuneChanged);
  addItem( itemAIPIDAutoTune, QStringLiteral( "AIPIDAutoTune" ) );
  KConfigCompilerSignallingItem  *itemAIShadowMode;
  KConfigSkeleton::ItemBool  *innerItemAIShadowMode;
  innerItemAIShadowMode = new KConfigSkeleton::ItemBool( currentGroup(), QStringLiteral( "AIShadowMode" ), mAIShadowMode, false );
  itemAIShadowMode = new KConfigCompilerSignallingItem(innerItemAIShadowMode, this, notifyFunction, signalAIShadowModeChanged);
  addItem( itemAIShadowMode, QStringLiteral( "AIShadowMode" ) );
  KConfigCompilerSignallingItem  *itemPHD2Host;
  KConfigSkeleton::ItemString  *innerItemPHD2Host;
  innerItemPHD2Host = new KConfigSkeleton::ItemString( currentGroup(), QStringLiteral( "PHD2Host" ), mPHD2Host, QStringLiteral( "localhost" ) );
  itemPHD2Host = new KConfigCompilerSignallingItem(innerItemPHD2Host, this, notifyFunction, signalPHD2HostChanged);
  addItem( itemPHD2Host, QStringLiteral( "PHD2Host" ) );
  KConfigCompilerSignallingItem  *itemPHD2Port;
  KConfigSkeleton::ItemUInt  *innerItemPHD2Port;
  innerItemPHD2Port = new KConfigSkeleton::ItemUInt( currentGroup(), QStringLiteral( "PHD2Port" ), mPHD2Port, 4400 );
  itemPHD2Port = new KConfigCompilerSignallingItem(innerItemPHD2Port, this, notifyFunction, signalPHD2PortChanged);
  addItem( itemPHD2Port, QStringLiteral( "PHD2Port" ) );
  KConfigCompilerSignallingItem  *itemLinGuiderHost;
  KConfigSkeleton::ItemString  *innerItemLinGuiderHost;
  innerItemLinGuiderHost = new KConfigSkeleton::ItemString( currentGroup(), QStringLiteral( "LinGuiderHost" ), mLinGuiderHost, QStringLiteral( "localhost" ) );
  itemLinGuiderHost = new KConfigCompilerSignallingItem(innerItemLinGuiderHost, this, notifyFunction, signalLinGuiderHostChanged);
  addItem( itemLinGuiderHost, QStringLiteral( "LinGuiderHost" ) );
  KConfigCompilerSignallingItem  *itemLinGuiderPort;
  KConfigSkeleton::ItemUInt  *innerItemLinGuiderPort;
  innerItemLinGuiderPort = new KConfigSkeleton::ItemUInt( currentGroup(), QStringLiteral( "LinGuiderPort" ), mLinGuiderPort, 5656 );
  itemLinGuiderPort = new KConfigCompilerSignallingItem(innerItemLinGuiderPort, this, notifyFunction, signalLinGuiderPortChanged);
  addItem( itemLinGuiderPort, QStringLiteral( "LinGuiderPort" ) );
  KConfigCompilerSignallingItem  *itemCalibrationPulseDuration;
  KConfigSkeleton::ItemUInt  *innerItemCalibrationPulseDuration;
  innerItemCalibrationPulseDuration = new KConfigSkeleton::ItemUInt( currentGroup(), QStringLiteral( "CalibrationPulseDuration" ), mCalibrationPulseDuration, 1000 );
  itemCalibrationPulseDuration = new KConfigCompilerSignallingItem(innerItemCalibrationPulseDuration, this, notifyFunction, signalCalibrationPulseDurationChanged);
  addItem( itemCalibrationPulseDuration, QStringLiteral( "CalibrationPulseDuration" ) );
  KConfigCompilerSignallingItem  *itemCalibrationMaxMove;
  KConfigSkeleton::ItemUInt  *innerItemCalibrationMaxMove;
  innerItemCalibrationMaxMove = new KConfigSkeleton::ItemUInt( currentGroup(), QStringLiteral( "CalibrationMaxMove" ), mCalibrationMaxMove, 15 );
  itemCalibrationMaxMove = new KConfigCompilerSignallingItem(innerItemCalibrationMaxMove, this, notifyFunction, signalCalibrationMaxMoveChanged);
  addItem( itemCalibrationMaxMove, QStringLiteral( "CalibrationMaxMove" ) );
  KConfigCompilerSignallingItem  *itemGuideSquareSize;
  KConfigSkeleton::ItemString  *innerItemGuideSquareSize;
  innerItemGuideSquareSize = new KConfigSkeleton::ItemString( currentGroup(), QStringLiteral( "GuideSquareSize" ), mGuideSquareSize, QStringLiteral( "32" ) );
  itemGuideSquareSize = new KConfigCompilerSignallingItem(innerItemGuideSquareSize, this, notifyFunction, signalGuideSquareSizeChanged);
  addItem( itemGuideSquareSize, QStringLiteral( "GuideSquareSize" ) );
  KConfigCompilerSignallingItem  *itemGuideBinning;
  KConfigSkeleton::ItemString  *innerItemGuideBinning;
  innerItemGuideBinning = new KConfigSkeleton::ItemString( currentGroup(), QStringLiteral( "GuideBinning" ), mGuideBinning, QStringLiteral( "2x2" ) );
  itemGuideBinning = new KConfigCompilerSignallingItem(innerItemGuideBinning, this, notifyFunction, signalGuideBinningChanged);
  addItem( itemGuideBinning, QStringLiteral( "GuideBinning" ) );
  KConfigCompilerSignallingItem  *itemGuideAutoStar;
  KConfigSkeleton::ItemBool  *innerItemGuideAutoStar;
  innerItemGuideAutoStar = new KConfigSkeleton::ItemBool( currentGroup(), QStringLiteral( "GuideAutoStar" ), mGuideAutoStar, false );
  itemGuideAutoStar = new KConfigCompilerSignallingItem(innerItemGuideAutoStar, this, notifyFunction, signalGuideAutoStarChanged);
  addItem( itemGuideAutoStar, QStringLiteral( "GuideAutoStar" ) );
  KConfigCompilerSignallingItem  *itemGuideShowFrame;
  KConfigSkeleton::ItemBool  *innerItemGuideShowFrame;
  innerItemGuideShowFrame = new KConfigSkeleton::ItemBool( currentGroup(), QStringLiteral( "guideShowFrame" ), mGuideShowFrame, true );
  itemGuideShowFrame = new KConfigCompilerSignallingItem(innerItemGuideShowFrame, this, notifyFunction, signalGuideShowFrameChanged);
  addItem( itemGuideShowFrame, QStringLiteral( "guideShowFrame" ) );
  KConfigCompilerSignallingItem  *itemGuideAutoSquareSizeEnabled;
  KConfigSkeleton::ItemBool  *innerItemGuideAutoSquareSizeEnabled;
  innerItemGuideAutoSquareSizeEnabled = new KConfigSkeleton::ItemBool( currentGroup(), QStringLiteral( "GuideAutoSquareSizeEnabled" ), mGuideAutoSquareSizeEnabled, false );
  itemGuideAutoSquareSizeEnabled = new KConfigCompilerSignallingItem(innerItemGuideAutoSquareSizeEnabled, this, notifyFunction, signalGuideAutoSquareSizeEnabledChanged);
  addItem( itemGuideAutoSquareSizeEnabled, QStringLiteral( "GuideAutoSquareSizeEnabled" ) );
  KConfigCompilerSignallingItem  *itemAutoModeIterations;
  KConfigSkeleton::ItemUInt  *innerItemAutoModeIterations;
  innerItemAutoModeIterations = new KConfigSkeleton::ItemUInt( currentGroup(), QStringLiteral( "AutoModeIterations" ), mAutoModeIterations, 3 );
  itemAutoModeIterations = new KConfigCompilerSignallingItem(innerItemAutoModeIterations, this, notifyFunction, signalAutoModeIterationsChanged);
  addItem( itemAutoModeIterations, QStringLiteral( "AutoModeIterations" ) );
  KConfigCompilerSignallingItem  *itemGuideLostStarTimeout;
  KConfigSkeleton::ItemUInt  *innerItemGuideLostStarTimeout;
  innerItemGuideLostStarTimeout = new KConfigSkeleton::ItemUInt( currentGroup(), QStringLiteral( "GuideLostStarTimeout" ), mGuideLostStarTimeout, 60 );
  itemGuideLostStarTimeout = new KConfigCompilerSignallingItem(innerItemGuideLostStarTimeout, this, notifyFunction, signalGuideLostStarTimeoutChanged);
  addItem( itemGuideLostStarTimeout, QStringLiteral( "GuideLostStarTimeout" ) );
  KConfigCompilerSignallingItem  *itemGuideCalibrationTimeout;
  KConfigSkeleton::ItemUInt  *innerItemGuideCalibrationTimeout;
  innerItemGuideCalibrationTimeout = new KConfigSkeleton::ItemUInt( currentGroup(), QStringLiteral( "GuideCalibrationTimeout" ), mGuideCalibrationTimeout, 600 );
  itemGuideCalibrationTimeout = new KConfigCompilerSignallingItem(innerItemGuideCalibrationTimeout, this, notifyFunction, signalGuideCalibrationTimeoutChanged);
  addItem( itemGuideCalibrationTimeout, QStringLiteral( "GuideCalibrationTimeout" ) );
  KConfigCompilerSignallingItem  *itemGuideMaxDeltaRMS;
  KConfigSkeleton::ItemDouble  *innerItemGuideMaxDeltaRMS;
  innerItemGuideMaxDeltaRMS = new KConfigSkeleton::ItemDouble( currentGroup(), QStringLiteral( "GuideMaxDeltaRMS" ), mGuideMaxDeltaRMS, 10 );
  itemGuideMaxDeltaRMS = new KConfigCompilerSignallingItem(innerItemGuideMaxDeltaRMS, this, notifyFunction, signalGuideMaxDeltaRMSChanged);
  addItem( itemGuideMaxDeltaRMS, QStringLiteral( "GuideMaxDeltaRMS" ) );
  KConfigCompilerSignallingItem  *itemGuideMaxHFR;
  KConfigSkeleton::ItemDouble  *innerItemGuideMaxHFR;
  innerItemGuideMaxHFR = new KConfigSkeleton::ItemDouble( currentGroup(), QStringLiteral( "GuideMaxHFR" ), mGuideMaxHFR, 4.5 );
  itemGuideMaxHFR = new KConfigCompilerSignallingItem(innerItemGuideMaxHFR, this, notifyFunction, signalGuideMaxHFRChanged);
  addItem( itemGuideMaxHFR, QStringLiteral( "GuideMaxHFR" ) );
  KConfigCompilerSignallingItem  *itemMinDetectionsSEPMultistar;
  KConfigSkeleton::ItemUInt  *innerItemMinDetectionsSEPMultistar;
  innerItemMinDetectionsSEPMultistar = new KConfigSkeleton::ItemUInt( currentGroup(), QStringLiteral( "MinDetectionsSEPMultistar" ), mMinDetectionsSEPMultistar, 1 );
  itemMinDetectionsSEPMultistar = new KConfigCompilerSignallingItem(innerItemMinDetectionsSEPMultistar, this, notifyFunction, signalMinDetectionsSEPMultistarChanged);
  addItem( itemMinDetectionsSEPMultistar, QStringLiteral( "MinDetectionsSEPMultistar" ) );
  KConfigCompilerSignallingItem  *itemMaxMultistarReferenceStars;
  KConfigSkeleton::ItemUInt  *innerItemMaxMultistarReferenceStars;
  innerItemMaxMultistarReferenceStars = new KConfigSkeleton::ItemUInt( currentGroup(), QStringLiteral( "MaxMultistarReferenceStars" ), mMaxMultistarReferenceStars, 10 );
  itemMaxMultistarReferenceStars = new KConfigCompilerSignallingItem(innerItemMaxMultistarReferenceStars, this, notifyFunction, signalMaxMultistarReferenceStarsChanged);
  addItem( itemMaxMultistarReferenceStars, QStringLiteral( "MaxMultistarReferenceStars" ) );
  KConfigCompilerSignallingItem  *itemAlwaysInventGuideStar;
  KConfigSkeleton::ItemBool  *innerItemAlwaysInventGuideStar;
  innerItemAlwaysInventGuideStar = new KConfigSkeleton::ItemBool( currentGroup(), QStringLiteral( "AlwaysInventGuideStar" ), mAlwaysInventGuideStar, true );
  itemAlwaysInventGuideStar = new KConfigCompilerSignallingItem(innerItemAlwaysInventGuideStar, this, notifyFunction, signalAlwaysInventGuideStarChanged);
  addItem( itemAlwaysInventGuideStar, QStringLiteral( "AlwaysInventGuideStar" ) );
  KConfigCompilerSignallingItem  *itemTwoAxisEnabled;
  KConfigSkeleton::ItemBool  *innerItemTwoAxisEnabled;
  innerItemTwoAxisEnabled = new KConfigSkeleton::ItemBool( currentGroup(), QStringLiteral( "TwoAxisEnabled" ), mTwoAxisEnabled, true );
  itemTwoAxisEnabled = new KConfigCompilerSignallingItem(innerItemTwoAxisEnabled, this, notifyFunction, signalTwoAxisEnabledChanged);
  addItem( itemTwoAxisEnabled, QStringLiteral( "TwoAxisEnabled" ) );
  KConfigCompilerSignallingItem  *itemUseGuideHead;
  KConfigSkeleton::ItemBool  *innerItemUseGuideHead;
  innerItemUseGuideHead = new KConfigSkeleton::ItemBool( currentGroup(), QStringLiteral( "UseGuideHead" ), mUseGuideHead, true );
  itemUseGuideHead = new KConfigCompilerSignallingItem(innerItemUseGuideHead, this, notifyFunction, signalUseGuideHeadChanged);
  addItem( itemUseGuideHead, QStringLiteral( "UseGuideHead" ) );
  KConfigCompilerSignallingItem  *itemSaveGuideLog;
  KConfigSkeleton::ItemBool  *innerItemSaveGuideLog;
  innerItemSaveGuideLog = new KConfigSkeleton::ItemBool( currentGroup(), QStringLiteral( "SaveGuideLog" ), mSaveGuideLog, true );
  itemSaveGuideLog = new KConfigCompilerSignallingItem(innerItemSaveGuideLog, this, notifyFunction, signalSaveGuideLogChanged);
  addItem( itemSaveGuideLog, QStringLiteral( "SaveGuideLog" ) );
  KConfigCompilerSignallingItem  *itemGuideDarkFrame;
  KConfigSkeleton::ItemBool  *innerItemGuideDarkFrame;
  innerItemGuideDarkFrame = new KConfigSkeleton::ItemBool( currentGroup(), QStringLiteral( "GuideDarkFrame" ), mGuideDarkFrame, false );
  itemGuideDarkFrame = new KConfigCompilerSignallingItem(innerItemGuideDarkFrame, this, notifyFunction, signalGuideDarkFrameChanged);
  addItem( itemGuideDarkFrame, QStringLiteral( "GuideDarkFrame" ) );
  KConfigCompilerSignallingItem  *itemGuideSubframe;
  KConfigSkeleton::ItemBool  *innerItemGuideSubframe;
  innerItemGuideSubframe = new KConfigSkeleton::ItemBool( currentGroup(), QStringLiteral( "GuideSubframe" ), mGuideSubframe, false );
  itemGuideSubframe = new KConfigCompilerSignallingItem(innerItemGuideSubframe, this, notifyFunction, signalGuideSubframeChanged);
  addItem( itemGuideSubframe, QStringLiteral( "GuideSubframe" ) );
  KConfigCompilerSignallingItem  *itemDitherPixels;
  KConfigSkeleton::ItemDouble  *innerItemDitherPixels;
  innerItemDitherPixels = new KConfigSkeleton::ItemDouble( currentGroup(), QStringLiteral( "DitherPixels" ), mDitherPixels, 2 );
  itemDitherPixels = new KConfigCompilerSignallingItem(innerItemDitherPixels, this, notifyFunction, signalDitherPixelsChanged);
  addItem( itemDitherPixels, QStringLiteral( "DitherPixels" ) );
  KConfigCompilerSignallingItem  *itemDitherFrames;
  KConfigSkeleton::ItemUInt  *innerItemDitherFrames;
  innerItemDitherFrames = new KConfigSkeleton::ItemUInt( currentGroup(), QStringLiteral( "DitherFrames" ), mDitherFrames, 1 );
  itemDitherFrames = new KConfigCompilerSignallingItem(innerItemDitherFrames, this, notifyFunction, signalDitherFramesChanged);
  addItem( itemDitherFrames, QStringLiteral( "DitherFrames" ) );
  KConfigCompilerSignallingItem  *itemDitherSettle;
  KConfigSkeleton::ItemUInt  *innerItemDitherSettle;
  innerItemDitherSettle = new KConfigSkeleton::ItemUInt( currentGroup(), QStringLiteral( "DitherSettle" ), mDitherSettle, 0 );
  itemDitherSettle = new KConfigCompilerSignallingItem(innerItemDitherSettle, this, notifyFunction, signalDitherSettleChanged);
  addItem( itemDitherSettle, QStringLiteral( "DitherSettle" ) );
  KConfigCompilerSignallingItem  *itemDitherThreshold;
  KConfigSkeleton::ItemDouble  *innerItemDitherThreshold;
  innerItemDitherThreshold = new KConfigSkeleton::ItemDouble( currentGroup(), QStringLiteral( "DitherThreshold" ), mDitherThreshold, 1 );
  itemDitherThreshold = new KConfigCompilerSignallingItem(innerItemDitherThreshold, this, notifyFunction, signalDitherThresholdChanged);
  addItem( itemDitherThreshold, QStringLiteral( "DitherThreshold" ) );
  KConfigCompilerSignallingItem  *itemDitherTimeout;
  KConfigSkeleton::ItemUInt  *innerItemDitherTimeout;
  innerItemDitherTimeout = new KConfigSkeleton::ItemUInt( currentGroup(), QStringLiteral( "DitherTimeout" ), mDitherTimeout, 45 );
  itemDitherTimeout = new KConfigCompilerSignallingItem(innerItemDitherTimeout, this, notifyFunction, signalDitherTimeoutChanged);
  addItem( itemDitherTimeout, QStringLiteral( "DitherTimeout" ) );
  KConfigCompilerSignallingItem  *itemDitherMaxIterations;
  KConfigSkeleton::ItemUInt  *innerItemDitherMaxIterations;
  innerItemDitherMaxIterations = new KConfigSkeleton::ItemUInt( currentGroup(), QStringLiteral( "DitherMaxIterations" ), mDitherMaxIterations, 10 );
  itemDitherMaxIterations = new KConfigCompilerSignallingItem(innerItemDitherMaxIterations, this, notifyFunction, signalDitherMaxIterationsChanged);
  addItem( itemDitherMaxIterations, QStringLiteral( "DitherMaxIterations" ) );
  KConfigCompilerSignallingItem  *itemDitherNoGuidingPulse;
  KConfigSkeleton::ItemUInt  *innerItemDitherNoGuidingPulse;
  innerItemDitherNoGuidingPulse = new KConfigSkeleton::ItemUInt( currentGroup(), QStringLiteral( "DitherNoGuidingPulse" ), mDitherNoGuidingPulse, 500 );
  itemDitherNoGuidingPulse = new KConfigCompilerSignallingItem(innerItemDitherNoGuidingPulse, this, notifyFunction, signalDitherNoGuidingPulseChanged);
  addItem( itemDitherNoGuidingPulse, QStringLiteral( "DitherNoGuidingPulse" ) );
  KConfigCompilerSignallingItem  *itemDitherFailAbortsAutoGuide;
  KConfigSkeleton::ItemBool  *innerItemDitherFailAbortsAutoGuide;
  innerItemDitherFailAbortsAutoGuide = new KConfigSkeleton::ItemBool( currentGroup(), QStringLiteral( "DitherFailAbortsAutoGuide" ), mDitherFailAbortsAutoGuide, false );
  itemDitherFailAbortsAutoGuide = new KConfigCompilerSignallingItem(innerItemDitherFailAbortsAutoGuide, this, notifyFunction, signalDitherFailAbortsAutoGuideChanged);
  addItem( itemDitherFailAbortsAutoGuide, QStringLiteral( "DitherFailAbortsAutoGuide" ) );
  KConfigCompilerSignallingItem  *itemDitherWithOnePulse;
  KConfigSkeleton::ItemBool  *innerItemDitherWithOnePulse;
  innerItemDitherWithOnePulse = new KConfigSkeleton::ItemBool( currentGroup(), QStringLiteral( "DitherWithOnePulse" ), mDitherWithOnePulse, false );
  itemDitherWithOnePulse = new KConfigCompilerSignallingItem(innerItemDitherWithOnePulse, this, notifyFunction, signalDitherWithOnePulseChanged);
  addItem( itemDitherWithOnePulse, QStringLiteral( "DitherWithOnePulse" ) );
  KConfigCompilerSignallingItem  *itemDitherEnabled;
  KConfigSkeleton::ItemBool  *innerItemDitherEnabled;
  innerItemDitherEnabled = new KConfigSkeleton::ItemBool( currentGroup(), QStringLiteral( "DitherEnabled" ), mDitherEnabled, false );
  itemDitherEnabled = new KConfigCompilerSignallingItem(innerItemDitherEnabled, this, notifyFunction, signalDitherEnabledChanged);
  addItem( itemDitherEnabled, QStringLiteral( "DitherEnabled" ) );
  KConfigCompilerSignallingItem  *itemDitherNoGuiding;
  KConfigSkeleton::ItemBool  *innerItemDitherNoGuiding;
  innerItemDitherNoGuiding = new KConfigSkeleton::ItemBool( currentGroup(), QStringLiteral( "DitherNoGuiding" ), mDitherNoGuiding, false );
  itemDitherNoGuiding = new KConfigCompilerSignallingItem(innerItemDitherNoGuiding, this, notifyFunction, signalDitherNoGuidingChanged);
  addItem( itemDitherNoGuiding, QStringLiteral( "DitherNoGuiding" ) );
  KConfigCompilerSignallingItem  *itemRAGuideEnabled;
  KConfigSkeleton::ItemBool  *innerItemRAGuideEnabled;
  innerItemRAGuideEnabled = new KConfigSkeleton::ItemBool( currentGroup(), QStringLiteral( "RAGuideEnabled" ), mRAGuideEnabled, true );
  itemRAGuideEnabled = new KConfigCompilerSignallingItem(innerItemRAGuideEnabled, this, notifyFunction, signalRAGuideEnabledChanged);
  addItem( itemRAGuideEnabled, QStringLiteral( "RAGuideEnabled" ) );
  KConfigCompilerSignallingItem  *itemDECGuideEnabled;
  KConfigSkeleton::ItemBool  *innerItemDECGuideEnabled;
  innerItemDECGuideEnabled = new KConfigSkeleton::ItemBool( currentGroup(), QStringLiteral( "DECGuideEnabled" ), mDECGuideEnabled, true );
  itemDECGuideEnabled = new KConfigCompilerSignallingItem(innerItemDECGuideEnabled, this, notifyFunction, signalDECGuideEnabledChanged);
  addItem( itemDECGuideEnabled, QStringLiteral( "DECGuideEnabled" ) );
  KConfigCompilerSignallingItem  *itemNorthDECGuideEnabled;
  KConfigSkeleton::ItemBool  *innerItemNorthDECGuideEnabled;
  innerItemNorthDECGuideEnabled = new KConfigSkeleton::ItemBool( currentGroup(), QStringLiteral( "NorthDECGuideEnabled" ), mNorthDECGuideEnabled, true );
  itemNorthDECGuideEnabled = new KConfigCompilerSignallingItem(innerItemNorthDECGuideEnabled, this, notifyFunction, signalNorthDECGuideEnabledChanged);
  addItem( itemNorthDECGuideEnabled, QStringLiteral( "NorthDECGuideEnabled" ) );
  KConfigCompilerSignallingItem  *itemSouthDECGuideEnabled;
  KConfigSkeleton::ItemBool  *innerItemSouthDECGuideEnabled;
  innerItemSouthDECGuideEnabled = new KConfigSkeleton::ItemBool( currentGroup(), QStringLiteral( "SouthDECGuideEnabled" ), mSouthDECGuideEnabled, true );
  itemSouthDECGuideEnabled = new KConfigCompilerSignallingItem(innerItemSouthDECGuideEnabled, this, notifyFunction, signalSouthDECGuideEnabledChanged);
  addItem( itemSouthDECGuideEnabled, QStringLiteral( "SouthDECGuideEnabled" ) );
  KConfigCompilerSignallingItem  *itemEastRAGuideEnabled;
  KConfigSkeleton::ItemBool  *innerItemEastRAGuideEnabled;
  innerItemEastRAGuideEnabled = new KConfigSkeleton::ItemBool( currentGroup(), QStringLiteral( "EastRAGuideEnabled" ), mEastRAGuideEnabled, true );
  itemEastRAGuideEnabled = new KConfigCompilerSignallingItem(innerItemEastRAGuideEnabled, this, notifyFunction, signalEastRAGuideEnabledChanged);
  addItem( itemEastRAGuideEnabled, QStringLiteral( "EastRAGuideEnabled" ) );
  KConfigCompilerSignallingItem  *itemWestRAGuideEnabled;
  KConfigSkeleton::ItemBool  *innerItemWestRAGuideEnabled;
  innerItemWestRAGuideEnabled = new KConfigSkeleton::ItemBool( currentGroup(), QStringLiteral( "WestRAGuideEnabled" ), mWestRAGuideEnabled, true );
  itemWestRAGuideEnabled = new KConfigCompilerSignallingItem(innerItemWestRAGuideEnabled, this, notifyFunction, signalWestRAGuideEnabledChanged);
  addItem( itemWestRAGuideEnabled, QStringLiteral( "WestRAGuideEnabled" ) );
  KConfigCompilerSignallingItem  *itemRAProportionalGain;
  KConfigSkeleton::ItemDouble  *innerItemRAProportionalGain;
  innerItemRAProportionalGain = new KConfigSkeleton::ItemDouble( currentGroup(), QStringLiteral( "RAProportionalGain" ), mRAProportionalGain, 0.75 );
  itemRAProportionalGain = new KConfigCompilerSignallingItem(innerItemRAProportionalGain, this, notifyFunction, signalRAProportionalGainChanged);
  addItem( itemRAProportionalGain, QStringLiteral( "RAProportionalGain" ) );
  KConfigCompilerSignallingItem  *itemDECProportionalGain;
  KConfigSkeleton::ItemDouble  *innerItemDECProportionalGain;
  innerItemDECProportionalGain = new KConfigSkeleton::ItemDouble( currentGroup(), QStringLiteral( "DECProportionalGain" ), mDECProportionalGain, 0.75 );
  itemDECProportionalGain = new KConfigCompilerSignallingItem(innerItemDECProportionalGain, this, notifyFunction, signalDECProportionalGainChanged);
  addItem( itemDECProportionalGain, QStringLiteral( "DECProportionalGain" ) );
  KConfigCompilerSignallingItem  *itemRAIntegralGain;
  KConfigSkeleton::ItemDouble  *innerItemRAIntegralGain;
  innerItemRAIntegralGain = new KConfigSkeleton::ItemDouble( currentGroup(), QStringLiteral( "RAIntegralGain" ), mRAIntegralGain, 0 );
  itemRAIntegralGain = new KConfigCompilerSignallingItem(innerItemRAIntegralGain, this, notifyFunction, signalRAIntegralGainChanged);
  addItem( itemRAIntegralGain, QStringLiteral( "RAIntegralGain" ) );
  KConfigCompilerSignallingItem  *itemDECIntegralGain;
  KConfigSkeleton::ItemDouble  *innerItemDECIntegralGain;
  innerItemDECIntegralGain = new KConfigSkeleton::ItemDouble( currentGroup(), QStringLiteral( "DECIntegralGain" ), mDECIntegralGain, 0 );
  itemDECIntegralGain = new KConfigCompilerSignallingItem(innerItemDECIntegralGain, this, notifyFunction, signalDECIntegralGainChanged);
  addItem( itemDECIntegralGain, QStringLiteral( "DECIntegralGain" ) );
  KConfigCompilerSignallingItem  *itemRAMinimumPulseArcSec;
  KConfigSkeleton::ItemDouble  *innerItemRAMinimumPulseArcSec;
  innerItemRAMinimumPulseArcSec = new KConfigSkeleton::ItemDouble( currentGroup(), QStringLiteral( "RAMinimumPulseArcSec" ), mRAMinimumPulseArcSec, 0.2 );
  itemRAMinimumPulseArcSec = new KConfigCompilerSignallingItem(innerItemRAMinimumPulseArcSec, this, notifyFunction, signalRAMinimumPulseArcSecChanged);
  addItem( itemRAMinimumPulseArcSec, QStringLiteral( "RAMinimumPulseArcSec" ) );
  KConfigCompilerSignallingItem  *itemDECMinimumPulseArcSec;
  KConfigSkeleton::ItemDouble  *innerItemDECMinimumPulseArcSec;
  innerItemDECMinimumPulseArcSec = new KConfigSkeleton::ItemDouble( currentGroup(), QStringLiteral( "DECMinimumPulseArcSec" ), mDECMinimumPulseArcSec, 0.2 );
  itemDECMinimumPulseArcSec = new KConfigCompilerSignallingItem(innerItemDECMinimumPulseArcSec, this, notifyFunction, signalDECMinimumPulseArcSecChanged);
  addItem( itemDECMinimumPulseArcSec, QStringLiteral( "DECMinimumPulseArcSec" ) );
  KConfigCompilerSignallingItem  *itemRAMaximumPulseArcSec;
  KConfigSkeleton::ItemUInt  *innerItemRAMaximumPulseArcSec;
  innerItemRAMaximumPulseArcSec = new KConfigSkeleton::ItemUInt( currentGroup(), QStringLiteral( "RAMaximumPulseArcSec" ), mRAMaximumPulseArcSec, 25 );
  itemRAMaximumPulseArcSec = new KConfigCompilerSignallingItem(innerItemRAMaximumPulseArcSec, this, notifyFunction, signalRAMaximumPulseArcSecChanged);
  addItem( itemRAMaximumPulseArcSec, QStringLiteral( "RAMaximumPulseArcSec" ) );
  KConfigCompilerSignallingItem  *itemDECMaximumPulseArcSec;
  KConfigSkeleton::ItemUInt  *innerItemDECMaximumPulseArcSec;
  innerItemDECMaximumPulseArcSec = new KConfigSkeleton::ItemUInt( currentGroup(), QStringLiteral( "DECMaximumPulseArcSec" ), mDECMaximumPulseArcSec, 25 );
  itemDECMaximumPulseArcSec = new KConfigCompilerSignallingItem(innerItemDECMaximumPulseArcSec, this, notifyFunction, signalDECMaximumPulseArcSecChanged);
  addItem( itemDECMaximumPulseArcSec, QStringLiteral( "DECMaximumPulseArcSec" ) );
  KConfigCompilerSignallingItem  *itemGPGEnabled;
  KConfigSkeleton::ItemBool  *innerItemGPGEnabled;
  innerItemGPGEnabled = new KConfigSkeleton::ItemBool( currentGroup(), QStringLiteral( "GPGEnabled" ), mGPGEnabled, false );
  itemGPGEnabled = new KConfigCompilerSignallingItem(innerItemGPGEnabled, this, notifyFunction, signalGPGEnabledChanged);
  addItem( itemGPGEnabled, QStringLiteral( "GPGEnabled" ) );
  KConfigCompilerSignallingItem  *itemGPGDarkGuiding;
  KConfigSkeleton::ItemBool  *innerItemGPGDarkGuiding;
  innerItemGPGDarkGuiding = new KConfigSkeleton::ItemBool( currentGroup(), QStringLiteral( "GPGDarkGuiding" ), mGPGDarkGuiding, false );
  itemGPGDarkGuiding = new KConfigCompilerSignallingItem(innerItemGPGDarkGuiding, this, notifyFunction, signalGPGDarkGuidingChanged);
  addItem( itemGPGDarkGuiding, QStringLiteral( "GPGDarkGuiding" ) );
  KConfigCompilerSignallingItem  *itemGPGDarkGuidingInterval;
  KConfigSkeleton::ItemDouble  *innerItemGPGDarkGuidingInterval;
  innerItemGPGDarkGuidingInterval = new KConfigSkeleton::ItemDouble( currentGroup(), QStringLiteral( "GPGDarkGuidingInterval" ), mGPGDarkGuidingInterval, 1 );
  itemGPGDarkGuidingInterval = new KConfigCompilerSignallingItem(innerItemGPGDarkGuidingInterval, this, notifyFunction, signalGPGDarkGuidingIntervalChanged);
  addItem( itemGPGDarkGuidingInterval, QStringLiteral( "GPGDarkGuidingInterval" ) );
  KConfigCompilerSignallingItem  *itemAIDarkGuiding;
  KConfigSkeleton::ItemBool  *innerItemAIDarkGuiding;
  innerItemAIDarkGuiding = new KConfigSkeleton::ItemBool( currentGroup(), QStringLiteral( "AIDarkGuiding" ), mAIDarkGuiding, false );
  itemAIDarkGuiding = new KConfigCompilerSignallingItem(innerItemAIDarkGuiding, this, notifyFunction, signalAIDarkGuidingChanged);
  addItem( itemAIDarkGuiding, QStringLiteral( "AIDarkGuiding" ) );
  KConfigCompilerSignallingItem  *itemAIDarkGuidingInterval;
  KConfigSkeleton::ItemDouble  *innerItemAIDarkGuidingInterval;
  innerItemAIDarkGuidingInterval = new KConfigSkeleton::ItemDouble( currentGroup(), QStringLiteral( "AIDarkGuidingInterval" ), mAIDarkGuidingInterval, 1.0 );
  itemAIDarkGuidingInterval = new KConfigCompilerSignallingItem(innerItemAIDarkGuidingInterval, this, notifyFunction, signalAIDarkGuidingIntervalChanged);
  addItem( itemAIDarkGuidingInterval, QStringLiteral( "AIDarkGuidingInterval" ) );
  KConfigCompilerSignallingItem  *itemGPGcWeight;
  KConfigSkeleton::ItemDouble  *innerItemGPGcWeight;
  innerItemGPGcWeight = new KConfigSkeleton::ItemDouble( currentGroup(), QStringLiteral( "GPGcWeight" ), mGPGcWeight, 0.6 );
  itemGPGcWeight = new KConfigCompilerSignallingItem(innerItemGPGcWeight, this, notifyFunction, signalGPGcWeightChanged);
  addItem( itemGPGcWeight, QStringLiteral( "GPGcWeight" ) );
  KConfigCompilerSignallingItem  *itemGPGMinPeriodsForInference;
  KConfigSkeleton::ItemUInt  *innerItemGPGMinPeriodsForInference;
  innerItemGPGMinPeriodsForInference = new KConfigSkeleton::ItemUInt( currentGroup(), QStringLiteral( "GPGMinPeriodsForInference" ), mGPGMinPeriodsForInference, 2 );
  itemGPGMinPeriodsForInference = new KConfigCompilerSignallingItem(innerItemGPGMinPeriodsForInference, this, notifyFunction, signalGPGMinPeriodsForInferenceChanged);
  addItem( itemGPGMinPeriodsForInference, QStringLiteral( "GPGMinPeriodsForInference" ) );
  KConfigCompilerSignallingItem  *itemGPGMinMove;
  KConfigSkeleton::ItemDouble  *innerItemGPGMinMove;
  innerItemGPGMinMove = new KConfigSkeleton::ItemDouble( currentGroup(), QStringLiteral( "GPGMinMove" ), mGPGMinMove, 0.2 );
  itemGPGMinMove = new KConfigCompilerSignallingItem(innerItemGPGMinMove, this, notifyFunction, signalGPGMinMoveChanged);
  addItem( itemGPGMinMove, QStringLiteral( "GPGMinMove" ) );
  KConfigCompilerSignallingItem  *itemGPGSE0KLengthScale;
  KConfigSkeleton::ItemUInt  *innerItemGPGSE0KLengthScale;
  innerItemGPGSE0KLengthScale = new KConfigSkeleton::ItemUInt( currentGroup(), QStringLiteral( "GPGSE0KLengthScale" ), mGPGSE0KLengthScale, 700 );
  itemGPGSE0KLengthScale = new KConfigCompilerSignallingItem(innerItemGPGSE0KLengthScale, this, notifyFunction, signalGPGSE0KLengthScaleChanged);
  addItem( itemGPGSE0KLengthScale, QStringLiteral( "GPGSE0KLengthScale" ) );
  KConfigCompilerSignallingItem  *itemGPGSE0KSignalVariance;
  KConfigSkeleton::ItemDouble  *innerItemGPGSE0KSignalVariance;
  innerItemGPGSE0KSignalVariance = new KConfigSkeleton::ItemDouble( currentGroup(), QStringLiteral( "GPGSE0KSignalVariance" ), mGPGSE0KSignalVariance, 20.0 );
  itemGPGSE0KSignalVariance = new KConfigCompilerSignallingItem(innerItemGPGSE0KSignalVariance, this, notifyFunction, signalGPGSE0KSignalVarianceChanged);
  addItem( itemGPGSE0KSignalVariance, QStringLiteral( "GPGSE0KSignalVariance" ) );
  KConfigCompilerSignallingItem  *itemGPGPKLengthScale;
  KConfigSkeleton::ItemDouble  *innerItemGPGPKLengthScale;
  innerItemGPGPKLengthScale = new KConfigSkeleton::ItemDouble( currentGroup(), QStringLiteral( "GPGPKLengthScale" ), mGPGPKLengthScale, 10.0 );
  itemGPGPKLengthScale = new KConfigCompilerSignallingItem(innerItemGPGPKLengthScale, this, notifyFunction, signalGPGPKLengthScaleChanged);
  addItem( itemGPGPKLengthScale, QStringLiteral( "GPGPKLengthScale" ) );
  KConfigCompilerSignallingItem  *itemGPGPeriod;
  KConfigSkeleton::ItemDouble  *innerItemGPGPeriod;
  innerItemGPGPeriod = new KConfigSkeleton::ItemDouble( currentGroup(), QStringLiteral( "GPGPeriod" ), mGPGPeriod, 480 );
  itemGPGPeriod = new KConfigCompilerSignallingItem(innerItemGPGPeriod, this, notifyFunction, signalGPGPeriodChanged);
  addItem( itemGPGPeriod, QStringLiteral( "GPGPeriod" ) );
  KConfigCompilerSignallingItem  *itemGPGPKSignalVariance;
  KConfigSkeleton::ItemDouble  *innerItemGPGPKSignalVariance;
  innerItemGPGPKSignalVariance = new KConfigSkeleton::ItemDouble( currentGroup(), QStringLiteral( "GPGPKSignalVariance" ), mGPGPKSignalVariance, 20.0 );
  itemGPGPKSignalVariance = new KConfigCompilerSignallingItem(innerItemGPGPKSignalVariance, this, notifyFunction, signalGPGPKSignalVarianceChanged);
  addItem( itemGPGPKSignalVariance, QStringLiteral( "GPGPKSignalVariance" ) );
  KConfigCompilerSignallingItem  *itemGPGSE1KLengthScale;
  KConfigSkeleton::ItemDouble  *innerItemGPGSE1KLengthScale;
  innerItemGPGSE1KLengthScale = new KConfigSkeleton::ItemDouble( currentGroup(), QStringLiteral( "GPGSE1KLengthScale" ), mGPGSE1KLengthScale, 25.0 );
  itemGPGSE1KLengthScale = new KConfigCompilerSignallingItem(innerItemGPGSE1KLengthScale, this, notifyFunction, signalGPGSE1KLengthScaleChanged);
  addItem( itemGPGSE1KLengthScale, QStringLiteral( "GPGSE1KLengthScale" ) );
  KConfigCompilerSignallingItem  *itemGPGSE1KSignalVariance;
  KConfigSkeleton::ItemDouble  *innerItemGPGSE1KSignalVariance;
  innerItemGPGSE1KSignalVariance = new KConfigSkeleton::ItemDouble( currentGroup(), QStringLiteral( "GPGSE1KSignalVariance" ), mGPGSE1KSignalVariance, 10.0 );
  itemGPGSE1KSignalVariance = new KConfigCompilerSignallingItem(innerItemGPGSE1KSignalVariance, this, notifyFunction, signalGPGSE1KSignalVarianceChanged);
  addItem( itemGPGSE1KSignalVariance, QStringLiteral( "GPGSE1KSignalVariance" ) );
  KConfigCompilerSignallingItem  *itemGPGMinPeriodsForPeriodEstimate;
  KConfigSkeleton::ItemUInt  *innerItemGPGMinPeriodsForPeriodEstimate;
  innerItemGPGMinPeriodsForPeriodEstimate = new KConfigSkeleton::ItemUInt( currentGroup(), QStringLiteral( "GPGMinPeriodsForPeriodEstimate" ), mGPGMinPeriodsForPeriodEstimate, 2 );
  itemGPGMinPeriodsForPeriodEstimate = new KConfigCompilerSignallingItem(innerItemGPGMinPeriodsForPeriodEstimate, this, notifyFunction, signalGPGMinPeriodsForPeriodEstimateChanged);
  addItem( itemGPGMinPeriodsForPeriodEstimate, QStringLiteral( "GPGMinPeriodsForPeriodEstimate" ) );
  KConfigCompilerSignallingItem  *itemGPGPointsForApproximation;
  KConfigSkeleton::ItemUInt  *innerItemGPGPointsForApproximation;
  innerItemGPGPointsForApproximation = new KConfigSkeleton::ItemUInt( currentGroup(), QStringLiteral( "GPGPointsForApproximation" ), mGPGPointsForApproximation, 100 );
  itemGPGPointsForApproximation = new KConfigCompilerSignallingItem(innerItemGPGPointsForApproximation, this, notifyFunction, signalGPGPointsForApproximationChanged);
  addItem( itemGPGPointsForApproximation, QStringLiteral( "GPGPointsForApproximation" ) );
  KConfigCompilerSignallingItem  *itemGPGpWeight;
  KConfigSkeleton::ItemDouble  *innerItemGPGpWeight;
  innerItemGPGpWeight = new KConfigSkeleton::ItemDouble( currentGroup(), QStringLiteral( "GPGpWeight" ), mGPGpWeight, 0.5 );
  itemGPGpWeight = new KConfigCompilerSignallingItem(innerItemGPGpWeight, this, notifyFunction, signalGPGpWeightChanged);
  addItem( itemGPGpWeight, QStringLiteral( "GPGpWeight" ) );
  KConfigCompilerSignallingItem  *itemGPGEstimatePeriod;
  KConfigSkeleton::ItemBool  *innerItemGPGEstimatePeriod;
  innerItemGPGEstimatePeriod = new KConfigSkeleton::ItemBool( currentGroup(), QStringLiteral( "GPGEstimatePeriod" ), mGPGEstimatePeriod, true );
  itemGPGEstimatePeriod = new KConfigCompilerSignallingItem(innerItemGPGEstimatePeriod, this, notifyFunction, signalGPGEstimatePeriodChanged);
  addItem( itemGPGEstimatePeriod, QStringLiteral( "GPGEstimatePeriod" ) );
  KConfigCompilerSignallingItem  *itemGuiderAccuracyThreshold;
  KConfigSkeleton::ItemUInt  *innerItemGuiderAccuracyThreshold;
  innerItemGuiderAccuracyThreshold = new KConfigSkeleton::ItemUInt( currentGroup(), QStringLiteral( "GuiderAccuracyThreshold" ), mGuiderAccuracyThreshold, 2 );
  itemGuiderAccuracyThreshold = new KConfigCompilerSignallingItem(innerItemGuiderAccuracyThreshold, this, notifyFunction, signalGuiderAccuracyThresholdChanged);
  addItem( itemGuiderAccuracyThreshold, QStringLiteral( "GuiderAccuracyThreshold" ) );
  KConfigCompilerSignallingItem  *itemRADisplayedOnGuideGraph;
  KConfigSkeleton::ItemBool  *innerItemRADisplayedOnGuideGraph;
  innerItemRADisplayedOnGuideGraph = new KConfigSkeleton::ItemBool( currentGroup(), QStringLiteral( "RADisplayedOnGuideGraph" ), mRADisplayedOnGuideGraph, true );
  itemRADisplayedOnGuideGraph = new KConfigCompilerSignallingItem(innerItemRADisplayedOnGuideGraph, this, notifyFunction, signalRADisplayedOnGuideGraphChanged);
  addItem( itemRADisplayedOnGuideGraph, QStringLiteral( "RADisplayedOnGuideGraph" ) );
  KConfigCompilerSignallingItem  *itemDEDisplayedOnGuideGraph;
  KConfigSkeleton::ItemBool  *innerItemDEDisplayedOnGuideGraph;
  innerItemDEDisplayedOnGuideGraph = new KConfigSkeleton::ItemBool( currentGroup(), QStringLiteral( "DEDisplayedOnGuideGraph" ), mDEDisplayedOnGuideGraph, true );
  itemDEDisplayedOnGuideGraph = new KConfigCompilerSignallingItem(innerItemDEDisplayedOnGuideGraph, this, notifyFunction, signalDEDisplayedOnGuideGraphChanged);
  addItem( itemDEDisplayedOnGuideGraph, QStringLiteral( "DEDisplayedOnGuideGraph" ) );
  KConfigCompilerSignallingItem  *itemRACorrDisplayedOnGuideGraph;
  KConfigSkeleton::ItemBool  *innerItemRACorrDisplayedOnGuideGraph;
  innerItemRACorrDisplayedOnGuideGraph = new KConfigSkeleton::ItemBool( currentGroup(), QStringLiteral( "RACorrDisplayedOnGuideGraph" ), mRACorrDisplayedOnGuideGraph, false );
  itemRACorrDisplayedOnGuideGraph = new KConfigCompilerSignallingItem(innerItemRACorrDisplayedOnGuideGraph, this, notifyFunction, signalRACorrDisplayedOnGuideGraphChanged);
  addItem( itemRACorrDisplayedOnGuideGraph, QStringLiteral( "RACorrDisplayedOnGuideGraph" ) );
  KConfigCompilerSignallingItem  *itemDECorrDisplayedOnGuideGraph;
  KConfigSkeleton::ItemBool  *innerItemDECorrDisplayedOnGuideGraph;
  innerItemDECorrDisplayedOnGuideGraph = new KConfigSkeleton::ItemBool( currentGroup(), QStringLiteral( "DECorrDisplayedOnGuideGraph" ), mDECorrDisplayedOnGuideGraph, false );
  itemDECorrDisplayedOnGuideGraph = new KConfigCompilerSignallingItem(innerItemDECorrDisplayedOnGuideGraph, this, notifyFunction, signalDECorrDisplayedOnGuideGraphChanged);
  addItem( itemDECorrDisplayedOnGuideGraph, QStringLiteral( "DECorrDisplayedOnGuideGraph" ) );
  KConfigCompilerSignallingItem  *itemSNRDisplayedOnGuideGraph;
  KConfigSkeleton::ItemBool  *innerItemSNRDisplayedOnGuideGraph;
  innerItemSNRDisplayedOnGuideGraph = new KConfigSkeleton::ItemBool( currentGroup(), QStringLiteral( "SNRDisplayedOnGuideGraph" ), mSNRDisplayedOnGuideGraph, true );
  itemSNRDisplayedOnGuideGraph = new KConfigCompilerSignallingItem(innerItemSNRDisplayedOnGuideGraph, this, notifyFunction, signalSNRDisplayedOnGuideGraphChanged);
  addItem( itemSNRDisplayedOnGuideGraph, QStringLiteral( "SNRDisplayedOnGuideGraph" ) );
  KConfigCompilerSignallingItem  *itemRMSDisplayedOnGuideGraph;
  KConfigSkeleton::ItemBool  *innerItemRMSDisplayedOnGuideGraph;
  innerItemRMSDisplayedOnGuideGraph = new KConfigSkeleton::ItemBool( currentGroup(), QStringLiteral( "RMSDisplayedOnGuideGraph" ), mRMSDisplayedOnGuideGraph, true );
  itemRMSDisplayedOnGuideGraph = new KConfigCompilerSignallingItem(innerItemRMSDisplayedOnGuideGraph, this, notifyFunction, signalRMSDisplayedOnGuideGraphChanged);
  addItem( itemRMSDisplayedOnGuideGraph, QStringLiteral( "RMSDisplayedOnGuideGraph" ) );
  KConfigCompilerSignallingItem  *itemRAHysteresis;
  KConfigSkeleton::ItemDouble  *innerItemRAHysteresis;
  innerItemRAHysteresis = new KConfigSkeleton::ItemDouble( currentGroup(), QStringLiteral( "RAHysteresis" ), mRAHysteresis, 0 );
  itemRAHysteresis = new KConfigCompilerSignallingItem(innerItemRAHysteresis, this, notifyFunction, signalRAHysteresisChanged);
  addItem( itemRAHysteresis, QStringLiteral( "RAHysteresis" ) );
  KConfigCompilerSignallingItem  *itemDECHysteresis;
  KConfigSkeleton::ItemDouble  *innerItemDECHysteresis;
  innerItemDECHysteresis = new KConfigSkeleton::ItemDouble( currentGroup(), QStringLiteral( "DECHysteresis" ), mDECHysteresis, 0 );
  itemDECHysteresis = new KConfigCompilerSignallingItem(innerItemDECHysteresis, this, notifyFunction, signalDECHysteresisChanged);
  addItem( itemDECHysteresis, QStringLiteral( "DECHysteresis" ) );

  setCurrentGroup( QStringLiteral( "Scheduler" ) );

  KConfigCompilerSignallingItem  *itemSchedulerAlgorithm;
  KConfigSkeleton::ItemUInt  *innerItemSchedulerAlgorithm;
  innerItemSchedulerAlgorithm = new KConfigSkeleton::ItemUInt( currentGroup(), QStringLiteral( "SchedulerAlgorithm" ), mSchedulerAlgorithm, 1 );
  itemSchedulerAlgorithm = new KConfigCompilerSignallingItem(innerItemSchedulerAlgorithm, this, notifyFunction, signalSchedulerAlgorithmChanged);
  addItem( itemSchedulerAlgorithm, QStringLiteral( "SchedulerAlgorithm" ) );
  KConfigCompilerSignallingItem  *itemSchedulerLogging;
  KConfigSkeleton::ItemBool  *innerItemSchedulerLogging;
  innerItemSchedulerLogging = new KConfigSkeleton::ItemBool( currentGroup(), QStringLiteral( "SchedulerLogging" ), mSchedulerLogging, false );
  itemSchedulerLogging = new KConfigCompilerSignallingItem(innerItemSchedulerLogging, this, notifyFunction, signalSchedulerLoggingChanged);
  addItem( itemSchedulerLogging, QStringLiteral( "SchedulerLogging" ) );
  KConfigCompilerSignallingItem  *itemStopEkosAfterShutdown;
  KConfigSkeleton::ItemBool  *innerItemStopEkosAfterShutdown;
  innerItemStopEkosAfterShutdown = new KConfigSkeleton::ItemBool( currentGroup(), QStringLiteral( "StopEkosAfterShutdown" ), mStopEkosAfterShutdown, true );
  itemStopEkosAfterShutdown = new KConfigCompilerSignallingItem(innerItemStopEkosAfterShutdown, this, notifyFunction, signalStopEkosAfterShutdownChanged);
  addItem( itemStopEkosAfterShutdown, QStringLiteral( "StopEkosAfterShutdown" ) );
  KConfigCompilerSignallingItem  *itemShutdownScriptTerminatesINDI;
  KConfigSkeleton::ItemBool  *innerItemShutdownScriptTerminatesINDI;
  innerItemShutdownScriptTerminatesINDI = new KConfigSkeleton::ItemBool( currentGroup(), QStringLiteral( "ShutdownScriptTerminatesINDI" ), mShutdownScriptTerminatesINDI, false );
  itemShutdownScriptTerminatesINDI = new KConfigCompilerSignallingItem(innerItemShutdownScriptTerminatesINDI, this, notifyFunction, signalShutdownScriptTerminatesINDIChanged);
  addItem( itemShutdownScriptTerminatesINDI, QStringLiteral( "ShutdownScriptTerminatesINDI" ) );
  KConfigCompilerSignallingItem  *itemCameraWarmupEnabled;
  KConfigSkeleton::ItemBool  *innerItemCameraWarmupEnabled;
  innerItemCameraWarmupEnabled = new KConfigSkeleton::ItemBool( currentGroup(), QStringLiteral( "CameraWarmupEnabled" ), mCameraWarmupEnabled, false );
  itemCameraWarmupEnabled = new KConfigCompilerSignallingItem(innerItemCameraWarmupEnabled, this, notifyFunction, signalCameraWarmupEnabledChanged);
  addItem( itemCameraWarmupEnabled, QStringLiteral( "CameraWarmupEnabled" ) );
  KConfigCompilerSignallingItem  *itemCameraWarmupRamp;
  KConfigSkeleton::ItemUInt  *innerItemCameraWarmupRamp;
  innerItemCameraWarmupRamp = new KConfigSkeleton::ItemUInt( currentGroup(), QStringLiteral( "CameraWarmupRamp" ), mCameraWarmupRamp, 5 );
  itemCameraWarmupRamp = new KConfigCompilerSignallingItem(innerItemCameraWarmupRamp, this, notifyFunction, signalCameraWarmupRampChanged);
  innerItemCameraWarmupRamp->setMinValue(1);
  innerItemCameraWarmupRamp->setMaxValue(30);
  addItem( itemCameraWarmupRamp, QStringLiteral( "CameraWarmupRamp" ) );
  KConfigCompilerSignallingItem  *itemPreemptiveShutdown;
  KConfigSkeleton::ItemBool  *innerItemPreemptiveShutdown;
  innerItemPreemptiveShutdown = new KConfigSkeleton::ItemBool( currentGroup(), QStringLiteral( "PreemptiveShutdown" ), mPreemptiveShutdown, true );
  itemPreemptiveShutdown = new KConfigCompilerSignallingItem(innerItemPreemptiveShutdown, this, notifyFunction, signalPreemptiveShutdownChanged);
  addItem( itemPreemptiveShutdown, QStringLiteral( "PreemptiveShutdown" ) );
  KConfigCompilerSignallingItem  *itemResetMountModelOnAlignFail;
  KConfigSkeleton::ItemBool  *innerItemResetMountModelOnAlignFail;
  innerItemResetMountModelOnAlignFail = new KConfigSkeleton::ItemBool( currentGroup(), QStringLiteral( "ResetMountModelOnAlignFail" ), mResetMountModelOnAlignFail, false );
  itemResetMountModelOnAlignFail = new KConfigCompilerSignallingItem(innerItemResetMountModelOnAlignFail, this, notifyFunction, signalResetMountModelOnAlignFailChanged);
  addItem( itemResetMountModelOnAlignFail, QStringLiteral( "ResetMountModelOnAlignFail" ) );
  KConfigCompilerSignallingItem  *itemResetMountModelBeforeJob;
  KConfigSkeleton::ItemBool  *innerItemResetMountModelBeforeJob;
  innerItemResetMountModelBeforeJob = new KConfigSkeleton::ItemBool( currentGroup(), QStringLiteral( "ResetMountModelBeforeJob" ), mResetMountModelBeforeJob, false );
  itemResetMountModelBeforeJob = new KConfigCompilerSignallingItem(innerItemResetMountModelBeforeJob, this, notifyFunction, signalResetMountModelBeforeJobChanged);
  addItem( itemResetMountModelBeforeJob, QStringLiteral( "ResetMountModelBeforeJob" ) );
  KConfigCompilerSignallingItem  *itemResetGuideCalibration;
  KConfigSkeleton::ItemBool  *innerItemResetGuideCalibration;
  innerItemResetGuideCalibration = new KConfigSkeleton::ItemBool( currentGroup(), QStringLiteral( "ResetGuideCalibration" ), mResetGuideCalibration, true );
  itemResetGuideCalibration = new KConfigCompilerSignallingItem(innerItemResetGuideCalibration, this, notifyFunction, signalResetGuideCalibrationChanged);
  addItem( itemResetGuideCalibration, QStringLiteral( "ResetGuideCalibration" ) );
  KConfigCompilerSignallingItem  *itemForceAlignmentBeforeJob;
  KConfigSkeleton::ItemBool  *innerItemForceAlignmentBeforeJob;
  innerItemForceAlignmentBeforeJob = new KConfigSkeleton::ItemBool( currentGroup(), QStringLiteral( "ForceAlignmentBeforeJob" ), mForceAlignmentBeforeJob, false );
  itemForceAlignmentBeforeJob = new KConfigCompilerSignallingItem(innerItemForceAlignmentBeforeJob, this, notifyFunction, signalForceAlignmentBeforeJobChanged);
  addItem( itemForceAlignmentBeforeJob, QStringLiteral( "ForceAlignmentBeforeJob" ) );
  KConfigCompilerSignallingItem  *itemReuseGuideCalibration;
  KConfigSkeleton::ItemBool  *innerItemReuseGuideCalibration;
  innerItemReuseGuideCalibration = new KConfigSkeleton::ItemBool( currentGroup(), QStringLiteral( "ReuseGuideCalibration" ), mReuseGuideCalibration, false );
  itemReuseGuideCalibration = new KConfigCompilerSignallingItem(innerItemReuseGuideCalibration, this, notifyFunction, signalReuseGuideCalibrationChanged);
  addItem( itemReuseGuideCalibration, QStringLiteral( "ReuseGuideCalibration" ) );
  KConfigCompilerSignallingItem  *itemReverseDecOnPierSideChange;
  KConfigSkeleton::ItemBool  *innerItemReverseDecOnPierSideChange;
  innerItemReverseDecOnPierSideChange = new KConfigSkeleton::ItemBool( currentGroup(), QStringLiteral( "ReverseDecOnPierSideChange" ), mReverseDecOnPierSideChange, false );
  itemReverseDecOnPierSideChange = new KConfigCompilerSignallingItem(innerItemReverseDecOnPierSideChange, this, notifyFunction, signalReverseDecOnPierSideChangeChanged);
  addItem( itemReverseDecOnPierSideChange, QStringLiteral( "ReverseDecOnPierSideChange" ) );
  KConfigCompilerSignallingItem  *itemGuideCalibrationBacklash;
  KConfigSkeleton::ItemBool  *innerItemGuideCalibrationBacklash;
  innerItemGuideCalibrationBacklash = new KConfigSkeleton::ItemBool( currentGroup(), QStringLiteral( "GuideCalibrationBacklash" ), mGuideCalibrationBacklash, true );
  itemGuideCalibrationBacklash = new KConfigCompilerSignallingItem(innerItemGuideCalibrationBacklash, this, notifyFunction, signalGuideCalibrationBacklashChanged);
  addItem( itemGuideCalibrationBacklash, QStringLiteral( "GuideCalibrationBacklash" ) );
  KConfigCompilerSignallingItem  *itemAssumeDecOrthogonal;
  KConfigSkeleton::ItemBool  *innerItemAssumeDecOrthogonal;
  innerItemAssumeDecOrthogonal = new KConfigSkeleton::ItemBool( currentGroup(), QStringLiteral( "AssumeDecOrthogonal" ), mAssumeDecOrthogonal, false );
  itemAssumeDecOrthogonal = new KConfigCompilerSignallingItem(innerItemAssumeDecOrthogonal, this, notifyFunction, signalAssumeDecOrthogonalChanged);
  addItem( itemAssumeDecOrthogonal, QStringLiteral( "AssumeDecOrthogonal" ) );
  KConfigCompilerSignallingItem  *itemSerializedCalibration;
  KConfigSkeleton::ItemString  *innerItemSerializedCalibration;
  innerItemSerializedCalibration = new KConfigSkeleton::ItemString( currentGroup(), QStringLiteral( "SerializedCalibration" ), mSerializedCalibration );
  itemSerializedCalibration = new KConfigCompilerSignallingItem(innerItemSerializedCalibration, this, notifyFunction, signalSerializedCalibrationChanged);
  addItem( itemSerializedCalibration, QStringLiteral( "SerializedCalibration" ) );
  KConfigCompilerSignallingItem  *itemRealignAfterCalibrationFailure;
  KConfigSkeleton::ItemBool  *innerItemRealignAfterCalibrationFailure;
  innerItemRealignAfterCalibrationFailure = new KConfigSkeleton::ItemBool( currentGroup(), QStringLiteral( "RealignAfterCalibrationFailure" ), mRealignAfterCalibrationFailure, false );
  itemRealignAfterCalibrationFailure = new KConfigCompilerSignallingItem(innerItemRealignAfterCalibrationFailure, this, notifyFunction, signalRealignAfterCalibrationFailureChanged);
  addItem( itemRealignAfterCalibrationFailure, QStringLiteral( "RealignAfterCalibrationFailure" ) );
  KConfigCompilerSignallingItem  *itemPreemptiveShutdownTime;
  KConfigSkeleton::ItemDouble  *innerItemPreemptiveShutdownTime;
  innerItemPreemptiveShutdownTime = new KConfigSkeleton::ItemDouble( currentGroup(), QStringLiteral( "PreemptiveShutdownTime" ), mPreemptiveShutdownTime, 2 );
  itemPreemptiveShutdownTime = new KConfigCompilerSignallingItem(innerItemPreemptiveShutdownTime, this, notifyFunction, signalPreemptiveShutdownTimeChanged);
  addItem( itemPreemptiveShutdownTime, QStringLiteral( "PreemptiveShutdownTime" ) );
  KConfigCompilerSignallingItem  *itemRememberJobProgress;
  KConfigSkeleton::ItemBool  *innerItemRememberJobProgress;
  innerItemRememberJobProgress = new KConfigSkeleton::ItemBool( currentGroup(), QStringLiteral( "RememberJobProgress" ), mRememberJobProgress, true );
  itemRememberJobProgress = new KConfigCompilerSignallingItem(innerItemRememberJobProgress, this, notifyFunction, signalRememberJobProgressChanged);
  addItem( itemRememberJobProgress, QStringLiteral( "RememberJobProgress" ) );
  KConfigCompilerSignallingItem  *itemGreedyScheduling;
  KConfigSkeleton::ItemBool  *innerItemGreedyScheduling;
  innerItemGreedyScheduling = new KConfigSkeleton::ItemBool( currentGroup(), QStringLiteral( "GreedyScheduling" ), mGreedyScheduling, true );
  itemGreedyScheduling = new KConfigCompilerSignallingItem(innerItemGreedyScheduling, this, notifyFunction, signalGreedySchedulingChanged);
  addItem( itemGreedyScheduling, QStringLiteral( "GreedyScheduling" ) );
  KConfigCompilerSignallingItem  *itemLeadTime;
  KConfigSkeleton::ItemDouble  *innerItemLeadTime;
  innerItemLeadTime = new KConfigSkeleton::ItemDouble( currentGroup(), QStringLiteral( "LeadTime" ), mLeadTime, 5 );
  itemLeadTime = new KConfigCompilerSignallingItem(innerItemLeadTime, this, notifyFunction, signalLeadTimeChanged);
  addItem( itemLeadTime, QStringLiteral( "LeadTime" ) );
  KConfigCompilerSignallingItem  *itemPreDawnTime;
  KConfigSkeleton::ItemDouble  *innerItemPreDawnTime;
  innerItemPreDawnTime = new KConfigSkeleton::ItemDouble( currentGroup(), QStringLiteral( "PreDawnTime" ), mPreDawnTime, 30 );
  itemPreDawnTime = new KConfigCompilerSignallingItem(innerItemPreDawnTime, this, notifyFunction, signalPreDawnTimeChanged);
  addItem( itemPreDawnTime, QStringLiteral( "PreDawnTime" ) );
  KConfigCompilerSignallingItem  *itemDawnOffset;
  KConfigSkeleton::ItemDouble  *innerItemDawnOffset;
  innerItemDawnOffset = new KConfigSkeleton::ItemDouble( currentGroup(), QStringLiteral( "DawnOffset" ), mDawnOffset, 0 );
  itemDawnOffset = new KConfigCompilerSignallingItem(innerItemDawnOffset, this, notifyFunction, signalDawnOffsetChanged);
  addItem( itemDawnOffset, QStringLiteral( "DawnOffset" ) );
  KConfigCompilerSignallingItem  *itemDuskOffset;
  KConfigSkeleton::ItemDouble  *innerItemDuskOffset;
  innerItemDuskOffset = new KConfigSkeleton::ItemDouble( currentGroup(), QStringLiteral( "DuskOffset" ), mDuskOffset, 0 );
  itemDuskOffset = new KConfigCompilerSignallingItem(innerItemDuskOffset, this, notifyFunction, signalDuskOffsetChanged);
  addItem( itemDuskOffset, QStringLiteral( "DuskOffset" ) );
  KConfigCompilerSignallingItem  *itemTelescopeFocalLength;
  KConfigSkeleton::ItemDouble  *innerItemTelescopeFocalLength;
  innerItemTelescopeFocalLength = new KConfigSkeleton::ItemDouble( currentGroup(), QStringLiteral( "TelescopeFocalLength" ), mTelescopeFocalLength, 0 );
  itemTelescopeFocalLength = new KConfigCompilerSignallingItem(innerItemTelescopeFocalLength, this, notifyFunction, signalTelescopeFocalLengthChanged);
  addItem( itemTelescopeFocalLength, QStringLiteral( "TelescopeFocalLength" ) );
  KConfigCompilerSignallingItem  *itemTelescopeFocalReducer;
  KConfigSkeleton::ItemDouble  *innerItemTelescopeFocalReducer;
  innerItemTelescopeFocalReducer = new KConfigSkeleton::ItemDouble( currentGroup(), QStringLiteral( "TelescopeFocalReducer" ), mTelescopeFocalReducer, 1 );
  itemTelescopeFocalReducer = new KConfigCompilerSignallingItem(innerItemTelescopeFocalReducer, this, notifyFunction, signalTelescopeFocalReducerChanged);
  addItem( itemTelescopeFocalReducer, QStringLiteral( "TelescopeFocalReducer" ) );
  KConfigCompilerSignallingItem  *itemCameraPixelWidth;
  KConfigSkeleton::ItemDouble  *innerItemCameraPixelWidth;
  innerItemCameraPixelWidth = new KConfigSkeleton::ItemDouble( currentGroup(), QStringLiteral( "CameraPixelWidth" ), mCameraPixelWidth, 0 );
  itemCameraPixelWidth = new KConfigCompilerSignallingItem(innerItemCameraPixelWidth, this, notifyFunction, signalCameraPixelWidthChanged);
  addItem( itemCameraPixelWidth, QStringLiteral( "CameraPixelWidth" ) );
  KConfigCompilerSignallingItem  *itemCameraPixelHeight;
  KConfigSkeleton::ItemDouble  *innerItemCameraPixelHeight;
  innerItemCameraPixelHeight = new KConfigSkeleton::ItemDouble( currentGroup(), QStringLiteral( "CameraPixelHeight" ), mCameraPixelHeight, 0 );
  itemCameraPixelHeight = new KConfigCompilerSignallingItem(innerItemCameraPixelHeight, this, notifyFunction, signalCameraPixelHeightChanged);
  addItem( itemCameraPixelHeight, QStringLiteral( "CameraPixelHeight" ) );
  KConfigCompilerSignallingItem  *itemCameraWidth;
  KConfigSkeleton::ItemUInt  *innerItemCameraWidth;
  innerItemCameraWidth = new KConfigSkeleton::ItemUInt( currentGroup(), QStringLiteral( "CameraWidth" ), mCameraWidth, 0 );
  itemCameraWidth = new KConfigCompilerSignallingItem(innerItemCameraWidth, this, notifyFunction, signalCameraWidthChanged);
  addItem( itemCameraWidth, QStringLiteral( "CameraWidth" ) );
  KConfigCompilerSignallingItem  *itemCameraHeight;
  KConfigSkeleton::ItemUInt  *innerItemCameraHeight;
  innerItemCameraHeight = new KConfigSkeleton::ItemUInt( currentGroup(), QStringLiteral( "CameraHeight" ), mCameraHeight, 0 );
  itemCameraHeight = new KConfigCompilerSignallingItem(innerItemCameraHeight, this, notifyFunction, signalCameraHeightChanged);
  addItem( itemCameraHeight, QStringLiteral( "CameraHeight" ) );
  KConfigCompilerSignallingItem  *itemCameraRotation;
  KConfigSkeleton::ItemDouble  *innerItemCameraRotation;
  innerItemCameraRotation = new KConfigSkeleton::ItemDouble( currentGroup(), QStringLiteral( "CameraRotation" ), mCameraRotation, 0 );
  itemCameraRotation = new KConfigCompilerSignallingItem(innerItemCameraRotation, this, notifyFunction, signalCameraRotationChanged);
  addItem( itemCameraRotation, QStringLiteral( "CameraRotation" ) );
  KConfigCompilerSignallingItem  *itemErrorHandlingStrategy;
  KConfigSkeleton::ItemUInt  *innerItemErrorHandlingStrategy;
  innerItemErrorHandlingStrategy = new KConfigSkeleton::ItemUInt( currentGroup(), QStringLiteral( "ErrorHandlingStrategy" ), mErrorHandlingStrategy, 1 );
  itemErrorHandlingStrategy = new KConfigCompilerSignallingItem(innerItemErrorHandlingStrategy, this, notifyFunction, signalErrorHandlingStrategyChanged);
  addItem( itemErrorHandlingStrategy, QStringLiteral( "ErrorHandlingStrategy" ) );
  KConfigCompilerSignallingItem  *itemErrorHandlingStrategyDelay;
  KConfigSkeleton::ItemUInt  *innerItemErrorHandlingStrategyDelay;
  innerItemErrorHandlingStrategyDelay = new KConfigSkeleton::ItemUInt( currentGroup(), QStringLiteral( "ErrorHandlingStrategyDelay" ), mErrorHandlingStrategyDelay, 0 );
  itemErrorHandlingStrategyDelay = new KConfigCompilerSignallingItem(innerItemErrorHandlingStrategyDelay, this, notifyFunction, signalErrorHandlingStrategyDelayChanged);
  addItem( itemErrorHandlingStrategyDelay, QStringLiteral( "ErrorHandlingStrategyDelay" ) );
  KConfigCompilerSignallingItem  *itemRescheduleErrors;
  KConfigSkeleton::ItemBool  *innerItemRescheduleErrors;
  innerItemRescheduleErrors = new KConfigSkeleton::ItemBool( currentGroup(), QStringLiteral( "RescheduleErrors" ), mRescheduleErrors, false );
  itemRescheduleErrors = new KConfigCompilerSignallingItem(innerItemRescheduleErrors, this, notifyFunction, signalRescheduleErrorsChanged);
  addItem( itemRescheduleErrors, QStringLiteral( "RescheduleErrors" ) );
  KConfigCompilerSignallingItem  *itemAlignCheckFrequency;
  KConfigSkeleton::ItemUInt  *innerItemAlignCheckFrequency;
  innerItemAlignCheckFrequency = new KConfigSkeleton::ItemUInt( currentGroup(), QStringLiteral( "AlignCheckFrequency" ), mAlignCheckFrequency, 0 );
  itemAlignCheckFrequency = new KConfigCompilerSignallingItem(innerItemAlignCheckFrequency, this, notifyFunction, signalAlignCheckFrequencyChanged);
  addItem( itemAlignCheckFrequency, QStringLiteral( "AlignCheckFrequency" ) );
  KConfigCompilerSignallingItem  *itemAlignCheckThreshold;
  KConfigSkeleton::ItemDouble  *innerItemAlignCheckThreshold;
  innerItemAlignCheckThreshold = new KConfigSkeleton::ItemDouble( currentGroup(), QStringLiteral( "AlignCheckThreshold" ), mAlignCheckThreshold, 30 );
  itemAlignCheckThreshold = new KConfigCompilerSignallingItem(innerItemAlignCheckThreshold, this, notifyFunction, signalAlignCheckThresholdChanged);
  addItem( itemAlignCheckThreshold, QStringLiteral( "AlignCheckThreshold" ) );
  KConfigCompilerSignallingItem  *itemSchedulerTrackStep;
  KConfigSkeleton::ItemBool  *innerItemSchedulerTrackStep;
  innerItemSchedulerTrackStep = new KConfigSkeleton::ItemBool( currentGroup(), QStringLiteral( "SchedulerTrackStep" ), mSchedulerTrackStep, true );
  itemSchedulerTrackStep = new KConfigCompilerSignallingItem(innerItemSchedulerTrackStep, this, notifyFunction, signalSchedulerTrackStepChanged);
  addItem( itemSchedulerTrackStep, QStringLiteral( "SchedulerTrackStep" ) );
  KConfigCompilerSignallingItem  *itemSchedulerStartupEnabled;
  KConfigSkeleton::ItemBool  *innerItemSchedulerStartupEnabled;
  innerItemSchedulerStartupEnabled = new KConfigSkeleton::ItemBool( currentGroup(), QStringLiteral( "SchedulerStartupEnabled" ), mSchedulerStartupEnabled, true );
  itemSchedulerStartupEnabled = new KConfigCompilerSignallingItem(innerItemSchedulerStartupEnabled, this, notifyFunction, signalSchedulerStartupEnabledChanged);
  addItem( itemSchedulerStartupEnabled, QStringLiteral( "SchedulerStartupEnabled" ) );
  KConfigCompilerSignallingItem  *itemSchedulerPreStartupScript;
  KConfigSkeleton::ItemString  *innerItemSchedulerPreStartupScript;
  innerItemSchedulerPreStartupScript = new KConfigSkeleton::ItemString( currentGroup(), QStringLiteral( "SchedulerPreStartupScript" ), mSchedulerPreStartupScript );
  itemSchedulerPreStartupScript = new KConfigCompilerSignallingItem(innerItemSchedulerPreStartupScript, this, notifyFunction, signalSchedulerPreStartupScriptChanged);
  addItem( itemSchedulerPreStartupScript, QStringLiteral( "SchedulerPreStartupScript" ) );
  KConfigCompilerSignallingItem  *itemSchedulerPostStartupScript;
  KConfigSkeleton::ItemString  *innerItemSchedulerPostStartupScript;
  innerItemSchedulerPostStartupScript = new KConfigSkeleton::ItemString( currentGroup(), QStringLiteral( "SchedulerPostStartupScript" ), mSchedulerPostStartupScript, QStringLiteral( "observatory_startup" ) );
  itemSchedulerPostStartupScript = new KConfigCompilerSignallingItem(innerItemSchedulerPostStartupScript, this, notifyFunction, signalSchedulerPostStartupScriptChanged);
  addItem( itemSchedulerPostStartupScript, QStringLiteral( "SchedulerPostStartupScript" ) );
  KConfigCompilerSignallingItem  *itemSchedulerShutdownEnabled;
  KConfigSkeleton::ItemBool  *innerItemSchedulerShutdownEnabled;
  innerItemSchedulerShutdownEnabled = new KConfigSkeleton::ItemBool( currentGroup(), QStringLiteral( "SchedulerShutdownEnabled" ), mSchedulerShutdownEnabled, true );
  itemSchedulerShutdownEnabled = new KConfigCompilerSignallingItem(innerItemSchedulerShutdownEnabled, this, notifyFunction, signalSchedulerShutdownEnabledChanged);
  addItem( itemSchedulerShutdownEnabled, QStringLiteral( "SchedulerShutdownEnabled" ) );
  KConfigCompilerSignallingItem  *itemSchedulerPreShutdownScript;
  KConfigSkeleton::ItemString  *innerItemSchedulerPreShutdownScript;
  innerItemSchedulerPreShutdownScript = new KConfigSkeleton::ItemString( currentGroup(), QStringLiteral( "SchedulerPreShutdownScript" ), mSchedulerPreShutdownScript, QStringLiteral( "observatory_shutdown" ) );
  itemSchedulerPreShutdownScript = new KConfigCompilerSignallingItem(innerItemSchedulerPreShutdownScript, this, notifyFunction, signalSchedulerPreShutdownScriptChanged);
  addItem( itemSchedulerPreShutdownScript, QStringLiteral( "SchedulerPreShutdownScript" ) );
  KConfigCompilerSignallingItem  *itemSchedulerPostShutdownScript;
  KConfigSkeleton::ItemString  *innerItemSchedulerPostShutdownScript;
  innerItemSchedulerPostShutdownScript = new KConfigSkeleton::ItemString( currentGroup(), QStringLiteral( "SchedulerPostShutdownScript" ), mSchedulerPostShutdownScript );
  itemSchedulerPostShutdownScript = new KConfigCompilerSignallingItem(innerItemSchedulerPostShutdownScript, this, notifyFunction, signalSchedulerPostShutdownScriptChanged);
  addItem( itemSchedulerPostShutdownScript, QStringLiteral( "SchedulerPostShutdownScript" ) );
  KConfigCompilerSignallingItem  *itemSchedulerFocusStep;
  KConfigSkeleton::ItemBool  *innerItemSchedulerFocusStep;
  innerItemSchedulerFocusStep = new KConfigSkeleton::ItemBool( currentGroup(), QStringLiteral( "SchedulerFocusStep" ), mSchedulerFocusStep, true );
  itemSchedulerFocusStep = new KConfigCompilerSignallingItem(innerItemSchedulerFocusStep, this, notifyFunction, signalSchedulerFocusStepChanged);
  addItem( itemSchedulerFocusStep, QStringLiteral( "SchedulerFocusStep" ) );
  KConfigCompilerSignallingItem  *itemSchedulerGuideStep;
  KConfigSkeleton::ItemBool  *innerItemSchedulerGuideStep;
  innerItemSchedulerGuideStep = new KConfigSkeleton::ItemBool( currentGroup(), QStringLiteral( "SchedulerGuideStep" ), mSchedulerGuideStep, true );
  itemSchedulerGuideStep = new KConfigCompilerSignallingItem(innerItemSchedulerGuideStep, this, notifyFunction, signalSchedulerGuideStepChanged);
  addItem( itemSchedulerGuideStep, QStringLiteral( "SchedulerGuideStep" ) );
  KConfigCompilerSignallingItem  *itemSchedulerAlignStep;
  KConfigSkeleton::ItemBool  *innerItemSchedulerAlignStep;
  innerItemSchedulerAlignStep = new KConfigSkeleton::ItemBool( currentGroup(), QStringLiteral( "SchedulerAlignStep" ), mSchedulerAlignStep, true );
  itemSchedulerAlignStep = new KConfigCompilerSignallingItem(innerItemSchedulerAlignStep, this, notifyFunction, signalSchedulerAlignStepChanged);
  addItem( itemSchedulerAlignStep, QStringLiteral( "SchedulerAlignStep" ) );
  KConfigCompilerSignallingItem  *itemSchedulerAltitude;
  KConfigSkeleton::ItemBool  *innerItemSchedulerAltitude;
  innerItemSchedulerAltitude = new KConfigSkeleton::ItemBool( currentGroup(), QStringLiteral( "SchedulerAltitude" ), mSchedulerAltitude, true );
  itemSchedulerAltitude = new KConfigCompilerSignallingItem(innerItemSchedulerAltitude, this, notifyFunction, signalSchedulerAltitudeChanged);
  addItem( itemSchedulerAltitude, QStringLiteral( "SchedulerAltitude" ) );
  KConfigCompilerSignallingItem  *itemSchedulerAltitudeValue;
  KConfigSkeleton::ItemDouble  *innerItemSchedulerAltitudeValue;
  innerItemSchedulerAltitudeValue = new KConfigSkeleton::ItemDouble( currentGroup(), QStringLiteral( "SchedulerAltitudeValue" ), mSchedulerAltitudeValue, 0 );
  itemSchedulerAltitudeValue = new KConfigCompilerSignallingItem(innerItemSchedulerAltitudeValue, this, notifyFunction, signalSchedulerAltitudeValueChanged);
  addItem( itemSchedulerAltitudeValue, QStringLiteral( "SchedulerAltitudeValue" ) );
  KConfigCompilerSignallingItem  *itemSchedulerHorizon;
  KConfigSkeleton::ItemBool  *innerItemSchedulerHorizon;
  innerItemSchedulerHorizon = new KConfigSkeleton::ItemBool( currentGroup(), QStringLiteral( "SchedulerHorizon" ), mSchedulerHorizon, true );
  itemSchedulerHorizon = new KConfigCompilerSignallingItem(innerItemSchedulerHorizon, this, notifyFunction, signalSchedulerHorizonChanged);
  addItem( itemSchedulerHorizon, QStringLiteral( "SchedulerHorizon" ) );
  KConfigCompilerSignallingItem  *itemSchedulerMoonSeparation;
  KConfigSkeleton::ItemBool  *innerItemSchedulerMoonSeparation;
  innerItemSchedulerMoonSeparation = new KConfigSkeleton::ItemBool( currentGroup(), QStringLiteral( "SchedulerMoonSeparation" ), mSchedulerMoonSeparation, false );
  itemSchedulerMoonSeparation = new KConfigCompilerSignallingItem(innerItemSchedulerMoonSeparation, this, notifyFunction, signalSchedulerMoonSeparationChanged);
  addItem( itemSchedulerMoonSeparation, QStringLiteral( "SchedulerMoonSeparation" ) );
  KConfigCompilerSignallingItem  *itemSchedulerMoonSeparationValue;
  KConfigSkeleton::ItemDouble  *innerItemSchedulerMoonSeparationValue;
  innerItemSchedulerMoonSeparationValue = new KConfigSkeleton::ItemDouble( currentGroup(), QStringLiteral( "SchedulerMoonSeparationValue" ), mSchedulerMoonSeparationValue, 0 );
  itemSchedulerMoonSeparationValue = new KConfigCompilerSignallingItem(innerItemSchedulerMoonSeparationValue, this, notifyFunction, signalSchedulerMoonSeparationValueChanged);
  addItem( itemSchedulerMoonSeparationValue, QStringLiteral( "SchedulerMoonSeparationValue" ) );
  KConfigCompilerSignallingItem  *itemSchedulerMoonAltitude;
  KConfigSkeleton::ItemBool  *innerItemSchedulerMoonAltitude;
  innerItemSchedulerMoonAltitude = new KConfigSkeleton::ItemBool( currentGroup(), QStringLiteral( "SchedulerMoonAltitude" ), mSchedulerMoonAltitude, false );
  itemSchedulerMoonAltitude = new KConfigCompilerSignallingItem(innerItemSchedulerMoonAltitude, this, notifyFunction, signalSchedulerMoonAltitudeChanged);
  addItem( itemSchedulerMoonAltitude, QStringLiteral( "SchedulerMoonAltitude" ) );
  KConfigCompilerSignallingItem  *itemSchedulerMoonAltitudeMaxValue;
  KConfigSkeleton::ItemDouble  *innerItemSchedulerMoonAltitudeMaxValue;
  innerItemSchedulerMoonAltitudeMaxValue = new KConfigSkeleton::ItemDouble( currentGroup(), QStringLiteral( "SchedulerMoonAltitudeMaxValue" ), mSchedulerMoonAltitudeMaxValue, 90 );
  itemSchedulerMoonAltitudeMaxValue = new KConfigCompilerSignallingItem(innerItemSchedulerMoonAltitudeMaxValue, this, notifyFunction, signalSchedulerMoonAltitudeMaxValueChanged);
  addItem( itemSchedulerMoonAltitudeMaxValue, QStringLiteral( "SchedulerMoonAltitudeMaxValue" ) );
  KConfigCompilerSignallingItem  *itemSchedulerWeather;
  KConfigSkeleton::ItemBool  *innerItemSchedulerWeather;
  innerItemSchedulerWeather = new KConfigSkeleton::ItemBool( currentGroup(), QStringLiteral( "SchedulerWeather" ), mSchedulerWeather, false );
  itemSchedulerWeather = new KConfigCompilerSignallingItem(innerItemSchedulerWeather, this, notifyFunction, signalSchedulerWeatherChanged);
  addItem( itemSchedulerWeather, QStringLiteral( "SchedulerWeather" ) );
  KConfigCompilerSignallingItem  *itemSchedulerWeatherGracePeriod;
  KConfigSkeleton::ItemUInt  *innerItemSchedulerWeatherGracePeriod;
  innerItemSchedulerWeatherGracePeriod = new KConfigSkeleton::ItemUInt( currentGroup(), QStringLiteral( "SchedulerWeatherGracePeriod" ), mSchedulerWeatherGracePeriod, 10 );
  itemSchedulerWeatherGracePeriod = new KConfigCompilerSignallingItem(innerItemSchedulerWeatherGracePeriod, this, notifyFunction, signalSchedulerWeatherGracePeriodChanged);
  addItem( itemSchedulerWeatherGracePeriod, QStringLiteral( "SchedulerWeatherGracePeriod" ) );
  KConfigCompilerSignallingItem  *itemSchedulerWeatherShutdownDelay;
  KConfigSkeleton::ItemUInt  *innerItemSchedulerWeatherShutdownDelay;
  innerItemSchedulerWeatherShutdownDelay = new KConfigSkeleton::ItemUInt( currentGroup(), QStringLiteral( "SchedulerWeatherShutdownDelay" ), mSchedulerWeatherShutdownDelay, 10 );
  itemSchedulerWeatherShutdownDelay = new KConfigCompilerSignallingItem(innerItemSchedulerWeatherShutdownDelay, this, notifyFunction, signalSchedulerWeatherShutdownDelayChanged);
  addItem( itemSchedulerWeatherShutdownDelay, QStringLiteral( "SchedulerWeatherShutdownDelay" ) );
  KConfigCompilerSignallingItem  *itemSchedulerSafetyMonitorConnectionString;
  KConfigSkeleton::ItemString  *innerItemSchedulerSafetyMonitorConnectionString;
  innerItemSchedulerSafetyMonitorConnectionString = new KConfigSkeleton::ItemString( currentGroup(), QStringLiteral( "SchedulerSafetyMonitorConnectionString" ), mSchedulerSafetyMonitorConnectionString );
  itemSchedulerSafetyMonitorConnectionString = new KConfigCompilerSignallingItem(innerItemSchedulerSafetyMonitorConnectionString, this, notifyFunction, signalSchedulerSafetyMonitorConnectionStringChanged);
  addItem( itemSchedulerSafetyMonitorConnectionString, QStringLiteral( "SchedulerSafetyMonitorConnectionString" ) );
  KConfigCompilerSignallingItem  *itemSchedulerTwilight;
  KConfigSkeleton::ItemBool  *innerItemSchedulerTwilight;
  innerItemSchedulerTwilight = new KConfigSkeleton::ItemBool( currentGroup(), QStringLiteral( "SchedulerTwilight" ), mSchedulerTwilight, true );
  itemSchedulerTwilight = new KConfigCompilerSignallingItem(innerItemSchedulerTwilight, this, notifyFunction, signalSchedulerTwilightChanged);
  addItem( itemSchedulerTwilight, QStringLiteral( "SchedulerTwilight" ) );
  KConfigCompilerSignallingItem  *itemSchedulerCompleteSequences;
  KConfigSkeleton::ItemBool  *innerItemSchedulerCompleteSequences;
  innerItemSchedulerCompleteSequences = new KConfigSkeleton::ItemBool( currentGroup(), QStringLiteral( "SchedulerCompleteSequences" ), mSchedulerCompleteSequences, true );
  itemSchedulerCompleteSequences = new KConfigCompilerSignallingItem(innerItemSchedulerCompleteSequences, this, notifyFunction, signalSchedulerCompleteSequencesChanged);
  addItem( itemSchedulerCompleteSequences, QStringLiteral( "SchedulerCompleteSequences" ) );
  KConfigCompilerSignallingItem  *itemSchedulerRepeatEverything;
  KConfigSkeleton::ItemBool  *innerItemSchedulerRepeatEverything;
  innerItemSchedulerRepeatEverything = new KConfigSkeleton::ItemBool( currentGroup(), QStringLiteral( "SchedulerRepeatEverything" ), mSchedulerRepeatEverything, false );
  itemSchedulerRepeatEverything = new KConfigCompilerSignallingItem(innerItemSchedulerRepeatEverything, this, notifyFunction, signalSchedulerRepeatEverythingChanged);
  addItem( itemSchedulerRepeatEverything, QStringLiteral( "SchedulerRepeatEverything" ) );
  KConfigCompilerSignallingItem  *itemSchedulerRepeatSequences;
  KConfigSkeleton::ItemBool  *innerItemSchedulerRepeatSequences;
  innerItemSchedulerRepeatSequences = new KConfigSkeleton::ItemBool( currentGroup(), QStringLiteral( "SchedulerRepeatSequences" ), mSchedulerRepeatSequences, false );
  itemSchedulerRepeatSequences = new KConfigCompilerSignallingItem(innerItemSchedulerRepeatSequences, this, notifyFunction, signalSchedulerRepeatSequencesChanged);
  addItem( itemSchedulerRepeatSequences, QStringLiteral( "SchedulerRepeatSequences" ) );
  KConfigCompilerSignallingItem  *itemSchedulerUntilTerminated;
  KConfigSkeleton::ItemBool  *innerItemSchedulerUntilTerminated;
  innerItemSchedulerUntilTerminated = new KConfigSkeleton::ItemBool( currentGroup(), QStringLiteral( "SchedulerUntilTerminated" ), mSchedulerUntilTerminated, false );
  itemSchedulerUntilTerminated = new KConfigCompilerSignallingItem(innerItemSchedulerUntilTerminated, this, notifyFunction, signalSchedulerUntilTerminatedChanged);
  addItem( itemSchedulerUntilTerminated, QStringLiteral( "SchedulerUntilTerminated" ) );
  KConfigCompilerSignallingItem  *itemSchedulerUntil;
  KConfigSkeleton::ItemBool  *innerItemSchedulerUntil;
  innerItemSchedulerUntil = new KConfigSkeleton::ItemBool( currentGroup(), QStringLiteral( "SchedulerUntil" ), mSchedulerUntil, false );
  itemSchedulerUntil = new KConfigCompilerSignallingItem(innerItemSchedulerUntil, this, notifyFunction, signalSchedulerUntilChanged);
  addItem( itemSchedulerUntil, QStringLiteral( "SchedulerUntil" ) );
  KConfigCompilerSignallingItem  *itemSchedulerUntilValue;
  KConfigSkeleton::ItemString  *innerItemSchedulerUntilValue;
  innerItemSchedulerUntilValue = new KConfigSkeleton::ItemString( currentGroup(), QStringLiteral( "SchedulerUntilValue" ), mSchedulerUntilValue );
  itemSchedulerUntilValue = new KConfigCompilerSignallingItem(innerItemSchedulerUntilValue, this, notifyFunction, signalSchedulerUntilValueChanged);
  addItem( itemSchedulerUntilValue, QStringLiteral( "SchedulerUntilValue" ) );
  KConfigCompilerSignallingItem  *itemSchedulerExecutionSequencesLimit;
  KConfigSkeleton::ItemUInt  *innerItemSchedulerExecutionSequencesLimit;
  innerItemSchedulerExecutionSequencesLimit = new KConfigSkeleton::ItemUInt( currentGroup(), QStringLiteral( "SchedulerExecutionSequencesLimit" ), mSchedulerExecutionSequencesLimit, 0 );
  itemSchedulerExecutionSequencesLimit = new KConfigCompilerSignallingItem(innerItemSchedulerExecutionSequencesLimit, this, notifyFunction, signalSchedulerExecutionSequencesLimitChanged);
  addItem( itemSchedulerExecutionSequencesLimit, QStringLiteral( "SchedulerExecutionSequencesLimit" ) );

  setCurrentGroup( QStringLiteral( "Analyze" ) );

  KConfigCompilerSignallingItem  *itemAnalyzeRestartWithEkos;
  KConfigSkeleton::ItemBool  *innerItemAnalyzeRestartWithEkos;
  innerItemAnalyzeRestartWithEkos = new KConfigSkeleton::ItemBool( currentGroup(), QStringLiteral( "AnalyzeRestartWithEkos" ), mAnalyzeRestartWithEkos, true );
  itemAnalyzeRestartWithEkos = new KConfigCompilerSignallingItem(innerItemAnalyzeRestartWithEkos, this, notifyFunction, signalAnalyzeRestartWithEkosChanged);
  addItem( itemAnalyzeRestartWithEkos, QStringLiteral( "AnalyzeRestartWithEkos" ) );
  KConfigCompilerSignallingItem  *itemAnalyzeAlternativeDirectoryName;
  KConfigSkeleton::ItemString  *innerItemAnalyzeAlternativeDirectoryName;
  innerItemAnalyzeAlternativeDirectoryName = new KConfigSkeleton::ItemString( currentGroup(), QStringLiteral( "AnalyzeAlternativeDirectoryName" ), mAnalyzeAlternativeDirectoryName, QDir::homePath() );
  itemAnalyzeAlternativeDirectoryName = new KConfigCompilerSignallingItem(innerItemAnalyzeAlternativeDirectoryName, this, notifyFunction, signalAnalyzeAlternativeDirectoryNameChanged);
  addItem( itemAnalyzeAlternativeDirectoryName, QStringLiteral( "AnalyzeAlternativeDirectoryName" ) );
  KConfigCompilerSignallingItem  *itemAnalyzeHFR;
  KConfigSkeleton::ItemBool  *innerItemAnalyzeHFR;
  innerItemAnalyzeHFR = new KConfigSkeleton::ItemBool( currentGroup(), QStringLiteral( "AnalyzeHFR" ), mAnalyzeHFR, true );
  itemAnalyzeHFR = new KConfigCompilerSignallingItem(innerItemAnalyzeHFR, this, notifyFunction, signalAnalyzeHFRChanged);
  addItem( itemAnalyzeHFR, QStringLiteral( "AnalyzeHFR" ) );
  KConfigCompilerSignallingItem  *itemAnalyzeNumCaptureStars;
  KConfigSkeleton::ItemBool  *innerItemAnalyzeNumCaptureStars;
  innerItemAnalyzeNumCaptureStars = new KConfigSkeleton::ItemBool( currentGroup(), QStringLiteral( "AnalyzeNumCaptureStars" ), mAnalyzeNumCaptureStars, false );
  itemAnalyzeNumCaptureStars = new KConfigCompilerSignallingItem(innerItemAnalyzeNumCaptureStars, this, notifyFunction, signalAnalyzeNumCaptureStarsChanged);
  addItem( itemAnalyzeNumCaptureStars, QStringLiteral( "AnalyzeNumCaptureStars" ) );
  KConfigCompilerSignallingItem  *itemAnalyzeMedian;
  KConfigSkeleton::ItemBool  *innerItemAnalyzeMedian;
  innerItemAnalyzeMedian = new KConfigSkeleton::ItemBool( currentGroup(), QStringLiteral( "AnalyzeMedian" ), mAnalyzeMedian, false );
  itemAnalyzeMedian = new KConfigCompilerSignallingItem(innerItemAnalyzeMedian, this, notifyFunction, signalAnalyzeMedianChanged);
  addItem( itemAnalyzeMedian, QStringLiteral( "AnalyzeMedian" ) );
  KConfigCompilerSignallingItem  *itemAnalyzeEccentricity;
  KConfigSkeleton::ItemBool  *innerItemAnalyzeEccentricity;
  innerItemAnalyzeEccentricity = new KConfigSkeleton::ItemBool( currentGroup(), QStringLiteral( "AnalyzeEccentricity" ), mAnalyzeEccentricity, false );
  itemAnalyzeEccentricity = new KConfigCompilerSignallingItem(innerItemAnalyzeEccentricity, this, notifyFunction, signalAnalyzeEccentricityChanged);
  addItem( itemAnalyzeEccentricity, QStringLiteral( "AnalyzeEccentricity" ) );
  KConfigCompilerSignallingItem  *itemAnalyzeTemperature;
  KConfigSkeleton::ItemBool  *innerItemAnalyzeTemperature;
  innerItemAnalyzeTemperature = new KConfigSkeleton::ItemBool( currentGroup(), QStringLiteral( "AnalyzeTemperature" ), mAnalyzeTemperature, false );
  itemAnalyzeTemperature = new KConfigCompilerSignallingItem(innerItemAnalyzeTemperature, this, notifyFunction, signalAnalyzeTemperatureChanged);
  addItem( itemAnalyzeTemperature, QStringLiteral( "AnalyzeTemperature" ) );
  KConfigCompilerSignallingItem  *itemFocusPosition;
  KConfigSkeleton::ItemBool  *innerItemFocusPosition;
  innerItemFocusPosition = new KConfigSkeleton::ItemBool( currentGroup(), QStringLiteral( "FocusPosition" ), mFocusPosition, false );
  itemFocusPosition = new KConfigCompilerSignallingItem(innerItemFocusPosition, this, notifyFunction, signalFocusPositionChanged);
  addItem( itemFocusPosition, QStringLiteral( "FocusPosition" ) );
  KConfigCompilerSignallingItem  *itemAnalyzeNumStars;
  KConfigSkeleton::ItemBool  *innerItemAnalyzeNumStars;
  innerItemAnalyzeNumStars = new KConfigSkeleton::ItemBool( currentGroup(), QStringLiteral( "AnalyzeNumStars" ), mAnalyzeNumStars, false );
  itemAnalyzeNumStars = new KConfigCompilerSignallingItem(innerItemAnalyzeNumStars, this, notifyFunction, signalAnalyzeNumStarsChanged);
  addItem( itemAnalyzeNumStars, QStringLiteral( "AnalyzeNumStars" ) );
  KConfigCompilerSignallingItem  *itemAnalyzeSkyBg;
  KConfigSkeleton::ItemBool  *innerItemAnalyzeSkyBg;
  innerItemAnalyzeSkyBg = new KConfigSkeleton::ItemBool( currentGroup(), QStringLiteral( "AnalyzeSkyBg" ), mAnalyzeSkyBg, false );
  itemAnalyzeSkyBg = new KConfigCompilerSignallingItem(innerItemAnalyzeSkyBg, this, notifyFunction, signalAnalyzeSkyBgChanged);
  addItem( itemAnalyzeSkyBg, QStringLiteral( "AnalyzeSkyBg" ) );
  KConfigCompilerSignallingItem  *itemAnalyzeSNR;
  KConfigSkeleton::ItemBool  *innerItemAnalyzeSNR;
  innerItemAnalyzeSNR = new KConfigSkeleton::ItemBool( currentGroup(), QStringLiteral( "AnalyzeSNR" ), mAnalyzeSNR, true );
  itemAnalyzeSNR = new KConfigCompilerSignallingItem(innerItemAnalyzeSNR, this, notifyFunction, signalAnalyzeSNRChanged);
  addItem( itemAnalyzeSNR, QStringLiteral( "AnalyzeSNR" ) );
  KConfigCompilerSignallingItem  *itemAnalyzeRA;
  KConfigSkeleton::ItemBool  *innerItemAnalyzeRA;
  innerItemAnalyzeRA = new KConfigSkeleton::ItemBool( currentGroup(), QStringLiteral( "AnalyzeRA" ), mAnalyzeRA, false );
  itemAnalyzeRA = new KConfigCompilerSignallingItem(innerItemAnalyzeRA, this, notifyFunction, signalAnalyzeRAChanged);
  addItem( itemAnalyzeRA, QStringLiteral( "AnalyzeRA" ) );
  KConfigCompilerSignallingItem  *itemAnalyzeDEC;
  KConfigSkeleton::ItemBool  *innerItemAnalyzeDEC;
  innerItemAnalyzeDEC = new KConfigSkeleton::ItemBool( currentGroup(), QStringLiteral( "AnalyzeDEC" ), mAnalyzeDEC, false );
  itemAnalyzeDEC = new KConfigCompilerSignallingItem(innerItemAnalyzeDEC, this, notifyFunction, signalAnalyzeDECChanged);
  addItem( itemAnalyzeDEC, QStringLiteral( "AnalyzeDEC" ) );
  KConfigCompilerSignallingItem  *itemAnalyzeRAp;
  KConfigSkeleton::ItemBool  *innerItemAnalyzeRAp;
  innerItemAnalyzeRAp = new KConfigSkeleton::ItemBool( currentGroup(), QStringLiteral( "AnalyzeRAp" ), mAnalyzeRAp, false );
  itemAnalyzeRAp = new KConfigCompilerSignallingItem(innerItemAnalyzeRAp, this, notifyFunction, signalAnalyzeRApChanged);
  addItem( itemAnalyzeRAp, QStringLiteral( "AnalyzeRAp" ) );
  KConfigCompilerSignallingItem  *itemAnalyzeDECp;
  KConfigSkeleton::ItemBool  *innerItemAnalyzeDECp;
  innerItemAnalyzeDECp = new KConfigSkeleton::ItemBool( currentGroup(), QStringLiteral( "AnalyzeDECp" ), mAnalyzeDECp, false );
  itemAnalyzeDECp = new KConfigCompilerSignallingItem(innerItemAnalyzeDECp, this, notifyFunction, signalAnalyzeDECpChanged);
  addItem( itemAnalyzeDECp, QStringLiteral( "AnalyzeDECp" ) );
  KConfigCompilerSignallingItem  *itemAnalyzeDrift;
  KConfigSkeleton::ItemBool  *innerItemAnalyzeDrift;
  innerItemAnalyzeDrift = new KConfigSkeleton::ItemBool( currentGroup(), QStringLiteral( "AnalyzeDrift" ), mAnalyzeDrift, false );
  itemAnalyzeDrift = new KConfigCompilerSignallingItem(innerItemAnalyzeDrift, this, notifyFunction, signalAnalyzeDriftChanged);
  addItem( itemAnalyzeDrift, QStringLiteral( "AnalyzeDrift" ) );
  KConfigCompilerSignallingItem  *itemAnalyzeRMS;
  KConfigSkeleton::ItemBool  *innerItemAnalyzeRMS;
  innerItemAnalyzeRMS = new KConfigSkeleton::ItemBool( currentGroup(), QStringLiteral( "AnalyzeRMS" ), mAnalyzeRMS, true );
  itemAnalyzeRMS = new KConfigCompilerSignallingItem(innerItemAnalyzeRMS, this, notifyFunction, signalAnalyzeRMSChanged);
  addItem( itemAnalyzeRMS, QStringLiteral( "AnalyzeRMS" ) );
  KConfigCompilerSignallingItem  *itemAnalyzeTargetDistance;
  KConfigSkeleton::ItemBool  *innerItemAnalyzeTargetDistance;
  innerItemAnalyzeTargetDistance = new KConfigSkeleton::ItemBool( currentGroup(), QStringLiteral( "AnalyzeTargetDistance" ), mAnalyzeTargetDistance, false );
  itemAnalyzeTargetDistance = new KConfigCompilerSignallingItem(innerItemAnalyzeTargetDistance, this, notifyFunction, signalAnalyzeTargetDistanceChanged);
  addItem( itemAnalyzeTargetDistance, QStringLiteral( "AnalyzeTargetDistance" ) );
  KConfigCompilerSignallingItem  *itemAnalyzeRMSC;
  KConfigSkeleton::ItemBool  *innerItemAnalyzeRMSC;
  innerItemAnalyzeRMSC = new KConfigSkeleton::ItemBool( currentGroup(), QStringLiteral( "AnalyzeRMSC" ), mAnalyzeRMSC, false );
  itemAnalyzeRMSC = new KConfigCompilerSignallingItem(innerItemAnalyzeRMSC, this, notifyFunction, signalAnalyzeRMSCChanged);
  addItem( itemAnalyzeRMSC, QStringLiteral( "AnalyzeRMSC" ) );
  KConfigCompilerSignallingItem  *itemAnalyzeMountRA;
  KConfigSkeleton::ItemBool  *innerItemAnalyzeMountRA;
  innerItemAnalyzeMountRA = new KConfigSkeleton::ItemBool( currentGroup(), QStringLiteral( "AnalyzeMountRA" ), mAnalyzeMountRA, false );
  itemAnalyzeMountRA = new KConfigCompilerSignallingItem(innerItemAnalyzeMountRA, this, notifyFunction, signalAnalyzeMountRAChanged);
  addItem( itemAnalyzeMountRA, QStringLiteral( "AnalyzeMountRA" ) );
  KConfigCompilerSignallingItem  *itemAnalyzeMountDEC;
  KConfigSkeleton::ItemBool  *innerItemAnalyzeMountDEC;
  innerItemAnalyzeMountDEC = new KConfigSkeleton::ItemBool( currentGroup(), QStringLiteral( "AnalyzeMountDEC" ), mAnalyzeMountDEC, false );
  itemAnalyzeMountDEC = new KConfigCompilerSignallingItem(innerItemAnalyzeMountDEC, this, notifyFunction, signalAnalyzeMountDECChanged);
  addItem( itemAnalyzeMountDEC, QStringLiteral( "AnalyzeMountDEC" ) );
  KConfigCompilerSignallingItem  *itemAnalyzeMountHA;
  KConfigSkeleton::ItemBool  *innerItemAnalyzeMountHA;
  innerItemAnalyzeMountHA = new KConfigSkeleton::ItemBool( currentGroup(), QStringLiteral( "AnalyzeMountHA" ), mAnalyzeMountHA, false );
  itemAnalyzeMountHA = new KConfigCompilerSignallingItem(innerItemAnalyzeMountHA, this, notifyFunction, signalAnalyzeMountHAChanged);
  addItem( itemAnalyzeMountHA, QStringLiteral( "AnalyzeMountHA" ) );
  KConfigCompilerSignallingItem  *itemAnalyzeAz;
  KConfigSkeleton::ItemBool  *innerItemAnalyzeAz;
  innerItemAnalyzeAz = new KConfigSkeleton::ItemBool( currentGroup(), QStringLiteral( "AnalyzeAz" ), mAnalyzeAz, false );
  itemAnalyzeAz = new KConfigCompilerSignallingItem(innerItemAnalyzeAz, this, notifyFunction, signalAnalyzeAzChanged);
  addItem( itemAnalyzeAz, QStringLiteral( "AnalyzeAz" ) );
  KConfigCompilerSignallingItem  *itemAnalyzeAlt;
  KConfigSkeleton::ItemBool  *innerItemAnalyzeAlt;
  innerItemAnalyzeAlt = new KConfigSkeleton::ItemBool( currentGroup(), QStringLiteral( "AnalyzeAlt" ), mAnalyzeAlt, false );
  itemAnalyzeAlt = new KConfigCompilerSignallingItem(innerItemAnalyzeAlt, this, notifyFunction, signalAnalyzeAltChanged);
  addItem( itemAnalyzeAlt, QStringLiteral( "AnalyzeAlt" ) );
  KConfigCompilerSignallingItem  *itemAnalyzePierSide;
  KConfigSkeleton::ItemBool  *innerItemAnalyzePierSide;
  innerItemAnalyzePierSide = new KConfigSkeleton::ItemBool( currentGroup(), QStringLiteral( "AnalyzePierSide" ), mAnalyzePierSide, false );
  itemAnalyzePierSide = new KConfigCompilerSignallingItem(innerItemAnalyzePierSide, this, notifyFunction, signalAnalyzePierSideChanged);
  addItem( itemAnalyzePierSide, QStringLiteral( "AnalyzePierSide" ) );
  KConfigCompilerSignallingItem  *itemAnalyzeStatsYAxis;
  KConfigSkeleton::ItemString  *innerItemAnalyzeStatsYAxis;
  innerItemAnalyzeStatsYAxis = new KConfigSkeleton::ItemString( currentGroup(), QStringLiteral( "AnalyzeStatsYAxis" ), mAnalyzeStatsYAxis );
  itemAnalyzeStatsYAxis = new KConfigCompilerSignallingItem(innerItemAnalyzeStatsYAxis, this, notifyFunction, signalAnalyzeStatsYAxisChanged);
  addItem( itemAnalyzeStatsYAxis, QStringLiteral( "AnalyzeStatsYAxis" ) );

  setCurrentGroup( QStringLiteral( "INDI Lite" ) );

  KConfigCompilerSignallingItem  *itemLastServer;
  KConfigSkeleton::ItemString  *innerItemLastServer;
  innerItemLastServer = new KConfigSkeleton::ItemString( currentGroup(), QStringLiteral( "LastServer" ), mLastServer );
  itemLastServer = new KConfigCompilerSignallingItem(innerItemLastServer, this, notifyFunction, signalLastServerChanged);
  addItem( itemLastServer, QStringLiteral( "LastServer" ) );
  KConfigCompilerSignallingItem  *itemLastServerPort;
  KConfigSkeleton::ItemUInt  *innerItemLastServerPort;
  innerItemLastServerPort = new KConfigSkeleton::ItemUInt( currentGroup(), QStringLiteral( "LastServerPort" ), mLastServerPort, 7624 );
  itemLastServerPort = new KConfigCompilerSignallingItem(innerItemLastServerPort, this, notifyFunction, signalLastServerPortChanged);
  addItem( itemLastServerPort, QStringLiteral( "LastServerPort" ) );
  KConfigCompilerSignallingItem  *itemLastWebManagerPort;
  KConfigSkeleton::ItemUInt  *innerItemLastWebManagerPort;
  innerItemLastWebManagerPort = new KConfigSkeleton::ItemUInt( currentGroup(), QStringLiteral( "LastWebManagerPort" ), mLastWebManagerPort, 8624 );
  itemLastWebManagerPort = new KConfigCompilerSignallingItem(innerItemLastWebManagerPort, this, notifyFunction, signalLastWebManagerPortChanged);
  addItem( itemLastWebManagerPort, QStringLiteral( "LastWebManagerPort" ) );

  setCurrentGroup( QStringLiteral( "HIPS" ) );

  KConfigCompilerSignallingItem  *itemHIPSMemoryCache;
  KConfigSkeleton::ItemUInt  *innerItemHIPSMemoryCache;
  innerItemHIPSMemoryCache = new KConfigSkeleton::ItemUInt( currentGroup(), QStringLiteral( "HIPSMemoryCache" ), mHIPSMemoryCache, 300 );
  itemHIPSMemoryCache = new KConfigCompilerSignallingItem(innerItemHIPSMemoryCache, this, notifyFunction, signalHIPSMemoryCacheChanged);
  addItem( itemHIPSMemoryCache, QStringLiteral( "HIPSMemoryCache" ) );
  KConfigCompilerSignallingItem  *itemHIPSNetCache;
  KConfigSkeleton::ItemUInt  *innerItemHIPSNetCache;
  innerItemHIPSNetCache = new KConfigSkeleton::ItemUInt( currentGroup(), QStringLiteral( "HIPSNetCache" ), mHIPSNetCache, 1000 );
  itemHIPSNetCache = new KConfigCompilerSignallingItem(innerItemHIPSNetCache, this, notifyFunction, signalHIPSNetCacheChanged);
  addItem( itemHIPSNetCache, QStringLiteral( "HIPSNetCache" ) );
  KConfigCompilerSignallingItem  *itemHIPSSource;
  KConfigSkeleton::ItemString  *innerItemHIPSSource;
  innerItemHIPSSource = new KConfigSkeleton::ItemString( currentGroup(), QStringLiteral( "HIPSSource" ), mHIPSSource, QStringLiteral( "None" ) );
  itemHIPSSource = new KConfigCompilerSignallingItem(innerItemHIPSSource, this, notifyFunction, signalHIPSSourceChanged);
  addItem( itemHIPSSource, QStringLiteral( "HIPSSource" ) );
  KConfigCompilerSignallingItem  *itemHIPSBiLinearInterpolation;
  KConfigSkeleton::ItemBool  *innerItemHIPSBiLinearInterpolation;
  innerItemHIPSBiLinearInterpolation = new KConfigSkeleton::ItemBool( currentGroup(), QStringLiteral( "HIPSBiLinearInterpolation" ), mHIPSBiLinearInterpolation, false );
  itemHIPSBiLinearInterpolation = new KConfigCompilerSignallingItem(innerItemHIPSBiLinearInterpolation, this, notifyFunction, signalHIPSBiLinearInterpolationChanged);
  addItem( itemHIPSBiLinearInterpolation, QStringLiteral( "HIPSBiLinearInterpolation" ) );
  KConfigCompilerSignallingItem  *itemHIPSShowGrid;
  KConfigSkeleton::ItemBool  *innerItemHIPSShowGrid;
  innerItemHIPSShowGrid = new KConfigSkeleton::ItemBool( currentGroup(), QStringLiteral( "HIPSShowGrid" ), mHIPSShowGrid, false );
  itemHIPSShowGrid = new KConfigCompilerSignallingItem(innerItemHIPSShowGrid, this, notifyFunction, signalHIPSShowGridChanged);
  addItem( itemHIPSShowGrid, QStringLiteral( "HIPSShowGrid" ) );
  KConfigCompilerSignallingItem  *itemHIPSPanning;
  KConfigSkeleton::ItemBool  *innerItemHIPSPanning;
  innerItemHIPSPanning = new KConfigSkeleton::ItemBool( currentGroup(), QStringLiteral( "HIPSPanning" ), mHIPSPanning, false );
  itemHIPSPanning = new KConfigCompilerSignallingItem(innerItemHIPSPanning, this, notifyFunction, signalHIPSPanningChanged);
  addItem( itemHIPSPanning, QStringLiteral( "HIPSPanning" ) );
  KConfigCompilerSignallingItem  *itemShowHIPS;
  KConfigSkeleton::ItemBool  *innerItemShowHIPS;
  innerItemShowHIPS = new KConfigSkeleton::ItemBool( currentGroup(), QStringLiteral( "ShowHIPS" ), mShowHIPS, false );
  itemShowHIPS = new KConfigCompilerSignallingItem(innerItemShowHIPS, this, notifyFunction, signalShowHIPSChanged);
  addItem( itemShowHIPS, QStringLiteral( "ShowHIPS" ) );
  KConfigCompilerSignallingItem  *itemHIPSUseOfflineSource;
  KConfigSkeleton::ItemBool  *innerItemHIPSUseOfflineSource;
  innerItemHIPSUseOfflineSource = new KConfigSkeleton::ItemBool( currentGroup(), QStringLiteral( "HIPSUseOfflineSource" ), mHIPSUseOfflineSource, false );
  itemHIPSUseOfflineSource = new KConfigCompilerSignallingItem(innerItemHIPSUseOfflineSource, this, notifyFunction, signalHIPSUseOfflineSourceChanged);
  addItem( itemHIPSUseOfflineSource, QStringLiteral( "HIPSUseOfflineSource" ) );
  KConfigCompilerSignallingItem  *itemHIPSOfflinePath;
  KConfigSkeleton::ItemString  *innerItemHIPSOfflinePath;
  innerItemHIPSOfflinePath = new KConfigSkeleton::ItemString( currentGroup(), QStringLiteral( "HIPSOfflinePath" ), mHIPSOfflinePath );
  itemHIPSOfflinePath = new KConfigCompilerSignallingItem(innerItemHIPSOfflinePath, this, notifyFunction, signalHIPSOfflinePathChanged);
  addItem( itemHIPSOfflinePath, QStringLiteral( "HIPSOfflinePath" ) );

  setCurrentGroup( QStringLiteral( "Terrain" ) );

  KConfigCompilerSignallingItem  *itemTerrainSource;
  KConfigSkeleton::ItemString  *innerItemTerrainSource;
  innerItemTerrainSource = new KConfigSkeleton::ItemString( currentGroup(), QStringLiteral( "TerrainSource" ), mTerrainSource, QStringLiteral( "None" ) );
  itemTerrainSource = new KConfigCompilerSignallingItem(innerItemTerrainSource, this, notifyFunction, signalTerrainSourceChanged);
  addItem( itemTerrainSource, QStringLiteral( "TerrainSource" ) );
  KConfigCompilerSignallingItem  *itemTerrainSourceCorrectAz;
  KConfigSkeleton::ItemInt  *innerItemTerrainSourceCorrectAz;
  innerItemTerrainSourceCorrectAz = new KConfigSkeleton::ItemInt( currentGroup(), QStringLiteral( "TerrainSourceCorrectAz" ), mTerrainSourceCorrectAz, 0 );
  itemTerrainSourceCorrectAz = new KConfigCompilerSignallingItem(innerItemTerrainSourceCorrectAz, this, notifyFunction, signalTerrainSourceCorrectAzChanged);
  addItem( itemTerrainSourceCorrectAz, QStringLiteral( "TerrainSourceCorrectAz" ) );
  KConfigCompilerSignallingItem  *itemTerrainSourceCorrectAlt;
  KConfigSkeleton::ItemInt  *innerItemTerrainSourceCorrectAlt;
  innerItemTerrainSourceCorrectAlt = new KConfigSkeleton::ItemInt( currentGroup(), QStringLiteral( "TerrainSourceCorrectAlt" ), mTerrainSourceCorrectAlt, 0 );
  itemTerrainSourceCorrectAlt = new KConfigCompilerSignallingItem(innerItemTerrainSourceCorrectAlt, this, notifyFunction, signalTerrainSourceCorrectAltChanged);
  addItem( itemTerrainSourceCorrectAlt, QStringLiteral( "TerrainSourceCorrectAlt" ) );
  KConfigCompilerSignallingItem  *itemTerrainDownsampling;
  KConfigSkeleton::ItemInt  *innerItemTerrainDownsampling;
  innerItemTerrainDownsampling = new KConfigSkeleton::ItemInt( currentGroup(), QStringLiteral( "TerrainDownsampling" ), mTerrainDownsampling, 4 );
  itemTerrainDownsampling = new KConfigCompilerSignallingItem(innerItemTerrainDownsampling, this, notifyFunction, signalTerrainDownsamplingChanged);
  addItem( itemTerrainDownsampling, QStringLiteral( "TerrainDownsampling" ) );
  KConfigCompilerSignallingItem  *itemTerrainPanning;
  KConfigSkeleton::ItemBool  *innerItemTerrainPanning;
  innerItemTerrainPanning = new KConfigSkeleton::ItemBool( currentGroup(), QStringLiteral( "TerrainPanning" ), mTerrainPanning, true );
  itemTerrainPanning = new KConfigCompilerSignallingItem(innerItemTerrainPanning, this, notifyFunction, signalTerrainPanningChanged);
  addItem( itemTerrainPanning, QStringLiteral( "TerrainPanning" ) );
  KConfigCompilerSignallingItem  *itemShowTerrain;
  KConfigSkeleton::ItemBool  *innerItemShowTerrain;
  innerItemShowTerrain = new KConfigSkeleton::ItemBool( currentGroup(), QStringLiteral( "ShowTerrain" ), mShowTerrain, false );
  itemShowTerrain = new KConfigCompilerSignallingItem(innerItemShowTerrain, this, notifyFunction, signalShowTerrainChanged);
  addItem( itemShowTerrain, QStringLiteral( "ShowTerrain" ) );
  KConfigCompilerSignallingItem  *itemTerrainSkipSpeedup;
  KConfigSkeleton::ItemBool  *innerItemTerrainSkipSpeedup;
  innerItemTerrainSkipSpeedup = new KConfigSkeleton::ItemBool( currentGroup(), QStringLiteral( "TerrainSkipSpeedup" ), mTerrainSkipSpeedup, true );
  itemTerrainSkipSpeedup = new KConfigCompilerSignallingItem(innerItemTerrainSkipSpeedup, this, notifyFunction, signalTerrainSkipSpeedupChanged);
  addItem( itemTerrainSkipSpeedup, QStringLiteral( "TerrainSkipSpeedup" ) );
  KConfigCompilerSignallingItem  *itemTerrainTransparencySpeedup;
  KConfigSkeleton::ItemBool  *innerItemTerrainTransparencySpeedup;
  innerItemTerrainTransparencySpeedup = new KConfigSkeleton::ItemBool( currentGroup(), QStringLiteral( "TerrainTransparencySpeedup" ), mTerrainTransparencySpeedup, true );
  itemTerrainTransparencySpeedup = new KConfigCompilerSignallingItem(innerItemTerrainTransparencySpeedup, this, notifyFunction, signalTerrainTransparencySpeedupChanged);
  addItem( itemTerrainTransparencySpeedup, QStringLiteral( "TerrainTransparencySpeedup" ) );
  KConfigCompilerSignallingItem  *itemTerrainSmoothPixels;
  KConfigSkeleton::ItemBool  *innerItemTerrainSmoothPixels;
  innerItemTerrainSmoothPixels = new KConfigSkeleton::ItemBool( currentGroup(), QStringLiteral( "TerrainSmoothPixels" ), mTerrainSmoothPixels, false );
  itemTerrainSmoothPixels = new KConfigCompilerSignallingItem(innerItemTerrainSmoothPixels, this, notifyFunction, signalTerrainSmoothPixelsChanged);
  addItem( itemTerrainSmoothPixels, QStringLiteral( "TerrainSmoothPixels" ) );

  setCurrentGroup( QStringLiteral( "ImageOverlay" ) );

  KConfigCompilerSignallingItem  *itemShowImageOverlays;
  KConfigSkeleton::ItemBool  *innerItemShowImageOverlays;
  innerItemShowImageOverlays = new KConfigSkeleton::ItemBool( currentGroup(), QStringLiteral( "ShowImageOverlays" ), mShowImageOverlays, false );
  itemShowImageOverlays = new KConfigCompilerSignallingItem(innerItemShowImageOverlays, this, notifyFunction, signalShowImageOverlaysChanged);
  addItem( itemShowImageOverlays, QStringLiteral( "ShowImageOverlays" ) );
  KConfigCompilerSignallingItem  *itemShowImageOverlaysBelowCatalogs;
  KConfigSkeleton::ItemBool  *innerItemShowImageOverlaysBelowCatalogs;
  innerItemShowImageOverlaysBelowCatalogs = new KConfigSkeleton::ItemBool( currentGroup(), QStringLiteral( "ShowImageOverlaysBelowCatalogs" ), mShowImageOverlaysBelowCatalogs, false );
  itemShowImageOverlaysBelowCatalogs = new KConfigCompilerSignallingItem(innerItemShowImageOverlaysBelowCatalogs, this, notifyFunction, signalShowImageOverlaysBelowCatalogsChanged);
  addItem( itemShowImageOverlaysBelowCatalogs, QStringLiteral( "ShowImageOverlaysBelowCatalogs" ) );
  KConfigCompilerSignallingItem  *itemShowSelectedImageOverlay;
  KConfigSkeleton::ItemBool  *innerItemShowSelectedImageOverlay;
  innerItemShowSelectedImageOverlay = new KConfigSkeleton::ItemBool( currentGroup(), QStringLiteral( "ShowSelectedImageOverlay" ), mShowSelectedImageOverlay, true );
  itemShowSelectedImageOverlay = new KConfigCompilerSignallingItem(innerItemShowSelectedImageOverlay, this, notifyFunction, signalShowSelectedImageOverlayChanged);
  addItem( itemShowSelectedImageOverlay, QStringLiteral( "ShowSelectedImageOverlay" ) );
  KConfigCompilerSignallingItem  *itemImageOverlayMaxDimension;
  KConfigSkeleton::ItemInt  *innerItemImageOverlayMaxDimension;
  innerItemImageOverlayMaxDimension = new KConfigSkeleton::ItemInt( currentGroup(), QStringLiteral( "ImageOverlayMaxDimension" ), mImageOverlayMaxDimension, 1000 );
  itemImageOverlayMaxDimension = new KConfigCompilerSignallingItem(innerItemImageOverlayMaxDimension, this, notifyFunction, signalImageOverlayMaxDimensionChanged);
  addItem( itemImageOverlayMaxDimension, QStringLiteral( "ImageOverlayMaxDimension" ) );
  KConfigCompilerSignallingItem  *itemImageOverlayTimeout;
  KConfigSkeleton::ItemInt  *innerItemImageOverlayTimeout;
  innerItemImageOverlayTimeout = new KConfigSkeleton::ItemInt( currentGroup(), QStringLiteral( "ImageOverlayTimeout" ), mImageOverlayTimeout, 30 );
  itemImageOverlayTimeout = new KConfigCompilerSignallingItem(innerItemImageOverlayTimeout, this, notifyFunction, signalImageOverlayTimeoutChanged);
  addItem( itemImageOverlayTimeout, QStringLiteral( "ImageOverlayTimeout" ) );
  KConfigCompilerSignallingItem  *itemImageOverlayDefaultScale;
  KConfigSkeleton::ItemDouble  *innerItemImageOverlayDefaultScale;
  innerItemImageOverlayDefaultScale = new KConfigSkeleton::ItemDouble( currentGroup(), QStringLiteral( "ImageOverlayDefaultScale" ), mImageOverlayDefaultScale, 0 );
  itemImageOverlayDefaultScale = new KConfigCompilerSignallingItem(innerItemImageOverlayDefaultScale, this, notifyFunction, signalImageOverlayDefaultScaleChanged);
  addItem( itemImageOverlayDefaultScale, QStringLiteral( "ImageOverlayDefaultScale" ) );

  setCurrentGroup( QStringLiteral( "Observatory" ) );

  KConfigCompilerSignallingItem  *itemDefaultObservatoryWeatherSource;
  KConfigSkeleton::ItemString  *innerItemDefaultObservatoryWeatherSource;
  innerItemDefaultObservatoryWeatherSource = new KConfigSkeleton::ItemString( currentGroup(), QStringLiteral( "DefaultObservatoryWeatherSource" ), mDefaultObservatoryWeatherSource );
  itemDefaultObservatoryWeatherSource = new KConfigCompilerSignallingItem(innerItemDefaultObservatoryWeatherSource, this, notifyFunction, signalDefaultObservatoryWeatherSourceChanged);
  addItem( itemDefaultObservatoryWeatherSource, QStringLiteral( "DefaultObservatoryWeatherSource" ) );
  KConfigCompilerSignallingItem  *itemWarningActionsActive;
  KConfigSkeleton::ItemBool  *innerItemWarningActionsActive;
  innerItemWarningActionsActive = new KConfigSkeleton::ItemBool( currentGroup(), QStringLiteral( "warningActionsActive" ), mWarningActionsActive, true );
  itemWarningActionsActive = new KConfigCompilerSignallingItem(innerItemWarningActionsActive, this, notifyFunction, signalWarningActionsActiveChanged);
  addItem( itemWarningActionsActive, QStringLiteral( "warningActionsActive" ) );
  KConfigCompilerSignallingItem  *itemAlertActionsActive;
  KConfigSkeleton::ItemBool  *innerItemAlertActionsActive;
  innerItemAlertActionsActive = new KConfigSkeleton::ItemBool( currentGroup(), QStringLiteral( "alertActionsActive" ), mAlertActionsActive, true );
  itemAlertActionsActive = new KConfigCompilerSignallingItem(innerItemAlertActionsActive, this, notifyFunction, signalAlertActionsActiveChanged);
  addItem( itemAlertActionsActive, QStringLiteral( "alertActionsActive" ) );
  KConfigCompilerSignallingItem  *itemWeatherWarningCloseDome;
  KConfigSkeleton::ItemBool  *innerItemWeatherWarningCloseDome;
  innerItemWeatherWarningCloseDome = new KConfigSkeleton::ItemBool( currentGroup(), QStringLiteral( "weatherWarningCloseDome" ), mWeatherWarningCloseDome, false );
  itemWeatherWarningCloseDome = new KConfigCompilerSignallingItem(innerItemWeatherWarningCloseDome, this, notifyFunction, signalWeatherWarningCloseDomeChanged);
  addItem( itemWeatherWarningCloseDome, QStringLiteral( "weatherWarningCloseDome" ) );
  KConfigCompilerSignallingItem  *itemWeatherWarningCloseShutter;
  KConfigSkeleton::ItemBool  *innerItemWeatherWarningCloseShutter;
  innerItemWeatherWarningCloseShutter = new KConfigSkeleton::ItemBool( currentGroup(), QStringLiteral( "weatherWarningCloseShutter" ), mWeatherWarningCloseShutter, false );
  itemWeatherWarningCloseShutter = new KConfigCompilerSignallingItem(innerItemWeatherWarningCloseShutter, this, notifyFunction, signalWeatherWarningCloseShutterChanged);
  addItem( itemWeatherWarningCloseShutter, QStringLiteral( "weatherWarningCloseShutter" ) );
  KConfigCompilerSignallingItem  *itemWeatherWarningStopScheduler;
  KConfigSkeleton::ItemBool  *innerItemWeatherWarningStopScheduler;
  innerItemWeatherWarningStopScheduler = new KConfigSkeleton::ItemBool( currentGroup(), QStringLiteral( "weatherWarningStopScheduler" ), mWeatherWarningStopScheduler, true );
  itemWeatherWarningStopScheduler = new KConfigCompilerSignallingItem(innerItemWeatherWarningStopScheduler, this, notifyFunction, signalWeatherWarningStopSchedulerChanged);
  addItem( itemWeatherWarningStopScheduler, QStringLiteral( "weatherWarningStopScheduler" ) );
  KConfigCompilerSignallingItem  *itemWeatherWarningDelay;
  KConfigSkeleton::ItemUInt  *innerItemWeatherWarningDelay;
  innerItemWeatherWarningDelay = new KConfigSkeleton::ItemUInt( currentGroup(), QStringLiteral( "weatherWarningDelay" ), mWeatherWarningDelay, 600 );
  itemWeatherWarningDelay = new KConfigCompilerSignallingItem(innerItemWeatherWarningDelay, this, notifyFunction, signalWeatherWarningDelayChanged);
  addItem( itemWeatherWarningDelay, QStringLiteral( "weatherWarningDelay" ) );
  KConfigCompilerSignallingItem  *itemWeatherAlertCloseDome;
  KConfigSkeleton::ItemBool  *innerItemWeatherAlertCloseDome;
  innerItemWeatherAlertCloseDome = new KConfigSkeleton::ItemBool( currentGroup(), QStringLiteral( "weatherAlertCloseDome" ), mWeatherAlertCloseDome, true );
  itemWeatherAlertCloseDome = new KConfigCompilerSignallingItem(innerItemWeatherAlertCloseDome, this, notifyFunction, signalWeatherAlertCloseDomeChanged);
  addItem( itemWeatherAlertCloseDome, QStringLiteral( "weatherAlertCloseDome" ) );
  KConfigCompilerSignallingItem  *itemWeatherAlertCloseShutter;
  KConfigSkeleton::ItemBool  *innerItemWeatherAlertCloseShutter;
  innerItemWeatherAlertCloseShutter = new KConfigSkeleton::ItemBool( currentGroup(), QStringLiteral( "weatherAlertCloseShutter" ), mWeatherAlertCloseShutter, true );
  itemWeatherAlertCloseShutter = new KConfigCompilerSignallingItem(innerItemWeatherAlertCloseShutter, this, notifyFunction, signalWeatherAlertCloseShutterChanged);
  addItem( itemWeatherAlertCloseShutter, QStringLiteral( "weatherAlertCloseShutter" ) );
  KConfigCompilerSignallingItem  *itemWeatherAlertStopScheduler;
  KConfigSkeleton::ItemBool  *innerItemWeatherAlertStopScheduler;
  innerItemWeatherAlertStopScheduler = new KConfigSkeleton::ItemBool( currentGroup(), QStringLiteral( "weatherAlertStopScheduler" ), mWeatherAlertStopScheduler, true );
  itemWeatherAlertStopScheduler = new KConfigCompilerSignallingItem(innerItemWeatherAlertStopScheduler, this, notifyFunction, signalWeatherAlertStopSchedulerChanged);
  addItem( itemWeatherAlertStopScheduler, QStringLiteral( "weatherAlertStopScheduler" ) );
  KConfigCompilerSignallingItem  *itemWeatherAlertDelay;
  KConfigSkeleton::ItemUInt  *innerItemWeatherAlertDelay;
  innerItemWeatherAlertDelay = new KConfigSkeleton::ItemUInt( currentGroup(), QStringLiteral( "weatherAlertDelay" ), mWeatherAlertDelay, 30 );
  itemWeatherAlertDelay = new KConfigCompilerSignallingItem(innerItemWeatherAlertDelay, this, notifyFunction, signalWeatherAlertDelayChanged);
  addItem( itemWeatherAlertDelay, QStringLiteral( "weatherAlertDelay" ) );
  KConfigCompilerSignallingItem  *itemObservatoryStatusUseDome;
  KConfigSkeleton::ItemBool  *innerItemObservatoryStatusUseDome;
  innerItemObservatoryStatusUseDome = new KConfigSkeleton::ItemBool( currentGroup(), QStringLiteral( "observatoryStatusUseDome" ), mObservatoryStatusUseDome, true );
  itemObservatoryStatusUseDome = new KConfigCompilerSignallingItem(innerItemObservatoryStatusUseDome, this, notifyFunction, signalObservatoryStatusUseDomeChanged);
  addItem( itemObservatoryStatusUseDome, QStringLiteral( "observatoryStatusUseDome" ) );
  KConfigCompilerSignallingItem  *itemObservatoryStatusUseShutter;
  KConfigSkeleton::ItemBool  *innerItemObservatoryStatusUseShutter;
  innerItemObservatoryStatusUseShutter = new KConfigSkeleton::ItemBool( currentGroup(), QStringLiteral( "observatoryStatusUseShutter" ), mObservatoryStatusUseShutter, true );
  itemObservatoryStatusUseShutter = new KConfigCompilerSignallingItem(innerItemObservatoryStatusUseShutter, this, notifyFunction, signalObservatoryStatusUseShutterChanged);
  addItem( itemObservatoryStatusUseShutter, QStringLiteral( "observatoryStatusUseShutter" ) );
  KConfigCompilerSignallingItem  *itemObservatoryStatusUseWeather;
  KConfigSkeleton::ItemBool  *innerItemObservatoryStatusUseWeather;
  innerItemObservatoryStatusUseWeather = new KConfigSkeleton::ItemBool( currentGroup(), QStringLiteral( "observatoryStatusUseWeather" ), mObservatoryStatusUseWeather, true );
  itemObservatoryStatusUseWeather = new KConfigCompilerSignallingItem(innerItemObservatoryStatusUseWeather, this, notifyFunction, signalObservatoryStatusUseWeatherChanged);
  addItem( itemObservatoryStatusUseWeather, QStringLiteral( "observatoryStatusUseWeather" ) );
  KConfigCompilerSignallingItem  *itemWeatherAutoScaleValues;
  KConfigSkeleton::ItemBool  *innerItemWeatherAutoScaleValues;
  innerItemWeatherAutoScaleValues = new KConfigSkeleton::ItemBool( currentGroup(), QStringLiteral( "weatherAutoScaleValues" ), mWeatherAutoScaleValues, true );
  itemWeatherAutoScaleValues = new KConfigCompilerSignallingItem(innerItemWeatherAutoScaleValues, this, notifyFunction, signalWeatherAutoScaleValuesChanged);
  addItem( itemWeatherAutoScaleValues, QStringLiteral( "weatherAutoScaleValues" ) );

  setCurrentGroup( QStringLiteral( "ASTAP" ) );

  KConfigCompilerSignallingItem  *itemASTAPExecutable;
  KConfigSkeleton::ItemString  *innerItemASTAPExecutable;
  innerItemASTAPExecutable = new KConfigSkeleton::ItemString( currentGroup(), QStringLiteral( "ASTAPExecutable" ), mASTAPExecutable, KSUtils::getDefaultPath("ASTAP") );
  itemASTAPExecutable = new KConfigCompilerSignallingItem(innerItemASTAPExecutable, this, notifyFunction, signalASTAPExecutableChanged);
  addItem( itemASTAPExecutable, QStringLiteral( "ASTAPExecutable" ) );
  KConfigCompilerSignallingItem  *itemASTAPDownSample;
  KConfigSkeleton::ItemBool  *innerItemASTAPDownSample;
  innerItemASTAPDownSample = new KConfigSkeleton::ItemBool( currentGroup(), QStringLiteral( "ASTAPDownSample" ), mASTAPDownSample, false );
  itemASTAPDownSample = new KConfigCompilerSignallingItem(innerItemASTAPDownSample, this, notifyFunction, signalASTAPDownSampleChanged);
  addItem( itemASTAPDownSample, QStringLiteral( "ASTAPDownSample" ) );
  KConfigCompilerSignallingItem  *itemASTAPDownSampleValue;
  KConfigSkeleton::ItemDouble  *innerItemASTAPDownSampleValue;
  innerItemASTAPDownSampleValue = new KConfigSkeleton::ItemDouble( currentGroup(), QStringLiteral( "ASTAPDownSampleValue" ), mASTAPDownSampleValue, 0 );
  itemASTAPDownSampleValue = new KConfigCompilerSignallingItem(innerItemASTAPDownSampleValue, this, notifyFunction, signalASTAPDownSampleValueChanged);
  addItem( itemASTAPDownSampleValue, QStringLiteral( "ASTAPDownSampleValue" ) );
  KConfigCompilerSignallingItem  *itemASTAPSearchRadius;
  KConfigSkeleton::ItemBool  *innerItemASTAPSearchRadius;
  innerItemASTAPSearchRadius = new KConfigSkeleton::ItemBool( currentGroup(), QStringLiteral( "ASTAPSearchRadius" ), mASTAPSearchRadius, true );
  itemASTAPSearchRadius = new KConfigCompilerSignallingItem(innerItemASTAPSearchRadius, this, notifyFunction, signalASTAPSearchRadiusChanged);
  addItem( itemASTAPSearchRadius, QStringLiteral( "ASTAPSearchRadius" ) );
  KConfigCompilerSignallingItem  *itemASTAPSearchRadiusValue;
  KConfigSkeleton::ItemDouble  *innerItemASTAPSearchRadiusValue;
  innerItemASTAPSearchRadiusValue = new KConfigSkeleton::ItemDouble( currentGroup(), QStringLiteral( "ASTAPSearchRadiusValue" ), mASTAPSearchRadiusValue, 30 );
  itemASTAPSearchRadiusValue = new KConfigCompilerSignallingItem(innerItemASTAPSearchRadiusValue, this, notifyFunction, signalASTAPSearchRadiusValueChanged);
  addItem( itemASTAPSearchRadiusValue, QStringLiteral( "ASTAPSearchRadiusValue" ) );
  KConfigCompilerSignallingItem  *itemASTAPUpdateFITS;
  KConfigSkeleton::ItemBool  *innerItemASTAPUpdateFITS;
  innerItemASTAPUpdateFITS = new KConfigSkeleton::ItemBool( currentGroup(), QStringLiteral( "ASTAPUpdateFITS" ), mASTAPUpdateFITS, false );
  itemASTAPUpdateFITS = new KConfigCompilerSignallingItem(innerItemASTAPUpdateFITS, this, notifyFunction, signalASTAPUpdateFITSChanged);
  addItem( itemASTAPUpdateFITS, QStringLiteral( "ASTAPUpdateFITS" ) );
  KConfigCompilerSignallingItem  *itemASTAPLargeSearchWindow;
  KConfigSkeleton::ItemBool  *innerItemASTAPLargeSearchWindow;
  innerItemASTAPLargeSearchWindow = new KConfigSkeleton::ItemBool( currentGroup(), QStringLiteral( "ASTAPLargeSearchWindow" ), mASTAPLargeSearchWindow, false );
  itemASTAPLargeSearchWindow = new KConfigCompilerSignallingItem(innerItemASTAPLargeSearchWindow, this, notifyFunction, signalASTAPLargeSearchWindowChanged);
  addItem( itemASTAPLargeSearchWindow, QStringLiteral( "ASTAPLargeSearchWindow" ) );

  setCurrentGroup( QStringLiteral( "Mosaic" ) );

  KConfigCompilerSignallingItem  *itemMosaicTransparencyAuto;
  KConfigSkeleton::ItemBool  *innerItemMosaicTransparencyAuto;
  innerItemMosaicTransparencyAuto = new KConfigSkeleton::ItemBool( currentGroup(), QStringLiteral( "MosaicTransparencyAuto" ), mMosaicTransparencyAuto, true );
  itemMosaicTransparencyAuto = new KConfigCompilerSignallingItem(innerItemMosaicTransparencyAuto, this, notifyFunction, signalMosaicTransparencyAutoChanged);
  addItem( itemMosaicTransparencyAuto, QStringLiteral( "MosaicTransparencyAuto" ) );
  KConfigCompilerSignallingItem  *itemMosaicTransparencyLevel;
  KConfigSkeleton::ItemDouble  *innerItemMosaicTransparencyLevel;
  innerItemMosaicTransparencyLevel = new KConfigSkeleton::ItemDouble( currentGroup(), QStringLiteral( "MosaicTransparencyLevel" ), mMosaicTransparencyLevel, 50 );
  itemMosaicTransparencyLevel = new KConfigCompilerSignallingItem(innerItemMosaicTransparencyLevel, this, notifyFunction, signalMosaicTransparencyLevelChanged);
  addItem( itemMosaicTransparencyLevel, QStringLiteral( "MosaicTransparencyLevel" ) );

  setCurrentGroup( QStringLiteral( "MCP" ) );

  KConfigCompilerSignallingItem  *itemMCPEnabled;
  KConfigSkeleton::ItemBool  *innerItemMCPEnabled;
  innerItemMCPEnabled = new KConfigSkeleton::ItemBool( currentGroup(), QStringLiteral( "MCPEnabled" ), mMCPEnabled, false );
  itemMCPEnabled = new KConfigCompilerSignallingItem(innerItemMCPEnabled, this, notifyFunction, signalMCPEnabledChanged);
  addItem( itemMCPEnabled, QStringLiteral( "MCPEnabled" ) );
  KConfigCompilerSignallingItem  *itemMCPPort;
  KConfigSkeleton::ItemUInt  *innerItemMCPPort;
  innerItemMCPPort = new KConfigSkeleton::ItemUInt( currentGroup(), QStringLiteral( "MCPPort" ), mMCPPort, 8765 );
  itemMCPPort = new KConfigCompilerSignallingItem(innerItemMCPPort, this, notifyFunction, signalMCPPortChanged);
  addItem( itemMCPPort, QStringLiteral( "MCPPort" ) );
  KConfigCompilerSignallingItem  *itemMCPReadOnlyMode;
  KConfigSkeleton::ItemBool  *innerItemMCPReadOnlyMode;
  innerItemMCPReadOnlyMode = new KConfigSkeleton::ItemBool( currentGroup(), QStringLiteral( "MCPReadOnlyMode" ), mMCPReadOnlyMode, false );
  itemMCPReadOnlyMode = new KConfigCompilerSignallingItem(innerItemMCPReadOnlyMode, this, notifyFunction, signalMCPReadOnlyModeChanged);
  addItem( itemMCPReadOnlyMode, QStringLiteral( "MCPReadOnlyMode" ) );
  KConfigCompilerSignallingItem  *itemMCPDisabledTools;
  KConfigSkeleton::ItemStringList  *innerItemMCPDisabledTools;
  innerItemMCPDisabledTools = new KConfigSkeleton::ItemStringList( currentGroup(), QStringLiteral( "MCPDisabledTools" ), mMCPDisabledTools );
  itemMCPDisabledTools = new KConfigCompilerSignallingItem(innerItemMCPDisabledTools, this, notifyFunction, signalMCPDisabledToolsChanged);
  addItem( itemMCPDisabledTools, QStringLiteral( "MCPDisabledTools" ) );
}

Options::~Options()
{
  if (s_globalOptions.exists() && !s_globalOptions.isDestroyed()) {
    s_globalOptions()->q = nullptr;
  }
}


void Options::itemChanged(quint64 signalFlag) {

  switch (signalFlag) {
  case signalPositionTimeBoxChanged:
    Q_EMIT PositionTimeBoxChanged();
    break;
  case signalPositionFocusBoxChanged:
    Q_EMIT PositionFocusBoxChanged();
    break;
  case signalPositionGeoBoxChanged:
    Q_EMIT PositionGeoBoxChanged();
    break;
  case signalShadeTimeBoxChanged:
    Q_EMIT ShadeTimeBoxChanged();
    break;
  case signalShadeFocusBoxChanged:
    Q_EMIT ShadeFocusBoxChanged();
    break;
  case signalShadeGeoBoxChanged:
    Q_EMIT ShadeGeoBoxChanged();
    break;
  case signalShowInfoBoxesChanged:
    Q_EMIT ShowInfoBoxesChanged();
    break;
  case signalShowTimeBoxChanged:
    Q_EMIT ShowTimeBoxChanged();
    break;
  case signalShowFocusBoxChanged:
    Q_EMIT ShowFocusBoxChanged();
    break;
  case signalShowGeoBoxChanged:
    Q_EMIT ShowGeoBoxChanged();
    break;
  case signalStickyTimeBoxChanged:
    Q_EMIT StickyTimeBoxChanged();
    break;
  case signalStickyFocusBoxChanged:
    Q_EMIT StickyFocusBoxChanged();
    break;
  case signalStickyGeoBoxChanged:
    Q_EMIT StickyGeoBoxChanged();
    break;
  case signalShowStatusBarChanged:
    Q_EMIT ShowStatusBarChanged();
    break;
  case signalShowAltAzFieldChanged:
    Q_EMIT ShowAltAzFieldChanged();
    break;
  case signalShowRADecFieldChanged:
    Q_EMIT ShowRADecFieldChanged();
    break;
  case signalShowJ2000RADecFieldChanged:
    Q_EMIT ShowJ2000RADecFieldChanged();
    break;
  case signalShowSensorFOVChanged:
    Q_EMIT ShowSensorFOVChanged();
    break;
  case signalWindowWidthChanged:
    Q_EMIT WindowWidthChanged();
    break;
  case signalWindowHeightChanged:
    Q_EMIT WindowHeightChanged();
    break;
  case signalKStarsGeometryChanged:
    Q_EMIT KStarsGeometryChanged();
    break;
  case signalRunStartupWizardChanged:
    Q_EMIT RunStartupWizardChanged();
    break;
  case signalCurrentThemeChanged:
    Q_EMIT CurrentThemeChanged();
    break;
  case signalCatalogFileChanged:
    Q_EMIT CatalogFileChanged();
    break;
  case signalShowCatalogChanged:
    Q_EMIT ShowCatalogChanged();
    break;
  case signalShowCatalogNamesChanged:
    Q_EMIT ShowCatalogNamesChanged();
    break;
  case signalResolveNamesOnlineChanged:
    Q_EMIT ResolveNamesOnlineChanged();
    break;
  case signalDSOCachePercentageChanged:
    Q_EMIT DSOCachePercentageChanged();
    break;
  case signalDSOMinZoomFactorChanged:
    Q_EMIT DSOMinZoomFactorChanged();
    break;
  case signalDSOCatalogFilenameChanged:
    Q_EMIT DSOCatalogFilenameChanged();
    break;
  case signalDSODefaultCatalogFilenameChanged:
    Q_EMIT DSODefaultCatalogFilenameChanged();
    break;
  case signalINDIWindowWidthChanged:
    Q_EMIT INDIWindowWidthChanged();
    break;
  case signalINDIWindowHeightChanged:
    Q_EMIT INDIWindowHeightChanged();
    break;
  case signalINDIWindowGeometryChanged:
    Q_EMIT INDIWindowGeometryChanged();
    break;
  case signalUseGeographicUpdateChanged:
    Q_EMIT useGeographicUpdateChanged();
    break;
  case signalUseTimeUpdateChanged:
    Q_EMIT useTimeUpdateChanged();
    break;
  case signalIndependentWindowINDIChanged:
    Q_EMIT independentWindowINDIChanged();
    break;
  case signalShowTargetCrosshairChanged:
    Q_EMIT showTargetCrosshairChanged();
    break;
  case signalShowINDIMessagesChanged:
    Q_EMIT showINDIMessagesChanged();
    break;
  case signalShowINDIwindowInitiallyChanged:
    Q_EMIT showINDIwindowInitiallyChanged();
    break;
  case signalMaxFocusFrameFilesChanged:
    Q_EMIT maxFocusFrameFilesChanged();
    break;
  case signalMessageNotificationINDIChanged:
    Q_EMIT messageNotificationINDIChanged();
    break;
  case signalTimeSourceChanged:
    Q_EMIT timeSourceChanged();
    break;
  case signalLocationSourceChanged:
    Q_EMIT locationSourceChanged();
    break;
  case signalUseExternalSkyMapChanged:
    Q_EMIT useExternalSkyMapChanged();
    break;
  case signalFitsDirChanged:
    Q_EMIT fitsDirChanged();
    break;
  case signalServerTransferBufferSizeChanged:
    Q_EMIT serverTransferBufferSizeChanged();
    break;
  case signalServerPortStartChanged:
    Q_EMIT serverPortStartChanged();
    break;
  case signalServerPortEndChanged:
    Q_EMIT serverPortEndChanged();
    break;
  case signalIndiServerChanged:
    Q_EMIT indiServerChanged();
    break;
  case signalIndiServerIsInternalChanged:
    Q_EMIT indiServerIsInternalChanged();
    break;
  case signalIndiDriversDirChanged:
    Q_EMIT indiDriversDirChanged();
    break;
  case signalIndiDriversAreInternalChanged:
    Q_EMIT indiDriversAreInternalChanged();
    break;
  case signalStreamWindowWidthChanged:
    Q_EMIT streamWindowWidthChanged();
    break;
  case signalStreamWindowHeightChanged:
    Q_EMIT streamWindowHeightChanged();
    break;
  case signalINDIMountLoggingChanged:
    Q_EMIT INDIMountLoggingChanged();
    break;
  case signalINDIFocuserLoggingChanged:
    Q_EMIT INDIFocuserLoggingChanged();
    break;
  case signalINDICCDLoggingChanged:
    Q_EMIT INDICCDLoggingChanged();
    break;
  case signalINDIFilterWheelLoggingChanged:
    Q_EMIT INDIFilterWheelLoggingChanged();
    break;
  case signalINDIDomeLoggingChanged:
    Q_EMIT INDIDomeLoggingChanged();
    break;
  case signalINDIDetectorLoggingChanged:
    Q_EMIT INDIDetectorLoggingChanged();
    break;
  case signalINDIWeatherLoggingChanged:
    Q_EMIT INDIWeatherLoggingChanged();
    break;
  case signalINDIAuxiliaryLoggingChanged:
    Q_EMIT INDIAuxiliaryLoggingChanged();
    break;
  case signalINDIRotatorLoggingChanged:
    Q_EMIT INDIRotatorLoggingChanged();
    break;
  case signalINDIGPSLoggingChanged:
    Q_EMIT INDIGPSLoggingChanged();
    break;
  case signalINDIAOLoggingChanged:
    Q_EMIT INDIAOLoggingChanged();
    break;
  case signalCityNameChanged:
    Q_EMIT CityNameChanged();
    break;
  case signalProvinceNameChanged:
    Q_EMIT ProvinceNameChanged();
    break;
  case signalCountryNameChanged:
    Q_EMIT CountryNameChanged();
    break;
  case signalLongitudeChanged:
    Q_EMIT LongitudeChanged();
    break;
  case signalLatitudeChanged:
    Q_EMIT LatitudeChanged();
    break;
  case signalElevationChanged:
    Q_EMIT ElevationChanged();
    break;
  case signalTimeZoneChanged:
    Q_EMIT TimeZoneChanged();
    break;
  case signalDSTChanged:
    Q_EMIT DSTChanged();
    break;
  case signalUseAnimatedSlewingChanged:
    Q_EMIT UseAnimatedSlewingChanged();
    break;
  case signalLeftClickSelectsObjectChanged:
    Q_EMIT LeftClickSelectsObjectChanged();
    break;
  case signalDefaultCursorChanged:
    Q_EMIT DefaultCursorChanged();
    break;
  case signalFOVNamesChanged:
    Q_EMIT FOVNamesChanged();
    break;
  case signalFadePlanetTrailsChanged:
    Q_EMIT FadePlanetTrailsChanged();
    break;
  case signalFocusRAChanged:
    Q_EMIT FocusRAChanged();
    break;
  case signalFocusDecChanged:
    Q_EMIT FocusDecChanged();
    break;
  case signalFocusObjectChanged:
    Q_EMIT FocusObjectChanged();
    break;
  case signalIsTrackingChanged:
    Q_EMIT IsTrackingChanged();
    break;
  case signalHideOnSlewChanged:
    Q_EMIT HideOnSlewChanged();
    break;
  case signalHideCBoundsChanged:
    Q_EMIT HideCBoundsChanged();
    break;
  case signalHideCLinesChanged:
    Q_EMIT HideCLinesChanged();
    break;
  case signalSkyCultureChanged:
    Q_EMIT SkyCultureChanged();
    break;
  case signalHideCNamesChanged:
    Q_EMIT HideCNamesChanged();
    break;
  case signalHideGridsChanged:
    Q_EMIT HideGridsChanged();
    break;
  case signalHideMilkyWayChanged:
    Q_EMIT HideMilkyWayChanged();
    break;
  case signalHideOtherChanged:
    Q_EMIT HideOtherChanged();
    break;
  case signalHidePlanetsChanged:
    Q_EMIT HidePlanetsChanged();
    break;
  case signalHideStarsChanged:
    Q_EMIT HideStarsChanged();
    break;
  case signalHideLabelsChanged:
    Q_EMIT HideLabelsChanged();
    break;
  case signalShowAsteroidsChanged:
    Q_EMIT ShowAsteroidsChanged();
    break;
  case signalShowAsteroidNamesChanged:
    Q_EMIT ShowAsteroidNamesChanged();
    break;
  case signalOrbitalElementsAutoUpdateChanged:
    Q_EMIT OrbitalElementsAutoUpdateChanged();
    break;
  case signalShowCometsChanged:
    Q_EMIT ShowCometsChanged();
    break;
  case signalShowCometComasChanged:
    Q_EMIT ShowCometComasChanged();
    break;
  case signalShowCometNamesChanged:
    Q_EMIT ShowCometNamesChanged();
    break;
  case signalShowSupernovaeChanged:
    Q_EMIT ShowSupernovaeChanged();
    break;
  case signalShowSupernovaNamesChanged:
    Q_EMIT ShowSupernovaNamesChanged();
    break;
  case signalMagnitudeLimitShowSupernovaeChanged:
    Q_EMIT MagnitudeLimitShowSupernovaeChanged();
    break;
  case signalSupernovaDetectionAgeChanged:
    Q_EMIT SupernovaDetectionAgeChanged();
    break;
  case signalSupernovaDownloadUrlChanged:
    Q_EMIT SupernovaDownloadUrlChanged();
    break;
  case signalLimitSupernovaeByZoomChanged:
    Q_EMIT LimitSupernovaeByZoomChanged();
    break;
  case signalSupernovaeHostOnlyChanged:
    Q_EMIT SupernovaeHostOnlyChanged();
    break;
  case signalSupernovaeClassifiedOnlyChanged:
    Q_EMIT SupernovaeClassifiedOnlyChanged();
    break;
  case signalShowSupernovaAlertsChanged:
    Q_EMIT ShowSupernovaAlertsChanged();
    break;
  case signalMagnitudeLimitAlertSupernovaeChanged:
    Q_EMIT MagnitudeLimitAlertSupernovaeChanged();
    break;
  case signalShowCBoundsChanged:
    Q_EMIT ShowCBoundsChanged();
    break;
  case signalShowHighlightedCBoundChanged:
    Q_EMIT ShowHighlightedCBoundChanged();
    break;
  case signalShowCLinesChanged:
    Q_EMIT ShowCLinesChanged();
    break;
  case signalShowConstellationArtChanged:
    Q_EMIT ShowConstellationArtChanged();
    break;
  case signalShowCNamesChanged:
    Q_EMIT ShowCNamesChanged();
    break;
  case signalShowDeepSkyChanged:
    Q_EMIT ShowDeepSkyChanged();
    break;
  case signalShowEclipticChanged:
    Q_EMIT ShowEclipticChanged();
    break;
  case signalShowEquatorChanged:
    Q_EMIT ShowEquatorChanged();
    break;
  case signalAutoSelectGridChanged:
    Q_EMIT AutoSelectGridChanged();
    break;
  case signalShowEquatorialGridChanged:
    Q_EMIT ShowEquatorialGridChanged();
    break;
  case signalShowHorizontalGridChanged:
    Q_EMIT ShowHorizontalGridChanged();
    break;
  case signalShowLocalMeridianChanged:
    Q_EMIT ShowLocalMeridianChanged();
    break;
  case signalShowGroundChanged:
    Q_EMIT ShowGroundChanged();
    break;
  case signalShowHorizonChanged:
    Q_EMIT ShowHorizonChanged();
    break;
  case signalShowFlagsChanged:
    Q_EMIT ShowFlagsChanged();
    break;
  case signalSimulateDaytimeChanged:
    Q_EMIT SimulateDaytimeChanged();
    break;
  case signalShowOtherChanged:
    Q_EMIT ShowOtherChanged();
    break;
  case signalShowMilkyWayChanged:
    Q_EMIT ShowMilkyWayChanged();
    break;
  case signalFillMilkyWayChanged:
    Q_EMIT FillMilkyWayChanged();
    break;
  case signalShowSolarSystemChanged:
    Q_EMIT ShowSolarSystemChanged();
    break;
  case signalShowPlanetImagesChanged:
    Q_EMIT ShowPlanetImagesChanged();
    break;
  case signalShowPlanetNamesChanged:
    Q_EMIT ShowPlanetNamesChanged();
    break;
  case signalShowSunChanged:
    Q_EMIT ShowSunChanged();
    break;
  case signalSunScaleChanged:
    Q_EMIT SunScaleChanged();
    break;
  case signalShowMoonChanged:
    Q_EMIT ShowMoonChanged();
    break;
  case signalMoonScaleChanged:
    Q_EMIT MoonScaleChanged();
    break;
  case signalShowMercuryChanged:
    Q_EMIT ShowMercuryChanged();
    break;
  case signalShowVenusChanged:
    Q_EMIT ShowVenusChanged();
    break;
  case signalShowMarsChanged:
    Q_EMIT ShowMarsChanged();
    break;
  case signalShowJupiterChanged:
    Q_EMIT ShowJupiterChanged();
    break;
  case signalShowSaturnChanged:
    Q_EMIT ShowSaturnChanged();
    break;
  case signalShowUranusChanged:
    Q_EMIT ShowUranusChanged();
    break;
  case signalShowNeptuneChanged:
    Q_EMIT ShowNeptuneChanged();
    break;
  case signalShowPlutoChanged:
    Q_EMIT ShowPlutoChanged();
    break;
  case signalShowStarsChanged:
    Q_EMIT ShowStarsChanged();
    break;
  case signalShowStarMagnitudesChanged:
    Q_EMIT ShowStarMagnitudesChanged();
    break;
  case signalShowStarsOverHIPSChanged:
    Q_EMIT ShowStarsOverHIPSChanged();
    break;
  case signalShowStarNamesChanged:
    Q_EMIT ShowStarNamesChanged();
    break;
  case signalShowDeepSkyMagnitudesChanged:
    Q_EMIT ShowDeepSkyMagnitudesChanged();
    break;
  case signalShowDeepSkyNamesChanged:
    Q_EMIT ShowDeepSkyNamesChanged();
    break;
  case signalShowMosaicPanelChanged:
    Q_EMIT ShowMosaicPanelChanged();
    break;
  case signalSlewTimeScaleChanged:
    Q_EMIT SlewTimeScaleChanged();
    break;
  case signalBoxBGModeChanged:
    Q_EMIT BoxBGModeChanged();
    break;
  case signalProjectionChanged:
    Q_EMIT ProjectionChanged();
    break;
  case signalUseAbbrevConstellNamesChanged:
    Q_EMIT UseAbbrevConstellNamesChanged();
    break;
  case signalUseLatinConstellNamesChanged:
    Q_EMIT UseLatinConstellNamesChanged();
    break;
  case signalUseLocalConstellNamesChanged:
    Q_EMIT UseLocalConstellNamesChanged();
    break;
  case signalUseAltAzChanged:
    Q_EMIT UseAltAzChanged();
    break;
  case signalUseAutoLabelChanged:
    Q_EMIT UseAutoLabelChanged();
    break;
  case signalUseAutoTrailChanged:
    Q_EMIT UseAutoTrailChanged();
    break;
  case signalUseHoverLabelChanged:
    Q_EMIT UseHoverLabelChanged();
    break;
  case signalUseRefractionChanged:
    Q_EMIT UseRefractionChanged();
    break;
  case signalUseRelativisticChanged:
    Q_EMIT UseRelativisticChanged();
    break;
  case signalUseAntialiasChanged:
    Q_EMIT UseAntialiasChanged();
    break;
  case signalZoomFactorChanged:
    Q_EMIT ZoomFactorChanged();
    break;
  case signalSkyRotationChanged:
    Q_EMIT SkyRotationChanged();
    break;
  case signalMirrorSkyMapChanged:
    Q_EMIT MirrorSkyMapChanged();
    break;
  case signalErectObserverCorrectionChanged:
    Q_EMIT ErectObserverCorrectionChanged();
    break;
  case signalZoomScrollFactorChanged:
    Q_EMIT ZoomScrollFactorChanged();
    break;
  case signalMagLimitAsteroidChanged:
    Q_EMIT MagLimitAsteroidChanged();
    break;
  case signalMagLimitAsteroidDownloadChanged:
    Q_EMIT MagLimitAsteroidDownloadChanged();
    break;
  case signalAsteroidLabelDensityChanged:
    Q_EMIT AsteroidLabelDensityChanged();
    break;
  case signalMagLimitDrawDeepSkyChanged:
    Q_EMIT MagLimitDrawDeepSkyChanged();
    break;
  case signalMagLimitDrawDeepSkyZoomOutChanged:
    Q_EMIT MagLimitDrawDeepSkyZoomOutChanged();
    break;
  case signalShowUnknownMagObjectsChanged:
    Q_EMIT ShowUnknownMagObjectsChanged();
    break;
  case signalShowInlineImagesChanged:
    Q_EMIT ShowInlineImagesChanged();
    break;
  case signalStarDensityChanged:
    Q_EMIT StarDensityChanged();
    break;
  case signalMagLimitHideStarChanged:
    Q_EMIT MagLimitHideStarChanged();
    break;
  case signalStarLabelDensityChanged:
    Q_EMIT StarLabelDensityChanged();
    break;
  case signalDeepSkyLabelDensityChanged:
    Q_EMIT DeepSkyLabelDensityChanged();
    break;
  case signalDeepSkyLongLabelsChanged:
    Q_EMIT DeepSkyLongLabelsChanged();
    break;
  case signalLabelFontScalingChanged:
    Q_EMIT LabelFontScalingChanged();
    break;
  case signalMaxRadCometNameChanged:
    Q_EMIT MaxRadCometNameChanged();
    break;
  case signalUseGLChanged:
    Q_EMIT UseGLChanged();
    break;
  case signalRunClockChanged:
    Q_EMIT RunClockChanged();
    break;
  case signalImagingPlannerAcceptOpenClusterChanged:
    Q_EMIT ImagingPlannerAcceptOpenClusterChanged();
    break;
  case signalImagingPlannerAcceptNebulaChanged:
    Q_EMIT ImagingPlannerAcceptNebulaChanged();
    break;
  case signalImagingPlannerAcceptGlobularClusterChanged:
    Q_EMIT ImagingPlannerAcceptGlobularClusterChanged();
    break;
  case signalImagingPlannerAcceptPlanetaryChanged:
    Q_EMIT ImagingPlannerAcceptPlanetaryChanged();
    break;
  case signalImagingPlannerAcceptSupernovaRemnantChanged:
    Q_EMIT ImagingPlannerAcceptSupernovaRemnantChanged();
    break;
  case signalImagingPlannerAcceptGalaxyChanged:
    Q_EMIT ImagingPlannerAcceptGalaxyChanged();
    break;
  case signalImagingPlannerAcceptGalaxyClusterChanged:
    Q_EMIT ImagingPlannerAcceptGalaxyClusterChanged();
    break;
  case signalImagingPlannerAcceptDarkNebulaChanged:
    Q_EMIT ImagingPlannerAcceptDarkNebulaChanged();
    break;
  case signalImagingPlannerAcceptOtherChanged:
    Q_EMIT ImagingPlannerAcceptOtherChanged();
    break;
  case signalAstrobinAwardChanged:
    Q_EMIT AstrobinAwardChanged();
    break;
  case signalAstrobinMinRadiusChanged:
    Q_EMIT AstrobinMinRadiusChanged();
    break;
  case signalAstrobinMaxRadiusChanged:
    Q_EMIT AstrobinMaxRadiusChanged();
    break;
  case signalImagingPlannerUseArtificialHorizonChanged:
    Q_EMIT ImagingPlannerUseArtificialHorizonChanged();
    break;
  case signalImagingPlannerMinHoursChanged:
    Q_EMIT ImagingPlannerMinHoursChanged();
    break;
  case signalImagingPlannerMinAltitudeChanged:
    Q_EMIT ImagingPlannerMinAltitudeChanged();
    break;
  case signalImagingPlannerMinMoonSeparationChanged:
    Q_EMIT ImagingPlannerMinMoonSeparationChanged();
    break;
  case signalImagingPlannerMaxMoonAltitudeChanged:
    Q_EMIT ImagingPlannerMaxMoonAltitudeChanged();
    break;
  case signalImagingPlannerShowPickedChanged:
    Q_EMIT ImagingPlannerShowPickedChanged();
    break;
  case signalImagingPlannerShowNotPickedChanged:
    Q_EMIT ImagingPlannerShowNotPickedChanged();
    break;
  case signalImagingPlannerDontCarePickedChanged:
    Q_EMIT ImagingPlannerDontCarePickedChanged();
    break;
  case signalImagingPlannerShowKeywordChanged:
    Q_EMIT ImagingPlannerShowKeywordChanged();
    break;
  case signalImagingPlannerShowNotKeywordChanged:
    Q_EMIT ImagingPlannerShowNotKeywordChanged();
    break;
  case signalImagingPlannerDontCareKeywordChanged:
    Q_EMIT ImagingPlannerDontCareKeywordChanged();
    break;
  case signalImagingPlannerKeywordChanged:
    Q_EMIT ImagingPlannerKeywordChanged();
    break;
  case signalImagingPlannerShowImagedChanged:
    Q_EMIT ImagingPlannerShowImagedChanged();
    break;
  case signalImagingPlannerShowNotImagedChanged:
    Q_EMIT ImagingPlannerShowNotImagedChanged();
    break;
  case signalImagingPlannerDontCareImagedChanged:
    Q_EMIT ImagingPlannerDontCareImagedChanged();
    break;
  case signalImagingPlannerShowAddedChanged:
    Q_EMIT ImagingPlannerShowAddedChanged();
    break;
  case signalImagingPlannerShowNotAddedChanged:
    Q_EMIT ImagingPlannerShowNotAddedChanged();
    break;
  case signalImagingPlannerDontCareAddedChanged:
    Q_EMIT ImagingPlannerDontCareAddedChanged();
    break;
  case signalImagingPlannerShowIgnoredChanged:
    Q_EMIT ImagingPlannerShowIgnoredChanged();
    break;
  case signalImagingPlannerShowNotIgnoredChanged:
    Q_EMIT ImagingPlannerShowNotIgnoredChanged();
    break;
  case signalImagingPlannerDontCareIgnoredChanged:
    Q_EMIT ImagingPlannerDontCareIgnoredChanged();
    break;
  case signalImagingPlannerHideAstrobinDetailsChanged:
    Q_EMIT ImagingPlannerHideAstrobinDetailsChanged();
    break;
  case signalImagingPlannerHideFiltersChanged:
    Q_EMIT ImagingPlannerHideFiltersChanged();
    break;
  case signalImagingPlannerHideImageChanged:
    Q_EMIT ImagingPlannerHideImageChanged();
    break;
  case signalImagingPlannerHideAltitudeGraphChanged:
    Q_EMIT ImagingPlannerHideAltitudeGraphChanged();
    break;
  case signalImagingPlannerCatalogPathChanged:
    Q_EMIT ImagingPlannerCatalogPathChanged();
    break;
  case signalImagingPlannerCenterOnSkyMapChanged:
    Q_EMIT ImagingPlannerCenterOnSkyMapChanged();
    break;
  case signalImagingPlannerIndependentWindowChanged:
    Q_EMIT ImagingPlannerIndependentWindowChanged();
    break;
  case signalImagingPlannerStartSolvingImmediatelyChanged:
    Q_EMIT ImagingPlannerStartSolvingImmediatelyChanged();
    break;
  case signalObsListSymbolChanged:
    Q_EMIT ObsListSymbolChanged();
    break;
  case signalObsListTextChanged:
    Q_EMIT ObsListTextChanged();
    break;
  case signalObsListPreferDSSChanged:
    Q_EMIT ObsListPreferDSSChanged();
    break;
  case signalObsListPreferSDSSChanged:
    Q_EMIT ObsListPreferSDSSChanged();
    break;
  case signalObsListDemoteHoleChanged:
    Q_EMIT ObsListDemoteHoleChanged();
    break;
  case signalObsListHoleSizeChanged:
    Q_EMIT ObsListHoleSizeChanged();
    break;
  case signalObsListCoverageChanged:
    Q_EMIT ObsListCoverageChanged();
    break;
  case signalColorSchemeFileChanged:
    Q_EMIT ColorSchemeFileChanged();
    break;
  case signalStarColorModeChanged:
    Q_EMIT StarColorModeChanged();
    break;
  case signalStarColorIntensityChanged:
    Q_EMIT StarColorIntensityChanged();
    break;
  case signalDomeSlitInvertedChanged:
    Q_EMIT DomeSlitInvertedChanged();
    break;
  case signalAngularRulerColorChanged:
    Q_EMIT AngularRulerColorChanged();
    break;
  case signalBoxBGColorChanged:
    Q_EMIT BoxBGColorChanged();
    break;
  case signalBoxGrabColorChanged:
    Q_EMIT BoxGrabColorChanged();
    break;
  case signalBoxTextColorChanged:
    Q_EMIT BoxTextColorChanged();
    break;
  case signalCBoundColorChanged:
    Q_EMIT CBoundColorChanged();
    break;
  case signalCBoundHighColorChanged:
    Q_EMIT CBoundHighColorChanged();
    break;
  case signalCLineColorChanged:
    Q_EMIT CLineColorChanged();
    break;
  case signalCNameColorChanged:
    Q_EMIT CNameColorChanged();
    break;
  case signalCompassColorChanged:
    Q_EMIT CompassColorChanged();
    break;
  case signalEclipticColorChanged:
    Q_EMIT EclipticColorChanged();
    break;
  case signalEquatorColorChanged:
    Q_EMIT EquatorColorChanged();
    break;
  case signalEquatorialGridColorChanged:
    Q_EMIT EquatorialGridColorChanged();
    break;
  case signalHorizontalGridColorChanged:
    Q_EMIT HorizontalGridColorChanged();
    break;
  case signalSpecialObjectColorChanged:
    Q_EMIT SpecialObjectColorChanged();
    break;
  case signalHorizonColorChanged:
    Q_EMIT HorizonColorChanged();
    break;
  case signalLocalMeridianColorChanged:
    Q_EMIT LocalMeridianColorChanged();
    break;
  case signalMilkyWayWColorChanged:
    Q_EMIT MilkyWayWColorChanged();
    break;
  case signalStarNameColorChanged:
    Q_EMIT StarNameColorChanged();
    break;
  case signalDeepSkyNameColorChanged:
    Q_EMIT DeepSkyNameColorChanged();
    break;
  case signalPlanetNameColorChanged:
    Q_EMIT PlanetNameColorChanged();
    break;
  case signalPlanetTrailColorChanged:
    Q_EMIT PlanetTrailColorChanged();
    break;
  case signalSkyColorChanged:
    Q_EMIT SkyColorChanged();
    break;
  case signalSkyColorDaytimeChanged:
    Q_EMIT SkyColorDaytimeChanged();
    break;
  case signalArtificialHorizonColorChanged:
    Q_EMIT ArtificialHorizonColorChanged();
    break;
  case signalTelescopeTargetColorChanged:
    Q_EMIT TelescopeTargetColorChanged();
    break;
  case signalVisibleSatColorChanged:
    Q_EMIT VisibleSatColorChanged();
    break;
  case signalSatColorChanged:
    Q_EMIT SatColorChanged();
    break;
  case signalSatLabelColorChanged:
    Q_EMIT SatLabelColorChanged();
    break;
  case signalSupernovaColorChanged:
    Q_EMIT SupernovaColorChanged();
    break;
  case signalAsteroidColorChanged:
    Q_EMIT AsteroidColorChanged();
    break;
  case signalUserLabelColorChanged:
    Q_EMIT UserLabelColorChanged();
    break;
  case signalRAGuideColorChanged:
    Q_EMIT RAGuideColorChanged();
    break;
  case signalDEGuideColorChanged:
    Q_EMIT DEGuideColorChanged();
    break;
  case signalSolverFOVColorChanged:
    Q_EMIT SolverFOVColorChanged();
    break;
  case signalXplanetIsInternalChanged:
    Q_EMIT xplanetIsInternalChanged();
    break;
  case signalXplanetPathChanged:
    Q_EMIT XplanetPathChanged();
    break;
  case signalXplanetUseFIFOChanged:
    Q_EMIT XplanetUseFIFOChanged();
    break;
  case signalXplanetTimeoutChanged:
    Q_EMIT XplanetTimeoutChanged();
    break;
  case signalXplanetAnimationDelayChanged:
    Q_EMIT XplanetAnimationDelayChanged();
    break;
  case signalXplanetWidthChanged:
    Q_EMIT XplanetWidthChanged();
    break;
  case signalXplanetHeightChanged:
    Q_EMIT XplanetHeightChanged();
    break;
  case signalXplanetLabelChanged:
    Q_EMIT XplanetLabelChanged();
    break;
  case signalXplanetLabelLocalTimeChanged:
    Q_EMIT XplanetLabelLocalTimeChanged();
    break;
  case signalXplanetLabelGMTChanged:
    Q_EMIT XplanetLabelGMTChanged();
    break;
  case signalXplanetLabelStringChanged:
    Q_EMIT XplanetLabelStringChanged();
    break;
  case signalXplanetFontSizeChanged:
    Q_EMIT XplanetFontSizeChanged();
    break;
  case signalXplanetColorChanged:
    Q_EMIT XplanetColorChanged();
    break;
  case signalXplanetDateFormatChanged:
    Q_EMIT XplanetDateFormatChanged();
    break;
  case signalXplanetLabelTLChanged:
    Q_EMIT XplanetLabelTLChanged();
    break;
  case signalXplanetLabelTRChanged:
    Q_EMIT XplanetLabelTRChanged();
    break;
  case signalXplanetLabelBRChanged:
    Q_EMIT XplanetLabelBRChanged();
    break;
  case signalXplanetLabelBLChanged:
    Q_EMIT XplanetLabelBLChanged();
    break;
  case signalXplanetGlareChanged:
    Q_EMIT XplanetGlareChanged();
    break;
  case signalXplanetRandomChanged:
    Q_EMIT XplanetRandomChanged();
    break;
  case signalXplanetLatLongChanged:
    Q_EMIT XplanetLatLongChanged();
    break;
  case signalXplanetLatitudeChanged:
    Q_EMIT XplanetLatitudeChanged();
    break;
  case signalXplanetLongitudeChanged:
    Q_EMIT XplanetLongitudeChanged();
    break;
  case signalXplanetProjectionChanged:
    Q_EMIT XplanetProjectionChanged();
    break;
  case signalXplanetBackgroundChanged:
    Q_EMIT XplanetBackgroundChanged();
    break;
  case signalXplanetBackgroundImageChanged:
    Q_EMIT XplanetBackgroundImageChanged();
    break;
  case signalXplanetBackgroundImagePathChanged:
    Q_EMIT XplanetBackgroundImagePathChanged();
    break;
  case signalXplanetBackgroundColorChanged:
    Q_EMIT XplanetBackgroundColorChanged();
    break;
  case signalXplanetBackgroundColorValueChanged:
    Q_EMIT XplanetBackgroundColorValueChanged();
    break;
  case signalXplanetMagnitudeChanged:
    Q_EMIT XplanetMagnitudeChanged();
    break;
  case signalXplanetArcFileChanged:
    Q_EMIT XplanetArcFileChanged();
    break;
  case signalXplanetArcFilePathChanged:
    Q_EMIT XplanetArcFilePathChanged();
    break;
  case signalXplanetConfigFileChanged:
    Q_EMIT XplanetConfigFileChanged();
    break;
  case signalXplanetConfigFilePathChanged:
    Q_EMIT XplanetConfigFilePathChanged();
    break;
  case signalXplanetFOVChanged:
    Q_EMIT XplanetFOVChanged();
    break;
  case signalXplanetMarkerFileChanged:
    Q_EMIT XplanetMarkerFileChanged();
    break;
  case signalXplanetMarkerFilePathChanged:
    Q_EMIT XplanetMarkerFilePathChanged();
    break;
  case signalXplanetMarkerBoundsChanged:
    Q_EMIT XplanetMarkerBoundsChanged();
    break;
  case signalXplanetMarkerBoundsPathChanged:
    Q_EMIT XplanetMarkerBoundsPathChanged();
    break;
  case signalXplanetStarmapChanged:
    Q_EMIT XplanetStarmapChanged();
    break;
  case signalXplanetStarmapPathChanged:
    Q_EMIT XplanetStarmapPathChanged();
    break;
  case signalXplanetQualityChanged:
    Q_EMIT XplanetQualityChanged();
    break;
  case signalShowSatellitesChanged:
    Q_EMIT ShowSatellitesChanged();
    break;
  case signalShowVisibleSatellitesChanged:
    Q_EMIT ShowVisibleSatellitesChanged();
    break;
  case signalDrawSatellitesLikeStarsChanged:
    Q_EMIT DrawSatellitesLikeStarsChanged();
    break;
  case signalShowSatellitesLabelsChanged:
    Q_EMIT ShowSatellitesLabelsChanged();
    break;
  case signalSelectedSatellitesChanged:
    Q_EMIT SelectedSatellitesChanged();
    break;
  case signalKStarsFirstRunChanged:
    Q_EMIT KStarsFirstRunChanged();
    break;
  case signalAlwaysRecomputeCoordinatesChanged:
    Q_EMIT AlwaysRecomputeCoordinatesChanged();
    break;
  case signalDefaultDSSImageSizeChanged:
    Q_EMIT DefaultDSSImageSizeChanged();
    break;
  case signalDSSPaddingChanged:
    Q_EMIT DSSPaddingChanged();
    break;
  case signalVerboseLoggingChanged:
    Q_EMIT VerboseLoggingChanged();
    break;
  case signalRegularLoggingChanged:
    Q_EMIT RegularLoggingChanged();
    break;
  case signalDisableLoggingChanged:
    Q_EMIT DisableLoggingChanged();
    break;
  case signalLogToDefaultChanged:
    Q_EMIT LogToDefaultChanged();
    break;
  case signalLogToFileChanged:
    Q_EMIT LogToFileChanged();
    break;
  case signalFITSLoggingChanged:
    Q_EMIT FITSLoggingChanged();
    break;
  case signalINDILoggingChanged:
    Q_EMIT INDILoggingChanged();
    break;
  case signalCaptureLoggingChanged:
    Q_EMIT CaptureLoggingChanged();
    break;
  case signalFocusLoggingChanged:
    Q_EMIT FocusLoggingChanged();
    break;
  case signalSaveGuideImagesChanged:
    Q_EMIT SaveGuideImagesChanged();
    break;
  case signalSaveAlignImagesChanged:
    Q_EMIT SaveAlignImagesChanged();
    break;
  case signalSaveFailedAlignImagesChanged:
    Q_EMIT SaveFailedAlignImagesChanged();
    break;
  case signalDontSyncToRealTimeChanged:
    Q_EMIT DontSyncToRealTimeChanged();
    break;
  case signalGuideLoggingChanged:
    Q_EMIT GuideLoggingChanged();
    break;
  case signalAlignmentLoggingChanged:
    Q_EMIT AlignmentLoggingChanged();
    break;
  case signalMountLoggingChanged:
    Q_EMIT MountLoggingChanged();
    break;
  case signalObservatoryLoggingChanged:
    Q_EMIT ObservatoryLoggingChanged();
    break;
  case signalImageDebayerEngineChanged:
    Q_EMIT ImageDebayerEngineChanged();
    break;
  case signalImageDebayerAlgoChanged:
    Q_EMIT ImageDebayerAlgoChanged();
    break;
  case signalStackDebayerEngineChanged:
    Q_EMIT StackDebayerEngineChanged();
    break;
  case signalStackDebayerAlgoChanged:
    Q_EMIT StackDebayerAlgoChanged();
    break;
  case signalFITSWindowGeometryChanged:
    Q_EMIT FITSWindowGeometryChanged();
    break;
  case signalUseFITSViewerChanged:
    Q_EMIT useFITSViewerChanged();
    break;
  case signalSinglePreviewFITSChanged:
    Q_EMIT singlePreviewFITSChanged();
    break;
  case signalSingleWindowCapturedFITSChanged:
    Q_EMIT singleWindowCapturedFITSChanged();
    break;
  case signalSingleWindowOpenedFITSChanged:
    Q_EMIT singleWindowOpenedFITSChanged();
    break;
  case signalFocusFITSOnNewImageChanged:
    Q_EMIT focusFITSOnNewImageChanged();
    break;
  case signalIndependentWindowFITSChanged:
    Q_EMIT independentWindowFITSChanged();
    break;
  case signalLiveStackerOwnProcessChanged:
    Q_EMIT liveStackerOwnProcessChanged();
    break;
  case signalAutoDebayerChanged:
    Q_EMIT AutoDebayerChanged();
    break;
  case signalAuto3DCubeChanged:
    Q_EMIT Auto3DCubeChanged();
    break;
  case signalAutoHFRChanged:
    Q_EMIT AutoHFRChanged();
    break;
  case signalQuickHFRChanged:
    Q_EMIT QuickHFRChanged();
    break;
  case signalStellarSolverPartitionChanged:
    Q_EMIT StellarSolverPartitionChanged();
    break;
  case signalAutoWCSChanged:
    Q_EMIT AutoWCSChanged();
    break;
  case signalLimitedResourcesModeChanged:
    Q_EMIT LimitedResourcesModeChanged();
    break;
  case signalNonLinearHistogramChanged:
    Q_EMIT NonLinearHistogramChanged();
    break;
  case signalHIPSOpacityChanged:
    Q_EMIT HIPSOpacityChanged();
    break;
  case signalHIPSOffsetXChanged:
    Q_EMIT HIPSOffsetXChanged();
    break;
  case signalHIPSOffsetYChanged:
    Q_EMIT HIPSOffsetYChanged();
    break;
  case signalFitsSolverProfileChanged:
    Q_EMIT FitsSolverProfileChanged();
    break;
  case signalFitsSolverModuleChanged:
    Q_EMIT FitsSolverModuleChanged();
    break;
  case signalFitsSolverProfileIndecesChanged:
    Q_EMIT FitsSolverProfileIndecesChanged();
    break;
  case signalFitsCatalogChanged:
    Q_EMIT FitsCatalogChanged();
    break;
  case signalFitsCatObjShowNamesChanged:
    Q_EMIT FitsCatObjShowNamesChanged();
    break;
  case signalFitsSolverUseScaleChanged:
    Q_EMIT FitsSolverUseScaleChanged();
    break;
  case signalFitsSolverUsePositionChanged:
    Q_EMIT FitsSolverUsePositionChanged();
    break;
  case signalFitsSolverScaleChanged:
    Q_EMIT FitsSolverScaleChanged();
    break;
  case signalFitsSolverImageScaleUnitsChanged:
    Q_EMIT FitsSolverImageScaleUnitsChanged();
    break;
  case signalFitsSolverRadiusChanged:
    Q_EMIT FitsSolverRadiusChanged();
    break;
  case signalFitsLSHideGeneralChanged:
    Q_EMIT fitsLSHideGeneralChanged();
    break;
  case signalFitsLSHideCalibrationChanged:
    Q_EMIT fitsLSHideCalibrationChanged();
    break;
  case signalFitsLSHideAlignmentChanged:
    Q_EMIT fitsLSHideAlignmentChanged();
    break;
  case signalFitsLSHideStackingChanged:
    Q_EMIT fitsLSHideStackingChanged();
    break;
  case signalFitsLSHidePostProcChanged:
    Q_EMIT fitsLSHidePostProcChanged();
    break;
  case signalFitsLSCalcSNRChanged:
    Q_EMIT fitsLSCalcSNRChanged();
    break;
  case signalFitsLSMasterDarkChanged:
    Q_EMIT fitsLSMasterDarkChanged();
    break;
  case signalFitsLSMasterFlatChanged:
    Q_EMIT fitsLSMasterFlatChanged();
    break;
  case signalFitsLSHotPixelsChanged:
    Q_EMIT fitsLSHotPixelsChanged();
    break;
  case signalFitsLSColdPixelsChanged:
    Q_EMIT fitsLSColdPixelsChanged();
    break;
  case signalFitsLSAlignMethodChanged:
    Q_EMIT fitsLSAlignMethodChanged();
    break;
  case signalFitsLSNumInMemChanged:
    Q_EMIT fitsLSNumInMemChanged();
    break;
  case signalFitsLSDownscaleChanged:
    Q_EMIT fitsLSDownscaleChanged();
    break;
  case signalFitsLSWeightingChanged:
    Q_EMIT fitsLSWeightingChanged();
    break;
  case signalFitsLSNormalizationChanged:
    Q_EMIT fitsLSNormalizationChanged();
    break;
  case signalFitsLSStackingMethodChanged:
    Q_EMIT fitsLSStackingMethodChanged();
    break;
  case signalFitsLSLowSigmaChanged:
    Q_EMIT fitsLSLowSigmaChanged();
    break;
  case signalFitsLSHighSigmaChanged:
    Q_EMIT fitsLSHighSigmaChanged();
    break;
  case signalFitsLSWinsorCutoffChanged:
    Q_EMIT fitsLSWinsorCutoffChanged();
    break;
  case signalFitsLSIterationsChanged:
    Q_EMIT fitsLSIterationsChanged();
    break;
  case signalFitsLSKappaChanged:
    Q_EMIT fitsLSKappaChanged();
    break;
  case signalFitsLSAlphaChanged:
    Q_EMIT fitsLSAlphaChanged();
    break;
  case signalFitsLSSigmaChanged:
    Q_EMIT fitsLSSigmaChanged();
    break;
  case signalFitsPSFUpdateChanged:
    Q_EMIT fitsPSFUpdateChanged();
    break;
  case signalFitsLSPostProcChanged:
    Q_EMIT fitsLSPostProcChanged();
    break;
  case signalFitsLSGradientAmtChanged:
    Q_EMIT fitsLSGradientAmtChanged();
    break;
  case signalFitsLSDeconvAmtChanged:
    Q_EMIT fitsLSDeconvAmtChanged();
    break;
  case signalFitsLSPSFSigmaChanged:
    Q_EMIT fitsLSPSFSigmaChanged();
    break;
  case signalFitsLSDenoiseAmtChanged:
    Q_EMIT fitsLSDenoiseAmtChanged();
    break;
  case signalFitsLSSharpenAmtChanged:
    Q_EMIT fitsLSSharpenAmtChanged();
    break;
  case signalFitsLSSharpenKernalChanged:
    Q_EMIT fitsLSSharpenKernalChanged();
    break;
  case signalFitsLSSharpenSigmaChanged:
    Q_EMIT fitsLSSharpenSigmaChanged();
    break;
  case signalFitsLSMWindowGeometryChanged:
    Q_EMIT fitsLSMWindowGeometryChanged();
    break;
  case signalFitsLSMVisibleColumnsChanged:
    Q_EMIT fitsLSMVisibleColumnsChanged();
    break;
  case signalFitsLSMColumnWidthsChanged:
    Q_EMIT fitsLSMColumnWidthsChanged();
    break;
  case signalFitsLSMSortColumnChanged:
    Q_EMIT fitsLSMSortColumnChanged();
    break;
  case signalFitsLSMSortOrderChanged:
    Q_EMIT fitsLSMSortOrderChanged();
    break;
  case signalFitsLSMHighlightingChanged:
    Q_EMIT fitsLSMHighlightingChanged();
    break;
  case signalFitsLSWebcastTitleChanged:
    Q_EMIT fitsLSWebcastTitleChanged();
    break;
  case signalFitsLSWebcastLogoLChanged:
    Q_EMIT fitsLSWebcastLogoLChanged();
    break;
  case signalFitsLSWebcastLogoRChanged:
    Q_EMIT fitsLSWebcastLogoRChanged();
    break;
  case signalFitsLSWebcastPortChanged:
    Q_EMIT fitsLSWebcastPortChanged();
    break;
  case signalFitsLSWebcastThrottleChanged:
    Q_EMIT fitsLSWebcastThrottleChanged();
    break;
  case signalBortleClassChanged:
    Q_EMIT BortleClassChanged();
    break;
  case signalTelescopeCheckChanged:
    Q_EMIT TelescopeCheckChanged();
    break;
  case signalBinocularsCheckChanged:
    Q_EMIT BinocularsCheckChanged();
    break;
  case signalBinocularsApertureChanged:
    Q_EMIT BinocularsApertureChanged();
    break;
  case signalScopeListIndexChanged:
    Q_EMIT ScopeListIndexChanged();
    break;
  case signalEkosWindowWidthChanged:
    Q_EMIT EkosWindowWidthChanged();
    break;
  case signalEkosWindowHeightChanged:
    Q_EMIT EkosWindowHeightChanged();
    break;
  case signalEkosGeometryChanged:
    Q_EMIT EkosGeometryChanged();
    break;
  case signalEkosTopIconsChanged:
    Q_EMIT EkosTopIconsChanged();
    break;
  case signalEkosLeftIconsChanged:
    Q_EMIT EkosLeftIconsChanged();
    break;
  case signalIndependentWindowEkosChanged:
    Q_EMIT independentWindowEkosChanged();
    break;
  case signalProfileChanged:
    Q_EMIT profileChanged();
    break;
  case signalNeverLoadConfigChanged:
    Q_EMIT neverLoadConfigChanged();
    break;
  case signalLoadConfigOnConnectionChanged:
    Q_EMIT loadConfigOnConnectionChanged();
    break;
  case signalLoadDefaultConfigChanged:
    Q_EMIT loadDefaultConfigChanged();
    break;
  case signalAutoLoadSerialAssistantChanged:
    Q_EMIT autoLoadSerialAssistantChanged();
    break;
  case signalRememberCredentialsChanged:
    Q_EMIT RememberCredentialsChanged();
    break;
  case signalAutoStartEkosLiveChanged:
    Q_EMIT AutoStartEkosLiveChanged();
    break;
  case signalEkosLiveUsernameChanged:
    Q_EMIT EkosLiveUsernameChanged();
    break;
  case signalEkosLiveObservatoryChanged:
    Q_EMIT EkosLiveObservatoryChanged();
    break;
  case signalEkosLiveOfflineServerChanged:
    Q_EMIT EkosLiveOfflineServerChanged();
    break;
  case signalEkosLiveOnlineServerChanged:
    Q_EMIT EkosLiveOnlineServerChanged();
    break;
  case signalEkosLiveSoundChanged:
    Q_EMIT EkosLiveSoundChanged();
    break;
  case signalEkosLiveNotificationsChanged:
    Q_EMIT EkosLiveNotificationsChanged();
    break;
  case signalEkosLiveCloudChanged:
    Q_EMIT EkosLiveCloudChanged();
    break;
  case signalMaxDarkTemperatureDiffChanged:
    Q_EMIT MaxDarkTemperatureDiffChanged();
    break;
  case signalShutterfulCCDsChanged:
    Q_EMIT shutterfulCCDsChanged();
    break;
  case signalShutterlessCCDsChanged:
    Q_EMIT shutterlessCCDsChanged();
    break;
  case signalDarkLibraryDurationChanged:
    Q_EMIT DarkLibraryDurationChanged();
    break;
  case signalUseGraphicalCountsDisplayChanged:
    Q_EMIT UseGraphicalCountsDisplayChanged();
    break;
  case signalMinimumAltLimitChanged:
    Q_EMIT MinimumAltLimitChanged();
    break;
  case signalMaximumAltLimitChanged:
    Q_EMIT MaximumAltLimitChanged();
    break;
  case signalEnableAltitudeLimitsChanged:
    Q_EMIT EnableAltitudeLimitsChanged();
    break;
  case signalEnableAltitudeLimitsTrackingOnlyChanged:
    Q_EMIT EnableAltitudeLimitsTrackingOnlyChanged();
    break;
  case signalConfirmBelowHorizonChanged:
    Q_EMIT ConfirmBelowHorizonChanged();
    break;
  case signalMeridianFlipOffsetDegreesChanged:
    Q_EMIT MeridianFlipOffsetDegreesChanged();
    break;
  case signalMaximumHaLimitChanged:
    Q_EMIT MaximumHaLimitChanged();
    break;
  case signalEnableHaLimitChanged:
    Q_EMIT EnableHaLimitChanged();
    break;
  case signalExecuteMeridianFlipChanged:
    Q_EMIT ExecuteMeridianFlipChanged();
    break;
  case signalLeftRightReversedChanged:
    Q_EMIT LeftRightReversedChanged();
    break;
  case signalUpDownReversedChanged:
    Q_EMIT UpDownReversedChanged();
    break;
  case signalParkEveryDayChanged:
    Q_EMIT ParkEveryDayChanged();
    break;
  case signalParkTimeChanged:
    Q_EMIT ParkTimeChanged();
    break;
  case signalDefaultObserverChanged:
    Q_EMIT DefaultObserverChanged();
    break;
  case signalSyncFOVPAChanged:
    Q_EMIT SyncFOVPAChanged();
    break;
  case signalPAMultiplierChanged:
    Q_EMIT PAMultiplierChanged();
    break;
  case signalPAOffsetChanged:
    Q_EMIT PAOffsetChanged();
    break;
  case signalPAPierSideChanged:
    Q_EMIT PAPierSideChanged();
    break;
  case signalGuideDeviationChanged:
    Q_EMIT GuideDeviationChanged();
    break;
  case signalGuideDeviationRepsChanged:
    Q_EMIT GuideDeviationRepsChanged();
    break;
  case signalStartGuideDeviationChanged:
    Q_EMIT StartGuideDeviationChanged();
    break;
  case signalGuideDitherPerJobFrequencyChanged:
    Q_EMIT GuideDitherPerJobFrequencyChanged();
    break;
  case signalHFRDeviationChanged:
    Q_EMIT HFRDeviationChanged();
    break;
  case signalMaxFocusTemperatureDeltaChanged:
    Q_EMIT MaxFocusTemperatureDeltaChanged();
    break;
  case signalAutoDarkChanged:
    Q_EMIT AutoDarkChanged();
    break;
  case signalEnforceGuideDeviationChanged:
    Q_EMIT EnforceGuideDeviationChanged();
    break;
  case signalEnforceAutofocusHFRChanged:
    Q_EMIT EnforceAutofocusHFRChanged();
    break;
  case signalEnforceAutofocusOnTemperatureChanged:
    Q_EMIT EnforceAutofocusOnTemperatureChanged();
    break;
  case signalEnforceRefocusEveryNChanged:
    Q_EMIT EnforceRefocusEveryNChanged();
    break;
  case signalRefocusEveryNChanged:
    Q_EMIT RefocusEveryNChanged();
    break;
  case signalRefocusAfterMeridianFlipChanged:
    Q_EMIT RefocusAfterMeridianFlipChanged();
    break;
  case signalResetMountModelAfterMeridianChanged:
    Q_EMIT ResetMountModelAfterMeridianChanged();
    break;
  case signalForcedFlipChanged:
    Q_EMIT ForcedFlipChanged();
    break;
  case signalCalibrationADUValueChanged:
    Q_EMIT CalibrationADUValueChanged();
    break;
  case signalCalibrationADUValueToleranceChanged:
    Q_EMIT CalibrationADUValueToleranceChanged();
    break;
  case signalCalibrationPreActionIndexChanged:
    Q_EMIT CalibrationPreActionIndexChanged();
    break;
  case signalCalibrationFlatDurationIndexChanged:
    Q_EMIT CalibrationFlatDurationIndexChanged();
    break;
  case signalCalibrationWallAzChanged:
    Q_EMIT CalibrationWallAzChanged();
    break;
  case signalCalibrationWallAltChanged:
    Q_EMIT CalibrationWallAltChanged();
    break;
  case signalMaxTemperatureDiffChanged:
    Q_EMIT MaxTemperatureDiffChanged();
    break;
  case signalMaxStartGuiderDriftChanged:
    Q_EMIT MaxStartGuiderDriftChanged();
    break;
  case signalEnforceStartGuiderDriftChanged:
    Q_EMIT EnforceStartGuiderDriftChanged();
    break;
  case signalGuidingSettleChanged:
    Q_EMIT GuidingSettleChanged();
    break;
  case signalAlwaysResetSequenceWhenStartingChanged:
    Q_EMIT AlwaysResetSequenceWhenStartingChanged();
    break;
  case signalFlatSyncFocusChanged:
    Q_EMIT FlatSyncFocusChanged();
    break;
  case signalHFRThresholdPercentageChanged:
    Q_EMIT HFRThresholdPercentageChanged();
    break;
  case signalHFRCheckAlgorithmChanged:
    Q_EMIT HFRCheckAlgorithmChanged();
    break;
  case signalInSequenceCheckFramesChanged:
    Q_EMIT InSequenceCheckFramesChanged();
    break;
  case signalAutoStretchChanged:
    Q_EMIT AutoStretchChanged();
    break;
  case signalStretchPreviewSamplingChanged:
    Q_EMIT StretchPreviewSamplingChanged();
    break;
  case signalClipping64KValueChanged:
    Q_EMIT Clipping64KValueChanged();
    break;
  case signalClipping256ValueChanged:
    Q_EMIT Clipping256ValueChanged();
    break;
  case signalAdaptiveSamplingChanged:
    Q_EMIT AdaptiveSamplingChanged();
    break;
  case signalUseSummaryPreviewChanged:
    Q_EMIT useSummaryPreviewChanged();
    break;
  case signalUseDSLRImageViewerChanged:
    Q_EMIT useDSLRImageViewerChanged();
    break;
  case signalForceDSLRPresetsChanged:
    Q_EMIT ForceDSLRPresetsChanged();
    break;
  case signalCaptureDirectoryChanged:
    Q_EMIT CaptureDirectoryChanged();
    break;
  case signalPlaceholderFormatChanged:
    Q_EMIT PlaceholderFormatChanged();
    break;
  case signalRemoteCaptureDirectoryChanged:
    Q_EMIT RemoteCaptureDirectoryChanged();
    break;
  case signalManualCoverTimeoutChanged:
    Q_EMIT ManualCoverTimeoutChanged();
    break;
  case signalCaptureOperationsTimeoutChanged:
    Q_EMIT CaptureOperationsTimeoutChanged();
    break;
  case signalMinFlipDurationChanged:
    Q_EMIT MinFlipDurationChanged();
    break;
  case signalCapturePositionChanged:
    Q_EMIT CapturePositionChanged();
    break;
  case signalCaptureTrainIDChanged:
    Q_EMIT CaptureTrainIDChanged();
    break;
  case signalCaptureCalibrationWallChanged:
    Q_EMIT CaptureCalibrationWallChanged();
    break;
  case signalCaptureCalibrationParkMountChanged:
    Q_EMIT CaptureCalibrationParkMountChanged();
    break;
  case signalCaptureCalibrationParkDomeChanged:
    Q_EMIT CaptureCalibrationParkDomeChanged();
    break;
  case signalCaptureCalibrationUseManualChanged:
    Q_EMIT CaptureCalibrationUseManualChanged();
    break;
  case signalCaptureCalibrationUseADUChanged:
    Q_EMIT CaptureCalibrationUseADUChanged();
    break;
  case signalCaptureCalibrationADUValueChanged:
    Q_EMIT CaptureCalibrationADUValueChanged();
    break;
  case signalCaptureCalibrationADUToleranceChanged:
    Q_EMIT CaptureCalibrationADUToleranceChanged();
    break;
  case signalCaptureCalibrationSkyFlatsChanged:
    Q_EMIT CaptureCalibrationSkyFlatsChanged();
    break;
  case signalAbsTicksSpinChanged:
    Q_EMIT AbsTicksSpinChanged();
    break;
  case signalFocusExposureChanged:
    Q_EMIT FocusExposureChanged();
    break;
  case signalFocusBinningChanged:
    Q_EMIT FocusBinningChanged();
    break;
  case signalFocusGainChanged:
    Q_EMIT FocusGainChanged();
    break;
  case signalFocusISOChanged:
    Q_EMIT FocusISOChanged();
    break;
  case signalDefaultFocusTemperatureSourceChanged:
    Q_EMIT DefaultFocusTemperatureSourceChanged();
    break;
  case signalFocusFilterChanged:
    Q_EMIT FocusFilterChanged();
    break;
  case signalUseFocusDarkFrameChanged:
    Q_EMIT UseFocusDarkFrameChanged();
    break;
  case signalFocusSubFrameChanged:
    Q_EMIT FocusSubFrameChanged();
    break;
  case signalFocusBoxSizeChanged:
    Q_EMIT FocusBoxSizeChanged();
    break;
  case signalFocusUseFullFieldChanged:
    Q_EMIT FocusUseFullFieldChanged();
    break;
  case signalFocusNoMaskRBChanged:
    Q_EMIT FocusNoMaskRBChanged();
    break;
  case signalFocusRingMaskRBChanged:
    Q_EMIT focusRingMaskRBChanged();
    break;
  case signalFocusMosaicMaskRBChanged:
    Q_EMIT focusMosaicMaskRBChanged();
    break;
  case signalFocusFullFieldInnerRadiusChanged:
    Q_EMIT FocusFullFieldInnerRadiusChanged();
    break;
  case signalFocusFullFieldOuterRadiusChanged:
    Q_EMIT FocusFullFieldOuterRadiusChanged();
    break;
  case signalFocusMosaicTileWidthChanged:
    Q_EMIT FocusMosaicTileWidthChanged();
    break;
  case signalFocusMosaicSpaceChanged:
    Q_EMIT focusMosaicSpaceChanged();
    break;
  case signalFocusAutoStarEnabledChanged:
    Q_EMIT FocusAutoStarEnabledChanged();
    break;
  case signalFocusSuspendGuidingChanged:
    Q_EMIT FocusSuspendGuidingChanged();
    break;
  case signalFocusGuideSettleTimeChanged:
    Q_EMIT FocusGuideSettleTimeChanged();
    break;
  case signalFocusUnitsChanged:
    Q_EMIT FocusUnitsChanged();
    break;
  case signalFocusAdaptiveChanged:
    Q_EMIT FocusAdaptiveChanged();
    break;
  case signalFocusAdaptiveMinMoveChanged:
    Q_EMIT focusAdaptiveMinMoveChanged();
    break;
  case signalFocusAdaptStartChanged:
    Q_EMIT FocusAdaptStartChanged();
    break;
  case signalFocusAdaptiveMaxMoveChanged:
    Q_EMIT focusAdaptiveMaxMoveChanged();
    break;
  case signalFocusDetectionChanged:
    Q_EMIT FocusDetectionChanged();
    break;
  case signalFocusSEPProfileChanged:
    Q_EMIT FocusSEPProfileChanged();
    break;
  case signalFocusAlgorithmChanged:
    Q_EMIT FocusAlgorithmChanged();
    break;
  case signalFocusCurveFitChanged:
    Q_EMIT FocusCurveFitChanged();
    break;
  case signalFocusStarMeasureChanged:
    Q_EMIT FocusStarMeasureChanged();
    break;
  case signalFocusStarPSFChanged:
    Q_EMIT FocusStarPSFChanged();
    break;
  case signalFocusUseWeightsChanged:
    Q_EMIT FocusUseWeightsChanged();
    break;
  case signalFocusR2LimitChanged:
    Q_EMIT FocusR2LimitChanged();
    break;
  case signalFocusRefineCurveFitChanged:
    Q_EMIT FocusRefineCurveFitChanged();
    break;
  case signalFocusFramesCountChanged:
    Q_EMIT focusFramesCountChanged();
    break;
  case signalFocusHFRFramesCountChanged:
    Q_EMIT focusHFRFramesCountChanged();
    break;
  case signalFocusMultiRowAverageChanged:
    Q_EMIT FocusMultiRowAverageChanged();
    break;
  case signalFocusGaussianSigmaChanged:
    Q_EMIT FocusGaussianSigmaChanged();
    break;
  case signalFocusThresholdChanged:
    Q_EMIT FocusThresholdChanged();
    break;
  case signalFocusDenoiseChanged:
    Q_EMIT FocusDenoiseChanged();
    break;
  case signalFocusDonutChanged:
    Q_EMIT FocusDonutChanged();
    break;
  case signalFocusTimeDilationChanged:
    Q_EMIT FocusTimeDilationChanged();
    break;
  case signalFocusOutlierRejectionChanged:
    Q_EMIT focusOutlierRejectionChanged();
    break;
  case signalFocusScanStartPosChanged:
    Q_EMIT focusScanStartPosChanged();
    break;
  case signalFocusScanAlwaysOnChanged:
    Q_EMIT focusScanAlwaysOnChanged();
    break;
  case signalFocusScanDatapointsChanged:
    Q_EMIT focusScanDatapointsChanged();
    break;
  case signalFocusScanStepSizeFactorChanged:
    Q_EMIT focusScanStepSizeFactorChanged();
    break;
  case signalFocusGaussianKernelSizeChanged:
    Q_EMIT FocusGaussianKernelSizeChanged();
    break;
  case signalFocusToleranceChanged:
    Q_EMIT FocusToleranceChanged();
    break;
  case signalFocusWalkChanged:
    Q_EMIT FocusWalkChanged();
    break;
  case signalFocusSettleTimeChanged:
    Q_EMIT FocusSettleTimeChanged();
    break;
  case signalFocusTicksChanged:
    Q_EMIT FocusTicksChanged();
    break;
  case signalFocusOutStepsChanged:
    Q_EMIT FocusOutStepsChanged();
    break;
  case signalFocusNumStepsChanged:
    Q_EMIT focusNumStepsChanged();
    break;
  case signalFocusMaxTravelChanged:
    Q_EMIT FocusMaxTravelChanged();
    break;
  case signalFocusMaxSingleStepChanged:
    Q_EMIT FocusMaxSingleStepChanged();
    break;
  case signalFocusBacklashChanged:
    Q_EMIT FocusBacklashChanged();
    break;
  case signalFocusAFOverscanChanged:
    Q_EMIT FocusAFOverscanChanged();
    break;
  case signalFocusOverscanDelayChanged:
    Q_EMIT FocusOverscanDelayChanged();
    break;
  case signalFocusCaptureTimeoutChanged:
    Q_EMIT FocusCaptureTimeoutChanged();
    break;
  case signalFocusMotionTimeoutChanged:
    Q_EMIT FocusMotionTimeoutChanged();
    break;
  case signalFocusCFZAlgorithmChanged:
    Q_EMIT focusCFZAlgorithmChanged();
    break;
  case signalFocusCFZToleranceChanged:
    Q_EMIT focusCFZToleranceChanged();
    break;
  case signalFocusCFZTauChanged:
    Q_EMIT focusCFZTauChanged();
    break;
  case signalFocusCFZDisplayVCurveChanged:
    Q_EMIT focusCFZDisplayVCurveChanged();
    break;
  case signalFocusCFZWavelengthChanged:
    Q_EMIT focusCFZWavelengthChanged();
    break;
  case signalFocusCFZApertureChanged:
    Q_EMIT focusCFZApertureChanged();
    break;
  case signalFocusCFZFNumberChanged:
    Q_EMIT focusCFZFNumberChanged();
    break;
  case signalFocusCFZSeeingChanged:
    Q_EMIT focusCFZSeeingChanged();
    break;
  case signalFocusCFZStepSizeChanged:
    Q_EMIT focusCFZStepSizeChanged();
    break;
  case signalFocusAdvHelpOnlyChangesChanged:
    Q_EMIT focusAdvHelpOnlyChangesChanged();
    break;
  case signalFocusAdvUpdateParamsChanged:
    Q_EMIT focusAdvUpdateParamsChanged();
    break;
  case signalFocusAdvFindStarsChanged:
    Q_EMIT focusAdvFindStarsChanged();
    break;
  case signalFocusAdvCourseAdjChanged:
    Q_EMIT focusAdvCourseAdjChanged();
    break;
  case signalFocusAdvFineAdjChanged:
    Q_EMIT focusAdvFineAdjChanged();
    break;
  case signalFocusSplitterChanged:
    Q_EMIT FocusSplitterChanged();
    break;
  case signalRightLayoutChanged:
    Q_EMIT rightLayoutChanged();
    break;
  case signalAdaptFocusBFOChanged:
    Q_EMIT adaptFocusBFOChanged();
    break;
  case signalAbInsTileSelectionChanged:
    Q_EMIT abInsTileSelectionChanged();
    break;
  case signalAbInsShowLabelsChanged:
    Q_EMIT abInsShowLabelsChanged();
    break;
  case signalAbInsShowCFZChanged:
    Q_EMIT abInsShowCFZChanged();
    break;
  case signalAbInsOptCentresChanged:
    Q_EMIT abInsOptCentresChanged();
    break;
  case signalAbInsHSplitterChanged:
    Q_EMIT abInsHSplitterChanged();
    break;
  case signalAbInsVSplitterChanged:
    Q_EMIT abInsVSplitterChanged();
    break;
  case signalAbInsSelectionChanged:
    Q_EMIT abInsSelectionChanged();
    break;
  case signalAbInsThemeChanged:
    Q_EMIT abInsThemeChanged();
    break;
  case signalAbInsLabelsChanged:
    Q_EMIT abInsLabelsChanged();
    break;
  case signalAbInsSensorChanged:
    Q_EMIT abInsSensorChanged();
    break;
  case signalAbInsPetzvalWireChanged:
    Q_EMIT abInsPetzvalWireChanged();
    break;
  case signalAbInsPetzvalSurfaceChanged:
    Q_EMIT abInsPetzvalSurfaceChanged();
    break;
  case signalTiltPlateTypeChanged:
    Q_EMIT tiltPlateTypeChanged();
    break;
  case signalTiltRadiusChanged:
    Q_EMIT tiltRadiusChanged();
    break;
  case signalTiltThreadIndexChanged:
    Q_EMIT tiltThreadIndexChanged();
    break;
  case signalTiltScrewPitchChanged:
    Q_EMIT tiltScrewPitchChanged();
    break;
  case signalTiltRotationChanged:
    Q_EMIT tiltRotationChanged();
    break;
  case signalTiltModeChanged:
    Q_EMIT tiltModeChanged();
    break;
  case signalTiltPlatePresentChanged:
    Q_EMIT tiltPlatePresentChanged();
    break;
  case signalFocusSextractorTypeChanged:
    Q_EMIT FocusSextractorTypeChanged();
    break;
  case signalFocusOptionsProfileChanged:
    Q_EMIT FocusOptionsProfileChanged();
    break;
  case signalHFRSextractorTypeChanged:
    Q_EMIT HFRSextractorTypeChanged();
    break;
  case signalHFROptionsProfileChanged:
    Q_EMIT HFROptionsProfileChanged();
    break;
  case signalGuideSextractorTypeChanged:
    Q_EMIT GuideSextractorTypeChanged();
    break;
  case signalGuideOptionsProfileChanged:
    Q_EMIT GuideOptionsProfileChanged();
    break;
  case signalSolveSextractorTypeChanged:
    Q_EMIT SolveSextractorTypeChanged();
    break;
  case signalSolverModeChanged:
    Q_EMIT SolverModeChanged();
    break;
  case signalSolverTypeChanged:
    Q_EMIT SolverTypeChanged();
    break;
  case signalSolveOptionsProfileChanged:
    Q_EMIT SolveOptionsProfileChanged();
    break;
  case signalLoggerLevelChanged:
    Q_EMIT LoggerLevelChanged();
    break;
  case signalAstrometryLogToFileChanged:
    Q_EMIT AstrometryLogToFileChanged();
    break;
  case signalAstrometryLogFilepathChanged:
    Q_EMIT AstrometryLogFilepathChanged();
    break;
  case signalAstrometryIndexFolderListChanged:
    Q_EMIT AstrometryIndexFolderListChanged();
    break;
  case signalAlignExposureChanged:
    Q_EMIT AlignExposureChanged();
    break;
  case signalAlignBinningChanged:
    Q_EMIT AlignBinningChanged();
    break;
  case signalAlignGainChanged:
    Q_EMIT AlignGainChanged();
    break;
  case signalAlignISOChanged:
    Q_EMIT AlignISOChanged();
    break;
  case signalAlignDarkFrameChanged:
    Q_EMIT AlignDarkFrameChanged();
    break;
  case signalAlignFilterChanged:
    Q_EMIT AlignFilterChanged();
    break;
  case signalAlignUseCurrentFilterChanged:
    Q_EMIT AlignUseCurrentFilterChanged();
    break;
  case signalAstrometryUseRotatorChanged:
    Q_EMIT AstrometryUseRotatorChanged();
    break;
  case signalAstrometryRotatorThresholdChanged:
    Q_EMIT AstrometryRotatorThresholdChanged();
    break;
  case signalAstrometryFlipRotationAllowedChanged:
    Q_EMIT AstrometryFlipRotationAllowedChanged();
    break;
  case signalRotatorParityReversedChanged:
    Q_EMIT RotatorParityReversedChanged();
    break;
  case signalAstrometrySolverWCSChanged:
    Q_EMIT AstrometrySolverWCSChanged();
    break;
  case signalAstrometrySolverOverlayChanged:
    Q_EMIT AstrometrySolverOverlayChanged();
    break;
  case signalAstrometryDifferentialSlewingChanged:
    Q_EMIT AstrometryDifferentialSlewingChanged();
    break;
  case signalAlignAccuracyThresholdChanged:
    Q_EMIT AlignAccuracyThresholdChanged();
    break;
  case signalAlignSettlingTimeChanged:
    Q_EMIT AlignSettlingTimeChanged();
    break;
  case signalAstrometryUseNoFITS2FITSChanged:
    Q_EMIT AstrometryUseNoFITS2FITSChanged();
    break;
  case signalAstrometryUseResortChanged:
    Q_EMIT AstrometryUseResortChanged();
    break;
  case signalAstrometryUseNoVerifyChanged:
    Q_EMIT AstrometryUseNoVerifyChanged();
    break;
  case signalAstrometryUseImageScaleChanged:
    Q_EMIT AstrometryUseImageScaleChanged();
    break;
  case signalAstrometryImageScaleLowChanged:
    Q_EMIT AstrometryImageScaleLowChanged();
    break;
  case signalAstrometryImageScaleHighChanged:
    Q_EMIT AstrometryImageScaleHighChanged();
    break;
  case signalAstrometryAutoUpdateImageScaleChanged:
    Q_EMIT AstrometryAutoUpdateImageScaleChanged();
    break;
  case signalAstrometryImageScaleUnitsChanged:
    Q_EMIT AstrometryImageScaleUnitsChanged();
    break;
  case signalAstrometryUseDownsampleChanged:
    Q_EMIT AstrometryUseDownsampleChanged();
    break;
  case signalAstrometryDownsampleChanged:
    Q_EMIT AstrometryDownsampleChanged();
    break;
  case signalAstrometryAutoDownsampleChanged:
    Q_EMIT AstrometryAutoDownsampleChanged();
    break;
  case signalAstrometryDynamicThresholdChanged:
    Q_EMIT AstrometryDynamicThresholdChanged();
    break;
  case signalAstrometryUsePositionChanged:
    Q_EMIT AstrometryUsePositionChanged();
    break;
  case signalAstrometryPositionRAChanged:
    Q_EMIT AstrometryPositionRAChanged();
    break;
  case signalAstrometryPositionDEChanged:
    Q_EMIT AstrometryPositionDEChanged();
    break;
  case signalAstrometryAutoUpdatePositionChanged:
    Q_EMIT AstrometryAutoUpdatePositionChanged();
    break;
  case signalAstrometryRadiusChanged:
    Q_EMIT AstrometryRadiusChanged();
    break;
  case signalAstrometryDetectParityChanged:
    Q_EMIT AstrometryDetectParityChanged();
    break;
  case signalAstrometryCustomOptionsChanged:
    Q_EMIT AstrometryCustomOptionsChanged();
    break;
  case signalAstrometrySolverBinaryChanged:
    Q_EMIT AstrometrySolverBinaryChanged();
    break;
  case signalAstrometryWCSInfoChanged:
    Q_EMIT AstrometryWCSInfoChanged();
    break;
  case signalAstrometryConfFileChanged:
    Q_EMIT AstrometryConfFileChanged();
    break;
  case signalSextractorBinaryChanged:
    Q_EMIT SextractorBinaryChanged();
    break;
  case signalWatneyBinaryChanged:
    Q_EMIT WatneyBinaryChanged();
    break;
  case signalAstrometryAPIKeyChanged:
    Q_EMIT AstrometryAPIKeyChanged();
    break;
  case signalAstrometryAPIURLChanged:
    Q_EMIT AstrometryAPIURLChanged();
    break;
  case signalAstrometryUseJPEGChanged:
    Q_EMIT AstrometryUseJPEGChanged();
    break;
  case signalAstrometryTimeoutChanged:
    Q_EMIT AstrometryTimeoutChanged();
    break;
  case signalPAHMountSpeedChanged:
    Q_EMIT PAHMountSpeedChanged();
    break;
  case signalPAHRotaionChanged:
    Q_EMIT PAHRotaionChanged();
    break;
  case signalPAHRefreshAlgorithmChanged:
    Q_EMIT PAHRefreshAlgorithmChanged();
    break;
  case signalPAHDirectionChanged:
    Q_EMIT PAHDirectionChanged();
    break;
  case signalPAHAutoParkChanged:
    Q_EMIT PAHAutoParkChanged();
    break;
  case signalPAHManualSlewChanged:
    Q_EMIT PAHManualSlewChanged();
    break;
  case signalPAHExposureChanged:
    Q_EMIT PAHExposureChanged();
    break;
  case signalPAHAutoPACCorrectionChanged:
    Q_EMIT PAHAutoPACCorrectionChanged();
    break;
  case signalPAHAutoChangeDirectionChanged:
    Q_EMIT PAHAutoChangeDirectionChanged();
    break;
  case signalPAHSuccessThresholdChanged:
    Q_EMIT PAHSuccessThresholdChanged();
    break;
  case signalPAHCorrectionTimeoutChanged:
    Q_EMIT PAHCorrectionTimeoutChanged();
    break;
  case signalGuideExposureChanged:
    Q_EMIT GuideExposureChanged();
    break;
  case signalGuideDelayChanged:
    Q_EMIT GuideDelayChanged();
    break;
  case signalGuiderTypeChanged:
    Q_EMIT GuiderTypeChanged();
    break;
  case signalGuideAlgorithmChanged:
    Q_EMIT GuideAlgorithmChanged();
    break;
  case signalRAGuidePulseAlgorithmChanged:
    Q_EMIT RAGuidePulseAlgorithmChanged();
    break;
  case signalDECGuidePulseAlgorithmChanged:
    Q_EMIT DECGuidePulseAlgorithmChanged();
    break;
  case signalAIGuiderWeightsFileChanged:
    Q_EMIT AIGuiderWeightsFileChanged();
    break;
  case signalAIPredictionGainChanged:
    Q_EMIT AIPredictionGainChanged();
    break;
  case signalAIProportionalBackoffChanged:
    Q_EMIT AIProportionalBackoffChanged();
    break;
  case signalAIPIDAutoTuneChanged:
    Q_EMIT AIPIDAutoTuneChanged();
    break;
  case signalAIShadowModeChanged:
    Q_EMIT AIShadowModeChanged();
    break;
  case signalPHD2HostChanged:
    Q_EMIT PHD2HostChanged();
    break;
  case signalPHD2PortChanged:
    Q_EMIT PHD2PortChanged();
    break;
  case signalLinGuiderHostChanged:
    Q_EMIT LinGuiderHostChanged();
    break;
  case signalLinGuiderPortChanged:
    Q_EMIT LinGuiderPortChanged();
    break;
  case signalCalibrationPulseDurationChanged:
    Q_EMIT CalibrationPulseDurationChanged();
    break;
  case signalCalibrationMaxMoveChanged:
    Q_EMIT CalibrationMaxMoveChanged();
    break;
  case signalGuideSquareSizeChanged:
    Q_EMIT GuideSquareSizeChanged();
    break;
  case signalGuideBinningChanged:
    Q_EMIT GuideBinningChanged();
    break;
  case signalGuideAutoStarChanged:
    Q_EMIT GuideAutoStarChanged();
    break;
  case signalGuideShowFrameChanged:
    Q_EMIT guideShowFrameChanged();
    break;
  case signalGuideAutoSquareSizeEnabledChanged:
    Q_EMIT GuideAutoSquareSizeEnabledChanged();
    break;
  case signalAutoModeIterationsChanged:
    Q_EMIT AutoModeIterationsChanged();
    break;
  case signalGuideLostStarTimeoutChanged:
    Q_EMIT GuideLostStarTimeoutChanged();
    break;
  case signalGuideCalibrationTimeoutChanged:
    Q_EMIT GuideCalibrationTimeoutChanged();
    break;
  case signalGuideMaxDeltaRMSChanged:
    Q_EMIT GuideMaxDeltaRMSChanged();
    break;
  case signalGuideMaxHFRChanged:
    Q_EMIT GuideMaxHFRChanged();
    break;
  case signalMinDetectionsSEPMultistarChanged:
    Q_EMIT MinDetectionsSEPMultistarChanged();
    break;
  case signalMaxMultistarReferenceStarsChanged:
    Q_EMIT MaxMultistarReferenceStarsChanged();
    break;
  case signalAlwaysInventGuideStarChanged:
    Q_EMIT AlwaysInventGuideStarChanged();
    break;
  case signalTwoAxisEnabledChanged:
    Q_EMIT TwoAxisEnabledChanged();
    break;
  case signalUseGuideHeadChanged:
    Q_EMIT UseGuideHeadChanged();
    break;
  case signalSaveGuideLogChanged:
    Q_EMIT SaveGuideLogChanged();
    break;
  case signalGuideDarkFrameChanged:
    Q_EMIT GuideDarkFrameChanged();
    break;
  case signalGuideSubframeChanged:
    Q_EMIT GuideSubframeChanged();
    break;
  case signalDitherPixelsChanged:
    Q_EMIT DitherPixelsChanged();
    break;
  case signalDitherFramesChanged:
    Q_EMIT DitherFramesChanged();
    break;
  case signalDitherSettleChanged:
    Q_EMIT DitherSettleChanged();
    break;
  case signalDitherThresholdChanged:
    Q_EMIT DitherThresholdChanged();
    break;
  case signalDitherTimeoutChanged:
    Q_EMIT DitherTimeoutChanged();
    break;
  case signalDitherMaxIterationsChanged:
    Q_EMIT DitherMaxIterationsChanged();
    break;
  case signalDitherNoGuidingPulseChanged:
    Q_EMIT DitherNoGuidingPulseChanged();
    break;
  case signalDitherFailAbortsAutoGuideChanged:
    Q_EMIT DitherFailAbortsAutoGuideChanged();
    break;
  case signalDitherWithOnePulseChanged:
    Q_EMIT DitherWithOnePulseChanged();
    break;
  case signalDitherEnabledChanged:
    Q_EMIT DitherEnabledChanged();
    break;
  case signalDitherNoGuidingChanged:
    Q_EMIT DitherNoGuidingChanged();
    break;
  case signalRAGuideEnabledChanged:
    Q_EMIT RAGuideEnabledChanged();
    break;
  case signalDECGuideEnabledChanged:
    Q_EMIT DECGuideEnabledChanged();
    break;
  case signalNorthDECGuideEnabledChanged:
    Q_EMIT NorthDECGuideEnabledChanged();
    break;
  case signalSouthDECGuideEnabledChanged:
    Q_EMIT SouthDECGuideEnabledChanged();
    break;
  case signalEastRAGuideEnabledChanged:
    Q_EMIT EastRAGuideEnabledChanged();
    break;
  case signalWestRAGuideEnabledChanged:
    Q_EMIT WestRAGuideEnabledChanged();
    break;
  case signalRAProportionalGainChanged:
    Q_EMIT RAProportionalGainChanged();
    break;
  case signalDECProportionalGainChanged:
    Q_EMIT DECProportionalGainChanged();
    break;
  case signalRAIntegralGainChanged:
    Q_EMIT RAIntegralGainChanged();
    break;
  case signalDECIntegralGainChanged:
    Q_EMIT DECIntegralGainChanged();
    break;
  case signalRAMinimumPulseArcSecChanged:
    Q_EMIT RAMinimumPulseArcSecChanged();
    break;
  case signalDECMinimumPulseArcSecChanged:
    Q_EMIT DECMinimumPulseArcSecChanged();
    break;
  case signalRAMaximumPulseArcSecChanged:
    Q_EMIT RAMaximumPulseArcSecChanged();
    break;
  case signalDECMaximumPulseArcSecChanged:
    Q_EMIT DECMaximumPulseArcSecChanged();
    break;
  case signalGPGEnabledChanged:
    Q_EMIT GPGEnabledChanged();
    break;
  case signalGPGDarkGuidingChanged:
    Q_EMIT GPGDarkGuidingChanged();
    break;
  case signalGPGDarkGuidingIntervalChanged:
    Q_EMIT GPGDarkGuidingIntervalChanged();
    break;
  case signalAIDarkGuidingChanged:
    Q_EMIT AIDarkGuidingChanged();
    break;
  case signalAIDarkGuidingIntervalChanged:
    Q_EMIT AIDarkGuidingIntervalChanged();
    break;
  case signalGPGcWeightChanged:
    Q_EMIT GPGcWeightChanged();
    break;
  case signalGPGMinPeriodsForInferenceChanged:
    Q_EMIT GPGMinPeriodsForInferenceChanged();
    break;
  case signalGPGMinMoveChanged:
    Q_EMIT GPGMinMoveChanged();
    break;
  case signalGPGSE0KLengthScaleChanged:
    Q_EMIT GPGSE0KLengthScaleChanged();
    break;
  case signalGPGSE0KSignalVarianceChanged:
    Q_EMIT GPGSE0KSignalVarianceChanged();
    break;
  case signalGPGPKLengthScaleChanged:
    Q_EMIT GPGPKLengthScaleChanged();
    break;
  case signalGPGPeriodChanged:
    Q_EMIT GPGPeriodChanged();
    break;
  case signalGPGPKSignalVarianceChanged:
    Q_EMIT GPGPKSignalVarianceChanged();
    break;
  case signalGPGSE1KLengthScaleChanged:
    Q_EMIT GPGSE1KLengthScaleChanged();
    break;
  case signalGPGSE1KSignalVarianceChanged:
    Q_EMIT GPGSE1KSignalVarianceChanged();
    break;
  case signalGPGMinPeriodsForPeriodEstimateChanged:
    Q_EMIT GPGMinPeriodsForPeriodEstimateChanged();
    break;
  case signalGPGPointsForApproximationChanged:
    Q_EMIT GPGPointsForApproximationChanged();
    break;
  case signalGPGpWeightChanged:
    Q_EMIT GPGpWeightChanged();
    break;
  case signalGPGEstimatePeriodChanged:
    Q_EMIT GPGEstimatePeriodChanged();
    break;
  case signalGuiderAccuracyThresholdChanged:
    Q_EMIT GuiderAccuracyThresholdChanged();
    break;
  case signalRADisplayedOnGuideGraphChanged:
    Q_EMIT RADisplayedOnGuideGraphChanged();
    break;
  case signalDEDisplayedOnGuideGraphChanged:
    Q_EMIT DEDisplayedOnGuideGraphChanged();
    break;
  case signalRACorrDisplayedOnGuideGraphChanged:
    Q_EMIT RACorrDisplayedOnGuideGraphChanged();
    break;
  case signalDECorrDisplayedOnGuideGraphChanged:
    Q_EMIT DECorrDisplayedOnGuideGraphChanged();
    break;
  case signalSNRDisplayedOnGuideGraphChanged:
    Q_EMIT SNRDisplayedOnGuideGraphChanged();
    break;
  case signalRMSDisplayedOnGuideGraphChanged:
    Q_EMIT RMSDisplayedOnGuideGraphChanged();
    break;
  case signalRAHysteresisChanged:
    Q_EMIT RAHysteresisChanged();
    break;
  case signalDECHysteresisChanged:
    Q_EMIT DECHysteresisChanged();
    break;
  case signalSchedulerAlgorithmChanged:
    Q_EMIT SchedulerAlgorithmChanged();
    break;
  case signalSchedulerLoggingChanged:
    Q_EMIT SchedulerLoggingChanged();
    break;
  case signalStopEkosAfterShutdownChanged:
    Q_EMIT StopEkosAfterShutdownChanged();
    break;
  case signalShutdownScriptTerminatesINDIChanged:
    Q_EMIT ShutdownScriptTerminatesINDIChanged();
    break;
  case signalCameraWarmupEnabledChanged:
    Q_EMIT CameraWarmupEnabledChanged();
    break;
  case signalCameraWarmupRampChanged:
    Q_EMIT CameraWarmupRampChanged();
    break;
  case signalPreemptiveShutdownChanged:
    Q_EMIT PreemptiveShutdownChanged();
    break;
  case signalResetMountModelOnAlignFailChanged:
    Q_EMIT ResetMountModelOnAlignFailChanged();
    break;
  case signalResetMountModelBeforeJobChanged:
    Q_EMIT ResetMountModelBeforeJobChanged();
    break;
  case signalResetGuideCalibrationChanged:
    Q_EMIT ResetGuideCalibrationChanged();
    break;
  case signalForceAlignmentBeforeJobChanged:
    Q_EMIT ForceAlignmentBeforeJobChanged();
    break;
  case signalReuseGuideCalibrationChanged:
    Q_EMIT ReuseGuideCalibrationChanged();
    break;
  case signalReverseDecOnPierSideChangeChanged:
    Q_EMIT ReverseDecOnPierSideChangeChanged();
    break;
  case signalGuideCalibrationBacklashChanged:
    Q_EMIT GuideCalibrationBacklashChanged();
    break;
  case signalAssumeDecOrthogonalChanged:
    Q_EMIT AssumeDecOrthogonalChanged();
    break;
  case signalSerializedCalibrationChanged:
    Q_EMIT SerializedCalibrationChanged();
    break;
  case signalRealignAfterCalibrationFailureChanged:
    Q_EMIT RealignAfterCalibrationFailureChanged();
    break;
  case signalPreemptiveShutdownTimeChanged:
    Q_EMIT PreemptiveShutdownTimeChanged();
    break;
  case signalRememberJobProgressChanged:
    Q_EMIT RememberJobProgressChanged();
    break;
  case signalGreedySchedulingChanged:
    Q_EMIT GreedySchedulingChanged();
    break;
  case signalLeadTimeChanged:
    Q_EMIT LeadTimeChanged();
    break;
  case signalPreDawnTimeChanged:
    Q_EMIT PreDawnTimeChanged();
    break;
  case signalDawnOffsetChanged:
    Q_EMIT DawnOffsetChanged();
    break;
  case signalDuskOffsetChanged:
    Q_EMIT DuskOffsetChanged();
    break;
  case signalTelescopeFocalLengthChanged:
    Q_EMIT TelescopeFocalLengthChanged();
    break;
  case signalTelescopeFocalReducerChanged:
    Q_EMIT TelescopeFocalReducerChanged();
    break;
  case signalCameraPixelWidthChanged:
    Q_EMIT CameraPixelWidthChanged();
    break;
  case signalCameraPixelHeightChanged:
    Q_EMIT CameraPixelHeightChanged();
    break;
  case signalCameraWidthChanged:
    Q_EMIT CameraWidthChanged();
    break;
  case signalCameraHeightChanged:
    Q_EMIT CameraHeightChanged();
    break;
  case signalCameraRotationChanged:
    Q_EMIT CameraRotationChanged();
    break;
  case signalErrorHandlingStrategyChanged:
    Q_EMIT ErrorHandlingStrategyChanged();
    break;
  case signalErrorHandlingStrategyDelayChanged:
    Q_EMIT ErrorHandlingStrategyDelayChanged();
    break;
  case signalRescheduleErrorsChanged:
    Q_EMIT RescheduleErrorsChanged();
    break;
  case signalAlignCheckFrequencyChanged:
    Q_EMIT AlignCheckFrequencyChanged();
    break;
  case signalAlignCheckThresholdChanged:
    Q_EMIT AlignCheckThresholdChanged();
    break;
  case signalSchedulerTrackStepChanged:
    Q_EMIT SchedulerTrackStepChanged();
    break;
  case signalSchedulerStartupEnabledChanged:
    Q_EMIT SchedulerStartupEnabledChanged();
    break;
  case signalSchedulerPreStartupScriptChanged:
    Q_EMIT SchedulerPreStartupScriptChanged();
    break;
  case signalSchedulerPostStartupScriptChanged:
    Q_EMIT SchedulerPostStartupScriptChanged();
    break;
  case signalSchedulerShutdownEnabledChanged:
    Q_EMIT SchedulerShutdownEnabledChanged();
    break;
  case signalSchedulerPreShutdownScriptChanged:
    Q_EMIT SchedulerPreShutdownScriptChanged();
    break;
  case signalSchedulerPostShutdownScriptChanged:
    Q_EMIT SchedulerPostShutdownScriptChanged();
    break;
  case signalSchedulerFocusStepChanged:
    Q_EMIT SchedulerFocusStepChanged();
    break;
  case signalSchedulerGuideStepChanged:
    Q_EMIT SchedulerGuideStepChanged();
    break;
  case signalSchedulerAlignStepChanged:
    Q_EMIT SchedulerAlignStepChanged();
    break;
  case signalSchedulerAltitudeChanged:
    Q_EMIT SchedulerAltitudeChanged();
    break;
  case signalSchedulerAltitudeValueChanged:
    Q_EMIT SchedulerAltitudeValueChanged();
    break;
  case signalSchedulerHorizonChanged:
    Q_EMIT SchedulerHorizonChanged();
    break;
  case signalSchedulerMoonSeparationChanged:
    Q_EMIT SchedulerMoonSeparationChanged();
    break;
  case signalSchedulerMoonSeparationValueChanged:
    Q_EMIT SchedulerMoonSeparationValueChanged();
    break;
  case signalSchedulerMoonAltitudeChanged:
    Q_EMIT SchedulerMoonAltitudeChanged();
    break;
  case signalSchedulerMoonAltitudeMaxValueChanged:
    Q_EMIT SchedulerMoonAltitudeMaxValueChanged();
    break;
  case signalSchedulerWeatherChanged:
    Q_EMIT SchedulerWeatherChanged();
    break;
  case signalSchedulerWeatherGracePeriodChanged:
    Q_EMIT SchedulerWeatherGracePeriodChanged();
    break;
  case signalSchedulerWeatherShutdownDelayChanged:
    Q_EMIT SchedulerWeatherShutdownDelayChanged();
    break;
  case signalSchedulerSafetyMonitorConnectionStringChanged:
    Q_EMIT SchedulerSafetyMonitorConnectionStringChanged();
    break;
  case signalSchedulerTwilightChanged:
    Q_EMIT SchedulerTwilightChanged();
    break;
  case signalSchedulerCompleteSequencesChanged:
    Q_EMIT SchedulerCompleteSequencesChanged();
    break;
  case signalSchedulerRepeatEverythingChanged:
    Q_EMIT SchedulerRepeatEverythingChanged();
    break;
  case signalSchedulerRepeatSequencesChanged:
    Q_EMIT SchedulerRepeatSequencesChanged();
    break;
  case signalSchedulerUntilTerminatedChanged:
    Q_EMIT SchedulerUntilTerminatedChanged();
    break;
  case signalSchedulerUntilChanged:
    Q_EMIT SchedulerUntilChanged();
    break;
  case signalSchedulerUntilValueChanged:
    Q_EMIT SchedulerUntilValueChanged();
    break;
  case signalSchedulerExecutionSequencesLimitChanged:
    Q_EMIT SchedulerExecutionSequencesLimitChanged();
    break;
  case signalAnalyzeRestartWithEkosChanged:
    Q_EMIT AnalyzeRestartWithEkosChanged();
    break;
  case signalAnalyzeAlternativeDirectoryNameChanged:
    Q_EMIT AnalyzeAlternativeDirectoryNameChanged();
    break;
  case signalAnalyzeHFRChanged:
    Q_EMIT AnalyzeHFRChanged();
    break;
  case signalAnalyzeNumCaptureStarsChanged:
    Q_EMIT AnalyzeNumCaptureStarsChanged();
    break;
  case signalAnalyzeMedianChanged:
    Q_EMIT AnalyzeMedianChanged();
    break;
  case signalAnalyzeEccentricityChanged:
    Q_EMIT AnalyzeEccentricityChanged();
    break;
  case signalAnalyzeTemperatureChanged:
    Q_EMIT AnalyzeTemperatureChanged();
    break;
  case signalFocusPositionChanged:
    Q_EMIT FocusPositionChanged();
    break;
  case signalAnalyzeNumStarsChanged:
    Q_EMIT AnalyzeNumStarsChanged();
    break;
  case signalAnalyzeSkyBgChanged:
    Q_EMIT AnalyzeSkyBgChanged();
    break;
  case signalAnalyzeSNRChanged:
    Q_EMIT AnalyzeSNRChanged();
    break;
  case signalAnalyzeRAChanged:
    Q_EMIT AnalyzeRAChanged();
    break;
  case signalAnalyzeDECChanged:
    Q_EMIT AnalyzeDECChanged();
    break;
  case signalAnalyzeRApChanged:
    Q_EMIT AnalyzeRApChanged();
    break;
  case signalAnalyzeDECpChanged:
    Q_EMIT AnalyzeDECpChanged();
    break;
  case signalAnalyzeDriftChanged:
    Q_EMIT AnalyzeDriftChanged();
    break;
  case signalAnalyzeRMSChanged:
    Q_EMIT AnalyzeRMSChanged();
    break;
  case signalAnalyzeTargetDistanceChanged:
    Q_EMIT AnalyzeTargetDistanceChanged();
    break;
  case signalAnalyzeRMSCChanged:
    Q_EMIT AnalyzeRMSCChanged();
    break;
  case signalAnalyzeMountRAChanged:
    Q_EMIT AnalyzeMountRAChanged();
    break;
  case signalAnalyzeMountDECChanged:
    Q_EMIT AnalyzeMountDECChanged();
    break;
  case signalAnalyzeMountHAChanged:
    Q_EMIT AnalyzeMountHAChanged();
    break;
  case signalAnalyzeAzChanged:
    Q_EMIT AnalyzeAzChanged();
    break;
  case signalAnalyzeAltChanged:
    Q_EMIT AnalyzeAltChanged();
    break;
  case signalAnalyzePierSideChanged:
    Q_EMIT AnalyzePierSideChanged();
    break;
  case signalAnalyzeStatsYAxisChanged:
    Q_EMIT AnalyzeStatsYAxisChanged();
    break;
  case signalLastServerChanged:
    Q_EMIT LastServerChanged();
    break;
  case signalLastServerPortChanged:
    Q_EMIT LastServerPortChanged();
    break;
  case signalLastWebManagerPortChanged:
    Q_EMIT LastWebManagerPortChanged();
    break;
  case signalHIPSMemoryCacheChanged:
    Q_EMIT HIPSMemoryCacheChanged();
    break;
  case signalHIPSNetCacheChanged:
    Q_EMIT HIPSNetCacheChanged();
    break;
  case signalHIPSSourceChanged:
    Q_EMIT HIPSSourceChanged();
    break;
  case signalHIPSBiLinearInterpolationChanged:
    Q_EMIT HIPSBiLinearInterpolationChanged();
    break;
  case signalHIPSShowGridChanged:
    Q_EMIT HIPSShowGridChanged();
    break;
  case signalHIPSPanningChanged:
    Q_EMIT HIPSPanningChanged();
    break;
  case signalShowHIPSChanged:
    Q_EMIT ShowHIPSChanged();
    break;
  case signalHIPSUseOfflineSourceChanged:
    Q_EMIT HIPSUseOfflineSourceChanged();
    break;
  case signalHIPSOfflinePathChanged:
    Q_EMIT HIPSOfflinePathChanged();
    break;
  case signalTerrainSourceChanged:
    Q_EMIT TerrainSourceChanged();
    break;
  case signalTerrainSourceCorrectAzChanged:
    Q_EMIT TerrainSourceCorrectAzChanged();
    break;
  case signalTerrainSourceCorrectAltChanged:
    Q_EMIT TerrainSourceCorrectAltChanged();
    break;
  case signalTerrainDownsamplingChanged:
    Q_EMIT TerrainDownsamplingChanged();
    break;
  case signalTerrainPanningChanged:
    Q_EMIT TerrainPanningChanged();
    break;
  case signalShowTerrainChanged:
    Q_EMIT ShowTerrainChanged();
    break;
  case signalTerrainSkipSpeedupChanged:
    Q_EMIT TerrainSkipSpeedupChanged();
    break;
  case signalTerrainTransparencySpeedupChanged:
    Q_EMIT TerrainTransparencySpeedupChanged();
    break;
  case signalTerrainSmoothPixelsChanged:
    Q_EMIT TerrainSmoothPixelsChanged();
    break;
  case signalShowImageOverlaysChanged:
    Q_EMIT ShowImageOverlaysChanged();
    break;
  case signalShowImageOverlaysBelowCatalogsChanged:
    Q_EMIT ShowImageOverlaysBelowCatalogsChanged();
    break;
  case signalShowSelectedImageOverlayChanged:
    Q_EMIT ShowSelectedImageOverlayChanged();
    break;
  case signalImageOverlayMaxDimensionChanged:
    Q_EMIT ImageOverlayMaxDimensionChanged();
    break;
  case signalImageOverlayTimeoutChanged:
    Q_EMIT ImageOverlayTimeoutChanged();
    break;
  case signalImageOverlayDefaultScaleChanged:
    Q_EMIT ImageOverlayDefaultScaleChanged();
    break;
  case signalDefaultObservatoryWeatherSourceChanged:
    Q_EMIT DefaultObservatoryWeatherSourceChanged();
    break;
  case signalWarningActionsActiveChanged:
    Q_EMIT warningActionsActiveChanged();
    break;
  case signalAlertActionsActiveChanged:
    Q_EMIT alertActionsActiveChanged();
    break;
  case signalWeatherWarningCloseDomeChanged:
    Q_EMIT weatherWarningCloseDomeChanged();
    break;
  case signalWeatherWarningCloseShutterChanged:
    Q_EMIT weatherWarningCloseShutterChanged();
    break;
  case signalWeatherWarningStopSchedulerChanged:
    Q_EMIT weatherWarningStopSchedulerChanged();
    break;
  case signalWeatherWarningDelayChanged:
    Q_EMIT weatherWarningDelayChanged();
    break;
  case signalWeatherAlertCloseDomeChanged:
    Q_EMIT weatherAlertCloseDomeChanged();
    break;
  case signalWeatherAlertCloseShutterChanged:
    Q_EMIT weatherAlertCloseShutterChanged();
    break;
  case signalWeatherAlertStopSchedulerChanged:
    Q_EMIT weatherAlertStopSchedulerChanged();
    break;
  case signalWeatherAlertDelayChanged:
    Q_EMIT weatherAlertDelayChanged();
    break;
  case signalObservatoryStatusUseDomeChanged:
    Q_EMIT observatoryStatusUseDomeChanged();
    break;
  case signalObservatoryStatusUseShutterChanged:
    Q_EMIT observatoryStatusUseShutterChanged();
    break;
  case signalObservatoryStatusUseWeatherChanged:
    Q_EMIT observatoryStatusUseWeatherChanged();
    break;
  case signalWeatherAutoScaleValuesChanged:
    Q_EMIT weatherAutoScaleValuesChanged();
    break;
  case signalASTAPExecutableChanged:
    Q_EMIT ASTAPExecutableChanged();
    break;
  case signalASTAPDownSampleChanged:
    Q_EMIT ASTAPDownSampleChanged();
    break;
  case signalASTAPDownSampleValueChanged:
    Q_EMIT ASTAPDownSampleValueChanged();
    break;
  case signalASTAPSearchRadiusChanged:
    Q_EMIT ASTAPSearchRadiusChanged();
    break;
  case signalASTAPSearchRadiusValueChanged:
    Q_EMIT ASTAPSearchRadiusValueChanged();
    break;
  case signalASTAPUpdateFITSChanged:
    Q_EMIT ASTAPUpdateFITSChanged();
    break;
  case signalASTAPLargeSearchWindowChanged:
    Q_EMIT ASTAPLargeSearchWindowChanged();
    break;
  case signalMosaicTransparencyAutoChanged:
    Q_EMIT MosaicTransparencyAutoChanged();
    break;
  case signalMosaicTransparencyLevelChanged:
    Q_EMIT MosaicTransparencyLevelChanged();
    break;
  case signalMCPEnabledChanged:
    Q_EMIT MCPEnabledChanged();
    break;
  case signalMCPPortChanged:
    Q_EMIT MCPPortChanged();
    break;
  case signalMCPReadOnlyModeChanged:
    Q_EMIT MCPReadOnlyModeChanged();
    break;
  case signalMCPDisabledToolsChanged:
    Q_EMIT MCPDisabledToolsChanged();
    break;
  }
}
